#include "mainwindow.h"
#include "ui_mainwindow.h"
#include <iostream>
#include <cmath>
#include <QFile>
#include <QTextStream>
#include <QDesktopServices>
#include <QUrl>

// Set up the main window --> automatically generated header
MainWindow::MainWindow(QWidget *parent) :
QMainWindow(parent),
ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    // Set the icon for the dock
    //parent->setWindowIcon(QIcon(QString("../FLiPS.icns")));
    // Set up the default values
    ui->celsiusButton->setChecked(true);
    ui->charpyButton->setChecked(true);
    ui->rangeButton->setChecked(true);
    QString charpyText = QString::fromUtf8("Charpy / J\u202Fcm\u207B\u00B2");
    QString charpyUnit = QString::fromUtf8("J\u202Fcm\u207B\u00B2");
    QString fractureToughnessText = QString::fromUtf8("Fracture toughness / MPa\u202F\u221Am");
    QString celsiusText = QString::fromUtf8("\u202F\u00B0C");
    QString farenheitText = QString::fromUtf8("\u202F\u00B0F");
    QString kelvinText = QString::fromUtf8("\u202FK");
    ui->experimentTable->setItem(0,1, new QTableWidgetItem(celsiusText));
    ui->charpyButton->setText(charpyText);
    ui->fracturetoughnessButton->setText(fractureToughnessText);
    ui->celsiusButton->setText(celsiusText);
    ui->farenheitButton->setText(farenheitText);
    ui->mechpropTable->setItem(1,1, new QTableWidgetItem(charpyUnit));
    /*QString plusminus = QString::fromUtf8("\u00B1");
    ui->pmBending->setText(plusminus);
    ui->pmUniaxial->setText(plusminus);
    ui->pmTorsional->setText(plusminus);*/
    QPixmap uncertainty_symbol = QPixmap("/Users/chris/Dropbox/fatigue-gui/fatigue-all/uncertainty.png",0,Qt::AutoColor);
    int uncertainty_dimension = 10;
    QPixmap uncertainty_scaled=uncertainty_symbol.scaledToHeight(uncertainty_dimension,Qt::SmoothTransformation);
    //QPixmap uncertainty_scaled = QPixmap::scaled(uncertainty_dimension uncertainty_dimension,Qt::IgnoreAspectRatio,Qt::FastTransformation) uncertainty_symbol; // QPixmap::Scaled(height width,aspect ratio (0=ignore, 1=shrink to fit,2=expand to fit),transform mode(0=fast/no smoothing, 1=smoothing)
    ui->pmBending->setPixmap(uncertainty_scaled);
    ui->pmTorsional->setPixmap(uncertainty_scaled);
    ui->pmUniaxial->setPixmap(uncertainty_scaled);
    ui->message_label->setWordWrap(true);
    QString update_message("Welcome to the Fatigue Life Predictor for SLIMMER (FLiPS) v1.1.  Fatigue lives are predicted, but no uncertainties are calculated.  This will be implemented in a future release.");
    ui->message_label->setText(update_message);
}

MainWindow::~MainWindow()
{
    delete ui;
}

double yield = 1000.0;
double toughness = 10.0;
double elongation = 15.0;
double reduction = 8.0;
double uts = -45.7867;
double temperature = 25.0;
double frequency = 20.0;;
double stressconc = 1.0;
double stress = 100.0;
double r_eff = -1.0;
bool read_ok = true;
QString zeromean("Zero mean stress (and therefore R=-1) has an infinite number of conditions, so no prediction may be made.  Please provide different information.");

// Set up the quit button functionality
void MainWindow::on_quitButton_clicked()
{
    QCoreApplication::quit();
}

// Set up the reset button functionality

int ireset=0;







void MainWindow::on_celsiusButton_released()
{
//    QColor halfgrey = QColor(128,128,128);
    QString celsiusText = QString::fromUtf8("\u202F\u00B0C");
    ui->experimentTable->setItem(0,1, new QTableWidgetItem(celsiusText));
}

void MainWindow::on_kelvinButton_released()
{
    QString kelvinText = QString::fromUtf8("\u202FK");
    ui->experimentTable->setItem(0,1, new QTableWidgetItem(kelvinText));
}

void MainWindow::on_farenheitButton_released()
{
    QString farenheitText = QString::fromUtf8("\u202F\u00B0F");
    ui->experimentTable->setItem(0,1, new QTableWidgetItem(farenheitText));
}

void MainWindow::on_charpyButton_released()
{
    QString charpyTextTable = QString::fromUtf8("J\u202Fcm\u207B\u00B2");
    ui->mechpropTable->setItem(1,1, new QTableWidgetItem(charpyTextTable));
}

void MainWindow::on_fracturetoughnessButton_released()
{
    QString fractureToughnessTextTable = QString::fromUtf8("MPa\u202F\u221Am");
    ui->mechpropTable->setItem(1,1, new QTableWidgetItem(fractureToughnessTextTable));
}

void MainWindow::on_resetButton_clicked()
{
    QString update_message("Welcome to the Fatigue Life Predictor for SLIMMER (FLiPS), version 1.0");
    update_message.sprintf("Hello again.");
    ui->message_label->setText(update_message);
    ui->celsiusButton->setChecked(true);
    ui->charpyButton->setChecked(true);
    ui->rangeButton->setChecked(true);
    ireset=0;
    while (ireset<5)
    {
        ui->experimentTable->setItem(ireset,0, new QTableWidgetItem(""));
        ireset++;
    };
    ireset=0;
    while (ireset<5)
    {
        ui->mechpropTable->setItem(ireset,0, new QTableWidgetItem(""));
        ireset++;
    };
    ui->mechpropTable->setItem(1,2,new QTableWidgetItem(""));
    ui->experimentTable->setItem(0,2,new QTableWidgetItem(""));
    ui->experimentTable->setItem(2,2,new QTableWidgetItem(""));
    ui->experimentTable->setItem(4,2,new QTableWidgetItem(""));
    ui->predictBending->setText("");
    ui->predictUniaxial->setText("");
    ui->predictTorsional->setText("");
    ui->uncertaintyBending->setText("");
    ui->uncertaintyUniaxial->setText("");
    ui->uncertaintyTorsional->setText("");
    ui->uncertainties_checkbox->setCheckState( Qt::Unchecked );
}









static double uniaxial_lu_parameters[9][301][301] = {
    {
        { -.25567000E+06, 0.12768600E+06, 0.11411000E+06, 0.12771400E+06, 0.76573500E+04, -.85499700E+04, 0.80187500E+05, 0.30415100E+05, 0.94480200E+05, -.15176700E+03, 0.72598900E+05, -.26759400E+06, 0.13356400E+06, 0.11576900E+06, 0.13377300E+06, 0.79673600E+04, -.74824800E+04, 0.84164600E+05, 0.35018700E+05, 0.10155100E+06, -.99639900E+03, 0.77255500E+05, -.37576600E+06, 0.18721900E+06, 0.16016600E+06, 0.18745200E+06, 0.17754700E+05, -.12416800E+05, 0.11147500E+06, 0.29466900E+05, 0.13553600E+06, -.10125100E+04, 0.98566300E+05, -.27129100E+06, 0.13524300E+06, 0.11354800E+06, 0.13558400E+06, 0.10302500E+05, -.77216700E+04, 0.78445600E+05, 0.16932100E+05, 0.95004700E+05, 0.44038200E+03, 0.84326300E+05, 0.21543500E+06, -.10737000E+06, -.90349900E+05, -.10765100E+06, -.76020800E+04, 0.61229200E+04, -.62151100E+05, -.13889800E+05, -.76301900E+05, -.65788600E+02, -.65879600E+05, -.34579100E+06, 0.17232400E+06, 0.13871000E+06, 0.17264600E+06, 0.11150500E+05, -.11345900E+05, 0.10680500E+06, 0.37605200E+05, 0.12792600E+06, -.16334300E+04, 0.91812900E+05, -.43565000E+06, 0.21743300E+06, 0.18939500E+06, 0.21779800E+06, 0.12346300E+05, -.15182500E+05, 0.13824300E+06, 0.58641100E+05, 0.16805600E+06, -.33005000E+04, 0.12477200E+06, -.17879200E+06, 0.89253100E+05, 0.79713200E+05, 0.89272400E+05, 0.99286700E+04, -.24488500E+04, 0.52843400E+05, 0.14056900E+05, 0.61657700E+05, 0.24461100E+04, 0.44866000E+05, -.61112800E+06, 0.30472400E+06, 0.25763900E+06, 0.30510100E+06, 0.26459200E+05, -.16401500E+05, 0.16437200E+06, 0.11676800E+05, 0.20961600E+06, 0.20315100E+04, 0.18094300E+06, 0.46006100E+06, -.22952300E+06, -.20249400E+06, -.22978000E+06, -.18818400E+05, 0.12138300E+05, -.13637500E+06, -.38121700E+05, -.16481400E+06, -.16980700E+04, -.13053100E+06, 0.51956800E+05, -.25808900E+05, -.20489900E+05, -.25963500E+05, 0.44035100E+03, 0.55963100E+04, -.15050900E+05, -.15380000E+04, -.18263900E+05, 0.29937900E+04, -.17437200E+05, 0.18053300E+06, -.89863100E+05, -.77167700E+05, -.89946300E+05, -.10474400E+05, 0.30055500E+04, -.45076600E+05, 0.35971000E+04, -.60370700E+05, -.76831000E+03, -.49492500E+05, 0.24271700E+06, -.12101800E+06, -.10229200E+06, -.12133700E+06, -.11725200E+05, 0.65812600E+04, -.70042500E+05, -.14698300E+05, -.84628900E+05, -.78756100E+03, -.67202700E+05, 0.24312800E+06, -.12120600E+06, -.10116400E+06, -.12153400E+06, -.11523500E+05, 0.63210700E+04, -.69465000E+05, -.14001100E+05, -.85128200E+05, -.78190900E+03, -.67997000E+05, 0.35876000E+06, -.17885700E+06, -.15288200E+06, -.17929200E+06, -.13708100E+05, 0.12617100E+05, -.10708800E+06, -.30080200E+05, -.13160900E+06, 0.13454700E+04, -.10348300E+06, 0.48035500E+05, -.23931000E+05, -.18887100E+05, -.23914400E+05, -.25509400E+04, -.20989200E+04, -.88718500E+04, 0.55247100E+04, -.14384700E+05, -.15852800E+04, -.16102000E+05, 0.71038600E+06, -.35424400E+06, -.32961800E+06, -.35455000E+06, -.25476800E+05, 0.23404400E+05, -.21307900E+06, -.58491500E+05, -.25326400E+06, 0.12270500E+04, -.20037500E+06, 0.13608100E+06, -.67711200E+05, -.58257100E+05, -.67779900E+05, -.43914100E+04, 0.64474400E+04, -.37210000E+05, -.16142800E+04, -.44174700E+05, 0.78577000E+03, -.40522100E+05, -.43808900E+06, 0.21838100E+06, 0.18587200E+06, 0.21868900E+06, 0.17691300E+05, -.13971100E+05, 0.12942700E+06, 0.32743200E+05, 0.15597000E+06, -.56109400E+03, 0.12503300E+06, 0.38587800E+06, -.19258800E+06, -.18093400E+06, -.19271900E+06, -.96422100E+04, 0.20123800E+05, -.12362800E+06, -.44849500E+05, -.14012600E+06, 0.37628100E+04, -.10921400E+06, -.37692100E+06, 0.18798900E+06, 0.16461000E+06, 0.18829800E+06, 0.11658100E+05, -.14110300E+05, 0.11699400E+06, 0.41715500E+05, 0.13971700E+06, -.25665600E+04, 0.10786600E+06, -.40457600E+06, 0.20202700E+06, 0.18011300E+06, 0.20199000E+06, 0.13394000E+05, -.11344400E+05, 0.12375600E+06, 0.42059800E+05, 0.14598200E+06, 0.14230900E+04, 0.11607500E+06, -.67453100E+05, 0.16812400E+03, 0.47145700E+04, 0.20190100E+05, 0.24454200E+04, -.88284200E+03, -.41321300E+05, -.74002100E+04, 0.33099800E+05, 0.17489400E+05, 0.83649800E+04, 0.59000700E+05, 0.36204800E+05, 0.80871200E+04, -.70752400E+04, 0.15479600E+04, 0.45603000E+05, -.96933200E+02, -.48254000E+05, -.84792300E+04, -.22109700E+05, 0.10868600E+05, 0.17095500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16038500E+00, 0.64279200E+03, 0.29487600E+04, -.18934000E+04, 0.10425300E+05, -.21680400E+04, 0.43816100E+04, 0.51624100E+04, -.48595500E+04, -.14113600E+03, -.20384800E+05, 0.46177000E+05, -.21866600E+05, -.79489800E+04, -.23458100E+05, 0.85085200E+04, -.12004000E+05, 0.37995700E+04, 0.15511700E+05, -.18340900E+05, -.76775400E+04, -.43035200E+05, -.90904800E+05, 0.50763300E+05, 0.49972300E+05, 0.38708600E+05, 0.57002800E+05, 0.87015500E+04, 0.75333400E+04, -.13914900E+05, -.13445700E+05, 0.12539400E+05, -.20810200E+05, 0.14889300E+05, -.45525600E+04, 0.73469400E+04, -.83489100E+04, 0.13292800E+05, -.76068500E+04, 0.29290300E+04, 0.41905900E+04, -.21985900E+05, -.41077600E+04, -.34735800E+05, -.21937300E+05, 0.82606100E+04, -.86396700E+04, 0.11949700E+05, -.96060300E+04, 0.10979500E+05, -.42709100E+04, -.54632800E+04, 0.23802100E+05, 0.72204700E+04, 0.36120100E+05, -.33540500E+05, 0.23104700E+05, 0.38993900E+05, 0.12900400E+05, 0.49072100E+05, 0.96587600E+04, -.27419300E+04, -.82558700E+04, -.28542000E+05, 0.13415200E+05, -.40286000E+05, 0.70264800E+05, -.33608600E+05, -.95881500E+04, -.35556600E+05, 0.15164700E+05, -.20728300E+05, 0.75847100E+04, 0.25218300E+05, -.27797300E+05, -.13713800E+05, -.68092500E+05, -.18935900E+05, 0.11597700E+05, 0.10212200E+05, 0.75528800E+04, 0.21499000E+05, -.53161100E+03, 0.36835100E+04, 0.14316300E+04, -.34500200E+04, 0.14044700E+04, -.17003100E+05, -.10713000E+05, 0.13366400E+05, 0.31191700E+05, -.18301800E+04, 0.52131300E+05, -.19919100E+05, 0.18702200E+05, 0.13365900E+05, -.31450900E+05, -.11551300E+05, -.78883600E+05, -.66283400E+04, -.22071900E+04, -.11854100E+05, 0.71944800E+04, -.37508900E+05, 0.18208600E+05, -.14815600E+05, -.17432300E+05, 0.19199900E+05, 0.11889400E+05, 0.59361200E+05, 0.13437300E+05, -.74821200E+04, -.68222700E+04, -.64883900E+04, -.47799700E+04, 0.45914400E+04, -.54150200E+04, -.31189200E+04, -.51399500E+04, 0.43981700E+04, 0.25022400E+04, 0.35358600E+05, -.21327500E+05, -.24895000E+05, -.12696000E+05, -.29018500E+05, -.22012300E+04, -.31240700E+04, 0.10522200E+05, 0.20262600E+05, -.53666600E+04, 0.23822100E+05, -.14870300E+05, 0.43581800E+04, -.73274100E+04, 0.77388700E+04, -.79758100E+04, 0.10746100E+05, -.58985300E+04, -.63381400E+04, 0.18152400E+05, 0.74335900E+04, 0.35898800E+05, -.29917500E+05, 0.11738700E+05, -.82396500E+04, 0.15387900E+05, -.71691300E+04, 0.15139000E+05, -.66251500E+04, -.96300100E+04, 0.23783600E+05, 0.10860000E+05, 0.44682900E+05, -.14455700E+05, 0.36793400E+04, -.10488000E+05, 0.85812600E+04, -.27008000E+05, 0.18881400E+05, -.11885500E+05, -.20247200E+05, 0.15607000E+05, 0.13286300E+05, 0.49528300E+05, -.57927600E+04, 0.18766100E+04, -.38752400E+02, 0.45006500E+04, -.57246900E+04, 0.15645700E+03, 0.80725200E+03, 0.82619300E+03, 0.88439000E+04, -.67535600E+03, 0.10239200E+05, 0.94694600E+05, -.56500800E+05, -.61415400E+05, -.37400900E+05, -.72287700E+05, 0.18421700E+04, -.17252100E+05, 0.73003100E+04, 0.35252800E+05, -.59534700E+04, 0.63138000E+05, 0.61018500E+05, -.33829000E+05, -.33149300E+05, -.26441400E+05, -.28351800E+05, -.92917900E+04, -.12031200E+04, 0.12902100E+05, 0.54591300E+04, -.10106800E+05, -.13297500E+03, -.65065500E+05, 0.37186000E+05, 0.45126900E+05, 0.27055400E+05, 0.55431300E+05, 0.11823900E+05, 0.18879400E+04, -.13961800E+05, -.24611600E+05, 0.15953900E+05, -.32229300E+05, 0.50253900E+05, -.30117000E+05, -.28284000E+05, -.21721100E+05, -.25630700E+05, 0.89139700E+04, -.17294900E+05, -.86239600E+04, -.56292300E+04, 0.63293500E+04, 0.21832200E+05, -.57055700E+04, 0.55785900E+04, 0.17375600E+05, 0.33491100E+03, 0.22010900E+05, -.76165200E+04, 0.96393100E+04, 0.84861000E+04, -.86239000E+04, -.40039300E+04, -.36077500E+05, -.27408100E+04, 0.28295900E+04, 0.10717200E+05, -.32988000E+04, 0.19788700E+05, -.28283300E+04, 0.64927500E+04, 0.52893500E+04, -.12485900E+05, 0.77497300E+03, -.34527200E+05, -.10237900E+05, -.18337200E+03, 0.10577300E+05, -.11446100E+05, -.44266700E+05, -.32242800E+05, -.84776700E+04, -.11283200E+05, -.16864800E+05, -.53314300E+04, -.14569300E+05, 0.66800200E+04, -.21438900E+04, -.45799200E+05, 0.39094200E+05, -.17468100E+05, 0.35760200E+03, 0.48679900E+04, 0.17501600E+04, 0.24406000E+05, -.49409700E+04, 0.37130800E+04, -.68509400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.47123200E+00, -.29102000E+00, 0.35123800E+05, -.32776400E+02, -.47620100E+04, -.37470700E+04, -.30704500E+03, -.12405700E+05, -.17288500E+05, -.18745300E+03, -.35833700E+04, 0.59744400E+05, -.30270900E+05, 0.57122700E+05, -.29894200E+05, -.12628200E+05, -.17714900E+05, -.12799000E+04, -.32043300E+04, -.39389700E+05, -.10259000E+05, -.32871700E+05, 0.78256500E+05, -.41805500E+05, 0.15130100E+06, -.39260200E+05, -.57078800E+05, -.80152800E+05, 0.37445100E+05, 0.47584600E+04, -.70759700E+05, -.62596300E+05, -.56718000E+05, 0.13726100E+04, -.17958200E+04, 0.11688100E+06, -.82186400E+03, -.17774900E+05, -.30633100E+05, 0.13691200E+05, -.17427000E+05, -.44275700E+05, -.20612200E+05, -.91950500E+04, 0.19216100E+05, -.85859000E+04, -.93681700E+05, -.94651900E+04, 0.24682100E+04, 0.16761900E+05, -.92748600E+04, 0.15965100E+05, 0.30742800E+05, 0.99267100E+04, 0.10042300E+04, 0.15161300E+06, -.78126700E+05, 0.15993700E+06, -.75944200E+05, -.56504900E+05, -.72551200E+05, 0.22969900E+05, 0.11148700E+05, -.97562300E+05, -.55460800E+05, -.89006500E+05, 0.13082800E+06, -.66294100E+05, 0.10286200E+06, -.65435300E+05, -.27696600E+05, -.40487500E+05, -.44998900E+03, 0.42478500E+04, -.70132800E+05, -.25900100E+05, -.70963500E+05, 0.71425300E+05, -.35901700E+05, 0.58209600E+05, -.35782000E+05, -.29475800E+05, -.32060900E+05, 0.98272300E+04, 0.51881400E+04, -.43652300E+05, -.24847200E+05, -.41806700E+05, -.34212100E+05, 0.14512500E+05, 0.25064800E+06, 0.16853300E+05, -.35666100E+05, -.67019700E+05, 0.32515900E+05, -.31454000E+05, -.69520600E+05, -.46191500E+05, -.17628000E+05, -.10311900E+06, 0.52629900E+05, -.17082200E+06, 0.51715600E+05, 0.45931900E+05, 0.65049800E+05, -.17640200E+05, -.22388600E+03, 0.83935300E+05, 0.47077500E+05, 0.71216700E+05, 0.45265200E+05, -.21347000E+05, -.30903600E+05, -.22623500E+05, 0.93037000E+03, 0.12148700E+05, -.12285100E+05, 0.38846800E+04, -.13571200E+05, 0.10014600E+05, -.14926500E+05, 0.34312700E+05, -.16112600E+05, -.52532300E+05, -.16996700E+05, 0.74299900E+04, 0.16383000E+05, -.16636800E+05, 0.14915900E+05, 0.20610800E+05, 0.12191800E+05, -.38042700E+04, 0.16231700E+05, -.70200600E+04, -.10464100E+06, -.80500000E+04, 0.84807600E+04, 0.20703800E+05, -.99107900E+04, 0.19325400E+05, 0.35618900E+05, 0.12651100E+05, 0.24788500E+04, 0.98684400E+04, -.37380700E+04, -.10860500E+06, -.48517900E+04, 0.40601300E+04, 0.20100900E+05, -.88092600E+04, 0.17280900E+05, 0.37898500E+05, 0.11996200E+05, 0.73288600E+04, -.64873600E+05, 0.34770500E+05, -.13709800E+06, 0.32518100E+05, 0.36555400E+05, 0.64755500E+05, -.26507800E+05, -.91351600E+04, 0.49953100E+05, 0.49482200E+05, 0.47120200E+05, -.26044300E+04, 0.12304900E+04, -.23059400E+05, 0.13604800E+04, 0.27612800E+04, 0.43060000E+03, 0.10830700E+04, 0.58201300E+04, 0.15529900E+05, -.47910100E+03, 0.33709700E+04, 0.22900300E+06, -.11230200E+06, -.17817200E+06, -.11405900E+06, 0.11100600E+05, 0.43860000E+05, -.60690400E+05, 0.58230500E+05, 0.18280100E+05, 0.31208600E+05, -.75710500E+05, 0.57715900E+05, -.27226600E+05, -.75354600E+05, -.28748100E+05, 0.14116500E+05, 0.28344200E+05, -.25882200E+05, 0.13400900E+05, 0.92631900E+04, 0.21759700E+05, -.17457100E+05, 0.58103100E+05, -.31412500E+05, 0.17690000E+06, -.29319500E+05, -.57921700E+05, -.77131700E+05, 0.35742300E+05, -.11142800E+05, -.81323100E+05, -.58046900E+05, -.44913700E+05, 0.16779300E+06, -.82809500E+05, -.99496100E+05, -.83756400E+05, -.21420600E+04, 0.20150400E+05, -.31743500E+05, 0.32391800E+05, -.21215100E+05, 0.13879800E+05, -.61980200E+05, 0.23010200E+05, -.13917300E+05, 0.12579500E+06, -.11597800E+05, -.20189100E+05, -.33765100E+05, 0.91878100E+04, -.13235900E+05, -.42235600E+05, -.22279500E+05, -.24341800E+05, 0.49542300E+04, -.26862500E+04, 0.84494000E+05, -.25794600E+04, -.89457300E+04, -.77272000E+04, -.42642000E+03, -.23739600E+05, -.41986000E+05, -.94185900E+03, -.10556400E+05, 0.90345100E+04, -.42781300E+05, -.28256200E+05, 0.40350600E+04, 0.55971400E+04, 0.29963700E+05, -.66429800E+04, 0.22694800E+05, -.84712600E+04, 0.30521000E+05, 0.10232300E+05, -.30679800E+05, 0.60557400E+05, 0.90037300E+04, -.20692000E+05, 0.87904200E+04, 0.47444200E+05, -.49273600E+05, 0.23193100E+05, 0.31477400E+04, 0.40896300E+05, -.25936400E+05, 0.41327700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22025600E+00, 0.16095800E+01, -.35993600E+00, 0.51006900E+04, -.28974800E+05, -.19262600E+05, 0.14261500E+05, 0.23667600E+05, 0.31575100E+05, -.19787700E+05, 0.24167200E+05, -.80763600E+05, 0.39494600E+05, 0.31700300E+05, 0.41389500E+05, -.24803600E+05, -.15189300E+05, 0.22160300E+05, 0.24355200E+04, 0.45343200E+05, -.12591900E+05, 0.55458000E+05, 0.11478300E+06, -.62195100E+05, -.11260100E+06, -.39210900E+05, -.19595400E+06, -.26260700E+06, 0.13719800E+06, 0.15985500E+06, 0.17984300E+06, -.24340100E+06, 0.30755900E+05, -.34861700E+05, 0.15087700E+05, -.45257100E+05, 0.19959100E+05, -.80412700E+05, -.13060000E+06, 0.73615700E+05, 0.62643100E+05, 0.12711000E+06, -.11876800E+06, 0.48392900E+05, 0.51323100E+05, -.23692700E+05, 0.36825900E+05, -.28399600E+05, 0.53438500E+05, 0.92296800E+05, -.56578700E+05, -.51352600E+05, -.11633500E+06, 0.85310200E+05, -.50013500E+05, 0.91525800E+05, -.48230900E+05, -.13417800E+06, -.35278700E+05, -.18332200E+06, -.23084800E+06, 0.12388200E+06, 0.13388800E+06, 0.16270300E+06, -.21088100E+06, 0.34273500E+05, -.15930000E+06, 0.77154400E+05, 0.75398900E+05, 0.80804600E+05, -.43657600E+05, -.30625500E+05, 0.43611100E+05, -.56525900E+02, 0.78019500E+05, -.27002700E+05, 0.95229500E+05, 0.11969000E+06, -.59087400E+05, -.38572000E+05, -.54656000E+05, -.68675400E+05, -.68351400E+05, 0.27035400E+05, 0.62779500E+05, 0.24920300E+05, -.66731400E+05, -.25425400E+05, -.14449500E+06, 0.70249700E+05, -.53989100E+05, 0.91719700E+05, -.19153700E+06, -.28119100E+06, 0.16052300E+06, 0.12130300E+06, 0.28258000E+06, -.26404000E+06, 0.14793700E+06, 0.35814500E+03, -.39164000E+03, -.10039300E+05, -.10703800E+05, 0.11891800E+06, 0.14144100E+06, -.81400400E+05, -.93431300E+05, -.12733400E+06, 0.13556600E+06, -.40589000E+05, 0.15447900E+06, -.74375700E+05, -.37061200E+05, -.77864300E+05, 0.14295600E+05, 0.51346700E+05, -.48235600E+05, 0.34667500E+04, -.66059000E+05, 0.45342000E+05, -.63169400E+05, -.86810600E+05, 0.44273500E+05, 0.13677900E+06, 0.29920600E+05, 0.10965400E+06, 0.15333200E+06, -.73798400E+05, -.10897200E+06, -.13016600E+06, 0.14444200E+06, -.18253200E+05, 0.35971000E+05, -.15812600E+05, 0.35963200E+05, -.18848300E+05, 0.55780800E+05, 0.10079700E+06, -.55558000E+05, -.48648800E+05, -.10844500E+06, 0.91718100E+05, -.45091300E+05, 0.65078600E+05, -.30274400E+05, 0.31317700E+05, -.33752300E+05, 0.48709700E+05, 0.90746700E+05, -.54292900E+05, -.43585200E+05, -.11589000E+06, 0.83390600E+05, -.58928600E+05, 0.17905000E+06, -.85172800E+05, -.40860700E+05, -.93217100E+05, 0.90973600E+05, 0.14378800E+06, -.10577000E+06, -.41716100E+05, -.14798600E+06, 0.13488700E+06, -.10589000E+06, -.57978100E+05, 0.28230900E+05, 0.26321400E+05, 0.24644500E+05, 0.22341300E+05, 0.19423700E+05, -.25554200E+04, -.24896800E+05, -.16390700E+05, 0.19705000E+05, 0.12651400E+05, 0.40903700E+04, -.11591800E+04, 0.22865300E+06, -.29046500E+05, 0.26276000E+06, 0.39810300E+06, -.23136400E+06, -.25368500E+06, -.38988900E+06, 0.37395400E+06, -.12237900E+06, -.38325800E+05, 0.21379500E+05, 0.89355100E+05, 0.81750400E+04, 0.10189500E+06, 0.15892900E+06, -.84478000E+05, -.88375200E+05, -.12084300E+06, 0.14381400E+06, -.20076200E+05, 0.10187300E+06, -.55451900E+05, -.13972100E+06, -.36039600E+05, -.21685900E+06, -.28783700E+06, 0.14825700E+06, 0.16248800E+06, 0.20790200E+06, -.26446500E+06, 0.42314800E+05, 0.26214300E+06, -.13201900E+06, 0.19141400E+05, -.14031700E+06, 0.90524000E+05, 0.18017200E+06, -.13056600E+06, -.53864500E+05, -.20560600E+06, 0.16349100E+06, -.14608800E+06, -.87516200E+05, 0.38786000E+05, 0.38579100E+05, 0.50579900E+05, -.67118800E+05, -.84771900E+05, 0.60393100E+05, 0.38548200E+05, 0.10220100E+06, -.78068300E+05, 0.70924100E+05, 0.59498100E+05, -.29938400E+05, -.21709600E+05, -.17149900E+05, -.57573800E+05, -.41673900E+05, 0.20533200E+05, 0.57987800E+05, 0.56389900E+05, -.41581100E+05, 0.18581800E+05, 0.99551600E+04, -.13835400E+06, -.15045200E+06, 0.10583400E+05, 0.94993600E+05, 0.91069400E+05, 0.29676100E+04, 0.14758600E+06, 0.11382500E+06, 0.94093300E+05, 0.11133200E+06, -.95413400E+05, 0.47032800E+05, 0.10787600E+06, -.10721600E+06, 0.10025300E+06, 0.12151700E+06, -.53584800E+05, 0.11722000E+04, -.34292300E+05, 0.76872900E+05, -.11671600E+06, 0.13425500E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37995600E+00, 0.65586400E-01, -.31056000E+00, -.67476200E-01, 0.21747200E+05, 0.12399100E+05, -.17541900E+05, -.23198400E+05, -.80346900E+04, 0.89113000E+04, -.13908500E+05, -.44392700E+05, 0.21892200E+05, 0.12684100E+05, 0.22190300E+05, 0.30513500E+05, 0.19763500E+05, -.15589100E+05, -.26687100E+05, 0.11203700E+05, 0.13883100E+05, 0.53475500E+04, -.22393500E+06, 0.11108100E+06, 0.56372900E+05, 0.11196100E+06, 0.63802400E+05, 0.30555300E+05, 0.87564400E+04, -.49093600E+05, 0.68869300E+05, 0.19744300E+05, 0.76578500E+05, -.12183800E+06, 0.60336600E+05, 0.42230400E+05, 0.60872600E+05, 0.28621800E+05, 0.25586800E+05, -.40386800E+04, -.37282300E+05, 0.29079900E+05, 0.17384800E+05, 0.46249100E+05, 0.72562000E+05, -.35906900E+05, -.37853100E+05, -.36232600E+05, -.18268800E+05, -.15868900E+05, 0.47814500E+04, 0.26706100E+05, -.12379100E+05, -.10884000E+05, -.21742000E+05, -.15171700E+06, 0.75436600E+05, 0.18207300E+05, 0.75830700E+05, 0.54954500E+05, 0.31106000E+05, -.49567300E+04, -.46394800E+05, 0.43439200E+05, 0.20587200E+05, 0.48659800E+05, -.83686600E+05, 0.41194400E+05, 0.11044600E+05, 0.41837800E+05, 0.53919400E+05, 0.33107800E+05, -.25057800E+05, -.44499400E+05, 0.25154200E+05, 0.23153700E+05, 0.15202400E+05, -.11667000E+06, 0.58245500E+05, 0.24825100E+05, 0.58320700E+05, 0.35442600E+05, 0.21875100E+05, 0.19096600E+04, -.26134500E+05, 0.35887400E+05, 0.15588100E+05, 0.42009800E+05, -.23686300E+06, 0.11769100E+06, 0.88375600E+05, 0.11838000E+06, 0.76860300E+05, 0.36778300E+05, 0.28734800E+04, -.55199100E+05, 0.61405500E+05, 0.25654300E+05, 0.57013300E+05, 0.21293600E+06, -.10605900E+06, -.43705400E+05, -.10643300E+06, -.74633600E+05, -.42908600E+05, 0.71007800E+04, 0.57911000E+05, -.62663400E+05, -.30164800E+05, -.68320800E+05, 0.40700600E+04, -.16039900E+04, -.59334200E+04, -.20329500E+04, -.46026100E+04, 0.31045300E+04, -.60469000E+03, 0.15183800E+04, -.14520900E+04, 0.37066100E+04, 0.48774600E+04, 0.13182600E+06, -.65323900E+05, -.68120800E+05, -.65883700E+05, -.27028200E+05, -.16215000E+05, -.10046700E+05, 0.24185600E+05, -.36555600E+05, -.11291300E+05, -.39941300E+05, 0.11499000E+06, -.57130300E+05, -.45587500E+05, -.57472000E+05, -.22062100E+05, -.22467100E+05, 0.83063900E+03, 0.31316100E+05, -.26865300E+05, -.15281500E+05, -.39628300E+05, 0.10228200E+06, -.50774500E+05, -.48922900E+05, -.51112400E+05, -.19949800E+05, -.20011300E+05, 0.12553600E+04, 0.28877400E+05, -.22118400E+05, -.13705100E+05, -.31365600E+05, 0.14334500E+06, -.70737500E+05, -.36669400E+05, -.71649700E+05, -.48445400E+05, -.22886800E+05, 0.76431300E+03, 0.32858800E+05, -.46194700E+05, -.14511500E+05, -.44244200E+05, 0.37993900E+05, -.19058600E+05, -.16117700E+05, -.18985200E+05, -.97065900E+04, -.78142600E+04, -.10502700E+04, 0.76346100E+04, -.86248000E+04, -.61951600E+04, -.13308000E+05, 0.21134600E+06, -.10474100E+06, -.10615300E+06, -.10556800E+06, -.70430300E+05, -.31392600E+05, 0.69661800E+04, 0.77063400E+05, -.41075600E+05, -.19546700E+05, -.42462000E+05, 0.66942300E+05, -.33108500E+05, -.22324200E+05, -.33456000E+05, -.17389900E+05, -.28863300E+04, -.56733700E+04, 0.15686200E+05, -.16607100E+05, -.23237200E+03, -.18177800E+05, -.22033100E+06, 0.10909600E+06, 0.56809700E+05, 0.11009700E+06, 0.65289400E+05, 0.36738700E+05, 0.12089000E+04, -.58860700E+05, 0.61992200E+05, 0.24416800E+05, 0.75604200E+05, 0.12908000E+05, -.63851800E+04, -.10417200E+05, -.64213900E+04, -.25759100E+05, -.14432200E+04, 0.14727300E+05, 0.30551300E+05, 0.92591600E+04, 0.14983700E+04, 0.22435100E+05, -.53607100E+05, 0.26078500E+05, 0.10628500E+04, 0.26784400E+05, 0.40620700E+05, 0.17577400E+05, -.15685700E+05, -.35276000E+05, 0.73247200E+04, 0.12008500E+05, -.21313200E+04, -.26675500E+05, 0.13301900E+05, 0.34797000E+04, 0.13328800E+05, 0.37956700E+05, 0.21944700E+05, -.24172400E+05, -.40103900E+05, -.72114700E+04, 0.16223400E+05, -.11912200E+05, -.32675800E+05, 0.25674300E+05, 0.27516700E+05, -.47578900E+04, -.30837200E+05, -.35946700E+05, -.21378700E+05, -.25944800E+05, 0.40370500E+04, -.27609800E+05, -.15753700E+05, 0.26291800E+05, -.17927200E+05, -.34677600E+05, 0.38248500E+05, -.24903300E+05, -.28156900E+05, 0.23233300E+05, -.22126100E+05, 0.13469200E+05, -.31802000E+05, 0.25742500E+05, -.25445500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17293500E+00, -.46117700E+00, -.28342500E+00, -.49220600E+00, 0.63175200E-02, 0.19539500E+05, -.18913400E+05, -.24633400E+05, -.14731600E+05, 0.92349700E+04, 0.17477300E+05, -.46290400E+05, 0.23986600E+05, 0.50135200E+04, 0.23134100E+05, 0.24521400E+04, 0.32493800E+05, -.18076700E+05, -.31122600E+05, 0.38117600E+04, 0.18069600E+05, 0.42397200E+05, -.12777800E+06, 0.71989600E+05, -.12421200E+04, 0.63878600E+05, -.18322900E+04, 0.30082100E+05, 0.83062700E+03, -.43499100E+05, 0.18648500E+05, 0.75207000E+04, 0.85893000E+05, -.12259400E+06, 0.66242900E+05, 0.21489700E+05, 0.61211000E+05, 0.92509400E+04, 0.36270700E+05, -.73968100E+04, -.46694100E+05, 0.10269200E+05, 0.20144100E+05, 0.71408500E+05, 0.10829200E+06, -.57700900E+05, -.23680600E+05, -.54055500E+05, -.82435100E+04, -.31519200E+05, 0.64776500E+04, 0.37968400E+05, -.11979600E+05, -.18227800E+05, -.61446700E+05, -.15000300E+06, 0.80667400E+05, -.13752100E+05, 0.74951500E+05, -.29984300E+04, 0.27673400E+05, 0.37670400E+04, -.48665900E+05, 0.28333300E+05, 0.87258500E+04, 0.95376900E+05, -.50967300E+05, 0.27596000E+05, -.16605700E+05, 0.25473800E+05, 0.31021900E+04, 0.51085000E+05, -.32055300E+05, -.41242300E+05, 0.78036300E+04, 0.27866500E+05, 0.61041300E+05, -.78256500E+05, 0.39783000E+05, 0.11072000E+05, 0.39102700E+05, 0.29524900E+04, 0.22056400E+05, -.93707400E+03, -.27698900E+05, 0.10048300E+05, 0.10853700E+05, 0.50810700E+05, -.22331500E+06, 0.11878600E+06, 0.32131100E+05, 0.11156800E+06, 0.58708400E+04, 0.67215900E+05, -.14711900E+05, -.77671900E+05, 0.23242400E+05, 0.31099300E+05, 0.14776400E+06, 0.16280800E+06, -.84734100E+05, -.14088800E+05, -.81341200E+05, -.10702900E+05, -.58344000E+05, 0.15901000E+05, 0.60324100E+05, -.23505900E+05, -.30156700E+05, -.11015700E+06, -.98217700E+04, 0.15267400E+04, 0.76325200E+04, 0.49144400E+04, 0.11785200E+04, -.19561200E+04, 0.24892200E+04, -.24430700E+04, 0.36854400E+04, 0.22176800E+04, 0.65544000E+03, 0.12391300E+06, -.66168000E+05, -.38115300E+05, -.61904700E+05, 0.82705600E+03, -.19207900E+05, -.65459800E+04, 0.34884200E+05, -.19029200E+05, -.76441800E+04, -.67846300E+05, 0.11222000E+06, -.59670100E+05, -.24486800E+05, -.56066200E+05, -.11238100E+05, -.36093800E+05, 0.91938900E+04, 0.43467400E+05, -.70885600E+04, -.21474200E+05, -.65693500E+05, 0.12395000E+06, -.65306600E+05, -.26242100E+05, -.61921000E+05, -.11115800E+05, -.38340700E+05, 0.89240300E+04, 0.44344200E+05, -.12514700E+05, -.23108700E+05, -.71821800E+05, 0.10411300E+06, -.57795200E+05, 0.43488500E+04, -.52015300E+05, -.12272300E+04, -.33482500E+05, 0.76183800E+04, 0.32034500E+05, -.23029500E+05, -.12079400E+05, -.76819400E+05, 0.57537200E+05, -.28613400E+05, -.23970600E+05, -.28746800E+05, -.35305800E+04, -.11108200E+05, -.20734200E+04, 0.15756500E+05, -.71894000E+04, -.80181600E+04, -.27930300E+05, 0.24370400E+06, -.13066200E+06, -.62227500E+05, -.12165900E+06, 0.48861200E+04, -.50447400E+05, 0.44957200E+04, 0.93786300E+05, -.13819600E+05, -.13134600E+05, -.15680300E+06, 0.58472200E+05, -.33905900E+05, -.23368400E+04, -.29207800E+05, 0.35639500E+04, -.56153400E+04, -.55525500E+04, 0.18382500E+05, -.21168500E+04, 0.36213500E+04, -.34647700E+05, -.15911200E+06, 0.87966800E+05, 0.36578200E+04, 0.79433600E+05, -.15676100E+04, 0.39472000E+05, -.29528900E+04, -.62074700E+05, 0.15736300E+05, 0.14302700E+05, 0.10393800E+06, 0.23188700E+05, -.14998800E+05, 0.18215100E+05, -.11537400E+05, 0.71317000E+04, -.12352900E+05, 0.14965400E+05, 0.28672700E+05, 0.17134100E+05, 0.48937600E+04, -.38677200E+05, -.32540100E+05, 0.22341400E+05, -.18496000E+05, 0.16235100E+05, 0.39846300E+04, 0.40480200E+05, -.25985000E+05, -.37871800E+05, -.13150800E+05, 0.20635700E+05, 0.42848200E+05, -.44143800E+05, 0.22598900E+05, 0.10348500E+05, 0.22057100E+05, 0.38875300E+04, 0.39270300E+05, -.27157000E+05, -.50882900E+05, -.19535500E+05, 0.20746300E+05, 0.46460700E+05, -.26695400E+05, 0.32559700E+05, 0.13665400E+05, 0.15284700E+05, 0.18640500E+05, 0.10154800E+05, -.14438500E+05, -.14834500E+05, -.95532400E+03, -.21769100E+05, -.60004800E+04, 0.18462100E+05, -.50210400E+04, 0.20673700E+05, -.13561700E+05, -.12240300E+05, -.31528000E+05, 0.13560500E+05, -.16394200E+05, -.87034100E+04, -.29053800E+05, 0.17265100E+05, -.26598500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54722500E+00, 0.10666800E+01, 0.22187300E+00, 0.50656500E+00, -.11204500E-01, -.99570700E+00, 0.71663000E+05, 0.15949000E+06, 0.42710600E+05, -.30626300E+04, -.26561200E+05, 0.65934400E+05, -.31691500E+05, -.29215800E+05, -.32975000E+05, 0.19007500E+04, 0.63803100E+04, 0.77921600E+05, 0.20418500E+06, 0.32263900E+05, -.20147200E+04, -.60637200E+05, 0.23863300E+06, -.11162100E+06, -.98365700E+05, -.11932400E+06, 0.86562900E+04, 0.74409800E+05, 0.37420100E+05, 0.22969200E+06, -.53178100E+05, 0.55662300E+05, -.12300100E+06, 0.13361100E+06, -.62159400E+05, -.55196800E+05, -.66865600E+05, 0.16279800E+05, 0.51435900E+05, 0.29975600E+05, 0.16263000E+06, -.25379000E+05, 0.38371300E+05, -.81082800E+05, -.10894600E+06, 0.51246700E+05, 0.40765700E+05, 0.54536100E+05, -.10366800E+05, -.39445900E+05, -.23128200E+05, -.12807600E+06, 0.24046300E+05, -.29620800E+05, 0.57297500E+05, 0.95862300E+05, -.44098900E+05, -.30019900E+05, -.47967300E+05, 0.11644700E+05, 0.52311400E+05, 0.70131100E+05, 0.21728000E+06, -.35845700E+04, 0.37893000E+05, -.64338500E+05, 0.11060100E+06, -.51848600E+05, -.54097100E+05, -.55307600E+05, 0.65407900E+03, 0.18082100E+05, 0.11906700E+06, 0.31999300E+06, 0.40811600E+05, 0.31601200E+04, -.92887800E+05, 0.46047100E+05, -.23441300E+05, -.31513200E+05, -.23042000E+05, 0.61919500E+03, 0.10539300E+05, 0.41733700E+05, 0.11378700E+06, 0.10195900E+05, 0.73966700E+04, -.32275900E+05, 0.48658500E+06, -.23850800E+06, -.21916400E+06, -.24335800E+06, 0.22215700E+05, 0.12557800E+06, 0.38116500E+04, 0.33994900E+06, -.12039900E+06, 0.92769300E+05, -.19316600E+06, -.19105900E+06, 0.94214100E+05, 0.10131800E+06, 0.95574400E+05, -.35546900E+04, -.50401300E+05, -.77457100E+05, -.28749300E+06, 0.97749400E+04, -.35830400E+05, 0.10001800E+06, -.13605400E+06, 0.63935400E+05, 0.52516400E+05, 0.68029500E+05, -.16974300E+04, -.36406900E+05, 0.27540700E+05, -.34545700E+05, 0.42710900E+05, -.26172100E+05, 0.44636600E+05, -.21174000E+06, 0.10268500E+06, 0.82567700E+05, 0.10590700E+06, -.24902100E+04, -.38434100E+05, 0.11947100E+05, -.95936100E+05, 0.70477100E+05, -.31513200E+05, 0.80816000E+05, -.11561100E+06, 0.54768900E+05, 0.48936400E+05, 0.57835900E+05, -.16887400E+05, -.46177700E+05, -.26599500E+05, -.14528100E+06, 0.21847900E+05, -.34319300E+05, 0.69345800E+05, -.12533200E+06, 0.59773900E+05, 0.52058800E+05, 0.62703700E+05, -.15025600E+05, -.44120400E+05, -.25267400E+05, -.14481800E+06, 0.25499200E+05, -.32738000E+05, 0.67592700E+05, -.21941200E+06, 0.10324200E+06, 0.99396200E+05, 0.10973500E+06, -.88985300E+04, -.63175100E+05, -.39305900E+05, -.22748800E+06, 0.35747700E+05, -.45559700E+05, 0.11290300E+06, -.43056800E+05, 0.22330600E+05, 0.24356600E+05, 0.21543600E+05, -.11833200E+04, -.17791700E+04, 0.47274200E+03, -.24319700E+05, 0.13620800E+05, -.30534700E+04, 0.16786500E+05, -.34552800E+06, 0.16729700E+06, 0.11020100E+06, 0.17289900E+06, -.13974400E+05, -.11868300E+06, -.89498500E+05, -.43142100E+06, 0.60670200E+05, -.91533100E+05, 0.17198300E+06, -.17193400E+06, 0.82158700E+05, 0.64773900E+05, 0.85986600E+05, -.58351500E+04, -.51394400E+05, 0.19004600E+05, -.75034600E+05, 0.55751500E+05, -.37726000E+05, 0.65826100E+05, 0.23590400E+06, -.10964800E+06, -.95691200E+05, -.11804000E+06, 0.17590200E+05, 0.81558000E+05, 0.51364400E+05, 0.26779400E+06, -.45726900E+05, 0.60335400E+05, -.12854700E+06, -.15649100E+06, 0.77694600E+05, 0.34531400E+05, 0.78287200E+05, -.99856200E+04, -.83057000E+05, -.46966300E+05, -.23968300E+06, 0.10674100E+05, -.59611800E+05, 0.77146500E+05, 0.10456700E+06, -.45365100E+05, -.54650100E+05, -.52308400E+05, 0.84433200E+04, 0.47151800E+05, 0.73519800E+05, 0.24642700E+06, 0.19542100E+05, 0.29889200E+05, -.64335900E+05, 0.16620600E+05, -.79592300E+04, -.10872500E+05, -.83216700E+04, 0.13508400E+04, 0.30590800E+04, 0.10739600E+06, 0.25053800E+06, 0.59629000E+05, -.24606800E+04, -.44266800E+05, 0.37961000E+05, 0.51535800E+05, 0.26442600E+05, -.38797100E+02, 0.30666100E+04, -.34846500E+03, 0.32817200E+05, -.24398800E+05, -.39969900E+05, 0.19523200E+05, -.22496400E+05, 0.11172300E+05, 0.41798300E+04, 0.73835800E+04, -.65206300E+04, 0.10430900E+05, -.96731800E+04, 0.96023100E+04, 0.10086800E+05, -.67024700E+04, 0.47117100E+03, 0.64142100E+04, -.52253400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23193900E+00, 0.75648200E+00, 0.35339400E+00, 0.66856300E+00, -.30201500E-01, -.68621200E+00, 0.10538100E-01, -.74404200E+04, -.51443600E+04, 0.22118800E+04, 0.13430400E+04, 0.34441300E+05, -.16725700E+05, -.16055900E+05, -.17224500E+05, -.29022100E+04, -.16139400E+04, -.26641600E+04, 0.14207200E+04, -.15245000E+05, -.13661200E+04, -.12818700E+05, 0.22532200E+06, -.10950500E+06, -.99847100E+05, -.11266500E+06, -.46794700E+05, -.36617600E+05, 0.11272900E+05, 0.53029500E+05, -.39040600E+05, -.32312800E+05, -.81107500E+05, 0.89308900E+05, -.42664700E+05, -.41117300E+05, -.44684200E+05, -.12656100E+05, -.83071200E+04, 0.10891300E+04, 0.18859600E+05, -.22700900E+05, -.54106000E+04, -.33079600E+05, -.64751000E+05, 0.30976200E+05, 0.30890600E+05, 0.32406800E+05, 0.72456300E+04, 0.29902200E+04, 0.26117000E+04, -.12152200E+05, 0.17389200E+05, 0.91577800E+03, 0.21182200E+05, 0.18968100E+06, -.93107900E+05, -.81111300E+05, -.94857600E+05, -.42058600E+05, -.40129800E+05, 0.17494400E+05, 0.48870700E+05, -.29409200E+05, -.36196300E+05, -.66052000E+05, 0.67259100E+05, -.32336800E+05, -.30663100E+05, -.33632900E+05, -.53494300E+04, -.16249900E+04, -.66863700E+04, 0.23852600E+04, -.28823900E+05, -.63510600E+03, -.25079200E+05, 0.64781200E+05, -.32418000E+05, -.28056800E+05, -.32399300E+05, -.17869000E+05, -.17541000E+05, 0.93588200E+04, 0.14464100E+05, -.14709600E+05, -.13567600E+05, -.24345200E+05, 0.14796200E+06, -.71874100E+05, -.66010100E+05, -.74011200E+05, -.18850600E+05, 0.28769100E+04, -.78209900E+04, 0.22977000E+05, -.46759400E+05, 0.99668300E+04, -.49403100E+05, -.11886400E+06, 0.58670000E+05, 0.50576900E+05, 0.59453700E+05, 0.19829300E+05, 0.91615600E+04, 0.30459800E+04, -.13649900E+05, 0.39501600E+05, 0.28798000E+04, 0.41630100E+05, -.36646800E+05, 0.16803700E+05, 0.17047500E+05, 0.18324600E+05, -.76883000E+03, -.11267400E+05, 0.11068500E+05, -.60111000E+03, 0.15114400E+05, -.99643700E+04, 0.11118700E+05, -.13162600E+06, 0.64426100E+05, 0.61458500E+05, 0.65830500E+05, 0.27309900E+05, 0.25594000E+05, -.77188800E+04, -.36966300E+05, 0.14689800E+05, 0.22496500E+05, 0.46677200E+05, -.62759600E+05, 0.29979800E+05, 0.29789500E+05, 0.31395100E+05, 0.67534300E+04, 0.21020300E+04, 0.15418600E+04, -.11663900E+05, 0.19573700E+05, -.67449300E+03, 0.19983200E+05, -.58105500E+05, 0.27730600E+05, 0.28194400E+05, 0.29071500E+05, 0.50256700E+04, 0.16479400E+03, 0.28361000E+04, -.94875400E+04, 0.20240200E+05, -.25788700E+04, 0.17647400E+05, -.12019400E+06, 0.57597800E+05, 0.54141400E+05, 0.60111100E+05, 0.16945300E+05, 0.39612400E+04, 0.31375000E+04, -.16533500E+05, 0.39068700E+05, 0.30708100E+03, 0.44202200E+05, -.77007000E+04, 0.40994800E+04, 0.40925300E+04, 0.38579300E+04, 0.31994600E+04, 0.35846500E+04, -.22957100E+04, -.34909300E+04, 0.14558600E+04, 0.25494400E+04, 0.22699600E+04, -.28468500E+06, 0.13981900E+06, 0.12914000E+06, 0.14240900E+06, 0.50475900E+05, 0.33470000E+05, -.27539100E+04, -.59018200E+05, 0.50294900E+05, 0.26258300E+05, 0.94717800E+05, -.10840100E+06, 0.52624200E+05, 0.48123300E+05, 0.54210400E+05, 0.22186100E+05, 0.14639400E+05, -.45344500E+04, -.27448600E+05, 0.13876200E+05, 0.14407600E+05, 0.36432800E+05, 0.22647500E+06, -.10986600E+06, -.10012300E+06, -.11327900E+06, -.45651900E+05, -.38459000E+05, 0.13502600E+05, 0.56242600E+05, -.38579800E+05, -.33803200E+05, -.83774300E+05, -.71504300E+05, 0.35326000E+05, 0.27909100E+05, 0.35771300E+05, 0.74810200E+03, -.19594800E+05, 0.18022100E+05, 0.41649100E+04, 0.31127300E+05, -.20867400E+05, 0.18719100E+05, 0.53548500E+05, -.24150800E+05, -.23494200E+05, -.26786200E+05, -.28429100E+04, 0.82117400E+04, -.95392700E+04, 0.41011000E+03, -.23102000E+05, 0.89376500E+04, -.15236200E+05, 0.14889000E+04, -.59164400E+03, -.29587900E+03, -.74932600E+03, -.14119900E+04, -.75410900E+03, 0.11682400E+04, -.98203800E+04, -.86996900E+04, 0.27038400E+04, 0.34220700E+04, 0.36536700E+05, -.11442400E+05, -.86676000E+04, -.34544600E+04, 0.17266900E+05, 0.19340200E+05, 0.21998400E+05, 0.87722800E+04, 0.83009500E+02, 0.17652300E+05, 0.11234800E+05, -.22203100E+05, 0.51782400E+04, 0.18241200E+05, -.19374700E+05, 0.13959900E+05, 0.19674200E+05, -.12082300E+05, 0.18726600E+05, -.71332500E+04, 0.21955800E+05, -.14788600E+05, 0.11958100E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46829400E-02, -.62320400E-01, -.19404200E-01, 0.30360600E-01, -.64169200E-01, 0.13608000E-05, -.66372000E-02, -.11581200E-03, -.61405300E+03, 0.82296100E+02, 0.21909500E+03, 0.28027700E+04, -.13987800E+04, -.69386600E+03, -.14017600E+04, -.24755400E+03, -.65501500E+03, -.78097600E+02, 0.61100600E+03, -.16037600E+04, -.22895100E+03, -.69057900E+03, -.22715900E+05, 0.10706000E+05, 0.13002500E+04, 0.11357800E+05, -.20011000E+04, -.94202400E+02, 0.26943100E+03, -.10313500E+05, 0.18539800E+04, 0.14080000E+04, 0.14889800E+05, -.16139300E+05, 0.77101800E+04, 0.34568900E+04, 0.80666500E+04, -.17521000E+04, -.40700300E+04, 0.31528300E+04, -.37484000E+04, 0.30349100E+04, -.27761700E+04, 0.87679600E+04, 0.51133500E+04, -.21702300E+04, -.48861600E+03, -.25533500E+04, 0.17508900E+04, 0.23220400E+04, -.99013500E+03, 0.24698600E+04, 0.71755300E+03, 0.12588400E+04, -.40834300E+04, -.24241000E+05, 0.11437500E+05, 0.25293500E+03, 0.12119300E+05, -.19408200E+04, -.29747100E+04, 0.27084800E+04, -.72884500E+04, 0.31427200E+04, -.89213100E+03, 0.14279900E+05, 0.52971900E+04, -.26624400E+04, -.17256400E+04, -.26488500E+04, -.74773600E+03, -.68001500E+03, -.63962700E+03, 0.48816400E+03, -.28498500E+04, -.83306600E+02, -.25722100E+03, -.31815100E+04, 0.15586500E+04, -.22969600E+03, 0.15901300E+04, 0.10419200E+04, 0.20225300E+04, -.12837000E+04, -.27364900E+04, -.77706600E+03, 0.21510900E+04, 0.30480800E+04, -.16080800E+05, 0.77567700E+04, -.15410800E+04, 0.80388300E+04, -.75522200E+04, -.27398700E+04, 0.15072500E+02, -.11421300E+05, -.10514300E+04, -.35716800E+03, 0.17419500E+05, 0.81397500E+03, -.28482300E+03, 0.29837400E+04, -.40519600E+03, 0.17331100E+04, -.21950000E+04, 0.30253100E+04, 0.62956100E+04, 0.37204400E+04, -.30920000E+04, -.66469000E+04, 0.62247700E+04, -.29673300E+04, 0.15254900E+04, -.31123400E+04, 0.40446100E+04, 0.18780100E+04, -.91030500E+03, 0.30478600E+04, -.18230400E+04, 0.11245600E+04, -.68219800E+04, 0.83314000E+04, -.41889600E+04, 0.33012900E+04, -.41644000E+04, 0.16773100E+04, -.81617300E+03, 0.91429200E+03, 0.59610300E+04, 0.17391700E+04, -.19493100E+04, -.67301400E+04, 0.10237500E+05, -.45130000E+04, -.24902900E+04, -.51169700E+04, 0.14234800E+04, 0.30371400E+04, -.21425800E+04, 0.25160400E+04, -.13818300E+04, 0.19153300E+04, -.62166500E+04, 0.48923100E+04, -.18529000E+04, -.11118700E+04, -.24441500E+04, 0.17468400E+04, 0.27880800E+04, -.12949100E+04, 0.19852600E+04, 0.55135200E+03, 0.16012400E+04, -.42692200E+04, 0.44710700E+04, -.19993600E+04, 0.19395100E+04, -.22342800E+04, 0.44452900E+04, 0.89877400E+03, 0.12327500E+04, 0.64677200E+04, 0.14030300E+04, -.34209500E+03, -.82770300E+04, 0.67324500E+03, -.34379900E+03, -.67013700E+03, -.33581100E+03, -.64296100E+03, -.46260800E+03, 0.17767100E+03, 0.41648300E+03, 0.69973200E+03, -.50406400E+03, -.12755400E+03, 0.23096900E+05, -.11437200E+05, 0.77040100E+04, -.11541800E+05, 0.85110200E+04, 0.50379800E+02, 0.18337900E+04, 0.16819400E+05, 0.30427300E+04, -.30787900E+04, -.20706500E+05, 0.15150700E+05, -.72235600E+04, -.74158000E+03, -.75742800E+04, 0.30834500E+04, 0.11610500E+04, -.69307500E+03, 0.66781000E+04, -.13774400E+04, -.71701200E+02, -.10049900E+05, -.34672400E+05, 0.16963200E+05, 0.48898900E+04, 0.17333000E+05, -.25703700E+04, -.40974400E+04, 0.41935700E+04, -.99024800E+04, 0.59411400E+04, -.20848200E+04, 0.19472800E+05, 0.14083400E+05, -.69680600E+04, 0.57283500E+04, -.70406300E+04, 0.85764800E+04, 0.35606000E+04, -.96706400E+03, 0.83831400E+04, -.19626700E+04, 0.15857400E+04, -.14436800E+05, -.38315500E+04, 0.15313700E+04, 0.63247900E+03, 0.19147000E+04, -.28103900E+04, -.10504800E+04, 0.14205000E+03, -.28293700E+04, -.56965900E+03, -.33574500E+03, 0.55292300E+04, 0.84131600E+03, -.46147700E+03, 0.46465800E+03, -.42071400E+03, 0.38997300E+03, 0.42404300E+03, -.41630800E+03, -.30855400E+03, -.19078600E+04, 0.51832800E+03, -.17967600E+03, -.41744500E+04, -.12334000E+03, 0.37098700E+03, 0.29196600E+04, 0.24821700E+04, 0.32177500E+04, -.23176600E+04, -.31532200E+03, 0.70311200E+03, 0.13066300E+03, 0.67199200E+03, -.69039400E+03, 0.11899800E+04, 0.27929400E+04, -.30482900E+04, 0.67411800E+03, 0.51450400E+03, -.52771800E+03, -.14375000E+04, -.14480900E+04, -.10642900E+03, -.43961100E+02, 0.18031100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27403700E+00, -.51262200E+00, -.14779600E+00, -.23605600E+00, 0.27314700E+00, 0.64696800E+00, -.37393400E-01, -.51229200E+00, -.40269900E+01, 0.45358000E+04, 0.58846100E+04, -.74435000E+04, 0.35874300E+04, -.77455700E+03, 0.37248700E+04, -.84017000E+03, 0.39979000E+04, -.23183900E+04, 0.24357700E+03, 0.45240200E+04, 0.68743100E+04, 0.14316500E+05, -.26881300E+05, 0.10312900E+05, -.29778900E+05, 0.13444700E+05, -.22240300E+05, -.44833000E+04, -.11046100E+04, -.16299300E+05, 0.22870600E+05, 0.53798700E+04, 0.52316700E+05, -.38117100E+05, 0.17224700E+05, -.40706300E+04, 0.19082100E+05, -.12653500E+05, -.17018100E+05, 0.11124800E+05, -.47959800E+03, 0.26016200E+05, -.84620300E+04, 0.34766200E+05, 0.48238800E+04, -.58593500E+03, 0.12403400E+05, -.24357900E+04, 0.11562000E+05, 0.76662300E+04, -.16272400E+04, 0.12195500E+03, -.10284400E+05, 0.12482400E+04, -.20343300E+05, -.54311900E+05, 0.24313400E+05, -.27399500E+05, 0.27172800E+05, -.19223000E+05, -.14667200E+05, 0.11056400E+05, -.82691700E+04, 0.32763400E+05, -.41509200E+04, 0.57559000E+05, -.15210900E+05, 0.71594700E+04, -.48875600E+04, 0.76086600E+04, -.16048900E+04, 0.11534800E+05, -.70931000E+04, -.56306000E+04, 0.47004300E+04, 0.15704500E+05, 0.30869100E+05, -.66827300E+04, 0.33363500E+04, -.92240000E+04, 0.33499200E+04, 0.34947100E+02, 0.66485000E+04, -.34985300E+04, -.45704900E+04, 0.77873300E+04, 0.96694000E+04, 0.16593100E+05, -.15180000E+05, 0.65087800E+04, -.35540500E+05, 0.76235600E+04, -.37213200E+05, -.15605900E+04, -.76554300E+04, -.24464300E+05, 0.12556800E+05, 0.16773800E+05, 0.71467200E+05, 0.42735600E+04, -.17882300E+04, 0.26161800E+05, -.21564200E+04, 0.11305700E+05, -.17242500E+05, 0.15654000E+05, 0.19450200E+05, -.65495700E+04, -.26000500E+05, -.45614000E+05, 0.68774700E+04, -.25784200E+04, 0.12350200E+05, -.34401700E+04, 0.16229000E+05, 0.29868100E+04, 0.15551200E+04, 0.11877000E+05, -.14492000E+03, -.66741800E+03, -.22190400E+05, -.23563400E+05, 0.11718500E+05, 0.36383500E+05, 0.11764600E+05, 0.17009200E+05, 0.76602400E+03, 0.61459500E+04, -.10921800E+02, -.51726800E+04, -.51438700E+04, -.15556900E+05, 0.21345200E+05, -.79131800E+04, 0.51481600E+04, -.10683200E+05, 0.10191900E+05, 0.11552200E+05, -.62081400E+04, -.93816300E+03, -.17685200E+05, 0.38001600E+04, -.29073800E+05, 0.10146300E+05, -.23864500E+04, 0.92679200E+04, -.50872700E+04, 0.10626800E+05, 0.77752300E+04, -.23722900E+04, -.35085700E+03, -.12325100E+05, 0.31693500E+03, -.26189100E+05, 0.21354100E+05, -.92905900E+04, 0.15830800E+05, -.10689400E+05, 0.19467500E+05, -.82019700E+04, 0.93231700E+04, 0.25409300E+05, -.65922100E+04, -.16349900E+05, -.48306400E+05, -.73550700E+04, 0.35305700E+04, 0.35240800E+04, 0.36718200E+04, -.63516800E+03, -.73202200E+03, 0.96899000E+03, -.43848000E+04, -.12555200E+04, -.13713600E+04, 0.90440800E+03, -.44696900E+05, 0.22672400E+05, 0.83232300E+05, 0.22295000E+05, 0.54882200E+05, 0.66050000E+04, 0.16052600E+05, 0.19230900E+05, -.74049400E+04, -.15060300E+05, -.55112600E+05, 0.49827100E+04, -.95901100E+03, 0.20394600E+05, -.24986000E+04, 0.21759400E+05, 0.11726900E+05, -.21777100E+04, 0.71619200E+04, -.99169800E+04, 0.44836900E+04, -.23790700E+05, -.64620200E+05, 0.30277000E+05, -.19441800E+05, 0.32349900E+05, -.24961800E+05, -.23335700E+05, 0.15777600E+05, -.79361200E+04, 0.42834600E+05, -.10310600E+05, 0.65316300E+05, 0.50600600E+04, -.26457000E+04, 0.35841500E+05, -.25510900E+04, 0.35525800E+05, 0.80717600E+04, 0.49101700E+04, 0.26066000E+05, 0.17699500E+03, -.62778800E+04, -.45603000E+05, 0.65547600E+04, -.52906300E+04, -.16433900E+05, -.32669600E+04, -.13913000E+05, 0.10828500E+03, -.47842800E+04, -.59186000E+04, -.13679900E+04, 0.78598500E+04, 0.25741500E+05, 0.10766700E+05, -.55448100E+04, -.52524900E+04, -.53766400E+04, -.51118900E+03, -.47195800E+03, -.10886900E+04, 0.38098600E+04, -.14404100E+03, 0.67477500E+04, 0.56764500E+04, -.61737700E+04, 0.34418100E+04, 0.75039800E+04, 0.11131400E+05, 0.21816900E+05, 0.17555800E+05, -.15115600E+04, -.40298600E+04, 0.13510600E+05, 0.51481400E+04, 0.77763800E+04, -.64673300E+04, 0.13139300E+04, 0.22259900E+05, -.20089200E+05, 0.12222800E+05, 0.44917700E+04, -.19153800E+04, -.53442500E+04, -.13764000E+05, 0.50868700E+04, 0.14834400E+04, -.44869400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17213300E+01, -.14991600E+01, -.33460800E+00, -.11570900E+01, -.13108100E+01, 0.11171800E+01, -.61854400E+00, -.26935400E+01, -.71049500E+01, 0.27142200E+00, 0.85227000E+05, 0.62530800E+05, -.31234900E+05, -.98173100E+04, -.31284100E+05, 0.25811600E+04, -.12824800E+05, 0.41469400E+04, 0.29264600E+05, -.18630900E+05, -.12018500E+05, 0.50202800E+05, 0.29323700E+06, -.14909700E+06, -.21546400E+06, -.14663500E+06, -.18759100E+06, -.27349000E+06, 0.15552900E+06, 0.17852600E+06, 0.87329300E+05, -.24902000E+06, 0.10726200E+06, -.10559700E+05, 0.42546200E+04, -.34083400E+05, 0.51343100E+04, -.73259300E+05, -.13305600E+06, 0.87273500E+05, 0.59088900E+05, 0.60143200E+05, -.11336900E+06, 0.12589600E+06, -.56660900E+05, 0.29764200E+05, 0.35031100E+05, 0.28484800E+05, 0.51602100E+05, 0.92917900E+05, -.48703500E+05, -.54689900E+05, -.20948400E+05, 0.77043100E+05, -.77625200E+05, 0.34027200E+06, -.17176200E+06, -.23775300E+06, -.17021600E+06, -.18582300E+06, -.27825600E+06, 0.15092300E+06, 0.18141200E+06, 0.53126400E+05, -.24867900E+06, 0.58243800E+05, 0.11266600E+06, -.56904900E+05, -.10596800E+05, -.56348800E+05, 0.18510100E+04, -.24706600E+05, 0.44774800E+04, 0.41485400E+05, -.35659000E+05, -.22196100E+05, 0.78944800E+05, 0.15412100E+06, -.75944800E+05, -.64147500E+05, -.77101600E+05, -.46114300E+05, -.68497100E+05, 0.40399500E+05, 0.65036600E+05, -.59214600E+04, -.63177600E+05, 0.22760900E+05, -.51836700E+04, 0.39856300E+04, -.77975400E+05, 0.24528000E+04, -.14266000E+06, -.21536100E+06, 0.12634100E+06, 0.10350000E+06, 0.10004300E+06, -.18091100E+06, 0.30357200E+06, -.16058100E+06, 0.78310600E+05, 0.50341600E+05, 0.80393900E+05, 0.62218900E+05, 0.10445000E+06, -.49002500E+05, -.76771700E+05, 0.24790800E+04, 0.88505000E+05, -.12515700E+06, 0.85088400E+05, -.41273900E+05, 0.94909100E+04, -.42538800E+05, 0.25811400E+05, 0.31458300E+05, -.23185800E+05, 0.13461600E+05, -.33000700E+05, 0.26678600E+05, -.74455600E+05, -.22330000E+06, 0.10984900E+06, 0.19937500E+06, 0.11173300E+06, 0.11890000E+06, 0.16222800E+06, -.81972400E+05, -.12955000E+06, -.58917100E+05, 0.14564000E+06, -.39953400E+05, 0.61613500E+04, -.50828200E+03, 0.21441700E+05, -.30044100E+04, 0.50918000E+05, 0.92587300E+05, -.58101500E+05, -.45050900E+05, -.36661200E+05, 0.76143500E+05, -.12392900E+06, -.34626300E+05, 0.19908000E+05, 0.17242200E+05, 0.17405400E+05, 0.46954000E+05, 0.87930000E+05, -.48996800E+05, -.49610900E+05, -.15116100E+05, 0.70507400E+05, -.10435900E+06, -.54309800E+05, 0.28280800E+05, 0.41268500E+05, 0.27223000E+05, 0.81630100E+05, 0.13375100E+06, -.85364600E+05, -.60912000E+05, -.27091800E+05, 0.11509100E+06, -.12450300E+06, -.25196400E+05, 0.11953000E+05, 0.63615800E+04, 0.12635600E+05, 0.72342700E+04, 0.12028000E+05, -.61670800E+04, -.20547500E+05, -.31014000E+04, 0.11074000E+05, -.15966600E+05, -.29214600E+06, 0.14230300E+06, 0.37201700E+06, 0.14640000E+06, 0.27110600E+06, 0.35961400E+06, -.19747200E+06, -.22145400E+06, -.15636100E+06, 0.31781800E+06, -.26602800E+06, -.98189500E+05, 0.50014500E+05, 0.12402300E+06, 0.49143400E+05, 0.11693200E+06, 0.15840800E+06, -.90709500E+05, -.80975700E+05, -.70773000E+05, 0.14213000E+06, -.67906900E+05, 0.21242600E+06, -.10717100E+06, -.20000000E+06, -.10641100E+06, -.20416600E+06, -.31099900E+06, 0.18712000E+06, 0.18165700E+06, 0.12036800E+06, -.28019300E+06, 0.14936300E+06, 0.17362300E+06, -.89238500E+05, 0.73524700E+05, -.86723200E+05, 0.87340900E+05, 0.11168900E+06, -.70161500E+05, 0.14287400E+05, -.88793800E+05, 0.89873300E+05, -.25840900E+06, 0.18809400E+05, -.11990400E+05, 0.69587100E+04, -.94627000E+04, -.32275700E+05, -.46443100E+05, 0.24443400E+05, 0.25945900E+05, 0.10692200E+05, -.40238400E+05, 0.13771300E+06, 0.33190400E+05, -.16621000E+05, 0.11200000E+04, -.16616400E+05, -.39326900E+04, -.66826400E+04, 0.19665300E+04, 0.13900100E+05, -.86312600E+04, -.53006200E+04, 0.12991200E+06, 0.40553000E+05, -.11737300E+06, -.11433100E+06, 0.11952700E+05, 0.75427300E+05, 0.90344000E+05, 0.10929600E+05, 0.11248800E+06, 0.82429600E+05, 0.97313200E+05, 0.98683600E+05, -.11244800E+06, 0.52451500E+05, 0.79332500E+05, -.85676300E+05, 0.88200400E+05, 0.13207900E+06, -.62869700E+05, 0.27219600E+05, -.22003900E+05, 0.90304900E+05, -.10734100E+06, 0.11647900E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40606500E+00, 0.38986100E+00, 0.27365500E+00, -.60474500E-01, -.28003100E+00, -.28698700E+00, 0.98721700E-01, 0.57859200E+00, 0.92254200E+01, -.30724700E+00, 0.10387100E-01, -.55216800E+05, 0.27249800E+05, 0.90453000E+04, 0.27608200E+05, 0.51112600E+04, 0.10663200E+05, 0.86266700E+02, -.14478100E+05, 0.18425900E+05, 0.76528400E+04, 0.21735200E+05, 0.50198700E+05, -.22725700E+05, 0.14360400E+04, -.25101200E+05, 0.27228600E+05, 0.11117600E+05, -.27257800E+04, 0.50440400E+05, 0.12461300E+05, -.28321500E+04, -.51222000E+05, 0.43557800E+05, -.20561900E+05, -.16713100E+05, -.21779400E+05, 0.18864200E+05, 0.38187400E+05, -.22764500E+05, 0.80300600E+04, -.68012500E+04, 0.26439300E+05, -.25718300E+05, 0.21037400E+05, -.12280600E+05, -.38429500E+04, -.10519600E+05, -.16805700E+05, -.22759800E+05, 0.54819600E+04, -.33841800E+04, -.17341500E+05, -.13358600E+05, 0.15487100E+04, 0.55017000E+05, -.24857500E+05, -.31212800E+04, -.27513600E+05, 0.26763800E+05, 0.38721100E+05, -.23269900E+05, 0.23803100E+05, 0.57043800E+04, 0.19800300E+05, -.43740700E+05, -.10277100E+06, 0.50976700E+05, 0.10999800E+05, 0.51384900E+05, 0.12218900E+05, 0.15118300E+05, 0.47022400E+04, -.17793500E+05, 0.38029000E+05, 0.10584500E+05, 0.32760000E+05, -.23312500E+05, 0.11125200E+05, 0.33837300E+04, 0.11653700E+05, -.24366000E+04, -.58074500E+04, 0.59166100E+04, 0.84720200E+04, 0.16620400E+05, -.98417100E+04, 0.29040900E+04, 0.23829600E+05, -.12972400E+05, 0.85820400E+04, -.11929200E+05, 0.57911400E+05, 0.15830600E+05, 0.53012600E+04, 0.61364600E+05, 0.24407100E+05, -.45332000E+04, -.77412900E+05, 0.10054700E+06, -.49110100E+05, -.23074600E+05, -.50269300E+05, -.22634700E+05, 0.46916500E+04, -.24594300E+05, -.25799000E+05, -.54980500E+05, 0.15782600E+05, -.37950300E+04, -.24559200E+05, 0.11870500E+05, -.20070200E+05, 0.12280300E+05, -.30401200E+05, -.76828700E+04, 0.18308700E+03, -.22333500E+05, 0.60577100E+04, -.30959100E+04, 0.44115000E+05, -.10218500E+05, 0.70501200E+04, -.36906100E+05, 0.51140300E+04, -.15721500E+05, 0.25732900E+04, -.49762600E+04, -.28695800E+05, -.18294500E+05, 0.12653300E+05, 0.21972000E+05, -.11649200E+05, 0.24991800E+04, 0.99055900E+04, 0.58226300E+04, -.14845100E+05, -.28883600E+05, 0.14617500E+05, -.18904100E+04, -.34111300E+04, -.18556500E+05, 0.13336000E+05, 0.30948600E+05, -.18732200E+05, 0.11679700E+04, -.15475000E+05, -.16972700E+05, -.27698100E+05, 0.79599100E+04, 0.24274200E+04, -.19206400E+05, -.16731500E+05, -.18668700E+04, 0.58488400E+05, -.29274700E+05, -.18136600E+05, -.29242300E+05, -.41124500E+05, -.11206400E+05, -.12582500E+05, -.31404100E+05, -.37258100E+05, 0.15430300E+03, 0.17881700E+05, -.87851200E+04, 0.46665600E+04, 0.83570900E+04, 0.43922300E+04, 0.51699100E+04, 0.19795400E+04, 0.13314300E+04, -.25591700E+03, -.46041100E+01, 0.31522900E+04, 0.13492600E+03, -.25718100E+05, 0.16006500E+05, -.96430900E+05, 0.12860600E+05, -.70646600E+05, 0.26366100E+04, -.23125400E+05, -.93348400E+05, -.42347700E+05, 0.27169900E+05, 0.83417400E+05, -.49900400E+05, 0.23904700E+05, -.83905900E+04, 0.24949500E+05, -.27893000E+05, -.88160100E+04, 0.11984000E+04, -.36118200E+05, -.59659600E+03, 0.13730200E+03, 0.46680700E+05, 0.12706900E+06, -.63230600E+05, -.24812000E+05, -.63544800E+05, 0.30569900E+05, 0.43337600E+05, -.32859300E+05, 0.40624600E+05, -.18510100E+05, 0.25427700E+05, -.77027100E+05, -.41977500E+05, 0.22464500E+05, -.57427700E+05, 0.20997500E+05, -.61651600E+05, -.93802400E+04, -.95056400E+04, -.58739000E+05, -.13586900E+03, 0.28631600E+04, 0.81452800E+05, -.20660200E+05, 0.11800400E+05, -.42336200E+04, 0.10328600E+05, 0.24141000E+05, 0.85492900E+04, 0.35761200E+04, 0.11609700E+05, 0.13768200E+05, 0.36612900E+04, -.17294300E+05, -.21485200E+05, 0.10825200E+05, -.15385800E+04, 0.10738400E+05, -.12970800E+04, -.31594000E+03, 0.30285200E+04, -.29821500E+04, 0.88057800E+04, -.72435100E+03, 0.11033800E+05, 0.94675700E+04, 0.71363300E+04, 0.54139200E+04, -.15894400E+05, -.19051300E+05, -.28679900E+05, 0.61260200E+04, -.46500400E+04, -.15028900E+02, -.89542200E+04, -.65409800E+04, 0.16155400E+05, -.13001700E+05, -.21616200E+05, 0.26496800E+05, -.97388900E+04, -.14678800E+05, 0.10473600E+05, -.18920100E+03, 0.10679500E+05, -.92861100E+04, 0.61831700E+04, -.67912600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45998000E+00, -.63238800E+00, 0.17619800E+00, -.16578200E+00, 0.25348800E+00, -.16912000E+00, 0.24438200E+00, 0.30538000E+00, -.84802000E+01, -.82885000E-01, -.21693700E-01, -.58581200E+00, -.14741900E+04, -.28207800E+04, 0.70687700E+01, 0.10740300E+04, 0.42871700E+04, -.48016600E+04, -.71148400E+04, -.32560300E+04, 0.39400000E+04, 0.26796900E+04, -.65280400E+05, 0.19371600E+05, -.24571900E+05, 0.32648700E+05, 0.97605100E+04, 0.35714600E+05, -.39693400E+05, -.56144000E+05, -.14082200E+03, 0.37187200E+05, 0.59362300E+05, -.85824500E+04, -.34751700E+04, -.15082600E+05, 0.43449900E+04, -.49042100E+04, -.50220800E+04, -.85691600E+04, -.13523900E+05, 0.51863600E+04, -.25763200E+04, 0.13868300E+05, -.29164100E+05, 0.20669800E+05, 0.22920900E+05, 0.14526900E+05, 0.87163000E+04, 0.20193800E+04, 0.11246400E+05, 0.77477500E+04, 0.87780700E+04, -.36981900E+03, 0.56595500E+03, -.96933500E+05, 0.38858300E+05, -.22510500E+05, 0.48502900E+05, 0.95877900E+04, 0.19278000E+05, -.23391100E+05, -.46862700E+05, 0.15810100E+05, 0.22991000E+05, 0.65374800E+05, 0.31253300E+04, -.53242400E+04, -.15086500E+05, -.15556900E+04, 0.17133100E+04, 0.11747900E+05, -.11686600E+05, -.12147700E+05, -.57426000E+04, 0.10872100E+05, 0.10531500E+05, -.11949100E+05, 0.54100600E+04, -.14839200E+05, 0.59929500E+04, 0.10945000E+05, 0.20373000E+05, -.20073000E+05, -.18526500E+05, -.10623700E+04, 0.18094200E+05, 0.17636900E+05, 0.94127600E+05, -.56845100E+05, -.92446100E+05, -.46993600E+05, -.33404900E+05, 0.13367300E+05, -.47734700E+05, -.41438600E+05, -.38555200E+05, 0.17174100E+05, 0.23920900E+05, -.36021600E+05, 0.22147600E+05, 0.58789900E+05, 0.17967700E+05, 0.95901800E+03, -.31287800E+05, 0.39151900E+05, 0.31600900E+05, 0.18279200E+05, -.29694800E+05, -.24469200E+05, -.26556200E+05, 0.18785000E+05, 0.19005500E+05, 0.13275200E+05, 0.15248800E+05, -.57794500E+04, 0.10924000E+05, 0.85764700E+04, 0.11700000E+05, -.79886900E+04, -.11122500E+05, -.42274100E+04, 0.71608200E+04, 0.26147900E+05, 0.20768100E+04, 0.46841300E+04, -.15929600E+05, 0.25538200E+05, 0.29009400E+05, 0.18044400E+05, -.18542300E+05, -.18336600E+05, -.19557500E+05, 0.16654700E+05, 0.19048700E+05, 0.97536100E+04, 0.71339800E+04, 0.47725100E+04, 0.90851600E+04, 0.64960500E+04, 0.18952400E+04, 0.25623300E+04, -.34459500E+04, -.38694300E+05, 0.25975900E+05, 0.25176100E+05, 0.19314400E+05, 0.96047600E+04, 0.35254200E+04, 0.11973300E+05, 0.52390900E+04, 0.89385900E+04, 0.10341600E+04, 0.18296100E+04, -.26211200E+05, 0.22391700E+05, 0.43439100E+05, 0.13078100E+05, 0.10514000E+05, -.21434900E+05, 0.35634700E+05, 0.35919600E+05, 0.17801500E+05, -.23202400E+05, -.25725200E+05, -.12926500E+05, 0.59257500E+04, 0.60355000E+04, 0.64500000E+04, -.11615700E+04, -.23364100E+03, 0.33111500E+04, 0.92880400E+03, 0.36030600E+04, 0.18954700E+03, 0.55089100E+04, -.49788000E+05, 0.35451700E+05, 0.94213700E+05, 0.24772600E+05, 0.33553500E+05, -.28080300E+05, 0.62930400E+05, 0.67993500E+05, 0.43445300E+05, -.36370200E+05, -.38708500E+05, 0.35019700E+05, -.10268000E+05, 0.12185700E+05, -.17526700E+05, 0.62181300E+04, -.89168300E+04, 0.15025000E+05, 0.28091800E+05, -.95038600E+03, -.12174700E+05, -.32562800E+05, -.94022700E+05, 0.34382900E+05, -.18208300E+05, 0.47097600E+05, 0.61755200E+04, 0.17770000E+05, -.25961700E+05, -.50491000E+05, 0.16040800E+05, 0.20739100E+05, 0.68014800E+05, -.52955000E+05, 0.29960700E+05, 0.68383700E+05, 0.26433300E+05, 0.39441100E+05, 0.16273100E+04, 0.21380400E+05, 0.22505400E+05, 0.18642200E+05, -.47166300E+04, -.21447200E+05, 0.23006000E+05, -.21703300E+05, -.26901300E+05, -.11479800E+05, -.10268500E+05, 0.72120500E+04, -.13336300E+05, -.11140600E+05, -.89620300E+04, 0.84586700E+04, 0.13498500E+05, 0.76184600E+04, -.46067400E+04, -.54599200E+04, -.37957700E+04, 0.10217500E+04, 0.90704200E+03, -.26305500E+04, -.72612800E+03, -.65141900E+03, 0.37911500E+03, -.36896000E+04, -.10919900E+05, 0.14129100E+05, 0.14498100E+05, 0.75650100E+04, 0.82455900E+04, 0.55852500E+04, -.25352000E+04, -.13335700E+05, -.22238300E+04, -.11811000E+05, -.51903300E+04, -.43431100E+03, -.14092900E+05, 0.73108000E+04, -.60791500E+04, -.11475600E+04, -.22285500E+05, 0.81197900E+04, -.49791100E+04, -.67606300E+04, -.57340800E+04, 0.11529500E+05, -.14186900E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21898100E+01, -.13670400E+01, 0.19287000E+01, -.10744800E+01, 0.90386800E-01, 0.65556900E+00, -.35716200E+00, -.24999600E+01, -.34520700E+02, 0.23900700E+00, 0.18900600E+00, -.15452400E+01, -.58984600E+00, -.45073200E+05, 0.19271200E+02, 0.41673700E+04, 0.79290100E+04, -.82564100E+04, -.53101700E+04, -.57538800E+04, 0.88383000E+04, 0.12013600E+05, -.36454700E+06, 0.16661000E+06, -.30738000E+06, 0.18229900E+06, -.79249800E+05, -.30217300E+05, -.56930200E+04, -.15596200E+06, 0.16865300E+06, -.10648300E+05, 0.32747900E+06, -.25980700E+06, 0.12050300E+06, -.13674400E+06, 0.13004800E+06, -.61806200E+05, -.11588500E+06, 0.66559100E+05, -.36017300E+05, 0.14407100E+06, -.93724500E+05, 0.16543900E+06, 0.12402600E+05, 0.31201800E+04, 0.15879800E+06, -.63487000E+04, 0.67784700E+05, 0.75842300E+05, -.18885200E+05, 0.14688800E+05, -.41761600E+05, 0.56317800E+05, -.62291700E+05, -.53118700E+06, 0.25069900E+06, -.33387400E+06, 0.26569600E+06, -.74367200E+05, -.10109000E+06, 0.69224200E+05, -.11231000E+06, 0.23481900E+06, -.65569500E+05, 0.36937000E+06, -.26422800E+05, 0.12449500E+05, -.11751600E+06, 0.13231000E+05, 0.69118000E+04, 0.37118600E+05, -.27003200E+05, -.26689800E+05, -.83036600E+03, 0.33501500E+05, 0.63354700E+05, -.81229000E+05, 0.40200100E+05, -.11385300E+06, 0.40666500E+05, 0.27625100E+05, 0.53666500E+05, -.35940300E+05, -.51058100E+05, 0.36451600E+05, 0.47901100E+05, 0.91099600E+05, -.12768400E+06, 0.57882700E+05, -.45448000E+06, 0.64044700E+05, -.22482200E+06, -.10203400E+06, -.17271900E+05, -.18043200E+06, 0.86187100E+05, -.62087600E+05, 0.34779400E+06, 0.36724200E+05, -.15962900E+05, 0.32172000E+06, -.18482300E+05, 0.33240000E+05, -.81504800E+05, 0.86377500E+05, 0.12664500E+06, -.23233500E+05, -.81839600E+05, -.19410900E+06, 0.89887300E+05, -.41225600E+05, 0.82548300E+05, -.44952300E+05, 0.94665300E+05, 0.33020100E+05, -.78252500E+04, 0.64830900E+05, -.27091500E+05, 0.17477500E+05, -.14104000E+06, -.23504400E+05, 0.11776300E+05, 0.26496400E+06, 0.11647200E+05, 0.10368500E+06, 0.61811400E+05, 0.13193000E+05, 0.48106100E+05, -.27617400E+05, 0.35735200E+05, -.95914300E+05, 0.13240000E+06, -.52033700E+05, 0.12419400E+06, -.66265500E+05, 0.52189300E+05, 0.87747700E+05, -.42856100E+05, 0.17058600E+05, -.90650400E+05, 0.67587000E+05, -.11054400E+06, 0.34138800E+05, -.34473400E+04, 0.15401200E+06, -.17156300E+05, 0.60719400E+05, 0.76021000E+05, -.22861500E+05, 0.13274000E+05, -.49036400E+05, 0.54750000E+05, -.79845600E+05, 0.11633400E+06, -.52547900E+05, 0.25665400E+06, -.58242700E+05, 0.96806700E+05, -.10034900E+05, 0.49629700E+05, 0.15250300E+06, -.37252600E+05, -.24183400E+05, -.22023500E+06, -.35305900E+05, 0.17240900E+05, 0.22950100E+05, 0.17617400E+05, -.47513600E+04, 0.32768000E+04, 0.37710400E+04, -.72520800E+04, 0.16078600E+04, 0.35392700E+04, 0.14534500E+05, -.46383900E+05, 0.26443400E+05, 0.65907100E+06, 0.22861000E+05, 0.34236700E+06, 0.17307300E+06, 0.37605700E+05, 0.18038700E+06, -.72837700E+05, 0.10263800E+06, -.28757800E+06, 0.15993000E+06, -.71849700E+05, 0.17293100E+06, -.80010100E+05, 0.11160400E+06, 0.72363900E+05, -.15211700E+05, 0.81216500E+05, -.86480500E+05, 0.47509500E+05, -.17285000E+06, -.59120400E+06, 0.28557900E+06, -.27790100E+06, 0.29584500E+06, -.10395100E+06, -.14166500E+06, 0.88862300E+05, -.12325200E+06, 0.28333300E+06, -.11067700E+06, 0.40663100E+06, 0.14962300E+06, -.73801900E+05, 0.32212200E+06, -.74938900E+05, 0.24117800E+06, 0.12823800E+06, -.19157400E+05, 0.14523900E+06, -.72071000E+05, 0.80376800E+05, -.27403700E+06, -.66202600E+05, 0.23918300E+05, -.12437800E+06, 0.33165300E+05, -.60670500E+05, 0.21390400E+04, -.11287700E+05, -.55047500E+05, 0.30164100E+05, 0.66202900E+04, 0.13219500E+06, 0.35699800E+05, -.18721000E+05, -.30944300E+05, -.17809800E+05, 0.54791900E+04, 0.69926100E+04, -.92177500E+04, 0.45045800E+04, -.38881800E+04, 0.44722000E+04, -.13204300E+05, -.66810000E+05, -.15670300E+05, -.15610400E+05, 0.54534900E+05, 0.95682500E+05, 0.83890700E+05, -.20569800E+05, 0.21186600E+05, 0.70637100E+05, 0.10434800E+05, 0.52148000E+05, -.41604000E+05, -.38637100E+05, 0.10440000E+06, -.97682700E+05, 0.51424600E+05, 0.56390400E+04, 0.21835900E+05, -.42418400E+05, -.52102700E+05, -.25851300E+04, -.23528000E+05, 0.15637000E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.61535700E-01, -.73799400E+00, -.99727300E-01, 0.42551900E+00, -.32978900E+00, 0.30962800E+00, 0.49978000E-02, 0.60779200E-01, 0.28539300E+01, -.95007400E-01, -.59110100E-01, 0.71233200E-01, -.13120200E+00, -.10739200E+00, 0.15436700E+02, 0.11783600E+04, 0.43537300E+04, -.20722200E+04, -.37491700E+03, -.12708200E+04, 0.28185300E+04, -.37244100E+03, 0.22960200E+06, -.11465900E+06, -.96063400E+05, -.11478400E+06, -.48544100E+05, -.15348300E+05, -.18715900E+05, 0.41981400E+05, -.36033600E+05, -.17774800E+05, -.67855900E+05, 0.10199000E+06, -.50207400E+05, -.37987800E+05, -.50877300E+05, -.20876200E+05, -.86829600E+04, -.73173500E+04, 0.25406700E+05, -.15109800E+05, -.10446800E+05, -.36109500E+05, -.79236300E+05, 0.39468700E+05, 0.32568900E+05, 0.39495200E+05, 0.13563300E+05, -.93790300E+03, 0.11183000E+05, -.15211600E+05, 0.13969800E+05, 0.31665300E+03, 0.23826300E+05, 0.17890300E+06, -.90226700E+05, -.71915600E+05, -.89378100E+05, -.40334000E+05, -.22897300E+05, -.51613400E+04, 0.42646000E+05, -.21773000E+05, -.25001800E+05, -.51077900E+05, 0.14704800E+05, -.71902500E+04, -.86859500E+04, -.73380600E+04, 0.89374100E+03, 0.91604100E+04, -.75326200E+04, -.31565900E+03, -.64063700E+04, 0.69013600E+04, -.44146100E+04, 0.74599600E+05, -.37436600E+05, -.33992900E+05, -.37262300E+05, -.18006800E+05, -.10758700E+05, -.34098100E+04, 0.14772700E+05, -.12029700E+05, -.11097900E+05, -.20912400E+05, 0.24675300E+06, -.12347100E+06, -.96584000E+05, -.12324000E+06, -.44407300E+05, 0.12211800E+05, -.45089900E+05, 0.28645400E+05, -.60242500E+05, 0.92174900E+04, -.61565300E+05, -.14175500E+06, 0.71006400E+05, 0.62696800E+05, 0.70787100E+05, 0.26670600E+05, -.56736400E+04, 0.27133400E+05, -.11154500E+05, 0.34805200E+05, -.46837900E+04, 0.34908000E+05, -.46333500E+05, 0.22975800E+05, 0.18726100E+05, 0.23161200E+05, 0.53685100E+04, -.14781000E+05, 0.16213300E+05, 0.50035200E+04, 0.19736900E+05, -.14112000E+05, 0.85680000E+04, -.15881700E+06, 0.78875800E+05, 0.67709100E+05, 0.79332500E+05, 0.32318900E+05, 0.12180900E+05, 0.13159900E+05, -.33275100E+05, 0.20570600E+05, 0.13867900E+05, 0.45551200E+05, -.77645800E+05, 0.39025500E+05, 0.28683300E+05, 0.38765200E+05, 0.14118200E+05, 0.14656000E+04, 0.88542200E+04, -.18330500E+05, 0.13528100E+05, 0.27504200E+04, 0.23591100E+05, -.71411000E+05, 0.36127200E+05, 0.28402400E+05, 0.35632700E+05, 0.11733000E+05, -.38587800E+04, 0.11536700E+05, -.13689100E+05, 0.14647300E+05, -.25668000E+04, 0.18465000E+05, -.13490600E+06, 0.67377400E+05, 0.55854900E+05, 0.67394800E+05, 0.24266500E+05, -.12869400E+05, 0.26617500E+05, -.61520000E+04, 0.39241400E+05, -.11271100E+05, 0.36390600E+05, -.19347500E+05, 0.97570800E+04, 0.89910300E+04, 0.96439300E+04, 0.49817400E+04, 0.47466400E+04, 0.50339000E+03, -.66953400E+04, 0.15029300E+04, 0.50827500E+04, 0.49077700E+04, -.36629700E+06, 0.18230700E+06, 0.15417400E+06, 0.18288000E+06, 0.69706900E+05, 0.41129500E+04, 0.46743200E+05, -.53734000E+05, 0.65829000E+05, 0.73348500E+04, 0.10377900E+06, -.11737800E+06, 0.58733700E+05, 0.47413200E+05, 0.58650700E+05, 0.25462300E+05, 0.41450000E+04, 0.10704800E+05, -.19406100E+05, 0.17640500E+05, 0.56241000E+04, 0.33039200E+05, 0.22670600E+06, -.11245600E+06, -.92273300E+05, -.11317500E+06, -.50358600E+05, -.27767900E+05, -.96079300E+04, 0.54691900E+05, -.27771600E+05, -.30670600E+05, -.71071100E+05, -.13458900E+06, 0.67392200E+05, 0.47856000E+05, 0.67208000E+05, 0.18015500E+05, -.27737100E+05, 0.36877500E+05, 0.21379600E+04, 0.45465900E+05, -.26064100E+05, 0.33201800E+05, 0.60388500E+05, -.30130400E+05, -.25670700E+05, -.30144800E+05, -.92099900E+04, 0.86359400E+04, -.14581800E+05, 0.40913600E+04, -.18586600E+05, 0.77036000E+04, -.13786300E+05, 0.73437500E+04, -.37105600E+04, -.35119600E+04, -.36476400E+04, -.22159000E+04, -.14604200E+04, -.30923400E+03, 0.23314800E+04, -.67565200E+03, -.14929500E+04, -.12136600E+04, 0.37727200E+05, -.65699300E+04, -.73906300E+04, -.21759500E+04, 0.28293800E+05, 0.27455300E+05, 0.24436800E+05, 0.77514800E+04, 0.10118400E+04, 0.99997900E+04, 0.88530300E+04, -.20654800E+05, -.15773000E+04, 0.31646100E+05, -.31014400E+05, 0.16141200E+05, 0.30161900E+04, -.10242400E+05, 0.18386800E+05, -.11772000E+05, 0.20080100E+05, -.95357200E+04, 0.65152800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23360400E+00, 0.41806000E-01, -.99447000E-02, -.42176600E+00, 0.12741700E+00, -.64102700E-01, -.58931900E-01, -.36921900E+00, -.58778000E+01, -.13171900E+00, 0.24654000E-01, 0.32616100E-01, 0.12501600E-01, 0.53141400E-01, 0.20730800E+00, -.24366900E+04, -.22960600E+04, 0.19759700E+04, 0.34664900E+04, 0.49149400E+03, -.12229600E+04, 0.32107000E+04, -.12101700E+06, 0.57276400E+05, -.87725200E+04, 0.60510100E+05, -.59243000E+05, -.78297800E+05, 0.57313000E+05, -.11844300E+05, 0.66218300E+05, -.65093200E+05, 0.84705400E+05, -.12358000E+06, 0.60023700E+05, 0.15838500E+05, 0.61788800E+05, -.25151100E+05, -.52982200E+05, 0.41923600E+05, -.95981100E+04, 0.53290400E+05, -.43491100E+05, 0.65526600E+05, 0.68327300E+05, -.32180400E+05, -.12268000E+04, -.34161600E+05, 0.17757200E+05, 0.33088500E+05, -.23920300E+05, 0.53492000E+04, -.30686300E+05, 0.26386100E+05, -.41039700E+05, -.11662100E+06, 0.55092000E+05, -.31959100E+05, 0.58313100E+05, -.59827200E+05, -.86367100E+05, 0.62356100E+05, -.33223600E+04, 0.64207900E+05, -.69494600E+05, 0.77292200E+05, 0.25726700E+04, -.14942000E+04, 0.19921000E+04, -.12859100E+04, -.76649900E+04, -.42926000E+04, 0.19954700E+04, 0.23032900E+04, -.10953300E+04, -.28424000E+04, 0.91776500E+04, -.65683000E+04, 0.34064600E+04, 0.19232700E+04, 0.32854900E+04, -.84023700E+04, -.68647100E+04, 0.82147000E+04, -.46473500E+03, 0.63307800E+04, -.54032400E+04, 0.10090500E+05, -.20828700E+06, 0.10345500E+06, 0.88990900E+04, 0.10415100E+06, -.68888000E+05, -.80733100E+05, 0.57988400E+05, -.39297200E+05, 0.83872800E+05, -.63336900E+05, 0.14134900E+06, 0.42131400E+05, -.21065800E+05, -.80575400E+04, -.21067700E+05, 0.27619500E+05, 0.20237300E+05, -.13024300E+05, 0.15343600E+05, -.18230200E+05, 0.14534000E+05, -.45468300E+05, 0.72763100E+05, -.35560900E+05, 0.87552500E+03, -.36382000E+05, 0.23477400E+05, 0.24607400E+05, -.17999200E+05, 0.15594600E+05, -.27139800E+05, 0.19793400E+05, -.50411100E+05, 0.62414300E+05, -.31858700E+05, 0.39876000E+05, -.31210300E+05, 0.32615400E+05, 0.38210400E+05, -.27771900E+05, 0.53017600E+04, -.36907200E+05, 0.29679200E+05, -.47850500E+05, 0.98165600E+05, -.45865000E+05, -.15868300E+05, -.49080500E+05, 0.16044300E+05, 0.38114000E+05, -.31289600E+05, 0.70603700E+04, -.40552700E+05, 0.30413600E+05, -.52632100E+05, 0.79827100E+05, -.36749600E+05, -.98656400E+04, -.39911900E+05, 0.15345400E+05, 0.33771200E+05, -.26337300E+05, 0.55336500E+04, -.33044900E+05, 0.26316900E+05, -.46282200E+05, 0.92642200E+05, -.45147200E+05, -.82792400E+04, -.46321900E+05, 0.41076400E+05, 0.44373900E+05, -.31447800E+05, 0.20894400E+05, -.37764000E+05, 0.35830900E+05, -.69728300E+05, 0.47245200E+04, -.25417700E+04, -.41654600E+04, -.23619200E+04, -.95490900E+03, -.33424300E+03, -.14636500E+04, -.11185900E+04, -.28933800E+04, -.47679400E+03, -.17248800E+04, 0.19747000E+06, -.99412100E+05, 0.80044200E+05, -.98734700E+05, 0.96814000E+05, 0.10893900E+06, -.74014600E+05, 0.31519600E+05, -.10264000E+06, 0.86219200E+05, -.14585000E+06, 0.80502400E+05, -.38656300E+05, 0.18748200E+05, -.40250600E+05, 0.43555900E+05, 0.55385900E+05, -.35485300E+05, 0.10890100E+05, -.42874300E+05, 0.44905800E+05, -.57176600E+05, -.18770800E+06, 0.92199600E+05, 0.28391100E+03, 0.93859300E+05, -.67103200E+05, -.10365200E+06, 0.78712000E+05, -.12770100E+05, 0.93354100E+05, -.86553500E+05, 0.11196000E+06, 0.16511400E+06, -.82976900E+05, 0.34607500E+05, -.82561700E+05, 0.58097400E+05, 0.66845300E+05, -.42346100E+05, 0.36892500E+05, -.65082000E+05, 0.52063200E+05, -.11097100E+06, -.45346200E+05, 0.20572000E+05, 0.13581000E+05, 0.22673700E+05, -.22567300E+05, -.21332500E+05, 0.13906300E+05, -.97827800E+04, 0.18080700E+05, -.17309900E+05, 0.37350200E+05, 0.91671400E+04, -.47512700E+04, 0.16004600E+04, -.45811100E+04, -.16559000E+03, 0.54574300E+03, -.11827000E+04, 0.17023100E+04, -.25069200E+04, 0.37266800E+03, -.39457800E+04, -.24001600E+05, -.33439900E+05, -.33522300E+05, 0.17954700E+05, 0.33360500E+05, 0.36286300E+05, -.15306500E+05, 0.33445200E+05, 0.33849200E+05, 0.25807700E+05, 0.32009500E+05, -.28073900E+05, 0.20859000E+05, 0.38176000E+05, -.39142400E+05, 0.26787000E+05, 0.37459500E+05, -.14857100E+05, -.10062100E+05, -.14413800E+05, 0.16087400E+05, -.29962200E+05, 0.33273200E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.91782900E-01, -.14659400E+00, 0.41294300E-01, -.11793300E+00, -.67547000E-01, -.21791500E-02, -.10866200E+00, 0.49175800E-01, 0.85293800E+00, -.10448700E+00, -.75251300E-03, 0.29930300E+00, -.14760800E+00, -.27705600E-01, 0.33928200E-01, 0.27453600E+00, -.24177300E+04, 0.22627900E+04, 0.19995900E+04, -.32904000E+03, -.11800800E+04, -.99699700E+03, -.33851300E+05, 0.15910100E+05, -.12766400E+05, 0.16925900E+05, -.14334800E+04, 0.83692100E+04, -.14103300E+05, -.38147700E+05, -.18128500E+04, 0.12996300E+05, 0.21665500E+05, -.21417300E+05, 0.10140300E+05, -.15383700E+04, 0.10708600E+05, -.42915700E+04, -.10177500E+05, 0.30278800E+04, -.10509700E+05, 0.57323500E+04, -.65284100E+04, 0.92340800E+04, -.42732000E+04, 0.27111300E+04, 0.63122900E+04, 0.21369300E+04, 0.55122900E+04, 0.65070800E+04, 0.15109700E+04, 0.81336600E+04, 0.40466100E+04, 0.31767400E+04, 0.13938300E+04, -.43550700E+05, 0.20815900E+05, -.10392200E+05, 0.21776200E+05, 0.99527200E+03, 0.61007900E+03, -.46585200E+04, -.25655400E+05, 0.46155000E+04, 0.53517000E+04, 0.23612400E+05, 0.18247600E+03, -.15306300E+03, -.25909700E+04, -.91098400E+02, -.31030000E+03, -.22736400E+04, 0.10937000E+04, -.11086100E+04, -.15788300E+04, -.39458400E+03, 0.49531200E+03, -.21388800E+04, 0.10736200E+04, -.83948200E+04, 0.10698500E+04, 0.36469500E+04, 0.70371500E+04, -.71207900E+04, -.95994500E+04, -.24394800E+04, 0.77449800E+04, 0.39250300E+04, -.77193400E+04, 0.34654000E+04, -.23350300E+05, 0.38622300E+04, -.19717400E+05, -.41997000E+04, -.13463600E+05, -.43442100E+05, -.83734500E+04, 0.36810900E+04, 0.19128000E+05, -.13749700E+05, 0.69818800E+04, 0.24096800E+05, 0.68742700E+04, 0.39517500E+04, -.91355400E+04, 0.16101300E+05, 0.25464600E+05, 0.12150200E+05, -.12624100E+05, -.47601900E+04, 0.41996500E+04, -.18119000E+04, 0.39366400E+04, -.20999600E+04, 0.94731900E+04, 0.12062500E+04, 0.44823100E+04, 0.15748500E+05, 0.16793000E+04, -.14712800E+04, -.81480500E+04, -.13175400E+04, 0.62736600E+03, 0.14565000E+05, 0.65817500E+03, 0.53297200E+04, -.27705100E+04, 0.96245800E+04, 0.18612000E+05, 0.89750200E+04, -.63004400E+04, -.36817000E+04, 0.91399400E+04, -.36998700E+04, 0.27328600E+04, -.45695900E+04, 0.44848300E+04, 0.91083900E+04, -.20459100E+04, 0.73069200E+04, -.22787800E+04, 0.56681200E+04, -.32827100E+04, -.42432200E+04, 0.29636400E+04, 0.56173600E+04, 0.21217400E+04, 0.56583900E+04, 0.84785300E+04, 0.24907900E+03, 0.68343600E+04, 0.30481700E+04, 0.46984900E+04, 0.17318700E+04, -.58358200E+04, 0.33321600E+04, 0.17491000E+05, 0.29176600E+04, 0.10373900E+05, -.39234700E+04, 0.14263000E+05, 0.29512000E+05, 0.99311900E+04, -.84166900E+04, -.84874700E+04, -.72896400E+03, 0.32527800E+03, 0.65334600E+03, 0.36463600E+03, -.11611800E+04, -.12733600E+03, 0.25268400E+03, 0.12348300E+03, 0.49809500E+03, -.24094900E+03, 0.86160000E+03, -.10269000E+05, 0.52679800E+04, 0.42108500E+05, 0.51350600E+04, 0.24573600E+05, -.65503900E+04, 0.28786700E+05, 0.58972200E+05, 0.24141000E+05, -.16689600E+05, -.12449200E+05, 0.20051400E+05, -.94864000E+04, 0.56820700E+04, -.10025500E+05, 0.64902300E+04, -.15660500E+04, 0.70619100E+04, 0.23360200E+05, 0.14067100E+04, -.49746400E+04, -.14549300E+05, -.60701400E+05, 0.29710900E+05, -.27756700E+04, 0.30352300E+05, -.17178900E+04, -.37713600E+04, -.22549500E+04, -.31818100E+05, 0.10675400E+05, 0.14944400E+04, 0.30217100E+05, 0.25615400E+04, -.12320500E+04, 0.22909200E+05, -.12823300E+04, 0.22400100E+05, 0.29294900E+04, 0.11792300E+05, 0.35998700E+05, 0.67050600E+04, -.33380400E+04, -.15421000E+05, -.10791500E+05, 0.47270800E+04, -.20396200E+04, 0.53958900E+04, -.56088900E+04, -.14968400E+04, -.17644200E+04, -.12754100E+05, 0.87769100E+03, 0.85037900E+03, 0.89100500E+04, 0.27691300E+04, -.14424800E+04, -.20038800E+04, -.13837700E+04, 0.75981900E+03, 0.40998600E+03, -.55743700E+03, 0.40192600E+03, -.11219000E+04, 0.40002000E+03, -.15282900E+04, -.54104400E+04, 0.31294000E+04, 0.40692000E+04, 0.49083600E+04, 0.47715400E+04, 0.60597000E+04, -.18796400E+04, -.39193700E+04, -.41174800E+02, -.34433400E+04, -.57760200E+03, -.13334700E+04, -.33164100E+04, 0.53203300E+04, -.60663300E+04, -.10659700E+03, -.31070800E+04, 0.12178900E+04, -.16935400E+04, -.36780200E+04, -.11922300E+04, 0.34251800E+04, -.31284000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10548700E+00, -.44381100E+00, 0.25996900E-01, -.40268700E+00, -.60877700E-01, 0.44703900E+00, -.26877000E-01, -.39502100E+00, -.43920800E+01, -.18944700E+00, 0.46995300E-01, -.60160600E-01, 0.29497100E+00, -.59366000E-01, 0.11125300E+00, 0.36705400E+00, 0.14563700E+01, -.13795500E+04, -.63218800E+03, 0.52857400E+03, -.51327700E+03, 0.18110600E+04, -.15420500E+05, 0.74236600E+04, 0.76554600E+04, 0.77103400E+04, -.16202300E+05, -.51369400E+05, 0.45518600E+05, 0.50215700E+05, 0.43614300E+05, -.50814100E+05, 0.75515200E+04, -.15406300E+05, 0.73531400E+04, -.17387600E+03, 0.77030200E+04, -.66314600E+04, -.18579300E+05, 0.16867400E+05, 0.15773500E+05, 0.19976000E+05, -.17743000E+05, 0.92045900E+04, 0.21246600E+05, -.10388800E+05, -.17046800E+04, -.10623200E+05, 0.28466700E+04, 0.15094200E+05, -.15095000E+05, -.14406000E+05, -.20044500E+05, 0.14921000E+05, -.10553400E+05, 0.10338700E+05, -.50490900E+04, -.55626600E+04, -.51692700E+04, -.20097000E+05, -.42348700E+05, 0.33246800E+05, 0.39130600E+05, 0.29206800E+05, -.40531800E+05, -.29702500E+04, -.10133700E+04, 0.38091200E+03, 0.45039800E+04, 0.50669100E+03, -.29677600E+02, -.23944600E+04, 0.81395500E+03, 0.31864000E+04, 0.21415600E+04, -.33336100E+04, 0.21259200E+04, -.33793900E+04, 0.18678000E+04, 0.10033500E+05, 0.16897300E+04, -.46562000E+04, -.13777100E+05, 0.13275100E+05, 0.13937600E+05, 0.10118100E+05, -.13910000E+05, -.12924100E+04, -.75898100E+05, 0.38335000E+05, 0.28570300E+05, 0.37949200E+05, -.66079600E+03, -.46507900E+05, 0.51511600E+05, 0.49465200E+05, 0.57324900E+05, -.46526800E+05, 0.25024900E+05, 0.39181700E+05, -.19908000E+05, -.30969700E+05, -.19590900E+05, 0.17026700E+04, 0.29037500E+05, -.30958100E+05, -.31466200E+05, -.31321600E+05, 0.29938300E+05, -.95139400E+04, 0.41181200E+05, -.20462100E+05, -.75337900E+04, -.20590600E+05, -.28167100E+04, 0.13715300E+05, -.18375500E+05, -.13375400E+05, -.19901600E+05, 0.14312900E+05, -.15381100E+05, 0.14451200E+05, -.73096700E+04, 0.57351900E+04, -.72257500E+04, 0.67539000E+04, 0.28479400E+05, -.26628600E+05, -.30798700E+05, -.32565400E+05, 0.28448900E+05, -.62452100E+04, 0.19938600E+05, -.96542600E+04, -.20970700E+04, -.99691800E+04, 0.35051900E+04, 0.13706500E+05, -.13649300E+05, -.11788100E+05, -.17655000E+05, 0.13236400E+05, -.10912900E+05, 0.26375900E+05, -.12931900E+05, -.43470600E+04, -.13187800E+05, 0.19206300E+04, 0.13507600E+05, -.14620600E+05, -.12083700E+05, -.19511400E+05, 0.13354000E+05, -.12787600E+05, 0.54885200E+05, -.27408600E+05, -.26200600E+05, -.27442600E+05, -.56776200E+03, 0.31109400E+05, -.35760600E+05, -.31624400E+05, -.35220800E+05, 0.32078800E+05, -.17474700E+05, -.17738500E+04, 0.77741900E+03, -.47371300E+03, 0.88692000E+03, 0.12623700E+04, 0.16023500E+04, -.11989100E+04, -.25227500E+04, -.20622400E+04, 0.15114600E+04, 0.64097000E+03, 0.73511700E+05, -.37043300E+05, -.89022900E+04, -.36756000E+05, 0.88506500E+04, 0.74183300E+05, -.75746500E+05, -.81581700E+05, -.88170900E+05, 0.75210100E+05, -.26697600E+05, 0.69047600E+04, -.34393800E+04, 0.27709600E+04, -.34523800E+04, 0.81601700E+04, 0.29609100E+05, -.25557500E+05, -.29841900E+05, -.26067700E+05, 0.28940700E+05, -.28169300E+04, 0.77690300E+03, -.71697100E+03, -.40204900E+04, -.38829200E+03, -.20682400E+05, -.47765300E+05, 0.39125800E+05, 0.44653100E+05, 0.38296100E+05, -.46278100E+05, 0.33845300E+04, 0.76502400E+05, -.38706300E+05, -.17922700E+05, -.38251300E+05, -.52548900E+04, 0.32464900E+05, -.39968800E+05, -.34421400E+05, -.44417700E+05, 0.32963100E+05, -.26444300E+05, -.10367000E+05, 0.49871000E+04, 0.90901400E+04, 0.51835300E+04, -.10099800E+04, -.12830800E+05, 0.11911400E+05, 0.14425900E+05, 0.10719600E+05, -.13119500E+05, 0.35997200E+04, 0.38519700E+04, -.19037700E+04, 0.17413100E+04, -.19259400E+04, -.13007400E+04, -.13613700E+04, 0.34274700E+03, 0.14652500E+04, 0.29461900E+03, -.12387500E+04, -.12446000E+04, -.32559500E+04, -.23199600E+05, -.23913100E+05, -.25030400E+04, 0.22482500E+04, 0.32363500E+04, -.45040300E+04, 0.23501600E+05, 0.18307500E+05, 0.17384100E+05, 0.16655400E+05, -.11969900E+05, 0.10201100E+05, 0.35046700E+04, -.40808100E+04, 0.12442600E+05, 0.24700200E+05, -.71140600E+04, -.26499700E+04, 0.23180700E+04, 0.99175700E+04, -.20935600E+05, 0.23047000E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15624300E+01, 0.10785200E+01, 0.97998000E+00, 0.31256300E+00, -.94623000E-01, -.23702300E+00, 0.35072100E+00, 0.24353000E+01, 0.20870100E+02, -.71324500E+00, 0.16868200E-01, 0.50523500E+00, -.64407000E-01, -.13797400E+00, 0.15284300E+01, -.67910100E+00, 0.66173800E+00, 0.41513700E+01, -.16529500E+05, -.63000600E+04, 0.32489600E+04, -.72362200E+04, -.20639200E+06, 0.10758700E+06, 0.15354100E+06, 0.10319300E+06, 0.27291500E+06, 0.39652400E+06, -.27521500E+06, -.29197500E+06, -.20343000E+06, 0.37134300E+06, -.50266800E+04, 0.15887700E+06, -.77490000E+05, 0.66752600E+04, -.79438100E+05, 0.10598200E+06, 0.19026600E+06, -.15277000E+06, -.10609800E+06, -.16898100E+06, 0.17009700E+06, -.10593300E+06, -.12662900E+06, 0.60026700E+05, -.12588900E+05, 0.63310200E+05, -.58383500E+05, -.12003500E+06, 0.99749500E+05, 0.82985200E+05, 0.12749500E+06, -.10740200E+06, 0.90650400E+05, -.25004800E+06, 0.12967100E+06, 0.19570400E+06, 0.12501400E+06, 0.25907800E+06, 0.36972900E+06, -.24726800E+06, -.26502000E+06, -.15655200E+06, 0.33710400E+06, 0.28118300E+05, -.20393800E+05, 0.10768900E+05, -.11819000E+05, 0.10195300E+05, 0.85816700E+04, 0.80667100E+04, -.34074800E+04, -.32706400E+05, -.43095400E+04, 0.13829400E+05, -.74326200E+04, -.14858000E+06, 0.73141700E+05, 0.28419700E+05, 0.74285100E+05, 0.83453100E+05, 0.10537600E+06, -.75994600E+05, -.10145300E+06, -.21168600E+05, 0.10044800E+06, 0.49758600E+05, 0.26895600E+06, -.13684900E+06, -.19265100E+05, -.13450700E+06, 0.18408700E+06, 0.30014000E+06, -.24602500E+06, -.20515400E+06, -.26810000E+06, 0.27046600E+06, -.22021600E+06, 0.34510800E+05, -.14830400E+05, 0.39783000E+05, -.17248900E+05, -.11096700E+06, -.15854500E+06, 0.11567800E+06, 0.14005300E+06, 0.91497700E+05, -.14878600E+06, 0.29187900E+05, -.20571400E+06, 0.10175800E+06, -.11335700E+04, 0.10285800E+06, -.31469100E+05, -.69142400E+05, 0.74047700E+05, 0.16890100E+05, 0.89589700E+05, -.64676900E+05, 0.12332700E+06, 0.14140200E+06, -.66832100E+05, -.19880800E+06, -.70693600E+05, -.14089100E+06, -.20591300E+06, 0.14149400E+06, 0.19116800E+06, 0.15087600E+06, -.19284600E+06, 0.15005900E+04, -.22011500E+06, 0.10356700E+06, 0.29785000E+05, 0.11005300E+06, -.61783100E+05, -.12975800E+06, 0.12150500E+06, 0.76037400E+05, 0.15504700E+06, -.11349300E+06, 0.13038400E+06, -.22724900E+06, 0.10698000E+06, 0.32390600E+05, 0.11362300E+06, -.46698600E+05, -.11071300E+06, 0.11073300E+06, 0.70461300E+05, 0.14666100E+06, -.96496900E+05, 0.13620300E+06, -.13826900E+06, 0.67933300E+05, 0.37794400E+05, 0.69137500E+05, -.11405400E+06, -.19077800E+06, 0.17065500E+06, 0.12529100E+06, 0.13681200E+06, -.17997300E+06, 0.10814000E+06, 0.24323800E+05, -.11409900E+05, -.29463200E+04, -.12163600E+05, -.13250000E+05, -.14859700E+05, 0.89985700E+04, 0.27919200E+05, 0.10770000E+05, -.13794800E+05, -.61995200E+04, 0.46802800E+05, -.16147800E+05, -.31744400E+06, -.23407000E+05, -.30554400E+06, -.48473900E+06, 0.36498700E+06, 0.40026500E+06, 0.38888000E+06, -.45376800E+06, 0.12623900E+06, 0.75608200E+05, -.39324600E+05, -.11745400E+06, -.37806800E+05, -.15039300E+06, -.22249400E+06, 0.14938900E+06, 0.14712200E+06, 0.13058100E+06, -.20422500E+06, 0.28789600E+05, -.15179200E+06, 0.76346100E+05, 0.16811800E+06, 0.75878100E+05, 0.29985100E+06, 0.43998900E+06, -.30149700E+06, -.29508400E+06, -.24185100E+06, 0.40616700E+06, -.27730500E+05, -.35403800E+06, 0.18103200E+06, -.28025100E+05, 0.17703700E+06, -.82819400E+05, -.17298600E+06, 0.16001900E+06, 0.67697200E+05, 0.19497400E+06, -.15431100E+06, 0.22118700E+06, 0.31946400E+05, -.12663500E+05, -.31006200E+05, -.15975100E+05, 0.51665500E+05, 0.74226900E+05, -.52659100E+05, -.54800500E+05, -.45758700E+05, 0.69704400E+05, -.48932100E+05, -.39568700E+05, 0.19887700E+05, -.56144200E+04, 0.19775400E+05, 0.90355200E+04, 0.74510000E+04, -.57068600E+03, -.15623000E+05, 0.51305800E+04, 0.67223200E+04, 0.11174900E+05, -.26893300E+05, 0.16838500E+06, 0.17404200E+06, -.14072300E+05, -.11352400E+06, -.12245400E+06, -.55725300E+04, -.17206500E+06, -.12948900E+06, -.14120300E+06, -.13994000E+06, 0.13594600E+06, -.89297200E+05, -.13446700E+06, 0.13683600E+06, -.12742200E+06, -.18700000E+06, 0.82982300E+05, -.15826500E+05, 0.33204800E+05, -.11145600E+06, 0.15776300E+06, -.16743500E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36141300E+00, 0.83135700E+00, -.12417600E+00, 0.35494100E+00, -.37536300E+00, -.62320100E+00, 0.15135900E-01, -.15335800E+00, -.76202900E+01, -.61715600E+00, 0.72424900E-01, -.15016200E+00, -.67995900E-01, -.17222900E-01, -.35866200E+00, 0.66748400E-01, -.11470800E+01, -.84199600E+00, -.70680400E-01, -.41390000E+04, 0.13138900E+04, 0.35812800E+04, -.73467200E+05, 0.30369300E+05, -.11091200E+06, 0.36734600E+05, -.70085100E+05, -.70462700E+05, 0.20456800E+05, -.40503300E+05, 0.69325400E+05, -.54669300E+05, 0.10604900E+06, -.64558400E+05, 0.29239000E+05, -.37316400E+05, 0.32280100E+05, -.50156700E+05, -.97506700E+05, 0.46189000E+05, 0.77482900E+04, 0.65080500E+05, -.81730700E+05, 0.47288700E+05, -.32069000E+05, 0.19780600E+05, 0.49618100E+05, 0.16035500E+05, 0.44070300E+05, 0.63659600E+05, -.17600100E+05, -.96712200E+04, -.17449900E+05, 0.50528600E+05, -.76475200E+04, -.10282700E+06, 0.43957200E+05, -.11455200E+06, 0.51417600E+05, -.62809700E+05, -.94104200E+05, 0.46624900E+05, -.12776200E+05, 0.79590200E+05, -.72963900E+05, 0.10243900E+06, 0.10719100E+05, -.54415500E+04, -.15541200E+05, -.53588500E+04, -.10828300E+04, 0.57028200E+04, -.84248400E+04, -.66505400E+04, -.10522600E+05, 0.69229600E+04, 0.13823700E+05, 0.21207800E+05, -.10867700E+05, -.45660300E+05, -.10601800E+05, -.20960000E+04, 0.24870900E+04, -.90599300E+04, -.61662700E+04, 0.67708600E+04, 0.23401200E+04, 0.13569800E+05, -.48377900E+04, -.73939000E+02, -.13436600E+06, 0.24317700E+04, -.13137700E+06, -.94172300E+05, 0.62906100E+04, -.64360600E+05, 0.35820300E+05, -.68642300E+05, 0.12545800E+06, -.66223500E+05, 0.34049500E+05, 0.10329700E+06, 0.33109000E+05, 0.37879400E+05, -.19511300E+03, 0.33212700E+05, 0.40083700E+05, 0.75127000E+04, -.67313900E+04, -.44824100E+05, 0.59995700E+05, -.28637600E+05, 0.23882200E+05, -.29998600E+05, 0.46111800E+05, 0.20604300E+05, -.68670800E+04, 0.37286300E+05, -.17681700E+05, 0.12525500E+05, -.69811900E+05, -.74268100E+05, 0.35887500E+05, 0.12596700E+06, 0.37131900E+05, 0.61839500E+05, 0.45188100E+05, 0.11477000E+04, 0.11293400E+04, -.92377900E+04, 0.32598800E+05, -.15038600E+05, 0.20285300E+05, -.38833100E+04, 0.33158600E+05, -.10141600E+05, 0.41557600E+05, 0.79551200E+05, -.33453700E+05, -.13106200E+05, -.42680400E+05, 0.64638600E+05, -.27274900E+05, -.26249800E+05, 0.19374000E+05, 0.40313200E+05, 0.13124700E+05, 0.43080200E+05, 0.71437700E+05, -.22530000E+05, -.13589700E+05, -.20291500E+05, 0.55913700E+05, -.12010900E+05, 0.50290800E+04, -.12844500E+03, 0.70716100E+05, -.25158300E+04, 0.66031600E+05, 0.31396800E+05, 0.96223600E+04, 0.58569000E+05, -.71660200E+04, 0.19240400E+05, -.73777000E+05, -.22862200E+05, 0.11346200E+05, 0.87327100E+04, 0.11432000E+05, 0.59084300E+03, 0.45214200E+04, 0.67238000E+03, -.81126800E+04, 0.88911500E+02, 0.46207600E+04, 0.89900400E+04, -.12363200E+06, 0.61154800E+05, 0.28914600E+06, 0.61819800E+05, 0.18852000E+06, 0.11699600E+06, 0.50352800E+04, 0.52159800E+05, -.30972000E+05, 0.82360000E+05, -.83094300E+05, 0.42599500E+05, -.17829700E+05, 0.65200400E+05, -.21298400E+05, 0.66879400E+05, 0.57168200E+05, -.17182600E+05, 0.28123300E+05, -.39887400E+05, 0.42754100E+05, -.66405600E+05, -.16477000E+06, 0.79615500E+05, -.90050400E+05, 0.82392600E+05, -.83747800E+05, -.13072100E+06, 0.67477000E+05, -.16787300E+05, 0.12269200E+06, -.10945500E+06, 0.13433800E+06, 0.69570700E+05, -.34458300E+05, 0.11568200E+06, -.34793200E+05, 0.11524800E+06, 0.63907700E+05, -.83821800E+04, 0.75028100E+05, -.33040600E+05, 0.41220600E+05, -.12050900E+06, -.10265700E+05, 0.11837000E+04, -.23284900E+05, 0.51335700E+04, -.36986900E+05, -.18801100E+05, 0.30546800E+02, -.21322700E+05, 0.79142200E+04, -.12710000E+05, 0.46032900E+05, 0.27505900E+05, -.14179900E+05, -.88560900E+04, -.13748900E+05, -.33177000E+03, -.63389200E+03, -.36260300E+04, 0.54231300E+04, -.45698700E+04, -.10947300E+04, -.10640900E+05, -.13456500E+05, -.33163000E+05, -.32082500E+05, 0.20081700E+05, 0.49517000E+05, 0.56648300E+05, -.51230300E+04, 0.32858900E+05, 0.40111600E+05, 0.24476200E+05, 0.37836700E+05, -.43653300E+05, 0.40524700E+04, 0.56923100E+05, -.61317000E+05, 0.37209900E+05, 0.29365700E+05, -.13555200E+05, -.55519100E+04, -.22036800E+05, 0.25414100E+05, -.31883100E+05, 0.32812700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33120400E-01, 0.19435500E+01, -.35526200E+00, 0.11569500E+01, 0.84088100E-01, -.29620600E+00, -.90316800E-01, 0.28548000E+00, 0.53269500E+01, 0.92936500E+00, -.39847700E-01, 0.27274300E+00, -.15994800E+00, 0.11654900E+00, -.36218200E+00, 0.29543400E+00, 0.94481200E+00, 0.16364900E+00, 0.10374000E+00, -.54591300E+00, -.14550900E+04, -.14035700E+04, 0.22324300E+06, -.10769800E+06, -.54743800E+05, -.11162300E+06, -.24218400E+05, -.40117000E+05, 0.13576700E+05, 0.88237300E+05, -.33130800E+05, -.41236700E+05, -.10386600E+06, 0.11970100E+06, -.56870000E+05, -.34176600E+05, -.59849100E+05, -.75215900E+04, -.35957700E+04, -.64740100E+04, 0.36491700E+05, -.25493700E+05, -.52094800E+04, -.53821400E+05, -.51878600E+05, 0.23548900E+05, 0.13344800E+05, 0.25937200E+05, 0.32525100E+03, 0.20910500E+04, 0.52193200E+03, -.24570200E+05, 0.49888900E+04, 0.37850600E+04, 0.24097500E+05, 0.21855200E+06, -.10637200E+06, -.39825400E+05, -.10927800E+06, -.22308200E+05, -.27306700E+05, 0.39741500E+04, 0.70410800E+05, -.37208000E+05, -.31061300E+05, -.99347600E+05, 0.16494200E+05, -.79524600E+04, 0.43434400E+02, -.82474600E+04, 0.10382700E+04, -.29513800E+04, 0.72962700E+03, 0.75439900E+04, -.38774000E+04, -.42010700E+04, -.14733200E+05, 0.69913100E+05, -.34838900E+05, -.14019700E+05, -.34957700E+05, -.19328500E+05, -.25492000E+05, 0.10719400E+05, 0.27761400E+05, -.11445200E+05, -.24527700E+05, -.33217900E+05, 0.18661600E+06, -.91714400E+05, -.34901800E+05, -.93314500E+05, 0.12552700E+05, -.56230900E+04, -.43883300E+04, 0.85994600E+05, -.35245000E+05, -.10360800E+05, -.10378300E+06, -.95052400E+05, 0.46779400E+05, 0.70205100E+04, 0.47527800E+05, 0.94554400E+04, 0.28288600E+05, -.13063700E+05, -.52445700E+05, 0.14235100E+05, 0.28369700E+05, 0.57948200E+05, -.43167600E+05, 0.20610000E+05, 0.75806000E+04, 0.21584100E+05, -.18411100E+05, -.11198200E+05, 0.62802300E+04, -.19973900E+05, 0.13657300E+05, -.85328200E+04, 0.30606900E+05, -.10614300E+06, 0.52231200E+05, 0.26216900E+05, 0.53074800E+05, 0.11321300E+05, 0.23861400E+05, -.96241000E+04, -.49947800E+05, 0.46027600E+04, 0.26010700E+05, 0.47927500E+05, -.76366400E+05, 0.34974200E+05, 0.23024700E+05, 0.38180800E+05, 0.43611300E+04, 0.22570200E+04, 0.40151800E+04, -.26098600E+05, 0.15090400E+05, 0.35600800E+04, 0.33398400E+05, -.48858800E+05, 0.21534500E+05, 0.13454200E+05, 0.24427500E+05, 0.81445600E+03, 0.10874100E+04, 0.11820700E+04, -.22189900E+05, 0.68502700E+04, 0.27625100E+04, 0.22311600E+05, -.99912900E+05, 0.48623700E+05, 0.15517800E+05, 0.49957000E+05, -.49341100E+04, 0.13434200E+05, -.89137800E+04, -.53727000E+05, 0.19358300E+05, 0.15153100E+05, 0.61849300E+05, -.12768600E+05, 0.64925600E+04, 0.57882200E+04, 0.63840800E+04, 0.59809100E+04, 0.42864400E+04, -.32176200E+03, -.47099900E+04, 0.61131200E+03, 0.44919000E+04, 0.28106900E+04, -.22705600E+06, 0.11129200E+06, 0.44301500E+05, 0.11352900E+06, -.42378400E+04, 0.35676800E+05, -.21223500E+05, -.12379000E+06, 0.14557000E+05, 0.42720200E+05, 0.11805900E+06, -.10511900E+06, 0.50619500E+05, 0.24567500E+05, 0.52559100E+05, 0.14032400E+03, 0.11529900E+05, -.59626800E+04, -.46583100E+05, 0.11441900E+05, 0.14554000E+05, 0.51974900E+05, 0.27980700E+06, -.13653100E+06, -.73040100E+05, -.13990800E+06, -.23772400E+05, -.26112800E+05, -.26939700E+04, 0.88307500E+05, -.52769400E+05, -.28817900E+05, -.12644700E+06, -.83304700E+05, 0.41220100E+05, -.60630700E+03, 0.41656300E+05, -.35287300E+05, -.15467500E+05, 0.45830600E+04, -.49548600E+05, 0.19707300E+05, -.10150800E+05, 0.59477300E+05, 0.57640500E+05, -.26724700E+05, -.12213300E+05, -.28820800E+05, 0.93027200E+04, 0.26552800E+04, -.48861000E+04, 0.23074300E+05, -.14800800E+05, 0.11243400E+04, -.34871100E+05, -.44211200E+04, 0.23910900E+04, 0.15473200E+04, 0.22085500E+04, -.27862200E+04, -.27274000E+04, 0.23049000E+04, 0.82841300E+03, 0.28512000E+04, -.24734800E+04, 0.36033200E+04, 0.38382200E+05, -.14977200E+05, -.15973600E+05, -.14724400E+05, -.17683800E+04, 0.33678700E+03, 0.21268900E+05, 0.15087700E+05, -.21871100E+04, 0.15194300E+05, 0.72341600E+04, -.17764800E+05, 0.49550400E+04, -.96361200E+03, -.41047300E+03, 0.10010400E+05, 0.13138100E+05, -.10675600E+05, 0.21602900E+05, 0.58074800E+04, 0.19805400E+05, -.16130700E+05, 0.14989600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33122300E+00, 0.61425300E+00, 0.11596500E+00, 0.29963800E+00, 0.38571000E+00, 0.24233400E+00, 0.18898400E+00, 0.53203300E+00, -.68485000E+01, 0.47979600E+00, -.20010200E+00, -.82057500E+00, -.31260300E+00, 0.37921600E-01, 0.21844700E+00, -.10182400E+01, -.15814400E+01, 0.22252500E+00, 0.14081800E+00, 0.52089200E+00, -.23239800E+00, -.47478900E+04, -.10892700E+05, 0.31076700E+04, 0.11817200E+05, 0.54475300E+04, -.19137300E+05, 0.12666400E+05, -.23836500E+05, -.52886300E+05, -.20752900E+05, 0.18463700E+05, -.84824000E+04, -.48039500E+05, 0.22445800E+05, 0.25266700E+05, 0.24018500E+05, 0.33455300E+03, 0.83411200E+04, -.43158100E+04, -.28675400E+05, 0.18952200E+04, 0.10477600E+05, 0.11643800E+05, 0.27746100E+05, -.12370100E+05, -.12488800E+05, -.13871300E+05, -.64259400E+03, -.82439200E+04, 0.59129600E+04, 0.23698100E+05, 0.14934000E+04, -.99518400E+04, -.15285100E+04, -.44333800E+05, 0.20189100E+05, 0.15031500E+05, 0.22168900E+05, -.17304500E+05, -.41948400E+04, -.65327500E+04, -.40295500E+05, -.24136100E+04, 0.26610400E+04, 0.10029200E+05, 0.50690100E+04, -.27114400E+04, 0.22387500E+04, -.25342000E+04, -.30123400E+04, 0.16059100E+03, -.23637100E+04, -.35630700E+04, -.27823600E+04, 0.66413900E+03, -.13398200E+05, 0.17236400E+04, -.84013700E+03, 0.90084100E+04, -.86082600E+03, -.41638700E+04, 0.73955300E+04, -.98697100E+04, -.16691900E+05, -.99419900E+04, 0.86711900E+04, -.29629100E+04, -.48228700E+04, 0.18008600E+04, -.64645100E+03, 0.24173100E+04, -.25876900E+05, 0.92557400E+04, -.28333900E+05, -.67452600E+05, -.22999200E+05, 0.16916900E+05, -.21813300E+05, -.15969700E+05, 0.81739600E+04, -.72556600E+04, 0.79834100E+04, 0.14337600E+05, -.13344000E+05, 0.22780200E+05, 0.39676800E+05, 0.22956900E+05, -.16999700E+05, 0.20857500E+05, -.18377400E+05, 0.97545400E+04, 0.53354100E+04, 0.91884100E+04, 0.75577200E+04, -.49427200E+04, 0.12243700E+05, 0.16605500E+05, 0.10378100E+05, -.69923700E+04, 0.20107700E+05, 0.32111300E+05, -.16030300E+05, -.24200000E+04, -.16058300E+05, 0.54455400E+04, -.11464600E+05, 0.12742300E+05, 0.37010600E+05, 0.91521400E+04, -.14581200E+05, -.93792200E+04, 0.47692700E+05, -.21563700E+05, -.24970100E+05, -.23844300E+05, -.25776900E+04, -.79376300E+04, 0.22921600E+04, 0.25051500E+05, -.51053300E+04, -.94112700E+04, -.81156500E+04, 0.39011700E+05, -.17326100E+05, -.18816800E+05, -.19504300E+05, -.20887300E+04, -.81782200E+04, 0.39031900E+04, 0.24418700E+05, -.33566500E+04, -.97753200E+04, -.39007300E+04, -.19837000E+05, 0.10694000E+05, 0.29353700E+04, 0.99179800E+04, 0.16159600E+05, -.11995900E+05, 0.23928700E+05, 0.40338000E+05, 0.20358400E+05, -.16347700E+05, 0.22435200E+05, 0.22592400E+04, -.12418000E+04, -.18192100E+04, -.11294000E+04, -.67284600E+03, -.11824900E+04, 0.98242700E+03, 0.33810300E+04, 0.13217700E+04, -.12163900E+04, -.11737800E+04, 0.50059400E+05, -.24651400E+05, 0.17894600E+05, -.25030100E+05, 0.23161500E+05, -.24251700E+05, 0.36825800E+05, 0.99105700E+05, 0.26560900E+05, -.34706000E+05, -.31798800E+04, 0.24120400E+05, -.10944900E+05, -.93889800E+03, -.12059800E+05, 0.12046000E+05, -.24507000E+04, 0.84345100E+04, 0.31919900E+05, 0.51211800E+04, -.63536200E+04, -.50649300E+04, -.57778700E+05, 0.27282500E+05, 0.25872200E+05, 0.28893500E+05, -.16357500E+05, 0.37892700E+04, -.11729100E+05, -.52853400E+05, -.62852700E+04, 0.10366100E+05, 0.11823000E+05, -.31074700E+04, 0.14449000E+04, 0.27232000E+05, 0.15502200E+04, 0.21905100E+05, -.19484000E+04, 0.18973900E+05, 0.45398300E+05, 0.12234000E+05, -.88894800E+04, 0.17967700E+05, 0.36037000E+04, -.31402800E+04, 0.27861400E+04, -.18013600E+04, -.90485400E+04, 0.77870100E+03, -.70647400E+04, -.16779200E+05, -.57180900E+04, 0.28582300E+04, -.15737100E+05, -.58762700E+03, 0.18855500E+03, 0.95838000E+03, 0.29560800E+03, -.25482200E+02, 0.58048700E+03, -.60653500E+03, -.16816400E+04, -.52811900E+03, 0.45904900E+03, -.12726800E+03, -.41133100E+04, 0.55367100E+04, 0.56407500E+04, 0.84310600E+04, 0.13915200E+05, 0.12305700E+05, -.48468100E+03, -.56774000E+04, -.35802100E+04, -.43739800E+04, -.28453400E+04, -.23404400E+04, 0.29984500E+04, 0.14811200E+05, -.13622000E+05, -.36306900E+03, -.60976700E+04, -.23222000E+04, 0.21310400E+02, -.99906900E+04, -.20498800E+03, 0.56128500E+04, -.54996300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23378700E-01, -.44167200E-01, -.65918400E-01, 0.11439900E-01, -.34858300E-01, -.13412300E+00, -.28173100E-01, -.74941200E-01, 0.15313900E+01, -.26503000E+00, 0.14360400E-01, 0.19650500E+00, 0.18885500E+00, -.18659700E-01, -.95101000E-01, 0.34265800E+00, 0.65259400E+00, 0.19964400E+00, -.71822900E-01, -.24992100E+00, 0.12671400E+00, -.93897300E-01, -.77332000E+05, 0.38441700E+05, 0.14854000E+05, 0.38666000E+05, 0.65232100E+04, -.84046700E+04, 0.11759400E+05, -.13037600E+05, 0.23741400E+05, -.80133100E+04, 0.25278300E+05, -.31039900E+05, 0.15471700E+05, 0.48785400E+04, 0.15520100E+05, -.19882800E+04, -.11953900E+05, 0.87581900E+04, -.33469400E+04, 0.12322000E+05, -.11022200E+05, 0.95873200E+04, 0.19605600E+05, -.97015200E+04, -.45925800E+04, -.98028400E+04, 0.22367500E+04, 0.95733700E+04, -.64796200E+04, 0.20450300E+04, -.75294400E+04, 0.87209800E+04, -.36112300E+04, -.62660300E+05, 0.30982000E+05, 0.77764800E+04, 0.31330400E+05, 0.65813000E+04, -.47947100E+04, 0.87844000E+04, -.99781200E+04, 0.18210600E+05, -.42785300E+04, 0.20465500E+05, -.76878700E+04, 0.38601100E+04, 0.17698600E+03, 0.38439800E+04, 0.87965000E+03, -.42791800E+03, 0.94788100E+03, -.16197400E+04, 0.26920800E+04, -.65187800E+03, 0.26729700E+04, -.19767200E+05, 0.98519600E+04, 0.75524000E+03, 0.98837000E+04, 0.45780100E+04, 0.52447900E+03, 0.19158200E+04, -.27897100E+04, 0.70269800E+04, 0.11804300E+03, 0.58810900E+04, -.90116600E+05, 0.44894100E+05, 0.23398600E+05, 0.45059000E+05, -.15922700E+04, -.21886300E+05, 0.20862900E+05, -.13417600E+05, 0.32121300E+05, -.20925600E+05, 0.24757800E+05, 0.46972900E+05, -.23411900E+05, -.64072600E+04, -.23486600E+05, -.45158100E+04, 0.60101500E+04, -.82535400E+04, 0.68270900E+04, -.17350600E+05, 0.63975300E+04, -.12603300E+05, 0.32482500E+05, -.16196500E+05, -.88314500E+04, -.16241300E+05, 0.32742600E+04, 0.95859900E+04, -.87868100E+04, 0.42903300E+04, -.12532300E+05, 0.92003700E+04, -.98630100E+04, 0.30884600E+05, -.15510400E+05, -.71622200E+04, -.15442300E+05, -.13326100E+04, 0.53174100E+04, -.55067700E+04, 0.53967200E+04, -.84839500E+04, 0.46644200E+04, -.63966500E+04, 0.21149000E+05, -.10396300E+05, -.37983700E+04, -.10574600E+05, 0.25062100E+04, 0.11696000E+05, -.73956600E+04, 0.19287200E+04, -.91585500E+04, 0.10672100E+05, -.38344700E+04, 0.17798100E+05, -.87107000E+04, -.42068300E+04, -.88992000E+04, 0.27704600E+04, 0.11635700E+05, -.70504300E+04, 0.14291700E+04, -.77491400E+04, 0.10537400E+05, -.18018900E+04, 0.53515400E+05, -.26653600E+05, -.12202400E+05, -.26757800E+05, -.34118900E+02, 0.11604900E+05, -.11405200E+05, 0.77493400E+04, -.19500200E+05, 0.11343600E+05, -.16663500E+05, 0.19573300E+04, -.96684600E+03, -.84931200E+03, -.97860200E+03, -.79283200E+03, -.11332900E+03, -.23844000E+03, 0.13083700E+03, -.54499300E+03, -.84594100E+02, -.99968400E+02, 0.89130500E+05, -.44591300E+05, -.25380800E+05, -.44564900E+05, 0.16970000E+04, 0.19315600E+05, -.18134300E+05, 0.14527800E+05, -.27502000E+05, 0.17897800E+05, -.21773000E+05, 0.38274000E+05, -.18987100E+05, -.10032800E+05, -.19136900E+05, -.83915200E+03, 0.63535600E+04, -.63324400E+04, 0.68534700E+04, -.10826500E+05, 0.55651800E+04, -.11908600E+05, -.80835300E+05, 0.40368500E+05, 0.15677300E+05, 0.40418000E+05, 0.45707700E+04, -.11447200E+05, 0.13874100E+05, -.12682900E+05, 0.25770300E+05, -.10782900E+05, 0.27486200E+05, 0.57646800E+05, -.28747200E+05, -.16153800E+05, -.28823900E+05, 0.57330000E+04, 0.17206400E+05, -.14976300E+05, 0.82397600E+04, -.21186300E+05, 0.16253100E+05, -.16545400E+05, -.28591200E+05, 0.14141400E+05, 0.77834200E+04, 0.14295600E+05, -.56942200E+03, -.63613200E+04, 0.63300900E+04, -.47225900E+04, 0.10286400E+05, -.62704900E+04, 0.81805600E+04, 0.14880300E+04, -.76683200E+03, -.49542300E+03, -.74377800E+03, 0.61529800E+03, 0.46697500E+03, -.45702300E+03, 0.20308600E+03, -.61063700E+03, 0.37442000E+03, -.10830900E+04, -.12935800E+05, -.44702400E+04, -.45039300E+04, 0.13237800E+04, -.30599000E+04, -.10479700E+04, -.82286100E+04, 0.44459700E+04, 0.64674600E+04, 0.39477100E+03, 0.33235800E+04, 0.12043100E+04, 0.12167900E+04, -.20814300E+04, 0.85890400E+03, -.49537500E+03, 0.46019800E+04, 0.70362100E+03, -.64478500E+04, 0.24248300E+04, -.25832300E+04, -.30474300E+04, 0.44542200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31196600E+00, -.15446600E+00, -.14986100E+00, 0.72869800E+00, -.14539800E-01, 0.33762400E-01, 0.83662800E-01, 0.59195500E+00, 0.82053000E+01, 0.53906200E-01, -.45363000E-02, -.12043300E+00, 0.14834100E+00, -.99575900E-01, 0.48469300E+00, -.83457600E+00, 0.98848500E+00, 0.12824100E+01, 0.22421600E+00, 0.30881500E-01, 0.18395500E+00, 0.44232600E-01, 0.46806000E+00, 0.36709400E+04, 0.92030300E+04, 0.17607100E+01, 0.13795300E+05, 0.14962900E+05, -.60029000E+04, 0.52716700E+04, -.70079100E+04, 0.12205100E+05, -.87507800E+04, 0.89042900E+03, 0.22315000E+04, 0.39007100E+04, -.44686800E+03, 0.91724400E+04, 0.14140100E+05, -.54002800E+04, 0.11469000E+04, -.37092800E+04, 0.12604800E+05, -.39238900E+04, 0.79942800E+04, -.61140800E+04, -.68099600E+04, -.39945500E+04, -.71103100E+04, -.79837400E+04, 0.92577100E+03, -.15024800E+04, -.12157200E+04, -.66443700E+04, 0.12311700E+03, -.24494200E+04, 0.29946400E+04, 0.73290900E+04, 0.12281300E+04, 0.97756000E+04, 0.15228700E+05, -.85297400E+04, -.11884300E+04, -.69234800E+04, 0.12663700E+05, -.60376600E+04, -.17930600E+04, 0.15212700E+04, 0.18962700E+04, 0.89706300E+03, 0.39129900E+03, -.44400600E+03, 0.14586500E+04, 0.15879600E+04, 0.82225000E+03, -.42826500E+03, 0.28552200E+01, -.10465400E+05, 0.47042100E+04, 0.74032400E+04, 0.52343900E+04, 0.26401200E+04, 0.30426600E+04, -.11846200E+03, -.57322000E+03, 0.39007200E+03, 0.24811400E+04, 0.19750800E+04, 0.66220600E+04, -.30167900E+04, 0.14831600E+04, -.33009100E+04, 0.18487900E+05, 0.16072900E+05, -.29683100E+04, 0.13432000E+05, -.60232100E+04, 0.12435800E+05, -.14922800E+05, 0.12323900E+05, -.57138500E+04, -.10445600E+05, -.61643900E+04, -.74706500E+04, -.40685900E+04, -.39175200E+04, -.72715000E+04, -.18402100E+04, -.24732500E+04, 0.15712700E+04, -.17053200E+05, 0.72010800E+04, 0.67412200E+03, 0.85260700E+04, -.77106700E+04, -.53070500E+04, 0.27154100E+04, -.79840200E+04, 0.56023300E+04, -.40613800E+04, 0.11909900E+05, 0.17075100E+05, -.89519100E+04, -.12129500E+05, -.85415700E+04, -.74167000E+04, -.56324400E+04, 0.32992900E+03, 0.11194200E+04, -.13848400E+04, -.40357800E+04, -.16928800E+04, 0.74255700E+04, -.64942600E+04, -.56435100E+04, -.37099000E+04, -.76059600E+04, -.11121800E+05, 0.26720800E+04, -.40033600E+02, -.98832000E+02, -.95611000E+04, 0.30276200E+03, 0.11949200E+05, -.84728600E+04, -.69600600E+04, -.59724700E+04, -.74210900E+04, -.93226800E+04, 0.99967200E+03, -.38750100E+03, -.25146000E+04, -.76547200E+04, -.11068900E+04, -.22686400E+03, -.12038900E+04, -.45400300E+04, 0.11248900E+03, -.11452100E+05, -.89857700E+04, 0.12089200E+04, -.95482100E+04, 0.25195300E+04, -.70182500E+04, 0.61958900E+04, 0.26624200E+04, -.89736000E+03, -.75196700E+03, -.13307800E+04, -.53749800E+03, -.82191800E+03, 0.46905500E+02, 0.66592900E+03, -.18330200E+03, -.78794800E+03, -.37450700E+02, 0.29747000E+05, -.15720500E+05, -.21696200E+05, -.14873400E+05, -.21769500E+05, -.12500000E+05, -.18747700E+04, -.10480900E+05, -.38768100E+04, -.87128700E+04, 0.12670700E+04, -.25855100E+04, -.28294400E+03, -.13206500E+04, 0.12934900E+04, -.89534400E+04, -.84602700E+04, 0.37074100E+04, -.41025400E+04, 0.35687100E+04, -.66343600E+04, 0.66379000E+04, 0.12669000E+05, -.29710600E+04, 0.19727000E+04, -.63275700E+04, 0.14760900E+05, 0.21159500E+05, -.11811000E+05, 0.29763000E+04, -.12395800E+05, 0.18511100E+05, -.13492200E+05, -.80178400E+04, 0.48393200E+04, -.21097300E+04, 0.40028400E+04, -.11596900E+05, -.58334700E+04, -.63935600E+03, -.13876200E+05, 0.24355100E+04, -.36705000E+04, 0.10403200E+05, 0.66034900E+04, -.85883900E+03, -.18601300E+04, -.33009500E+04, 0.66399300E+04, 0.53027800E+04, -.12424200E+04, 0.54287800E+04, -.25598100E+04, 0.39885000E+04, -.67788700E+04, -.31378500E+04, 0.16546800E+04, 0.60488900E+03, 0.15720300E+04, 0.72694200E+02, 0.13820300E+03, 0.45152500E+03, -.36904300E+03, 0.10606500E+04, 0.85666600E+02, 0.83729000E+03, 0.45679100E+03, 0.67456100E+04, 0.67044000E+04, -.23770500E+04, -.82257600E+04, -.10027600E+05, 0.89672400E+03, -.67536500E+04, -.60195000E+04, -.46164800E+04, -.63392100E+04, 0.74469000E+04, -.32342800E+04, -.95801800E+04, 0.10576600E+05, -.54432300E+04, -.65217000E+04, 0.45564400E+04, -.17143500E+03, 0.32123600E+04, -.56882900E+04, 0.58562400E+04, -.67061700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.38020100E+00, 0.59433200E+00, -.46021000E+00, 0.28640500E+00, 0.65412500E-01, 0.28440800E+00, 0.13527200E+00, 0.74616400E+00, 0.16692100E+01, 0.27481200E+00, -.49486400E-01, -.30707000E+00, -.11522300E+00, -.18927100E+00, 0.20527800E+00, 0.54169700E-02, -.84581000E+00, 0.15317400E+01, 0.21504800E+00, 0.23918400E+00, -.37537800E+00, 0.44116400E+00, -.18349600E+01, 0.47220500E+00, -.70477300E+05, -.16105400E+01, 0.12374200E+05, 0.37389700E+05, -.46068700E+05, -.56969000E+05, -.38482700E+05, 0.43143500E+05, 0.17215400E+05, 0.66396600E+04, -.30979200E+04, -.48154400E+05, -.33174800E+04, -.43980000E+04, -.81237800E+04, -.65394200E+04, -.10030900E+05, -.83968100E+04, -.34834000E+04, 0.35299400E+04, -.16197400E+05, 0.80391000E+04, 0.38114100E+05, 0.80961200E+04, 0.61791600E+04, 0.27246400E+04, 0.87802300E+04, 0.11798800E+05, 0.13316200E+05, -.14804400E+04, -.16526800E+04, -.40907700E+05, 0.20390700E+05, -.44914700E+05, 0.20451800E+05, 0.18508700E+05, 0.23468500E+05, -.26573700E+05, -.41984100E+05, -.18055300E+05, 0.28454000E+05, 0.30771100E+05, 0.13226000E+05, -.66428500E+04, -.10857300E+05, -.66132800E+04, 0.11055800E+04, 0.51719400E+04, -.66827000E+04, -.34490400E+04, -.53580500E+04, 0.47878400E+04, -.23214200E+04, 0.22724200E+05, -.11257700E+05, -.25905700E+05, -.11363100E+05, 0.22315000E+04, 0.12329700E+05, -.18552000E+05, -.12851700E+05, -.13998500E+05, 0.12412800E+05, -.95288800E+03, 0.10016900E+06, -.49846400E+05, -.12509800E+06, -.50090000E+05, -.16229200E+05, 0.21477100E+05, -.52128800E+05, -.49514800E+05, -.60038300E+05, 0.29412900E+05, -.25758200E+04, -.81087500E+05, 0.40320700E+05, 0.73103300E+05, 0.40545300E+05, 0.45443600E+04, -.27666800E+05, 0.43808600E+05, 0.32727400E+05, 0.42100000E+05, -.30057800E+05, 0.91445900E+04, -.26036500E+05, 0.13067700E+05, 0.47947800E+05, 0.13018500E+05, 0.83075500E+04, -.54362300E+04, 0.13064400E+05, 0.14907900E+05, 0.12725600E+05, -.89806500E+04, -.32558000E+04, 0.38835900E+04, -.22256500E+04, 0.38836200E+05, -.19381200E+04, 0.48202800E+03, -.15283700E+05, 0.22782300E+05, 0.33587900E+05, 0.25117500E+05, -.20707100E+05, -.14914600E+05, -.19417300E+05, 0.97311400E+04, 0.44976700E+05, 0.97057600E+04, 0.74931400E+04, 0.10176800E+05, 0.53291100E+04, 0.54162400E+04, 0.89763300E+04, 0.54238000E+04, 0.21002000E+03, -.26041900E+05, 0.13097400E+05, 0.44050900E+05, 0.13018300E+05, 0.90510000E+04, 0.82813500E+04, 0.72660600E+04, 0.72094300E+04, 0.12258500E+05, 0.33019000E+04, 0.58411400E+03, -.65716200E+05, 0.32869700E+05, 0.76096700E+05, 0.32858600E+05, 0.78143000E+04, -.22387000E+05, 0.39370700E+05, 0.36244200E+05, 0.36795400E+05, -.26726700E+05, 0.44666500E+04, -.70326800E+04, 0.34641500E+04, 0.13306200E+04, 0.35162500E+04, 0.53176300E+03, -.14084000E+03, 0.25177200E+04, 0.11889400E+04, 0.44916300E+04, 0.81816900E+02, 0.18795200E+04, -.64058000E+05, 0.31458100E+05, 0.12183300E+06, 0.32030700E+05, 0.58078600E+04, -.57242000E+05, 0.79686200E+05, 0.93107100E+05, 0.85828000E+05, -.69638600E+05, -.11722600E+05, 0.86141500E+04, -.43265400E+04, 0.31432900E+05, -.43072800E+04, -.71441900E+04, -.23602500E+05, 0.24767900E+05, 0.35125600E+05, 0.23122100E+05, -.26707100E+05, -.13861400E+05, -.19879400E+05, 0.10138600E+05, -.64601000E+05, 0.99351900E+04, 0.15285400E+05, 0.25291400E+05, -.33299200E+05, -.44441600E+05, -.28129500E+05, 0.30403600E+05, 0.21323700E+05, -.62562500E+05, 0.31021200E+05, 0.94647600E+05, 0.31284600E+05, 0.14208000E+05, -.18584700E+05, 0.36407700E+05, 0.40610800E+05, 0.38407200E+05, -.27207700E+05, -.14824600E+04, 0.46501000E+05, -.23365400E+05, -.35277500E+05, -.23251100E+05, -.22027600E+04, 0.11959900E+05, -.19627300E+05, -.12156500E+05, -.22854000E+05, 0.13459400E+05, -.91366900E+04, 0.10427400E+05, -.52086600E+04, 0.13671300E+04, -.52154300E+04, 0.82837500E+03, 0.19300800E+04, -.33270400E+04, -.49268100E+03, -.55931700E+04, 0.17194600E+04, -.47617500E+04, 0.16915100E+04, 0.18004800E+05, 0.18044600E+05, 0.41057000E+04, -.63312000E+03, -.12689200E+04, 0.55067500E+04, -.17629200E+05, -.14468700E+05, -.14989700E+05, -.11458000E+05, 0.28409300E+04, -.19333800E+05, -.76744500E+03, 0.12534700E+04, -.67074500E+04, -.21989000E+05, 0.14068400E+05, 0.48227400E+04, -.93850300E+03, -.13366000E+05, 0.14503000E+05, -.18113700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24848100E+01, -.13222000E+01, -.83341500E-01, 0.26299600E-01, 0.10450500E+01, 0.91469300E+00, -.42575900E+00, 0.38686500E+00, 0.19106700E+02, -.10881900E+00, -.97630400E-01, -.96203700E+00, 0.13780700E+00, 0.31140900E-01, -.14766400E+01, -.31296200E+00, -.31103300E+01, -.23561200E+01, -.17332600E+00, -.54648100E+00, 0.21075200E+01, 0.50695100E+00, -.17085800E+01, 0.38378700E+00, -.61274100E-01, -.89375700E+02, 0.71736100E+05, 0.28288200E+05, -.45264300E+05, -.57088000E+04, 0.31790700E+05, 0.13414900E+05, -.52823100E+05, 0.16616700E+06, -.84639900E+05, -.70193100E+05, -.83057900E+05, -.15747500E+04, -.19529600E+05, -.23528900E+05, 0.29641000E+05, -.15555800E+05, -.26508500E+05, -.99034600E+05, -.12160500E+06, 0.60550100E+05, 0.52065900E+05, 0.60787100E+05, 0.83899100E+04, 0.25814200E+05, 0.92159400E+04, -.22094100E+05, 0.87141500E+04, 0.29677600E+05, 0.81433100E+05, 0.55361000E+05, -.23938000E+05, 0.67799600E+04, -.27684200E+05, 0.73693000E+05, 0.51981200E+05, -.60068100E+05, 0.32109600E+04, 0.10653500E+05, 0.33163000E+05, -.68977400E+05, -.19144300E+05, 0.87940600E+04, -.48156900E+04, 0.95757400E+04, 0.45796700E+04, -.13423900E+04, 0.72283700E+03, -.49712700E+04, 0.73980300E+04, -.16691700E+04, 0.50167600E+04, -.13975000E+05, 0.78452900E+04, -.16147000E+05, 0.69861000E+04, 0.24997900E+05, 0.17576900E+04, -.13240500E+05, 0.52345300E+03, 0.20081600E+05, -.11443100E+04, -.11116700E+05, 0.10113800E+06, -.49357000E+05, -.33994700E+05, -.50541200E+05, 0.30670000E+05, -.58567000E+05, 0.74731700E+04, 0.31987800E+05, 0.35727600E+05, -.71644200E+05, -.13841600E+06, -.46285400E+04, 0.12091700E+04, 0.37673400E+05, 0.23209600E+04, -.27704000E+05, 0.26332300E+05, -.11852200E+04, -.11787200E+05, -.36619800E+05, 0.31982800E+05, 0.51274400E+05, 0.56715900E+05, -.27564500E+05, -.40122300E+05, -.28361100E+05, -.10138900E+05, 0.12429700E+05, -.12129500E+05, 0.15212100E+05, -.20134400E+05, 0.14975600E+05, 0.53427100E+04, -.10880300E+06, 0.56360900E+05, 0.44319500E+04, 0.54425700E+05, -.19792800E+05, 0.15904300E+05, 0.18294900E+05, -.32554700E+05, -.40129000E+04, 0.24333200E+05, 0.89318100E+05, -.17014400E+06, 0.83264500E+05, 0.74090100E+05, 0.85072300E+05, 0.11643800E+05, 0.29998100E+05, 0.17654700E+05, -.25412600E+05, 0.22243800E+05, 0.33877100E+05, 0.10346300E+06, -.15313600E+06, 0.74203600E+05, 0.68139900E+05, 0.76556800E+05, 0.12217100E+05, 0.31588100E+05, 0.13642000E+05, -.21476200E+05, 0.20079400E+05, 0.34722200E+05, 0.99544900E+05, 0.19110100E+05, -.95745500E+04, 0.52003000E+04, -.95644200E+04, -.33518000E+05, 0.81343200E+04, 0.10031500E+05, 0.90632000E+04, -.27315500E+05, 0.14738100E+05, 0.37327800E+05, -.32319600E+05, 0.15668400E+05, 0.18523400E+05, 0.16178800E+05, 0.28369100E+04, 0.10138500E+05, 0.33704800E+03, -.91700600E+04, 0.86997600E+02, 0.10459100E+05, 0.16670300E+05, -.25647700E+06, 0.13086600E+06, -.11935300E+05, 0.12830800E+06, -.48439500E+05, 0.27134500E+05, 0.43652700E+05, -.63247500E+05, -.93101800E+04, 0.49092500E+05, 0.22164300E+06, -.46643300E+05, 0.22818000E+05, -.13550500E+05, 0.23379600E+05, -.37505500E+05, -.20215200E+05, 0.28231000E+05, -.62581100E+04, -.56114100E+04, -.10292300E+05, 0.56203200E+05, 0.10130600E+06, -.53546600E+05, -.20742700E+05, -.50615200E+05, 0.66360600E+05, 0.29840800E+05, -.56138300E+05, 0.17505100E+05, 0.16193300E+05, 0.10727600E+05, -.97292900E+05, -.54046700E+05, 0.26052600E+05, -.61744200E+05, 0.26990100E+05, -.27112400E+05, 0.68530400E+04, 0.14871400E+04, -.62015600E+04, -.58515900E+04, 0.19436100E+05, 0.86227100E+05, -.25924400E+05, 0.12794600E+05, 0.40465800E+04, 0.12947200E+05, 0.94090800E+04, -.15302200E+05, 0.97021600E+04, -.31011400E+04, 0.20239600E+05, -.17233500E+05, -.15851800E+05, 0.15307500E+05, -.74378800E+04, -.11128000E+05, -.76907700E+04, -.14324800E+04, -.39395800E+04, -.88015700E+02, 0.57083300E+04, -.75947600E+03, -.37689300E+04, -.93870300E+04, 0.86415900E+04, -.25780700E+04, -.25014000E+04, -.29558500E+05, -.39817900E+05, -.34635600E+05, 0.46335300E+04, 0.25140300E+04, 0.17921500E+04, -.15171200E+05, -.71480100E+04, 0.10238600E+05, -.37188300E+05, -.40261900E+05, 0.34432900E+05, -.13906000E+05, -.88674300E+04, 0.16310900E+05, -.14822500E+04, 0.24286200E+05, -.83775300E+04, 0.12611100E+04, 0.23925300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.37372500E+00, 0.79275000E+00, 0.22379300E-01, 0.45004500E+00, -.38380800E+00, -.70901700E+00, 0.17944800E-01, 0.26634000E+00, 0.15032300E+01, -.12370100E+01, 0.27533900E-01, 0.21525200E+00, 0.10258000E+00, -.58929600E-01, 0.59000700E-01, 0.19472400E+00, -.13904600E+00, -.41242300E+00, -.16002900E+00, 0.68203400E-01, -.29783400E+00, -.20660900E+00, -.57190300E+00, -.41640000E+00, 0.51751100E+00, -.18246400E-01, -.45136200E+05, -.10244000E+06, 0.78686300E+05, 0.53701500E+05, 0.52377500E+05, -.10156300E+06, -.11968600E+05, 0.17494100E+03, -.20311000E+03, 0.80964700E+04, -.88819300E+02, -.18742200E+05, -.42111200E+05, 0.25697800E+05, 0.13554500E+05, 0.19841700E+05, -.40868900E+05, -.77525600E+04, 0.10944700E+05, -.53994800E+04, -.13636300E+05, -.54701700E+04, 0.81593000E+04, 0.28383700E+05, -.17535300E+05, -.10212200E+05, -.16990100E+05, 0.27753000E+05, 0.62716300E+04, 0.46121400E+05, -.23148700E+05, -.26984100E+05, -.23058000E+05, -.49927600E+05, -.89373700E+05, 0.64200400E+05, 0.46774700E+05, 0.32610800E+05, -.87557000E+05, -.28651200E+05, -.69901500E+04, 0.35190000E+04, 0.32868300E+04, 0.34955700E+04, -.10454800E+04, -.50369200E+04, 0.39073900E+04, 0.20821800E+04, 0.35827900E+04, -.46462300E+04, 0.24133500E+04, 0.23435800E+05, -.11725200E+05, -.10173200E+05, -.11716600E+05, -.13034700E+05, -.30541200E+05, 0.23884300E+05, 0.22413700E+05, 0.87606100E+04, -.31172300E+05, -.16407600E+05, -.10214800E+06, 0.51084900E+05, 0.50924600E+05, 0.51082500E+05, -.23621000E+05, -.89905200E+05, 0.65804800E+05, 0.29755200E+05, 0.71836600E+05, -.89440300E+05, 0.12478000E+05, 0.43676400E+05, -.21851000E+05, -.25171300E+05, -.21840100E+05, 0.90750500E+04, 0.51500600E+05, -.41724700E+05, -.29283000E+05, -.37870800E+05, 0.52137500E+05, 0.21545500E+04, 0.53071100E+05, -.26557900E+05, -.34220700E+05, -.26536000E+05, 0.11808000E+04, 0.17504200E+05, -.18191700E+05, -.31636000E+04, -.21934000E+05, 0.18215500E+05, -.11381600E+05, -.21337900E+05, 0.10555600E+05, 0.12249200E+05, 0.10665700E+05, 0.21971800E+05, 0.49903100E+05, -.34346300E+05, -.33589000E+05, -.24089000E+05, 0.51130800E+05, 0.21346100E+05, 0.10777800E+05, -.52908900E+04, -.14674800E+05, -.53861100E+04, 0.98590300E+04, 0.29728200E+05, -.17461000E+05, -.63779700E+04, -.16331400E+05, 0.28929700E+05, 0.66768800E+04, 0.15148300E+05, -.74995700E+04, -.18378000E+05, -.75721800E+04, 0.65557500E+04, 0.27553700E+05, -.16350900E+05, -.66629900E+04, -.15885800E+05, 0.26768000E+05, 0.70188500E+04, 0.51872900E+05, -.25926000E+05, -.28134500E+05, -.25937400E+05, 0.18747500E+05, 0.67367800E+05, -.54521800E+05, -.29759700E+05, -.43665000E+05, 0.66390100E+05, -.51202600E+04, -.78964300E+04, 0.39572400E+04, 0.46743500E+04, 0.39488600E+04, 0.13197700E+04, 0.32840300E+04, -.10800400E+04, -.32940900E+04, -.15911700E+04, 0.37412800E+04, 0.49136800E+04, 0.40607000E+05, -.20490200E+05, -.63196900E+04, -.20302800E+05, 0.52679800E+05, 0.14146200E+06, -.10664300E+06, -.78021000E+05, -.90550000E+05, 0.14184700E+06, 0.17530400E+05, 0.16572700E+05, -.82845400E+04, -.28698000E+04, -.82847800E+04, 0.27376200E+05, 0.62050700E+05, -.46475900E+05, -.27427600E+05, -.36684100E+05, 0.59670800E+05, 0.14852600E+04, 0.15928900E+05, -.79007200E+04, -.10127700E+05, -.79579600E+04, -.54914300E+05, -.10513900E+06, 0.74199100E+05, 0.46485500E+05, 0.48830800E+05, -.10266200E+06, -.15020600E+05, 0.11146100E+06, -.55752000E+05, -.48336400E+05, -.55735800E+05, 0.12698700E+05, 0.57893800E+05, -.49259700E+05, -.15767900E+05, -.56681900E+05, 0.57684500E+05, -.26734900E+05, -.43200300E+05, 0.21598700E+05, 0.22671700E+05, 0.21600600E+05, -.49835300E+04, -.21500600E+05, 0.18371600E+05, 0.35316300E+04, 0.21524100E+05, -.21144500E+05, 0.96387400E+04, -.21807700E+04, 0.10858100E+04, -.20149300E+04, 0.10922100E+04, -.87505600E+02, -.12269500E+04, 0.13753900E+04, 0.62694600E+03, 0.21529700E+04, -.13593100E+04, -.51429900E+03, -.21160000E+04, -.43358300E+05, -.43360500E+05, -.25605200E+04, 0.10763300E+05, 0.18554900E+05, -.67748200E+04, 0.43085400E+05, 0.30969300E+05, 0.30745600E+05, 0.32787400E+05, -.31496800E+05, 0.23404900E+05, 0.14615900E+05, -.18753500E+05, 0.22796100E+05, 0.40433000E+05, -.23017600E+05, 0.11701900E+04, 0.20973300E+04, 0.29383100E+05, -.39209900E+05, 0.43390500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18497400E+01, 0.29604000E+01, -.18127600E-01, 0.10113900E+00, -.21666100E+01, -.35957100E+00, 0.29749600E+00, -.21543400E+01, -.70193300E+02, 0.12880400E+01, 0.28511300E+00, -.14143100E+01, -.75963200E+00, 0.43124800E-01, 0.16087500E+01, -.33393200E+01, -.49280300E+00, 0.40529500E+00, -.31412300E+00, 0.36426100E+01, -.49357900E+01, -.36338200E+00, -.33008300E+01, -.29684200E+00, 0.88255900E+00, 0.27436100E+00, 0.51284900E+01, 0.34098800E+06, -.20956000E+06, -.21257000E+06, -.22054600E+06, 0.36233300E+06, 0.17466500E+06, -.37955400E+06, 0.19345000E+06, 0.13150300E+06, 0.18978400E+06, 0.79546000E+05, 0.23098400E+06, -.57473700E+05, -.14043700E+06, -.36852000E+05, 0.23103800E+06, 0.25407100E+06, 0.22505600E+06, -.11264200E+06, -.56608000E+05, -.11256800E+06, -.45503200E+05, -.17990200E+06, 0.54003300E+05, 0.10690600E+06, 0.41840000E+05, -.17921000E+06, -.20081400E+06, -.31144000E+06, 0.14985400E+06, 0.81510000E+05, 0.15563700E+06, 0.14533200E+05, 0.23245800E+06, -.11375100E+06, -.19459200E+06, -.95504800E+05, 0.26080000E+06, 0.28261800E+06, 0.53897600E+05, -.25804200E+05, 0.34138000E+04, -.26963800E+05, -.75084600E+04, 0.20606400E+05, -.15265200E+05, -.37543700E+04, -.24873600E+05, 0.19925000E+05, -.15611000E+05, -.10905400E+06, 0.53149700E+05, 0.93368800E+05, 0.54486100E+05, 0.19787100E+04, 0.12654200E+06, -.68079900E+05, -.10909100E+06, -.58911600E+05, 0.13472100E+06, 0.11214800E+06, 0.42827500E+05, -.23628500E+05, -.68502200E+05, -.21677200E+05, 0.45633700E+04, 0.46120000E+06, -.24861700E+06, -.24192400E+06, -.27851400E+06, 0.47944400E+06, 0.30088900E+06, -.76063800E+05, 0.39968900E+05, -.12559500E+05, 0.38087600E+05, 0.28852200E+05, -.26452200E+06, 0.16322400E+06, 0.18417000E+06, 0.19250800E+06, -.27668700E+06, -.15173100E+06, -.23491700E+06, 0.11632100E+06, 0.18158100E+06, 0.11747300E+06, 0.27254700E+05, -.72432000E+05, 0.77704600E+05, 0.73629300E+04, 0.93985600E+05, -.81396900E+05, 0.26155100E+04, 0.32353900E+06, -.16424900E+06, -.59555300E+05, -.16170300E+06, -.22484400E+05, -.21001300E+06, 0.82744500E+05, 0.19949600E+06, 0.60493200E+05, -.23106400E+06, -.29078300E+06, 0.31955300E+06, -.15750900E+06, -.10564100E+06, -.15982800E+06, -.67466200E+05, -.20598500E+06, 0.42793200E+05, 0.10349000E+06, 0.25069000E+05, -.20198000E+06, -.24340000E+06, 0.26669300E+06, -.12987400E+06, -.72756600E+05, -.13337100E+06, -.53218700E+05, -.19933600E+06, 0.47061400E+05, 0.98028600E+05, 0.27192700E+05, -.19474800E+06, -.23531000E+06, -.16387400E+06, 0.81963200E+05, 0.66861000E+05, 0.81964900E+05, 0.32961700E+04, -.29231500E+06, 0.19188700E+06, 0.14436500E+06, 0.19413200E+06, -.29837600E+06, -.88602700E+05, 0.10459400E+06, -.51532000E+05, -.59636500E+05, -.52317700E+05, -.96959600E+04, -.33394200E+05, 0.22652800E+04, 0.34941600E+05, 0.19290800E+04, -.35558500E+05, -.61377100E+05, 0.43442900E+06, -.22041700E+06, 0.28547000E+05, -.21727400E+06, -.49525500E+05, -.57466800E+06, 0.29942700E+06, 0.47449800E+06, 0.27930600E+06, -.61778600E+06, -.57822000E+06, -.89527500E+04, 0.53640000E+04, 0.59155700E+05, 0.44629100E+04, -.92875400E+04, -.19718000E+06, 0.12122600E+06, 0.11850600E+06, 0.13485900E+06, -.20403700E+06, -.11387900E+06, -.32193700E+06, 0.16554600E+06, 0.99321900E+05, 0.16079200E+06, 0.54209600E+05, 0.34803300E+06, -.15985800E+06, -.23368400E+06, -.16091900E+06, 0.36889800E+06, 0.30021500E+06, -.23303600E+06, 0.11835400E+06, 0.27461700E+06, 0.11668400E+06, 0.29473100E+05, -.22052300E+06, 0.17169700E+06, 0.11680000E+06, 0.18799600E+06, -.24438300E+06, -.10333000E+06, 0.15445000E+06, -.77060300E+05, -.69175900E+05, -.77237200E+05, -.96894300E+04, 0.10174100E+06, -.77598100E+05, -.29069800E+05, -.97990100E+05, 0.10358700E+06, 0.21227700E+05, -.21008600E+05, 0.10157400E+05, 0.32521100E+05, 0.10439600E+05, 0.24707600E+04, 0.13747200E+05, -.58937400E+04, -.15339500E+05, -.83601900E+04, 0.13577600E+05, 0.22702000E+05, -.13368600E+05, 0.16661700E+06, 0.16619400E+06, 0.77973200E+05, 0.67526400E+05, 0.19790100E+05, 0.14612400E+05, -.16531600E+06, -.10575000E+06, -.87973300E+05, -.10341000E+06, 0.10932300E+06, -.15167300E+05, 0.54733800E+05, -.23374400E+05, -.56323700E+05, -.13137200E+06, 0.57566600E+05, -.18708700E+05, -.76574200E+05, -.10288700E+06, 0.14712600E+06, -.16634500E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13524900E+01, -.57559600E+00, -.39645800E+00, -.23306300E+00, -.84887800E-01, -.30463900E+00, -.44297300E-01, 0.31856900E+00, 0.61693000E+01, -.87607900E+00, -.88643900E-01, 0.89307200E+00, 0.71685500E+00, -.20931200E+00, -.32596100E+00, 0.12832900E+01, 0.34996500E+01, -.55290900E+00, -.29113600E+00, -.46424500E+00, 0.49620500E+00, -.71494400E+00, -.47698000E+00, -.59970500E+00, 0.93556300E+00, -.35572600E-01, 0.17046900E+01, -.60653800E-01, 0.61626400E+05, 0.66726400E+05, 0.32994700E+05, -.32362400E+04, -.14635900E+05, -.56703300E+05, 0.28615300E+05, 0.13752600E+05, 0.28351300E+05, 0.24529700E+05, 0.49966100E+05, 0.56369300E+04, 0.44091700E+04, 0.74278500E+04, 0.44763400E+05, 0.23485000E+05, 0.66071700E+05, -.33135400E+05, -.18841900E+05, -.33037600E+05, -.18525900E+05, -.31814000E+05, -.88175300E+04, -.60685800E+04, -.18026400E+05, -.26913800E+05, -.26157800E+05, -.19434800E+05, 0.96273100E+04, -.81219600E+04, 0.97124000E+04, -.15339800E+05, -.12560400E+05, 0.62772900E+05, 0.50676400E+05, 0.36775000E+05, -.11932700E+05, 0.37022800E+04, -.16116500E+05, 0.80651500E+04, 0.10793700E+05, 0.80573500E+04, 0.23933200E+04, 0.84057100E+03, 0.74085500E+04, 0.47445900E+04, 0.56085900E+04, -.18264200E+03, -.20024700E+04, -.74885800E+05, 0.37398200E+05, 0.33863000E+05, 0.37440400E+05, 0.46648500E+04, 0.29160900E+04, 0.29576000E+05, 0.38113800E+04, 0.24838300E+05, 0.35273400E+04, 0.25182200E+05, -.19456400E+06, 0.97204200E+05, 0.72711800E+05, 0.97266100E+05, 0.68605400E+05, 0.67797400E+05, 0.44956100E+05, 0.42161300E+05, 0.60665000E+05, 0.59402800E+05, 0.38970600E+05, 0.14988100E+06, -.74862600E+05, -.66550200E+05, -.74937100E+05, -.28514000E+05, -.20348600E+05, -.45286200E+05, -.19814200E+05, -.48260200E+05, -.16204100E+05, -.37198900E+05, 0.18663500E+04, -.96792900E+03, 0.63618600E+04, -.93230200E+03, -.14234900E+05, -.19671400E+04, -.10390100E+05, -.28340900E+05, -.66058400E+04, 0.66681300E+03, 0.15975300E+05, 0.92681500E+05, -.46278700E+05, -.34256000E+05, -.46337500E+05, -.97521400E+04, 0.61720900E+03, -.42881100E+05, -.20838300E+05, -.49351500E+05, 0.86237900E+03, -.33552000E+05, 0.65311300E+05, -.32726100E+05, -.18216400E+05, -.32657900E+05, -.23744500E+05, -.46133600E+05, -.24174500E+04, -.22496200E+03, -.88097600E+04, -.40332800E+05, -.28113700E+05, 0.77865300E+05, -.38948200E+05, -.20978800E+05, -.38933300E+05, -.22893200E+05, -.41440500E+05, -.56146700E+04, -.12692000E+04, -.16256600E+05, -.35092600E+05, -.31523700E+05, 0.68962900E+05, -.34514700E+05, -.29085400E+05, -.34479800E+05, -.26747700E+05, -.22919100E+05, -.37164500E+05, -.42062800E+05, -.27972300E+05, -.16248300E+05, -.23006300E+04, 0.39615900E+05, -.19785800E+05, -.17221100E+05, -.19809200E+05, -.54729500E+04, -.80921000E+04, -.43080600E+04, 0.54726400E+04, -.88400700E+04, -.88936200E+04, -.17774400E+05, 0.18158200E+06, -.90667200E+05, -.70913200E+05, -.90795500E+05, -.34596200E+05, -.42040500E+04, -.97521600E+05, -.82332100E+05, -.99917800E+05, 0.16569100E+04, -.46562700E+05, -.43740800E+05, 0.21885700E+05, 0.23323200E+05, 0.21869700E+05, 0.26900200E+04, 0.43095300E+04, -.28975900E+05, -.49054700E+05, -.10260900E+05, 0.72164400E+04, 0.25640400E+05, -.71128600E+04, 0.36312900E+04, -.86099700E+04, 0.35463200E+04, 0.73428400E+04, 0.24086300E+05, 0.47076100E+05, 0.50434700E+05, 0.22309400E+05, 0.21203000E+05, -.63452200E+04, 0.53361600E+05, -.26625500E+05, -.16954900E+05, -.26670800E+05, -.34249400E+05, -.13855700E+05, -.27328200E+05, -.53349500E+05, -.27537200E+05, -.81741500E+04, 0.11905300E+05, -.25651300E+05, 0.12850200E+05, 0.38707400E+04, 0.12825000E+05, 0.16800800E+05, 0.12630000E+05, 0.10755100E+05, 0.20071200E+05, 0.10603700E+05, 0.92661500E+04, -.43452600E+04, -.11069100E+05, 0.55294000E+04, 0.61686100E+04, 0.55304300E+04, 0.65385000E+03, 0.12658400E+04, 0.25265200E+04, -.22772900E+03, 0.34916300E+04, 0.15648200E+04, 0.67958700E+04, -.40915900E+04, 0.81522800E+04, 0.81132500E+04, 0.28564700E+04, 0.91177900E+03, -.10116400E+05, -.26782100E+04, -.84089000E+04, 0.41444000E+04, 0.37657800E+04, -.25051800E+04, 0.22241600E+05, 0.65583000E+04, -.17495500E+04, 0.79520800E+04, -.43615100E+04, 0.65393200E+04, 0.93650100E+04, -.15443800E+05, -.64739200E+04, -.15174400E+05, 0.62908600E+04, -.81216000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18271200E+01, -.14194700E+01, -.87778600E+00, -.44327700E+00, 0.81459200E-01, 0.46698700E+00, -.31296800E+00, -.32513600E+01, -.17757800E+02, 0.79205900E+00, 0.22558400E-01, -.94103500E+00, -.36397200E+00, 0.11620600E+00, -.14527700E+01, 0.51753400E+00, 0.26492800E+00, -.41872500E+01, -.83303200E+00, -.10755100E+01, -.20723000E+00, -.47735600E+00, -.47620600E+01, -.12900300E+01, 0.21732400E+01, -.92313900E-01, 0.20062400E+01, -.32980000E-01, -.10368900E+00, 0.52830400E+05, 0.64656900E+05, -.73036000E+04, 0.17326800E+05, 0.69309500E+05, -.32766800E+05, -.24300700E+04, -.34657500E+05, -.86636000E+04, -.91882200E+04, -.18713900E+04, 0.38963300E+05, 0.10548000E+03, -.11006600E+05, -.29841200E+05, -.87313900E+05, 0.43182800E+05, 0.10345000E+05, 0.43661900E+05, 0.17211700E+05, 0.16368700E+05, -.24370500E+04, -.39909900E+05, 0.76457300E+04, 0.17224200E+05, 0.37540200E+05, -.28660200E+05, 0.11011700E+05, 0.19440300E+03, 0.14336900E+05, -.68074400E+04, -.72351800E+04, 0.15584100E+04, 0.43010900E+05, 0.58044200E+05, -.79285600E+04, 0.30506100E+05, -.94269300E+04, 0.54750700E+04, 0.10848600E+04, 0.47146800E+04, 0.40999500E+04, 0.10072700E+04, 0.11670100E+04, -.27785100E+03, 0.37995900E+04, -.24867200E+03, 0.11519800E+04, -.46597300E+05, 0.22334500E+05, 0.11144700E+05, 0.23302000E+05, 0.17567000E+05, 0.80291800E+04, -.64386900E+03, 0.56966300E+04, 0.27868700E+05, 0.75560900E+04, 0.20900000E+05, 0.93599300E+03, -.25923500E+04, 0.41822400E+05, -.44656400E+03, -.25403400E+05, -.20795200E+05, 0.32213000E+05, 0.61706500E+05, 0.40396000E+05, -.24637600E+05, -.38289400E+04, 0.37698500E+05, -.17221000E+05, -.61487500E+04, -.18854000E+05, -.65096000E+04, 0.59061900E+04, -.16430200E+05, -.24942100E+05, -.38842300E+05, 0.92838900E+04, -.14861000E+05, 0.48645000E+05, -.24885400E+05, -.32065700E+05, -.24323700E+05, 0.91836500E+04, 0.80219300E+04, -.16866500E+05, -.55628000E+04, -.19365200E+05, 0.10646200E+05, -.17154500E+05, -.97948400E+05, 0.48047000E+05, 0.34589200E+05, 0.48966700E+05, 0.26162200E+05, 0.27702700E+05, -.61709400E+04, -.55019800E+05, -.27546700E+05, 0.27520100E+05, 0.31326600E+05, -.93081000E+05, 0.46607700E+05, 0.71715800E+04, 0.46546900E+05, 0.10837400E+05, 0.12341200E+05, 0.21268600E+04, -.39109800E+05, 0.15099900E+05, 0.13163000E+05, 0.41465100E+05, -.10593700E+06, 0.53495200E+05, 0.70259000E+04, 0.52972700E+05, 0.14147000E+05, 0.15397000E+05, 0.11543900E+04, -.40266600E+05, 0.21644200E+05, 0.15670400E+05, 0.48164400E+05, 0.45983900E+05, -.22782900E+05, -.41182300E+05, -.22994200E+05, -.63867600E+04, -.14481600E+05, -.19281100E+04, -.15356900E+05, -.22896200E+05, -.80148000E+04, -.13764100E+05, -.45724800E+04, 0.28301200E+04, 0.21002200E+04, 0.22878400E+04, 0.69231300E+03, 0.37153700E+04, -.27994300E+04, -.81358200E+04, -.23655400E+04, 0.25700900E+04, -.76453400E+03, -.91402800E+05, 0.45244000E+05, 0.26950000E+05, 0.45703900E+05, 0.67994100E+05, 0.59315900E+05, -.37084500E+05, -.11946000E+06, -.80541800E+05, 0.63173800E+05, 0.16146500E+05, -.31721600E+05, 0.16636000E+05, 0.10271700E+05, 0.15865800E+05, 0.20238100E+05, 0.74001400E+04, -.25020800E+03, -.34894800E+05, -.25758300E+05, 0.10050200E+05, 0.97175600E+02, -.68336300E+04, 0.55364600E+04, 0.25824900E+03, 0.34324900E+04, -.81961600E+04, -.14856500E+05, 0.74886700E+04, 0.59165900E+05, 0.70702000E+05, -.19001200E+05, 0.19049800E+05, 0.57061600E+05, -.26533600E+05, -.44613700E+05, -.28544400E+05, 0.31798900E+05, 0.15399600E+05, -.32218500E+05, -.28821600E+05, -.32563700E+05, 0.20716800E+05, -.22603700E+05, -.30320500E+05, 0.15229200E+05, 0.11951300E+05, 0.15161300E+05, -.69275900E+04, -.99125900E+04, 0.16059600E+05, 0.15809800E+05, 0.18902000E+05, -.11996400E+05, 0.15125800E+05, 0.23887400E+04, -.14378500E+04, -.62049500E+04, -.11897100E+04, -.18596300E+04, -.29136000E+04, 0.23630300E+04, 0.46125200E+04, 0.12722800E+04, -.25942500E+04, 0.43892800E+04, -.27676400E+04, -.11994100E+05, -.12308800E+05, -.16450700E+04, 0.97081100E+04, 0.14264800E+05, 0.26551800E+03, 0.12210200E+05, 0.19700800E+05, 0.98329700E+04, 0.93024900E+04, 0.14255700E+04, 0.29612600E+04, 0.11537700E+05, -.16123500E+05, 0.10994500E+05, 0.19448100E+05, -.50641300E+04, -.95427600E+04, -.59249400E+04, 0.82769400E+04, -.98203500E+04, 0.12016900E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10466400E+01, -.11947400E+00, -.94245400E-01, -.24901000E-01, 0.12944700E-02, 0.18340600E-01, 0.20324700E-01, -.62126300E-01, -.54256500E+00, -.28692000E+00, 0.14401400E-01, 0.71391500E+00, 0.42940900E-01, -.21887800E+00, 0.27473700E+00, 0.12644000E+01, 0.33319400E+01, -.50833300E+00, 0.58948200E-01, -.35538800E-01, -.15732700E+00, -.71232100E+00, -.91919800E+00, -.54121100E+00, -.39201100E+00, -.12426900E-01, -.43150400E+00, -.10982700E+00, 0.36388300E+00, 0.35485700E+00, -.38712200E+05, 0.27841000E+04, -.32784600E+04, -.31375000E+05, 0.15327700E+05, -.34290800E+04, 0.15688900E+05, 0.18178600E+04, 0.97103900E+03, 0.50248100E+04, -.33677700E+04, -.21430600E+04, 0.33197600E+04, 0.16605600E+05, 0.42399500E+05, -.20874900E+05, -.17432900E+04, -.21203000E+05, -.72101000E+04, -.43957200E+04, -.46686900E+04, 0.45219200E+04, -.30732000E+04, -.57963000E+04, -.21915500E+05, -.50101900E+04, 0.28120700E+04, 0.48654600E+04, 0.24997900E+04, 0.14144200E+04, -.20976600E+04, 0.23797500E+03, -.75504400E+04, -.32360800E+05, 0.12833800E+04, -.24352900E+04, 0.24888800E+05, -.12565700E+05, -.44694600E+04, -.12445300E+05, -.20684300E+04, 0.60189100E+03, -.29319500E+04, 0.66054100E+04, -.79584000E+04, 0.64052600E+03, -.83595000E+04, 0.36252500E+05, -.17862000E+05, -.82826500E+03, -.18128900E+05, -.11052800E+05, -.64916100E+04, -.15773600E+04, 0.56745400E+04, -.19645300E+05, -.72352500E+04, -.14768300E+05, 0.68541800E+05, -.33456000E+05, -.48482900E+05, -.34287700E+05, 0.33132100E+04, 0.88836800E+04, -.13387000E+05, 0.21094200E+05, -.43352900E+05, 0.86172200E+04, -.15933900E+05, -.56490000E+05, 0.27653800E+05, 0.38562900E+04, 0.28248600E+05, 0.84839200E+04, 0.39723000E+04, 0.49622700E+04, -.17706200E+05, 0.30182600E+05, 0.41515200E+04, 0.19257500E+05, -.23701300E+05, 0.11893200E+05, 0.36225800E+05, 0.11851600E+05, -.26807400E+04, -.19001500E+04, 0.64049000E+03, -.16065900E+05, 0.49611300E+04, -.24632900E+04, 0.35982100E+04, 0.56955900E+05, -.28924400E+05, -.39097000E+04, -.28472800E+05, -.12266800E+05, -.14333300E+05, 0.94566200E+03, 0.16206300E+05, 0.16746200E+05, -.14879400E+05, -.24416600E+05, 0.45374200E+05, -.22064800E+05, -.11719300E+04, -.22691300E+05, -.35165400E+04, -.22597500E+04, -.67318600E+04, 0.35081500E+04, -.80888200E+04, -.38868100E+04, -.23539200E+05, 0.49160700E+05, -.23983200E+05, -.15761000E+04, -.24582900E+05, -.51413500E+04, -.25923200E+04, -.74963200E+04, 0.21215300E+04, -.11143600E+05, -.38586700E+04, -.26249500E+05, -.45904900E+05, 0.22880400E+05, 0.23522900E+05, 0.22954200E+05, 0.32678800E+04, 0.87447400E+04, -.26903200E+04, -.24397900E+05, 0.18643400E+05, 0.79742700E+04, 0.14335100E+05, -.42438900E+04, 0.19792700E+04, -.10960800E+04, 0.21206700E+04, 0.10745700E+04, -.12953700E+04, 0.25166100E+04, 0.29446600E+04, 0.45157100E+04, -.67622400E+03, 0.27750100E+04, 0.88198200E+05, -.45228500E+05, 0.83335300E+04, -.44101900E+05, -.36842000E+05, -.31071500E+05, 0.24254200E+04, 0.13829200E+05, 0.36635900E+05, -.32322200E+05, -.39484600E+05, 0.35488700E+05, -.17961200E+05, -.53459600E+04, -.17745000E+05, -.12929700E+05, -.71546000E+04, -.14729400E+04, 0.55637400E+04, 0.12214900E+05, -.84043000E+04, -.11441100E+05, 0.40264900E+04, -.19392200E+04, -.72017600E+04, -.20250900E+04, 0.12324500E+04, 0.69296400E+04, -.48475500E+04, -.70618500E+04, -.44388000E+05, 0.10053600E+05, -.21733500E+04, -.17345400E+05, 0.78484400E+04, 0.47725500E+05, 0.86833500E+04, -.13448400E+05, -.40144600E+04, -.23551800E+03, -.24055700E+05, 0.77326600E+04, -.62185700E+04, -.21426600E+04, 0.57602000E+05, -.28865500E+05, -.19670500E+05, -.28801800E+05, 0.32602900E+03, 0.69525000E+04, -.11172200E+05, 0.11419400E+05, -.22548500E+05, 0.69680300E+04, -.20608500E+05, 0.19300500E+04, -.91690600E+03, 0.66561600E+04, -.96891400E+03, 0.23547300E+03, 0.13580300E+04, -.17788500E+04, -.22569800E+04, -.17401600E+04, 0.11470900E+04, -.30087700E+04, -.73288000E+01, 0.32141400E+04, 0.32182700E+04, 0.18385500E+04, -.55312700E+04, -.62102500E+04, 0.15545800E+03, -.31052400E+04, -.13085800E+05, -.24646800E+03, -.46983700E+04, -.42109300E+04, 0.29954300E+04, -.57170300E+04, 0.73158100E+04, -.17810300E+04, -.78140100E+04, 0.16828100E+04, 0.76261200E+04, 0.50170500E+04, -.27155400E+04, 0.33867600E+03, -.33365600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.58593700E+00, -.29844900E+01, 0.42386000E+00, -.20674200E+01, -.64341900E+00, -.10674300E+00, -.87142000E+00, 0.45089300E+00, 0.81462400E+01, -.19922000E+01, 0.61572100E-01, 0.13551600E+01, 0.10023800E+00, 0.27678000E-01, -.72274300E+00, 0.72426300E+00, 0.29216300E+01, -.10192900E+01, -.63121500E+00, -.68287800E+00, -.43710100E+00, -.45084200E+00, 0.35768200E+01, 0.22433700E+00, 0.97817900E+00, -.60151300E-02, 0.14310300E+01, 0.10180000E+00, -.40746500E+00, 0.37364000E+00, 0.20980400E-01, 0.76666600E+04, -.28241400E+04, -.12592400E+05, 0.56284400E+04, -.12975200E+05, 0.62959700E+04, 0.11380800E+05, 0.26539900E+05, -.13177100E+05, -.22531800E+05, -.58582500E+04, 0.27613400E+05, 0.12320000E+05, 0.28775700E+05, -.14407300E+05, 0.90972800E+04, -.14388300E+05, -.95540700E+04, -.16257600E+05, 0.37033500E+04, 0.15319900E+05, -.87436000E+04, -.16088900E+05, -.18201000E+05, -.20506500E+05, 0.12080100E+05, -.94912600E+04, 0.10251800E+05, -.14854800E+05, -.13270300E+05, 0.35619300E+04, -.18444400E+05, 0.12806400E+05, -.51208500E+04, 0.96431700E+04, 0.59176100E+04, -.33671100E+04, 0.84798300E+04, -.29590800E+04, -.18040400E+04, -.17073900E+04, 0.30792700E+04, 0.78933200E+04, -.16495900E+04, -.78836700E+03, -.75249900E+04, -.29580300E+05, 0.15231300E+05, 0.34873700E+05, 0.14789400E+05, 0.17428200E+04, 0.77146600E+04, 0.10050500E+04, -.85330500E+04, 0.15606200E+04, 0.88365100E+04, 0.11001600E+05, -.37810500E+05, 0.19731000E+05, -.38017400E+05, 0.18900500E+05, 0.23492600E+05, 0.88341800E+04, 0.73784800E+04, -.13742000E+04, 0.18331700E+05, 0.15948400E+05, 0.87804900E+04, 0.26200400E+05, -.13752700E+05, -.40894600E+05, -.13099200E+05, -.65808700E+04, -.72618300E+04, -.89063100E+04, -.67245700E+04, -.20584500E+04, -.91984100E+04, -.25298200E+04, -.65009900E+05, 0.32825600E+05, 0.19793800E+05, 0.32505200E+05, -.16486800E+05, -.14361600E+05, 0.14132000E+05, -.17582100E+05, 0.22484100E+05, -.14416500E+05, 0.35401700E+05, 0.10094100E+06, -.49603500E+05, -.64094400E+04, -.50469600E+05, -.65563400E+04, 0.48953900E+04, -.14731800E+05, 0.12533000E+05, -.32618500E+05, 0.10104300E+04, -.48634300E+05, 0.14735800E+05, -.78944600E+04, 0.13212200E+05, -.73684600E+04, -.10456900E+05, -.24296900E+05, 0.10371100E+05, 0.21644600E+05, 0.23812500E+04, -.23623300E+05, -.15860600E+05, 0.32315600E+05, -.16893000E+05, 0.11446600E+05, -.16157800E+05, -.10810300E+05, -.22147400E+05, 0.62184900E+04, 0.20655900E+05, -.67186900E+04, -.20890300E+05, -.22697400E+05, 0.32282500E+04, -.17298400E+04, 0.49438900E+04, -.16136200E+04, -.14927600E+05, -.76383700E+04, -.13426100E+03, -.38476400E+04, -.13655000E+04, -.11396600E+05, 0.78051700E+04, 0.10122700E+05, -.53146200E+04, -.37279500E+04, -.50617100E+04, -.32272300E+03, -.32952100E+04, -.11766200E+04, 0.56050100E+04, -.52739300E+04, -.30879800E+04, -.63472400E+04, 0.15353300E+06, -.75772200E+05, 0.36803400E+05, -.76768000E+05, -.21515200E+05, 0.21448700E+05, -.28520300E+05, 0.21368900E+05, -.63683200E+05, 0.10428900E+05, -.64519000E+05, 0.99738800E+04, -.53244000E+04, 0.28767000E+05, -.49904900E+04, -.27381200E+03, 0.13194800E+05, -.75476200E+04, -.65797800E+02, -.11629400E+05, 0.84931100E+04, -.15216600E+04, 0.51231200E+04, -.38459300E+04, -.20941100E+05, -.25645200E+04, 0.88131300E+02, 0.11764400E+05, -.11511100E+05, -.17376300E+05, -.73631000E+04, 0.20199800E+05, -.11303000E+03, 0.63789200E+04, -.39355200E+04, 0.67599100E+05, -.31864800E+04, -.14573800E+05, 0.19772300E+05, -.85301900E+04, -.81565600E+04, -.11161400E+05, 0.11554200E+05, 0.82940100E+04, 0.34095200E+05, -.17065900E+05, -.11576600E+05, -.17047800E+05, 0.81407400E+04, 0.66902700E+04, -.33701300E+04, 0.11226300E+05, -.86668200E+04, 0.76408500E+04, -.22086800E+05, -.10904400E+05, 0.55726500E+04, 0.59341400E+04, 0.54509400E+04, -.10551200E+04, -.12010000E+04, 0.31943100E+04, -.22010500E+04, 0.45714300E+04, -.72455900E+03, 0.44039600E+04, -.18773700E+04, 0.41688600E+04, 0.47532900E+04, 0.66845800E+03, -.69089900E+03, -.94148100E+04, -.13803400E+03, -.48633500E+04, -.24727800E+03, 0.31820200E+03, -.22869400E+04, -.99445600E+03, -.48694600E+04, -.42024700E+04, 0.89905500E+04, -.76463800E+03, -.33289300E+04, 0.89265900E+04, -.17792000E+04, -.24427700E+04, -.64438700E+04, 0.25757000E+04, -.41405800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21233000E+01, -.24335400E+01, -.98276300E+00, -.98693800E+00, -.77181000E+00, 0.16419900E+01, -.71241500E+00, -.34501300E+01, -.13988400E+00, 0.79956200E+00, 0.86699400E+00, 0.10113500E+01, 0.26134300E-01, -.30632000E+00, 0.29262800E+00, 0.29376700E+01, 0.26536500E+01, -.36178600E+00, 0.11905900E+00, -.60317800E+00, 0.12845900E+01, -.25568700E+01, -.21108400E+01, -.17075400E+01, -.86178700E+00, -.48893800E-01, -.20053200E+01, -.75192000E-01, -.21755800E+00, -.73805200E+00, -.45725700E+00, -.74553500E+00, -.85961700E+05, 0.40794800E+05, -.19846000E+05, -.22484700E+04, -.20402200E+05, 0.98679700E+04, 0.18776100E+05, -.15897000E+05, -.21547100E+04, -.17486800E+05, 0.19006500E+05, -.62604300E+05, -.30990200E+05, 0.15675800E+05, -.56576800E+04, 0.15503200E+05, -.62192200E+04, -.40075900E+04, 0.51568900E+04, -.33309300E+04, 0.10817000E+05, -.45471600E+04, 0.63771700E+05, -.65722500E+05, 0.30248500E+05, -.10466300E+04, 0.32871800E+05, -.24845600E+05, -.43368300E+05, 0.27164800E+05, -.87873600E+04, 0.27129900E+05, -.33232000E+05, -.33089700E+05, 0.91994900E+04, -.38878700E+04, 0.52640000E+04, -.45978400E+04, 0.12020100E+04, -.77061100E+03, 0.10377600E+04, 0.71985500E+04, -.23850400E+04, -.11292700E+04, -.22741800E+05, -.25976500E+05, 0.11979100E+05, 0.25171600E+05, 0.12993500E+05, 0.81055900E+04, -.51462600E+03, 0.37277300E+04, -.44713200E+04, 0.57584800E+04, -.10856000E+04, -.15948400E+05, 0.36716600E+05, -.20015800E+05, -.20517000E+05, -.18324700E+05, 0.66406500E+04, -.38248000E+04, -.32160400E+04, 0.50446500E+04, -.16463300E+05, -.25203100E+04, -.18122900E+06, 0.19779200E+05, -.82637600E+04, -.34208400E+05, -.98969800E+04, -.13002600E+05, 0.52229200E+04, -.10590500E+05, -.10811300E+05, -.54357700E+04, 0.79250500E+04, 0.84693400E+05, -.39650700E+05, 0.19036200E+05, 0.24628000E+04, 0.19823500E+05, -.54965600E+04, -.11150500E+05, 0.75479800E+04, -.15385000E+05, 0.13042700E+05, -.87285700E+04, 0.76133600E+05, 0.49663900E+05, -.25369900E+05, 0.61478700E+04, -.24844200E+05, 0.31422500E+04, 0.13373300E+05, -.93061900E+04, 0.11936500E+05, -.12069500E+05, 0.10667500E+05, 0.32227800E+05, -.27407600E+05, 0.14589300E+05, -.86547000E+04, 0.13714200E+05, -.11158800E+05, -.12849200E+05, 0.11969200E+05, 0.56310000E+04, 0.10639400E+05, -.12115300E+05, 0.63882100E+05, -.33440500E+05, 0.17793700E+05, -.11676300E+05, 0.16727500E+05, -.97395200E+04, -.52348700E+04, 0.83977900E+04, 0.72339700E+03, 0.11365500E+05, -.51947300E+04, 0.72598500E+05, -.45753200E+05, 0.22756700E+05, 0.18698700E+04, 0.22873000E+05, -.69179600E+04, -.34552900E+04, 0.57376200E+04, -.13700700E+05, 0.14624600E+05, -.11595200E+04, 0.10970200E+06, -.12728900E+04, 0.11778200E+04, 0.73917200E+03, 0.63893600E+03, -.34262100E+04, -.12786300E+03, -.42165100E+02, 0.27781300E+04, 0.32797700E+03, -.47429800E+03, 0.52022600E+04, 0.11588100E+06, -.57885100E+05, 0.50375100E+05, -.57937300E+05, 0.21244700E+05, 0.48993300E+05, -.42366800E+05, 0.12091600E+04, -.45831000E+05, 0.41486000E+05, 0.10800000E+06, 0.24632000E+05, -.11839600E+05, 0.20586600E+05, -.12307500E+05, 0.13604300E+05, 0.16152300E+05, -.12726200E+05, -.97364100E+03, -.14015400E+05, 0.13596400E+05, 0.36848700E+05, -.98464600E+04, 0.64118300E+04, -.17977900E+05, 0.49480700E+04, -.65166800E+04, -.45372200E+04, -.73550300E+03, -.92841200E+04, 0.79857200E+03, 0.58588100E+03, -.73194600E+05, 0.41297700E+05, -.18978900E+05, 0.43462900E+05, -.20670100E+05, 0.19346600E+05, 0.26317300E+05, -.22253900E+05, -.14260800E+05, -.20373200E+05, 0.22380100E+05, 0.87351000E+05, 0.33288200E+05, -.16045800E+05, -.99404300E+04, -.16642500E+05, 0.23058600E+04, 0.43016700E+04, -.19449400E+04, 0.13254800E+05, -.91168200E+04, 0.26859400E+04, -.69865200E+05, -.70616000E+04, 0.33536300E+04, -.13025700E+04, 0.35379600E+04, -.19185100E+02, -.18065100E+04, 0.31620900E+04, -.11769300E+03, 0.42964200E+04, -.18711400E+04, 0.12450300E+04, -.52766800E+04, -.42498600E+04, -.39392200E+04, -.34951200E+04, -.38884300E+04, -.17350400E+04, 0.71250400E+02, 0.37401800E+04, 0.10865700E+04, 0.40560600E+04, -.92386800E+03, -.51856400E+04, 0.22382900E+04, -.38320500E+04, 0.14405600E+04, 0.58589300E+03, 0.27400000E+04, 0.42873000E+03, -.21456200E+04, 0.74961100E+02, 0.35556600E+04, -.58125800E+04, 0.43522800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.84193000E+00, -.15734300E+01, 0.21405600E+00, -.65759600E+00, 0.50730200E+00, 0.10469800E+01, -.51869800E+00, 0.15053100E+01, 0.27433900E+02, -.67370200E+00, -.70284200E-01, 0.85830500E+00, 0.41741600E+00, -.89455900E-01, 0.13255900E+01, 0.10064200E+01, 0.46847500E+01, 0.50115600E+01, 0.44986900E+00, -.26572100E+01, -.21660700E+00, -.17394700E-01, 0.84273800E+00, -.26949800E+00, 0.49344100E+00, -.10832200E-02, 0.54053100E-01, -.89432600E-01, -.33144400E+00, -.24913100E+00, -.50550800E+00, 0.51107100E+00, -.25587500E-01, -.78749300E+05, 0.40188000E+05, 0.33698000E+05, 0.39376200E+05, -.27471300E+04, -.27406600E+05, 0.22641400E+05, -.78477600E+04, 0.29648300E+05, -.21723000E+05, 0.29019900E+05, 0.43214500E+05, -.21154800E+05, -.29071500E+05, -.21611600E+05, 0.47276700E+04, 0.22260400E+05, -.17098600E+05, 0.81541700E+03, -.17598700E+05, 0.17978600E+05, -.13732400E+05, 0.19364600E+05, -.12773300E+05, 0.72026600E+04, -.96899400E+04, 0.12394800E+05, 0.81762600E+04, -.24216100E+04, 0.79086300E+04, -.53873600E+04, 0.78213400E+04, -.11276100E+05, 0.81238100E+04, -.34261400E+04, -.40867800E+04, -.40632800E+04, 0.15471800E+04, 0.11046000E+04, -.10719900E+04, 0.31768500E+04, -.18097500E+04, 0.42517700E+03, -.55658500E+04, 0.23518300E+04, -.17321600E+04, -.65822900E+04, -.11797000E+04, -.70352900E+03, 0.98740000E+03, -.16080700E+04, -.26801000E+04, -.26906300E+04, 0.57184200E+03, -.92061200E+01, 0.65826200E+05, -.33624100E+05, 0.31830100E+04, -.32937400E+05, -.10528900E+04, 0.98136100E+04, -.12435800E+05, 0.57519000E+04, -.25313400E+05, 0.91519400E+04, -.35942700E+05, -.11151800E+05, 0.61782500E+04, 0.97632500E+04, 0.55811000E+04, 0.18198800E+04, -.37392600E+04, 0.34021000E+04, 0.14173000E+04, 0.59423300E+04, -.27397200E+04, 0.46880600E+04, -.53537200E+04, 0.21137900E+04, 0.86637900E+04, 0.26781900E+04, 0.25042800E+04, -.22514400E+04, -.14334700E+04, -.68647700E+04, -.10065100E+03, -.13051000E+04, 0.46809300E+04, -.33072700E+05, 0.14405400E+05, -.16180700E+03, 0.16543300E+05, 0.24120700E+04, -.86874400E+04, 0.87901100E+04, 0.55584500E+03, 0.15497200E+05, -.82882500E+04, 0.15860900E+05, 0.96073100E+05, -.46117200E+05, -.40200600E+05, -.48042200E+05, 0.53696700E+04, 0.33470700E+05, -.26660700E+05, 0.12123000E+05, -.36010700E+05, 0.26968800E+05, -.34454700E+05, 0.76346200E+05, -.35951200E+05, -.41329000E+05, -.38176300E+05, 0.63689600E+04, 0.33187400E+05, -.24739200E+05, 0.75610900E+04, -.29132600E+05, 0.26914900E+05, -.26332500E+05, -.24398800E+05, 0.12339100E+05, -.14098100E+03, 0.12202000E+05, 0.22271500E+04, -.35962100E+04, 0.45864600E+04, -.31467300E+03, 0.99795900E+04, -.29109500E+04, 0.12193900E+05, -.35974400E+04, 0.21318000E+04, 0.68806800E+03, 0.17968600E+04, -.18693100E+03, 0.69793700E+03, 0.72627900E+03, 0.10805700E+04, 0.20045500E+04, 0.31740300E+03, 0.35538700E+04, -.61588900E+05, 0.27732100E+05, -.13612300E+05, 0.30789900E+05, 0.36279500E+04, -.24710700E+05, 0.11404100E+05, -.10948700E+05, 0.24858200E+05, -.21989400E+05, 0.26225000E+05, -.13356600E+05, 0.70736300E+04, -.73677500E+04, 0.66803900E+04, -.13197400E+04, -.79120900E+04, 0.41572800E+04, -.31068900E+03, 0.50981300E+04, -.71898500E+04, 0.34022500E+04, -.13059700E+05, 0.90220700E+04, 0.13106800E+05, 0.65131000E+04, 0.71088600E+04, -.49627300E+04, 0.60675100E+04, 0.41683300E+04, 0.63307400E+04, -.37493200E+04, 0.18067500E+04, -.31008200E+05, 0.16022500E+05, -.90812100E+04, 0.15519400E+05, 0.43614800E+03, -.16887600E+05, 0.38727000E+04, -.13948400E+05, 0.85888500E+04, -.14389500E+05, 0.13290300E+05, 0.12666800E+05, -.63665400E+04, -.61605600E+04, -.63345200E+04, 0.34417200E+03, 0.17891900E+04, -.12201000E+04, 0.54650500E+04, -.26530200E+04, 0.10436200E+04, -.63316500E+04, -.42504700E+04, 0.19498300E+04, 0.94165400E+03, 0.21195100E+04, 0.49233500E+03, 0.40788800E+03, 0.21399100E+03, -.12018400E+04, 0.17501600E+04, 0.23710200E+03, 0.36940100E+04, 0.36810100E+04, 0.23405500E+04, 0.21697500E+04, -.75201500E+03, -.43176600E+04, 0.11710200E+04, 0.17554200E+04, -.21117200E+04, -.33616400E+04, -.64299300E+03, -.20755300E+04, 0.24319500E+04, 0.21204600E+04, -.31192100E+04, -.22730300E+03, -.12490200E+04, -.26147400E+04, -.20662300E+04, 0.54184800E+03, 0.16071300E+04, 0.18535100E+04, 0.14117300E+04, -.23143700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.49414400E+00, 0.39730900E-02, -.16563700E+00, 0.11517900E+01, 0.37310000E+00, -.35406100E+00, 0.17447900E+00, 0.17207900E+01, 0.16928200E+02, -.11414400E+00, -.11464600E+00, 0.23817700E+00, -.14241000E+00, -.14084000E+00, 0.40652500E+00, -.58838600E+00, -.98274600E+00, 0.23064800E+00, 0.26674400E+00, 0.11087300E+00, 0.79214000E+00, 0.18801700E+00, -.88555700E+00, 0.20829200E+00, 0.44493500E+00, -.31570000E-01, -.34593000E+00, -.14877800E+00, 0.17458600E+00, 0.26767800E+00, -.57462000E-01, -.45715200E+00, -.17199300E-01, 0.53886000E+00, -.16851500E+04, -.16387700E+04, -.29106900E+01, 0.11900300E+05, 0.34895800E+05, -.15721100E+05, -.15109000E+05, -.11805300E+05, 0.29775900E+05, 0.50762800E+04, 0.25353900E+05, -.12582200E+05, -.41821600E+04, -.12677000E+05, -.12210300E+05, -.24703100E+05, 0.81772000E+04, 0.15117500E+05, -.17714400E+04, -.20610900E+05, -.14312200E+05, -.88752700E+04, 0.82819300E+04, -.96895800E+04, 0.44319100E+04, -.47440300E+04, 0.12638500E+04, -.53732700E+04, -.15921500E+05, 0.39999100E+04, -.32667400E+03, 0.53233700E+04, -.74983700E+04, 0.28926600E+04, 0.55164000E+04, 0.37481500E+04, -.18112700E+04, -.23177900E+04, 0.30926400E+04, 0.50634900E+03, 0.23691000E+04, -.11978700E+04, 0.31979800E+04, -.13058700E+05, 0.75035200E+04, 0.93190000E+04, 0.65265100E+04, -.13530700E+04, 0.21259800E+04, 0.68589800E+03, -.35832000E+04, 0.51841700E+03, 0.20370000E+04, 0.59005700E+04, -.67799600E+05, 0.35693100E+05, -.40899700E+04, 0.33881700E+05, 0.13200300E+05, -.22659800E+04, 0.11521700E+05, -.91512200E+04, 0.29341600E+05, -.35139300E+04, 0.33640200E+05, 0.37688800E+05, -.20303400E+05, -.19874900E+05, -.18840800E+05, -.48693000E+04, 0.65359600E+03, -.88839900E+04, 0.11463600E+04, -.96580600E+04, 0.49261900E+03, -.13347000E+05, -.19145600E+05, 0.10288000E+05, -.83748700E+04, 0.95738200E+04, -.10884800E+05, -.30449700E+04, 0.63172400E+04, -.72619600E+03, 0.75251500E+04, -.34317000E+04, 0.12216500E+05, 0.58309600E+05, -.27431900E+05, -.15961200E+05, -.29153500E+05, -.42746500E+03, 0.72084700E+04, -.10280300E+05, 0.56069300E+04, -.20164000E+05, 0.81232300E+04, -.30300500E+05, 0.42390500E+04, -.32027600E+04, 0.38922800E+03, -.21197200E+04, -.13798700E+05, -.37506400E+05, 0.14414300E+05, 0.13264700E+05, 0.96965200E+04, -.31407300E+05, -.68327500E+04, 0.24608900E+05, -.13829100E+05, -.17141800E+04, -.12302500E+05, -.14929700E+05, -.35749300E+05, 0.11301600E+05, 0.15247300E+05, 0.52925000E+03, -.29656200E+05, -.14773700E+05, 0.33888300E+05, -.17106100E+05, -.65062700E+04, -.16942200E+05, -.10861000E+05, 0.11004000E+04, -.62530900E+04, 0.85449100E+03, -.13901500E+05, 0.14721100E+03, -.11330200E+05, 0.56413600E+04, -.33738200E+04, -.10845000E+02, -.28222000E+04, 0.17557000E+04, -.13928200E+04, -.60088900E+03, 0.27031600E+04, -.32315600E+04, -.55711200E+03, -.51542000E+04, 0.11168700E+06, -.54006400E+05, -.18013600E+05, -.55851400E+05, -.15396600E+05, 0.23209300E+05, -.18151600E+05, 0.21921000E+05, -.41775000E+05, 0.22453700E+05, -.45784300E+05, 0.86397600E+04, -.50358800E+04, 0.88973900E+04, -.43230500E+04, -.50672000E+04, 0.66051200E+04, -.36695300E+04, -.28868500E+03, -.66744100E+04, 0.68107800E+04, 0.45133700E+02, 0.12024000E+05, -.87275400E+04, -.12315500E+05, -.60220100E+04, -.81758800E+03, 0.15384500E+05, -.12130400E+05, -.13541600E+05, -.10492200E+05, 0.13608700E+05, -.81694200E+03, 0.21706500E+05, -.12479300E+05, 0.91380100E+04, -.10841900E+05, -.14782000E+05, 0.18312900E+05, -.51030900E+04, 0.68978900E+04, -.12168400E+05, 0.15665100E+05, -.13741800E+04, -.12138700E+05, 0.59643300E+04, 0.30474400E+04, 0.60685400E+04, 0.80004000E+04, 0.20672100E+04, 0.83935400E+03, -.45535500E+04, 0.41177300E+04, 0.22429100E+04, 0.20855000E+04, -.88085600E+04, 0.46560300E+04, 0.19926500E+04, 0.43988900E+04, 0.69329300E+03, 0.54881300E+03, 0.11814500E+04, -.24106400E+04, 0.23624200E+04, 0.48173800E+03, 0.24536400E+04, -.17147000E+04, 0.13073800E+04, 0.15178600E+04, -.54121000E+03, 0.24299600E+03, -.77116900E+04, -.72367500E+03, -.15909700E+04, 0.70619000E+03, -.18005300E+04, -.27352500E+03, 0.38967800E+03, -.22580600E+04, -.20940300E+04, 0.71672800E+04, -.20720400E+04, -.32996600E+04, 0.43472900E+04, -.94035500E+03, -.65576600E+03, -.47535400E+04, 0.15990600E+04, -.11828900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25088400E+01, 0.33049000E+01, -.28792300E+01, 0.12606900E+01, -.17082900E+01, -.90758600E+00, 0.25689300E+00, 0.13867500E+01, 0.99364600E+01, 0.30384700E+00, -.87354500E-01, 0.10418200E+01, 0.11655300E+00, 0.14295200E+00, -.36124400E+01, -.12883600E+01, -.44023800E+01, -.85804800E+01, -.75202300E+00, 0.13718300E+01, 0.29205700E+01, -.69721100E+00, -.22985400E+01, -.23743300E+00, -.68696800E+00, -.19530000E-01, 0.18438700E+01, 0.28224900E+00, -.29182000E+00, 0.35245900E-01, -.54250000E+00, -.64107700E-02, 0.25318400E+00, -.15310000E+01, -.14794600E+01, -.76408000E+05, -.25342400E+01, 0.22880900E+04, 0.16856000E+05, -.98962100E+04, -.16440300E+05, -.47273600E+04, 0.11791100E+05, 0.11984300E+05, 0.20332400E+05, -.10678100E+05, 0.43420200E+05, -.10167600E+05, -.58590500E+04, -.12755100E+05, 0.41723600E+04, 0.16880700E+05, -.24384900E+04, -.95032300E+04, -.16568600E+05, -.73213300E+03, 0.30921400E+04, 0.12377700E+05, 0.35787200E+03, 0.54283000E+04, 0.95154200E+04, -.12391800E+04, -.19022500E+04, 0.21882900E+04, 0.70466800E+04, 0.47456900E+04, 0.45149600E+04, -.30897400E+04, -.19191300E+04, -.22589600E+04, -.20210200E+04, 0.84185400E+01, 0.19686800E+03, 0.28860600E+04, -.96140200E+03, -.42355400E+03, -.19046900E+04, -.78619100E+03, 0.16476800E+04, 0.12514900E+05, 0.38904900E+03, -.74949400E+04, -.39158900E+04, 0.63273100E+03, -.12500300E+04, -.32563100E+03, -.37355600E+04, -.76641000E+03, -.76571600E+05, 0.40629500E+05, -.11859200E+05, 0.38259800E+05, 0.12450000E+05, -.10936300E+05, 0.28143900E+05, 0.18940900E+04, 0.46461700E+05, -.15602700E+05, 0.22085300E+05, 0.18203400E+05, -.11234500E+05, -.16147600E+05, -.90964200E+04, 0.86256200E+04, 0.90012300E+04, -.87859200E+04, -.67462100E+03, -.87323200E+04, 0.92704600E+04, -.77035200E+03, 0.62488100E+05, -.30399900E+05, 0.17250600E+05, -.31242600E+05, -.23575500E+04, 0.19616900E+05, -.20212200E+05, 0.12784600E+04, -.27898400E+05, 0.17947500E+05, -.22566100E+05, 0.63568000E+05, -.31569000E+05, -.98356500E+04, -.31780600E+05, -.14453000E+05, -.25255500E+04, -.11481400E+05, -.12909000E+04, -.20120100E+05, -.13835100E+04, -.29779100E+05, -.26957900E+04, -.17066400E+03, 0.87802700E+05, 0.13460100E+04, -.38959500E+04, -.18073200E+05, 0.11796700E+05, 0.18563100E+05, 0.41404900E+04, -.13087000E+05, -.10181500E+05, 0.14716000E+05, -.89404400E+04, 0.73300400E+05, -.73570100E+04, -.62197600E+04, -.17591500E+05, 0.77694700E+04, 0.18831300E+05, -.26360500E+04, -.12923300E+05, -.14698100E+05, 0.39924700E+05, -.19958500E+05, 0.92446000E+04, -.19959600E+05, -.53344800E+04, 0.38687900E+04, -.12147200E+05, 0.37258100E+04, -.21662300E+05, 0.59056800E+04, -.10205200E+05, 0.36838500E+04, -.25188900E+04, -.34667300E+04, -.18440500E+04, 0.31875000E+04, 0.32499400E+03, -.90986800E+03, 0.30575200E+04, -.32826200E+04, 0.97687500E+03, -.50922500E+04, 0.78155300E+05, -.39991700E+05, -.28981200E+05, -.39087000E+05, -.47827800E+05, -.27561700E+05, 0.63932000E+03, 0.20516500E+05, -.22103800E+05, -.21156400E+05, -.29479400E+05, 0.44986300E+03, -.80857200E+03, -.48546200E+04, -.22764500E+03, -.17054800E+05, -.13307500E+05, 0.45831800E+04, 0.24612900E+04, 0.25570600E+04, -.10817300E+05, 0.48519700E+04, 0.11249800E+05, -.69077300E+04, -.14170800E+05, -.56402900E+04, 0.44209100E+04, 0.14449700E+05, -.74841000E+04, -.50526200E+04, -.80076600E+04, 0.10357600E+05, 0.56585500E+02, 0.17688700E+05, -.11192800E+05, 0.59213000E+04, -.88281100E+04, -.28207600E+05, -.22832500E+04, -.60444500E+04, -.54531500E+03, -.17658700E+05, -.15785800E+03, 0.64712000E+04, 0.32172000E+04, -.23299400E+04, -.19808000E+04, -.16097500E+04, -.20782100E+04, -.86729200E+04, 0.46045900E+04, 0.12089600E+04, 0.27500700E+04, -.78491800E+04, -.78025200E+04, 0.13379500E+05, -.64787900E+04, 0.93290000E+04, -.66970500E+04, -.14787100E+04, 0.41219300E+03, -.23056500E+04, -.25408600E+02, -.51525800E+04, 0.82795100E+03, -.77541700E+04, -.11812800E+04, -.30371100E+04, -.26458900E+04, -.58302600E+03, 0.18883700E+04, -.73521500E+04, -.14721100E+04, 0.26171800E+04, 0.51565400E+03, -.17027700E+04, 0.24714700E+03, 0.71680200E+04, -.71957500E+04, 0.13221500E+04, 0.53983800E+04, -.31429800E+04, 0.10930500E+04, 0.94112400E+04, -.35176700E+04, 0.20971100E+03, -.13054600E+05, -.17108800E+04, 0.26421200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28755100E+01, -.22591900E+01, -.73613000E+00, -.69374800E+00, 0.39391900E+00, 0.12673500E+01, -.64692400E+00, -.24593200E+01, 0.46590900E+01, -.13801300E-01, -.16349900E-01, 0.59381200E+00, -.90330400E-01, -.24874800E+00, 0.21002700E+01, 0.32280500E+01, 0.64818600E+01, 0.37688400E+00, 0.66484000E-02, -.15583400E+01, 0.16048100E+01, -.91716100E+00, -.21326700E+00, -.88364000E+00, -.45955500E+00, 0.29928000E+00, -.15673100E+01, -.30730100E+00, 0.74017800E+00, 0.27683400E+00, 0.14146200E+01, 0.12865100E+00, -.13021700E+00, -.35926800E+00, -.11834400E+00, -.38188800E+00, -.24089800E+03, 0.90101000E+04, 0.22784600E+03, -.48950800E+04, -.82147400E+04, -.36930200E+04, 0.15245200E+04, -.13771300E+04, -.29759600E+05, 0.15029400E+05, -.93139700E+04, 0.15125600E+05, -.18890800E+04, 0.71617700E+04, 0.35068000E+04, -.83918500E+03, 0.13867800E+05, 0.51359900E+04, 0.16836100E+05, 0.14716100E+04, -.21428300E+04, 0.53947400E+04, -.87917600E+03, 0.41391800E+03, -.38305200E+04, 0.20120000E+04, 0.93738200E+03, -.74220500E+02, -.21474200E+04, 0.10547500E+04, 0.69477700E+04, -.31320400E+04, -.39240400E+04, -.35033700E+04, 0.67696300E+03, 0.64121500E+03, -.19106000E+04, 0.13259500E+04, -.22015300E+04, 0.48075400E+03, -.28798100E+04, 0.10474200E+04, -.84355500E+03, -.28326100E+04, -.59692000E+03, 0.24622100E+04, 0.36885500E+03, -.93897500E+03, -.11108300E+04, -.16267400E+04, 0.13749300E+04, -.25568600E+04, 0.32057400E+05, -.16526500E+05, 0.13606900E+05, -.16310300E+05, -.23275200E+04, 0.16861700E+04, -.62423000E+04, -.25507600E+04, -.17576900E+05, 0.25987900E+04, -.28019000E+05, -.10784000E+05, 0.57902200E+04, 0.54066700E+04, 0.55662900E+04, -.22683700E+04, 0.56356300E+03, 0.18917700E+04, -.18460300E+04, 0.58129400E+04, 0.25206500E+03, 0.10201100E+05, -.41607100E+04, 0.17981800E+04, -.62791000E+04, 0.20926400E+04, 0.47217900E+04, -.20609600E+04, 0.12690000E+04, -.56115800E+03, 0.17767800E+04, -.94955700E+03, 0.54623600E+04, -.19859200E+05, 0.89892000E+04, -.31983800E+04, 0.10067900E+05, 0.28883000E+04, -.11695600E+04, 0.35010400E+04, 0.85301900E+03, 0.11660900E+05, -.24987100E+04, 0.10246800E+05, -.77939100E+04, 0.43072800E+04, 0.30475500E+04, 0.40105900E+04, -.64731700E+04, 0.47239000E+04, 0.33754300E+04, 0.53219600E+04, 0.36940500E+04, 0.30702400E+04, 0.80582500E+04, -.34224000E+05, 0.17506700E+05, -.46085900E+04, 0.17260000E+05, -.27927400E+04, 0.10971600E+05, 0.32616600E+04, -.18158300E+04, 0.12441600E+05, 0.82631800E+04, 0.22346000E+05, -.19936700E+05, 0.10064800E+05, -.26164900E+04, 0.10085800E+05, -.81410000E+02, 0.57514300E+03, 0.36200100E+04, -.19532200E+04, 0.66470100E+04, 0.87658300E+03, 0.15439100E+05, 0.88771200E+03, -.24633700E+03, -.65207800E+03, -.39320900E+03, -.12850900E+04, -.14276600E+03, 0.35685700E+02, 0.21091500E+04, 0.11930100E+04, -.78407100E+03, 0.79555300E+03, -.17525500E+05, 0.75889100E+04, -.91512200E+04, 0.92551100E+04, 0.12109900E+05, 0.14333100E+04, -.59073400E+03, 0.10343000E+04, 0.14475800E+05, 0.33816500E+03, 0.85049500E+04, 0.19563800E+04, -.75769500E+03, -.45711300E+04, -.91731100E+03, 0.43459900E+04, 0.86878300E+03, -.16675600E+04, 0.37767700E+03, 0.43561800E+02, 0.12326300E+04, -.25426400E+04, -.12939700E+05, 0.74251300E+04, 0.48304800E+04, 0.61077500E+04, 0.46006900E+04, 0.18068600E+04, -.55213400E+03, -.63725100E+04, 0.34118500E+03, 0.28688800E+04, 0.56084700E+04, 0.20382000E+04, -.60428800E+03, -.11525500E+05, -.83572700E+03, 0.96688300E+04, -.60574300E+03, -.17542200E+04, -.48485500E+03, 0.12404700E+04, 0.89942400E+03, 0.24449600E+04, 0.48727100E+04, -.23928700E+04, -.34960600E+03, -.25274300E+04, -.10983300E+04, 0.14747100E+04, -.89362700E+03, 0.86480600E+03, -.19764300E+04, 0.76641100E+03, -.35409600E+04, -.33722100E+04, 0.15968900E+04, -.16227100E+04, 0.16502100E+04, 0.13433900E+04, -.48016100E+02, 0.52861200E+03, -.38330200E+03, 0.10565900E+04, -.20500100E+03, 0.24570500E+04, 0.10367300E+03, -.65243400E+03, -.42588000E+03, 0.47125100E+03, -.53769900E+04, -.13413200E+04, -.41898700E+03, 0.51362500E+03, -.83674700E+03, 0.12740800E+04, -.24237900E+03, -.23641900E+04, 0.50182500E+04, -.87533000E+04, 0.61709300E+04, 0.31728300E+03, 0.16538300E+04, -.44141400E+04, 0.34269400E+03, 0.89640400E+02, 0.44762900E+04, -.86431200E+03, 0.72377600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39167000E+00, -.10637800E+01, 0.29012400E-01, -.50839800E+00, 0.49943600E+00, 0.10343300E+01, 0.15566900E-01, -.15379300E+00, 0.61156300E+01, 0.27662000E+00, -.34555300E-01, -.93485400E-01, -.12699900E+00, -.56821000E-01, 0.46040400E+00, -.77472400E+00, 0.32270700E+00, 0.78294400E+00, 0.55705900E-01, -.44520800E+00, -.44494600E+00, 0.61642200E-01, 0.10937000E+01, -.42604500E+00, -.43906000E+00, -.10950800E-01, -.64624200E+00, -.27405700E-02, -.11031300E-01, -.11936500E-01, 0.19690800E+00, -.64737200E-03, -.80534200E-01, 0.22704000E-01, 0.50667100E-01, -.27136900E-02, 0.99811200E-02, 0.92820300E+04, 0.16079100E+05, -.95573000E+04, -.86514200E+04, -.69322400E+04, 0.13748000E+05, 0.30852300E+02, -.39661400E+04, 0.17114500E+04, -.11433900E+04, 0.19847000E+04, -.51070100E+04, -.58841300E+04, 0.41538700E+04, 0.29310100E+04, 0.42452600E+04, -.47543500E+04, 0.38502200E+04, -.94870500E+04, 0.49234900E+04, -.60741500E+04, 0.47503100E+04, -.88879700E+04, -.97913000E+04, 0.45851200E+04, -.35036500E+04, 0.51389600E+04, -.76672200E+04, 0.67564900E+04, 0.17663700E+04, -.87924500E+03, 0.16840300E+04, -.88192700E+03, -.62548800E+03, -.87858100E+03, 0.43423800E+03, 0.11243100E+04, -.58571200E+03, -.58700200E+03, -.34343900E+04, -.83180800E+04, 0.40899200E+04, 0.89485000E+04, 0.41624400E+04, 0.19090200E+04, 0.15396800E+04, -.14931200E+03, -.30388800E+04, -.62700400E+02, 0.15433500E+04, 0.32310400E+04, 0.27032900E+04, -.14157700E+04, -.12041800E+05, -.13318000E+04, 0.53729900E+04, -.67523600E+03, -.20651600E+04, -.16314600E+04, -.33581100E+04, -.11799800E+03, -.13781500E+05, 0.71747700E+04, -.34448700E+04, -.10505200E+05, -.35928600E+04, -.43612300E+04, -.26915300E+03, -.13490400E+04, -.65297700E+03, 0.79001500E+03, 0.41464100E+01, 0.50894200E+04, -.14113300E+05, 0.70107700E+04, -.76457000E+02, 0.70556000E+04, -.33345000E+04, -.32618700E+04, 0.35943500E+04, -.28712000E+04, 0.54151600E+04, -.30121200E+04, 0.14037300E+05, 0.22891500E+05, -.11248900E+05, -.15516600E+04, -.11453300E+05, -.64252400E+03, 0.33768000E+04, -.27571000E+04, 0.59659900E+04, -.52129100E+04, 0.27978200E+04, -.11740300E+05, -.25012800E+04, 0.76636700E+03, -.18422000E+03, 0.12547100E+04, -.80510800E+04, -.13275200E+05, 0.82776700E+04, 0.71471000E+04, 0.55592200E+04, -.10706300E+05, 0.26183100E+04, -.71305100E+04, 0.28874900E+04, -.44215500E+03, 0.35674200E+04, -.62261800E+04, -.83147100E+04, 0.63275700E+04, 0.41358700E+04, 0.53816100E+04, -.64050000E+04, 0.63999300E+04, -.49377400E+04, 0.23588700E+04, 0.14559400E+04, 0.24659000E+04, -.46145300E+04, -.45260700E+03, 0.12475100E+04, -.24041600E+04, 0.23807700E+04, -.48364200E+03, 0.11662200E+05, 0.73878700E+03, -.34400800E+03, 0.26447200E+03, -.36863200E+03, -.90578100E+03, -.58370000E+03, 0.29866600E+03, 0.14008500E+04, 0.11582800E+03, -.53512500E+03, -.15156300E+04, 0.45640400E+05, -.22277200E+05, 0.11347400E+05, -.22823400E+05, 0.51528400E+03, 0.14799000E+05, -.11302900E+05, 0.51910600E+04, -.15050100E+05, 0.12487400E+05, -.15935000E+05, 0.79065100E+04, -.39446900E+04, 0.67235900E+04, -.39510300E+04, 0.25569400E+04, 0.55835100E+04, -.42570900E+04, -.63526600E+03, -.45277200E+04, 0.49107800E+04, -.27229700E+04, -.51758900E+04, 0.23401900E+04, -.58920500E+04, 0.26041300E+04, 0.86499900E+03, 0.58414200E+04, -.43182100E+04, -.79667600E+04, -.27945000E+04, 0.60497000E+04, 0.46140200E+04, 0.93679700E+04, -.45601500E+04, 0.14541800E+05, -.46965800E+04, 0.20538000E+04, 0.95826200E+04, -.49410000E+04, -.26350100E+04, -.49736200E+04, 0.79802500E+04, 0.71121400E+04, 0.80243300E+04, -.38550300E+04, -.24125200E+04, -.40104500E+04, 0.13319400E+04, 0.15394900E+04, -.10624200E+04, 0.21053000E+04, -.23871100E+04, 0.14383100E+04, -.88039800E+04, -.20618500E+04, 0.10422800E+04, -.34265400E+03, 0.10349300E+04, -.40603600E+02, -.22693400E+03, 0.66790600E+03, -.10717500E+03, 0.11653600E+04, -.30589000E+03, 0.18545700E+04, -.14627200E+04, -.27182900E+03, -.18262600E+03, 0.39065700E+03, -.18275200E+04, -.33576500E+04, -.68485600E+03, 0.13786200E+03, 0.24168600E+03, 0.24543600E+03, -.19301800E+03, -.18247300E+04, -.57688000E+03, -.39134200E+04, 0.47384300E+04, -.15536600E+03, -.55987500E+03, 0.97498300E+03, -.45772800E+03, -.49424400E+03, -.16221500E+02, -.63120900E+03, 0.30824100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.40356800E+00, 0.68313100E-01, -.20245000E+00, -.41321400E+00, 0.40231200E+00, 0.25811000E+00, -.69238000E-01, -.37730700E+00, -.39755000E+01, 0.21946600E+00, 0.69852800E-01, -.29813100E+00, 0.16747100E+00, 0.31109700E-01, -.13507500E+00, 0.35197100E+00, 0.76258700E+00, 0.95418800E+00, 0.14643900E+00, 0.44090800E-01, -.39804400E-01, 0.14596300E+00, 0.81738300E+00, 0.44313700E+00, -.29983100E+00, 0.29713000E-01, -.59568600E+00, -.87120100E-01, 0.22479800E+00, 0.23073700E-01, 0.12363700E+00, 0.17331600E+00, -.13522900E+00, 0.18079900E-01, -.16807000E+00, -.15517100E+00, -.36770800E-04, 0.11140100E+00, 0.89669300E+04, -.47038100E+04, -.68380200E+04, -.81094200E+04, 0.77103500E+04, 0.17200500E+04, 0.74334200E+04, -.37282700E+04, -.33530900E+04, -.37208000E+04, -.16104600E+04, -.77205500E+04, 0.28975000E+04, 0.62416800E+04, 0.35267900E+04, -.66312600E+04, -.44301300E+04, -.49423100E+04, 0.30133800E+04, 0.34151200E+04, 0.24609000E+04, 0.27250400E+04, 0.38614700E+04, -.17221000E+04, -.37923700E+04, 0.65884200E+03, 0.26780300E+04, 0.30183300E+04, -.18205500E+04, 0.75116800E+03, -.63700400E+03, 0.90841700E+03, 0.57623200E+03, -.10011900E+03, 0.21403800E+03, -.76181800E+02, 0.90142300E+03, -.28789300E+02, -.50188400E+02, -.57875200E+04, 0.31056700E+04, -.58890900E+03, 0.28886700E+04, 0.10049500E+04, 0.87983700E+03, -.10920800E+03, -.19955600E+04, 0.45834000E+03, 0.73575200E+03, 0.22562600E+04, -.16679000E+05, 0.87012200E+04, 0.11191200E+05, 0.83070900E+04, 0.25154200E+04, 0.18102400E+04, 0.18770600E+04, -.41767400E+04, 0.19875900E+04, 0.95464700E+03, 0.45652800E+04, 0.16477900E+05, -.85683800E+04, -.29100900E+04, -.82319900E+04, -.27336600E+04, -.21236000E+03, -.19590100E+04, 0.30434900E+04, -.26518100E+04, -.47953100E+02, -.44574100E+04, 0.82132500E+03, -.25754400E+03, -.49303500E+03, -.40889200E+03, -.17575100E+04, 0.86527900E+03, -.17368600E+03, 0.12856100E+03, -.43284500E+03, 0.59222400E+03, 0.23193800E+04, 0.18665100E+04, -.72224200E+03, -.57404800E+04, -.92558700E+03, 0.99339200E+03, -.19383900E+03, -.12751900E+04, -.14632800E+04, 0.26107500E+03, 0.36166900E+03, -.20525900E+04, 0.21553800E+04, -.12301400E+04, 0.71388400E+03, -.10832000E+04, -.11160000E+04, -.10084300E+05, 0.47399400E+04, 0.70154600E+04, 0.73777000E+04, -.86574300E+04, -.26262600E+04, 0.84476600E+04, -.43179000E+04, -.13481500E+04, -.42260100E+04, -.21545700E+04, -.10531400E+05, 0.40029900E+04, 0.74541000E+04, 0.45455100E+04, -.89906200E+04, -.51193600E+04, 0.10526200E+05, -.52692300E+04, -.44807800E+04, -.52596000E+04, -.27211400E+04, 0.20063000E+03, -.16570800E+04, 0.12291400E+04, -.30832500E+04, 0.24844100E+03, -.26839300E+03, 0.12137700E+04, -.72351600E+03, -.52194000E+03, -.60934000E+03, 0.93376100E+03, -.42366800E+03, 0.16965900E+03, 0.14697800E+04, 0.57287400E+03, -.23115700E+03, -.20557300E+04, 0.15035000E+05, -.74438900E+04, -.21291800E+05, -.75248300E+04, -.46564800E+04, -.39832600E+04, -.10976800E+04, 0.42909600E+04, 0.17837900E+04, -.28020200E+04, -.36079900E+04, 0.42574000E+04, -.22391100E+04, -.59603600E+04, -.21311300E+04, -.15751300E+04, 0.26689400E+03, -.11621700E+04, 0.15671100E+03, -.60340300E+03, 0.56018100E+03, -.77367900E+03, 0.37177300E+03, -.47236600E+03, 0.22309900E+04, -.20735200E+03, -.62741600E+03, 0.49057700E+04, -.32062600E+04, -.53148900E+04, -.51759000E+04, 0.42411700E+04, 0.16085400E+04, 0.20325000E+04, -.13645700E+04, -.10037300E+05, -.99590600E+03, -.63290700E+04, -.21446800E+04, 0.67856300E+03, 0.94878800E+03, 0.12893700E+04, -.18227400E+04, 0.55915500E+04, -.73536400E+04, 0.35678700E+04, 0.18753900E+04, 0.36752500E+04, 0.21107800E+04, 0.35423100E+03, 0.22963000E+03, -.27790000E+04, 0.12493300E+04, 0.53556100E+03, 0.16899300E+04, -.35039500E+04, 0.17898600E+04, 0.17850700E+04, 0.17439000E+04, 0.48673700E+03, 0.82939500E+03, -.93595500E+02, -.15543500E+04, -.24894800E+03, 0.78763000E+03, 0.18351900E+04, -.14034100E+04, 0.97619500E+03, 0.10528000E+04, 0.15492300E+02, 0.14665200E+04, 0.30102800E+03, -.10809400E+04, -.10260600E+04, -.23140200E+03, -.89038500E+03, -.64166000E+03, 0.12225500E+04, 0.14210200E+04, 0.19442300E+04, -.74170800E+03, -.14218300E+04, -.14162200E+04, -.27995100E+03, -.68292900E+03, -.63559900E+02, -.81389500E+03, 0.10217000E+04, -.91351800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.94933400E+00, 0.30961100E+00, 0.14588300E+00, 0.97584200E-01, -.19135500E+00, 0.20137300E+00, 0.53454800E-01, -.54748600E+00, -.38096700E+01, 0.57412800E+00, -.44112300E-02, -.71931900E+00, -.29541700E+00, 0.12723500E+00, -.19535200E+00, -.15762500E+01, -.24689700E+01, -.35012000E+00, 0.50597900E-02, 0.45922700E+00, -.29946200E-01, 0.58153500E-01, -.90070100E+00, 0.14074500E+00, 0.40515900E+00, -.15338000E-01, 0.82485900E+00, 0.16320400E+00, -.35721000E+00, -.13102400E+00, -.75272700E+00, -.31765900E-01, 0.14601500E+00, -.36871400E+00, -.17522400E+00, 0.63855100E-01, 0.14638500E-02, 0.21227500E+00, 0.36450900E+00, -.35383400E+04, -.46364600E+04, 0.71641200E+03, -.49503600E+03, 0.24562000E+04, 0.13621000E+04, -.70424100E+03, 0.29008100E+04, -.67875500E+03, -.12912700E+03, 0.23700900E+03, 0.18197700E+04, 0.23861700E+04, -.16468700E+04, 0.62987400E+03, -.27961200E+04, 0.22069100E+03, -.15525000E+03, 0.36446900E+02, -.10483300E+03, 0.38145800E+01, 0.14274600E+03, 0.18867000E+04, 0.45403800E+04, 0.15573100E+04, 0.46273200E+03, 0.12278100E+04, 0.42360900E+04, -.21144000E+04, -.11532400E+04, -.21170500E+04, -.46008400E+03, 0.43697900E+03, -.82528000E+03, 0.28043800E+03, -.15263200E+04, 0.20222600E+03, -.74679200E+03, 0.51872000E+02, -.18146200E+02, 0.12626700E+04, -.23206200E+02, -.53738300E+03, -.18605000E+03, -.42785900E+02, -.61971700E+03, -.84781800E+03, -.24313200E+02, -.35289400E+03, 0.84606200E+04, -.40618000E+04, -.33461100E+04, -.42127600E+04, 0.32617700E+04, 0.67922500E+03, -.12376300E+04, 0.48154700E+04, 0.29918100E+03, 0.65372600E+03, -.72975200E+04, -.37317100E+04, 0.18039300E+04, 0.58185900E+03, 0.18622100E+04, 0.45024900E+03, -.34529500E+02, 0.78840000E+03, -.88369900E+03, 0.80139900E+03, 0.27525100E+02, 0.10921200E+04, 0.58867300E+04, -.29895500E+04, 0.45203400E+04, -.29443300E+04, 0.13263700E+04, 0.19611500E+04, -.25278700E+04, -.16674200E+04, -.33884700E+04, 0.19387900E+04, -.43051300E+04, 0.69481200E+04, -.36314500E+04, -.17313900E+04, -.34779500E+04, -.28980600E+04, -.12947500E+04, -.44408300E+03, 0.11173500E+04, -.17435500E+04, -.15789700E+04, -.29391900E+03, -.11997400E+04, 0.59794500E+03, -.36649100E+03, 0.60280300E+03, -.11041200E+03, -.21016900E+03, 0.49305700E+04, 0.64306200E+04, 0.68740800E+01, 0.38489700E+03, -.19491900E+04, 0.14894700E+03, -.10701300E+03, 0.17180800E+04, -.73359600E+02, -.20996400E+03, 0.50134400E+02, 0.39201900E+04, 0.52764400E+04, -.10417400E+04, 0.63167700E+03, -.21099000E+04, -.41712800E+04, 0.20309400E+04, 0.19164300E+04, 0.20838000E+04, -.30851500E+03, -.66855100E+03, 0.78775800E+03, -.14726200E+04, 0.14149500E+04, -.21832700E+03, 0.43123500E+03, -.37411600E+03, 0.17410200E+03, -.56094300E+03, 0.18845700E+03, -.42105800E+03, 0.25686300E+03, 0.24548700E+03, 0.45326400E+02, 0.39866500E+02, 0.61734100E+02, 0.14109900E+04, 0.20739200E+04, -.13196800E+04, 0.41594500E+03, -.10322900E+04, -.46608200E+04, -.41076200E+04, -.52101800E+03, -.60927700E+04, -.38123200E+04, -.37866300E+04, -.19527400E+04, -.16171200E+04, 0.77255100E+03, -.15512600E+03, 0.80969900E+03, -.14032300E+04, -.15480700E+04, 0.14953200E+03, -.25170200E+04, -.82284500E+03, -.11849500E+04, 0.10342300E+04, 0.15023300E+04, -.66635300E+03, -.35923000E+03, -.73981400E+03, 0.37067000E+03, 0.27056600E+03, -.40223000E+03, 0.11523700E+04, 0.10982000E+04, 0.95757400E+02, -.43525900E+03, -.23645900E+04, 0.10301800E+04, 0.29546000E+04, 0.11712800E+04, -.97690900E+03, -.15682200E+04, -.14050200E+04, -.74972300E+04, -.38946100E+04, -.11317600E+04, -.23090900E+04, 0.41942500E+04, -.20481500E+04, -.16923500E+04, -.20963500E+04, -.52273700E+03, -.62531600E+02, -.16883500E+03, 0.26450200E+04, 0.13339800E+03, -.26359300E+03, -.86631100E+03, 0.14325400E+04, -.70812600E+03, 0.11635300E+04, -.71179900E+03, 0.29510100E+03, 0.25786400E+02, -.42583500E+03, 0.35506100E+03, 0.42581100E+03, 0.22208100E+02, -.12924300E+04, 0.27343400E+03, -.32252900E+03, -.26775200E+03, -.61178900E+01, 0.12527100E+03, -.61804400E+03, 0.27398800E+03, 0.27271000E+03, -.40956500E+02, 0.24185200E+03, 0.14096400E+03, 0.46755200E+03, -.53774600E+03, -.42280500E+03, 0.85113400E+03, 0.40195700E+03, 0.59104800E+03, 0.70876300E+03, -.52387500E+03, -.13690300E+03, -.93450000E+03, -.33898100E+03, 0.21734600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.69930500E+00, -.59984100E-01, 0.26294900E-02, -.29885600E-01, 0.19983300E+00, 0.18248900E-01, 0.18255500E-01, 0.53614700E+00, -.22405200E+00, -.24426600E+00, -.31470600E-01, 0.36476900E+00, 0.22979500E+00, -.99591400E-01, 0.25130500E+00, 0.89155600E+00, 0.16733900E+01, 0.49503500E+00, 0.97229000E-01, -.27091700E-01, 0.43579800E-01, -.22550800E+00, 0.30871900E+00, -.42596200E-01, -.29685200E+00, 0.70244000E-02, -.20878600E+00, -.67221700E-01, 0.47881100E+00, -.23168300E+00, 0.27928600E+00, -.17959100E+00, -.67336200E-01, -.25344500E+00, -.34843700E+00, -.10524300E+00, 0.44386100E-02, 0.28125900E-02, 0.25084700E+00, 0.89805600E-01, -.40018400E+04, -.57179400E+03, 0.26061800E+03, 0.29065600E+02, -.72809400E+03, 0.40008400E+03, -.37274500E+04, 0.36273000E+03, 0.20138400E+03, 0.68151200E+03, -.17079500E+03, 0.28824100E+04, 0.23581800E+03, 0.35430100E+03, 0.94239300E+03, -.77711700E+03, 0.36359800E+03, -.18049400E+04, 0.38669400E+03, -.11093700E+04, -.19830100E+04, -.70738200E+03, -.51436500E+04, 0.41623200E+03, -.13953700E+04, 0.23623300E+03, -.12756900E+03, 0.47922700E+02, 0.17282400E+04, 0.63463200E+02, 0.21346800E+03, -.61852100E+03, 0.10193200E+04, 0.21364700E+04, 0.23115000E+03, -.48097400E+03, -.16853000E+04, -.29320500E+04, 0.15346000E+04, 0.15936100E+04, 0.14651200E+04, 0.14797500E+03, -.63397200E+03, 0.17949500E+04, 0.57106500E+03, 0.10628400E+04, -.83153000E+03, 0.13562200E+04, -.96083300E+03, 0.64470600E+03, 0.41085700E+03, 0.47368300E+03, -.10115400E+04, -.23313200E+04, 0.36911600E+04, -.11482500E+04, 0.44038800E+04, -.22154100E+04, -.12011300E+04, 0.70763500E+04, -.36922400E+04, -.51262600E+04, -.35373800E+04, -.92720100E+03, 0.59432000E+03, -.40137900E+04, -.20954000E+04, -.28246900E+04, 0.98055700E+03, -.99216200E+03, -.48236700E+04, 0.24343000E+04, -.50516500E+04, 0.24122200E+04, -.10447000E+04, -.16031900E+04, 0.83863800E+03, -.19468100E+04, 0.16251900E+04, -.13052300E+04, 0.50155700E+04, 0.58220500E+04, -.31053200E+04, -.13705000E+04, -.29109600E+04, 0.22172900E+04, 0.13928600E+04, -.59490200E+03, 0.55000300E+03, -.91961400E+03, 0.11772700E+04, -.50267000E+04, 0.91035400E+03, -.36869200E+03, -.44299400E+03, -.45595800E+03, 0.11200400E+02, 0.68864200E+03, -.83327200E+03, 0.36020000E+04, -.77763600E+03, 0.46542900E+03, -.64691700E+02, 0.33901400E+03, -.75348100E+02, -.33337700E+04, -.16952300E+03, 0.11855400E+03, 0.11911200E+04, -.99101300E+03, 0.29061500E+04, -.72645100E+03, 0.86524300E+03, 0.61871900E+03, -.12940800E+04, 0.65969500E+03, -.29078200E+04, 0.64733500E+03, -.63223900E+03, 0.36174700E+03, -.14285800E+04, 0.56912900E+03, -.11049100E+04, 0.51043300E+03, 0.42376100E+04, -.13581900E+04, 0.64796100E+03, 0.15647300E+04, 0.67818500E+03, 0.51641200E+03, 0.18396300E+03, -.25480600E+03, 0.70666500E+03, -.87021400E+03, 0.31337900E+03, -.69418300E+03, 0.18757200E+05, -.97768300E+04, -.75310500E+03, -.93842200E+04, 0.43395300E+04, 0.63278200E+04, -.40691700E+04, 0.81740000E+04, -.58183600E+04, 0.54468400E+04, -.82005900E+04, 0.18917200E+04, -.96960500E+03, 0.22649200E+04, -.94588300E+03, 0.21315200E+03, -.26108700E+03, 0.10018000E+04, 0.38706500E+04, 0.35266700E+03, -.64089800E+03, -.86298800E+03, -.67776200E+03, 0.44080200E+03, -.22955900E+04, 0.33604100E+03, -.49124200E+03, -.76680200E+03, -.15509300E+03, -.31925900E+04, -.72961900E+03, -.31717600E+03, 0.96917200E+03, 0.81973900E+04, -.42827400E+04, 0.64806000E+03, -.40945300E+04, 0.21556400E+04, 0.52793500E+04, -.37461200E+04, 0.28990300E+04, -.38183200E+04, 0.45149200E+04, 0.68388300E+03, -.16828700E+04, 0.77559300E+03, 0.35238700E+03, 0.84151400E+03, 0.10723500E+04, -.75081800E+03, 0.20872900E+04, 0.14116600E+04, 0.20451700E+04, -.76104100E+03, -.14122400E+04, -.36861900E+04, 0.18467900E+04, -.61769400E+03, 0.18409100E+04, -.61740100E+01, -.47325700E+03, 0.10747400E+04, -.54615600E+03, 0.16292800E+04, -.39456200E+03, 0.23403400E+04, -.15081000E+03, -.52108600E+03, -.41720300E+03, 0.79011400E+02, 0.15657700E+03, 0.40345000E+03, -.17392500E+03, 0.37542500E+03, 0.17438800E+03, 0.35579800E+03, 0.15630600E+03, 0.28180200E+03, 0.72631000E+03, 0.36587300E+01, -.21306700E+03, -.43090000E+03, -.11468500E+03, -.91252400E+02, -.16642800E+03, -.90591800E+02, 0.41297000E+03, -.34552800E+03, 0.58139700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13268000E+01, 0.30816000E+01, 0.15218800E+00, 0.24936400E+01, 0.16042100E+01, -.55854200E-01, 0.61310200E+00, 0.33779700E+01, -.62736400E+01, 0.13891800E+01, -.81561200E+00, -.22746000E+01, -.41130500E+00, -.18499500E+00, 0.16204700E+01, -.19238500E+01, -.25728500E+01, 0.27264900E+01, 0.72447200E+00, 0.62590200E+00, -.13659800E+01, 0.41619300E+00, -.41557000E+01, 0.24596200E+00, -.10789700E+00, 0.44296500E-01, -.41973400E+00, 0.11715400E-01, 0.94321900E-02, -.96252600E+00, -.14504400E+01, -.88830200E+00, 0.11360100E+01, 0.25398900E+00, -.14926200E+00, 0.40376600E+00, -.32615100E-01, -.19643400E+01, -.82161300E+00, -.13425900E+01, -.77835000E+00, 0.15521800E+05, -.37821700E+04, 0.12653800E+05, 0.19022600E+05, -.99485300E+04, -.76732800E+02, -.95134200E+04, -.27195800E+03, 0.22993500E+04, -.40941700E+04, 0.15467200E+04, -.19449200E+05, 0.43858400E+04, -.21183100E+05, 0.19023100E+05, -.80456400E+04, -.17000400E+05, -.95197200E+04, 0.12616600E+04, 0.46513200E+04, -.10003500E+05, -.11722300E+05, -.18601300E+04, 0.42927300E+04, -.12700800E+05, 0.17721600E+05, -.93272500E+04, -.12279900E+04, -.88623300E+04, -.36380500E+04, -.18536700E+04, -.18040100E+04, 0.43827400E+04, -.52010700E+04, -.71016400E+03, 0.67586200E+04, 0.20358200E+05, -.93862000E+04, 0.49773600E+01, -.10183200E+05, -.59318200E+04, 0.11180400E+04, -.61951600E+04, -.24664400E+04, -.98808600E+04, 0.60671600E+03, -.78917400E+04, 0.59313000E+05, -.27751400E+05, -.37155200E+05, -.29680700E+05, -.67296400E+04, -.90550800E+04, -.30394200E+04, 0.16447200E+05, 0.28693200E+04, -.10539900E+05, 0.19639500E+05, -.41840900E+05, 0.19401000E+05, 0.76783800E+04, 0.20926900E+05, 0.87998400E+04, 0.34174200E+04, 0.48611600E+04, -.97546900E+04, 0.93500900E+04, 0.33792300E+04, -.94980000E+04, 0.22843700E+04, -.73584700E+03, 0.46744400E+04, -.11409000E+04, -.57898800E+03, 0.43980900E+04, -.40385300E+04, -.67016200E+04, -.45009500E+04, 0.31978000E+04, -.28990200E+05, 0.36611200E+05, -.18930000E+05, -.31001000E+04, -.18296900E+05, 0.12264700E+04, 0.21858600E+04, -.36896800E+04, 0.53964500E+04, -.98164300E+04, 0.13886800E+04, -.12711600E+05, 0.63337900E+04, -.38042600E+04, -.63003500E+04, -.31718600E+04, -.93684500E+03, -.26134600E+04, -.57787500E+03, 0.16274600E+04, -.14228900E+05, 0.13915900E+04, -.17503700E+05, 0.22023000E+05, -.11976100E+05, -.70853100E+04, -.11014100E+05, -.81602200E+03, -.15908700E+04, -.32940900E+04, 0.28343100E+04, -.19101700E+05, 0.18666100E+04, -.25345200E+05, -.16665200E+05, 0.81907600E+04, 0.56892900E+04, 0.83361100E+04, 0.13669300E+04, 0.65805600E+04, -.25479700E+04, -.86600300E+04, -.56584200E+04, 0.59516000E+04, -.26229600E+05, -.17282500E+05, 0.81990700E+04, 0.67129600E+04, 0.86402100E+04, 0.39206400E+04, 0.15260000E+04, 0.29919700E+04, 0.10773800E+04, 0.23770300E+04, 0.23775100E+04, 0.11873400E+05, 0.47145800E+05, -.25220800E+05, 0.18248600E+05, -.23570300E+05, -.24680400E+04, 0.22916100E+05, -.18867300E+05, -.49957500E+04, -.41951300E+05, 0.20393200E+05, -.38332900E+05, -.99451300E+04, 0.45530200E+04, 0.15335300E+05, 0.49666500E+04, -.73657600E+04, 0.11270400E+04, -.20819800E+04, -.59282600E+04, -.70319700E+04, 0.15960800E+04, 0.10552000E+05, 0.25935800E+05, -.13412300E+05, -.18094500E+05, -.12987100E+05, -.53521900E+03, 0.28265400E+04, -.49421400E+04, 0.26731300E+04, 0.31388000E+04, 0.51976700E+03, -.11149300E+05, 0.59529800E+04, -.48584700E+04, 0.23776900E+05, -.29611600E+04, -.23523300E+04, 0.20023200E+05, -.13712100E+05, -.15449400E+05, -.23703000E+05, 0.16510800E+05, -.45379100E+05, 0.14062800E+05, -.73731900E+04, -.26802600E+04, -.70333500E+04, 0.12151700E+04, -.10621400E+04, -.44198900E+03, 0.36736600E+04, 0.18038900E+03, -.71216600E+03, 0.13171200E+05, -.53445800E+04, 0.28202300E+04, 0.53936600E+04, 0.26672100E+04, 0.13963100E+04, 0.47358900E+03, -.35451800E+03, -.34045000E+04, 0.28045200E+04, 0.17247100E+03, -.63221200E+04, 0.44072300E+04, -.23963700E+04, -.21653200E+04, -.17131000E+04, 0.11739300E+04, -.31861500E+04, 0.31872400E+04, 0.23006900E+04, -.11022800E+04, 0.11987400E+04, 0.19858100E+04, -.37935000E+04, -.22751600E+04, -.46888000E+02, 0.21141600E+04, 0.27536400E+04, -.62342700E+04, 0.37590100E+04, -.50888000E+03, -.19462100E+03, -.10792500E+04, -.20093100E+04, 0.23048900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35081600E+00, 0.10306700E+01, -.34820400E-01, 0.43362400E+00, -.39865500E+00, -.92343700E+00, -.10007200E-01, 0.16627600E+00, -.62846600E+01, -.23149500E+00, 0.66308400E-01, -.71609700E-01, -.11148200E+00, 0.40314100E-01, -.55002300E+00, 0.16368600E+00, -.36435000E+00, -.38498800E+00, 0.36515500E-01, 0.83820800E+00, 0.40516600E+00, 0.15813200E+00, 0.16110200E+00, 0.43763800E-01, -.67441300E-01, 0.46847100E-02, -.70133000E-01, -.24693300E-01, 0.90135100E-01, 0.43922600E-01, 0.20260100E+00, -.10221000E-01, -.10452400E+00, 0.28967900E-01, -.66791900E-01, -.35949000E-01, 0.21625500E-02, 0.10133900E+00, 0.14765800E+00, -.80654200E-02, 0.19967600E+00, -.36075700E-01, 0.89252900E+03, 0.26653600E+03, 0.16873100E+04, -.80600800E+03, -.18289700E+03, -.84342100E+03, -.15449500E+03, -.37752500E+03, -.85299800E+02, 0.44672200E+03, -.37107100E+03, -.93715700E+03, -.95908200E+03, 0.34037200E+02, -.13042700E+03, -.12601800E+03, -.16448500E+02, 0.86337900E+02, 0.77214700E+03, -.78735800E+03, -.13481100E+04, -.51915800E+03, 0.54620100E+03, -.27300400E+03, -.90265800E+03, 0.48360800E+03, 0.39641900E+03, 0.45143200E+03, 0.13395400E+03, 0.58454100E+02, 0.14424300E+03, -.70059700E+02, 0.34862200E+03, 0.51341200E+02, 0.11540900E+04, -.84566400E+02, -.53629500E+01, 0.42253200E+03, 0.42565600E+02, -.28352300E+03, 0.25640200E+03, -.21128600E+03, 0.57405400E+02, 0.12658000E+02, 0.22430200E+03, 0.38367400E+03, -.52872000E+04, 0.25175100E+04, 0.10750500E+04, 0.26454100E+04, -.55381900E+02, 0.31168900E+03, 0.40718800E+03, -.83543500E+03, 0.12103000E+04, 0.14950700E+03, 0.54256900E+04, 0.14271700E+04, -.62587300E+03, -.11103000E+04, -.71396300E+03, -.13472200E+02, -.31412100E+03, -.17552600E+03, -.32351000E+03, -.44395900E+03, -.25657500E+03, -.20426300E+04, -.23931800E+04, 0.11766800E+04, -.72276100E+03, 0.11964900E+04, -.79929000E+03, -.68501000E+03, 0.81853800E+03, -.10054000E+03, 0.93842600E+03, -.53859800E+03, -.59157400E+02, 0.24935500E+04, -.12472300E+04, -.36968400E+03, -.12471800E+04, 0.27156600E+03, 0.77384600E+03, -.69224800E+03, 0.13340000E+03, -.99262400E+03, 0.77289300E+03, -.86818400E+03, 0.15197100E+03, 0.11874000E+02, 0.17318400E+02, -.75683000E+02, -.14508000E+02, 0.21915900E+02, -.21993900E+03, -.21418900E+03, 0.22154400E+03, -.10121500E+04, -.45994400E+03, 0.14339700E+04, -.61054100E+03, -.25058600E+02, -.71686700E+03, -.72923900E+02, -.26700700E+03, -.25202100E+03, 0.16126800E+03, -.97733600E+02, -.11611600E+04, -.10352000E+04, 0.29321300E+04, -.14426100E+04, -.91053000E+03, -.14662600E+04, -.40522500E+03, -.18878400E+03, -.42106900E+03, -.70928300E+02, -.10415800E+04, -.20216200E+03, -.32966600E+04, 0.25075600E+03, -.97247500E+02, -.15519800E+03, -.12523500E+03, 0.20033100E+03, -.97176000E+02, 0.42451100E+02, 0.12660200E+03, 0.28097800E+02, -.95734800E+02, 0.11091800E+03, 0.70356200E+04, -.34717400E+04, -.13957200E+04, -.35173400E+04, -.26272800E+03, 0.15841800E+04, -.16159000E+04, 0.98007900E+03, -.26186400E+04, 0.15659200E+04, -.33913300E+04, -.24536400E+03, 0.15297500E+03, 0.10869700E+04, 0.12232500E+03, -.28284200E+03, 0.33384700E+03, -.27171200E+03, -.19548700E+03, -.21232800E+03, 0.47891400E+03, 0.57543200E+03, 0.17678500E+04, -.83197600E+03, -.79631200E+03, -.88274500E+03, -.18792100E+03, 0.52723100E+03, -.79765900E+03, -.51450700E+03, -.57466500E+03, 0.68910100E+03, -.65689300E+03, 0.34121400E+04, -.15913200E+04, -.37835800E+03, -.17072100E+04, -.68622200E+03, 0.83057700E+03, -.42385000E+03, 0.99306400E+03, -.79807000E+03, 0.84501900E+03, -.34857600E+04, -.85579900E+03, 0.43321700E+03, 0.67122800E+03, 0.42798100E+03, 0.34066200E+03, 0.45443300E+03, -.17524300E+03, -.37167400E+03, 0.13286900E+02, 0.29377200E+03, 0.12950400E+04, -.35663000E+03, 0.16736700E+03, 0.17720700E+03, 0.17877400E+03, -.18391600E+03, -.62996400E+00, -.36265500E+00, -.21030100E+03, -.12022100E+03, 0.62858400E+01, -.29391000E+03, -.60148300E-01, 0.30336800E+03, 0.27561200E+03, -.82329900E+02, -.76116700E+02, -.33031400E+03, 0.16168700E+02, -.27510600E+03, -.34970600E+02, -.22471000E+03, -.12354000E+03, 0.25064400E+03, -.49945800E+02, -.26181700E+03, 0.32750600E+03, -.12108900E+03, -.25418200E+03, 0.22332400E+03, -.46286400E+02, -.22224100E+02, -.41268300E+03, 0.32176600E+03, -.28620400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.73146100E+00, 0.23730600E+00, 0.44398900E+00, -.42435300E+00, -.59068300E+00, 0.85853600E-01, 0.15195900E+00, 0.28903800E+00, 0.63302200E+00, -.41735900E+00, 0.28216900E-01, 0.41637300E+00, -.34610900E+00, -.58023700E-01, 0.11152700E+00, -.55755500E+00, -.11934600E+01, -.61530900E+00, -.35651300E-01, 0.11909300E+00, -.12366500E+01, -.46023500E-01, -.16351400E+01, -.62456900E+00, 0.98144000E+00, -.41685100E-01, 0.12789100E+01, 0.15480600E+00, -.18830200E+00, 0.26497400E+00, 0.37692800E-01, -.93304000E-01, -.32520900E-01, 0.28162000E-01, 0.77080700E-01, 0.10338800E+00, 0.26367900E-02, -.42811600E+00, -.60521700E+00, -.21086600E+00, -.24779600E+00, 0.23818200E+00, 0.92310700E+00, -.49819400E+04, -.57160100E+04, 0.29211400E+04, -.21668000E+03, 0.28631500E+04, -.91837100E+02, 0.13690800E+04, 0.25408400E+03, -.97257900E+03, 0.21422500E+04, 0.11883400E+04, 0.86070100E+04, -.97190900E+04, 0.44842700E+04, -.35359600E+04, 0.48748400E+04, -.69752900E+04, -.10627500E+05, 0.64279900E+04, 0.69435000E+03, 0.33936300E+04, -.80066100E+04, 0.66952200E+04, -.50329300E+04, 0.26292200E+04, 0.30647700E+04, 0.25192600E+04, 0.63636700E+03, -.50015300E+03, 0.20516600E+04, 0.11383500E+04, 0.17209200E+04, -.63560800E+03, -.54011600E+04, -.80933400E+04, 0.38768400E+04, 0.34856400E+04, 0.40542800E+04, 0.24744500E+04, -.21129200E+04, 0.41997200E+04, 0.27619200E+04, 0.64016700E+04, -.21658600E+04, 0.26789500E+04, -.64533100E+04, 0.30380700E+04, -.41142400E+04, 0.32735800E+04, 0.12354100E+04, -.42824600E+04, 0.47437200E+04, 0.88073000E+03, 0.39329600E+04, -.29986300E+04, -.21474300E+05, 0.13223800E+05, -.63593900E+04, -.74910000E+04, -.66230600E+04, -.36357500E+04, 0.15211100E+04, -.60140000E+04, -.27605800E+04, -.71480400E+04, 0.20163100E+04, 0.91677300E+04, -.42259800E+04, 0.19457000E+04, -.69181700E+04, 0.21104500E+04, -.10437600E+04, -.29094800E+04, 0.11399100E+04, -.11054200E+04, 0.26415100E+04, -.21797500E+04, 0.17074900E+05, 0.19222600E+03, -.18454100E+03, 0.49860500E+04, -.10974600E+03, 0.85409000E+03, 0.29593600E+04, 0.31270700E+03, 0.28529900E+03, 0.78026700E+02, 0.25499800E+04, -.36844000E+04, 0.17465200E+04, -.68321400E+03, -.98472800E+02, -.86463400E+03, 0.43232100E+03, 0.21505600E+04, -.11885000E+04, -.51537800E+03, -.39473100E+04, 0.23932900E+04, 0.59188100E+04, -.21307000E+04, 0.12590800E+04, 0.21434500E+03, 0.10692600E+04, 0.22022900E+03, 0.30815700E+04, -.11134500E+04, -.14591900E+04, -.27340100E+04, 0.31677600E+04, 0.87379400E+04, -.26301100E+04, 0.12435300E+04, -.72095500E+03, 0.13092300E+04, -.58285400E+03, -.14600700E+04, -.12976900E+03, 0.79988800E+03, 0.12104700E+04, -.93466000E+03, 0.19448300E+05, 0.10259800E+04, -.42545000E+03, 0.13947500E+04, -.51008900E+03, -.15515300E+04, 0.37411800E+03, -.10832100E+04, -.14371100E+04, -.17715500E+04, 0.19130400E+03, -.30045000E+04, 0.75732500E+04, -.37897200E+04, 0.14392200E+05, -.37828000E+04, 0.72996700E+04, 0.84361400E+04, -.10245500E+04, 0.58224000E+04, 0.40728500E+04, 0.64174400E+04, 0.36961400E+04, 0.53326700E+04, -.26245700E+04, 0.32077800E+04, -.26618200E+04, 0.43484100E+04, 0.82446300E+03, 0.12965700E+04, 0.62514700E+04, 0.38548500E+04, -.52148800E+03, -.44859900E+04, -.10579100E+05, 0.54992600E+04, -.91507100E+03, 0.53233400E+04, -.14300000E+04, -.44390900E+04, 0.26877900E+04, -.14430200E+04, 0.12656800E+04, -.28878000E+04, 0.53043200E+04, 0.10195600E+05, -.48943300E+04, 0.37954800E+04, -.51273900E+04, 0.71743000E+04, 0.42212800E+04, -.25161300E+04, 0.49436500E+04, 0.13778300E+04, 0.34597400E+04, 0.17583000E+05, -.56319300E+03, 0.44420500E+03, -.15165200E+04, 0.28453200E+03, -.50684200E+03, -.19243900E+04, 0.31143800E+04, 0.38512900E+04, 0.17655900E+04, -.18792600E+04, -.10616500E+05, 0.14231300E+04, -.73243300E+03, -.42695500E+04, -.70068500E+03, -.93663900E+03, -.14664400E+04, 0.12322000E+04, 0.19288100E+04, 0.79229300E+03, -.12418300E+04, 0.34299500E+04, -.15857500E+04, -.15064100E+04, -.15316500E+04, 0.76491600E+03, 0.12931600E+03, 0.79546400E+03, -.86273800E+03, 0.14151200E+04, 0.18692200E+04, 0.85889300E+03, 0.30305900E+03, 0.39019000E+03, -.15792400E+03, 0.65397400E+03, -.94469900E+03, -.16239400E+03, 0.31758600E+04, -.57363400E+03, 0.71849400E+03, -.27523800E+02, 0.13451200E+04, -.14203300E+04, 0.15401000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21412300E+01, 0.34389000E+01, 0.70972600E+00, 0.13436000E+01, -.25870700E-01, -.12364000E+01, 0.65092900E+00, 0.14596200E+01, -.32957000E+02, -.44306500E-01, -.98892900E+00, -.25520700E+01, -.25022700E+00, 0.18231400E+00, -.13816400E+01, -.33709000E+01, -.47657400E+01, -.31995800E+01, -.38335600E+00, 0.31241100E+01, -.95636900E+00, 0.69564000E+00, -.30334800E+01, 0.13132300E+01, 0.75466600E+00, 0.97975800E-02, 0.23401900E+01, 0.23526400E+00, -.28865000E-01, 0.16318000E+00, -.90309700E+00, -.31969300E+00, 0.57216400E+00, -.14646800E+01, -.99464200E+00, 0.21522000E+00, -.17895100E-01, -.49307400E+00, 0.97279700E+00, -.41507600E+00, 0.25479600E+01, 0.63981900E+00, 0.57976700E+00, 0.22773100E+01, 0.38802100E+05, -.19899200E+05, 0.13607100E+05, -.19409300E+05, -.19813700E+04, -.84078100E+04, -.28509400E+04, 0.49150000E+04, -.15044500E+05, -.63739200E+04, -.25807800E+05, 0.26085700E+05, -.10937700E+05, 0.13982500E+05, -.13074100E+05, 0.20935100E+05, 0.35994800E+05, -.14562800E+05, 0.10473000E+05, -.53858100E+04, 0.26936200E+05, -.17614200E+05, 0.15740000E+05, -.84408700E+04, -.13126800E+05, -.78757800E+04, -.24034900E+04, 0.29551200E+04, -.73854000E+04, -.58646600E+04, -.52245400E+04, 0.28007700E+04, 0.17250000E+05, 0.26406800E+05, -.12471400E+05, -.91883100E+04, -.13219000E+05, -.10075300E+05, 0.61019700E+04, -.14720200E+05, -.10086800E+05, -.19494800E+05, 0.65385800E+04, -.10365800E+05, 0.20757000E+05, -.95036000E+04, -.13330500E+04, -.10471000E+05, 0.41911000E+04, 0.16901900E+05, -.13680200E+05, 0.64798100E+04, -.80035100E+04, 0.12367000E+05, 0.44375800E+05, -.44753700E+05, 0.21348300E+05, 0.27014000E+05, 0.22401500E+05, 0.14475900E+05, -.39451700E+04, 0.21208000E+05, 0.11389700E+05, 0.20776300E+05, -.61345400E+04, -.20715900E+05, 0.34441600E+05, -.16495700E+05, 0.42296200E+05, -.17215900E+05, 0.39990300E+04, 0.15963500E+05, -.11304000E+05, 0.28696400E+04, -.18121200E+05, 0.13078400E+05, -.60570900E+05, 0.91658400E+04, -.37051100E+04, -.14247400E+05, -.45498000E+04, -.12903500E+05, -.15295800E+05, -.23478300E+04, -.70596300E+03, -.38073100E+04, -.12882300E+05, 0.14036300E+05, -.64678900E+04, 0.18041700E+04, -.30129500E+03, 0.32154500E+04, -.87575300E+03, -.71049300E+04, 0.51250000E+04, 0.45699200E+04, 0.12625800E+05, -.71340900E+04, 0.32460400E+04, 0.20884800E+05, -.11922400E+05, 0.10081900E+05, -.10451900E+05, -.17250100E+04, -.13977600E+05, 0.38937700E+04, 0.93799300E+04, 0.22356300E+04, -.12337600E+05, -.15822500E+05, 0.11941400E+05, -.57718600E+04, 0.14901600E+05, -.59574400E+04, 0.75615300E+03, 0.21919300E+04, 0.10265700E+04, -.41158200E+04, -.47370800E+04, 0.78514100E+03, -.59574100E+05, 0.19418200E+04, -.13728100E+04, -.91928100E+04, -.97500700E+03, 0.33600400E+04, -.57998900E+03, 0.25242000E+04, 0.36825000E+04, 0.39936000E+04, -.58011800E+03, 0.13198600E+05, -.42953900E+05, 0.22296600E+05, -.41272000E+05, 0.21486100E+05, -.47219900E+05, -.52430900E+05, 0.11016500E+05, -.34640300E+05, -.75043000E+04, -.43267400E+05, 0.29671000E+04, -.19358000E+05, 0.94303500E+04, -.14585900E+05, 0.96681600E+04, -.17536900E+05, -.70774100E+04, -.33476700E+04, -.25261200E+05, -.11151000E+05, -.20642800E+04, 0.10639800E+05, 0.34599800E+05, -.18654800E+05, 0.77829800E+04, -.17373100E+05, 0.59496500E+04, 0.15528000E+05, -.75739800E+04, 0.99539100E+04, -.32818400E+04, 0.10628200E+05, -.22982400E+05, -.57071400E+05, 0.27667300E+05, -.75870600E+03, 0.28594300E+05, -.33662800E+05, -.27753100E+05, 0.12109400E+05, -.31539900E+05, -.13454300E+04, -.23369400E+05, -.42246000E+05, 0.15023000E+05, -.80611300E+04, -.15168900E+04, -.75189300E+04, -.94030700E+03, 0.56031900E+04, -.11976500E+05, -.90911200E+04, -.82423800E+04, 0.54247500E+04, 0.22632300E+05, 0.81626500E+04, -.39586500E+04, 0.15731100E+05, -.41007000E+04, 0.21352800E+04, 0.48404100E+04, -.61056700E+04, -.36811700E+04, -.49116300E+04, 0.42329800E+04, -.17227800E+05, 0.46392700E+04, 0.46669600E+04, 0.43929000E+04, -.21934200E+04, -.95998900E+03, -.45494000E+04, 0.29210100E+04, -.39687500E+04, -.48719100E+04, -.27269600E+04, -.77637100E+03, 0.86663100E+03, -.37864900E+04, -.85108400E+03, 0.20739000E+04, 0.11067000E+04, -.75753900E+04, 0.54283700E+04, -.31769100E+04, -.71777300E+02, -.85367900E+04, 0.39627700E+04, -.51013900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30043300E+01, -.15889300E+01, 0.83389300E+00, -.54238700E+00, -.11021300E+01, -.33882000E+01, 0.71765400E+00, -.77468100E+00, -.37518700E+02, -.20019100E+01, 0.17145100E+00, -.78494000E+00, -.10662400E+01, 0.45154700E+00, -.55921600E+00, -.85962100E+00, -.53501200E+01, -.68394700E+00, 0.33313500E+00, 0.39150400E+01, -.81267300E+00, -.30863700E+00, 0.83036200E+00, -.20551500E+01, 0.28868700E+00, -.10165600E+00, 0.94522200E+00, 0.86649400E-01, 0.13893800E+00, 0.37342200E+00, 0.10581900E+01, -.49839400E-01, 0.28158700E+00, -.14023500E+01, 0.82309700E+00, -.39267600E+00, -.33032300E-02, -.13480500E+01, 0.48128700E+00, 0.22535000E+01, 0.77013500E+00, 0.20339000E+00, 0.18618900E+01, 0.15330200E+01, -.97649100E-01, 0.10259000E+04, -.10033400E+05, -.20123300E+01, 0.70769200E+03, 0.10498600E+04, -.11413600E+04, -.28250900E+04, -.19348300E+03, 0.90309800E+03, -.30787900E+04, 0.54895700E+04, -.49855900E+04, 0.32508700E+04, -.27523100E+04, 0.73284400E+04, 0.15075200E+05, -.42938200E+04, 0.68881500E+04, -.13797900E+04, 0.11827100E+05, -.48156100E+04, -.45607500E+04, 0.28471300E+04, -.72717100E+04, 0.22789900E+04, 0.24361200E+03, 0.19118500E+04, -.31400700E+04, -.70475600E+04, 0.90933500E+03, 0.17813300E+04, 0.12949500E+05, 0.71121500E+04, -.42826600E+04, -.12980500E+05, -.35598300E+04, -.98749200E+03, 0.46831700E+04, -.66545100E+04, -.63543900E+04, -.83034600E+04, 0.53936300E+04, -.21712500E+04, 0.29030800E+05, -.16195900E+05, 0.21550900E+05, -.14537700E+05, -.22244600E+04, 0.18504400E+05, -.20536800E+05, -.98043300E+04, -.26768000E+05, 0.19113000E+05, 0.10493900E+05, -.12580600E+05, 0.75496300E+04, 0.22383000E+05, 0.62961900E+04, 0.27322800E+04, -.68532400E+04, 0.13378800E+05, 0.12413600E+05, 0.11136600E+05, -.86904200E+04, -.14776900E+05, -.17211800E+04, 0.44294000E+03, 0.71198200E+04, 0.86177900E+03, 0.36750900E+04, 0.11347600E+04, 0.29700600E+04, 0.70462000E+04, 0.19612600E+04, -.59799400E+03, -.19142400E+05, -.35817000E+05, 0.17497000E+05, -.60676100E+04, 0.17916400E+05, 0.26182100E+04, -.59564900E+04, 0.58629900E+04, 0.76680300E+03, 0.12497200E+05, -.62093900E+04, 0.25475600E+05, 0.76252400E+04, -.11048200E+04, -.54056500E+03, -.38171000E+04, -.90287200E+03, -.20183700E+04, 0.12505400E+04, 0.46100400E+04, 0.31700900E+04, -.23806900E+04, -.48925300E+04, 0.48143600E+04, 0.46085200E+03, -.68948400E+04, -.24094700E+04, -.43364200E+03, -.17111800E+04, 0.14884400E+04, 0.36958600E+04, 0.46498600E+04, -.21273300E+04, -.55892400E+04, -.51809900E+04, 0.28069900E+04, 0.15366000E+04, 0.25936700E+04, 0.22979800E+04, -.29892400E+04, 0.67247500E+04, 0.19220200E+04, 0.74245600E+04, -.46056100E+04, -.23278300E+05, 0.21720900E+04, -.66187900E+03, -.40279400E+04, -.10870600E+04, -.70683700E+03, -.96178000E+03, 0.13823200E+04, 0.14684200E+04, 0.38048900E+04, -.14815300E+04, 0.59655200E+04, -.64267100E+05, 0.32045800E+05, -.25052700E+05, 0.32135500E+05, 0.64710500E+04, -.14633100E+05, 0.82171500E+04, -.19198500E+05, 0.13417900E+05, -.14348700E+05, 0.18631800E+05, -.66360800E+04, 0.37904600E+04, -.12558100E+05, 0.33249300E+04, -.58628300E+03, 0.20883000E+04, -.39086500E+04, -.12834400E+05, -.73014900E+04, 0.34460800E+04, 0.31189000E+04, 0.14595500E+05, -.59406400E+04, -.35920600E+03, -.73153000E+04, 0.39861500E+03, 0.41901100E+04, -.17994000E+04, 0.45027000E+04, -.31948100E+03, 0.27921600E+04, -.11198000E+05, -.33826700E+05, 0.18497000E+05, -.19773400E+05, 0.16927500E+05, 0.65187700E+03, -.16378000E+05, 0.11653100E+05, -.67023400E+04, 0.10835600E+05, -.15209500E+05, -.18438000E+05, -.97603300E+04, 0.49847800E+04, 0.47089700E+04, 0.48784000E+04, 0.47716500E+03, 0.60127300E+04, -.62851100E+04, -.11255400E+05, -.20138600E+04, 0.62642200E+04, 0.19177000E+05, 0.18282800E+04, -.10964800E+04, 0.23992300E+04, -.91886100E+03, 0.23848200E+04, 0.28683300E+04, -.25971000E+04, -.10090900E+04, -.22203900E+04, 0.22827700E+04, -.57007500E+04, 0.13920200E+04, 0.44641400E+04, 0.43139300E+04, -.21553600E+03, 0.72583700E+03, 0.12546200E+04, 0.12620700E+04, -.40942300E+04, -.20573100E+04, -.91225900E+03, -.56839700E+03, -.15088100E+04, 0.38352500E+04, 0.45568700E+03, -.42082900E+03, 0.11675100E+04, -.33983300E+04, -.36652700E+04, -.92655000E+03, -.76398100E+03, 0.29191200E+04, 0.38541200E+04, -.45104200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.74002300E+00, 0.14344000E+01, 0.15258000E+00, 0.10628500E+01, 0.55982200E+00, -.57247600E+00, 0.29074300E+00, 0.17699300E+01, 0.49157300E+01, 0.46967200E+00, -.31425800E+00, -.15090900E+00, -.11879000E+00, 0.33800400E-01, 0.72762800E+00, -.25926100E+00, -.11736500E+00, 0.17128400E+01, 0.32502700E+00, -.32782100E+00, -.42002200E+00, -.88132300E-02, -.39078900E+00, 0.19250100E+00, -.25400700E+00, 0.35291500E-01, -.60244100E+00, -.70586800E-02, -.15673800E+00, -.47669400E+00, -.23527800E+00, -.28113000E+00, 0.36711700E+00, -.15707600E+00, -.51488500E+00, -.21095800E-01, -.63363900E-02, -.17639800E+00, -.79405500E-01, -.24413600E+00, 0.18327800E+00, 0.25408000E+00, 0.61226200E+00, 0.34339200E+00, 0.23609500E+00, 0.98800900E-01, -.75024200E+04, -.27811200E+01, -.65649400E+03, -.44566000E+03, 0.40777800E+03, 0.11974400E+04, 0.97608300E+03, -.37662400E+03, 0.72688500E+03, -.34569800E+03, 0.33890100E+03, -.22671600E+04, 0.16721200E+03, 0.59294800E+03, 0.15026800E+04, -.30746800E+04, -.70003300E+04, -.10394400E+04, 0.10628400E+04, 0.15502800E+04, -.58165100E+04, 0.28304400E+04, 0.21018900E+04, 0.29072500E+04, 0.51476700E+03, -.11198300E+04, 0.23598100E+04, 0.18445000E+04, 0.25295300E+04, -.76484400E+03, 0.11597200E+04, -.29967400E+04, 0.16655400E+04, -.42023600E+04, 0.14955900E+04, 0.89841800E+03, -.56282400E+03, 0.17654700E+04, 0.17568100E+04, 0.30376900E+04, -.89195800E+03, -.40110500E+03, -.39366700E+04, 0.23502300E+04, 0.41584200E+04, 0.19497500E+04, 0.19096800E+03, -.26267000E+04, 0.42585100E+04, 0.20169400E+04, 0.56625600E+04, -.23350500E+04, -.59185000E+04, 0.12626100E+05, -.66463800E+04, 0.36942300E+03, -.63096600E+04, -.22488300E+04, 0.41559200E+03, -.49831100E+04, -.26878500E+04, -.62171300E+04, 0.85411500E+03, -.14866400E+04, -.10396000E+05, 0.52711800E+04, -.12268900E+05, 0.51990600E+04, -.29727000E+04, -.38473300E+04, 0.28395200E+04, -.19653200E+04, 0.45458600E+04, -.34429200E+04, 0.79956800E+04, -.63044400E+04, 0.29373000E+04, -.25227800E+04, 0.31551700E+04, 0.35944800E+04, 0.18240200E+04, 0.10239400E+04, -.15773400E+04, 0.28092900E+04, 0.22065600E+04, 0.37847800E+04, 0.42514200E+04, -.21977000E+04, -.70722200E+03, -.21285700E+04, -.27011200E+03, 0.39515100E+03, -.16479300E+04, -.39023000E+03, -.26510200E+04, 0.73050900E+03, -.18040000E+04, 0.50017300E+04, -.25312000E+04, -.59225800E+04, -.25017300E+04, -.81346800E+03, 0.16954700E+03, -.16243500E+04, -.84665500E+02, -.25795900E+04, 0.49162100E+03, -.12597500E+04, 0.31140100E+04, -.15469800E+04, -.47065000E+04, -.15553900E+04, -.12218300E+04, -.96008100E+03, -.10418500E+04, 0.90283600E+03, -.26780000E+04, -.10938400E+04, 0.16339100E+04, -.39421700E+04, 0.18855800E+04, 0.41140600E+04, 0.19693000E+04, 0.82865900E+03, 0.64811800E+03, -.23442600E+03, -.11005400E+04, -.64223700E+03, 0.84177400E+03, 0.27585500E+04, 0.14971100E+04, -.13024300E+04, -.83866400E+04, -.75657800E+03, 0.59163100E+04, 0.65777100E+04, 0.50231500E+03, 0.77661500E+04, 0.36876300E+04, 0.63664500E+04, 0.86678200E+03, 0.95165000E+03, -.55683200E+03, -.84779300E+03, -.47835600E+03, 0.15379700E+04, 0.41919500E+03, 0.15750600E+04, 0.57213000E+04, 0.30678400E+04, -.35390700E+03, -.20315400E+04, -.60551100E+03, 0.33198900E+03, -.14200500E+04, 0.29196700E+03, -.24966100E+03, -.13955800E+04, -.53187500E+03, -.17422700E+04, -.12189800E+04, -.81535100E+03, 0.47546400E+03, 0.31777100E+04, -.19900000E+04, -.88915800E+04, -.15772500E+04, 0.56484400E+03, 0.33047500E+04, -.52801000E+03, 0.51794600E+04, 0.12415900E+04, 0.27418800E+04, 0.17448400E+04, -.13481100E+05, 0.66290500E+04, 0.29251400E+04, 0.67400300E+04, 0.33782900E+04, -.11080800E+04, 0.43372800E+04, 0.11371600E+04, 0.57823000E+04, -.91616200E+03, 0.26241700E+04, -.64180600E+04, 0.32300400E+04, -.18955900E+04, 0.32039100E+04, 0.42121700E+03, -.59511600E+03, 0.15459900E+04, -.61392800E+03, 0.23646400E+04, -.51007000E+03, 0.28500600E+04, -.48754800E+02, -.12901100E+03, -.22149800E+02, 0.11579000E+03, -.14840500E+03, 0.16156000E+03, -.75943000E+02, -.68402600E+01, 0.44739000E+03, 0.19521700E+02, -.98300700E+02, 0.11257600E+04, 0.14848500E+04, -.11335700E+03, 0.13035000E+03, -.54997700E+03, -.86815200E+03, -.14171200E+04, 0.72187800E+03, 0.11562800E+03, 0.16795000E+04, 0.21142400E+03, 0.24928600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.27032200E+01, 0.33005500E+01, 0.39853800E+00, 0.98823000E+00, -.10358300E+01, -.11068000E+01, 0.58017900E+00, 0.48660700E+00, -.36182000E+02, 0.63469300E+00, 0.11524700E+00, -.11458500E+01, -.49415800E+00, -.97481400E-02, -.16063900E+01, -.44358300E+01, -.51864400E+01, -.17643500E+01, -.12639700E-01, 0.48603400E+01, -.18821600E+01, 0.13907800E+00, -.29803700E+01, 0.11978900E+01, -.47248000E+00, 0.92907800E-01, 0.21478300E+01, 0.58668800E+00, -.26468000E+00, -.29930700E+00, -.46612600E+00, -.53778500E+00, 0.28609400E+00, -.98596500E+00, -.67520300E+00, 0.29068000E+00, 0.40545600E-02, 0.31742400E-01, 0.23396800E+01, 0.11507500E+00, 0.11455600E+01, 0.57558900E+00, 0.80762100E+00, 0.65211000E+00, -.27336300E+00, -.18001400E+00, -.24157300E+01, 0.30039300E+02, -.13770200E+04, -.53463700E+04, 0.19155800E+04, 0.91370500E+03, -.17129600E+04, -.36567200E+04, -.32317500E+04, 0.48270500E+04, -.15766900E+04, 0.18603200E+04, -.24141000E+04, 0.51111100E+04, 0.13292600E+05, -.59906100E+04, -.14956600E+04, -.89869300E+03, 0.96573900E+04, 0.17649200E+03, -.86151100E+04, 0.40669500E+04, -.64791300E+03, 0.43074400E+04, -.24767900E+03, -.61878000E+03, 0.23647200E+04, -.42139700E+02, 0.33553600E+04, -.33877300E+03, 0.86129500E+04, -.90046300E+03, 0.75193200E+03, -.87363000E+04, 0.44994200E+03, -.16783600E+04, 0.16126600E+04, -.68328400E+03, -.20058700E+03, -.14511600E+04, 0.15368300E+04, -.19321500E+04, -.12663000E+05, 0.67032600E+04, 0.91570900E+03, 0.63301800E+04, 0.86036600E+04, 0.50169500E+04, 0.32756600E+04, 0.57066500E+04, 0.96164100E+04, 0.46354400E+04, 0.61986500E+04, 0.98843800E+04, -.53634400E+04, 0.10659700E+05, -.49416000E+04, 0.66952100E+03, -.24134600E+04, -.21161600E+04, -.29531300E+03, -.32014600E+04, -.26589000E+04, -.11099600E+05, -.15206300E+05, 0.78745800E+04, -.32198800E+04, 0.76032400E+04, -.46967800E+04, -.41088400E+04, 0.37396700E+04, -.28959200E+04, 0.55954400E+04, -.38557400E+04, -.48093900E+04, -.76805400E+04, 0.43024700E+04, -.84724900E+04, 0.38411000E+04, -.43105100E+04, -.37574900E+04, 0.11772800E+04, -.28485000E+04, 0.62665100E+03, -.15381600E+04, 0.17617700E+05, 0.32339600E+04, -.18036400E+04, -.13405600E+04, -.16177800E+04, -.95275400E+03, -.33484300E+04, 0.50631900E+03, 0.25359000E+04, 0.16026300E+04, -.23109200E+04, -.35900100E+04, 0.53522000E+04, -.27657500E+04, -.13649600E+04, -.26765900E+04, -.21102700E+04, -.75676200E+04, 0.18703200E+04, 0.38938000E+04, 0.66933800E+03, -.54854600E+04, -.61746700E+04, 0.10207500E+05, -.50520700E+04, 0.33204000E+04, -.51033900E+04, -.26929900E+04, -.32679600E+04, 0.10839800E+03, 0.90084000E+02, -.24047200E+04, -.41269300E+04, -.20365700E+05, 0.65316900E+03, -.48980200E+03, 0.18820300E+04, -.32647600E+03, 0.38503400E+03, 0.56016000E+03, -.87819400E+03, -.14192000E+04, -.23444900E+04, 0.44210200E+03, 0.96058200E+04, -.37373500E+05, 0.19059400E+05, -.16870200E+05, 0.18688500E+05, -.11124900E+05, -.10834600E+05, 0.95293300E+04, -.76593200E+04, 0.33343000E+04, -.63690100E+04, 0.14759100E+05, -.21908000E+04, 0.96968000E+03, -.77036900E+04, 0.10827000E+04, -.10513800E+04, 0.61485400E+03, 0.71857600E+03, -.28062200E+03, -.18774400E+04, 0.74495500E+03, -.43646900E+04, 0.86690500E+04, -.48344900E+04, 0.12196400E+04, -.43359700E+04, -.92906600E+02, 0.29860100E+03, -.14903300E+04, 0.23743200E+04, -.51227200E+03, 0.28118900E+03, -.66107100E+04, -.32673700E+05, 0.15970700E+05, -.75635300E+04, 0.16337700E+05, -.10512800E+05, -.85440500E+04, 0.77928100E+04, -.59598400E+04, 0.65453300E+04, -.66042100E+04, -.86055300E+04, -.16522900E+05, 0.80482700E+04, 0.18728000E+04, 0.82611600E+04, 0.52526400E+04, 0.21770400E+04, 0.27428800E+04, -.18764900E+01, 0.63604500E+04, 0.19937700E+04, 0.12293800E+05, -.59173100E+04, 0.30075800E+04, 0.44455200E+03, 0.29584200E+04, 0.10051700E+04, 0.43346500E+03, 0.89676800E+03, -.64965700E+03, 0.29474700E+04, 0.44215400E+03, -.13278700E+04, 0.98472900E+03, 0.18102400E+04, 0.16930000E+04, -.16274500E+03, 0.14838800E+03, -.10786100E+04, 0.74218400E+03, -.16615700E+04, -.40665400E+03, -.25748300E+03, 0.99329200E+02, 0.16474600E+04, -.11322000E+04, 0.12188400E+03, 0.57327300E+03, 0.24252000E+03, -.15524800E+04, -.63231000E+01, -.28802900E+03, -.41833100E+03, 0.10051100E+02, 0.15195400E+04, -.17888500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.70611800E+00, 0.46405000E+00, 0.58050900E-01, 0.21871500E+00, -.15135700E+00, 0.21912400E+00, 0.11023600E+00, -.33961100E+00, 0.28454200E+01, 0.81762400E+00, -.21505900E-01, -.32479600E+00, -.57730900E+00, 0.71225900E-01, 0.12638400E+00, -.14556600E+01, -.18076800E+01, -.10130200E+00, 0.11391200E+00, 0.25395700E+00, 0.13267200E+00, 0.22735600E+00, 0.71805100E-02, -.44135600E+00, -.26612500E+00, -.11836900E-01, -.13357600E+00, 0.10862400E+00, -.49362000E+00, -.29665600E-01, -.24018800E+00, -.24109300E-02, 0.34446000E-02, 0.89079600E-01, 0.14195500E+00, 0.45668600E-01, 0.59393600E-02, 0.29948900E+00, -.38024900E+00, -.24667100E+00, -.39042700E+00, 0.14413600E+00, 0.10767300E+01, 0.64822500E+00, -.38028700E-01, 0.91216300E-01, -.32533700E+00, -.93203700E-01, -.10782600E+04, -.25795900E+04, 0.11217200E+04, 0.56721000E+02, -.70398300E+03, -.18960500E+04, -.73449200E+03, 0.44048600E+04, -.19513200E+04, 0.42844100E+04, -.22092700E+04, 0.48066400E+04, 0.73269700E+04, -.24156900E+04, 0.10751200E+04, -.11234400E+04, 0.54410400E+04, -.25004800E+04, 0.26426900E+03, -.21667500E+03, -.16673100E+04, -.13337100E+03, -.27690200E+03, 0.33394600E+03, 0.18656100E+03, 0.39731500E+03, -.25055800E+03, 0.29892200E+03, 0.18776400E+04, -.77858900E+03, 0.51602800E+03, -.57849600E+04, 0.38590800E+03, -.35044000E+03, 0.47834100E+03, 0.38501800E+01, -.89690800E+03, -.12123400E+04, 0.40800700E+03, -.32832900E+03, 0.13080700E+05, -.62765200E+04, -.56462100E+04, -.65620300E+04, 0.23105700E+04, 0.28851100E+04, -.31701500E+04, 0.23032000E+04, -.12150400E+04, 0.23102000E+04, -.27499800E+04, 0.25142500E+04, -.14678400E+04, 0.85450700E+04, -.12525600E+04, 0.34055400E+03, -.85502000E+03, -.20515300E+03, 0.49499100E+03, -.59238700E+03, -.89811000E+03, -.37941700E+04, -.18068900E+04, 0.97405400E+03, 0.17554500E+04, 0.90463300E+03, -.68717400E+03, -.17133000E+03, -.31624000E+03, -.21184000E+04, -.30230200E+03, 0.69111500E+02, -.23050300E+04, -.15179200E+05, 0.76493400E+04, -.34626600E+04, 0.75945200E+04, -.25921400E+04, -.54662400E+04, 0.51112000E+04, -.81304500E+03, 0.56200500E+04, -.42067700E+04, 0.96378700E+04, 0.39061100E+03, -.37144800E+03, 0.98948500E+03, -.19899800E+03, -.55943500E+03, -.15106400E+04, 0.99167100E+03, 0.11277300E+04, 0.59480000E+03, -.12069400E+04, -.98330800E+03, 0.73870900E+03, -.45646200E+03, 0.12082500E+04, -.37078700E+03, -.12597500E+04, -.32620300E+04, 0.16797100E+04, 0.12863800E+04, 0.61120600E+02, -.24946700E+04, -.16070200E+04, 0.25272900E+03, -.12836800E+03, 0.28306800E+04, -.12405900E+03, 0.68080700E+02, -.50940700E+03, -.19250200E+03, -.28507600E+03, 0.24517200E+03, -.53189700E+03, -.44558900E+04, -.21993000E+04, 0.10267200E+04, 0.23007000E+04, 0.10979600E+04, 0.39997000E+03, 0.51167900E+03, 0.48734200E+03, 0.35258500E+03, 0.16016300E+03, 0.39632700E+03, 0.29023500E+04, -.36064800E+05, 0.17924800E+05, -.14340600E+05, 0.18027000E+05, -.73227600E+04, -.13266200E+05, 0.10073400E+05, -.71395700E+04, 0.90503300E+04, -.10113300E+05, 0.16999700E+05, -.18945300E+04, 0.87470400E+03, -.84528100E+04, 0.94351100E+03, -.12860500E+04, -.12057100E+04, 0.98705300E+03, -.80082900E+03, -.90133600E+03, -.81432800E+03, 0.45810900E+03, 0.42856300E+04, -.22490500E+04, 0.37319200E+04, -.21569700E+04, 0.47887600E+03, 0.71250100E+03, -.56091100E+03, 0.12392200E+04, -.59965100E+03, 0.41160700E+03, -.24601200E+04, -.23482800E+05, 0.11495900E+05, -.83640100E+04, 0.11755000E+05, -.57948100E+04, -.78834300E+04, 0.43939300E+04, -.80107200E+04, 0.38463900E+04, -.59727800E+04, 0.58624600E+04, -.22898400E+04, 0.10868500E+04, -.34628900E+04, 0.11439200E+04, 0.10167000E+04, 0.65215100E+03, 0.37553900E+03, 0.70055900E+03, 0.18155000E+04, 0.63122300E+03, 0.37839600E+04, -.15166300E+04, 0.77938700E+03, -.27245300E+03, 0.75282600E+03, 0.43876200E+03, 0.22942100E+03, 0.95348100E+02, -.17682400E+03, 0.13715300E+04, 0.24056800E+03, -.35765100E+03, 0.56403100E+03, 0.85631400E+03, 0.80500300E+03, -.20070200E+03, -.56556100E+02, -.67921500E+03, 0.18996400E+03, -.77280000E+03, -.53612100E+03, -.39648600E+03, 0.21537300E+00, 0.75181300E+03, -.62147500E+03, -.12664100E+03, 0.56445000E+03, -.84462300E+02, -.17537600E+04, -.44129200E+03, -.37168200E+03, -.49370800E+02, 0.28771700E+03, 0.45030300E+03, -.87420900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17098600E+01, -.99940600E+00, -.10398400E+01, -.21930800E+00, 0.22636400E+00, 0.28638300E+00, -.35625400E+00, -.23769100E+01, -.19896700E+02, 0.82551400E+00, 0.99892800E-01, -.62203200E+00, 0.43471000E+00, 0.87705200E-01, -.11197100E+01, 0.14608300E+00, 0.10967200E+01, -.27970900E+01, -.87557500E+00, -.20173800E+00, -.14654200E+00, -.84290300E+00, 0.12390900E+01, 0.16034300E+00, -.14732800E+00, 0.70392000E-02, 0.49412600E+00, 0.16520600E+00, -.18626500E+00, -.13453800E+00, -.38009300E+00, 0.20887700E+00, 0.26426400E+00, 0.44385000E+00, 0.46099100E+00, 0.17127100E+00, -.86108900E-02, -.28760400E+00, -.95583500E+00, -.37786900E+00, -.17010800E+01, 0.99169300E-01, 0.24301700E+00, 0.32214900E+00, -.45416400E+00, -.14297800E+00, -.29863900E+00, -.16883900E+00, -.30702100E+00, -.52874600E+04, 0.17938400E+04, 0.40175100E+03, 0.62334200E+03, -.42465600E+04, -.44305200E+04, 0.20338100E+05, -.94561600E+04, 0.13041900E+05, -.10189000E+05, 0.17188400E+05, 0.25195400E+05, -.11589400E+05, 0.36107000E+04, -.62635400E+04, 0.18583100E+05, -.13377900E+05, 0.39696500E+04, -.21890500E+04, -.73275800E+04, -.19885000E+04, -.38798500E+02, 0.18274600E+04, -.31216600E+04, -.28288000E+04, -.12910800E+04, 0.18323000E+04, 0.11248000E+05, 0.12383600E+05, -.59420200E+04, -.14710100E+05, -.62017300E+04, -.40250300E+04, 0.32381600E+04, -.60946100E+04, -.41871400E+04, -.92054200E+04, 0.32169400E+04, -.52956700E+04, 0.31681400E+05, -.15759000E+05, 0.10887800E+05, -.15900700E+05, 0.24466100E+04, 0.12350600E+05, -.11868700E+05, 0.40773900E+04, -.12864000E+05, 0.10672400E+05, 0.16949900E+05, -.13561700E+05, 0.65199400E+04, 0.23482800E+05, 0.67960200E+04, 0.39965600E+04, -.39711000E+04, 0.94273200E+04, 0.61071900E+04, 0.78746500E+04, -.51016500E+04, -.16841200E+05, 0.42880400E+04, -.18277700E+04, 0.16839000E+05, -.21408000E+04, 0.15433100E+04, 0.42002900E+04, -.15771400E+04, 0.94820900E+03, -.34321900E+04, 0.27184700E+04, -.26630700E+05, -.31825200E+05, 0.16500600E+05, -.11687600E+05, 0.15932100E+05, -.55203900E+04, -.12023500E+05, 0.55453400E+04, -.56427400E+04, 0.10458600E+05, -.96731900E+04, 0.25159600E+05, -.98313500E+04, 0.45277600E+04, 0.29862700E+04, 0.49040300E+04, -.58857400E+03, -.53780800E+04, 0.53081900E+04, 0.39188000E+04, 0.10428700E+05, -.51655100E+04, 0.15975700E+04, -.11954200E+05, 0.57762500E+04, 0.27306500E+04, 0.59714200E+04, -.11052600E+03, -.87781000E+04, 0.70042300E+04, 0.47688100E+04, 0.11879900E+05, -.79315500E+04, -.12022800E+04, 0.31642600E+04, -.14007100E+04, 0.39753800E+04, -.15740600E+04, -.11480800E+02, 0.72239800E+03, 0.89794400E+03, -.21557000E+04, -.97392400E+03, -.53583700E+03, -.31964100E+05, -.33469600E+04, 0.15385800E+04, -.11344600E+04, 0.16703400E+04, 0.22600600E+04, 0.12492400E+03, 0.18588800E+04, 0.19721100E+04, 0.34944500E+04, 0.73430500E+02, 0.97102800E+04, -.79456300E+05, 0.40348700E+05, -.43410000E+05, 0.39729000E+05, -.22597900E+05, -.36370100E+05, 0.15716000E+05, -.26937700E+05, 0.16889800E+05, -.29250500E+05, 0.29047600E+05, -.10672000E+05, 0.52923800E+04, -.20264900E+05, 0.53268300E+04, -.71375400E+04, -.20254700E+04, -.10736800E+04, -.11570200E+05, -.49754200E+04, 0.15054200E+03, 0.59523800E+04, 0.18249500E+05, -.96372600E+04, 0.82647900E+04, -.91702200E+04, 0.24762400E+04, 0.67324300E+04, -.36621000E+04, 0.42990400E+04, -.15013300E+04, 0.43382800E+04, -.11669600E+05, -.54877300E+05, 0.27367700E+05, -.20575200E+05, 0.27476600E+05, -.19890700E+05, -.23576100E+05, 0.12806600E+05, -.19354400E+05, 0.10136600E+05, -.19953600E+05, -.11877500E+05, -.46047200E+04, 0.20229700E+04, 0.67097100E+03, 0.22980300E+04, 0.20520700E+04, 0.43235500E+04, -.49415300E+04, -.66204000E+04, -.11547000E+04, 0.45696100E+04, 0.19110400E+05, -.30382400E+04, 0.15453500E+04, 0.71635800E+04, 0.15058800E+04, 0.25115700E+04, 0.30454900E+04, -.22782000E+04, -.29166400E+04, -.74878700E+03, 0.26286800E+04, -.62853000E+04, 0.28974200E+04, 0.37854500E+04, 0.37631800E+04, -.13117000E+04, -.50566900E+03, -.11603700E+04, 0.12906000E+04, -.34977100E+04, -.28070600E+04, -.12951000E+04, -.54354300E+03, 0.82007200E+02, 0.77199700E+03, -.63501600E+03, 0.89905000E+03, 0.31558400E+03, -.58735100E+04, -.93952800E+03, -.70902900E+03, 0.84570900E+02, -.34828100E+03, 0.31269600E+04, -.38793000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14382300E+00, -.25926100E-01, 0.18118900E-01, 0.36123600E+00, 0.16267600E+00, -.12598400E+00, 0.61679500E-01, 0.51024500E+00, 0.46811800E+01, 0.13220800E-01, -.52783000E-01, 0.88014500E-02, -.62259000E-01, -.31432200E-01, 0.22913200E+00, -.12709300E+00, -.35426900E+00, 0.13249600E+00, 0.10741000E+00, -.41327800E-01, 0.31057200E+00, -.83618400E-02, 0.56506700E+00, 0.53782600E-02, -.15374900E+00, 0.27921800E-02, -.44008800E+00, -.27778200E-01, -.62335900E-01, -.25066900E-01, 0.45080000E-01, -.11869500E+00, 0.21361000E-01, 0.16628900E-01, 0.14474400E+00, -.46677000E-03, -.26750200E-03, 0.61987700E-01, -.18320200E+00, 0.11163300E+00, 0.25394800E+00, 0.24475400E-02, 0.32485700E+00, -.33753400E-01, -.29008700E-01, 0.19739200E-01, -.11191700E+00, -.51924200E-01, 0.29301900E+00, -.40969100E-01, -.23532800E+03, -.92343300E+02, 0.14526400E+03, 0.16416800E+02, -.18021300E+03, 0.47641100E+03, -.17421300E+03, -.12412800E+03, -.24152700E+03, 0.37591200E+03, 0.31312700E+03, -.44127500E+03, -.93692700E+03, 0.14913100E+03, 0.20149200E+03, -.12545800E+03, -.38072800E+01, -.23201400E+02, -.27532400E+03, 0.12922500E+01, 0.78674700E+02, 0.96409800E+00, -.17263200E+03, -.77516600E+02, 0.20300300E+03, 0.57066600E+02, 0.50217000E+03, 0.14141300E+04, -.66050900E+03, -.74574500E+03, -.70872000E+03, -.19736900E+02, 0.30714500E+03, -.81026400E+03, -.39995600E+02, -.32767000E+03, 0.17354600E+03, -.79319300E+03, 0.53337400E+04, -.25749700E+04, -.33387400E+03, -.26768600E+04, -.12960200E+04, -.48036000E+03, -.41403200E+02, 0.18874500E+04, -.22205300E+04, -.37357300E+03, -.14645500E+04, -.19878500E+04, 0.90923300E+03, 0.10604900E+04, 0.99645400E+03, 0.12545900E+03, -.46510600E+02, 0.67020400E+03, -.28962900E+03, 0.75622100E+03, 0.47503200E+01, 0.23503200E+03, -.14535700E+04, 0.75492300E+03, 0.70593200E+03, 0.72732200E+03, -.18607400E+02, -.25662200E+03, 0.33985500E+03, -.20238500E+03, 0.67212600E+03, -.47318200E+03, -.56374300E+03, -.12910300E+04, 0.61193500E+03, 0.34570300E+03, 0.64878500E+03, 0.27937400E+03, 0.12610700E+02, -.47538000E+03, -.94154000E+03, 0.76267500E+03, 0.15396500E+03, 0.10885900E+04, 0.48368400E+03, -.23862400E+03, -.23477300E+03, -.24377500E+03, 0.68479700E+01, -.29346700E+02, -.47141300E+03, -.35860700E+03, -.78233100E+02, 0.19386500E+02, -.11184200E+03, 0.57924800E+03, -.28954900E+03, -.28913100E+03, -.29056800E+03, -.43769200E+01, -.96254800E+02, -.55092700E+03, -.41440700E+03, -.21545900E+02, -.50359900E+02, -.32881100E+03, -.10327100E+04, 0.52116700E+03, 0.14899000E+03, 0.51770200E+03, -.51130700E+02, 0.25331100E+03, 0.61636100E+02, -.80137200E+03, -.34328000E+03, 0.88584800E+02, -.62430900E+03, -.20846300E+04, 0.10175100E+04, 0.65286300E+03, 0.10418000E+04, 0.59539700E+03, 0.25702900E+03, 0.19869900E+03, -.30193300E+03, 0.67693900E+03, 0.34519000E+03, 0.12758300E+04, -.25589400E+04, 0.11769500E+04, 0.74209900E+03, 0.12796600E+04, -.30731300E+03, 0.20171300E+03, -.87115800E+03, -.12418400E+04, 0.12008400E+04, 0.27382800E+03, 0.87242900E+03, 0.35303700E+03, -.19515600E+03, -.31602400E+03, -.17761600E+03, 0.19637700E+03, 0.69192500E+03, -.77539200E+03, -.45164600E+02, -.90190700E+02, 0.54967600E+03, -.51588900E+03, 0.27619100E+03, -.14840600E+03, 0.94913100E+02, -.14567600E+03, 0.47133200E+02, 0.35396100E+03, -.48991800E+03, -.58990200E+03, -.27299100E+03, 0.38131100E+03, -.26425800E+03, -.18713500E+04, 0.84173900E+03, 0.72680400E+03, 0.94198800E+03, -.64522400E+03, -.11123900E+03, 0.10270500E+03, -.57516600E+03, 0.87080200E+03, -.38312800E+03, -.83948800E+03, -.91912000E+02, 0.11600400E+02, 0.61022000E+03, 0.45232500E+02, 0.60468900E+02, 0.17790300E+03, -.55365700E+02, -.20125400E+03, -.34319300E+03, 0.30401800E+03, 0.35310100E+03, -.53569900E+03, 0.27380000E+03, 0.57775300E+03, 0.26565500E+03, 0.15841900E+03, 0.16294200E+03, -.54373800E+02, -.38926700E+03, -.19048800E+03, 0.13027200E+03, -.19941800E+03, 0.38603400E+02, 0.29820600E+02, 0.46943500E+02, -.37253400E+02, -.44740800E+02, 0.70628000E+01, -.24567900E+02, -.22371200E+02, -.83760900E+02, 0.15890300E+03, -.32581300E+02, -.34724100E+03, 0.28304600E+03, -.90516900E+01, -.20772500E+02, 0.13245900E+03, -.41595600E+03, -.11347600E+03, 0.68829800E+02, 0.12347000E+02, 0.35028000E+03, 0.17611700E+02, -.19671500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.61345000E+00, 0.23133100E+00, -.44024100E+00, -.80543400E+00, 0.47094400E+00, 0.51584000E+00, -.13514800E+00, -.71190500E+00, -.22541700E+01, 0.39469400E+00, 0.14561600E-01, -.20589700E+00, 0.21461500E+00, 0.61548000E-01, -.36866800E+00, 0.50861000E-01, 0.14959000E+01, -.22668100E+00, -.10801100E+00, -.55704200E+00, 0.66200900E-01, -.58370900E+00, 0.38942000E+01, -.43586300E+00, -.69636300E+00, 0.16727700E-01, -.11278600E+01, -.20716100E-01, -.67933800E-01, 0.12496000E+00, 0.48345900E+00, 0.39502300E+00, 0.76347400E-01, 0.11482800E+00, 0.24843400E+00, -.21598000E+00, 0.34880800E-02, -.19328600E+00, 0.18332700E+00, 0.27301000E+00, -.11052600E+00, -.13652200E-01, 0.27852000E+00, -.27400100E+00, -.29181700E+00, -.14426600E+00, 0.48686800E+00, -.62130300E-02, -.35655800E-01, 0.32704100E+00, 0.24220500E+01, -.17074000E+04, -.11937500E+04, 0.15616300E+02, -.82359300E+03, 0.25982800E+04, -.15682600E+04, 0.53719700E+04, -.12870000E+04, 0.47431700E+04, 0.66422900E+04, 0.54076000E+02, 0.88563700E+04, -.97902300E+03, 0.53941800E+04, -.30769400E+04, -.35992700E+03, 0.28804800E+03, -.40869200E+04, 0.18218600E+03, -.39459200E+03, 0.11084900E+04, -.15640600E+04, -.34574600E+04, -.54372200E+03, 0.75385000E+03, 0.36398100E+04, 0.29362400E+04, -.16605200E+04, -.52431700E+04, -.14620700E+04, -.13158000E+04, -.29859000E+03, -.84386600E+03, -.17428800E+04, -.33056800E+04, 0.57986100E+03, -.69085300E+03, 0.15950400E+04, -.12265200E+04, 0.68159500E+04, -.76036000E+03, 0.67674800E+03, 0.54905300E+04, -.64569600E+04, -.44828000E+04, -.52672800E+04, 0.53995600E+04, 0.81929500E+04, -.48530400E+04, 0.27989500E+04, 0.98168200E+04, 0.24176300E+04, 0.24017300E+04, -.21726700E+02, 0.39757600E+04, 0.49713000E+04, 0.27141300E+04, -.11993500E+04, -.41778300E+04, 0.13639800E+05, -.69131900E+04, 0.44939800E+04, -.68218900E+04, 0.27977500E+04, 0.40787700E+04, -.29099900E+04, 0.42919700E+04, -.52421300E+04, 0.38402800E+04, -.10758100E+05, -.17157100E+05, 0.87163800E+04, -.23111500E+04, 0.85675800E+04, -.24628200E+04, -.47068800E+04, 0.44451300E+04, 0.78857300E+03, 0.46511400E+04, -.47514800E+04, 0.85057500E+04, -.21127700E+03, 0.20728800E+03, 0.13180900E+04, 0.11252200E+03, -.26432100E+03, -.66822600E+03, 0.18838300E+04, 0.14697200E+04, 0.14023500E+04, -.10689300E+04, 0.59675600E+03, -.10032500E+04, 0.53638500E+03, 0.16652900E+04, 0.50477600E+03, -.14469100E+03, -.55967000E+03, 0.19376100E+04, 0.93998300E+03, 0.10831200E+04, -.85467600E+03, 0.58621500E+03, 0.39885500E+04, -.20005500E+04, 0.20922100E+04, -.19989300E+04, 0.18931100E+04, 0.51076100E+03, 0.46248600E+03, 0.11366700E+04, 0.18940500E+04, 0.40765500E+03, -.75354900E+04, 0.52176000E+04, -.25074800E+04, -.32539100E+04, -.26065400E+04, -.14628100E+04, -.51120900E+03, 0.12361500E+03, 0.82767800E+03, 0.51600200E+03, -.10824200E+04, -.17035800E+04, -.35493700E+05, 0.18235900E+05, -.15093100E+05, 0.17749500E+05, -.33213700E+04, -.13334400E+05, 0.76987600E+04, -.13010000E+05, 0.60937300E+04, -.12159900E+05, 0.12873700E+05, -.38308600E+04, 0.20223000E+04, -.82758800E+04, 0.19214900E+04, -.22786700E+04, -.23859700E+04, 0.38916300E+03, -.64672100E+04, -.24845300E+04, -.12222400E+04, 0.29582400E+04, 0.37673300E+04, -.18476600E+04, 0.38544000E+04, -.18567600E+04, 0.57053700E+03, 0.14802300E+04, 0.74342400E+03, 0.35571500E+04, 0.60142200E+03, 0.73284400E+03, -.30104000E+04, -.13823100E+05, 0.73647500E+04, -.13025600E+05, 0.68880900E+04, -.10822100E+04, -.98632900E+04, 0.45614600E+04, -.60805700E+04, 0.22192800E+04, -.75721600E+04, -.98511100E+03, -.10821400E+04, 0.65830800E+03, -.82373700E+03, 0.54343500E+03, -.22237300E+04, 0.42098000E+03, -.22420600E+04, -.33153700E+04, -.11700200E+03, 0.38282100E+03, 0.65110600E+04, 0.60828300E+04, -.30701000E+04, -.78716900E+03, -.30328500E+04, 0.12724600E+03, 0.57430300E+03, -.13531100E+04, 0.15704600E+04, -.11476100E+04, 0.46284300E+03, -.26381800E+04, 0.44393100E+03, 0.69794200E+03, 0.48927700E+03, -.13558900E+03, 0.11695000E+03, -.11528400E+03, 0.35470900E+03, -.43310800E+03, -.39828700E+03, -.37204500E+03, 0.30820300E+03, 0.25511600E+03, 0.14416800E+03, 0.12490400E+02, 0.14453600E+03, 0.40950900E+03, 0.12394800E+04, -.93972100E+03, -.73676500E+03, -.14724500E+03, -.53019900E+02, 0.59085900E+03, -.81349400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.47019300E+00, -.21290000E-02, -.46794400E+00, 0.53266400E+00, 0.25456500E+00, -.60520700E-01, -.12578100E+00, -.48262700E+00, -.53217800E+01, 0.69258600E+00, 0.33987600E-01, -.51714100E+00, 0.29311900E-01, 0.72524500E-01, -.48332200E+00, -.29810500E+00, -.47750800E+00, -.85029200E+00, -.15510600E+00, -.17007100E+00, 0.23597900E+00, -.80048400E-01, -.74023300E+00, -.12587600E+00, 0.35316000E+00, -.10944700E-01, 0.51170300E+00, 0.20249200E-01, -.24602300E-01, 0.54816200E-01, -.35389900E+00, -.24670500E-01, -.10989300E-01, 0.62051500E-01, -.25247700E-01, -.11877500E-01, 0.98993100E-03, 0.10367200E+00, 0.29251600E+00, -.15303300E+00, -.20773000E+00, 0.60480100E-01, 0.41379000E+00, 0.22643200E+00, 0.49598200E-01, 0.39090500E-01, 0.33750900E-01, 0.82710900E-02, 0.19754600E+00, -.17439300E-02, -.49648500E+00, -.21713400E+00, 0.82922700E+03, -.93960000E+02, 0.41385200E+03, -.49272800E+03, 0.11720200E+03, 0.20889400E+04, 0.24980200E+03, 0.94187300E+03, 0.42806200E+03, 0.79993800E+03, 0.17181500E+04, 0.50880800E+02, 0.32065600E+03, 0.16870300E+03, -.66305800E+03, 0.37487300E+03, -.29594900E+03, 0.33215700E+03, 0.35728300E+03, 0.49200600E+03, -.38802100E+03, -.73499500E+03, 0.22406000E+03, 0.36869000E+03, -.55204600E+03, 0.48167300E+03, -.31419600E+03, -.74868200E+03, -.23912700E+03, -.30978200E+03, -.29840400E+03, 0.22057200E+02, 0.43271200E+02, 0.88076200E+03, -.33062500E+03, 0.55568700E+03, 0.22680400E+04, -.12817800E+04, 0.30413900E+04, -.11234500E+04, -.32108100E+03, 0.14889600E+04, -.13145200E+04, -.47512900E+03, -.19865300E+04, 0.14957900E+04, -.20806700E+04, 0.16746200E+04, -.70557600E+03, 0.23278700E+03, -.83979400E+03, -.26009400E+02, -.47715400E+03, 0.79763500E+03, 0.16505000E+04, -.85888900E+03, -.55955300E+03, -.19050000E+03, 0.35188300E+04, -.18025900E+04, 0.30215800E+04, -.17599900E+04, 0.99466800E+03, 0.10367300E+04, -.82900400E+03, 0.86838700E+03, -.11295900E+04, 0.66931100E+03, -.23165900E+03, -.43849800E+04, 0.22121300E+04, 0.90131700E+02, 0.21894900E+04, -.58248700E+03, -.15268900E+04, 0.60920900E+03, -.10080500E+04, 0.14787200E+04, -.13685000E+04, 0.12176800E+04, -.31076000E+03, 0.17715200E+03, -.27203400E+02, 0.15733100E+03, 0.20213800E+02, 0.14390000E+03, 0.31399600E+03, 0.26491300E+03, 0.29470900E+03, 0.14150000E+01, 0.63646800E+03, -.84892000E+03, 0.42887200E+03, 0.46363900E+02, 0.42533500E+03, 0.74758400E+02, 0.26979700E+03, 0.26888900E+03, 0.10409800E+03, 0.76526800E+03, 0.79749200E+02, 0.11056600E+04, 0.43965700E+03, -.21882400E+03, -.10286400E+03, -.22112300E+03, 0.30287400E+03, -.18231100E+03, 0.12207300E+03, 0.66702600E+03, -.30031400E+03, -.24872000E+03, 0.15379800E+04, 0.30229400E+03, -.11254000E+03, -.75894500E+03, -.15047900E+03, -.57950500E+02, -.71923200E+02, 0.81929000E+02, 0.11852500E+03, 0.54063100E+03, -.44752700E+02, -.11311500E+04, -.90575200E+04, 0.46463300E+04, -.26232000E+04, 0.45297800E+04, -.14661000E+04, -.54754400E+04, 0.23616200E+04, -.19095600E+04, 0.54155600E+04, -.50861300E+04, 0.50320700E+04, -.52916600E+03, 0.30094200E+03, -.23109400E+04, 0.26606400E+03, -.21394500E+03, -.52926200E+03, 0.80060500E+02, -.61287000E+03, 0.10244500E+04, -.46822200E+03, 0.91661400E+03, -.12036700E+03, 0.99214400E+02, 0.13892700E+04, 0.67718100E+02, 0.19908700E+03, 0.11364900E+03, 0.40727900E+03, 0.77234400E+03, 0.11997600E+03, -.70864000E+02, 0.20075300E+03, -.42003200E+04, 0.22490100E+04, -.17094100E+04, 0.20934900E+04, -.67851500E+03, -.36818800E+04, 0.18201100E+04, -.61711700E+03, 0.28554000E+04, -.34580800E+04, 0.46197500E+04, 0.45948900E+03, -.18698800E+03, 0.81836500E+02, -.22909900E+03, -.74492100E+03, 0.19908500E+02, -.72668800E+03, -.90760600E+03, -.83461600E+03, 0.16262000E+03, -.11959900E+04, 0.12047800E+04, -.61366500E+03, 0.56393600E+03, -.59991100E+03, 0.85511600E+02, 0.35094400E+03, -.51353700E+03, -.39416100E+02, -.10426100E+04, 0.25739300E+03, -.54145500E+02, -.20571700E+03, 0.32555100E+03, 0.27488700E+03, 0.86008100E+02, -.32063200E+01, 0.16400100E+03, -.21099400E+03, -.25587500E+03, 0.32210900E+03, -.11786800E+03, -.68822100E+02, 0.20994600E+03, 0.29279200E+03, -.78166300E+01, -.80173200E+02, -.52247100E+02, -.29949500E+02, -.24985500E+03, 0.94742700E+02, 0.13706300E+02, -.85467200E+00, 0.27314900E+03, -.33297200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24017200E+00, -.80083500E+00, -.36045900E+00, -.34877800E+00, 0.28322700E+00, 0.11424000E+01, 0.70622900E-02, -.85749300E+00, -.10431300E+02, 0.56320700E+00, 0.20017800E-01, -.47427600E+00, 0.31135500E+00, -.26062000E-01, -.10047600E-02, -.18478300E+00, -.70616600E+00, 0.24731100E+00, -.18965100E+00, -.16083000E-01, -.37256100E+00, 0.37368300E-01, 0.64336000E+00, -.29268300E+00, 0.25677000E+00, -.10122600E-01, -.55569200E-02, 0.78844700E-01, -.28406200E+00, -.20305000E+00, -.51687600E+00, 0.68099900E-01, 0.42169700E-01, -.22277100E+00, -.27202100E+00, -.90752600E-01, 0.74871200E-02, 0.62233900E-01, -.15143400E+00, 0.11848300E+00, 0.25862400E+00, -.25965100E-01, 0.58651900E+00, 0.27076200E+00, 0.66826900E-02, 0.57217700E-01, 0.28885300E+00, -.44939400E-01, 0.14895200E+00, -.17176500E-01, 0.70600900E+00, 0.66300600E-01, 0.35901200E+00, -.17970100E+03, -.32920900E+02, 0.66721400E+03, -.37674700E+03, -.19894300E+02, -.33531200E+03, 0.16454300E+03, -.25058800E+03, 0.64807200E+03, 0.10953500E+04, 0.22079500E+03, -.10673100E+02, -.11452200E+04, 0.33747300E+04, -.16761200E+04, -.88958800E+03, -.16876700E+04, -.24569900E+03, 0.41322100E+03, -.83999500E+03, 0.38139600E+03, -.12943300E+04, 0.32200700E+03, 0.27197000E+03, 0.23564700E+04, -.11933000E+04, -.95151600E+02, -.11790700E+04, -.11894400E+02, 0.41097000E+03, -.11653500E+04, -.94381400E+03, -.19007700E+04, 0.21049300E+03, -.79558400E+03, 0.14295400E+05, -.71549200E+04, -.42345500E+04, -.71536100E+04, -.14377700E+04, 0.76526900E+03, -.31750200E+04, 0.15770400E+04, -.43937800E+04, 0.42629600E+03, -.16586700E+04, -.74347100E+04, 0.37366600E+04, 0.18504700E+04, 0.37182200E+04, 0.76733600E+03, -.36665800E+02, 0.21635100E+04, -.13091200E+03, 0.31155200E+04, -.20031900E+02, 0.37367700E+03, 0.43963700E+04, -.22169000E+04, 0.37792400E+04, -.21978500E+04, 0.13853300E+04, 0.20526900E+04, -.18126000E+04, -.70092000E+03, -.24598700E+04, 0.15433300E+04, -.45289300E+04, 0.60981800E+03, -.32165200E+03, 0.89518900E+03, -.30446700E+03, 0.92976300E+02, -.11510400E+04, 0.47865100E+03, 0.62255600E+03, 0.54003600E+03, -.11736700E+04, -.29590200E+03, -.54802000E+02, 0.27701300E+01, -.19094600E+03, 0.26592800E+02, -.34725400E+03, -.70146500E+03, 0.66525300E+03, 0.66965200E+03, 0.55685000E+03, -.69674000E+03, 0.18306100E+03, -.12207100E+04, 0.59890700E+03, -.75753600E+02, 0.61021200E+03, -.19788700E+03, -.44798400E+03, 0.69913100E+03, 0.36682200E+03, 0.78364700E+03, -.56551600E+03, 0.58654600E+03, -.66030400E+04, 0.32971400E+04, 0.15184300E+04, 0.33018900E+04, 0.92833300E+03, 0.82044200E+03, 0.66605900E+03, -.14611700E+04, 0.18297800E+04, 0.85205100E+03, -.14434400E+03, -.13114600E+04, 0.66285300E+03, -.71810600E+02, 0.65504300E+03, -.32154000E+01, -.93722300E+02, 0.48766000E+03, 0.42655200E+03, 0.50000800E+03, 0.19844500E+02, 0.95158100E+03, -.19125500E+04, 0.92925200E+03, 0.25157000E+04, 0.95244600E+03, 0.59326700E+03, -.16839300E+04, 0.19503600E+03, -.18535500E+04, -.81202400E+03, -.18973100E+04, -.67853500E+03, 0.61274500E+01, -.18149200E+01, -.34760400E+03, -.36237700E+01, -.59997000E+03, -.23051700E+03, -.79273700E+03, -.17188500E+04, -.15475000E+04, -.19952500E+03, 0.11317400E+04, 0.32480200E+03, -.13637000E+03, -.21652200E+03, -.16530100E+03, 0.19675100E+02, 0.26338100E+03, 0.23089100E+03, 0.47183900E+03, 0.29033600E+03, 0.14716200E+03, -.26568700E+03, -.32877400E+04, 0.16528600E+04, 0.37155500E+04, 0.16475300E+04, 0.12028700E+04, 0.22358300E+03, -.56183900E+03, -.37166900E+04, -.16794600E+04, -.23376200E+03, -.24066300E+04, 0.57620500E+04, -.28647800E+04, -.20858100E+04, -.28810600E+04, -.99518600E+03, -.28068400E+03, -.10528900E+04, 0.56721400E+03, -.16872700E+04, -.81975600E+02, -.40945000E+03, 0.20667800E+04, -.10351500E+04, 0.63504300E+03, -.10351800E+04, 0.11458700E+03, 0.17585100E+03, -.42437300E+03, 0.67593500E+02, -.33118200E+03, 0.13636900E+03, -.18889600E+04, 0.16197900E+03, -.10620900E+03, -.93003900E+02, -.79395000E+02, 0.11638600E+03, 0.10550700E+03, 0.10193000E+03, 0.11507500E+03, -.50048500E+03, 0.10640600E+03, 0.53610400E+02, -.69802600E+03, -.16705700E+02, 0.62673200E+02, -.34230700E+02, 0.34048800E+03, -.11852300E+04, 0.13689000E+03, -.43909000E+03, -.44147600E+02, 0.67352300E+02, -.28088900E+03, 0.49486800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39021900E+00, 0.52913700E+00, -.98291200E-01, 0.72209100E+00, 0.33840600E+00, -.65136200E+00, 0.59550700E+00, -.26791600E+00, 0.19407900E+01, 0.49438000E+00, -.48046300E-01, -.10796400E+00, -.35319100E+00, 0.32009200E-01, 0.10171300E-02, 0.12960700E-01, -.11049600E+01, 0.97206600E+00, 0.34565200E+00, 0.15263600E-01, 0.26061900E+00, 0.42741300E+00, -.15702200E+01, 0.24015000E-01, 0.49044500E+00, -.11803600E-01, 0.29247100E+00, 0.59268300E-02, 0.82409100E-01, -.27837600E-01, -.16342300E+00, -.28664000E+00, -.21666500E-01, 0.63323700E-01, -.47530100E-01, -.31634300E-01, -.11666800E-02, -.42046400E+00, 0.18606800E+00, -.99773600E-01, -.38344100E+00, 0.14833600E+00, 0.26844000E+00, 0.23939200E+00, -.16727300E+00, -.14104000E+00, -.68763000E-01, -.19028400E-01, 0.38339100E+00, 0.57969600E-01, -.14203500E+01, -.23103500E-01, 0.97806500E+00, -.38109400E+00, -.22539800E+04, 0.33923100E+04, -.15323900E+04, -.10462800E+04, -.17031900E+04, 0.23721300E+04, 0.57086800E+04, -.36334100E+04, -.63231400E+03, -.20287500E+04, 0.43119500E+04, -.21271000E+04, -.44564100E+04, 0.21691800E+04, -.23559600E+04, 0.22269100E+04, -.89576500E+02, 0.42719400E+03, -.96677500E+03, -.35193900E+04, 0.10353800E+04, 0.45916500E+03, 0.71619400E+04, 0.48967900E+04, -.23393900E+04, -.42679700E+04, -.24519100E+04, -.81247800E+03, 0.13394600E+04, -.23969400E+04, -.61119300E+03, -.33010600E+04, 0.19739500E+04, -.31815200E+04, -.14294500E+05, 0.72884100E+04, 0.11290900E+05, 0.71262300E+04, -.14812800E+04, 0.25382400E+04, 0.11204300E+04, -.34160700E+04, -.15543500E+04, 0.36642200E+04, 0.15990100E+05, -.82509000E+04, 0.39383900E+04, 0.77804400E+04, 0.41308700E+04, 0.21726600E+04, -.12499400E+04, 0.41231000E+04, 0.28964500E+04, 0.50003700E+04, -.24130500E+04, -.46855600E+04, -.18984000E+04, 0.10459400E+04, -.24618700E+04, 0.95032300E+03, 0.14978400E+04, -.52743400E+03, 0.23202500E+04, 0.43677900E+04, 0.20876300E+04, -.99957200E+03, -.10285100E+05, -.54427800E+04, 0.26623600E+04, -.90513800E+03, 0.27285000E+04, 0.14248600E+04, 0.12607100E+04, -.20661500E+04, -.24507500E+04, -.10295500E+03, 0.95848200E+03, 0.71735100E+04, 0.31536200E+04, -.14882500E+04, -.98585100E+03, -.15809400E+04, -.71517100E+03, -.16919600E+04, -.64546200E+03, -.46591900E+03, 0.50833400E+03, -.16056200E+04, -.15973500E+04, 0.44314700E+04, -.21813400E+04, -.11238000E+04, -.22177900E+04, -.76261400E+03, -.19849400E+04, -.66333900E+03, -.10388800E+03, 0.36807700E+03, -.19038400E+04, -.34796100E+04, 0.54505800E+04, -.26902700E+04, 0.37249800E+03, -.27223900E+04, 0.56721800E+03, 0.42853100E+02, 0.11003600E+04, 0.16069800E+04, -.81336800E+01, -.84243000E+03, -.14418200E+05, 0.26837500E+04, -.13935800E+04, -.22243100E+04, -.13429100E+04, 0.24592900E+03, -.14791100E+03, -.77722500E+03, -.73538300E+03, -.20299600E+02, -.38574400E+03, 0.26840100E+04, -.12845900E+05, 0.62579700E+04, -.24386100E+04, 0.64239200E+04, 0.19789100E+04, 0.19760600E+04, 0.79823700E+03, -.40258900E+03, 0.15901500E+04, 0.12621200E+04, -.48099300E+03, -.19655900E+04, 0.96191100E+03, -.79839300E+03, 0.98205700E+03, -.13687400E+03, 0.10354400E+04, -.10600100E+04, -.27262200E+04, -.18782400E+04, 0.14195500E+04, -.15605500E+04, 0.33016500E+04, -.16980000E+04, 0.22305700E+03, -.16670300E+04, 0.10111900E+03, 0.17069200E+04, -.89710000E+03, 0.24542800E+03, -.33901200E+03, 0.12885200E+04, -.41110400E+04, -.28085200E+04, 0.12369500E+04, -.47295800E+04, 0.14175800E+04, 0.13130600E+02, -.16113800E+04, 0.42447500E+04, 0.67555800E+04, 0.36699500E+04, -.17700800E+04, -.16955300E+05, -.83917900E+04, 0.40788100E+04, 0.51835000E+04, 0.41943100E+04, 0.34027600E+03, 0.20060900E+04, -.10622000E+04, -.51502200E+04, 0.18763000E+03, 0.21665600E+04, 0.96975500E+04, 0.40428500E+03, -.19160000E+03, 0.94810800E+03, -.20669600E+03, 0.58608100E+03, 0.65042500E+03, -.44689900E+03, -.32254900E+03, -.10081400E+04, 0.69846000E+03, -.26904900E+04, 0.77472700E+03, 0.11665300E+04, 0.12286300E+04, -.16476000E+03, 0.11890500E+03, 0.41737400E+02, 0.66576300E+03, -.11668100E+04, -.84347800E+03, 0.85480600E+02, -.92356300E+02, -.84287300E+03, 0.10672100E+04, 0.10680700E+03, 0.77901400E+02, 0.41321300E+03, 0.10797300E+04, -.75390700E+03, 0.11263600E+03, -.16932700E+03, 0.61518700E+03, 0.12975200E+04, -.11713300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24310800E+00, 0.52077400E-01, -.12451300E+00, -.61669900E-01, 0.57701100E+00, 0.41297500E-01, -.15062900E-03, -.25954900E-01, -.29969900E+00, -.60487900E-01, -.47813300E-02, -.17098300E-01, 0.58121700E-02, -.69821500E-02, 0.18597200E-01, -.30895200E-01, 0.93867800E-03, -.21622300E-01, -.31586000E-01, -.30523600E-01, -.20408000E+00, 0.77443900E-01, -.51535900E+00, -.11094700E-02, 0.48192500E-01, 0.16867900E-02, 0.13245700E+00, -.28522800E-02, -.42521300E-01, 0.46421700E-01, 0.19404000E-01, 0.89928700E-01, 0.46839800E-03, 0.13941200E-01, -.37379800E-01, 0.44152200E-01, -.24569200E-02, -.11502500E+00, -.17137800E+00, -.61706900E-01, -.21703500E+00, -.90429400E-02, -.41093600E+00, -.62678600E-01, 0.64667100E-01, 0.19218600E-01, 0.15006600E+00, 0.19941000E-01, -.24220800E+00, -.43597500E-01, -.83451200E+00, -.39881400E-01, -.18600400E+00, -.12559500E+00, -.96763600E-01, 0.12142500E+04, -.59962000E+03, 0.60519800E+03, -.61011400E+03, 0.87042800E+03, 0.84536200E+03, -.36872400E+03, 0.21512000E+03, -.14965600E+03, 0.60766700E+03, -.89808100E+03, 0.88547700E+03, -.44615200E+03, -.22882000E+03, -.44328300E+03, -.43453400E+03, -.84223200E+02, -.25154100E+03, -.23882000E+03, -.37473600E+03, -.17556200E+01, 0.28260400E+03, 0.97208300E+03, -.47724800E+03, -.10424800E+04, -.48752600E+03, 0.66275300E+01, 0.10180600E+03, -.38150900E+03, -.45275900E+02, -.45634100E+03, 0.83112900E+02, -.56764700E+03, 0.45598500E+04, -.22549200E+04, -.13957000E+04, -.22892300E+04, -.13096900E+04, -.64031900E+03, -.50645800E+03, 0.89900100E+03, -.12782800E+04, -.55402800E+03, -.20328400E+03, -.17141500E+04, 0.84056900E+03, 0.16450400E+04, 0.85917600E+03, 0.46688500E+03, 0.39191600E+03, 0.41879900E+03, 0.19052700E+03, 0.69845800E+03, 0.24558200E+03, 0.24652500E+03, 0.11797300E+04, -.58816200E+03, 0.45015200E+03, -.58935700E+03, 0.30817600E+03, 0.46230800E+03, -.23293100E+03, 0.43812700E+03, -.41914900E+03, 0.26522500E+03, -.92171100E+03, -.35737900E+04, 0.17755300E+04, 0.33533400E+03, 0.17893300E+04, 0.23668500E+03, -.45259500E+03, 0.59696200E+03, -.66777200E+03, 0.13002100E+04, -.23998900E+03, 0.10114800E+04, 0.24851500E+03, -.13318000E+03, -.22701600E+02, -.12592200E+03, -.33532900E+02, -.60677200E+02, -.20106800E+03, -.29297500E+03, -.10701200E+02, -.99737400E+02, -.30904500E+02, -.11818100E+02, 0.53079300E+00, 0.29639100E+02, 0.51994000E+01, -.11662000E+02, -.66214900E+02, -.15594600E+03, -.35221400E+03, 0.34364500E+02, -.11087100E+03, 0.12815700E+02, 0.93075400E+01, -.75968200E+01, -.15065800E+03, -.35719100E+01, 0.40954800E+03, 0.66536600E+03, -.23417000E+03, -.30783200E+03, -.28486700E+03, 0.46577400E+03, -.28866400E+03, -.17681700E+04, 0.87896700E+03, 0.90591500E+03, 0.88344600E+03, 0.47039000E+03, 0.24940800E+03, 0.26928300E+03, -.21960100E+03, 0.51820300E+03, 0.30103000E+03, 0.39575500E+03, -.61101600E+04, 0.30267700E+04, -.12292200E+04, 0.30536300E+04, -.45919900E+03, -.92718700E+03, 0.10316900E+04, -.14516600E+04, 0.15772700E+04, -.65062700E+03, 0.27988500E+04, -.23164500E+03, 0.11118400E+03, -.12965800E+04, 0.11504800E+03, -.29347500E+03, 0.12816800E+03, -.23246400E+03, -.41690900E+03, -.27880000E+03, 0.15726200E+03, 0.29765800E+03, 0.90189200E+03, -.44857600E+03, 0.35881700E+03, -.45736300E+03, 0.19230500E+03, 0.47174300E+03, -.37828300E+03, -.76023000E+02, -.21846200E+03, 0.35246800E+03, -.37827700E+03, -.25146400E+04, 0.12366900E+04, -.12472300E+04, 0.12631800E+04, -.59421700E+03, -.50859000E+03, 0.47636300E+03, -.68919100E+03, 0.39547400E+03, -.55544800E+03, 0.11742600E+04, -.26065100E+03, 0.12835500E+03, -.15387800E+03, 0.12981100E+03, -.34148200E+03, -.10779800E+03, -.41760900E+02, -.50550600E+03, -.26309800E+02, 0.55946800E+02, 0.69247900E+03, 0.28823100E+03, -.14302100E+03, -.92332800E+02, -.14636300E+03, 0.90856600E+02, 0.97766100E+02, -.11734500E+03, -.62981000E+02, -.63712200E+02, 0.81959000E+02, -.25921800E+03, 0.14127900E+03, -.30919500E+02, -.26100700E+02, -.10275000E+03, -.70838600E+02, -.65696200E+02, 0.30745100E+02, 0.35383000E+02, -.11277200E+03, 0.52622200E+02, 0.50875300E+02, -.25674400E+03, 0.56700900E+02, -.58334500E+02, 0.54952700E+02, 0.93692000E+02, -.30315600E+03, -.15308300E+03, 0.16830600E+02, 0.54155600E+02, 0.26174500E+03, -.44338700E+02, 0.27195800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22703700E+00, 0.86077700E+00, -.11912900E+00, 0.83290900E+00, 0.13701200E+00, -.48738900E+00, 0.30022900E-01, 0.67487400E+00, 0.18585500E-01, 0.24937200E+00, -.33144300E-01, 0.17151700E+00, 0.19070600E+00, -.82320300E-01, 0.71299100E-01, 0.26696800E+00, 0.12269000E+01, 0.10292500E+01, 0.13434600E+00, 0.12347800E+00, 0.28366400E+00, -.49916800E-01, -.14436500E+01, 0.25859400E-01, 0.33542800E+00, 0.20157700E-02, 0.74967600E+00, 0.48416400E-02, 0.21119200E+00, -.98487400E-01, -.27463200E+00, 0.12349200E+00, 0.10908300E-01, 0.11013300E+00, -.60711600E-01, -.30052000E-01, -.19559500E-02, -.71302100E-01, 0.31645700E+00, -.16269600E+00, -.90527100E+00, 0.95071600E-01, 0.61999100E-01, 0.17979600E+00, -.71229200E-01, -.12849700E-01, 0.19479600E+00, -.31741300E-01, 0.22675200E+00, 0.14032000E+00, -.13283800E+01, -.12497100E+00, 0.11618500E+01, -.78210300E-01, 0.36726500E+00, 0.11553700E+01, 0.16233700E+03, -.36014000E+03, 0.71431800E+00, 0.66193300E+03, 0.87350800E+03, -.56530600E+03, -.63375300E+03, -.62649500E+02, 0.83238000E+03, 0.10749500E+03, 0.17081900E+04, -.92831100E+03, -.11506500E+04, -.85396600E+03, 0.46956600E+03, 0.48875800E+03, -.51002300E+03, 0.42001900E+03, -.61886500E+03, 0.39524000E+03, -.80917500E+03, 0.11558100E+04, -.42190700E+03, -.10483100E+04, -.57755000E+03, -.19247700E+03, 0.39934100E+03, -.62055000E+03, -.25961500E+03, -.39653200E+03, 0.31658300E+03, 0.12068600E+03, 0.30182200E+04, -.11914100E+04, 0.69256700E+03, -.15068800E+04, -.96730900E+02, 0.11058000E+04, -.17927200E+04, -.83465400E+03, -.10941700E+04, 0.14124700E+03, -.41296200E+03, -.22597300E+04, 0.82364400E+03, 0.19669200E+04, 0.11293700E+04, 0.18033800E+03, -.21406100E+03, 0.88681800E+03, -.91371500E+02, 0.78588800E+03, 0.67828900E+02, 0.65137200E+01, 0.13548400E+04, -.58627900E+03, -.12864900E+03, -.67754100E+03, 0.66384300E+03, 0.94227700E+03, -.55505400E+03, -.13919700E+03, -.75221500E+03, 0.91184000E+03, -.11966200E+04, 0.13261400E+04, -.86264000E+03, -.10729900E+04, -.66363500E+03, -.32844200E+03, -.76657400E+03, -.26048300E+02, 0.39598700E+03, 0.42431000E+02, -.72559400E+03, 0.44859500E+02, -.12253600E+03, 0.95460800E+02, -.80688000E+02, 0.61668700E+02, 0.13778300E+03, 0.27244000E+03, -.34159700E+03, -.48736500E+03, -.23441100E+03, 0.26506600E+03, 0.52808400E+03, 0.27631200E+03, -.11726300E+03, -.12072500E+03, -.13798800E+03, 0.13376500E+03, 0.15765300E+03, -.37310800E+03, -.52745800E+03, -.45613300E+03, 0.18770100E+03, 0.23825600E+03, -.17550300E+04, 0.90402200E+03, 0.57630600E+03, 0.87725900E+03, -.18210800E+01, 0.65367200E+02, 0.54576500E+03, -.18785600E+03, 0.15624200E+03, 0.32378800E+03, 0.91355300E+00, 0.11833000E+04, -.67041600E+03, -.82606700E+03, -.59149300E+03, -.96005700E+02, -.28643200E+03, 0.28630200E+02, 0.49693500E+03, -.49634200E+03, -.19224200E+03, -.23517700E+03, -.32227900E+04, 0.11226300E+04, 0.11901600E+03, 0.16117900E+04, -.38061100E+03, -.59764200E+03, 0.90896000E+03, 0.82815700E+03, 0.19361600E+04, -.37923200E+03, 0.11658900E+04, 0.34662600E+03, -.23398600E+03, -.65695200E+03, -.17337300E+03, 0.46899900E+02, 0.32844100E+03, -.66254800E+03, -.27244600E+03, -.12866000E+03, 0.32187300E+03, -.18552300E+03, -.67727600E+03, 0.35823900E+03, 0.44048100E+03, 0.34015500E+03, 0.25187900E+03, 0.59520700E+03, -.17988100E+03, -.47276600E+03, -.15106200E+03, 0.50177000E+03, 0.24535800E+03, -.35602800E+04, 0.14319700E+04, 0.95732200E+03, 0.17787300E+04, 0.17617900E+03, 0.48063900E+03, 0.67725600E+03, -.33164600E+03, 0.98176700E+03, 0.72962000E+03, 0.26870000E+03, 0.36811700E+04, -.19705300E+04, -.19863500E+04, -.18404700E+04, 0.46584300E+02, 0.10612100E+03, -.11338900E+04, -.72199300E+02, -.13223400E+04, -.30029300E+02, -.11870800E+04, 0.11515100E+04, -.55708200E+03, -.13271000E+03, -.57521000E+03, 0.36305300E+01, 0.38553100E+02, -.31199300E+03, -.34672000E+02, -.26702000E+03, 0.16179100E+02, -.53696500E+03, -.14525500E+02, 0.94076400E+02, 0.41184300E+02, -.31691800E-01, -.54374700E+02, -.46505800E+02, -.39368300E+01, -.57751700E+01, -.18866200E+03, -.24955100E+03, -.48270000E+02, -.81706400E+03, 0.12588600E+03, -.12763600E+02, -.16736900E+02, -.12352900E+02, -.99789600E+03, -.79362400E+02, -.41439100E+02, -.12687500E+01, 0.22133600E+03, -.12691300E+03, -.11104100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23174400E+01, -.23522600E+01, 0.29187200E+01, -.92552000E+00, 0.79923600E+00, 0.76777900E+00, -.23884900E+00, -.38255500E+01, -.50532400E+02, 0.26131000E+00, 0.27283000E+00, -.15167600E+01, -.10369300E+01, -.70612800E-01, 0.26467200E+01, 0.55946000E+00, 0.30578900E+01, 0.46622900E+01, 0.68031700E+00, 0.21749400E+01, -.35222300E+01, -.66002800E+00, -.21043500E+01, 0.60612500E+00, 0.20047300E+01, -.40572600E-01, -.31467700E+00, -.87441600E-01, 0.98230300E+00, 0.57847200E+00, 0.13524100E+01, -.45965800E+00, 0.22005900E+00, 0.54651900E+00, 0.14557600E+01, -.68150700E-01, -.10535800E-01, -.31601100E+00, -.96306200E-01, 0.46873500E+00, 0.46782300E+00, 0.40014000E+00, 0.18941400E+01, 0.80199400E+00, -.65356800E+00, -.35431600E+00, -.14094900E+01, -.19760900E+00, 0.14240000E+01, 0.70739600E+00, 0.13070200E+01, 0.12867300E+01, 0.55661900E-02, -.20149100E+01, 0.16699200E+01, -.60622400E+01, 0.75608200E+00, -.12391600E+05, -.22773200E+02, -.24061100E+03, 0.37243800E+04, -.26790800E+04, -.49484800E+04, 0.33012200E+04, 0.30180500E+04, -.31296800E+03, -.27728500E+03, 0.13296700E+03, -.20790600E+04, 0.13446600E+03, -.33115700E+04, -.12400900E+04, 0.86706200E+03, 0.15085200E+04, 0.35029800E+03, 0.11536700E+03, 0.29977500E+04, -.11689500E+04, 0.64096000E+03, -.12524400E+05, 0.57313400E+03, 0.33815900E+04, 0.31189700E+04, -.23748200E+04, -.16610900E+04, 0.99504400E+02, 0.23362400E+04, -.13115700E+04, 0.62713200E+05, -.31207100E+05, -.27250600E+05, -.31425800E+05, -.55394200E+04, -.12216000E+04, -.96619900E+04, 0.11193500E+05, -.18594600E+05, 0.10093700E+04, -.23703100E+05, 0.15037300E+04, -.85853400E+03, 0.19987300E+05, -.73497000E+03, -.14702500E+04, -.58330000E+03, -.10785100E+04, -.27787300E+04, 0.10723500E+03, -.10965500E+04, -.17250600E+04, -.25597600E+05, 0.12806400E+05, -.12335200E+05, 0.12802500E+05, -.72886500E+03, -.59418500E+04, 0.61929000E+04, -.49512700E+04, 0.10601200E+05, -.69791900E+04, 0.10036000E+05, -.36659500E+05, 0.18211900E+05, 0.65380700E+04, 0.18350900E+05, 0.42137000E+04, 0.16557100E+04, 0.58769400E+04, -.46134800E+04, 0.13668600E+05, 0.30802400E+04, 0.15973100E+05, 0.54814200E+04, -.28409700E+04, -.15769900E+04, -.27538100E+04, 0.56296400E+02, 0.30402300E+03, -.23240900E+04, -.53806000E+03, -.13648000E+04, 0.51228100E+03, -.32802300E+04, 0.60361000E+04, -.30587100E+04, 0.81978900E+03, -.30241900E+04, -.22491400E+03, -.69861400E+03, -.15569300E+04, -.32044300E+03, -.16343300E+04, -.54138200E+03, -.41521000E+04, -.12750700E+05, 0.63648600E+04, 0.55230000E+04, 0.63842400E+04, 0.10436500E+04, 0.29158600E+04, 0.96228800E+03, -.67567100E+04, 0.84400500E+03, 0.54865300E+03, 0.48098400E+04, -.19509200E+05, 0.97260100E+04, 0.12250200E+05, 0.97506200E+04, 0.21093900E+04, 0.18891200E+04, 0.25412700E+04, -.24977900E+04, 0.39825200E+04, 0.25285600E+04, 0.89263700E+04, -.53211300E+05, 0.26358100E+05, 0.79419400E+04, 0.26602900E+05, 0.80028900E+04, 0.20007700E+05, -.19361000E+04, -.17264300E+05, 0.11017400E+05, 0.18046800E+05, 0.25954600E+05, 0.25842300E+04, -.13082000E+04, -.62047000E+04, -.12999300E+04, 0.24331800E+04, 0.86318700E+04, -.55583300E+04, -.29848900E+04, -.42788700E+04, 0.70054700E+04, 0.16104000E+03, 0.44918400E+04, -.21960100E+04, -.52270500E+04, -.22968500E+04, -.26382500E+03, 0.16203800E+04, -.30368100E+04, -.30108200E+04, -.82656100E+03, 0.21009300E+04, -.84763200E+03, -.23685500E+05, 0.11731700E+05, -.66814900E+04, 0.11886500E+05, 0.31990200E+04, 0.86162800E+04, -.14529400E+04, -.11261800E+05, 0.51992900E+04, 0.48349200E+04, 0.99496100E+04, -.84735800E+04, 0.42167400E+04, -.45385500E+04, 0.42321700E+04, 0.51816200E+03, 0.29860200E+04, 0.15590200E+04, -.61977500E+03, 0.22080600E+04, 0.42939700E+04, 0.65616900E+04, -.79336800E+04, 0.39702900E+04, -.19706800E+04, 0.39511000E+04, 0.13720900E+04, 0.14429100E+03, 0.12084800E+04, -.25142800E+04, 0.26971400E+04, 0.22335500E+02, 0.17866000E+04, 0.39919700E+02, 0.11634100E+04, 0.13064000E+04, -.34018900E+03, 0.64440200E+02, -.14682500E+03, 0.51702900E+03, -.11246600E+04, 0.24703100E+03, 0.11365100E+04, 0.62796500E+03, -.37441900E+04, 0.21658200E+03, 0.19987400E+03, -.45745100E+01, 0.17591900E+04, -.61221600E+04, -.27015500E+04, 0.58161800E+03, -.64833700E+02, 0.72478100E+04, 0.15559400E+03, -.10123300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13168800E+01, 0.10773700E+01, 0.19160100E+00, -.24182500E+00, -.11171100E+01, -.38474700E+00, 0.23918400E+00, 0.18313300E+01, 0.26570400E+02, -.85797900E+00, -.15880200E-01, 0.20342800E+01, -.31358300E+00, 0.78432600E-01, -.32126500E+00, -.77262400E+00, 0.12341200E+00, -.15376700E+01, 0.84867200E-01, 0.30224900E+00, 0.12202700E+01, -.19930000E+00, 0.82948600E+00, -.10124900E+01, -.15737200E+01, 0.53174500E-02, -.74438100E-01, 0.62338600E-01, -.14970000E+00, -.28267400E+00, 0.52467400E+00, -.17506800E+00, -.13543400E+00, -.33449600E+00, -.34805500E+00, 0.73776600E-02, 0.10704300E-01, 0.73550100E+00, 0.38059400E-01, -.23361400E+00, 0.70013200E+00, -.77369400E-01, -.14084800E-01, 0.10789100E+00, 0.25457500E+00, 0.26943500E+00, 0.29500800E-01, 0.13741700E+00, 0.39739800E+00, -.39631300E+00, 0.24810100E+01, -.54395400E+00, -.31672000E+00, -.26651800E+00, -.12416700E+01, 0.22116500E+01, -.92189600E+00, -.15723700E+00, 0.18370200E+02, 0.13336600E+04, 0.42749800E+04, -.12576700E+04, 0.40120100E+04, -.10712700E+04, 0.37652500E+04, -.91445900E+03, -.27466000E+04, 0.13788400E+04, -.40418500E+04, 0.13766500E+04, 0.71166300E+03, 0.88628500E+03, -.48507700E+03, -.15616700E+04, 0.89130100E+02, 0.29595800E+03, 0.33708000E+04, -.13717800E+04, 0.67197800E+03, -.46895200E+03, 0.69501600E+03, -.83694800E+03, -.75589300E+03, 0.19332500E+03, -.53215500E+03, -.94522100E+03, 0.74221100E+03, 0.14935700E+04, -.30336400E+05, 0.15049200E+05, 0.15135700E+05, 0.15225200E+05, 0.43998800E+04, 0.24455700E+04, 0.30516800E+04, -.66912600E+04, 0.72466800E+04, 0.18800900E+04, 0.15715800E+05, -.31837700E+03, 0.19439100E+03, 0.39780200E+04, 0.14621600E+03, 0.15117700E+04, 0.12301400E+04, 0.13145600E+03, 0.10995000E+04, 0.47358300E+03, 0.27774100E+03, -.41141100E+04, 0.12649000E+05, -.62973000E+04, -.42728300E+04, -.63276200E+04, 0.96172200E+03, 0.29532900E+04, -.34238000E+04, 0.17731200E+04, -.54959900E+04, 0.41492100E+04, -.84394200E+04, 0.10888400E+02, 0.48130200E+02, -.30805300E+04, -.20645900E+02, -.69088900E+03, 0.10530000E+04, -.13699800E+04, 0.14431800E+04, -.31005500E+03, -.26363500E+02, 0.18901900E+04, -.28580800E+04, 0.14592800E+04, 0.13104000E+04, 0.14392900E+04, -.10122200E+03, -.48401000E+03, 0.18693600E+04, 0.16155300E+04, 0.19804200E+04, -.67476900E+03, 0.13151700E+04, -.26387000E+04, 0.13359700E+04, 0.17267000E+04, 0.13237600E+04, -.36441900E+02, -.32755900E+03, 0.17361400E+04, 0.17407700E+04, 0.16878900E+04, -.44884600E+03, 0.14946500E+04, 0.94630700E+04, -.46958100E+04, 0.11331800E+04, -.47382400E+04, -.40807200E+03, -.11357900E+04, 0.85055100E+02, 0.25754300E+04, -.25881100E+03, -.39873000E+03, -.96197400E+04, 0.12365000E+05, -.61667100E+04, -.66795800E+04, -.61786400E+04, -.21766400E+04, -.11670400E+04, -.16480000E+04, 0.13410600E+04, -.32177500E+04, -.19587300E+04, -.39599500E+04, 0.34136400E+04, -.15927200E+04, -.11645200E+05, -.16986400E+04, 0.99487100E+02, -.19996600E+04, -.99163100E+03, 0.65097000E+03, -.19036700E+04, -.21669900E+04, -.42418000E+04, -.30134300E+04, 0.15345500E+04, -.10146100E+04, 0.15127800E+04, -.14108100E+04, -.32100700E+04, 0.11457300E+04, -.23021200E+04, -.80708100E+03, -.19560200E+04, 0.25158000E+04, -.44279400E+03, 0.19329400E+03, 0.12210200E+04, 0.26100600E+03, 0.17137000E+03, 0.38032000E+02, 0.12070100E+04, 0.27283200E+04, 0.16215300E+04, -.26959700E+03, -.10595600E+04, 0.80788700E+04, -.39540600E+04, -.11077600E+05, -.40753500E+04, 0.55490400E+03, -.26770500E+04, -.15198100E+03, 0.22174500E+04, -.36916200E+04, 0.28784600E+02, -.93596300E+04, -.86067100E+03, 0.39258800E+03, 0.74768700E+03, 0.43355700E+03, -.95989000E+01, -.49439700E+03, -.81980200E+03, -.59176600E+03, 0.95038800E+03, -.12567200E+04, 0.33087400E+04, 0.53101000E+04, -.26604700E+04, -.59674000E+03, -.26413600E+04, -.43107500E+03, -.43064800E+03, -.62150900E+03, 0.16616700E+04, 0.11933600E+02, -.12215700E+03, -.30563900E+04, 0.28523200E+03, -.40087800E+03, -.34824300E+03, 0.45953700E+02, 0.15822300E+03, 0.13138300E+03, 0.55110300E+03, 0.33858100E+03, 0.15409800E+03, -.27355400E+03, 0.24171700E+03, 0.13911400E+04, 0.37572100E+03, 0.48177800E+02, -.39022800E+02, -.13582900E+03, 0.39309300E+04, -.14358700E+03, -.91611300E+03, -.18848500E+03, -.13518000E+04, -.82030800E+02, 0.23719300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16779900E+00, -.27891400E+00, 0.88334000E-01, -.32395400E+00, -.96825600E-02, 0.23667800E+00, -.47881200E-01, -.14003700E+00, -.21613400E+01, 0.28614700E+00, 0.21602600E-01, 0.76837600E-02, 0.14710700E+00, 0.13197100E-01, -.36178000E-01, 0.27788200E+00, 0.94777900E+00, 0.60241100E+00, 0.33248800E-01, -.12086400E+00, 0.31843100E+00, -.17537600E-01, 0.48211600E+00, -.35731100E-01, -.11671500E+00, 0.36354700E-03, 0.11819200E-01, 0.14930700E-01, -.41658000E-01, -.50857100E-02, -.19608800E-01, -.57464500E-01, 0.14178100E-01, 0.71902900E-01, 0.11789100E+00, 0.40780500E-01, -.10824200E-02, 0.29952700E-01, -.24683900E-01, -.21632000E-02, -.55228500E-01, 0.24571500E-01, 0.22623000E+00, 0.41223200E-01, -.99749800E-02, -.11058100E-02, -.20824900E+00, -.53706200E-02, 0.16069200E+00, -.16267100E-01, 0.49644600E+00, 0.83353700E-02, -.23787900E+00, -.21700100E+00, -.74782300E-02, -.59651300E+00, -.47454200E+00, 0.26322900E-01, 0.66997700E-01, -.59416000E+03, -.12319200E+04, 0.27435000E+03, -.72827700E+03, 0.18030700E+03, -.95223000E+03, -.10320700E+03, 0.19977900E+04, -.99991200E+03, 0.54618000E+03, -.99889200E+03, -.26444800E+01, -.23486500E+02, -.17510100E+03, 0.60424000E+03, -.68560300E+03, -.27549000E+01, -.11730300E+04, 0.32756100E+03, -.15957200E+03, 0.13020200E+04, -.16377800E+03, 0.18561400E+03, 0.44709800E+03, -.26216500E+03, -.15915900E+03, -.14598500E+03, 0.14127000E+03, 0.99514900E+02, 0.62657000E+04, -.31160900E+04, -.32834600E+04, -.31329900E+04, -.46316000E+03, 0.39827500E+03, -.16342900E+04, 0.37805300E+03, -.16403200E+04, -.11050100E+03, -.15842200E+04, -.26280200E+04, 0.13021100E+04, -.13280000E+04, 0.13139300E+04, -.10946300E+03, -.49194000E+03, 0.64515900E+03, -.40185900E+03, 0.10437000E+04, -.13745500E+03, 0.84831600E+03, -.16082800E+04, 0.80282500E+03, 0.22016500E+04, 0.80415100E+03, 0.54377700E+02, -.72527400E+02, 0.22729600E+03, -.64534600E+03, 0.47780400E+03, -.24995700E+03, 0.67324700E+03, 0.34438700E+04, -.17394300E+04, 0.45891600E+03, -.17221600E+04, -.11159400E+03, -.48999800E+03, -.17588400E+03, 0.55757900E+03, -.89747500E+03, -.32457400E+03, -.19544600E+04, 0.26754800E+03, -.12781500E+03, -.36168500E+03, -.13373900E+03, -.10527200E+02, 0.35943600E+01, -.19468700E+03, -.24884200E+03, -.22863800E+03, 0.48610900E+02, 0.25640700E+01, 0.13976700E+03, -.65361100E+02, -.53898000E+03, -.69820600E+02, 0.22908400E+02, 0.46407400E+02, -.19312700E+03, -.32804000E+03, -.20522900E+03, 0.89484300E+02, -.13822200E+01, -.38497800E+04, 0.19225900E+04, 0.48810500E+03, 0.19248300E+04, 0.18824600E+03, 0.23239300E+02, 0.56146500E+03, -.44108800E+03, 0.94974000E+03, 0.79932900E+02, 0.16829200E+04, -.37148100E+03, 0.18378700E+03, 0.64155900E+02, 0.18566300E+03, -.21646300E+02, -.17341400E+03, 0.22867000E+03, 0.29985800E+03, 0.42972700E+02, 0.41684600E+01, -.22574700E+02, 0.12870300E+04, -.67625900E+03, 0.48693100E+04, -.64423100E+03, 0.15115700E+03, -.26066800E+03, 0.26728600E+03, 0.91155500E+03, -.34722200E+03, -.81038600E+02, -.10575100E+04, 0.40305800E+03, -.20518800E+03, 0.12381700E+04, -.20165100E+03, 0.49189900E+03, 0.69518600E+03, -.40393900E+03, 0.20121100E+03, -.27546600E+03, 0.49707100E+03, -.24868800E+03, -.38646000E+03, 0.20038600E+03, -.45464400E+03, 0.19341000E+03, -.96425100E+02, -.17751500E+03, -.19409400E+02, -.38551900E+03, 0.18426300E+02, -.12575100E+03, 0.24843900E+03, -.28754400E+04, 0.14193800E+04, 0.54089600E+04, 0.14378000E+04, 0.54416800E+03, 0.69986400E+03, 0.32721200E+03, -.69400300E+03, 0.59627400E+03, 0.41474700E+03, 0.99136700E+03, 0.40764800E+04, -.20388000E+04, -.13159700E+04, -.20381800E+04, -.43255200E+02, 0.98451100E+02, -.74263200E+03, 0.53526700E+03, -.13815200E+04, 0.97135700E+02, -.18756400E+04, 0.16450700E+03, -.81416000E+02, 0.27392200E+02, -.82374100E+02, 0.12979100E+02, 0.82056600E+02, -.11519400E+03, -.11272400E+03, -.77682700E+02, -.68395900E+01, -.36440300E+02, 0.68291700E-01, 0.28579800E+02, -.22833900E+02, 0.98342500E+01, 0.23401700E+02, 0.43504000E+02, -.48247100E+02, 0.15252100E+02, -.18779200E+03, -.78687300E+02, -.80174300E+02, -.64836900E+03, -.24498300E+03, 0.37987200E+02, -.56268500E+02, 0.46123200E+02, -.10804800E+04, 0.27809600E+03, 0.60038000E+02, -.40145600E+01, -.18251300E+02, -.13989700E+03, -.22761200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42073200E+00, -.68119600E+00, 0.13277100E+00, -.70028800E+00, -.30309500E+00, 0.36585600E+00, -.18974100E+00, -.32918400E+00, -.89991300E+00, -.63930100E+00, 0.49241600E-01, 0.33755500E+00, 0.29095400E+00, -.19992800E-01, -.43227600E+00, 0.34301300E+00, 0.92390600E+00, 0.66210700E-01, -.14543300E+00, -.13981400E-01, -.20026700E+00, -.64598100E-01, -.58418700E+00, 0.40131900E-01, 0.33876100E+00, -.15474700E-01, 0.59070100E+00, 0.22401800E-01, 0.36962300E-03, 0.70556400E-01, -.21854300E+00, 0.18781300E+00, -.51636400E-03, 0.71132400E-01, -.11566600E+00, 0.44399400E-01, 0.42926200E-03, -.14651000E+00, 0.35543700E+00, -.47382900E+00, 0.76033300E-01, 0.16610400E+00, -.17496400E+00, 0.16942400E+00, -.46698300E-01, -.26076400E-01, -.63974000E+00, 0.30007100E-01, 0.31979900E+00, -.46592600E-01, 0.54031100E+00, -.47107000E-01, -.55141500E-01, -.88001100E-01, 0.13468500E+00, -.25583200E+00, -.53338600E+00, -.11628300E+00, 0.24298700E+00, -.20554700E+01, -.16786900E+04, 0.47284800E+03, -.19804800E+04, 0.10077600E+04, -.12002900E+04, 0.63890300E+03, 0.61215900E+04, -.30755400E+04, 0.60831900E+03, -.30607900E+04, -.73957200E+02, 0.83175200E+02, -.53796400E+03, 0.21922700E+04, -.18720600E+04, 0.21480300E+03, -.41202100E+04, 0.29586000E+03, -.95126600E+02, 0.11240600E+04, -.14792100E+03, 0.36286900E+03, 0.99544600E+03, -.52501200E+03, -.10376700E+04, -.13107700E+03, 0.14749100E+03, -.13843000E+03, 0.22868600E+05, -.11293900E+05, -.80800300E+04, -.11434800E+05, -.10277900E+04, 0.19607300E+04, -.58134500E+04, 0.27896400E+03, -.47237200E+04, 0.29481500E+03, -.11745000E+05, -.26513500E+04, 0.12038100E+04, -.15122500E+04, 0.13254100E+04, -.58980300E+03, -.10848500E+04, 0.88998100E+03, -.33246800E+03, 0.10832500E+04, -.14551400E+03, 0.27670600E+04, -.23088900E+04, 0.11676800E+04, 0.48860100E+04, 0.11544800E+04, 0.82727600E+03, 0.62224600E+03, -.15919300E+03, -.21562100E+04, 0.23695400E+03, 0.47752500E+02, 0.27749300E+04, 0.59002500E+04, -.30984300E+04, -.59036400E+03, -.29508600E+04, -.73321500E+03, -.24761800E+04, 0.71862700E+03, 0.15692600E+04, -.52706000E+03, -.18368300E+04, -.30997600E+04, -.68843100E+03, 0.33018900E+03, -.57469400E+03, 0.34434300E+03, 0.16701200E+03, 0.37395100E+03, -.37183500E+03, -.79331800E+03, -.72119200E+03, 0.51166400E+03, 0.69316200E+03, -.95210200E+03, 0.47888400E+03, -.76495600E+03, 0.47626500E+03, 0.23246500E+03, 0.40459000E+03, -.41626900E+03, -.11847700E+04, -.78429100E+03, 0.53196400E+03, 0.66998600E+03, -.10963100E+05, 0.54923200E+04, 0.11261100E+04, 0.54813400E+04, 0.57530600E+03, 0.40217300E+03, 0.12514000E+04, -.13529300E+04, 0.18233700E+04, 0.58782400E+03, 0.74581400E+04, -.15400400E+04, 0.74467400E+03, 0.58670900E+03, 0.76976700E+03, 0.19257600E+03, -.30374400E+03, 0.83651000E+03, 0.17514500E+04, 0.13549400E+03, 0.16846600E+03, 0.67975700E+03, -.22070800E+04, 0.79444000E+03, 0.65365900E+04, 0.11011700E+04, -.14823800E+04, -.26580700E+04, 0.19890900E+04, 0.13938300E+04, 0.19089300E+04, -.19144800E+04, 0.12596800E+04, 0.14826100E+04, -.76673600E+03, -.35991900E+02, -.74146200E+03, 0.29298700E+03, 0.11230300E+04, -.81950400E+03, 0.35957800E+03, -.25322900E+03, 0.73780600E+03, -.12484200E+04, -.12650100E+04, 0.69351400E+03, -.36350900E+03, 0.63309100E+03, 0.36758900E+03, 0.38955500E+03, -.27048400E+03, -.14060700E+04, -.39286600E+03, 0.44759900E+03, 0.11758200E+04, -.11024100E+05, 0.53562700E+04, 0.99507100E+04, 0.55123200E+04, 0.33053700E+03, 0.11058300E+04, 0.69337500E+03, -.44646400E+04, 0.16192300E+04, 0.44583700E+03, 0.68851700E+04, 0.96503500E+04, -.48663700E+04, -.46840800E+04, -.48249700E+04, -.14611300E+03, 0.21926100E+03, -.19274500E+04, 0.99152400E+03, -.28003800E+04, 0.28125700E+03, -.53601700E+04, -.51509100E+03, 0.26295300E+03, 0.40840000E+03, 0.25715100E+03, 0.33027200E+03, 0.35945700E+03, -.37402600E+03, -.89879100E+03, 0.38025000E+02, 0.99557000E+02, 0.74461200E+03, -.15053600E+03, 0.26856300E+03, 0.11646800E+03, -.84485100E+01, -.13129700E+03, -.96061100E+02, -.28959500E+03, -.91400900E+02, -.42086500E+03, -.37148900E+03, -.20776900E+03, -.15729200E+04, -.39151500E+03, -.86641900E+02, 0.29341400E+02, -.33271200E+02, -.37980100E+04, 0.39892400E+03, 0.99183100E+02, 0.78935000E+02, 0.35339600E+03, -.23603600E+03, -.25108900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.33840600E+01, -.36653400E+01, -.58751600E+00, -.11221300E+01, 0.14654200E+01, 0.14556300E+01, -.70685500E+00, 0.30514400E-01, 0.48070400E+02, -.76088700E+00, 0.12664900E-01, 0.17314300E+01, 0.84235400E+00, -.12165800E+00, 0.25707600E+01, 0.43025600E+01, 0.91052300E+01, 0.45725400E+01, 0.25014900E+00, -.52089000E+01, 0.23209200E+01, -.60755500E+00, 0.71076700E+01, -.10638500E+01, -.12028700E+01, -.38994800E-01, -.36474900E+01, -.54373000E+00, 0.28046800E+00, -.20164500E+00, 0.86438300E+00, 0.76252600E+00, -.38956100E+00, 0.15810100E+01, 0.14005900E+01, -.27519300E+00, -.12822400E+00, 0.75700300E+00, -.38796900E+01, 0.69897600E+00, -.17238400E+01, -.13724200E+01, -.21254600E+01, -.20537600E+01, -.56048100E+00, -.38382900E+00, 0.23282200E+01, 0.79637800E+00, -.34412000E+01, 0.38372100E+00, 0.28457200E+01, 0.21001900E+01, 0.27245300E+01, 0.12850500E+01, 0.17490300E+00, 0.12148400E+02, 0.37403200E+00, 0.65333100E+00, -.16904100E+01, 0.67622100E+01, -.29961100E+01, -.48188500E+04, -.93717200E+04, -.59469200E+04, 0.12318900E+04, -.81348600E+03, 0.15883900E+05, -.80425300E+04, -.78310000E+04, -.79424100E+04, 0.71613600E+04, 0.29598300E+04, -.17088600E+04, 0.92113300E+04, -.48248600E+04, 0.96928100E+03, -.86221200E+04, -.11057800E+05, 0.58450600E+04, 0.16271400E+05, 0.55286200E+04, -.11309000E+04, -.11570200E+04, 0.24534100E+04, -.58679400E+04, -.20801400E+04, 0.61467900E+03, 0.64773800E+04, -.39897400E+05, 0.20567100E+05, 0.22651300E+05, 0.19970600E+05, 0.17588200E+05, 0.95797300E+04, -.16642000E+04, -.26460900E+05, 0.15020800E+05, 0.16287800E+04, 0.10609500E+05, 0.15618300E+04, -.14739800E+04, -.15000000E+05, -.77081300E+03, -.34008400E+04, -.54685900E+03, -.24827900E+04, -.50561200E+04, 0.37956200E+03, 0.20905700E+04, -.22830600E+04, 0.18195100E+05, -.89015300E+04, 0.41748900E+03, -.90991600E+04, -.92563300E+03, 0.51674100E+04, -.10580000E+05, -.12200700E+05, -.14717100E+05, 0.11550300E+05, -.90928200E+04, 0.54122100E+05, -.27824600E+05, -.16716700E+05, -.27055400E+05, -.38777000E+04, 0.10935300E+03, -.26769500E+04, 0.18176600E+05, -.10010800E+05, -.46349700E+04, -.19081400E+05, -.23494300E+05, 0.11501800E+05, 0.97124400E+04, 0.11771600E+05, 0.12901800E+04, 0.52472200E+03, 0.72380300E+04, 0.28276500E+04, 0.59263000E+04, 0.79460500E+03, 0.86813700E+04, -.20083600E+05, 0.99701400E+04, 0.83482000E+04, 0.10064100E+05, 0.15345200E+04, 0.13336900E+04, 0.63189400E+04, 0.27456100E+04, 0.43715500E+04, 0.18484000E+04, 0.72994700E+04, -.75143600E+04, 0.39646000E+04, 0.31019500E+04, 0.37660000E+04, -.50515500E+04, -.50518700E+04, 0.13763800E+04, 0.39176400E+04, 0.39356400E+04, 0.14950900E+04, -.12471800E+04, 0.33293900E+05, -.16791500E+05, -.19318000E+05, -.16636000E+05, -.56739100E+04, -.46443500E+04, -.17889600E+04, 0.15014600E+05, -.76292200E+04, -.64325200E+04, -.92289200E+04, 0.11272300E+06, -.58061400E+05, -.29889200E+05, -.56283600E+05, -.69993500E+04, -.73079800E+04, -.13316100E+05, 0.29550900E+05, -.22629800E+05, -.69031700E+04, -.52303800E+05, -.38474500E+04, 0.18200900E+04, 0.10083900E+05, 0.19498500E+04, -.44860000E+04, -.12945700E+05, 0.69120100E+04, 0.37314900E+04, 0.27733900E+04, -.88753700E+04, 0.47429500E+04, -.11125900E+05, 0.58798700E+04, 0.36624800E+04, 0.55536700E+04, 0.10230300E+04, 0.88424600E+02, 0.24445100E+04, -.20301500E+04, 0.81695000E+03, -.23179400E+03, 0.53744000E+04, 0.48514300E+05, -.25046600E+05, -.55477900E+04, -.24270100E+05, -.23032400E+04, 0.22318700E+04, -.15660000E+05, -.43594400E+04, -.23892600E+05, 0.10756500E+05, -.26761100E+05, 0.33246500E+05, -.17010400E+05, -.10655300E+05, -.16632200E+05, 0.44568900E+04, -.11304100E+03, -.57893800E+04, 0.99211600E+04, -.49710000E+04, -.48477100E+04, -.11141300E+05, -.25270600E+04, 0.12842900E+04, 0.61730000E+04, 0.12740700E+04, -.15947000E+04, -.11687200E+04, -.61480900E+03, -.18430700E+04, 0.18848700E+04, -.51892100E+03, 0.37012800E+03, 0.19912200E+03, -.12701200E+04, -.10374200E+04, 0.90974000E+02, -.36675700E+03, -.40295000E+03, 0.15866100E+03, 0.10503800E+04, -.18024500E+04, -.32020400E+04, -.13883800E+04, 0.49689600E+04, 0.40421500E+03, -.68747700E+03, 0.63468600E+03, -.36271900E+04, 0.13587400E+04, 0.29461600E+04, -.23446900E+04, 0.15985400E+03, -.83770500E+04, -.10446200E+04, 0.10767800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.45148300E+00, 0.10114600E+00, -.95377800E-01, -.10437900E+01, -.20867200E+00, -.26310600E-01, -.17517900E+00, -.11462400E+01, -.11980700E+02, -.32863300E+00, 0.80799500E-01, 0.25508900E+00, 0.75754700E-01, 0.12030900E+00, 0.52835500E-01, 0.11914400E+01, 0.48079100E+00, -.10660300E+01, -.31186200E+00, -.66010200E-01, -.40126300E+00, -.27952600E+00, -.10089200E+00, -.23956800E+00, 0.50208800E+00, -.63244300E-02, 0.11547900E+01, 0.99988300E-01, -.27480700E-01, 0.29243900E+00, -.15990100E-02, 0.25743900E+00, 0.31114000E-01, 0.13509700E+00, 0.21365600E+00, 0.33910100E-01, -.30091100E-02, -.52002100E-01, -.20093200E+00, -.68212500E-01, -.49940500E+00, 0.49642300E-01, -.19005500E+00, -.80069400E-01, -.14218600E-01, 0.67412700E-02, 0.23062100E+00, 0.69552800E-01, -.23313200E-01, 0.51320000E-01, -.83683900E+00, 0.39866700E-01, 0.57718900E-01, 0.13754600E+00, -.21189500E+00, 0.67304900E+00, 0.47871300E+00, -.14533100E+00, -.27916100E-01, -.72376900E+00, 0.20084900E+00, 0.16065400E-01, 0.16528700E+04, 0.84806800E+03, -.19653000E+03, 0.16601200E+03, -.35889300E+04, 0.17998500E+04, 0.12896800E+03, 0.17944500E+04, -.32084200E+03, -.25479700E+03, 0.27541300E+03, -.14560200E+04, 0.11214000E+04, -.13560100E+03, 0.14343100E+04, -.63398600E+03, 0.30500400E+03, -.10993700E+04, 0.31697600E+03, 0.51823800E+03, -.95218400E+02, 0.33127300E+03, 0.64032600E+03, 0.41153500E+03, 0.30451200E+02, -.13590100E+03, -.40463300E+04, 0.19852200E+04, 0.43078800E+04, 0.20238800E+04, -.38099000E+02, -.46616500E+03, 0.19208900E+04, 0.21262800E+04, 0.36304400E+03, 0.74028500E+03, 0.67301800E+03, 0.28563000E+04, -.13977200E+04, 0.76527500E+03, -.14277100E+04, -.69918600E+03, -.36276900E+02, -.46202400E+03, 0.64301000E+03, -.87652100E+03, -.49905600E+03, -.36169300E+03, -.31728900E+04, 0.15833500E+04, -.41990800E+03, 0.15863900E+04, -.94569200E+02, -.12826000E+04, 0.15956800E+04, 0.14416900E+04, 0.21056700E+04, -.16324000E+04, 0.16542000E+04, -.49000600E+04, 0.24780100E+04, 0.24521400E+03, 0.24516400E+04, 0.13866300E+03, 0.68741100E+03, -.84317000E+03, -.23423900E+04, 0.40848600E+03, 0.93620700E+03, 0.16801200E+04, 0.14564200E+04, -.70193600E+03, -.21637600E+03, -.72886000E+03, -.12812000E+00, 0.53049000E+02, -.46872700E+03, -.23045500E+03, -.29040700E+03, -.98373000E+01, -.63355600E+03, 0.13319200E+04, -.65955900E+03, -.38667200E+01, -.66679100E+03, -.18025000E+02, 0.78950900E+01, -.38552600E+03, -.11848700E+03, -.19764400E+03, -.96181600E+02, -.61122900E+03, 0.28485900E+04, -.14317200E+04, -.75875800E+03, -.14240000E+04, -.17319200E+03, -.93361700E+02, -.10724100E+03, -.21423500E+03, -.30046300E+03, -.69350200E+03, -.35244000E+03, -.85963900E+03, 0.43697100E+03, 0.39208000E+03, 0.43022600E+03, 0.24295200E+03, 0.27734300E+03, -.29081200E+03, -.13335100E+04, 0.17865000E+03, 0.28741200E+03, -.21706500E+03, -.89956300E+04, 0.45811700E+04, -.27553900E+03, 0.45019800E+04, -.31443500E+03, 0.52933500E+03, -.51211100E+02, -.41000800E+04, 0.11646900E+04, 0.32620800E+03, 0.46170300E+04, 0.11381000E+03, -.46733700E+02, -.12498400E+04, -.57942300E+02, 0.54219000E+03, 0.10805100E+04, -.25740200E+03, -.52622800E+03, -.43890900E+03, 0.79826000E+03, -.25296500E+03, 0.12198500E+04, -.62479100E+03, -.27658500E+02, -.61113700E+03, -.29777600E+03, -.32433000E+03, -.99780200E+02, 0.45093900E+03, 0.16382400E+03, -.19625500E+03, -.60509800E+03, -.36929000E+04, 0.18914300E+04, -.18496900E+04, 0.18460800E+04, -.77991700E+03, -.14931500E+04, 0.18067600E+04, 0.83372300E+03, 0.23416000E+04, -.20385200E+04, 0.30987400E+04, -.59669200E+04, 0.29933500E+04, 0.29401500E+04, 0.29831500E+04, 0.43516600E+03, 0.40105000E+03, 0.63532400E+03, -.13560300E+04, 0.13474000E+04, 0.77097500E+03, 0.16061400E+04, -.98190800E+03, 0.48872400E+03, 0.99145200E+02, 0.49170000E+03, 0.63208800E+03, 0.18983200E+03, 0.16859900E+03, 0.10108100E+03, 0.27485600E+03, 0.17279900E+03, 0.24138700E+03, -.23372900E+02, 0.13128300E+03, 0.22640800E+03, -.20472900E+02, 0.47552600E+02, 0.42239900E+02, 0.22256000E+02, -.22956600E+03, 0.27452800E+03, 0.45473800E+03, 0.11414100E+03, -.98440700E+01, 0.39286700E+03, 0.75511200E+02, -.60305200E+02, 0.27859300E+03, 0.11800000E+04, -.44548400E+03, 0.22181900E+03, -.23808700E+02, 0.70403100E+03, 0.33158000E+03, -.13254600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15814100E+01, -.23218300E+01, -.47480700E+00, -.14806500E+01, -.35863800E+00, 0.12622900E+01, -.46350400E+00, -.19652200E+01, 0.75300600E+00, 0.85496200E-01, 0.86271500E+00, 0.14001700E+01, 0.53326500E+00, -.17592700E+00, 0.16708800E+00, 0.13336400E+01, 0.30990100E+01, 0.16248900E+01, 0.28625500E+00, 0.33136000E+00, 0.32411200E+00, -.14718700E+00, 0.34340400E+01, 0.90535500E+00, -.13711800E+01, 0.49771400E-01, -.18285600E+01, -.13309600E+00, 0.60794000E+00, -.88950500E-01, 0.86129200E+00, 0.12415800E+00, -.78798900E+00, -.92321000E-01, -.30876500E+00, -.36765600E+00, 0.20254400E-01, 0.13054800E+01, 0.17068500E+01, 0.14074400E+00, 0.12869900E+01, -.16147700E+00, 0.18739700E+01, 0.65893300E+00, -.12108400E+00, 0.15236300E-01, -.92491900E+00, -.12591300E+00, 0.54861300E+00, 0.14742100E+00, 0.20194900E+01, -.19849700E+00, -.51288600E+00, -.19985800E+00, -.12758300E+01, -.77724400E-01, -.11231100E+01, -.21925600E+00, -.38851000E+00, -.54848500E+01, -.11093900E+01, -.92132800E-01, -.99392400E+00, 0.26515600E+04, 0.26571900E+03, 0.10291000E+04, 0.10623100E+05, -.53506900E+04, -.24923100E+04, -.53115900E+04, 0.68347200E+03, 0.18254100E+04, -.29384000E+04, 0.13211700E+04, -.49094400E+04, 0.16661600E+04, -.47494000E+04, -.48995300E+03, 0.40072300E+03, 0.28685800E+04, 0.24494500E+03, 0.81590900E+03, 0.64489200E+04, -.48354400E+04, -.61933400E+04, -.43991800E+04, 0.54113500E+04, 0.64153800E+04, 0.27228100E+05, -.13415100E+05, 0.82912500E+03, -.13611900E+05, 0.72530000E+03, 0.16211100E+05, -.16435800E+05, -.79354700E+04, -.14101600E+05, 0.12577400E+05, -.53602800E+04, -.15202800E+05, 0.72690100E+04, 0.19553800E+04, 0.76024500E+04, 0.42620900E+03, -.76525700E+04, 0.91767100E+04, 0.53213800E+04, 0.11363400E+05, -.68398900E+04, -.31977300E+04, -.10284000E+05, 0.52611100E+04, 0.14113300E+05, 0.51418600E+04, 0.60185100E+04, 0.12622000E+04, 0.22638400E+04, -.15637100E+04, 0.32510900E+04, -.70558400E+03, -.30908300E+04, 0.16635700E+05, -.87029700E+04, -.30651000E+04, -.83167000E+04, -.13443000E+04, -.58096100E+04, -.27456300E+04, 0.32285400E+04, -.49911700E+04, -.50189200E+04, -.13027900E+04, 0.75722000E+03, -.31350300E+03, -.22004900E+04, -.37684300E+03, -.40883100E+03, -.99499100E+03, -.18909300E+03, -.40603900E+03, 0.56567900E+03, -.56179500E+03, 0.20596600E+04, 0.14446400E+04, -.68434100E+03, -.28430200E+04, -.72081200E+03, -.35456900E+03, -.13407300E+04, -.24229500E+03, -.98927700E+03, 0.21311500E+03, -.90888900E+03, 0.82428000E+03, -.24579100E+05, 0.12403400E+05, 0.53356100E+04, 0.12290400E+05, 0.19929200E+04, -.20737200E+04, 0.81159800E+04, -.10606600E+03, 0.99774600E+04, -.24219400E+04, 0.59967000E+03, 0.11200000E+05, -.56543600E+04, -.75916200E+04, -.55989300E+04, -.21086800E+04, -.30357400E+04, -.28779800E+03, 0.39511700E+04, -.35868700E+04, -.21073600E+04, -.13519600E+04, -.20631600E+05, 0.95662700E+04, 0.21397200E+05, 0.10324000E+05, 0.16480600E+04, -.67366500E+04, 0.59457000E+04, 0.29566900E+04, 0.31450600E+04, -.63056300E+04, 0.52756600E+04, 0.95111300E+03, -.48517400E+03, 0.12827900E+04, -.47330400E+03, 0.22066200E+04, 0.59062100E+04, -.58491700E+04, -.67832300E+04, -.70205300E+04, 0.52601000E+04, 0.41841600E+03, -.10782200E+04, 0.67610200E+03, -.77681600E+03, 0.53781100E+03, 0.35617200E+03, 0.15088100E+04, 0.74228700E+03, 0.52723700E+03, 0.24115200E+04, 0.11228100E+04, -.81599500E+03, -.39905200E+05, 0.19638800E+05, 0.29628000E+05, 0.19951300E+05, 0.54267700E+04, -.28421100E+03, 0.98408000E+04, -.39856100E+04, 0.10166700E+05, -.19105700E+04, 0.24406400E+04, 0.25388700E+05, -.12931100E+05, -.93588100E+04, -.12695200E+05, 0.28573500E+03, 0.49142600E+04, -.98219400E+04, -.27678800E+04, -.11177800E+05, 0.48675000E+04, -.96221300E+04, 0.89397300E+03, -.44337900E+03, 0.24672000E+04, -.44578900E+03, 0.20763400E+04, 0.18444300E+04, -.15533500E+04, -.17677400E+04, -.21378600E+03, 0.12957100E+04, -.31134600E+04, 0.17488800E+03, 0.30838800E+04, 0.27861200E+04, 0.13630300E+03, 0.62300300E+03, 0.74061400E+03, 0.99354300E+02, -.27124000E+04, -.18681500E+04, -.91109100E+03, -.78978000E+03, -.60454800E+04, 0.21083100E+03, 0.73206300E+03, -.82614700E+03, 0.88107100E+03, -.76487900E+04, 0.34560300E+03, -.86185200E+03, -.63682400E+03, 0.14101600E+04, 0.12626300E+04, -.31490200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44802200E+00, 0.84293300E+00, 0.50731600E-01, 0.40948600E+00, 0.12108100E-01, -.78934200E+00, 0.65180100E+00, -.19863500E+00, -.57108700E+01, 0.38356600E+00, 0.10414100E-01, -.33458900E+00, -.14380200E+00, 0.11564200E+00, -.44298300E+00, -.36081600E+00, -.63708000E+00, -.98095100E+00, -.16327900E+00, -.26878900E+00, -.52320400E+00, -.24744700E-01, -.51435600E+00, -.21791700E+00, 0.52205400E+00, -.12945700E-01, 0.76232500E+00, 0.68561500E-01, -.13213800E+00, 0.19570700E+00, -.39439800E-01, 0.75344400E-01, -.21562700E-01, 0.66128400E-02, -.18382000E+00, -.92790700E-02, 0.18183800E-02, -.29910900E-02, 0.29481700E+00, -.15284600E+00, -.41849900E+00, 0.11427400E+00, 0.47383100E+00, 0.28306900E+00, 0.92716900E-01, 0.41487400E-01, 0.32570000E+00, 0.81806900E-01, -.14760100E+00, -.29438500E-01, -.11374900E+01, -.69256200E-02, -.62598400E-02, 0.41075800E+00, -.23659100E+00, -.24528900E-01, -.37255500E+00, 0.61510000E-01, 0.15698100E+00, -.21815900E+00, 0.13001900E+00, 0.91665400E-01, -.12491500E+00, 0.11806200E+00, -.44744800E+03, 0.81731100E+02, -.75356300E+04, 0.37751000E+04, 0.21866700E+04, 0.37678500E+04, -.89707600E+02, -.16523400E+03, 0.48702000E+03, -.34019200E+04, 0.22472800E+04, -.60350800E+02, 0.19207900E+04, 0.28249600E+03, -.17070500E+03, -.21029300E+04, -.14122700E+03, -.23698700E+03, -.62606500E+03, 0.82819100E+03, 0.20445700E+04, 0.17318600E+04, -.85167300E+03, -.43508500E+03, -.60045600E+04, 0.29506100E+04, 0.27551100E+04, 0.30004400E+04, -.28879800E+04, -.22982900E+04, 0.28994800E+04, 0.21270900E+04, -.45537800E+03, -.54225000E+03, 0.25300500E+04, 0.65885900E+04, -.32256900E+04, -.25285300E+03, -.32951000E+04, -.35535800E+03, -.39809600E+03, -.52010300E+03, 0.20908900E+04, -.25089400E+04, -.64434800E+03, -.59520600E+03, -.58570700E+04, 0.29101600E+04, -.23689600E+04, 0.29286700E+04, -.11004800E+04, -.25136700E+04, 0.32342700E+04, 0.29877400E+04, 0.42500300E+04, -.31952900E+04, 0.47071900E+04, -.91450700E+04, 0.46412400E+04, 0.21921600E+04, 0.45726300E+04, 0.10778500E+04, 0.10070100E+04, -.18413200E+03, -.37710500E+04, 0.11618500E+04, 0.15069800E+04, 0.13609300E+04, 0.36817700E+04, -.17972200E+04, -.13330500E+04, -.18434800E+04, 0.32963900E+02, 0.41403200E+03, -.18855800E+04, -.17438400E+04, -.15917800E+04, 0.27866600E+03, -.15079600E+04, 0.39766500E+04, -.19798200E+04, -.12886800E+04, -.19908000E+04, -.58005700E+02, 0.19129200E+03, -.18186400E+04, -.14095300E+04, -.14113900E+04, 0.30958300E+02, -.16349000E+04, 0.84271100E+04, -.42345600E+04, -.28508300E+04, -.42142900E+04, -.18851400E+03, -.27226600E+03, -.92467600E+03, 0.16198600E+04, -.20304700E+04, -.10215600E+04, -.68387600E+02, -.48795900E+04, 0.24501900E+04, 0.26642100E+04, 0.24389000E+04, 0.15763500E+04, 0.10022400E+04, -.46344600E+02, -.27361300E+04, 0.14675900E+04, 0.11981000E+04, -.44632600E+03, -.13473700E+05, 0.69027700E+04, 0.17189700E+04, 0.67309900E+04, 0.43852000E+03, 0.14589200E+04, 0.17985100E+04, -.22419500E+04, 0.44772300E+04, 0.13354200E+04, 0.72746100E+04, 0.77955600E+03, -.37958900E+03, -.12630100E+04, -.39250400E+03, 0.11242800E+04, 0.16537600E+04, -.10801700E+02, 0.15077800E+04, 0.13054500E+04, 0.90653400E+03, -.17753500E+04, 0.15407200E+04, -.79972600E+03, -.37809200E+02, -.76995200E+03, -.21420000E+03, -.27412300E+03, -.67601600E+03, -.48388500E+03, -.83703700E+03, -.17495700E+03, -.70885500E+03, -.26139600E+04, 0.13814800E+04, -.25847000E+04, 0.13080800E+04, -.14105800E+04, -.14336800E+04, 0.31669600E+04, 0.50248200E+04, 0.53885400E+04, -.24607100E+04, 0.63745100E+04, -.99281800E+04, 0.50018500E+04, 0.45814900E+04, 0.49648300E+04, 0.38878200E+02, 0.11606600E+03, 0.15259000E+04, -.26022900E+04, 0.17263900E+04, 0.82724000E+03, 0.17729500E+04, 0.28080300E+01, -.35140400E+01, -.10298100E+04, -.21219000E+01, -.98247900E+02, -.37816600E+02, 0.26064800E+03, 0.45155800E+03, -.65261700E+03, 0.18578000E+02, 0.11823900E+04, -.92594300E+02, 0.41839100E+03, 0.47064100E+03, 0.33097200E+02, -.38502400E+02, -.37870100E+02, -.89983500E+02, -.50707300E+03, 0.51594100E+03, 0.24440400E+03, -.27166400E+02, 0.15754900E+03, 0.22370900E+03, 0.54093000E+02, -.62026000E+02, -.66972600E+02, 0.10028500E+04, -.50321600E+03, 0.80688200E+03, 0.57075300E+02, 0.89827600E+03, 0.70525600E+03, -.36855200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.95094500E+00, 0.33635500E+00, 0.18096200E+00, 0.10936700E+00, -.17095300E+00, 0.19571600E+00, 0.62985800E-01, -.49081000E+00, -.37808800E+01, 0.57871600E+00, -.16522600E-02, -.68225300E+00, -.28791800E+00, 0.13903500E+00, -.14820900E+00, -.15602200E+01, -.23449800E+01, 0.16542800E-01, 0.38958700E-01, 0.47284900E+00, -.83142800E-01, 0.12504700E+00, -.11700800E+01, 0.25026500E+00, 0.42050200E+00, -.10625300E-01, 0.81929000E+00, 0.16467200E+00, -.32064800E+00, -.24164900E+00, -.83721400E+00, -.10155700E+00, 0.13352100E+00, -.36286900E+00, -.23513700E+00, 0.38267900E-01, 0.20109500E-02, 0.16690500E+00, 0.39216400E+00, 0.82599700E+00, 0.12549800E+00, 0.45464100E-02, -.14906500E+00, 0.67370700E-01, -.56637700E-01, -.60918700E-01, -.53496500E-01, -.17805800E-01, 0.29293400E-01, 0.19602200E+00, -.10843100E+01, -.10464900E+00, -.12523400E+00, -.10840400E+00, 0.14618300E+00, -.10355900E+01, -.33616200E+00, -.34055500E-01, -.14617000E+00, -.12546200E+01, 0.41185100E+00, -.30006900E-01, 0.33254400E+00, 0.65399000E-01, -.52031200E+00, -.90067800E+03, -.97085300E+03, 0.48039100E+03, -.27429000E+03, 0.48543800E+03, -.65938500E+02, 0.12798900E+03, -.45447000E+03, -.14364600E+04, 0.23524300E+03, 0.62159300E+02, 0.10489900E+04, 0.23783300E+04, -.11724700E+04, -.68655800E+03, -.11891600E+04, -.35584500E+03, -.22904800E+03, -.88887500E+03, 0.67113700E+03, -.15931100E+03, -.20621600E+03, -.63732700E+03, 0.21674300E+04, -.10269100E+04, -.39718800E+03, -.10842700E+04, -.29786800E+04, -.26702000E+04, 0.61331800E+03, 0.22889800E+04, -.23029100E+04, -.25025500E+04, 0.39809200E+04, -.31285400E+04, 0.15255100E+04, 0.11565200E+04, 0.15640100E+04, 0.97291100E+03, 0.10213100E+04, 0.10551300E+04, -.15614000E+02, 0.78676300E+03, 0.99675600E+03, 0.66109500E+02, 0.26163300E+04, -.13038600E+04, -.84706700E+03, -.13081200E+04, -.36134800E+03, 0.60779800E+03, -.50895300E+03, 0.89582900E+03, -.67781900E+03, 0.50685800E+03, -.15820500E+04, -.29880200E+04, 0.14212300E+04, 0.15337300E+04, 0.14938100E+04, 0.88757400E+03, 0.96729900E+03, -.36644400E+03, -.98695100E+03, 0.12455700E+04, 0.89738600E+03, -.78313500E+03, 0.19076500E+04, -.85927500E+03, -.23036200E+03, -.95437700E+03, 0.82853900E+02, 0.42162800E+03, -.10882700E+04, -.10056100E+04, -.80725900E+03, 0.25508200E+03, -.67683000E+03, 0.12529600E+04, -.58976900E+03, -.11415800E+03, -.62697700E+03, 0.99365900E+02, 0.24713600E+03, -.76769600E+03, -.80819400E+03, -.58158700E+03, 0.11896800E+03, -.53418900E+03, 0.35321400E+04, -.17764600E+04, -.10864900E+04, -.17662900E+04, 0.75571700E+02, 0.71566900E+03, -.67118200E+03, -.18651300E+03, -.14021100E+04, 0.67992800E+03, -.17022800E+04, -.31316500E+04, 0.15549300E+04, 0.98217900E+03, 0.15655500E+04, 0.97841300E+03, 0.53560900E+03, 0.35112600E+03, -.11451800E+04, 0.12800600E+04, 0.58391000E+03, -.42052800E+03, -.35822300E+03, 0.76453200E+02, 0.56781800E+03, 0.17708900E+03, 0.10559500E+04, 0.21266300E+04, -.15964700E+04, -.13956800E+04, 0.52148400E+03, 0.20241400E+04, -.49153100E+03, 0.34592000E+03, -.17701500E+03, 0.23275400E+03, -.17290500E+03, 0.18695000E+03, 0.62019100E+03, -.99853200E+03, -.12806600E+03, 0.49067900E+02, 0.54647300E+03, 0.69656400E+02, 0.95037600E+03, -.44773000E+03, -.13040500E+03, -.47491500E+03, -.96883700E+02, 0.42476600E+03, -.80063500E+03, -.50372200E+03, -.56395900E+03, 0.34682300E+03, -.45907600E+03, 0.39281800E+04, -.20176400E+04, -.14771300E+04, -.19637700E+04, -.78872800E+02, 0.78009100E+03, -.70948900E+03, 0.81191800E+03, -.44155300E+03, 0.80597800E+03, -.11896900E+04, 0.26648400E+03, -.14290600E+03, 0.11266700E+04, -.13301700E+03, -.70475600E+03, -.61920300E+03, 0.11627400E+03, -.20674900E+03, -.53642500E+03, -.50351200E+03, 0.63078700E+03, 0.25926000E+04, -.12941300E+04, -.41417500E+03, -.12965800E+04, -.44956300E+03, -.16487100E+03, -.33414900E+03, 0.52607000E+03, -.88951100E+03, -.10600200E+03, -.73633900E+03, -.89820300E+01, -.45981700E+03, -.44542800E+03, -.55054100E+02, -.10807800E+02, 0.30398900E+01, 0.12202800E+02, 0.44842500E+03, 0.15715100E+03, 0.12472100E+03, 0.10491600E+03, -.26271300E+03, 0.24243100E+03, 0.40063300E+02, -.55039400E+02, 0.11756600E+03, 0.55193000E+03, -.14539000E+03, 0.63188500E+02, 0.40318400E+02, 0.15258300E+03, -.30561200E+03, 0.43603700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18788100E+00, 0.91455700E-01, 0.64976900E-01, 0.50175100E-01, -.13909700E-01, -.10873200E+00, 0.39029800E-01, -.15584700E+00, 0.13557300E+01, 0.19509600E+00, -.81864600E-03, 0.30232800E-01, -.12685600E+00, 0.65624600E-01, -.62449800E-01, -.17744700E+00, -.52310700E+00, -.11794900E+00, 0.11945700E-01, -.17778800E-01, 0.20707900E+00, 0.93908400E-01, -.11144100E+00, 0.69193600E-04, 0.89837600E-01, -.24398200E-02, 0.76112300E-01, 0.60056600E-02, -.18624300E-01, -.25583300E-01, -.95483400E-01, -.83759000E-01, -.62299700E-02, 0.53958700E-02, 0.63862900E-01, 0.57464400E-02, 0.31261600E-04, 0.59530400E-01, -.48467200E-01, 0.10398000E+00, 0.41578000E-01, -.18726400E-01, 0.11202400E+00, -.42957600E-01, -.13736500E-01, 0.17750700E-02, -.83563700E-01, -.15188200E-01, 0.10523700E+00, -.67380400E-02, 0.19385300E+00, 0.13795400E-01, -.78287100E-01, -.23110700E+00, -.44547700E-02, -.12104400E+00, -.80411300E-01, 0.49725300E-01, 0.21827500E-01, 0.67609700E+00, -.87130300E-01, 0.21750100E-01, -.27511000E-01, 0.14743500E-01, -.84921000E-01, 0.87584700E-01, -.10102500E+04, 0.51088700E+03, 0.81382900E+02, 0.50513900E+03, -.12360300E+03, -.67815000E+02, 0.77256600E+02, -.41426900E+03, 0.37363200E+03, -.53371900E+02, 0.60835400E+03, 0.29989500E+02, -.34650100E+02, -.18363500E+03, -.14985100E+02, -.17305300E+01, -.22528200E+03, 0.11700800E+03, 0.23348500E+03, 0.17517400E+03, -.17160500E+03, -.31285900E+03, -.95185500E+02, -.46284700E+01, 0.48009800E+03, 0.46880000E+02, -.42848000E+03, -.54996600E+03, 0.26261200E+03, 0.38675600E+03, 0.15975300E+03, -.99423500E+02, -.16220900E+03, 0.80074400E+03, -.35406300E+03, 0.48825100E+02, -.40070600E+03, 0.10599400E+02, 0.14041700E+03, -.79877400E+02, 0.17826800E+03, -.44460500E+03, 0.23759600E+02, -.60617900E+02, 0.20851100E+03, -.11121900E+03, -.46703000E+03, -.10420200E+03, -.10017100E+03, -.14467600E+03, 0.94049000E+02, 0.38230400E+03, 0.14265700E+03, -.21990600E+03, 0.59112800E+02, -.13734400E+04, 0.74537600E+03, 0.16289200E+03, 0.68646600E+03, 0.13282300E+03, 0.20931600E+03, 0.71474500E+02, -.43401900E+03, 0.38223000E+03, 0.20189000E+03, 0.37024800E+03, 0.47120700E+03, -.24311000E+03, -.11774100E+03, -.23632200E+03, -.45865900E+02, -.33891300E+02, -.15010400E+03, -.91477300E+02, -.13730300E+03, -.33962500E+02, -.19137100E+03, 0.30586800E+03, -.15905900E+03, -.35861600E+02, -.15357900E+03, -.35581400E+02, -.48531800E+01, -.14909700E+03, -.10252400E+03, -.86103100E+02, -.19701700E+02, -.83819800E+02, 0.13286600E+04, -.66730900E+03, -.39264600E+03, -.66461800E+03, 0.31472400E+01, 0.58708100E+02, -.31145100E+03, 0.10855600E+03, -.43422800E+03, -.76657300E+02, -.27595500E+03, -.12104600E+04, 0.61496000E+03, 0.48385600E+03, 0.60487300E+03, 0.20755300E+03, 0.19556000E+03, 0.16774800E+03, -.35699100E+03, 0.28870500E+03, 0.16425700E+03, 0.35862200E+03, -.57892100E+03, 0.40680300E+03, -.66001800E+03, 0.28684900E+03, -.44452800E+02, 0.13861700E+03, -.13469400E+03, -.62973100E+03, 0.18018400E+03, 0.22722000E+02, 0.39787300E+03, 0.52929600E+02, -.17688000E+02, -.25418000E+03, -.27332000E+02, -.20150700E+02, -.75829400E+02, 0.18758400E+03, 0.31004900E+03, 0.26870700E+03, -.13608800E+03, -.15159400E+03, 0.33492500E+03, -.19168900E+03, 0.92490400E+01, -.16711600E+03, -.60536900E+02, -.10334600E+03, -.82939800E+02, 0.10748400E+02, -.10419700E+03, -.46693800E+02, -.18133500E+03, 0.76417300E+03, -.32325600E+03, -.10847700E+04, -.38166800E+03, -.19480500E+03, -.23247400E+03, -.46774300E+02, 0.31895700E+03, -.34138900E+01, -.36498300E+03, 0.13955000E+03, -.15965900E+04, 0.81499700E+03, 0.88102200E+03, 0.79858600E+03, -.12400200E+03, -.11973400E+03, 0.28272700E+03, -.31246900E+03, 0.55170500E+03, -.27149900E+02, 0.57560600E+03, 0.34249700E+03, -.17339800E+03, -.89300000E+02, -.17161100E+03, -.15333400E+02, -.16413400E+02, -.11981500E+03, -.65540900E+01, -.10497700E+03, -.10407200E+02, -.14059700E+03, -.49240400E+01, -.33852800E+02, -.23281100E+02, -.13461500E+01, 0.40072800E+01, -.20878800E+01, -.25150400E+01, 0.22105700E+02, 0.11779800E+03, 0.61826100E+02, 0.27996100E+02, 0.22274000E+03, 0.88647100E+02, 0.80720400E+01, -.33076500E+01, 0.20207100E+02, 0.24412300E+03, -.78998400E+02, 0.71483200E+02, 0.47037200E+01, 0.58851400E+02, 0.87316000E+02, 0.27096500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.94045500E+00, -.25393200E+00, 0.22591200E+00, 0.43185700E+00, 0.23251700E+00, -.14126800E+01, 0.33301700E+00, 0.90554500E+00, 0.36086100E+01, -.26773700E+00, -.44097500E-01, 0.44994700E+00, -.67615800E+00, 0.16046700E+00, 0.90888200E+00, 0.14070700E+00, -.64142700E+00, 0.17787100E+01, 0.43946900E+00, 0.24628600E+00, -.15652600E+00, 0.10817400E-01, 0.14905600E+01, 0.25340400E+00, -.20159100E+00, 0.10152200E-01, -.44490300E+00, -.15103800E-01, -.92616800E-01, -.16870600E+00, 0.46876200E+00, -.12003000E+00, 0.54143900E-01, -.13942000E+00, -.95316500E-01, -.17196300E+00, 0.31605100E-03, 0.78263100E-01, 0.24052800E+00, 0.47718400E+00, 0.43594400E-01, 0.15947900E+00, 0.12331000E+01, 0.48053500E+00, -.90565300E-01, -.32957300E-01, 0.71729800E+00, -.57833800E-01, 0.34782000E-01, 0.27497200E+00, -.96179500E+00, 0.25720100E+00, 0.45683200E+00, -.34079300E+00, 0.43152300E+00, 0.10836300E+01, 0.41111200E+00, 0.83952800E-01, -.10642000E+00, 0.23048600E+01, -.34767000E+00, -.17850900E+00, 0.68360700E+00, -.32701500E+00, -.13887500E+01, 0.23064700E+00, 0.48163700E+01, -.45201600E+02, -.52543400E+02, -.11827600E+00, 0.23700700E+04, 0.19410700E+04, -.11810900E+04, -.93207500E+03, -.10215300E+04, 0.13753500E+04, -.32629100E+04, -.22685800E+04, 0.12737600E+04, 0.25073000E+04, 0.11342000E+04, -.75335300E+03, 0.21571600E+04, -.81539600E+03, -.19201800E+04, -.70284200E+03, 0.20406200E+04, 0.53197900E+04, -.13371100E+05, 0.69628600E+04, 0.96682500E+04, 0.66914000E+04, 0.25389200E+04, 0.88522900E+04, -.45419300E+04, -.11959000E+05, -.18266000E+04, 0.67166300E+04, 0.87030900E+04, 0.12768500E+04, -.94894800E+03, -.34258400E+04, -.63561700E+03, -.60447700E+03, -.47311000E+04, 0.32553200E+04, 0.43363800E+04, 0.28401200E+04, -.39793100E+04, -.32690200E+04, -.71063100E+04, 0.36361000E+04, 0.18953700E+04, 0.35527200E+04, 0.18481100E+04, -.85402500E+03, 0.27321200E+04, 0.74070600E+03, 0.26042600E+04, -.67680500E+03, 0.18598400E+04, 0.13615500E+05, -.71648400E+04, -.33096800E+04, -.68049000E+04, -.28415100E+03, -.12097600E+04, -.18338400E+04, 0.42380200E+04, -.42397500E+04, -.19098000E+04, -.57058900E+04, -.27487600E+04, 0.13765300E+04, 0.69627400E+03, 0.13796000E+04, 0.28043500E+03, 0.60899000E+02, 0.12193800E+03, -.11625300E+04, 0.69595900E+03, 0.91193800E+02, 0.10761400E+04, -.93359500E+03, 0.46834900E+03, 0.39935100E+02, 0.47132700E+03, 0.98308900E+02, -.43701000E+03, 0.12853200E+03, -.74155000E+03, 0.43016900E+03, -.33491700E+03, -.30033400E+03, -.25259400E+04, 0.13328200E+04, -.17383300E+03, 0.12653400E+04, -.55522600E+03, -.31616000E+04, 0.37632200E+04, 0.36948000E+04, 0.31930800E+04, -.22458600E+04, -.72027600E+03, 0.11795500E+05, -.59532600E+04, -.63747100E+04, -.58948000E+04, -.11458300E+04, -.18182400E+04, -.14730800E+04, 0.27966900E+04, -.27212600E+04, -.16833400E+04, -.56854100E+04, 0.10537700E+05, -.60075300E+04, 0.34576500E+04, -.52464800E+04, 0.98747100E+03, -.10725600E+04, 0.11664000E+04, 0.10166300E+05, -.20486800E+04, -.12120100E+04, -.48269200E+04, 0.45853300E+00, -.41191000E+02, 0.29705200E+04, 0.74914200E+01, 0.54497200E+03, 0.11354400E+04, -.14080700E+04, -.18221800E+04, -.16629300E+04, 0.14922900E+04, -.76828600E+02, -.11068400E+04, 0.69492200E+03, 0.45755000E+03, 0.55005600E+03, 0.59256900E+03, 0.11113900E+04, 0.26900300E+03, -.39889300E+03, 0.53226600E+03, 0.64680600E+03, 0.11770900E+02, -.36316100E+04, 0.14580800E+04, 0.87032500E+04, 0.18123900E+04, 0.16537100E+04, 0.91717700E+03, 0.35190800E+04, 0.50048400E+04, 0.26121200E+04, 0.13581700E+04, 0.30578300E+03, 0.92673700E+04, -.48021500E+04, -.32602800E+04, -.46361000E+04, 0.10673300E+04, 0.30508100E+04, -.45335200E+04, -.22990300E+04, -.51765100E+04, 0.23084900E+04, -.53721200E+04, -.62442000E+03, 0.32158000E+03, 0.83272700E+03, 0.31542000E+03, 0.25583600E+03, 0.34879600E+03, 0.96063800E+02, -.14772200E+03, -.33807200E+03, 0.36982300E+03, 0.79156800E+03, 0.54872300E+02, 0.20210300E+04, 0.20127400E+04, 0.88902100E+02, 0.10605000E+03, 0.14439200E+03, 0.44768200E+02, -.20190000E+04, -.79366800E+03, -.12625100E+04, -.84669600E+03, -.15467100E+04, 0.92404700E+02, 0.14315400E+03, -.16097600E+03, -.66575100E+03, -.15932500E+04, 0.50063200E+03, -.33550000E+03, -.20220500E+03, -.85369400E+03, 0.13062200E+04, -.20008600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.23574700E+01, 0.47910400E+01, -.65464200E+00, 0.28835200E+01, 0.22199400E+01, 0.13728400E+00, 0.82394900E+00, 0.37485400E+01, -.26060900E+01, 0.16107200E+01, -.16041500E+01, -.28717800E+01, 0.24451100E+00, -.50402400E+00, 0.74190900E+00, -.30931600E+01, -.38275000E+01, -.70199600E+00, 0.70545500E-01, 0.14388000E+01, -.11150500E+00, 0.12159000E+01, -.34781900E+01, -.46001900E+00, -.77163300E+00, -.11564000E-01, -.73866300E+00, -.22744800E-01, 0.62492500E-01, -.66986500E+00, -.14481900E+01, -.93913300E+00, 0.70617100E+00, 0.26838200E+00, 0.68928500E+00, 0.52150800E+00, -.17355200E-01, -.47085600E+00, -.12699800E+01, -.65976200E+00, 0.11681500E+01, 0.96459700E-01, -.22487200E+01, -.10125800E+01, 0.17971900E+00, 0.21923900E+00, -.18191000E+01, 0.78456100E-01, 0.80260900E+00, -.50764200E+00, 0.36989400E+01, -.97845100E+00, -.11689900E+01, -.45806000E+00, -.13228500E+01, 0.80438400E+00, 0.18376700E+01, 0.29399100E+00, 0.15873700E+01, 0.99384900E+00, 0.14438900E+01, -.23469300E+00, -.62739200E+00, -.82702000E+00, 0.19060500E+01, -.66231000E+00, -.82152400E+01, 0.55506300E+00, -.65024400E+04, -.26898800E-01, -.34692000E+03, -.24190300E+03, -.73965600E+03, 0.32829900E+03, 0.13277600E+04, -.39152100E+03, 0.57240100E+04, -.19830200E+03, 0.13167900E+03, 0.32646600E+03, 0.99142200E+02, 0.14482800E+04, -.78765400E+03, -.93537000E+03, -.23209000E+04, -.27089300E+04, 0.78899000E+02, -.29459100E+04, 0.20972900E+05, -.10520400E+05, 0.23529400E+04, -.10485200E+05, 0.29710800E+04, -.95523100E+03, -.17516900E+04, 0.55380900E+04, -.42907900E+04, 0.16354900E+04, -.16324400E+05, -.65529200E+04, 0.32399800E+04, 0.53058800E+04, 0.32769400E+04, -.11322200E+04, 0.17944700E+04, 0.27031400E+04, -.90290800E+03, 0.18840300E+04, 0.73861700E+03, 0.20483400E+04, 0.11541900E+05, -.57139700E+04, 0.89004700E+04, -.57710400E+04, 0.84252500E+02, 0.27030300E+04, -.53339000E+04, -.21639700E+04, -.53560600E+04, 0.26785000E+04, -.10908100E+05, -.30594200E+04, 0.14659900E+04, -.24972700E+04, 0.15287400E+04, -.22815200E+04, -.18873700E+04, 0.73603300E+03, -.23492800E+04, 0.21710800E+04, -.21931200E+04, 0.65088300E+04, -.13807400E+04, 0.74712000E+03, 0.16589800E+04, 0.69287900E+03, -.25795700E+03, -.30953000E+03, 0.13903900E+04, 0.20278700E+04, 0.90081600E+03, -.37201300E+03, 0.11317300E+04, -.22745500E+04, 0.11748400E+04, 0.18588600E+04, 0.11398100E+04, 0.96139300E+02, 0.61216300E+03, 0.10784200E+04, 0.15309900E+04, 0.80334500E+03, 0.50567800E+03, 0.22377900E+04, -.39203400E+04, 0.20301500E+04, 0.49142500E+04, 0.19606700E+04, -.38080300E+03, 0.16007200E+04, -.12566500E+04, -.21719700E+04, 0.94705700E+03, 0.11942300E+04, -.27421000E+04, -.58061700E+04, 0.28869200E+04, -.75874100E+03, 0.29036800E+04, -.16723700E+04, 0.34541800E+03, 0.18722100E+04, 0.57660200E+03, 0.23371100E+04, -.54041800E+03, 0.73436200E+04, -.86488800E+04, 0.42358300E+04, -.99223500E+04, 0.43275100E+04, -.45989200E+04, -.10194200E+05, 0.12498300E+04, -.79743200E+04, 0.31991900E+04, -.10168700E+05, 0.63911100E+04, 0.98797600E+02, -.18179100E+02, -.53026200E+04, -.46950500E+02, -.85940500E+03, -.28141400E+04, 0.20467700E+04, 0.75622500E+03, -.56512200E+03, -.23456800E+04, 0.14266700E+04, -.57214100E+03, 0.30089500E+03, 0.92775800E+03, 0.28638200E+03, -.12671900E+04, -.13971000E+04, 0.10675000E+04, 0.69564300E+03, 0.48793700E+03, -.89242800E+03, -.68198200E+02, -.88123500E+04, 0.44384700E+04, -.55386100E+04, 0.44053900E+04, -.20912300E+04, -.87721400E+04, -.20700600E+03, -.71209700E+04, 0.16789900E+03, -.78524000E+04, -.18964400E+04, 0.19428800E+04, -.10569900E+04, 0.29688700E+04, -.97193600E+03, -.15708200E+03, -.83799800E+03, -.71621700E+03, 0.62176400E+03, 0.84349600E+03, -.60732100E+03, 0.28307500E+04, 0.38527600E+04, -.19312200E+04, 0.42712800E+04, -.19261600E+04, 0.66413500E+03, 0.11821500E+04, -.29438200E+04, -.21507900E+04, -.23557100E+04, 0.87335700E+03, -.50263900E+04, 0.38517200E+02, -.10371100E+04, -.10359600E+04, -.81240200E+02, 0.21796700E+03, 0.17839400E+03, 0.21691700E+02, 0.11548800E+04, 0.31591800E+02, 0.90063600E+03, 0.34496200E+03, 0.17465700E+04, 0.11316900E+04, 0.93701100E+02, -.96740700E+02, 0.41680100E+03, 0.16824500E+04, -.43448500E+03, -.46522200E+03, -.47815500E+02, -.16918500E+03, -.38953200E+03, 0.87968800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.44921200E+01, -.32819100E+01, -.13874300E+01, -.10244400E+01, 0.53317000E+00, 0.15441400E+01, -.10506500E+01, -.48371500E+01, -.53612500E+01, 0.74261200E+00, 0.25157000E-01, 0.99407500E-01, -.44158100E+00, 0.22534200E+00, -.15754100E+01, 0.19729400E+01, 0.24627800E+01, -.76013200E+01, -.12025000E+01, -.17364300E+01, 0.21254800E+01, -.12747600E+01, -.40346500E+01, -.17923500E+01, 0.78852500E+00, -.13235500E+00, -.32326000E+00, -.42842400E+00, 0.53200800E+00, 0.90271000E+00, 0.42004500E+00, -.17670600E+00, 0.13026000E-01, -.33720200E+00, 0.15144200E+00, -.96148100E-01, 0.59073500E-02, 0.62616300E+00, -.72998100E+00, 0.64650600E+00, 0.18019700E+01, -.66108900E+00, -.17199700E+01, -.14208200E+01, 0.16465200E-01, 0.54566100E-01, -.12367900E+00, -.11023500E+00, -.89041100E-01, -.75556500E-01, 0.27579600E+01, -.37187000E+00, 0.11274800E+01, 0.22691200E+00, -.86206300E-02, -.14571300E+01, 0.37995200E+00, -.28277700E-01, -.30612700E+00, -.95230700E+00, -.50385600E+00, -.69393300E-01, -.77478800E-02, -.17940200E+00, -.11707200E+01, 0.52014900E+00, -.94621300E-01, -.10173100E+00, 0.51013500E-01, 0.30034700E+02, -.42760100E+03, -.15155000E+03, 0.28473300E+03, 0.55724100E+02, -.72161000E+03, -.86658700E+02, 0.99444400E+03, -.17269800E+04, 0.87313300E+03, 0.12055900E+04, 0.86350900E+03, 0.57559200E+03, 0.40834800E+03, 0.45520600E+02, -.69147800E+03, 0.37028000E+03, 0.47917100E+03, 0.22364400E+03, 0.75808900E+04, -.37760400E+04, -.53110100E+04, -.37914600E+04, 0.46023900E+03, 0.10710500E+04, -.23183400E+04, -.63663100E+03, -.42458400E+03, -.15186900E+03, -.19796600E+04, -.31160700E+04, 0.15325700E+04, 0.53676500E+03, 0.15575000E+04, 0.21214000E+03, 0.74790000E+03, -.22958500E+03, -.12893700E+04, 0.70643700E+03, 0.63384500E+03, 0.53638200E+03, 0.96617500E+03, -.47909400E+03, 0.22561100E+04, -.48301100E+03, 0.70853300E+03, 0.89572700E+03, -.10734500E+04, -.13785500E+04, -.70515400E+03, 0.98770000E+03, -.13235300E+04, 0.29550100E+04, -.15074900E+04, -.10344200E+03, -.14787800E+04, -.36178400E+03, -.11251900E+04, 0.56101100E+03, 0.10787000E+04, -.84477400E+03, -.76599800E+03, -.73590000E+03, -.61659500E+03, 0.27022300E+03, -.47707200E+02, 0.30826500E+03, -.11583300E+03, -.13945000E+03, 0.36040300E+03, 0.37093500E+03, 0.19609200E+03, -.74000200E+02, 0.70704500E+03, -.59669500E+03, 0.29099200E+03, -.25031800E+03, 0.29847200E+03, -.61497400E+02, -.13828300E+02, 0.19011100E+03, 0.12179400E+03, 0.18986100E+02, 0.43555400E+02, 0.80537200E+03, -.27035400E+04, 0.13582100E+04, 0.15257000E+04, 0.13513600E+04, 0.52514000E+03, 0.95590500E+03, 0.39654600E+02, -.43820600E+03, 0.10548900E+04, 0.10105500E+04, -.21750700E+03, 0.35540500E+04, -.17763800E+04, -.12652500E+04, -.17775700E+04, -.85503200E+03, -.44530700E+03, -.23848800E+03, 0.13863600E+04, -.18556000E+04, -.38664500E+03, -.33801400E+03, -.36252100E+04, 0.17479900E+04, 0.41381300E+04, 0.18078500E+04, 0.36271200E+03, -.56615200E+03, 0.16599300E+04, -.96499400E+03, 0.22311100E+03, -.18202300E+03, 0.30754500E+03, -.10878400E+03, 0.48734700E+02, 0.23954100E+03, 0.57017100E+02, 0.20899400E+03, 0.76233700E+03, -.42871200E+03, -.10910700E+04, -.78925600E+03, 0.75519300E+03, 0.38189800E+03, -.54407800E+03, 0.28247400E+03, -.65986100E+03, 0.27309700E+03, -.74558300E+02, 0.60098500E+02, 0.17024500E+03, 0.85872900E+02, 0.42560600E+03, 0.10333400E+03, 0.42597300E+03, -.73555000E+04, 0.36512200E+04, 0.51048800E+04, 0.36783100E+04, 0.12060200E+04, 0.65630600E+03, 0.38313400E+03, -.34650800E+04, 0.85400100E+03, 0.10541300E+04, 0.50356000E+03, 0.68727800E+04, -.34468900E+04, -.34914400E+04, -.34359600E+04, -.20166500E+02, 0.11602500E+03, -.15449200E+04, 0.31215500E+03, -.18159600E+04, 0.91275400E+02, -.17324500E+04, 0.14688600E+04, -.73438900E+03, -.10996800E+04, -.73519300E+03, 0.26833000E+03, 0.17278600E+02, -.22696900E+03, 0.48229400E+03, 0.67156100E+03, 0.39784200E+02, -.11850600E+04, 0.70455300E+02, -.25831300E+03, -.31605600E+03, -.56296200E+02, 0.27233700E+02, 0.34898700E+02, 0.47280400E+02, 0.28280200E+03, 0.20195300E+03, 0.30089500E+02, 0.26404300E+03, -.11975700E+04, -.38287100E+03, 0.91752500E+01, -.32947400E+02, 0.21927700E+03, -.95191200E+03, 0.12989100E+03, 0.25612100E+02, -.45670700E+01, 0.24837900E+03, -.55112100E+03, 0.20619500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.98010300E+00, 0.32880800E+01, 0.21846300E-03, 0.23028800E+01, 0.29031200E+00, -.60148500E+00, 0.87442900E+00, 0.29020800E+00, -.13551200E+02, 0.14413800E+01, 0.49547800E-01, -.11071100E+01, -.43477400E+00, -.23877000E+00, 0.10393900E+01, -.21228500E+01, -.30032000E+01, 0.30695200E+00, 0.35475500E+00, 0.21187200E+01, -.64384700E+00, 0.51764900E+00, -.54987100E+01, -.20976900E+00, -.28553700E+00, -.66392800E-02, -.15907600E+00, -.25743600E-01, 0.73241700E+00, -.17194600E+00, -.91301800E-01, -.11764800E+01, -.19519900E+00, 0.28294100E+00, 0.80986700E+00, 0.11772000E+00, 0.45532100E-03, 0.22658000E+00, -.40239300E+00, 0.75909000E+00, -.18618700E+00, -.43579400E+00, -.83249900E+00, -.30687500E+00, 0.65259600E-01, -.31481600E-01, 0.28542000E-01, 0.63281500E-01, -.12268200E+01, -.18901600E-02, -.27129700E+01, -.33264900E+00, -.12643900E+01, 0.58382600E+00, -.79443800E-01, 0.11776700E+01, -.37182000E-02, 0.27318100E-01, 0.49722500E-03, 0.19637200E+01, 0.66864800E-01, -.30752200E+00, 0.27235400E+00, -.33354500E+00, 0.20569300E+00, 0.63196100E+00, -.90138900E+01, -.74539100E+00, 0.35405500E+00, -.44292500E-02, 0.31889400E+04, 0.22483300E+04, -.90125300E+03, 0.39724600E+03, -.89515400E+03, 0.16595200E+04, -.30152900E+04, -.59521700E+04, 0.29565700E+04, 0.58267300E+04, 0.29759900E+04, -.82039200E+03, 0.30730200E+04, -.79708900E+03, -.33380700E+04, -.58852000E+03, 0.30877300E+04, 0.76103200E+04, -.18410100E+05, 0.89542800E+04, 0.13008600E+05, 0.92116200E+04, 0.43266100E+04, 0.13862900E+05, -.10429300E+05, -.22543700E+05, -.35374700E+03, 0.11526600E+05, 0.13702800E+05, 0.65933600E+04, -.32199500E+04, -.76525500E+04, -.32934800E+04, -.11063600E+04, -.72726500E+04, 0.37808600E+04, 0.55901100E+04, 0.23784800E+04, -.63111600E+04, -.70339800E+04, -.11207700E+05, 0.56683200E+04, -.10147600E+04, 0.56033700E+04, 0.22505800E+04, -.19395300E+04, 0.36422200E+04, -.39874600E+03, 0.33889100E+04, -.10622400E+04, 0.29003800E+04, 0.22306600E+05, -.10957000E+05, -.67998200E+04, -.11149500E+05, -.16626700E+03, -.13463000E+04, -.79138600E+03, 0.10227400E+05, -.46577900E+04, -.31232900E+04, -.85885700E+04, -.56708800E+04, 0.26267300E+04, 0.27035300E+04, 0.28408500E+04, 0.80842200E+02, -.80757500E+03, 0.12901200E+04, -.63741000E+03, 0.21973700E+04, -.36161900E+03, 0.18281700E+04, -.35641600E+04, 0.16674400E+04, 0.23562300E+04, 0.17866600E+04, -.16711300E+03, -.13292600E+04, 0.12237300E+04, -.35855000E+03, 0.18201800E+04, -.83733400E+03, -.35575600E+02, -.20125600E+04, 0.11112400E+04, -.64859500E+03, 0.10089500E+04, -.11166300E+04, -.47302000E+04, 0.46412800E+04, 0.56122300E+04, 0.35585200E+04, -.35977400E+04, -.29005500E+04, 0.14455900E+05, -.71939700E+04, -.81415500E+04, -.72245700E+04, -.16075200E+04, -.27744100E+04, -.55208000E+03, 0.54039500E+04, -.37356500E+04, -.27575300E+04, -.58443800E+04, 0.36720400E+05, -.18067100E+05, -.23864900E+04, -.18334400E+05, 0.24001800E+04, 0.11838100E+04, -.22995500E+04, 0.19296100E+05, -.83939200E+04, -.15852400E+03, -.16283600E+05, -.49739700E+03, 0.29602300E+03, 0.64190100E+04, 0.25251800E+03, -.56994200E+03, -.29523700E+02, -.87773400E+03, -.14200200E+04, -.15534600E+04, 0.88521900E+03, 0.65168200E+03, -.47424600E+03, 0.14993500E+03, 0.14152500E+04, 0.23298600E+03, 0.78006000E+03, 0.12954800E+04, 0.36319500E+03, -.17161200E+03, 0.84581200E+03, 0.71728000E+03, 0.22479200E+03, 0.93613200E+04, -.45011500E+04, 0.74794300E+04, -.46845000E+04, 0.31255700E+04, 0.41826900E+04, 0.20120100E+02, 0.68667800E+04, -.31124500E+04, 0.45139200E+04, -.77685700E+04, 0.10929700E+05, -.55510600E+04, -.38803200E+04, -.54675900E+04, 0.15023300E+04, 0.49664400E+04, -.66254600E+04, -.32246000E+04, -.50530400E+04, 0.34332700E+04, -.49661000E+04, -.32701300E+04, 0.16221200E+04, 0.20479600E+04, 0.16388400E+04, 0.22819500E+03, 0.32764300E+03, -.27473100E+03, -.17091800E+04, 0.52071900E+03, 0.43392300E+03, 0.11838100E+04, 0.36063500E+02, 0.32041200E+04, 0.32295000E+04, 0.95366500E+02, 0.26290700E+03, 0.21421100E+03, 0.44101300E+02, -.32145000E+04, -.96550300E+03, -.23944700E+04, -.13739900E+04, -.47597300E+03, 0.16249100E+03, 0.27123700E+03, -.17175200E+03, -.11454900E+04, -.37201100E+04, 0.82699800E+03, -.81072800E+03, -.32956300E+03, -.19515000E+04, 0.25880300E+04, -.31885700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31071900E+00, 0.94655400E+00, -.62833600E-01, 0.47666800E+00, -.28154300E+00, -.79737500E+00, 0.75533300E-03, 0.30383600E+00, -.37807400E+01, -.19029700E+00, 0.44559700E-01, 0.36440200E-03, 0.64233600E-01, 0.14836800E-01, 0.22433700E-01, 0.10942200E+00, 0.77423200E+00, 0.38556700E+00, 0.71361900E-01, 0.51598500E+00, 0.40667400E+00, -.71756200E-01, 0.73250000E+00, 0.27198000E+00, -.25262700E+00, 0.23548700E-01, -.82475900E-01, 0.12399000E-02, 0.77146800E-01, -.21350600E-01, 0.16555600E+00, 0.92001400E-01, -.50817800E-02, 0.96560600E-01, 0.55901200E-01, -.63037700E-02, -.45642700E-02, -.42679000E-02, -.94537600E-01, 0.38531000E-01, -.20272400E+00, -.48829100E-01, 0.14867900E+00, -.13072800E+00, -.93155100E-01, 0.45718800E-01, -.41588100E-01, -.38017000E-01, -.12727800E+00, 0.89920400E-01, -.48686900E+00, -.78170700E-01, 0.54436400E-02, -.44854700E-02, 0.30156000E+00, 0.20195500E+01, 0.44525000E+00, -.39709500E-01, 0.14539100E+00, 0.43224500E+00, -.29521400E-01, 0.56390200E-01, -.48187900E+00, 0.69810400E-01, 0.57658300E+00, -.39315400E+00, 0.70387700E+00, -.58780900E-01, -.26734200E-01, -.77921300E-03, 0.21586300E-01, -.45608500E+03, 0.69007200E+03, 0.12740600E+04, 0.70126600E+03, -.30542600E+03, -.85230900E+02, 0.54885400E+03, -.27793400E+03, -.90511500E+03, -.27444600E+03, 0.42744300E+02, -.55162700E+03, 0.21315000E+03, 0.32439500E+03, 0.23904500E+03, -.58635900E+03, -.55761000E+03, 0.39138500E+04, -.19206400E+04, -.25526800E+04, -.19558800E+04, 0.93469100E+03, -.11028700E+04, 0.91356800E+03, 0.26939500E+04, 0.54446600E+03, -.11829800E+04, -.27985400E+04, 0.12930700E+04, -.64609200E+03, 0.41978300E+03, -.64598100E+03, -.40583100E+03, 0.80288000E+03, -.13650400E+04, -.16084500E+04, -.13679900E+04, 0.88657900E+03, -.73954500E+02, -.46709000E+03, 0.21446600E+03, -.41667100E+03, 0.23346600E+03, -.67622400E+03, -.34116700E+03, -.44025000E+03, -.13113400E+04, -.17588900E+03, -.94241000E+02, 0.46746500E+03, -.19000500E+04, 0.95546300E+03, -.52328100E+02, 0.95129200E+03, -.45240500E+03, 0.10507100E+03, 0.66938400E+03, -.14364900E+03, 0.90316200E+03, 0.21453900E+03, 0.13346500E+04, -.20339700E+03, 0.38375100E+02, 0.25166400E+03, 0.10178000E+03, -.33084500E+02, -.24521300E+03, 0.59713600E+03, 0.98681700E+03, 0.46642100E+03, -.20013400E+03, -.31373800E+03, -.16615200E+03, 0.59278500E+02, 0.33847000E+03, 0.82996100E+02, -.98265000E+02, -.26895700E+03, 0.70927600E+03, 0.11480300E+04, 0.52278300E+03, -.22677900E+03, -.35707800E+03, -.96603400E+03, 0.46599400E+03, 0.74469900E+03, 0.48343900E+03, -.37695900E+03, 0.34183400E+03, -.67143200E+03, -.14073200E+04, -.71645900E+03, 0.38529300E+03, 0.54845700E+03, -.14280200E+04, 0.71257700E+03, 0.11400100E+04, 0.71456900E+03, -.92741000E+02, 0.21301300E+03, 0.14547400E+03, -.64671000E+02, 0.44415600E+03, 0.18950700E+03, 0.10674100E+04, 0.91825300E+03, -.47566800E+03, -.24798400E+04, -.45426300E+03, -.71359200E+03, 0.37055300E+03, -.12237600E+04, -.22484500E+04, -.44522100E+03, 0.59245200E+03, 0.27185900E+03, -.60511900E+02, 0.15056400E+02, -.60820900E+03, 0.28703900E+02, -.32427600E+03, -.60798700E+03, 0.40331300E+03, 0.31868500E+03, 0.63802300E+03, -.49305800E+03, 0.48988500E+03, 0.34759300E+03, -.17030800E+03, -.48699800E+02, -.17486500E+03, -.17580700E+03, -.29783000E+03, 0.35228100E+02, 0.17597600E+03, -.43118000E+02, -.22709500E+03, 0.93835200E+02, 0.18791300E+04, -.96384700E+03, -.25366300E+04, -.94014600E+03, -.74649300E+03, -.11282800E+03, -.18764800E+04, -.26735100E+04, -.14694700E+04, 0.80410400E+02, -.50314300E+03, -.24457200E+04, 0.12509300E+04, 0.31693200E+03, 0.12224200E+04, 0.29870100E+03, -.30074500E+03, 0.12773900E+04, 0.11911800E+04, 0.13732100E+04, -.40104100E+03, 0.12907300E+04, -.27610000E+04, 0.13827800E+04, 0.59498700E+03, 0.13812800E+04, 0.10983900E+03, 0.60805200E+02, 0.40621100E+03, -.54942100E+03, 0.46083100E+03, -.94821800E+01, 0.11501700E+04, -.26731500E+02, -.40641500E+03, -.38869700E+03, -.15328500E+02, -.17095400E+02, -.42717400E+02, -.23634800E+02, 0.41021100E+03, 0.21604100E+03, 0.23660200E+03, 0.19636400E+03, 0.62796100E+03, -.89299500E+02, -.45195500E+02, 0.10053800E+03, 0.10763500E+03, 0.12558700E+03, -.98959500E+02, 0.22260900E+02, 0.31930400E+02, 0.10208200E+03, -.32859000E+03, 0.45528900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20594300E+00, -.65691700E+00, -.12738300E+00, -.28780600E+00, 0.17244800E+00, 0.71393300E+00, -.73230600E-02, -.50614700E+00, -.53179100E+01, 0.11143200E+00, 0.16442300E-01, -.23151000E+00, 0.27951000E+00, -.80408600E-01, 0.20829800E+00, 0.49801300E-01, -.24124700E+00, 0.45664000E+00, -.86668700E-01, 0.81055800E-01, -.94491900E-01, -.50872100E-02, 0.10480100E+01, -.18430400E+00, -.15016400E-01, -.50199200E-02, -.24751100E+00, 0.41140200E-01, -.18457400E+00, -.18978500E+00, -.32631700E+00, 0.31877300E-01, 0.51832800E-01, -.12939500E+00, -.44896600E-01, -.42905800E-01, 0.40829400E-02, 0.55711700E-01, -.31810400E+00, 0.18226600E+00, 0.24553200E+00, -.69724600E-01, 0.26264800E+00, 0.80779600E-01, -.19268200E-01, 0.36705500E-01, 0.16379400E-01, -.61618800E-01, 0.21738300E+00, -.40776700E-01, 0.89222800E+00, 0.32432400E-01, 0.18173400E+00, 0.43859900E+00, 0.16840100E+00, -.45348400E-02, -.40937900E+00, 0.20269000E-01, 0.41372100E-01, 0.78305300E+00, -.24336700E-01, 0.25290900E-02, 0.24370100E-01, 0.17742100E-01, -.88590300E-01, 0.18018500E-01, -.79232300E+00, -.13232000E+00, -.15561800E-01, 0.13570700E-03, 0.14838000E-02, 0.43707200E+00, -.13803000E+03, -.34342600E+03, -.13323600E+03, 0.15001400E+02, 0.94823100E+02, -.48467700E+02, 0.24809100E+02, 0.32276600E+03, 0.24245600E+02, -.25598700E+01, 0.14395600E+03, -.14734400E+03, -.19587900E+03, -.17460600E+03, 0.18176100E+03, 0.15936100E+03, 0.77689700E+03, -.40005800E+03, 0.14743900E+03, -.38911900E+03, -.35242700E+03, 0.28226100E+03, -.75756700E+03, -.78530300E+03, -.62453300E+03, 0.33814100E+03, 0.16508300E+03, -.66083700E+03, 0.33232800E+03, -.86544000E+02, 0.33006700E+03, 0.11446700E+03, -.10120500E+03, 0.45021600E+03, 0.41206900E+03, 0.41868900E+03, -.17949100E+03, -.37490300E+02, 0.61526500E+03, -.30185400E+03, -.70648300E+02, -.30758200E+03, 0.30265200E+03, 0.25764900E+03, -.12400300E+03, 0.23301800E+03, -.15537100E+03, 0.17541800E+03, -.64922400E+03, 0.47746200E+03, -.23594500E+03, -.35600400E+02, -.23946800E+03, 0.17677900E+03, -.38048700E+02, -.23507200E+01, 0.28448200E+03, -.78039800E+02, -.10858200E+03, -.13560100E+03, 0.12711400E+02, 0.75525900E+01, -.43138200E+02, -.65002200E+01, -.26568800E+02, 0.48897400E+01, -.11811300E+03, -.22797800E+03, -.84440800E+02, 0.18560800E+02, 0.12979000E+03, -.10589000E+03, 0.57312200E+02, -.70130400E+02, 0.52901700E+02, 0.56043900E+01, 0.38721200E+02, -.15073300E+03, -.28909200E+03, -.96748900E+02, 0.51825800E+02, 0.21087800E+03, 0.22487300E+03, -.10685300E+03, -.23766400E+03, -.11270800E+03, 0.94986100E+02, 0.40702600E+02, 0.12440100E+03, 0.31642400E+03, 0.18952300E+03, -.22144800E+02, -.43718500E+03, 0.49294700E+02, -.23573700E+02, -.13627000E+03, -.25002600E+02, 0.23269100E+01, -.55529700E+02, 0.11216800E+03, 0.10216000E+03, -.40992000E+02, -.69100100E+02, 0.40314700E+02, 0.56541700E+03, -.27257000E+03, 0.56374100E+03, -.28574400E+03, 0.29350300E+03, 0.17341100E+03, -.12875100E+02, 0.27176600E+03, -.19570600E+03, 0.82006300E+01, -.41113800E+03, 0.11248900E+02, -.78198400E+00, 0.21632500E+03, -.52059400E+01, 0.63378000E+01, 0.11704200E+03, -.12337800E+03, -.19518500E+03, -.18474700E+03, 0.10413700E+03, -.94576000E+02, 0.10693800E+02, -.77157900E+01, -.42808100E+02, -.47072500E+01, 0.27514800E+02, 0.70182500E+02, 0.55640900E+01, 0.30305900E+02, 0.45305800E+02, 0.58567400E+02, -.55778200E+02, 0.62690900E+01, 0.64320800E+01, 0.59840900E+03, -.27580200E+01, 0.36610300E+03, 0.33737600E+03, 0.24036400E+02, 0.19409900E+03, -.16126500E+02, 0.24633100E+03, -.54275300E+03, 0.69371600E+03, -.35446700E+03, -.64800700E+02, -.34657500E+03, -.13482900E+03, 0.17564100E+02, -.33562600E+03, -.32565700E+03, -.28203800E+03, 0.58865000E+02, -.22724000E+03, 0.61353600E+03, -.30744400E+03, -.27339300E+03, -.30724700E+03, -.51221500E+01, -.10566700E+02, -.16339400E+03, 0.44883300E+02, -.21409100E+02, 0.92300000E+00, -.36417200E+03, 0.15865200E+02, 0.71116000E+02, 0.65501800E+02, -.82427800E+01, 0.10499100E+02, 0.15019300E+02, 0.11699500E+02, -.67859300E+02, -.35915800E+02, -.61287800E+02, -.32954600E+02, -.17880700E+03, 0.57712100E+02, 0.14806400E+02, -.28730100E+02, -.43733400E+01, -.19660600E+03, 0.77502100E+01, -.16141200E+02, -.81239500E+01, 0.19647000E+02, 0.67195100E+02, -.82901400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37898200E+00, 0.20039100E+00, -.26104500E+00, -.50562600E+00, 0.33358900E+00, 0.55560900E-01, -.77810300E-01, -.18088500E+00, -.19842600E+01, -.17456000E+00, 0.24166600E-02, 0.28941500E+00, 0.10884700E+00, 0.50245900E-02, -.24917800E+00, 0.60856400E+00, 0.43507700E+00, -.71340400E+00, -.13811400E+00, -.12614300E+00, -.26413900E-01, -.20437100E+00, 0.84412100E-02, -.39105300E-02, 0.47784000E+00, -.81960500E-02, 0.49919600E+00, 0.54349000E-02, 0.19034300E+00, 0.18922100E+00, 0.14367800E-01, -.53179700E-01, 0.20710600E-01, 0.10100000E+00, 0.34686800E+00, -.42249000E-01, -.50159500E-02, -.20531500E+00, -.19964300E-01, 0.17719000E+00, 0.16304600E+00, 0.43899900E-01, -.29471900E+00, -.10834600E+00, -.10173500E+00, -.68026300E-01, 0.13666900E+00, 0.41425800E-01, -.69360500E-01, 0.13357100E+00, 0.70613000E+00, 0.32722000E+00, -.64237200E+00, -.13601800E+00, -.25209700E+00, -.37722200E-01, 0.71881700E+00, -.96515300E-01, -.60049200E-01, -.89256200E+00, -.10726200E+00, -.73950800E-01, 0.38269100E+00, 0.16928800E+00, -.33823700E-01, -.39543000E-01, -.16585100E-01, -.10085200E+00, 0.11007600E+00, -.15558000E-02, 0.17909500E+00, 0.39365400E+00, 0.33224800E+00, -.18168100E+03, -.78417000E+02, -.93623300E+02, -.55074200E+03, -.31643900E+03, 0.15741000E+03, -.33277800E+03, 0.15820500E+03, 0.12265400E+03, -.53508800E+03, 0.47502700E+03, 0.28961400E+03, 0.43928600E+03, -.50177800E+03, -.62883600E+03, -.10711800E+04, 0.56088000E+03, -.75096400E+03, 0.53654800E+03, 0.62704300E+03, -.11149100E+04, 0.19400000E+04, 0.19272100E+04, 0.94196700E+03, -.13881100E+04, -.17594700E+04, 0.64530600E+03, -.32509100E+03, 0.32816600E+03, -.32218300E+03, -.23649000E+03, 0.70081000E+03, -.82509600E+03, -.32162300E+03, -.73836500E+03, 0.71966300E+03, 0.14683700E+04, 0.78070300E+03, -.39889500E+03, 0.11146500E+04, -.39042300E+03, -.63673300E+03, -.75211300E+02, -.37616200E+03, -.53114900E+03, -.52287500E+03, 0.18822600E+03, 0.12050000E+04, -.19323800E+04, 0.94340700E+03, 0.38297300E+03, 0.96681900E+03, -.18570200E+03, -.10106900E+03, 0.67813400E+02, -.92499400E+03, 0.42004800E+03, 0.88125200E+02, -.47391800E+02, -.33322800E+03, 0.21290100E+03, 0.97609700E+02, 0.16730700E+03, 0.15054200E+03, 0.38260800E+03, -.16682000E+02, 0.41483700E+02, -.21488000E+03, 0.23619500E+03, -.59976100E+02, -.54064900E+03, 0.29134900E+03, 0.80248000E+02, 0.27089300E+03, 0.19765200E+03, 0.49368100E+03, -.31077900E+02, -.10000200E+02, -.17464800E+03, 0.35699600E+03, 0.19790000E+03, -.23787000E+03, 0.10357000E+03, 0.33529000E+03, 0.11932300E+03, -.13456600E+03, -.23394800E+03, -.77204700E+02, 0.18332000E+03, -.64733800E+01, 0.19909900E+02, 0.20322700E+04, 0.34890300E+03, -.17749500E+03, 0.14152000E+03, -.17396000E+03, 0.18124000E+03, 0.27961700E+03, -.34427200E+03, -.31587800E+02, 0.17965500E+03, 0.25754100E+03, -.10234900E+04, -.35359500E+04, 0.17473400E+04, -.98899000E+03, 0.17718100E+04, -.11243700E+04, -.21206300E+04, 0.12619900E+04, -.78761300E+03, 0.15949400E+04, -.16073700E+04, 0.15834900E+04, -.40643000E+03, 0.19868800E+03, -.93344000E+03, 0.20617200E+03, 0.11443100E+03, -.61460000E+03, 0.59925700E+03, 0.41747500E+03, 0.41230000E+03, -.53636000E+03, -.85120400E+02, -.46338400E+03, 0.24099800E+03, 0.47595300E+02, 0.23104300E+03, 0.29122200E+02, -.31201300E+03, 0.10195600E+03, 0.10596000E+03, -.81232300E+02, -.29667100E+03, 0.14174700E+03, -.19102300E+04, 0.93951600E+03, -.11141300E+04, 0.95456300E+03, -.12578200E+04, -.20044000E+04, 0.69738900E+03, -.83674600E+03, 0.73364900E+03, -.14250300E+04, 0.34133200E+04, -.61557000E+03, 0.32113700E+03, -.22247500E+03, 0.30738900E+03, 0.55388200E+03, -.53315400E+03, 0.80132500E+03, 0.10459800E+04, 0.57364600E+03, -.53801000E+03, -.97227100E+03, 0.73813400E+02, -.35556500E+02, -.58435200E+02, -.36338100E+02, -.77065000E+02, -.16385400E+03, 0.26444200E+03, 0.49015600E+03, 0.15983000E+03, -.92799500E+02, 0.40603800E+03, -.34501400E+01, -.38528300E+03, -.34019900E+03, 0.25136500E+02, -.88708200E+02, -.66748900E+02, -.26859700E-01, 0.32069800E+03, 0.77923500E+02, 0.10277300E+03, 0.55032800E+02, 0.45096900E+03, -.16538500E+03, -.10768300E+03, 0.73135200E+02, -.12943200E+03, 0.86466200E+03, 0.78970300E+02, 0.30486700E+02, 0.71406000E+02, -.25738000E+03, -.32152200E+03, 0.37274200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.84262700E+00, 0.34551600E+00, 0.13618700E+00, 0.12227600E+00, -.25771600E-01, 0.14600000E+00, 0.62939800E-01, -.22995700E+00, -.25320600E+01, 0.46106900E+00, -.37753400E-01, -.55681100E+00, -.33042100E+00, 0.10436400E+00, 0.76168500E-02, -.12254300E+01, -.19934000E+01, 0.21871600E+00, 0.83862100E-01, 0.44573800E+00, -.87900500E-01, 0.38390500E+00, -.92800000E+00, 0.31611200E+00, 0.24093400E+00, -.33977600E-03, 0.42735000E+00, 0.10304700E+00, -.21101900E+00, -.19121700E+00, -.50204300E+00, -.12043000E+00, 0.12461700E-01, -.34455100E+00, -.30131900E+00, 0.44712500E-02, 0.32118000E-02, 0.28852300E+00, 0.30327000E+00, 0.81353300E+00, 0.46984700E+00, -.58665400E-01, -.10085600E+00, -.26259800E+00, -.57357300E-01, -.29568400E-01, -.20043900E-01, -.15474900E-02, 0.35157300E+00, 0.54951700E-01, -.17398500E+01, -.40338700E+00, 0.39637400E+00, -.36378200E+00, 0.24814300E+00, -.85567900E+00, 0.74071700E+00, -.29564900E-01, -.10971100E+00, -.41834200E+00, 0.45914900E+00, -.36213800E-01, 0.93320100E+00, -.26872100E+00, -.88312800E+00, 0.85309400E+00, 0.10923800E+00, -.37163000E+00, 0.35830100E-01, -.14945800E-02, 0.20763300E+00, -.97013400E+00, 0.26149000E+01, -.10393400E+00, 0.40655000E+03, -.23060200E+01, 0.95088500E+02, 0.24451500E+04, -.12220700E+04, -.19850000E+04, -.12226400E+04, -.23505000E+03, 0.27356200E+03, -.86170700E+03, 0.78085200E+02, -.54162600E+03, -.27496100E+02, -.13804200E+03, -.68849300E+03, 0.41164700E+03, -.47678100E+03, 0.34796500E+03, -.12721600E+03, -.14165900E+03, 0.21525200E+04, 0.35232200E+04, -.11936100E+04, -.87515900E+03, 0.13631000E+04, -.20091500E+04, 0.98451000E+03, 0.15933000E+04, 0.10064800E+04, 0.28609600E+03, 0.12425700E+03, 0.22973700E+03, -.35458800E+03, 0.75331100E+03, 0.38161300E+03, -.42297200E+03, -.33905500E+04, 0.16684400E+04, 0.19728000E+04, 0.16949900E+04, -.35024000E+03, -.75348400E+03, 0.10567600E+04, -.87562100E+02, 0.13964600E+04, -.93509100E+03, 0.17313600E+03, -.16870200E+04, 0.80073500E+03, 0.10720000E+04, 0.84706500E+03, -.56303300E+02, 0.32237400E+03, -.10005500E+04, -.20610700E+04, -.66471600E+03, 0.77751800E+03, 0.14160500E+04, 0.32494000E+04, -.16448400E+04, -.15064200E+04, -.16233700E+04, -.15396500E+03, -.23206600E+03, -.90441300E+03, -.38395200E+03, -.64584100E+03, -.27684100E+03, -.47501000E+03, 0.42884900E+04, -.21393100E+04, -.18597500E+04, -.21434300E+04, -.35132800E+03, -.60925600E+03, -.69332700E+03, 0.12846600E+03, -.56693200E+03, -.62740900E+03, -.10969600E+04, -.17894500E+04, 0.86585400E+03, 0.78493300E+03, 0.89622800E+03, -.52969000E+02, 0.32966400E+03, 0.30377400E+03, -.14071200E+04, -.28731200E+02, 0.37124900E+03, -.30083700E+03, 0.14544600E+04, -.73076900E+03, -.35771700E+03, -.72527700E+03, -.81321900E+02, -.19200400E+02, -.80975300E+03, -.40514200E+03, 0.39130300E+03, 0.17936700E+03, -.49558500E+03, -.69646100E+04, 0.33985200E+04, 0.24025700E+04, 0.34985200E+04, 0.21403900E+03, 0.85859100E+03, 0.14268200E+03, -.27462900E+04, 0.63264100E+03, 0.13890300E+04, 0.30936900E+04, 0.28251700E+03, -.16460600E+03, -.60876600E+03, -.14026400E+03, 0.50616400E+03, 0.10748800E+04, -.10463100E+04, -.12187900E+04, -.63896100E+03, 0.10323100E+04, 0.35022800E+02, 0.16832900E+03, -.64229500E+02, -.39676300E+03, -.87371100E+02, -.27067800E+03, 0.10584600E+03, -.17669700E+03, -.23933500E+03, 0.50764500E+02, 0.71867300E+02, -.36124500E+03, -.39232100E+04, 0.19006400E+04, 0.13608100E+04, 0.19595000E+04, -.50357700E+03, -.87518700E+03, 0.13522400E+04, -.60753900E+03, 0.20597000E+04, -.88949900E+03, -.39634500E+02, -.20041600E+04, 0.10353700E+04, 0.65255600E+03, 0.10005200E+04, 0.20187800E+03, 0.40619000E+03, 0.58529600E+03, -.83248100E+02, -.38278400E+03, 0.39300600E+03, 0.13926200E+04, -.25358000E+04, 0.12719700E+04, 0.10805100E+04, 0.12704000E+04, 0.20073900E+03, 0.44046600E+03, 0.64956500E+03, -.29191000E+03, -.48336600E+03, 0.26474800E+03, 0.12962600E+04, -.11269000E+02, -.11392500E+03, -.19787100E+03, -.11289700E+02, 0.42628100E+02, 0.59728800E+02, -.18682600E+02, 0.21295300E+03, -.24081400E+02, 0.40723000E+03, 0.22281400E+03, -.58423800E+03, 0.10013900E+01, 0.12532600E+03, -.10529100E+03, 0.33262900E+03, 0.43635000E+03, -.19111000E+03, 0.11892400E+03, -.23771200E+02, 0.45051100E+03, -.30976800E+03, 0.20475500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14746100E+01, -.86564800E+00, -.31400400E+00, -.57811700E-01, 0.28497200E+00, 0.69142400E-01, -.18052800E+00, -.15799600E+01, -.12076500E+02, 0.37548800E+00, 0.13267400E-01, -.18020600E+01, -.35000600E+00, 0.25734200E+00, -.74876900E+00, -.73305900E+00, -.22147000E+01, -.18408600E+01, -.27356200E+00, -.24142900E+00, 0.33531300E+00, 0.22614300E+00, -.87816600E+00, -.47558500E-01, 0.86225600E+00, -.27388300E-01, 0.98447100E+00, 0.10887700E-01, -.19419400E+00, 0.30782700E+00, -.21257200E+00, -.51501300E-01, -.46028900E-01, 0.11586000E+00, 0.27267400E+00, 0.67408400E-01, -.25083600E-02, 0.13508500E+00, 0.67236400E-01, 0.18995300E+00, -.29649700E+00, -.10568100E+00, -.13464600E+00, -.30007800E+00, 0.45139700E-01, 0.70368400E-02, -.88345600E-01, 0.46169800E-01, -.15624800E+00, -.80266400E-01, -.21854600E+00, -.11224000E+00, 0.28903200E+00, -.70618400E+00, -.44062100E-02, -.32506000E+00, 0.22136400E+00, 0.20923400E+00, 0.17745000E+00, 0.26420600E+01, -.18709400E+00, 0.27065600E-02, -.22093000E+00, -.32007700E+00, -.29002500E+00, -.37994400E+00, 0.27931200E+01, 0.51952000E+00, 0.26917100E-01, 0.95425400E-03, -.22320800E+00, -.30192400E+00, 0.12725700E+01, -.17909300E+01, 0.43478800E+00, -.17725700E+03, -.47415000E+03, -.10704000E+04, 0.53267400E+03, -.41429100E+03, 0.53518000E+03, 0.18551100E+03, -.10813000E+04, 0.10491500E+04, 0.48389500E+03, 0.76742700E+03, -.11105200E+04, -.11063900E+04, 0.11172000E+04, -.49331500E+03, -.18717700E+04, -.55728200E+03, 0.86582400E+03, -.31897300E+04, 0.37026100E+04, 0.43522800E+04, -.14433900E+03, -.30513200E+04, -.44384400E+04, 0.29201000E+04, -.14555900E+04, -.11884400E+03, -.14593800E+04, -.58713500E+03, 0.11381700E+04, -.18925600E+04, -.87208200E+03, -.17664100E+04, 0.13015200E+04, 0.17674400E+04, 0.21560600E+04, -.11000900E+04, 0.29988900E+03, -.10781300E+04, -.14435100E+04, -.14214400E+03, -.10664700E+04, -.15796200E+04, -.14233600E+04, 0.39933000E+03, 0.21856000E+04, -.48116100E+04, 0.23774600E+04, 0.11307900E+04, 0.24068800E+04, -.34419700E+02, 0.48266300E+03, 0.55190700E+03, -.10694000E+04, 0.15875700E+04, 0.45634600E+03, 0.68012600E+03, -.13603000E+04, 0.75570200E+03, 0.96344600E+03, 0.68094600E+03, 0.24555000E+03, 0.54964700E+03, 0.59907200E+03, 0.88505200E+03, 0.15276300E+03, 0.37138800E+03, -.27207400E+03, -.21663700E+04, 0.11099600E+04, 0.11781200E+04, 0.10837800E+04, 0.33073400E+03, 0.71711700E+03, 0.72804400E+03, 0.81035500E+03, 0.40413900E+03, 0.55926800E+03, 0.26315900E+03, -.13306000E+03, 0.27169200E+02, 0.81132000E+02, 0.67068800E+02, -.39896100E+03, -.59643300E+03, -.42288900E+03, 0.11250600E+02, -.12432600E+03, -.10143500E+03, 0.32681000E+04, -.24206100E+04, 0.11974300E+04, 0.14167200E+04, 0.12109900E+04, 0.76404700E+03, 0.86714400E+03, -.14228100E+03, -.17303300E+03, 0.17740100E+04, 0.73393200E+03, -.44554000E+03, -.63560100E+03, 0.29952000E+03, -.40582900E+04, 0.32331700E+03, -.16078500E+04, -.24238300E+04, -.26602400E+03, -.19368100E+04, 0.90380200E+03, -.19070300E+04, 0.24643800E+03, -.11939800E+04, 0.58769700E+03, -.10195600E+04, 0.59991900E+03, -.14107000E+03, -.15616700E+04, 0.12069000E+04, 0.82445100E+03, 0.76264200E+03, -.14308100E+04, 0.51821300E+03, -.14495200E+03, 0.88041300E+02, 0.34527300E+03, 0.71444700E+02, 0.48351400E+00, -.66650000E+03, 0.23426600E+03, 0.57009000E+03, -.26588100E+03, -.63770000E+03, 0.21705100E+03, 0.34034100E+04, -.17255800E+04, -.47544300E+04, -.17024600E+04, -.24216600E+04, -.27285000E+04, -.12419300E+04, -.23817400E+04, -.12652700E+04, -.18814800E+04, 0.30326400E+04, -.30015300E+04, 0.15404300E+04, 0.69849600E+03, 0.15002200E+04, 0.95655100E+03, -.11995800E+04, 0.25438200E+04, 0.30258400E+04, 0.17490500E+04, -.12188200E+04, -.49365900E+03, -.84661900E+03, 0.42663300E+03, 0.79833600E+03, 0.42415700E+03, -.11125400E+03, -.36090000E+03, 0.74990000E+03, 0.73705200E+03, 0.22261900E+03, -.17601900E+03, 0.90934500E+03, -.35368600E+02, -.76307700E+03, -.56581200E+03, 0.62818100E+02, -.10340100E+03, -.88348600E+02, -.14567200E+02, 0.53854700E+03, 0.75175900E+02, 0.25131700E+03, 0.70010900E+01, 0.15220000E+04, -.18403300E+03, -.17620600E+03, 0.16167700E+03, -.33060100E+03, 0.16932400E+04, 0.11426700E+03, -.12945100E+03, 0.11382200E+03, -.55814000E+03, -.52916700E+03, 0.74576900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14697300E+01, -.69266400E+00, -.15665500E+00, -.30775700E+00, 0.18662400E+00, -.52107500E+00, -.77927600E-01, 0.32210300E+00, 0.14204600E+01, -.10858800E+01, -.11617600E-02, 0.94325500E+00, 0.77177300E+00, -.10392100E+00, -.22168500E+00, 0.23121800E+01, 0.34235900E+01, -.86695700E-01, -.15818700E+00, -.57494600E+00, 0.35602500E+00, -.64559300E+00, -.11614000E+00, -.28550800E+00, 0.32398000E+00, -.99219900E-02, 0.81952200E+00, -.15762400E+00, 0.10148900E+01, -.17429300E+00, 0.28463800E+00, -.15261200E-01, -.16859200E+00, -.18610300E+00, -.56303300E+00, -.18937700E+00, 0.49437200E-02, 0.13853600E+00, 0.64968500E+00, -.15317000E+00, 0.31346100E+00, -.23570000E-01, -.54880000E+00, 0.42167200E-01, 0.12663900E+00, 0.73622000E-01, 0.70565700E+00, 0.61687300E-01, -.41175800E+00, -.59936600E-01, -.15844800E+01, -.25384000E+00, 0.48853600E+00, 0.41309400E+00, 0.87010200E-01, 0.50878600E+01, 0.64608200E+00, -.23151200E-01, 0.74224500E+00, 0.24409600E+01, -.19054500E+00, 0.22760000E+00, -.80131800E+00, 0.20381000E+00, 0.14873100E+01, -.12998200E+01, 0.45898500E+01, 0.22749900E+00, -.10881200E+00, 0.21607900E-03, -.20246600E+00, 0.16621200E+01, -.29292000E+00, -.59519000E+00, 0.87936300E+00, -.35456100E+00, -.13129300E+04, -.13701400E+04, 0.68784100E+03, 0.12803700E+04, 0.68512300E+03, -.42967800E+02, -.36089100E+03, 0.27684100E+03, -.29821000E+03, 0.19765400E+03, -.45833600E+01, -.36174300E+03, -.47190100E+04, 0.23348000E+04, -.20637100E+03, 0.23563800E+04, 0.31293700E+03, -.15202200E+04, 0.11455900E+04, -.19603700E+04, 0.57596600E+03, -.54325200E+03, -.11265100E+04, 0.20217300E+04, -.99908200E+03, -.18035100E+04, -.10124900E+04, 0.80397700E+02, 0.95002800E+02, -.44005900E+03, 0.71101500E+03, -.51961500E+03, -.25815400E+03, 0.22166600E+04, 0.17242200E+04, -.83699500E+03, -.29263700E+04, -.86187700E+03, -.70901200E+03, -.19377300E+03, -.45325800E+03, -.25498900E+02, -.93455100E+03, 0.44992500E+03, 0.27568100E+04, 0.66633500E+02, -.57700200E+02, 0.13817200E+03, -.36712300E+02, 0.50965100E+03, 0.56875800E+03, 0.93244600E+03, 0.22697300E+04, 0.10433100E+04, -.91726900E+02, -.22199200E+04, -.47068600E+04, 0.25944300E+04, 0.33761300E+04, 0.23528700E+04, 0.69149700E+03, 0.13932100E+04, 0.94076700E+03, 0.62615900E+03, 0.60550700E+03, 0.10922700E+04, 0.14907300E+03, -.63638300E+04, 0.32648300E+04, 0.37865400E+04, 0.31817900E+04, 0.86390000E+03, 0.14945700E+04, 0.11142600E+04, 0.26796500E+03, 0.88862500E+03, 0.12308300E+04, 0.10471500E+04, 0.26645800E+04, -.13366000E+04, -.81565800E+03, -.13335500E+04, -.39323800E+02, -.89953700E+03, 0.18459600E+02, 0.18284400E+04, -.46725100E+03, -.79446400E+03, 0.20751300E+04, -.28293400E+04, 0.14075000E+04, 0.13113700E+04, 0.14130200E+04, 0.69687200E+03, 0.54649000E+03, 0.38882500E+03, -.37779200E+03, 0.12160800E+04, 0.33205000E+03, -.62789800E+03, 0.12406300E+05, -.61536700E+04, -.41737200E+04, -.62172700E+04, 0.98220300E+03, 0.63147600E+03, -.15676900E+04, 0.46774900E+04, -.19536000E+04, -.18308700E+03, -.60583000E+04, -.13760100E+04, 0.71762700E+03, 0.19065800E+04, 0.69262600E+03, -.94668600E+03, -.17680400E+04, 0.98292600E+03, 0.75906400E+03, 0.88767200E+03, -.13851000E+04, 0.65345600E+03, -.12990400E+03, 0.68311400E+02, 0.85059000E+03, 0.67887800E+02, 0.68254100E+03, 0.53440200E+03, -.21390400E+03, 0.31749300E+02, -.75853600E+03, 0.30965300E+03, 0.15719000E+03, 0.11507200E+05, -.57110000E+04, -.45345700E+04, -.57518400E+04, 0.23278300E+03, 0.92896100E+03, -.25782200E+04, 0.23275800E+04, -.33135300E+04, 0.10584500E+04, 0.74904500E+02, -.68537100E+03, 0.32037700E+03, 0.52539000E+03, 0.34399800E+03, 0.48534600E+03, -.39120300E+03, 0.10261700E+04, 0.14998800E+04, 0.95407700E+03, -.51089300E+03, -.21434700E+04, 0.44008500E+03, -.22167300E+03, -.82086700E+02, -.22224300E+03, -.32055900E+03, -.71380900E+03, 0.32080600E+03, 0.61948600E+03, 0.27477300E+03, -.38608200E+03, 0.22814500E+03, 0.16932600E+02, 0.86549400E+02, 0.30653200E+03, 0.31045900E+02, -.20505800E+03, -.19237200E+03, 0.39382700E+02, -.30685700E+03, -.25559200E+03, -.38941000E+03, -.49518100E+03, 0.14962700E+04, -.21042600E+03, -.33118100E+03, 0.28627100E+03, -.57490000E+03, 0.91000000E+03, 0.34264400E+03, -.25973500E+03, 0.12298000E+03, -.90203300E+03, 0.35144600E+03, -.13292300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.64346900E+00, 0.12808100E+01, -.10966500E+00, 0.10067500E+01, 0.76104100E-01, -.72264500E+00, 0.46493900E+00, -.23787500E+00, -.73454100E+01, 0.58791400E+00, -.29450000E-01, -.56154600E+00, -.52433400E+00, 0.73336500E-01, -.43408300E-01, -.57980700E+00, -.23234600E+01, -.17725400E+01, -.67569800E-01, 0.71822500E-01, -.50105300E+00, -.10573400E+00, -.26784000E+01, -.90317500E+00, 0.91413600E+00, -.47811000E-01, 0.10586900E+01, 0.47364000E-01, 0.17209000E-01, 0.39412600E+00, 0.24826800E+00, -.33296100E+00, 0.21984900E-01, -.22906400E-01, 0.20554000E+00, 0.34449200E-01, -.42337600E-04, -.37435300E+00, -.53560000E+00, 0.37164000E+00, -.47675700E+00, 0.60754500E-01, 0.92017100E+00, 0.66669500E+00, -.21896500E-01, -.62501400E-01, 0.63115800E+00, -.49915300E-01, -.27852200E+00, 0.19851900E+00, -.26995900E+01, -.26183500E+00, 0.32976300E+00, 0.82469500E-01, 0.45263200E+00, 0.24334100E+01, 0.58717200E-01, 0.52485100E-01, 0.10648400E+00, 0.14826400E+01, -.33625100E+00, -.63204100E-01, 0.25596400E+00, -.18822700E+00, 0.10211300E+00, 0.42302300E+00, -.98002600E+00, -.14805300E-01, 0.31117600E-01, -.12023500E-02, 0.41936300E+00, 0.28803200E+00, 0.10634100E+01, -.15014500E+01, 0.51825900E+00, 0.35938300E+00, -.66700900E-01, 0.28758600E+04, -.14321500E+04, -.16966000E+04, -.14379000E+04, 0.25340000E+03, -.71768200E+03, 0.64773600E+03, 0.20686500E+04, 0.23095400E+03, -.10251100E+04, -.22986200E+04, 0.67756600E+04, -.33645300E+04, -.24968100E+04, -.33895800E+04, 0.82522600E+03, -.15737100E+03, -.11232600E+04, 0.22397200E+04, 0.23583700E+03, -.66513500E+03, -.42684700E+04, -.39183600E+04, 0.19378400E+04, 0.27439300E+04, 0.19582600E+04, -.44607600E+03, 0.58885400E+03, 0.23323300E+03, -.15941500E+04, -.33992700E+03, 0.66842100E+03, 0.26405100E+04, 0.33600500E+04, -.16785100E+04, 0.47797800E+04, -.16798900E+04, -.27837300E+03, 0.10120500E+04, -.67035600E+03, 0.12356600E+04, -.10828200E+04, 0.58825500E+03, -.65844700E+03, -.29928700E+04, 0.14240500E+04, -.27412400E+03, 0.14944800E+04, -.16110700E+04, -.23810900E+04, 0.86788500E+03, -.18509700E+04, 0.40755300E+03, -.15829900E+04, 0.13375600E+04, 0.87182900E+03, -.25107100E+03, -.51374100E+03, -.43627400E+03, 0.17273200E+03, 0.59731600E+03, -.10763300E+02, 0.64528100E+03, -.61571600E+03, 0.43756600E+03, -.53450300E+03, 0.30310200E+03, -.69054700E+02, -.55645900E+03, -.15164000E+03, 0.34798700E+03, 0.10160800E+04, -.22084400E+03, 0.25332700E+03, -.62819000E+03, 0.88212600E+03, 0.35723400E+02, -.42353700E+04, 0.21018800E+04, 0.21562900E+04, 0.21169800E+04, 0.46224400E+03, 0.58572800E+02, 0.35128800E+03, -.79986300E+02, 0.52819600E+03, -.47167700E+02, 0.23835500E+04, 0.21943300E+02, -.15369100E+02, -.91815800E+02, -.11900300E+02, -.44190300E+03, 0.17643800E+00, 0.13785400E+03, -.17946500E+02, 0.44532300E+02, 0.15253800E+03, 0.72417100E+02, -.20049800E+05, 0.99622600E+04, 0.30497200E+04, 0.10016900E+05, -.27318400E+04, -.78335000E+04, 0.59358100E+04, -.28520200E+04, 0.64442700E+04, -.67519300E+04, 0.86309600E+04, 0.10787900E+03, -.50287800E+02, -.27155900E+04, -.50267500E+02, 0.91088100E+03, -.39045500E+03, 0.11700400E+04, 0.18390600E+04, 0.41231600E+03, -.68857000E+03, -.67656500E+03, -.59235500E+03, 0.31997200E+03, 0.18362000E+03, 0.29787000E+03, -.16272100E+03, -.90127500E+03, 0.44238800E+03, 0.40698900E+03, -.16162000E+03, -.77382300E+03, -.10053200E+02, -.15522400E+05, 0.77317900E+04, 0.26995100E+04, 0.77621700E+04, -.11542000E+04, -.51204400E+04, 0.46285600E+04, -.82856800E+03, 0.51372200E+04, -.47170700E+04, 0.75662800E+04, 0.88281600E+03, -.44705300E+03, -.11453900E+04, -.44066900E+03, 0.37959200E+03, -.11499700E+04, -.21206400E+03, -.11645000E+03, 0.10882000E+03, -.81602300E+03, -.12326100E+04, 0.37442600E+04, -.18707800E+04, -.95500200E+03, -.18733900E+04, 0.75145100E+02, 0.93082800E+02, -.73584400E+03, 0.10075000E+04, -.79452300E+03, -.59374400E+02, -.17634500E+04, 0.21819400E+02, -.42496300E+03, -.55226100E+03, 0.10764300E+03, -.42673600E+02, -.25382600E+01, 0.15075600E+02, 0.55620500E+03, -.82794100E+02, 0.26657700E+02, 0.15366100E+03, -.35871400E+03, -.40657300E+03, -.76536200E+02, 0.14136300E+02, 0.17633000E+03, -.41152100E+03, 0.10750100E+03, 0.18246100E+03, 0.23907000E+02, 0.90011700E+02, -.43398600E+03, 0.36816900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28658900E+01, -.67411300E+00, -.87252800E+00, -.31554400E+00, 0.13150500E+00, 0.19415700E+01, -.69812600E+00, -.24884900E+01, 0.17530600E+00, 0.86347800E+00, -.20716900E-02, 0.37344900E+00, -.42037700E+00, -.31012000E+00, -.13517900E+00, 0.13294300E+01, 0.29074400E+01, -.28151200E+01, -.41403900E+00, -.20851500E+00, 0.10739100E+01, -.53515400E+00, -.41091400E+01, -.13550500E+01, -.24454600E+00, -.37670000E-01, -.13891400E+01, -.31195600E+00, 0.53141300E+00, 0.30014000E+00, 0.54795700E+00, -.43366900E+00, -.14641900E-01, -.27652800E+00, 0.17338500E+00, -.42146000E-01, 0.45486300E-02, 0.74405500E+00, -.70218800E+00, 0.50469900E+00, 0.21326500E+01, -.55200600E+00, -.14519600E+01, -.13123400E+01, 0.74020700E-01, 0.11645100E+00, -.58165500E+00, -.11427300E+00, 0.34357400E+00, -.28499800E+00, 0.41097400E+01, -.27177900E+00, 0.15677100E+00, -.66004700E+00, -.30908500E+00, -.26687100E+01, -.14931200E+01, 0.14969200E+00, -.12019300E+00, -.10745600E+01, 0.24252600E-01, 0.64774700E-01, -.27390900E+00, -.15703800E+00, -.15099300E+01, 0.67229800E+00, -.36500700E+01, -.60432300E+00, -.13919400E-01, 0.28110300E-02, -.64093900E-01, -.17352300E+01, 0.77604100E+00, 0.17091100E+01, 0.69691000E+00, -.15103200E+01, -.51038400E+00, -.40441300E+00, -.51396900E+02, -.43099700E+03, 0.85365800E-01, 0.37103500E+03, -.85974300E+03, 0.86778000E+03, 0.11560700E+04, 0.93699000E+03, -.10596000E+04, -.18689900E+04, 0.12768500E+05, -.66330100E+04, -.55185800E+04, -.63902100E+04, 0.14415800E+03, -.28108400E+04, -.57106900E+03, 0.36665900E+04, -.33668000E+04, -.20914400E+04, -.77390600E+04, 0.11484800E+04, -.40184100E+03, 0.85037700E+02, -.57708800E+03, -.77237900E+03, 0.43046000E+03, -.96762100E+03, -.11644600E+04, -.15002300E+04, 0.58715500E+03, 0.22087000E+04, 0.24181000E+04, -.11652500E+04, 0.19554300E+03, -.12086100E+04, -.13087200E+04, 0.14025400E+03, -.12616300E+04, -.13160000E+04, -.11850200E+04, 0.37295600E+03, 0.27770400E+04, -.43720600E+04, 0.23998700E+04, 0.92586300E+03, 0.21829700E+04, -.34544900E+03, -.60552500E+03, 0.19909900E+04, 0.33715300E+03, 0.19321000E+04, -.57268800E+03, 0.14856500E+03, -.29231600E+04, 0.15284500E+04, 0.24991400E+04, 0.14567600E+04, 0.31913200E+03, 0.58773900E+03, 0.14073000E+04, 0.20759200E+04, 0.95180500E+03, 0.49748500E+03, -.69653800E+03, -.48589200E+04, 0.24357600E+04, 0.29368600E+04, 0.24252800E+04, 0.52510800E+03, 0.90913600E+03, 0.15333600E+04, 0.16002200E+04, 0.13611800E+04, 0.81929600E+03, 0.21659600E+03, -.18960600E+04, 0.10215000E+04, 0.27130400E+03, 0.94564200E+03, -.19730800E+03, -.83461100E+03, -.43779200E+02, 0.27906100E+03, 0.19679600E+03, -.75319000E+03, 0.34412000E+04, -.75191100E+04, 0.37741600E+04, 0.34072600E+04, 0.37565300E+04, 0.12120500E+04, 0.11690200E+04, 0.11929100E+04, -.86981800E+03, 0.25006200E+04, 0.11704900E+04, 0.15088200E+04, -.26179800E+04, 0.17531700E+04, -.13739200E+04, 0.12861000E+04, -.97915900E+03, -.31737400E+04, 0.60483400E+03, -.14500800E+04, 0.21575500E+04, -.30751200E+04, 0.51238100E+03, -.10858000E+04, 0.61047500E+03, -.29547500E+03, 0.53739300E+03, 0.16752600E+02, -.12470700E+04, 0.12983200E+04, 0.20635900E+04, 0.15871700E+04, -.14960900E+04, 0.74372600E+03, 0.91971500E+03, -.55487500E+03, 0.58232900E+03, -.45639100E+03, -.59223100E+02, -.86868900E+03, 0.13817500E+03, 0.90981600E+03, -.78266400E+03, -.78198000E+03, 0.18602900E+02, 0.16835200E+04, -.56520100E+03, -.25565800E+04, -.83830500E+03, -.14921700E+04, -.19376500E+04, -.16016800E+04, -.23657600E+04, -.24588300E+03, -.18801600E+04, 0.36826500E+04, -.26451500E+03, 0.10710000E+03, -.33472700E+03, 0.13469900E+03, 0.11277900E+04, -.10606500E+04, 0.16288400E+04, 0.28218500E+04, 0.81427900E+03, -.89801000E+03, -.17889800E+04, 0.10599400E+04, -.54216600E+03, 0.14940600E+03, -.53323200E+03, 0.10467000E+03, -.42388400E+03, 0.79291000E+01, 0.66985600E+03, -.18176900E+03, -.20789700E+03, -.59293500E+03, 0.18171000E+02, -.46830900E+03, -.19724400E+03, 0.11097300E+03, -.48570300E+02, -.43661700E+02, 0.35369900E+02, 0.20473900E+03, -.67203400E+02, -.31489100E+02, -.20704200E+03, 0.12053800E+04, -.37841200E+03, -.18812700E+03, 0.19995000E+03, -.30176600E+03, -.68157800E+02, 0.14479000E+03, 0.77230900E+02, 0.87307800E+02, -.20670800E+03, -.26027200E+03, 0.40718200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39015800E+01, -.59105700E+01, -.15526000E+01, -.39923500E+01, -.19126600E+01, 0.20209900E+01, -.14065200E+01, -.67674300E+01, 0.13252100E+02, -.33233700E+00, 0.20716700E+01, 0.33769600E+01, 0.11149400E+01, 0.10260700E+00, -.37859500E+01, 0.29452700E+01, 0.31850100E+01, -.47549000E+01, -.98153100E+00, -.18945000E+01, 0.17628100E+01, -.88637200E+00, 0.48733200E+01, -.72095800E+00, 0.52464300E-01, -.13586200E-01, -.39437100E-01, -.41432000E-01, 0.11792000E+00, 0.11575100E+01, 0.14839900E+01, 0.96469500E+00, -.19452500E+01, 0.11956300E+00, 0.34409600E+00, -.58468000E+00, 0.42564300E-01, 0.25355600E+01, 0.15076300E+01, 0.11501600E+01, 0.61153000E+00, -.13957000E+01, 0.12045300E+01, 0.81129500E-01, -.26484400E+00, -.20276100E+00, -.62935900E+00, -.87327400E-01, -.54051100E+00, 0.56290100E-01, 0.81978300E+01, 0.96879300E+00, -.21355500E+01, -.17492300E-01, -.37896900E+01, 0.24401700E+01, -.75514400E+00, 0.39062200E+00, 0.67880200E-01, 0.79645900E-01, -.37291600E+01, -.73678400E-01, -.25411300E+01, 0.55659900E+00, 0.22371500E+01, -.51705800E+01, -.90371300E+01, 0.29675600E+00, 0.85762800E+00, 0.45868600E-02, 0.24105000E+00, -.23433000E+01, 0.59341700E+01, -.29484500E+01, 0.38264900E+01, 0.24705500E+01, -.28382000E+01, 0.13356500E+00, 0.72133000E-01, 0.74708300E+04, 0.38543200E+00, -.13437900E+04, -.32196200E+04, 0.59829300E+03, 0.14765900E+04, 0.15812500E+04, -.11827600E+04, -.72456400E+04, -.17497900E+05, 0.85169400E+04, 0.50794400E+04, 0.87241600E+04, -.20625200E+04, -.66224700E+04, 0.78994300E+03, -.78045400E+04, 0.99577600E+04, -.31239800E+04, 0.20797700E+04, 0.16040400E+04, -.74425300E+03, -.90518700E+04, -.81430300E+03, 0.21188400E+04, 0.26961100E+04, -.86318500E+03, 0.15536700E+03, -.26597100E+04, 0.76543800E+03, 0.87397500E+04, 0.19188400E+05, -.94705700E+04, -.11535900E+05, -.95923600E+04, -.19954900E+04, 0.28679500E+04, -.54726600E+04, 0.10085900E+04, -.81662400E+04, 0.49455600E+04, 0.29998900E+04, 0.10432300E+05, -.52737700E+04, -.18061900E+04, -.52344900E+04, 0.19827900E+04, 0.30112900E+04, 0.94430200E+03, 0.93017200E+04, 0.33481100E+04, 0.30475400E+03, -.12384800E+05, -.17362900E+05, 0.96634100E+04, 0.10355800E+05, 0.86671600E+04, 0.22309600E+04, 0.40035000E+04, 0.39735400E+04, 0.29490500E+04, 0.29046100E+04, 0.32671800E+04, 0.10375000E+04, -.25863500E+05, 0.13265200E+05, 0.12769400E+05, 0.12920500E+05, 0.31492700E+04, 0.49508800E+04, 0.44841300E+04, 0.73879100E+03, 0.36888100E+04, 0.42632300E+04, 0.52768800E+04, 0.14112300E+05, -.70300000E+04, -.51374500E+04, -.70661200E+04, -.37625000E+03, -.25124700E+04, -.19002600E+04, 0.58234400E+04, -.51444600E+04, -.24908100E+04, 0.19097900E+04, -.13484300E+05, 0.67478600E+04, 0.43027900E+04, 0.67293300E+04, 0.40994600E+04, 0.21693000E+04, 0.32186000E+04, -.21685600E+04, 0.12745700E+04, 0.14715900E+04, 0.27537400E+03, 0.63972800E+05, -.31705700E+05, -.15580400E+05, -.32088300E+05, 0.17719600E+04, 0.18344200E+04, -.10133100E+05, 0.18600900E+05, -.82834900E+04, -.14268900E+04, -.33990700E+05, -.35817100E+04, 0.19268400E+04, 0.83865300E+04, 0.17891500E+04, -.47229300E+04, -.79337400E+04, 0.37209000E+04, 0.55374900E+04, 0.66638000E+04, -.66344900E+04, 0.15198300E+04, -.72063000E+03, 0.34276700E+03, 0.17830500E+04, 0.37826800E+03, 0.32042200E+04, 0.22438200E+04, -.15435300E+04, 0.90277100E+02, -.31077900E+04, 0.15872700E+04, 0.11157300E+04, 0.49279300E+05, -.24430400E+05, -.13709000E+05, -.24625500E+05, 0.71431100E+03, 0.55419300E+04, -.11710500E+05, 0.85936900E+04, -.16309100E+05, 0.60415100E+04, -.87370000E+04, 0.40576600E+04, -.21728200E+04, 0.27734500E+04, -.20185600E+04, 0.52398700E+02, -.30602200E+04, 0.71085600E+03, 0.38027200E+04, 0.32339000E+04, -.34581000E+04, -.79885900E+04, 0.11408000E+05, -.57177100E+04, -.26149900E+04, -.57191700E+04, -.21903100E+04, -.33541900E+04, -.17238800E+04, 0.25798900E+04, 0.10753400E+04, -.19102500E+04, -.57800100E+04, 0.19387100E+03, -.45852700E+03, 0.37831500E+03, 0.66547400E+02, -.10139700E+04, -.96093700E+03, 0.23931500E+03, -.36149300E+03, -.31644300E+03, -.18962800E+04, -.17100500E+04, 0.57838200E+04, -.15199500E+03, -.14554000E+04, 0.12534400E+04, -.18708700E+04, 0.19165600E+04, 0.18146100E+04, -.67621500E+03, 0.56514700E+03, -.44780000E+04, 0.13133300E+04, 0.23846800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22828300E+01, -.21592600E+01, -.24644000E+00, -.30372700E+00, 0.20401500E+01, 0.12782900E+01, -.28048800E+00, 0.13533200E+01, 0.30374000E+02, -.15499500E+00, -.15767700E+00, 0.50549900E+00, 0.84487600E+00, -.22136900E+00, 0.47768900E+00, 0.23538100E+01, 0.32690100E+01, 0.30626500E+01, 0.65286200E+00, -.12734300E+01, 0.25679000E+01, 0.28035500E+00, 0.44406100E+01, 0.14497900E+01, -.22846000E+01, -.72105600E-01, -.50561900E+01, -.67836900E+00, 0.69220200E+00, -.66348100E+00, 0.70062100E-01, -.56514000E-01, -.18198400E+00, -.61219300E-01, -.31511400E+00, -.21110100E+00, 0.89230900E-02, 0.46396700E+00, 0.81424600E+00, 0.98634600E-01, 0.14238200E+01, -.19499000E+00, -.54538800E+00, -.61374700E+00, -.31324300E-01, 0.29378900E-01, -.56743700E+00, -.14778200E-01, 0.10208300E+00, -.84390800E-01, 0.23673200E+01, -.67511500E-01, 0.65937500E+00, -.11333000E-01, 0.12654000E+00, -.89471600E+00, -.40181700E+00, -.29534600E-01, 0.17610800E+00, 0.66753900E-02, 0.86957000E+00, 0.82112900E-02, -.67772600E+00, 0.91952900E-01, 0.56663200E-01, 0.21428000E+00, 0.15602500E+00, -.30736200E+00, 0.38597300E-01, -.87490900E-03, -.10931300E+00, 0.16235500E-01, -.28458900E+01, 0.30199500E+01, -.16796900E+01, -.14707100E+01, -.48423500E+00, -.95983400E+00, -.11213200E+00, -.10789200E+00, 0.30034000E+02, 0.12565800E+03, 0.11669800E+03, -.48557800E+03, -.31595100E+01, -.52616700E+03, 0.17499400E+03, -.63482800E+03, -.14933800E+04, 0.79189400E+03, -.25713100E+04, 0.74556000E+03, 0.42287100E+03, -.31993600E+04, 0.29541400E+04, 0.20550000E+04, -.32605100E+04, -.22995200E+04, -.66736000E+03, -.12538300E+04, 0.63391400E+03, 0.21844500E+03, 0.62633600E+03, 0.16121300E+03, 0.67655700E+03, -.50893500E+03, -.15309500E+04, 0.70728600E+03, 0.55050600E+03, 0.19385800E+04, 0.34852600E+01, -.23131400E+01, -.30310200E+04, -.16615400E+01, -.88212700E+03, -.46400100E+03, -.74397200E+02, -.49674100E+03, -.42297200E+03, 0.15475600E+03, 0.14286100E+04, -.30927000E+04, 0.14911700E+04, 0.14048400E+04, 0.15450500E+04, 0.60497800E+03, 0.14144700E+04, 0.89057600E+03, 0.10049000E+04, 0.12740000E+04, 0.67948300E+03, 0.79932100E+03, -.28044300E+04, 0.16488200E+04, 0.33397600E+04, 0.14023600E+04, 0.63313300E+03, 0.12074600E+04, 0.75434300E+03, 0.12285700E+04, 0.60163800E+03, 0.96327600E+03, -.26389600E+03, -.37124800E+04, 0.19469800E+04, 0.34358800E+04, 0.18564900E+04, 0.61060000E+03, 0.93182600E+03, 0.12844700E+04, 0.14026900E+04, 0.10202400E+04, 0.77675500E+03, 0.58895100E+02, 0.13755300E+04, -.72913100E+03, -.48012100E+03, -.68820300E+03, -.25506500E+03, -.15647100E+03, -.83284300E+02, -.58526200E+02, -.36390100E+03, 0.32030700E+02, 0.14364100E+03, -.35111300E+04, 0.17414500E+04, 0.20346100E+04, 0.17549600E+04, 0.53305300E+03, 0.74760500E+03, 0.12199200E+02, -.76868100E+03, 0.27947300E+04, 0.56481400E+03, 0.63048900E+03, 0.11055700E+05, -.55256800E+04, -.34088800E+04, -.55330700E+04, 0.19426200E+04, 0.38416600E+04, -.44520500E+04, -.28246000E+03, -.43361700E+04, 0.28268900E+04, -.55043900E+04, -.17598700E+04, 0.89098300E+03, 0.23113400E+04, 0.89859700E+03, -.66684500E+03, -.67773800E+03, -.34137200E+03, -.10277200E+04, -.74491800E+03, -.35596100E+03, 0.18046400E+04, 0.34244100E+03, -.15141800E+03, 0.94510400E+03, -.17015200E+03, 0.50105600E+03, 0.90230400E+03, -.40462600E+03, 0.11495300E+03, -.70630300E+03, 0.65087600E+03, 0.16436800E+03, 0.14506900E+05, -.72546600E+04, -.58450600E+04, -.72528500E+04, 0.32290900E+03, 0.18996400E+04, -.42641100E+04, 0.29863200E+03, -.42980700E+04, 0.18693200E+04, -.49085600E+04, -.34323500E+04, 0.17376400E+04, 0.12471900E+04, 0.17166400E+04, 0.71645800E+03, -.25106000E+03, 0.24901300E+04, 0.24881500E+04, 0.10412200E+04, -.39385300E+03, 0.88996300E+03, -.24613400E+04, 0.12332600E+04, 0.78578000E+03, 0.12298800E+04, 0.96505800E+02, -.50392200E+03, 0.13536600E+04, 0.87062200E+03, 0.20067000E+03, -.22729600E+03, 0.76950600E+03, 0.13030900E+02, -.27697300E+03, -.54716000E+01, -.21310600E+02, -.18579100E+03, -.17432300E+03, 0.28937400E+02, 0.65639000E+01, -.42644800E+03, 0.16974800E+03, -.31679500E+03, 0.10152600E+04, -.41225900E+02, -.26568500E+03, 0.28302400E+03, -.24900800E+03, 0.15836100E+04, 0.56709400E+02, -.45621500E+03, 0.10975900E+03, -.31474500E+03, -.17134300E+03, 0.30521000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40612900E+00, 0.98349300E-01, 0.37846000E-01, 0.96320300E-01, -.56656200E+00, -.43321700E+00, 0.12784000E-01, -.44230400E+00, -.73143000E+01, -.71951200E-01, 0.10009500E+00, -.32655500E-01, -.20031000E+00, 0.41768100E-01, 0.28191000E-01, 0.39373700E-01, -.81647700E+00, -.50351300E+00, 0.88388500E-02, 0.74495100E+00, 0.89195200E-01, 0.38260500E-02, 0.65855700E-01, -.82481200E-01, 0.14973400E-01, 0.42810600E-02, 0.10706400E+00, 0.17121000E-01, 0.38752600E-01, 0.62919300E-01, 0.16224400E+00, 0.34958800E-01, -.59499600E-01, -.20259900E+00, -.11830600E+00, -.10711000E+00, -.17730000E-03, -.24619800E+00, 0.85294100E+00, 0.26894700E+00, 0.25478500E+00, 0.78724200E-01, 0.80020800E+00, 0.36927100E+00, -.38277800E-01, 0.13643300E-01, -.24383200E+00, 0.11462700E-01, -.15131900E+00, 0.74967000E-01, 0.35138400E+00, 0.21280800E+00, -.56896900E+00, -.41839200E+00, -.12282000E+00, -.85705300E+00, -.37059100E+00, 0.46633600E-01, -.70364600E-01, -.33910000E+00, -.14405400E+00, -.13827600E+00, -.45374300E+00, 0.25616900E-03, -.50066400E+00, -.69435700E-01, 0.12048200E+01, 0.46549800E+00, 0.59235400E-01, -.48638800E-04, -.80737800E-01, -.25927900E+00, -.41333700E+00, 0.16009700E+00, -.14430500E+00, 0.74437700E-01, -.83660500E-01, 0.25244800E+00, -.34107400E-02, 0.50529300E-01, -.11854100E-02, -.29065500E+03, 0.96330100E+02, -.22996800E+03, -.31404300E+03, -.57625700E+02, 0.47093700E+02, 0.50986000E+03, 0.42919600E+03, -.20309600E+03, -.33858500E+03, -.21230700E+03, -.73337400E+03, -.35428900E+03, 0.34756100E+03, 0.55498700E+03, -.25701600E+03, -.51022400E+03, 0.10046100E+04, 0.52346200E+03, -.26299300E+03, -.31107000E+03, -.26059600E+03, 0.33942500E+03, 0.15949000E+03, -.12213100E+03, 0.62229400E+02, 0.20402000E+02, 0.24506400E+03, -.80856800E+03, -.26105700E+03, 0.12193600E+03, -.71599000E+03, 0.13035800E+03, 0.27348400E+03, 0.80755600E+02, -.54712900E+02, -.34038700E+03, 0.29613300E+02, 0.17758800E+02, -.29477400E+03, 0.25082700E+03, -.10857100E+03, 0.18989400E+03, -.12370700E+03, 0.30030100E+03, 0.29958000E+03, -.16853800E+03, 0.12385100E+03, 0.83757400E+02, 0.25421600E+03, -.13631600E+03, 0.29081000E+03, -.24904000E+03, -.17839200E+03, -.14414000E+03, 0.11754200E+03, -.11901000E+03, -.26228700E+03, -.38257000E+03, 0.12467500E+02, -.58020700E+02, 0.11423900E+03, 0.10222900E+04, -.55242100E+03, -.22792700E+03, -.51015000E+03, -.60694400E+02, -.43710700E+03, -.18403600E+03, -.17077000E+03, -.13281000E+03, -.34566100E+03, -.41063500E+03, 0.87906500E+03, -.43751700E+03, -.38852100E+03, -.43861300E+03, -.69881700E+02, 0.42066100E+03, -.34001700E+03, -.47904200E+03, -.38003900E+03, 0.44766600E+03, -.67290500E+03, 0.16546300E+02, -.99056000E+01, 0.47162200E+02, -.70894100E+01, 0.18526500E+03, 0.26439000E+02, -.95549700E+02, 0.31622400E+01, -.48734400E+02, 0.72121000E+02, 0.39050900E+02, 0.26874900E+04, -.13511000E+04, -.43123500E+02, -.13343100E+04, 0.58429700E+03, 0.18600500E+04, -.11407200E+04, 0.35046900E+02, -.97156100E+03, 0.17392500E+04, -.11965000E+04, 0.32186400E+03, -.16968800E+03, 0.28983100E+03, -.16249400E+03, -.16623000E+03, 0.29582000E+03, -.51445500E+03, -.54727300E+03, -.13820000E+03, 0.28329100E+03, 0.24066500E+02, 0.73694500E+02, -.42613000E+02, -.95377700E+02, -.38508700E+02, 0.18114400E+03, 0.53419300E+03, -.30757000E+03, -.30218000E+03, 0.22800900E+02, 0.47858500E+03, 0.16166900E+03, 0.21688400E+04, -.10936200E+04, 0.56041700E+02, -.10857300E+04, 0.29396000E+03, 0.13374800E+04, -.90322700E+03, -.44001100E+03, -.97612600E+03, 0.11976700E+04, -.15459400E+04, 0.76936500E+02, -.29533700E+02, 0.26712200E+02, -.39417700E+02, -.30173200E+03, 0.12011600E+03, 0.53462400E+02, 0.38220800E+02, -.15173200E+03, 0.95104600E+02, 0.37927900E+03, -.10795300E+04, 0.54018600E+03, 0.39209300E+03, 0.54116400E+03, 0.52132700E+02, 0.93572500E+02, 0.19855100E+03, -.29076400E+03, 0.15037200E+03, 0.75227100E+02, 0.56552600E+03, -.92569200E+01, -.56396500E+02, -.55654300E+02, -.22191400E+02, -.42414200E+02, -.58561700E+02, -.90508100E+01, 0.54569000E+02, 0.96303000E+02, 0.10017100E+03, 0.95722800E+02, -.21907000E+03, 0.11553400E+03, 0.26915900E+02, 0.68544700E+01, 0.70884700E+02, -.72057000E+02, -.87368000E+02, 0.24319600E+01, -.25429200E+02, 0.15301900E+03, -.94097500E+02, 0.77160300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.80591900E+00, 0.74342100E-01, -.31548400E+00, -.15318700E+01, -.23726200E-01, 0.45548900E+00, -.24067100E+00, -.20743600E+01, -.17422400E+02, 0.26642500E+00, 0.18526800E+00, -.35330700E+00, 0.22420500E+00, 0.17008400E+00, 0.36583800E+00, 0.86127500E+00, 0.30649200E+01, 0.12439800E+01, -.34915800E-01, -.44975700E+00, -.48863000E+00, -.57515800E+00, 0.42977300E+01, 0.60388700E-01, -.48189200E+00, 0.15346300E-01, -.38852000E+00, 0.63592000E-01, 0.10376800E+00, 0.77034000E-01, 0.61671200E+00, 0.61905000E+00, -.73786500E-01, -.33531000E+00, -.42992800E+00, -.31638300E+00, 0.11993500E-01, 0.15957400E+00, 0.35221400E+00, 0.33403600E+00, 0.30266700E+00, 0.70563100E-02, 0.63727500E+00, 0.14154000E+00, -.15275300E+00, -.13096700E-01, 0.60180400E+00, -.55612500E-02, -.87004000E-01, 0.20672000E+00, 0.11419500E+01, 0.60177500E+00, 0.93945800E+00, 0.35153100E+00, 0.29065500E+00, 0.25767800E+00, -.18937200E+00, -.27547400E-01, -.44903100E-01, 0.44593300E+00, -.37843200E+00, 0.66543800E-01, -.15550600E+00, 0.28788000E+00, 0.36428200E+00, 0.35114800E+00, -.13820200E+01, 0.86242000E-02, -.18157000E-01, 0.17058200E-02, -.25287300E+00, 0.16797500E+00, -.16592400E+01, 0.59517800E+00, 0.36713300E+00, -.88526400E+00, 0.20903900E+00, -.92888200E+00, 0.13090000E+00, -.83440200E-01, 0.28823600E-02, -.51518300E+00, -.16431400E+04, 0.18045900E+04, 0.17005600E+04, 0.64315300E+03, -.14160500E+04, -.24299200E+04, 0.41745900E+04, -.20943500E+04, -.59868100E+03, -.20913100E+04, 0.23660800E+03, -.15758200E+04, -.19785300E+04, -.28487800E+04, 0.16722900E+04, -.10098100E+04, -.47128400E+04, 0.33077100E+04, -.16436300E+04, -.22150000E+03, -.16559300E+04, -.65223600E+03, 0.11749300E+04, -.14860700E+04, -.73642800E+03, -.25366200E+04, 0.98426100E+03, 0.22181800E+04, 0.64463900E+04, -.32185600E+04, -.43395400E+03, -.32228900E+04, -.13771100E+03, 0.11901600E+04, -.15257300E+04, 0.86283000E+03, -.27440200E+04, 0.15267500E+04, 0.58185700E+03, -.42150200E+04, 0.21188700E+04, -.15391700E+04, 0.21034600E+04, -.27038700E+03, -.72216400E+03, 0.23373400E+04, 0.12274000E+04, 0.28608300E+04, -.10342200E+04, 0.53022200E+02, -.21291200E+04, 0.10970500E+04, 0.14196700E+04, 0.10633900E+04, 0.41851400E+03, 0.69989400E+03, 0.71920200E+03, 0.70835600E+03, 0.72232000E+02, 0.59012000E+03, -.59677100E+03, -.33825900E+04, 0.16909100E+04, 0.18920000E+04, 0.16907000E+04, 0.54683000E+03, 0.10612800E+04, 0.58140500E+03, 0.20258400E+03, 0.13332300E+03, 0.95772800E+03, 0.18109100E+03, 0.12742300E+04, -.63824100E+03, -.62981600E+03, -.63873500E+03, -.18869800E+02, -.50999600E+02, -.10110200E+04, 0.89665500E+03, -.10910000E+04, 0.13637100E+03, 0.29416200E+04, -.27469800E+04, 0.13696700E+04, 0.12123100E+04, 0.13713800E+04, 0.60162700E+03, 0.53107700E+03, 0.11620100E+04, 0.12759700E+04, 0.90876700E+03, 0.26934500E+03, 0.39312500E+03, 0.19151000E+04, -.91927500E+03, -.76187000E+04, -.97530000E+03, -.28759200E+04, -.46640200E+04, 0.10247500E+04, 0.13605000E+03, 0.16933200E+04, -.45318000E+04, 0.38547800E+03, 0.19384400E+03, -.89646500E+02, -.22934600E+04, -.96656400E+02, -.62356900E+03, -.24603300E+04, 0.24586000E+04, 0.27355100E+04, 0.14741300E+04, -.21578500E+04, -.59991200E+03, 0.41713300E+03, -.21461700E+03, 0.78018600E+03, -.20497100E+03, 0.34846900E+03, -.62628800E+02, -.18792300E+03, -.29743900E+02, -.90563100E+03, -.43568800E+02, 0.38565500E+03, 0.27440600E+04, -.13553500E+04, -.62356200E+04, -.13697700E+04, -.21799700E+04, -.25270800E+04, -.95952700E+03, -.11892000E+04, -.22942200E+04, -.17800400E+04, 0.46080400E+04, -.22099700E+04, 0.11034400E+04, -.16796700E+03, 0.11066700E+04, 0.16730900E+03, -.11567100E+04, 0.44481300E+03, -.91423600E+02, 0.22053900E+04, -.11411700E+04, -.22612500E+03, 0.23009300E+04, -.11516700E+04, -.70675700E+03, -.11532200E+04, -.12602600E+03, -.36217200E+03, -.72079400E+03, 0.34096100E+03, 0.17696600E+03, -.23626400E+03, -.88145700E+03, -.89004700E+02, -.48620500E+03, -.37506000E+03, 0.60120400E+02, -.16299800E+03, -.20056100E+03, -.62618800E+02, 0.38301700E+03, 0.81169300E+02, -.36222200E+03, -.22614200E+01, 0.12539100E+04, 0.69211900E+02, -.23831900E+03, 0.25427000E+03, -.37835300E+03, 0.90655900E+02, 0.65563900E+02, -.34705200E+02, 0.81166100E+02, -.73322800E+03, -.28999900E+02, 0.39878000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.52192200E+00, -.19935400E+01, -.19146500E+00, -.12255700E+01, 0.35409900E+00, 0.93934900E+00, -.42770600E-01, -.10700400E+01, 0.13401100E+01, 0.12297800E+00, 0.40758700E-02, -.19976300E-01, -.69341500E-01, 0.18255100E+00, -.11286300E+00, 0.16761600E+00, -.69506000E-01, -.99120900E+00, -.81619000E-01, -.69699600E+00, 0.19360800E+00, -.43612100E+00, 0.48867700E+01, 0.97613600E-01, -.14815300E+01, 0.23380000E-01, -.19283200E+01, -.30361400E-01, -.48805800E+00, 0.78687500E-01, 0.54859900E+00, 0.54230100E+00, 0.13350900E-01, -.19379200E+00, -.33801200E+00, -.14683800E+00, 0.60098100E-02, -.93683900E-01, -.15463900E-01, 0.28229800E+00, -.15268300E+00, -.95715500E-01, 0.86858700E-01, -.13095000E+00, -.91353000E-01, -.51618000E-01, 0.62005900E+00, -.43431600E-01, -.17239000E+00, 0.17996100E+00, -.51847800E+00, 0.38781500E+00, 0.82844200E+00, 0.48146400E+00, 0.49528300E+00, 0.76821700E+00, 0.69586600E+00, 0.17838100E+00, 0.27386700E-01, -.87419000E-01, -.12121900E+00, -.55627100E-01, -.31574000E+00, -.33175000E+00, 0.16719000E+00, -.60495200E-01, -.31069400E+01, 0.60785100E-01, -.81745200E-01, 0.55830000E-03, 0.55368700E-02, 0.32598800E+00, 0.17714100E+01, 0.33640400E-01, 0.12738600E+00, 0.31018200E+00, -.47264200E-01, -.31630700E-01, -.11846100E+00, 0.12912700E+00, -.63345300E-03, -.89455300E+00, -.44301000E+00, 0.58166100E+03, 0.41268600E+03, -.35937400E+02, -.27156800E+03, 0.56713100E+03, 0.80090700E+04, -.40265600E+04, -.69338100E+03, -.40029300E+04, -.69307600E+03, 0.10404000E+04, -.28213500E+04, -.92101700E+03, -.65779800E+03, 0.12990300E+04, -.22525500E+04, 0.32366000E+03, -.15474300E+03, 0.20713600E+03, -.16109700E+03, -.35913800E+03, -.51569300E+03, 0.26526500E+03, 0.87347800E+02, -.35326100E+03, -.38887100E+03, -.96942100E+03, -.91166900E+03, 0.45125600E+03, 0.46029300E+04, 0.45571800E+03, 0.14423300E+04, 0.14105300E+03, 0.44576600E+03, 0.87615000E+03, 0.67827700E+03, -.54228900E+03, -.68867200E+03, -.14912300E+03, 0.13432100E+03, -.83176400E+03, 0.74990600E+02, -.50400200E+03, -.15967700E+04, 0.37472000E+03, -.77138500E+03, -.17023800E+03, -.13025000E+04, 0.34180000E+03, 0.91373400E+03, -.68196800E+03, -.10694100E+04, -.45524700E+03, -.14483200E+03, -.69997400E+03, -.18091700E+03, -.52734800E+03, -.90537800E+02, -.45509100E+03, 0.67899300E+01, 0.17736600E+04, -.98561300E+03, -.12360800E+04, -.88533000E+03, -.25945600E+03, -.68610500E+03, -.41240600E+03, -.52497500E+03, -.34676900E+03, -.47892400E+03, -.63886400E+03, -.16231200E+04, 0.83483400E+03, 0.36701500E+03, 0.81219900E+03, 0.43644900E+03, 0.67894300E+03, -.41572900E+03, -.44245400E+03, 0.38783700E+03, 0.43283800E+03, -.12727400E+03, -.17633200E+03, 0.89407700E+02, -.19785400E+03, 0.88966800E+02, -.19369600E+03, -.17073200E+03, 0.50838700E+03, 0.79643400E+03, -.38657200E+03, -.95243600E+02, 0.91694800E+03, -.85793900E+04, 0.43219400E+04, 0.23308000E+04, 0.42954300E+04, -.17119200E+04, -.38749600E+04, 0.23320500E+04, -.25736500E+04, 0.18838600E+04, -.35849600E+04, 0.50477600E+04, 0.10950700E+04, -.55440400E+03, -.18494000E+04, -.55022900E+03, 0.31496200E+03, 0.30213200E+03, 0.50466300E+03, 0.86507400E+03, -.14668400E+02, -.19730200E+02, -.63796200E+03, 0.49670700E+03, -.27129500E+03, -.36974800E+03, -.24902300E+03, -.12535400E+03, 0.49429800E+02, -.18808200E+03, -.45163900E+03, -.12779000E+02, 0.25303200E+03, -.98479000E+02, -.10153200E+05, 0.50906400E+04, 0.40579300E+04, 0.50756600E+04, -.50844400E+03, -.21497200E+04, 0.23039000E+04, -.16474600E+04, 0.24079500E+04, -.25455900E+04, 0.41141200E+04, 0.86303200E+03, -.43323400E+03, -.70705000E+03, -.43216600E+03, -.37636800E+03, 0.30244800E+03, -.11932600E+04, -.15931700E+04, -.14275500E+03, 0.56019300E+03, -.17968900E+03, -.28286100E+03, 0.13900700E+03, 0.40426800E+03, 0.14218900E+03, 0.70358900E+03, 0.58683800E+03, -.63860900E+03, -.69510300E+03, 0.15506000E+03, 0.33165700E+03, -.43029100E+03, 0.48173500E+01, 0.13323300E+03, 0.12109700E+02, 0.24330600E+02, 0.11847400E+03, 0.87593800E+02, -.76261900E+01, -.14167800E+02, 0.98351600E+02, 0.85034400E+02, 0.22841200E+03, -.78857700E+03, 0.18518900E+03, 0.19293500E+03, -.13505900E+03, 0.23036400E+03, -.10745200E+04, -.35088900E+02, 0.20422700E+03, -.13216900E+03, 0.31359500E+03, 0.11070200E+03, -.14614700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.53225300E+00, 0.38922500E+00, 0.37884600E-01, 0.18324200E+00, 0.51328500E-01, 0.29559500E+00, 0.10680700E+00, -.18221300E-01, -.48605500E+01, 0.43502200E+00, -.15552300E-01, -.63540000E+00, -.34729200E+00, 0.15973600E-01, 0.16823600E+00, -.88163700E+00, -.15958200E+01, -.10754800E+00, 0.11070100E+00, 0.34776900E+00, -.54770200E+00, 0.26350800E+00, -.57940300E-01, 0.35556800E-01, -.27709100E+00, 0.55992500E-02, -.58698200E+00, 0.73172700E-01, -.44183700E+00, 0.11323300E+00, 0.12707800E+00, -.16617300E+00, 0.38105600E-01, 0.51779700E-01, 0.18507600E+00, 0.85297100E-01, -.32578200E-03, -.96840800E-01, -.31495200E+00, -.14359800E-01, 0.19602900E+00, 0.39395500E-01, 0.24321900E+00, 0.17230400E+00, 0.58277100E-01, 0.14732600E-01, -.15929300E+00, 0.32577700E-01, 0.15027000E+00, -.89229900E-01, -.36232300E+00, -.56361000E-01, -.40743700E+00, 0.16577600E+00, -.12073600E+00, -.11657000E+01, -.70702800E+00, 0.35538600E-01, 0.61965300E-02, 0.41351500E+00, 0.17658400E+00, 0.80843600E-02, 0.38199100E+00, -.11408900E+00, 0.18938400E+00, -.11003900E+00, -.12660400E+01, -.12151400E+00, 0.63137300E-01, -.23222300E-03, 0.12786800E+00, -.17989200E+00, 0.98485700E+00, -.26586400E+00, 0.47590900E+00, 0.23640500E+00, -.18264300E-01, 0.10202700E-01, -.70457900E-01, 0.11094800E-01, 0.81581400E-03, -.15660300E+00, 0.12195500E+00, 0.87213800E-01, 0.22790300E+03, 0.22045500E+03, -.20175700E+02, 0.46305900E+02, -.49022100E+03, 0.22558700E+03, 0.74560900E+03, 0.24416600E+03, -.45659700E+03, -.43656100E+03, 0.38326400E+03, 0.97113800E+03, 0.47033400E+03, -.35967700E+03, 0.47998200E+03, 0.96028300E+02, -.44757600E+02, -.56053600E+02, -.48450000E+02, 0.25575400E+02, -.16380100E+02, 0.86251900E+01, -.12490200E+03, -.18092300E+03, 0.47692500E+02, -.11692800E+03, 0.11959100E+04, -.58985200E+03, -.97022200E+03, -.59788300E+03, -.19147400E+03, 0.28431100E+03, -.33178500E+03, 0.10633700E+03, -.27891400E+03, 0.21127300E+03, -.30310700E+03, 0.18316300E+03, -.90028500E+02, 0.68163800E+02, -.91831500E+02, 0.82516300E+01, 0.16143800E+03, -.31201400E+03, -.52494400E+03, -.20212900E+03, 0.19002800E+03, -.29382000E+03, 0.13978300E+03, -.33837300E+02, -.11647400E+03, -.70939200E+02, 0.16673900E+02, 0.95468800E+02, -.10016900E+03, -.39666600E+02, -.61184600E+02, 0.62779000E+02, -.82439800E+02, 0.63211100E+02, -.16266000E+02, -.42893200E+02, -.32560500E+02, 0.37759500E+02, 0.10570600E+03, -.12473400E+03, -.10519200E+03, -.93457600E+02, 0.81604400E+02, -.15307800E+02, 0.93278100E+03, -.45953400E+03, -.51712000E+03, -.46677100E+03, -.85543100E+02, -.84835700E+02, -.20176800E+03, 0.19554800E+02, -.28680700E+03, -.12465000E+03, -.28040700E+03, -.10029800E+04, 0.50330300E+03, 0.26497700E+03, 0.50101900E+03, 0.18806000E+03, 0.53510600E+02, 0.14764700E+03, -.52808300E+03, 0.71695200E+02, 0.71159400E+02, 0.11257300E+03, -.80279200E+03, 0.41653000E+03, 0.38288800E+03, 0.39803600E+03, 0.55634300E+02, 0.12575800E+03, 0.13321500E+03, -.90062000E+02, 0.43591500E+03, 0.23118600E+03, 0.83487700E+01, -.18375500E+03, 0.10000800E+03, 0.17752400E+03, 0.90380600E+02, 0.16902100E+03, 0.10525400E+03, 0.14641900E+03, 0.49163000E+03, 0.35497700E+03, -.17156400E+02, -.10221400E+03, 0.73824800E+02, -.39643000E+02, -.42735500E+02, -.36507000E+02, -.69717000E+02, -.24291000E+03, 0.65839900E+02, 0.22517200E+03, 0.91492100E+02, -.24734200E+03, -.11884200E+03, 0.19011400E+03, -.79081400E+02, -.52138100E+02, -.94499000E+02, 0.96787000E+02, 0.19885100E+03, 0.11866500E+03, 0.60554300E+03, 0.35234900E+03, 0.21017600E+03, 0.26718500E+02, 0.34965700E+03, -.18617700E+03, 0.21143700E+03, -.17444400E+03, -.14829500E+03, -.28400500E+03, 0.75799600E+02, 0.24302200E+03, -.13999600E+03, -.25552700E+03, -.12175500E+03, 0.13879700E+04, -.69492900E+03, -.40351600E+03, -.69444200E+03, -.18986100E+03, -.44772400E+02, -.30105200E+03, 0.15429800E+03, -.41491500E+03, -.55857700E+02, -.36341900E+03, 0.12597500E+02, -.27890600E+02, -.47457900E+02, 0.12749800E+02, 0.95846500E+00, 0.72488500E+01, 0.11256600E+02, 0.48856100E+02, 0.47357400E+02, 0.11117400E+02, -.23895100E+02, 0.24033900E+02, 0.51313200E+02, -.10369000E+01, -.14153900E+02, -.18774100E+02, -.20317700E+02, -.21621800E+02, 0.97033100E+02, 0.59597100E+01, 0.40920600E+02, -.34998600E+02, 0.16836600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.79124300E+00, 0.14026200E+01, -.92122800E+00, 0.10361500E+01, 0.56090800E-01, -.54522800E+00, 0.19573300E+00, 0.15872100E+01, 0.16971100E+02, 0.57623100E+00, -.12782800E+00, 0.66077600E+00, -.22466200E-01, -.15079800E+00, 0.70499100E-01, -.37559600E+00, -.61367300E+00, -.89357800E+00, 0.78237600E-01, -.36494900E+00, 0.79526500E+00, -.17079100E+00, 0.70619300E+00, -.56133100E+00, -.67192400E+00, 0.79078600E-02, -.38987500E+00, 0.21052300E-01, -.15733500E+00, -.17294100E+00, -.25178600E-01, -.27739000E+00, 0.30442000E-01, -.10550100E+00, -.39090000E-01, 0.20474500E-01, 0.23929200E-02, 0.26036500E+00, -.40581800E+00, 0.91420100E-01, 0.63380400E+00, 0.11678500E-01, 0.82275600E+00, 0.17515800E+00, 0.92540000E-01, 0.15573300E+00, -.13052600E-01, -.54441200E-01, 0.57867800E+00, -.19404400E+00, 0.18228600E+01, -.23904200E+00, -.11529600E+00, -.82713000E-01, -.40106400E+00, 0.86710000E+00, -.70114400E+00, -.30950100E-01, 0.26299600E+00, 0.13474400E+01, -.27808000E-03, -.13327400E+00, -.33654600E+00, -.14547300E+00, -.27939600E+00, 0.49079800E-01, -.16332500E+01, 0.53974500E-01, 0.10283300E+00, -.10382700E-02, 0.17750200E+00, 0.41871600E+00, 0.85200100E+00, 0.19625200E+01, 0.72032900E-02, -.88989700E+00, -.81396200E+00, -.29833100E+00, -.14894200E+00, -.32072300E-01, 0.26076700E-02, -.12710300E+01, 0.26429700E+00, -.68262400E+00, 0.21392600E+00, -.48205800E+03, -.14065700E+03, -.93691200E+02, 0.83410600E+04, -.41842900E+04, -.44733500E+04, -.41702000E+04, -.10858400E+04, -.17940700E+04, -.18858900E+03, 0.24777900E+04, -.38207400E+04, -.21106300E+03, -.32721200E+04, -.21933700E+03, 0.13581900E+03, -.14822600E+03, 0.10978300E+03, -.20189600E+03, -.38172200E+03, 0.23439000E+03, -.30666100E+02, 0.61264500E+03, -.52249300E+03, 0.21013600E+03, -.59839200E+03, 0.30507900E+03, 0.17850600E+04, 0.29917300E+03, 0.35229800E+03, -.34790400E+03, 0.10437800E+03, 0.37612200E+02, 0.35621200E+03, -.67825100E+03, 0.14661600E+04, -.22997300E+04, 0.11847200E+04, 0.12362700E+04, 0.11495000E+04, 0.18565500E+03, -.55377200E+03, 0.86581300E+03, 0.11629700E+03, 0.97732200E+03, -.70404000E+03, 0.13138500E+02, -.31435200E+04, 0.15709400E+04, 0.20732000E+04, 0.15725400E+04, 0.61482400E+03, 0.46265600E+03, 0.92777900E+03, 0.76166800E+03, 0.90703100E+03, 0.49466300E+03, 0.18909300E+03, -.36952000E+04, 0.18280900E+04, 0.23757100E+04, 0.18483900E+04, 0.58585000E+03, 0.32338500E+03, 0.10600200E+04, 0.60621400E+03, 0.96572800E+03, 0.37343400E+03, 0.26595500E+02, -.49925600E+03, 0.25496200E+03, -.39404800E+02, 0.24975500E+03, 0.84948700E+02, -.15037500E+03, -.27070400E+03, -.21221200E+03, 0.51847500E+03, -.45040300E+03, 0.24329500E+03, -.65269000E+04, 0.32472200E+04, 0.34096500E+04, 0.32636000E+04, 0.10111900E+04, 0.81950300E+03, 0.95795700E+03, -.11051700E+04, 0.21768300E+04, 0.82312400E+03, 0.20578700E+04, -.69942900E+03, 0.42540100E+03, 0.11994700E+04, 0.35035900E+03, 0.15116100E+03, -.14260600E+04, -.41636400E+03, -.10053100E+04, 0.18787400E+03, -.20348900E+04, -.52484700E+03, -.32756400E+03, 0.17977700E+03, 0.28649000E+03, 0.16050900E+03, -.15373200E+03, -.38007300E+03, 0.16804600E+03, 0.69607100E+03, 0.26260400E+03, -.71197200E+03, 0.81112400E+03, 0.38594000E+03, -.21053200E+03, 0.25674800E+03, -.19281600E+03, 0.41567200E+03, 0.58318700E+03, -.40048400E+03, -.19541100E+03, -.60016800E+03, 0.63366500E+03, 0.49018100E+02, 0.12734000E+04, -.58693200E+03, 0.27142900E+03, -.63690900E+03, -.24229300E+03, -.77447500E+03, -.85619900E+03, -.66548900E+03, -.24940700E+03, -.16190700E+04, 0.69629800E+03, -.15470500E+04, 0.77366100E+03, -.60651700E+01, 0.77340200E+03, 0.25666900E+03, -.17306900E+03, 0.11936600E+04, 0.13138600E+04, 0.61683900E+03, 0.19907100E+03, -.36549500E+03, -.18317800E+04, 0.91378800E+03, 0.54540600E+03, 0.91591700E+03, 0.71620200E+03, 0.28446700E+02, 0.40478600E+03, -.54527200E+01, 0.48395300E+03, 0.10686800E+03, 0.55287200E+02, 0.71293000E+02, 0.10880000E+03, 0.31038800E+03, 0.78388800E+02, -.50264800E+02, -.54221200E+02, 0.67979600E+02, -.31147300E+03, -.35153600E+03, 0.17148200E+03, -.24188400E+03, 0.50208200E+03, -.14140300E+02, -.53427500E+02, 0.90254600E+02, -.88284000E+02, -.14143800E+03, 0.12208100E+03, -.76353500E+02, -.62245900E+02, 0.70857400E+01, 0.15803800E+03, -.11237700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57612000E+01, 0.45160300E+01, 0.14689400E+01, 0.18045200E+01, -.26855200E+00, -.24835300E+01, 0.13623200E+01, 0.57402300E+01, -.23566600E+00, 0.10177300E+00, -.38679100E-01, -.12599000E+01, 0.20605800E+00, 0.43988800E+00, 0.99331600E+00, -.37750600E+01, -.65247200E+01, 0.70687900E+01, 0.11986300E+01, 0.40197900E+00, -.30565200E+01, 0.13728100E+01, 0.59280300E+01, 0.12703700E+01, 0.11730500E+00, 0.19337800E+00, 0.24257000E+01, 0.79395400E+00, -.12275800E+01, -.10330400E+01, -.14001400E+01, 0.59814500E+00, 0.20455200E-01, 0.52571900E+00, -.87148000E+00, 0.39440200E-01, 0.33553600E+00, -.13642000E+01, 0.16791100E+01, -.21477200E+01, -.44674000E+01, 0.15203200E+01, 0.48541300E+01, 0.38405700E+01, 0.21914900E+00, -.21355400E-01, 0.13099900E+01, 0.43055400E+00, -.65012500E-01, 0.45024600E-01, -.67567600E+01, 0.47847900E+00, -.11272500E+01, 0.25917600E+01, -.32893200E+00, 0.37644500E+01, -.21561900E+01, -.15588600E+00, 0.13588600E+01, -.59904400E+00, 0.15745500E+01, 0.21158100E+00, -.48738100E+00, 0.95620600E+00, 0.64181100E+01, -.68180500E+00, -.51077100E+01, 0.47354700E+00, 0.23818900E+00, -.15985000E-02, 0.15181400E+00, 0.38485700E+01, -.30384200E+01, -.54127400E+01, -.18679300E+00, 0.29913600E+01, 0.23218600E+01, 0.11874900E+01, 0.14079600E+01, 0.16754700E+00, -.96026800E-02, 0.32598800E+01, -.15707100E+01, 0.27462600E+01, -.92958000E+00, 0.25621800E+01, 0.18697800E+04, 0.94806400E+02, -.80590600E+05, 0.40404400E+05, 0.36162800E+05, 0.40294500E+05, 0.52140500E+04, 0.10495500E+05, 0.49103300E+04, -.19864800E+05, 0.29074700E+05, 0.45622900E+04, 0.32883900E+05, 0.19788500E+04, -.11614400E+04, 0.12421900E+04, -.98974900E+03, 0.12872900E+04, 0.15486500E+04, 0.80817100E+02, 0.30963000E+04, -.58747900E+03, 0.90280600E+03, -.18279200E+04, 0.81086000E+04, -.40998400E+04, -.14375200E+05, -.40542500E+04, -.79260200E+03, 0.23317500E+04, 0.84856500E+03, 0.61648000E+04, -.25277400E+04, 0.39274000E+04, -.11038100E+05, 0.11741700E+05, -.61473200E+04, -.78431200E+04, -.58707100E+04, 0.34931700E+03, 0.48445600E+04, -.67671100E+04, -.24941000E+04, -.57679800E+04, 0.50108100E+04, 0.19457200E+02, 0.17042100E+05, -.82673100E+04, -.12730100E+05, -.85219600E+04, -.29834100E+04, -.16148500E+04, -.63616200E+04, -.70252300E+04, -.63497200E+04, -.20380800E+04, 0.24695000E+03, 0.19876200E+05, -.97186800E+04, -.13850400E+05, -.99390400E+04, -.25176300E+04, -.43674500E+03, -.77068600E+04, -.66627900E+04, -.70952300E+04, -.10217200E+04, 0.15627900E+04, 0.12450700E+05, -.63024400E+04, -.30993400E+04, -.62256600E+04, -.61243600E+03, 0.10646300E+03, 0.78213700E+03, 0.32269300E+04, -.38869200E+04, 0.10880300E+04, -.56037800E+04, 0.36400000E+05, -.18107600E+05, -.17196300E+05, -.18200400E+05, -.54281800E+04, -.49980100E+04, -.51346600E+04, 0.42849300E+04, -.12396600E+05, -.54721600E+04, -.12301500E+05, 0.80997100E+04, -.45331400E+04, -.12988200E+05, -.40522900E+04, -.16081900E+04, 0.73924600E+04, 0.33188900E+04, 0.10566200E+05, -.13108600E+04, 0.97149800E+04, 0.39341600E+03, 0.22828300E+04, -.12295600E+04, -.28708000E+04, -.11138200E+04, 0.84114200E+03, 0.11128100E+04, -.22715000E+03, -.27832100E+04, -.23989200E+04, 0.32478600E+04, -.61235800E+04, -.49824400E+04, 0.26167600E+04, -.61283100E+03, 0.24912800E+04, -.16420700E+04, -.26143000E+04, 0.25236800E+04, 0.18501800E+03, 0.37663700E+04, -.29168600E+04, -.24746300E+03, 0.27616400E+03, -.46443600E+03, -.96060800E+04, -.13761700E+03, 0.88209900E+03, 0.29829100E+04, 0.82137600E+04, 0.14954900E+05, 0.12793700E+04, 0.72549200E+04, -.68103700E+04, -.23821500E+04, 0.12021200E+04, 0.24258700E+04, 0.11913800E+04, -.24001300E+04, 0.62680100E+03, -.57349100E+04, -.10808500E+05, -.23153800E+03, -.10880700E+04, 0.71352500E+04, 0.11694400E+05, -.58323200E+04, -.65944900E+04, -.58474200E+04, -.42941700E+04, -.33763600E+03, -.25139300E+04, 0.44304300E+03, -.22507200E+04, -.69734900E+03, -.45611500E+03, -.40340700E+03, 0.44445000E+03, -.75813700E+03, -.39056700E+03, 0.13175200E+03, 0.19886500E+03, -.39678100E+03, 0.75907400E+03, 0.10028200E+04, -.12751900E+04, 0.78063900E+03, -.17021800E+04, 0.92784000E+03, 0.23153200E+03, -.60851800E+03, 0.11460000E+03, 0.26906300E+04, -.78156400E+03, 0.27040500E+02, 0.30026100E+03, -.89649000E+03, 0.33825900E+03, -.39090200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.60638900E-01, -.10457300E+00, -.59025000E-01, -.81296700E-02, -.47055900E-01, -.23663800E+00, -.55973600E-01, -.12526500E+00, 0.31624400E+01, -.18912700E+00, 0.99181200E-02, 0.41398900E+00, 0.22453700E+00, -.21112700E-01, -.16335600E+00, 0.63995400E+00, 0.16157800E+01, 0.38737700E+00, -.47126600E-01, -.39307900E+00, 0.36748700E+00, -.14132500E+00, 0.51738400E+00, 0.49750700E-01, 0.23105100E-01, 0.39963800E-03, -.49194700E-01, -.37670700E-01, 0.10879700E+00, 0.51423800E-01, 0.12677800E+00, -.82393000E-02, -.13668900E-01, -.48597600E-02, -.30496600E-01, -.13769400E-01, -.63135900E-03, 0.67074500E-02, 0.11739600E+00, -.12610400E-01, -.25292300E-02, -.53957700E-02, -.24270100E+00, -.54460700E-01, 0.73200500E-02, -.20900700E-02, 0.11188000E+00, 0.99822900E-02, -.14918900E+00, 0.47665200E-01, -.73728400E+00, -.94224600E-01, 0.11065400E+00, 0.11836900E+00, -.12127500E-01, 0.24374700E+00, 0.22603100E+00, -.46626000E-01, -.79868200E-01, -.10393200E+01, -.93881800E-02, -.67714100E-02, -.53235500E-02, 0.53551500E-01, 0.18562400E-01, 0.10823800E+00, 0.36227900E+00, 0.36829900E-01, -.24344300E-01, -.22278500E-03, -.24952300E-01, 0.27951100E-01, -.46758500E+00, -.80766200E-01, -.16863400E+00, 0.16223100E-01, -.42103900E-01, 0.50049700E-01, -.40973800E-01, -.12520900E-01, -.11505500E-03, 0.18009400E-01, -.51496300E-01, 0.37932600E-01, 0.17786900E+00, 0.37496900E-01, 0.13320000E-01, -.25687800E+03, 0.95204000E+03, -.48183400E+03, -.79151400E+03, -.47592500E+03, 0.14896500E+03, -.17751400E+02, -.26668100E+03, -.22864300E+03, -.42129700E+03, -.11103100E+03, -.64693600E+03, -.52134800E+02, 0.28973500E+02, 0.14668300E+02, 0.26104600E+02, 0.85225800E+01, 0.40113700E+02, -.45203000E+02, -.86012500E+02, 0.19786300E+02, 0.62333600E+02, 0.36524900E+03, -.11644000E+03, 0.62252300E+02, -.11358400E+03, 0.58212900E+02, -.65784600E+02, -.23612100E+02, 0.95373200E+01, -.76050700E+02, 0.16856200E+02, -.44209100E+01, 0.36765400E+03, -.54896800E+02, 0.24291000E+02, -.16293800E+02, 0.27364400E+02, -.64677500E+02, -.90465600E+02, 0.29612000E+03, 0.39126900E+03, 0.16899100E+03, -.11538200E+03, -.21363900E+03, -.35322200E+03, 0.20359000E+03, 0.43714600E+03, 0.17686300E+03, 0.11712400E+03, 0.22040600E+03, 0.33231400E+02, 0.93348700E+02, 0.25541100E+02, 0.16316200E+03, 0.49397000E+01, -.36893300E+03, 0.19551600E+03, 0.41477500E+03, 0.18471000E+03, 0.10682100E+03, 0.17098100E+03, 0.64579600E+02, 0.85480600E+02, 0.32133800E+02, 0.13009800E+03, 0.35542100E+02, -.34369800E+03, 0.17399900E+03, 0.17492700E+03, 0.17188900E+03, -.60674200E+01, -.44700200E+02, 0.98308200E+02, 0.49057000E+02, 0.36019000E+02, -.52531500E+00, 0.44438300E+03, -.65130000E+02, 0.31628800E+02, 0.75983300E+02, 0.32608900E+02, -.76744400E+01, 0.39853400E+02, 0.26642200E+02, 0.14157600E+03, 0.13798300E+03, 0.36677500E+02, -.82841000E+02, 0.55460800E+03, -.27035700E+03, -.11321000E+03, -.27709500E+03, 0.10795100E+03, 0.43503200E+02, 0.20714800E+02, 0.41832300E+03, 0.13172200E+02, 0.88270600E+02, -.44197800E+03, -.31572600E+02, 0.19827000E+02, 0.14210500E+03, 0.16733200E+02, -.49344700E+02, -.55714200E+02, 0.89891200E+01, 0.37545000E+02, 0.54921600E+02, -.16453900E+02, 0.62962900E+02, -.14579700E+02, 0.70926800E+01, 0.17070100E+03, 0.73140500E+01, 0.80065600E+02, 0.17395800E+03, -.83182700E+02, -.77292300E+02, -.14869500E+03, 0.12768800E+03, 0.58586000E+02, 0.32197800E+03, -.15316300E+03, -.73069900E+01, -.16105000E+03, 0.86751900E+02, 0.10562700E+03, -.18319600E+03, -.63721400E+02, -.10145000E+03, 0.18757700E+03, 0.19722400E+03, -.64307600E+02, 0.28535700E+02, -.91225100E+02, 0.32116100E+02, 0.12964500E+03, 0.61899300E+02, 0.71747700E+02, 0.99905300E+02, 0.20394100E+02, 0.24317900E+02, -.10741100E+03, -.16951900E+03, 0.84424100E+02, 0.58609900E+02, 0.84778900E+02, 0.17951700E+02, -.28019000E+01, 0.43566100E+02, 0.16711000E+00, -.95372000E+01, -.24168200E+01, 0.61960000E+02, -.25400500E+01, -.53348600E+01, 0.77606300E+01, 0.27186300E+01, -.30243200E+02, -.31245300E+02, -.58133300E-01, -.76683600E+01, -.42546900E+02, -.47168200E+02, -.29715200E+02, 0.17096700E+02, -.73862800E+02, -.35127100E+02, 0.32860600E+02, -.34720700E+02, -.43378100E+02, 0.21261800E+02, -.10103900E+01, 0.12506400E+02, -.30666700E+02, -.74969300E+01, 0.87100900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.65695300E+00, 0.11173200E+01, 0.61512800E-01, 0.11191700E+01, 0.44897900E+00, -.87039600E+00, 0.90661900E+00, -.46204600E+00, -.10022000E+02, 0.92414900E+00, 0.36401900E-02, -.82297300E+00, -.31700300E+00, -.37320100E-01, 0.65401500E+00, -.28381800E+00, -.14492400E+01, 0.13616300E+01, 0.40573700E+00, 0.56897200E+00, -.26183300E+00, 0.26733400E+00, -.70606400E+00, -.78399100E-01, 0.47307800E-01, -.38543200E-02, -.42950300E+00, 0.14771800E-01, 0.12828900E+00, -.54911800E-01, 0.33650600E+00, -.33659600E+00, -.43342800E-01, -.99390200E-01, 0.54499500E-01, -.92862100E-01, 0.40435800E-02, -.67280300E-01, -.16810700E+00, 0.56230200E+00, -.18223800E+00, -.92220100E-01, 0.37536300E+00, 0.17432400E+00, -.12436000E+00, -.79239400E-01, 0.39363200E+00, -.43728200E-01, -.64626400E-01, 0.13077500E+00, -.15502500E+01, 0.12236400E+00, 0.38055900E+00, -.21745400E+00, 0.93333600E+00, 0.24872400E+00, 0.97461600E-02, 0.99486100E-01, -.56853300E-01, 0.25871000E+01, -.79213500E-01, 0.11708400E-01, 0.36499000E+00, -.24321400E+00, -.62277700E+00, 0.37411800E+00, 0.19797500E+01, 0.73656600E-01, -.31892200E-01, -.11477000E-03, 0.61317800E-01, -.26940800E+00, -.56945600E+00, -.75422700E+00, -.38523300E+00, 0.23665100E-01, 0.17401700E+00, 0.56249300E+00, 0.73060400E-01, -.10647400E+00, -.72466300E-03, 0.11616700E+01, -.15081200E+00, -.81149200E+00, -.25127000E+00, -.20909300E-01, -.27422700E-01, -.20421900E+01, 0.73346000E+04, -.36704300E+04, -.32294800E+04, -.36682100E+04, -.81938700E+03, -.43827600E+03, -.95920700E+03, 0.11378300E+04, -.20910900E+04, -.22026400E+03, -.35528000E+04, -.58381400E+03, 0.30483300E+03, 0.28011300E+03, 0.29144700E+03, 0.11718600E+02, -.57374400E+02, 0.19744100E+03, -.27235000E+03, -.16071600E+03, -.11100500E+03, 0.46094300E+03, -.10711400E+04, 0.53739500E+03, 0.11739500E+04, 0.53563700E+03, 0.67274900E+03, -.23368300E+03, 0.26983800E+03, -.40907700E+02, 0.58166000E+03, -.38308800E+03, 0.50559900E+03, -.13970700E+04, 0.71591400E+03, 0.48834700E+03, 0.69768700E+03, 0.21105000E+03, -.41946600E+03, 0.48056200E+03, 0.36740500E+03, 0.71044800E+03, -.47689100E+03, 0.27917200E+03, 0.34822600E+03, -.20320000E+03, -.10880600E+03, -.17438000E+03, -.63385400E+02, -.26450300E+02, -.26729200E+03, -.32034300E+03, -.20348100E+03, -.47749400E+02, 0.13049000E+02, 0.13916800E+03, -.91781700E+02, -.78013000E+02, -.69743700E+02, -.46799400E+02, -.10743000E+02, -.26231100E+03, -.45308300E+03, -.15799300E+03, -.40364200E+02, 0.45442800E+02, -.71559000E+03, 0.36082100E+03, 0.36909700E+03, 0.35743300E+03, 0.26931900E+03, 0.27533000E+03, -.21124300E+03, -.33310000E+03, 0.47798400E+01, 0.22257700E+03, 0.58542300E+03, -.14235200E+04, 0.70898500E+03, 0.84032100E+03, 0.71128300E+03, 0.32588100E+03, 0.27948200E+03, 0.32581500E+03, 0.41796100E+03, 0.79049900E+03, 0.21878100E+03, 0.44909800E+03, -.18808900E+04, 0.97453100E+03, 0.12452700E+04, 0.93650000E+03, -.44029000E+03, -.83730400E+03, 0.14261400E+02, -.89235800E+03, 0.20944000E+03, -.82932300E+03, 0.10611300E+04, 0.29951000E+02, -.11110500E+02, -.99072500E+02, -.14453700E+02, 0.62793500E+02, 0.12782700E+03, 0.13127800E+02, -.11350800E+03, -.71040800E+02, 0.90830800E+02, 0.36855000E+02, 0.53013300E+03, -.27201200E+03, -.87465200E+02, -.26430700E+03, 0.33028600E+02, 0.21577300E+03, -.21256100E+03, 0.53381800E+02, -.18746100E+03, 0.22007200E+03, -.32800400E+03, -.25432000E+04, 0.12914700E+04, 0.14901600E+04, 0.12721100E+04, -.29295500E+03, -.54948200E+03, 0.12245200E+02, -.16137500E+04, 0.40993600E+03, -.44846900E+03, 0.18627100E+04, 0.38495200E+03, -.18958400E+03, -.47398900E+03, -.19209800E+03, 0.12369200E+03, 0.19168300E+03, 0.27007400E+03, 0.12324400E+04, 0.25911200E+03, 0.21035800E+03, -.58056100E+03, -.47266300E+03, 0.23491900E+03, -.61072100E+02, 0.23573600E+03, 0.28684300E+03, 0.37124900E+02, -.55234500E-01, 0.27021100E+03, 0.44958000E+03, -.15643300E+02, 0.44528100E+02, 0.11128900E+02, 0.46399200E+02, 0.68325200E+01, -.28667400E+01, 0.25566800E+02, 0.23940900E+02, 0.95348600E+01, -.76977300E+01, 0.65780400E+02, 0.10935500E+03, 0.27118000E+02, -.29416100E+03, 0.10625700E+02, 0.34671600E+02, -.33489200E+02, 0.99587900E+02, -.14435400E+03, 0.44281000E+02, 0.61045700E+02, -.13537200E+02, 0.10251000E+03, -.30636300E+02, -.59327700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24996000E+01, 0.35369400E+01, -.30769800E+01, 0.13902600E+01, -.16525900E+01, -.82795300E+00, 0.25611600E+00, 0.19705500E+01, 0.17436900E+02, 0.27905400E+00, -.96612200E-01, 0.13829600E+01, 0.22189200E+00, 0.23291300E+00, -.33259700E+01, -.37402700E+00, -.38226600E+01, -.79664900E+01, -.54016200E+00, 0.85070000E+00, 0.37288000E+01, -.23043300E+00, -.18645100E+01, -.12053100E+00, -.20814200E+01, 0.28940600E-01, 0.44446000E+00, 0.16137900E+00, -.28455700E+00, -.39286400E+00, -.41264600E+00, -.63218600E-02, -.25508300E-01, -.18377700E+01, -.20842300E+01, 0.74823500E+00, 0.28941700E-02, 0.13478700E+00, 0.12293800E+00, 0.23605400E+00, 0.81970500E+00, -.42615600E+00, -.12614800E+01, -.47163200E+00, 0.26759400E+00, -.46441100E-01, -.96283600E+00, -.11391600E+00, 0.32443000E+00, -.61898200E+00, 0.18517800E+01, -.98044900E+00, 0.70875300E+00, 0.24561700E+00, 0.17553100E+00, 0.20196100E+01, -.22160100E+01, 0.30408000E+00, 0.90814100E+00, -.18237400E+01, 0.10474600E+01, 0.33279300E+00, -.17422600E+01, 0.77601300E-01, 0.19742900E+01, -.33779900E+00, -.51333600E+01, -.48539700E+00, -.80603100E-01, 0.38389000E-02, -.55283100E-01, 0.14366200E+01, 0.31970800E+01, -.18069100E+01, 0.66300000E+00, 0.11226500E+01, -.17307500E+01, 0.30763700E+00, -.45025800E+00, 0.37657700E+00, 0.27848500E-02, -.18153000E+01, -.76656900E+00, 0.29971900E+00, -.75543600E+00, 0.13236900E+01, 0.12062400E+00, 0.10375900E-01, -.39616100E+00, -.21066100E+03, 0.17566600E+04, -.59277000E+01, -.41957500E+03, -.40395400E+03, -.21185300E+04, -.21955800E+04, 0.22002600E+04, -.82243200E+03, 0.56099700E+03, -.23523900E+03, 0.17844800E+03, -.81765900E+03, 0.11465400E+03, 0.19613400E+02, 0.85191500E+02, 0.87831700E+03, 0.54403800E+03, -.86849600E+03, 0.17321000E+03, 0.73308100E+03, 0.58682300E+04, -.28437500E+04, -.22104300E+04, -.29336700E+04, -.70307600E+03, 0.18058200E+04, -.13679500E+04, 0.14353100E+04, -.24844500E+04, 0.18126300E+04, -.17222600E+04, 0.53248300E+04, -.25899200E+04, -.28137400E+04, -.26670300E+04, 0.63034800E+03, -.55400000E+03, 0.16129100E+04, 0.35009000E+04, -.55656100E+03, -.11549300E+04, -.29011000E+04, -.16182900E+04, 0.99640300E+03, 0.47580100E+04, 0.80574700E+03, 0.54882300E+03, 0.14613700E+04, -.70850100E+02, 0.51461100E+03, 0.22694300E+03, 0.11190100E+04, -.76127200E+03, -.34764200E+04, 0.17888600E+04, 0.60973000E+04, 0.17356000E+04, 0.61843400E+03, 0.15287400E+04, 0.16612700E+02, -.70907900E+02, 0.56025400E+03, 0.12647900E+04, 0.19909700E+03, 0.17587200E+04, -.78830100E+03, -.28553800E+04, -.88175900E+03, 0.33093700E+03, -.56843800E+03, 0.23080000E+03, 0.19090200E+04, -.65127000E+03, -.46400300E+03, -.70361700E+03, -.17425700E+04, 0.88314200E+03, 0.11131500E+03, 0.86821300E+03, 0.78628100E+02, 0.14099800E+01, 0.73472200E+03, -.59530200E+02, 0.51963900E+03, -.17608900E+02, 0.37734000E+03, 0.12723400E+05, -.61333600E+04, -.61099300E+04, -.63863300E+04, 0.25582800E+04, -.89679400E+03, 0.19694600E+04, 0.71312200E+04, -.36431300E+04, -.12605400E+04, -.58341200E+04, -.13368000E+04, 0.74706300E+03, 0.16612900E+04, 0.66714800E+03, -.45242400E+03, -.10948400E+04, 0.12456400E+04, 0.93313300E+03, 0.20081800E+03, -.84715300E+03, 0.59504900E+03, 0.25937100E+04, -.13450100E+04, 0.20326700E+03, -.12923800E+04, -.36294600E+02, -.54038300E+02, -.29344200E+03, 0.89783800E+03, -.55931900E+03, -.38996600E+03, -.11140500E+04, 0.52763200E+04, -.24413600E+04, -.20049000E+04, -.26347600E+04, 0.13190600E+04, 0.12257200E+04, -.33255200E+03, 0.29804500E+04, -.30589100E+04, 0.14648200E+04, -.13219900E+04, 0.58459300E+03, -.40264600E+03, 0.16494500E+03, -.28982900E+03, 0.12765600E+04, -.10045700E+04, 0.10212900E+03, 0.38995800E+03, 0.85124000E+03, -.12083800E+04, -.84011000E+03, 0.38004700E+04, -.19138200E+04, -.50640900E+03, -.19039500E+04, 0.95561000E+02, -.19898200E+03, -.73920200E+03, 0.10684200E+04, -.60264600E+03, -.25393900E+03, -.18803700E+04, 0.14065900E+03, -.14110600E+03, -.12473400E+03, -.69530100E+00, 0.28315700E+02, -.18048800E+02, 0.12186000E+03, 0.12912000E+03, -.27136500E+02, -.64671400E+03, -.17349400E+03, 0.45634300E+03, 0.31319200E+03, -.37843300E+02, 0.75616700E+02, -.26200000E+03, -.75847100E+03, 0.23701000E+02, -.14139700E+03, -.17169300E+02, -.78059400E+03, 0.99476000E+02, 0.50913800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24721500E+00, 0.19329300E+00, -.81426600E+00, -.23814400E+00, 0.45922000E-01, 0.50539300E+00, -.10126400E+00, -.37328100E+00, -.20454600E+01, 0.27011100E+00, -.10669600E-03, -.88747200E-01, 0.12722200E+00, -.36805900E-01, -.33402300E+00, 0.25288200E+00, 0.30356100E+00, -.50486000E+00, -.14072500E+00, -.22942600E+00, -.81892600E-01, -.34440700E-01, 0.16708800E+00, 0.48303300E-01, 0.70225700E-01, 0.11320400E-01, -.69578000E-01, 0.67223000E-02, 0.55171300E-01, 0.29569300E-02, -.16028900E-02, 0.42395000E-01, -.21029300E-01, -.13272700E+00, -.23229000E+00, -.32459100E-01, 0.19378500E-02, 0.59874600E-01, 0.17566900E+00, -.58150700E-01, 0.49918300E+00, -.34110200E-01, -.15197200E+00, -.16057000E+00, 0.68417600E-01, 0.40296600E-01, -.49039600E-01, 0.34298400E-01, -.36550300E-01, -.11867200E+00, 0.94163900E+00, -.44206300E-01, -.13148100E+00, 0.15021600E+00, -.26240600E+00, -.13323100E+00, -.21426200E+00, 0.12162100E-02, 0.17702300E+00, 0.99426100E-02, 0.35135900E-01, 0.33007900E-01, -.19388600E+00, 0.31690900E-01, 0.40803100E+00, -.16981100E+00, -.43166100E+00, -.69426700E-02, 0.26049700E-01, 0.33033900E-03, -.91744900E-01, 0.18341000E+00, -.24934800E+00, -.33135800E+00, -.15442300E+00, 0.11770700E+00, 0.95854300E-01, 0.35334100E-01, 0.36488500E-01, 0.14116200E-01, -.71372900E-03, 0.30262400E+00, -.97155600E-01, 0.14026400E+00, 0.51059500E-01, 0.12387700E+00, 0.53119500E-01, 0.11068800E+00, -.47461500E-01, 0.11165300E-01, -.67853800E+03, 0.16767000E+00, 0.17795100E+03, -.11236800E+03, 0.29464700E+03, 0.23916100E+03, -.34974400E+03, -.12461500E+03, -.19255700E+03, -.43142000E+02, 0.23713200E+02, -.10114200E+03, 0.21648600E+02, 0.74051800E+01, 0.38994800E+02, -.14806500E+03, -.20738600E+03, -.20306900E+02, 0.19257300E+02, 0.11985300E+03, -.73061500E+03, 0.36632100E+03, 0.21333700E+03, 0.36529500E+03, -.21054000E+02, -.23570500E+03, 0.16388600E+03, -.24983400E+03, 0.25602600E+03, -.15314000E+03, 0.51162200E+03, -.15744200E+03, 0.80585600E+02, 0.22665800E+03, 0.78767900E+02, 0.52946900E+02, 0.18801800E+02, 0.15309900E+02, 0.33104000E+02, -.92379300E+02, 0.30400400E+02, 0.22365200E+02, -.24945800E+03, 0.11911300E+03, 0.12572100E+03, 0.12491400E+03, -.79661000E+01, -.49338500E+01, 0.94916800E+02, 0.60228500E+02, 0.61004700E+02, 0.76251200E+00, 0.95379100E+02, -.28466600E+03, 0.13938400E+03, 0.68133300E+02, 0.14250100E+03, -.34400500E+01, -.11044000E+02, 0.11820500E+03, 0.57334800E+02, 0.11254800E+03, -.59493300E+01, 0.10265100E+03, -.26718900E+03, 0.13599900E+03, 0.20284800E+03, 0.13366200E+03, 0.26780300E+02, 0.37309800E+00, 0.35891400E+02, -.59355300E+02, 0.53595400E+02, 0.23639400E+02, 0.22188900E+03, 0.20867100E+03, -.10496400E+03, 0.48365500E+02, -.10425200E+03, 0.92327000E+01, 0.61540800E+02, -.10968500E+03, 0.11122200E+03, 0.12278400E+03, 0.54350300E+02, -.15030000E+03, 0.27578900E+03, -.13531600E+03, 0.40441400E+03, -.13729500E+03, 0.48041700E+02, 0.91162700E+02, -.27940900E+03, -.25048000E+03, -.37908600E+03, 0.58908400E+02, -.25208500E+03, -.20010000E+03, 0.10008900E+03, 0.23819400E+03, 0.99855300E+02, -.99476200E+01, 0.39884400E+01, -.36064100E+02, -.13624200E+03, -.45657600E+02, 0.15736900E+02, 0.17259500E+03, -.26159000E+01, 0.73447200E+00, -.20056700E+02, 0.12348300E+01, 0.36449500E+02, 0.27481500E+02, 0.85108600E+01, 0.53063900E+02, -.63166300E+02, 0.29422400E+02, -.13435400E+01, 0.15065500E+03, -.72534500E+02, 0.22957400E+03, -.75426700E+02, -.94935400E+02, -.12988800E+03, -.11979300E+03, -.33127200E+03, 0.56543800E+02, -.90405600E+02, 0.26031100E+02, -.10597200E+03, 0.52860300E+02, -.80955400E+02, 0.52917700E+02, 0.17985500E+03, 0.72526000E+02, 0.18627500E+03, 0.39692100E+03, 0.30966100E+02, 0.54372400E+02, -.11009100E+03, -.56980700E+03, 0.28481300E+03, 0.91186900E+02, 0.28498500E+03, 0.76687200E+02, -.34253300E+02, 0.21580100E+03, 0.95984300E+02, 0.14510100E+03, -.10221700E+02, 0.23181500E+03, 0.94627500E+01, -.73296900E+01, 0.21497600E+01, 0.33767300E+01, -.10123800E+02, -.53926500E+01, 0.95201900E+01, -.20185300E+01, -.24739100E+02, 0.32958800E+02, -.15747500E+02, 0.15693900E+02, -.61781700E+02, -.17351700E+02, 0.16439700E+02, -.41819300E+01, 0.16892300E+03, 0.50671800E+02, -.12574100E+02, 0.11393200E+02, -.35533800E+02, -.24818900E+02, 0.13512000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42106100E+01, -.60982500E+01, -.18451700E+01, -.12749500E+01, 0.27323400E+01, 0.11061900E+01, -.72288600E+00, 0.40653400E+00, 0.85055900E+02, -.12412500E+01, -.62858700E+00, 0.15437700E+01, 0.14203700E+01, 0.22751300E+00, -.24877400E+01, 0.48688100E+01, 0.38237300E+01, -.38996000E+01, -.55632400E+00, -.63517400E+01, 0.77593200E+01, -.47598300E+00, 0.98598100E+01, -.20622400E+00, -.91942900E+00, -.31765300E+00, -.57336000E+01, -.12268700E+01, 0.24938100E+00, 0.68127400E+00, 0.40807400E+00, 0.97227200E+00, 0.14471300E+00, -.47637400E-01, 0.26155100E+00, -.20522600E+00, 0.57315400E-02, 0.38208200E+00, -.90795300E+00, 0.79462700E+00, -.74921400E+00, -.49763500E+00, -.12459400E+01, -.16635100E+01, -.81726000E-01, 0.15292100E-01, 0.16133900E+01, -.57697700E-01, -.65015100E-01, 0.19982400E+00, -.33366800E+01, 0.11336700E-01, 0.41244600E+01, 0.33588700E+00, 0.12880500E+01, -.30373400E+00, 0.25259000E+01, 0.16580000E+00, 0.89189300E+00, 0.76809800E+01, 0.45923000E+00, 0.27608000E+00, 0.13972900E+01, -.87554800E+00, 0.11642800E+01, -.92526100E+00, -.13697800E+01, -.45231100E+00, -.19971900E+00, -.18096100E+00, -.69854300E+00, -.27037800E+00, 0.23082300E+01, -.11893400E+01, 0.78352800E+00, -.42633600E+00, -.49715000E+00, -.14661900E+01, 0.98059500E-01, 0.61028100E-01, -.49665800E+00, -.23245100E+01, 0.26840000E+00, -.10301900E+01, 0.10096800E+01, 0.16828100E+01, 0.10147800E-02, -.61816900E+01, -.10385000E-01, 0.36226300E-01, 0.67732800E+00, -.83223800E+02, 0.19008700E+04, 0.15357100E+04, -.26908800E+04, -.69890200E+04, 0.17108800E+04, -.11785700E+04, -.19033700E+03, -.51017000E+03, 0.24358200E+03, 0.64529800E+03, 0.28092100E+03, 0.31272200E+03, 0.18732500E+04, -.12436600E+04, -.23590800E+04, -.11919900E+04, 0.20236800E+04, 0.14363900E+04, -.11099700E+03, 0.51560500E+02, 0.18863700E+04, 0.59817100E+02, 0.90353100E+03, 0.56692600E+03, 0.26125000E+03, 0.48812100E+03, -.83285500E+03, 0.10125100E+04, -.18318600E+04, 0.15197800E+04, -.77588600E+03, -.36639700E+04, -.73216900E+03, -.52746300E+03, -.76803700E+03, 0.20752000E+04, 0.29078100E+04, 0.60985100E+03, -.10873100E+04, 0.51445500E+03, 0.10881000E+04, -.60672200E+03, 0.21527700E+04, -.54947100E+03, 0.45592800E+03, 0.75385400E+03, -.72115300E+03, 0.11525900E+03, -.35273400E+03, 0.51720300E+03, -.78726700E+03, 0.32184700E+04, -.16410500E+04, 0.13028800E+04, -.16062400E+04, -.51146900E+02, 0.29057900E+02, -.45132900E+03, 0.59405500E+03, -.59186000E+03, -.61879900E+02, -.18167900E+04, -.23237500E+04, 0.11551400E+04, 0.80817600E+03, 0.11768700E+04, 0.24227900E+03, 0.16079500E+04, 0.58257400E+02, -.46014800E+03, -.11674700E+04, 0.24040600E+04, 0.79733600E+03, 0.97281300E+04, -.48510400E+04, -.47570900E+04, -.48653800E+04, -.11489200E+04, -.60798200E+03, -.10530200E+04, 0.46292800E+04, -.15849300E+04, -.65975900E+03, -.26136000E+04, 0.97012600E+04, -.48670300E+04, -.74712200E+04, -.48283300E+04, -.20277400E+03, 0.83391200E+03, -.82452800E+03, 0.13350400E+04, -.42172400E+04, 0.12454800E+04, -.14266600E+04, 0.41474400E+03, -.21950300E+03, -.61503500E+03, -.15291500E+03, -.93720200E+03, -.35554300E+03, -.12110600E+03, -.19265600E+04, -.15608800E+04, 0.67031800E+03, 0.93980900E+03, 0.11049600E+04, -.55066700E+03, 0.10098500E+04, -.62170800E+03, 0.48129300E+03, 0.22345300E+04, -.13032900E+04, -.13120900E+04, -.89420100E+03, 0.18035700E+04, 0.32410900E+03, 0.14379000E+04, -.74769200E+03, -.22902900E+04, -.66617500E+03, -.12406400E+03, 0.50789600E+03, -.10682300E+04, -.23080600E+04, -.30970500E+04, 0.19629600E+04, -.11434800E+04, -.16390700E+04, 0.82498900E+03, -.97839600E+02, 0.81019500E+03, 0.78345100E+03, 0.11577900E+04, -.12111600E+04, -.28153100E+04, 0.93557600E+03, 0.45814900E+03, 0.15017200E+04, -.31037200E+04, 0.15513800E+04, 0.22019300E+04, 0.15344400E+04, 0.32399000E+03, 0.36860900E+03, 0.35551000E+03, -.54783300E+03, 0.45697300E+03, 0.25778900E+03, 0.62931100E+03, -.13561300E+03, -.63645900E+03, -.73149500E+03, -.18699600E+03, -.21326900E+03, -.28100500E+03, -.11873000E+03, 0.72947400E+03, 0.37699300E+03, -.25201900E+03, 0.55550300E+03, -.83670200E+03, 0.19254500E+03, -.14533100E+03, 0.26779900E+03, 0.20245200E+03, 0.15434100E+03, -.18750100E+03, -.26012600E+03, 0.64348500E+02, -.34292200E+03, -.40458100E+03, 0.65571300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.33747200E+01, 0.17910700E+01, -.10488300E+01, 0.41130100E+00, 0.83439000E+00, 0.38747600E+01, -.85793200E+00, 0.16248500E+00, 0.36337200E+02, 0.24317100E+01, 0.18966600E-01, 0.76422400E+00, 0.95351100E+00, -.42980300E+00, -.84781700E+00, 0.27341400E+00, 0.36527900E+01, -.10365900E+01, -.49259100E+00, -.33419500E+01, 0.11308400E+01, 0.18835500E+00, -.87469600E+00, 0.18791000E+01, -.55831400E+00, 0.80791700E-01, -.99702200E+00, 0.10708700E-01, -.32508900E+00, -.49581900E+00, -.14416000E+01, 0.44503200E-01, -.37199800E+00, 0.10955400E+01, -.13856300E+01, 0.41237100E+00, 0.25603300E-01, 0.20035600E+01, 0.58758000E+00, -.27950300E+01, -.39821500E+00, -.13275400E-01, -.48927300E+00, -.77116900E+00, 0.18999000E+00, -.43428800E+00, -.17144400E+01, -.63260000E-01, 0.15020600E+01, -.16449900E+00, -.86963700E+00, -.16776500E+01, -.45648300E+00, 0.59763200E+00, -.52226600E+00, 0.39183600E+00, 0.32686500E+01, -.11560800E+00, 0.12039500E+01, 0.29060500E+01, 0.12108700E+01, -.20133800E+00, 0.12972700E+01, -.12644100E+01, 0.10210900E+01, -.23570700E+01, -.18510100E+01, -.93687900E+00, 0.20325500E+00, -.60268200E-02, 0.84324500E+00, -.24505200E+00, 0.31086900E+01, -.38696000E+00, 0.23642700E+00, 0.95711500E+00, 0.13101400E+01, 0.13682200E+01, -.87748800E-01, 0.22643800E+00, -.73371500E-02, 0.45035900E+01, -.18218900E+01, 0.99910000E+00, -.21754900E+01, 0.11535100E+01, 0.33639600E+00, -.79079800E+01, 0.14890200E+01, 0.28480400E+00, -.21130500E+01, 0.22985800E-01, 0.46726400E+04, 0.51238400E+03, 0.22722200E+04, 0.24617800E+04, -.42034200E+04, -.28476600E+03, -.39640500E+04, 0.62489700E+03, -.31962000E+03, -.10298400E+04, -.31430100E+03, -.45460400E+03, 0.42188000E+03, -.20410400E+04, -.21248500E+04, 0.28769000E+03, 0.57040600E+03, 0.23041600E+03, -.23890000E+04, 0.12153200E+04, -.14291300E+04, 0.11945500E+04, -.16883100E+04, -.78366300E+03, -.30991700E+03, -.33623600E+04, 0.79801800E+03, -.32065900E+03, 0.38123800E+04, 0.81893500E+03, -.49928900E+03, 0.14889900E+04, -.41570000E+03, -.11528200E+04, 0.16348800E+04, -.13405300E+04, -.12521600E+04, -.23828400E+04, 0.17380000E+04, 0.24049700E+03, -.81085600E+04, 0.43629200E+04, 0.28823800E+04, 0.40578000E+04, 0.26639700E+03, 0.31412700E+03, 0.38190900E+04, 0.37872000E+04, 0.30678900E+04, 0.16814100E+03, 0.16136000E+04, -.76330000E+04, 0.39698000E+04, 0.20565000E+04, 0.38203300E+04, 0.44052200E+03, 0.35702800E+03, 0.39925300E+04, 0.40767900E+04, 0.31357200E+04, 0.24074000E+03, 0.17540000E+04, -.53641400E+04, 0.26913600E+04, 0.16484300E+04, 0.26809500E+04, -.60995100E+03, -.87356800E+03, 0.12367000E+04, -.10443300E+04, 0.18081400E+04, -.45427900E+03, 0.27325700E+04, 0.34955100E+04, -.17495200E+04, -.19019100E+04, -.17488600E+04, -.12219800E+04, -.66523900E+02, -.12083800E+04, 0.35343000E+03, 0.20293300E+03, -.87689000E+02, -.14384400E+04, -.10386300E+04, 0.44844000E+03, 0.36663700E+04, 0.50609500E+03, 0.55754400E+03, 0.31113100E+04, -.45932600E+04, -.64282300E+04, -.21754300E+04, 0.37588000E+04, -.28014500E+04, -.15384400E+04, 0.78362300E+03, 0.13435000E+04, 0.77529400E+03, 0.20569200E+03, 0.59237100E+03, -.69652400E+03, -.10211200E+04, -.16861400E+03, 0.57597600E+03, 0.26191500E+04, -.29387200E+04, 0.14995400E+04, 0.31815200E+03, 0.14749700E+04, -.70347900E+02, -.78488200E+03, 0.14378900E+04, 0.96301400E+03, 0.50929200E+03, -.80276800E+03, 0.16106900E+04, 0.17091000E+04, -.85675700E+03, 0.10961400E+04, -.85481600E+03, 0.53635300E+03, 0.12735800E+03, -.21032700E+04, -.34206800E+04, 0.13728000E+04, 0.89804400E+03, -.14134300E+04, 0.89903800E+03, -.47114500E+03, 0.75922200E+03, -.44844200E+03, 0.11867600E+04, 0.32345900E+03, 0.10410400E+04, 0.17650900E+04, -.16633600E+04, 0.13707800E+03, -.62714900E+03, -.13379900E+04, 0.67257300E+03, 0.92691300E+03, 0.66707500E+03, -.13889700E+03, -.13820600E+03, 0.97455900E+03, 0.84580000E+02, -.96503400E+03, 0.54828800E+01, 0.99704900E+03, 0.24978400E+02, -.26233900E+03, -.43825500E+02, 0.55335700E+02, -.89939200E+02, -.16210700E+02, 0.35162600E+02, 0.48803400E+02, -.40514800E+03, 0.34888400E+03, -.19278700E+03, 0.15973900E+03, -.59342000E+03, -.38907800E+03, 0.32075300E+03, -.16118900E+03, 0.14571200E+04, 0.13113400E+03, -.35816100E+02, 0.17083100E+03, 0.31671800E+03, -.42232700E+03, 0.32930400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.84787000E+00, -.16128000E+01, 0.17748400E+00, -.71004500E+00, 0.40028900E+00, 0.10381500E+01, -.53145200E+00, 0.12488500E+01, 0.25545100E+02, -.64100300E+00, -.10367100E+00, 0.86440400E+00, 0.43202400E+00, -.46951600E-01, 0.76776600E+00, 0.97729700E+00, 0.36972100E+01, 0.37468500E+01, 0.26536700E+00, -.25604900E+01, -.14466000E+00, 0.30723900E-01, -.29913500E+00, -.24567200E+00, 0.91577000E+00, -.15210800E-01, 0.55304700E+00, -.80763000E-01, -.36270800E+00, -.10788300E+00, -.75751700E+00, 0.47583800E+00, 0.50170900E-01, 0.92673700E+00, -.54071700E-01, 0.56388800E-01, -.37286200E-03, -.41143100E+00, 0.22238300E+00, -.37798100E+00, -.26396100E+00, 0.18194100E+00, -.67567400E-01, 0.29323400E+00, 0.14275200E+00, 0.90694000E-01, -.12308600E+00, 0.24671600E-01, 0.11327700E+00, -.13351800E+00, -.25580200E+01, -.63079600E+00, 0.32746700E-01, 0.44146900E+00, 0.73542900E-01, 0.20726800E+00, 0.28080400E+00, -.20143300E+00, -.40542200E-01, -.23911000E+01, 0.37847300E+00, -.52888500E-01, 0.25937600E+00, 0.13095400E+00, 0.11754200E+00, 0.60504100E+00, 0.11039000E+00, -.42053100E+00, -.37474000E-01, -.23362900E-02, 0.28236200E+00, 0.37863200E+00, -.12505100E+01, 0.12644600E+01, -.40729500E+00, -.63973900E+00, 0.45350000E+00, 0.14663800E+00, -.17561800E+00, -.18240100E+00, 0.14392300E-02, 0.30130000E-01, 0.18677500E+00, 0.13729200E-01, -.25389000E+00, -.45728000E+00, -.49776300E-01, 0.19467100E+01, 0.66686700E+00, -.61508000E-01, -.22538400E+01, 0.17517300E-01, 0.61657400E-01, -.13857000E+04, 0.18337500E+04, 0.33933800E+04, -.20429500E+04, -.27183800E+03, -.10281000E+03, -.13423100E+03, 0.73448900E+02, -.16638900E+03, 0.65993800E+02, -.20872700E+03, -.22678300E+03, -.22399300E+03, -.29582500E+03, 0.29474200E+03, -.33509400E+03, -.34303500E+03, -.18066800E+04, 0.90686700E+03, -.82053400E+03, 0.90337300E+03, -.68492500E+03, -.77861800E+03, 0.38300200E+03, -.76341700E+03, 0.93037500E+03, -.69851600E+03, 0.13193500E+04, -.26075900E+04, 0.13039800E+04, 0.16239200E+04, 0.13019100E+04, 0.15463200E+03, 0.72483300E+03, -.54192400E+03, -.12335800E+04, 0.66053700E+02, 0.73127600E+03, 0.13593600E+04, -.17072000E+04, 0.87383100E+03, 0.56272500E+03, 0.85321300E+03, 0.16273600E+03, -.37155900E+00, 0.93096700E+03, 0.96180100E+03, 0.76471300E+03, 0.97119600E+02, 0.19285700E+03, -.16690100E+04, 0.85069500E+03, 0.63520200E+03, 0.83421900E+03, 0.21045900E+03, 0.27940000E+02, 0.10446800E+04, 0.13541900E+04, 0.76187400E+03, 0.10950800E+03, 0.14213700E+03, 0.34432200E+03, -.16483400E+03, -.21706200E+03, -.17295300E+03, -.28029500E+03, -.31836900E+03, -.19328700E+02, -.61131500E+03, 0.58956200E+03, -.52927800E+03, -.73647700E+03, -.33915400E+04, 0.16925700E+04, 0.16845600E+04, 0.16950800E+04, 0.38055000E+03, 0.45471500E+03, 0.51793800E+02, -.17484300E+04, 0.88900000E+03, 0.41672200E+03, 0.13668400E+04, -.30654800E+04, 0.15342500E+04, 0.25741200E+04, 0.15263700E+04, 0.70281600E+03, 0.14626600E+04, -.19931000E+04, -.41562100E+04, -.29335900E+02, 0.97194600E+03, 0.99518200E+02, -.79011500E+03, 0.40022300E+03, 0.81295100E+03, 0.39055900E+03, 0.38897500E+03, 0.67264100E+03, -.55801100E+03, -.42889200E+03, -.19917200E+02, 0.26139000E+03, 0.56355400E+03, -.56693800E+03, 0.28195200E+03, -.18148200E+03, 0.28586400E+03, 0.44731600E+02, -.39674000E+03, 0.28466000E+03, 0.27848100E+03, 0.19237000E+03, -.20009700E+03, 0.15095300E+03, 0.17797800E+04, -.87604700E+03, -.47207800E+03, -.88998200E+03, 0.13252300E+03, 0.14193200E+03, -.81129500E+03, -.95761800E+03, 0.56391900E+03, -.39303200E+03, -.16665200E+04, -.14347600E+03, 0.69325900E+02, 0.57284700E+03, 0.72455200E+02, -.52000600E+02, -.30289100E+03, 0.92098700E+03, 0.15166000E+04, -.22343000E+03, -.53900900E+02, -.99417600E+02, -.17296700E+03, 0.86746600E+02, -.46250300E+03, 0.85799400E+02, -.49727600E+02, -.34990300E+03, 0.56633300E+03, 0.51355400E+03, 0.26437500E+03, -.19138600E+03, 0.28219200E+02, 0.56162000E+02, 0.47219500E+02, 0.16077200E+03, 0.39311300E+02, -.56181300E+02, -.42070100E+02, 0.50341400E+02, -.15907300E+03, -.13803200E+03, 0.30842700E+03, -.16312700E+03, 0.20777800E+03, -.24899100E+02, -.89676400E+02, 0.91992400E+02, -.13635100E+01, 0.65465000E+03, -.49761600E+02, 0.45244500E+02, 0.15112600E+02, 0.37344900E+03, -.63484300E+01, -.45133800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10954000E+01, -.22722800E+01, 0.50841300E+00, -.22349500E+01, -.81105400E+00, 0.73405200E+00, -.59442600E+00, -.16685500E+01, -.52880500E+01, -.12814700E+01, 0.80045400E-01, 0.54666800E+00, 0.32549900E+00, 0.10193100E+00, -.14853700E+01, 0.73698300E+00, 0.17922300E+01, -.32237200E+00, -.55852900E+00, -.40008700E+00, -.60301100E+00, -.34866800E+00, 0.13890300E+01, -.24732200E+00, 0.95766800E+00, -.16845600E-01, 0.16419000E+01, 0.24923500E+00, -.52387400E+00, -.13852400E+00, -.40489800E+00, 0.54420500E+00, 0.23294600E+00, -.23434000E+00, -.53925100E+00, 0.60753800E-01, -.27708400E-02, -.12780600E-02, 0.36604300E+00, -.48343400E+00, -.48533500E+00, 0.22977800E+00, -.19249100E-01, 0.25260400E+00, 0.16309800E+00, 0.13611300E+00, 0.50792100E-01, 0.24948000E+00, -.70296900E-01, -.21947000E+00, 0.10448200E+01, 0.63311600E+00, -.15396300E+01, -.57860800E+00, -.10696100E+01, -.12894300E+01, -.61549000E+00, 0.65441400E-01, 0.33771700E+00, 0.18820000E+01, -.26050100E-01, -.13196700E+00, 0.12962400E+01, -.46299200E+00, -.10498500E+01, -.34444900E+00, 0.24680100E+01, 0.90729300E+00, -.86896000E-02, 0.11455700E-02, -.83042900E-02, -.62310300E+00, -.14586200E+01, -.26430200E+01, -.53132000E+00, 0.19138300E+01, 0.56491300E+00, 0.17048700E+00, 0.24125000E+00, 0.50034400E-01, -.25248400E-02, 0.14542500E+01, -.51732300E+00, 0.42003200E+00, -.20630000E+01, -.13360700E+01, 0.16852600E-01, -.22363800E+01, 0.17525100E+01, 0.41713200E+00, 0.23196100E+01, -.12458400E-01, -.26754700E+00, -.71001800E+00, 0.29059900E+04, 0.61124500E+04, -.22620600E+04, 0.17072500E+04, 0.66018600E+02, 0.19984300E+03, -.11244200E+03, -.90731600E+03, -.10034100E+03, -.53983700E+03, -.83069600E+03, -.51769500E+03, 0.18622100E+03, 0.15105200E+04, -.11166000E+04, -.17822800E+04, -.11186400E+04, 0.55855700E+03, 0.74103200E+03, 0.55933500E+03, -.89711000E+03, -.75760300E+03, -.37263100E+03, -.22624600E+04, 0.11069800E+04, -.12399500E+04, 0.80927000E+03, -.46383900E+03, 0.18909100E+03, 0.31792800E+04, 0.23061600E+03, -.52050100E+03, 0.62883100E+03, -.25789700E+04, -.33808600E+04, -.21821800E+04, 0.14719800E+04, 0.15103300E+03, -.38208100E+04, 0.20253900E+04, -.15617200E+04, 0.19107900E+04, 0.28679500E+03, -.32362300E+03, 0.19617400E+04, 0.15282600E+04, 0.15854000E+04, -.17069000E+03, 0.12849300E+04, -.31455600E+04, 0.16573800E+04, -.19768800E+04, 0.15733000E+04, 0.49097900E+03, -.90131200E+02, 0.17244300E+04, 0.17899200E+04, 0.12143200E+04, -.14804600E+02, 0.10919100E+04, -.22895600E+04, 0.11640000E+04, 0.61843700E+03, 0.11445200E+04, -.74983200E+03, -.10763200E+04, 0.26781000E+03, -.19607600E+04, 0.19999300E+04, -.15901300E+04, -.49693400E+03, -.39130000E+04, 0.19433700E+04, 0.19011700E+04, 0.19562600E+04, 0.54635400E+03, 0.49844400E+03, -.23352700E+03, -.33177000E+04, -.68321800E+03, 0.65969100E+03, 0.12922400E+04, -.16234200E+05, 0.80420500E+04, 0.86473300E+04, 0.81143000E+04, -.47264200E+03, -.75575300E+03, 0.27999300E+03, -.61768200E+04, 0.51029900E+04, -.44099100E+03, 0.31264400E+04, -.46120200E+03, 0.23454400E+03, -.49623200E+03, 0.22802500E+03, 0.10101800E+04, 0.11000400E+04, -.53847500E+03, 0.77449200E+03, 0.13223800E+04, 0.50953500E+02, 0.12937700E+03, -.31405500E+04, 0.15812700E+04, -.11767300E+04, 0.15715100E+04, -.75175200E+02, -.12270100E+04, 0.10300600E+04, 0.79153400E+02, 0.79953300E+03, -.75919700E+03, 0.77227900E+03, -.83410100E+04, 0.41595600E+04, 0.39340400E+04, 0.41704600E+04, 0.72669200E+02, -.21117400E+04, 0.20936100E+04, -.13566400E+04, 0.60874000E+04, -.32163900E+04, 0.83563200E+03, 0.15938200E+04, -.81338600E+03, 0.25065600E+03, -.79666500E+03, -.75779000E+03, -.37075800E+03, 0.21551900E+03, 0.42402500E+03, -.21873600E+04, 0.48996700E+03, -.77258900E+03, 0.55463200E+03, -.27418100E+03, -.56847100E+03, -.27775500E+03, -.12641100E+03, 0.13800100E+03, 0.89507900E+02, -.66676300E+03, -.77986700E+03, 0.29165000E+03, -.15451200E+03, 0.14181500E+03, 0.39410700E+03, 0.55829500E+03, 0.15742300E+03, -.59490100E+02, 0.54118200E+02, 0.11191700E+03, -.55681100E+03, -.38620900E+03, 0.62430900E+03, -.31419600E+03, 0.40179500E+03, -.37305500E+03, -.11582500E+03, -.16912400E+02, 0.52174800E+02, 0.47539900E+03, -.30015500E+02, 0.43558800E+03, -.18644500E+02, 0.86253300E+03, 0.13929900E+03, -.34923100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.59689500E+00, -.12766900E+01, 0.60307900E-01, -.12616400E+01, 0.12083000E+00, 0.81952000E+00, -.10676700E+00, -.10639400E+01, -.38920800E+01, 0.99280800E+00, 0.22444700E-01, -.34204400E+00, -.16367800E+00, 0.14952100E+00, -.25584500E+00, 0.87558300E-01, 0.67385400E+00, 0.33046500E+00, 0.84099900E-01, -.50871500E+00, 0.28614600E-01, -.86970200E-01, 0.33027500E+01, 0.13635300E+00, -.84525300E+00, 0.18476000E-01, -.14710900E+01, 0.34823800E-01, -.25815700E+00, -.98276800E-03, 0.41495100E+00, 0.41867800E+00, 0.85812100E-01, -.35394500E+00, -.34690900E+00, -.12092100E+00, 0.38859500E-02, -.24476100E+00, -.89671200E-01, 0.15428500E+00, 0.34918700E+00, 0.71174500E-01, 0.11039300E+00, 0.92688200E-01, -.18546900E+00, -.81886700E-01, 0.57570700E-01, -.61611600E-01, -.15143100E+00, 0.24142700E+00, 0.23497300E+01, 0.65437400E+00, -.47347200E+00, -.25686400E+00, 0.59000500E-01, -.15268900E+01, -.96565600E-01, 0.83429300E-01, -.16274700E+00, -.39743100E+00, 0.95536200E-01, -.16331600E+00, 0.34445700E+00, -.39017400E+00, -.64640400E+00, 0.62443400E+00, -.53308900E+01, -.79121000E-01, 0.23002700E+00, 0.90592000E-03, 0.21014200E+00, -.10470000E+01, -.42007800E-01, 0.14212100E+01, -.12478900E+00, -.40265700E+00, -.46659500E+00, -.14029500E+00, 0.17847100E+00, 0.68975500E-01, 0.59432400E-03, 0.15423100E+01, 0.16188800E+00, 0.15155300E+00, -.10325100E+01, 0.22743800E+00, 0.37474900E-01, -.34401800E+01, 0.28672900E+00, 0.95245300E-01, -.75877600E-01, 0.47853500E-01, 0.15815100E+00, -.37344900E+00, -.26876900E+00, 0.14756700E+04, -.16644700E+04, 0.63644700E+03, -.18703500E+03, 0.19354000E+03, -.98765800E+02, -.16242900E+03, -.10021500E+03, -.14428500E+03, -.49628500E+03, 0.10914900E+03, 0.36629300E+03, 0.45586700E+03, -.53398500E+03, -.90163300E+03, 0.11372600E+04, -.56437600E+03, -.10219800E+04, -.56853300E+03, -.49904400E+03, 0.26354200E+02, -.35976500E+03, -.33528300E+03, 0.99384500E+02, -.17266200E+03, 0.25100600E+03, -.12268400E+04, 0.58668900E+03, 0.13996000E+04, 0.60904500E+03, -.28803600E+03, 0.32730300E+03, -.55272000E+03, -.10479700E+04, -.90193000E+03, 0.57726400E+03, 0.75266100E+03, -.56428400E+03, 0.43707100E+03, -.69081700E+03, 0.27968700E+03, -.13759600E+03, -.65878100E+02, 0.97545500E+03, 0.13879900E+04, 0.50952000E+03, -.99087700E+02, -.24968700E+02, -.11306300E+04, 0.63697900E+03, -.78231600E+03, 0.56294100E+03, 0.75340500E+02, 0.20329000E+03, 0.89066300E+03, 0.13982600E+04, 0.65291100E+03, 0.12676500E+03, 0.52186900E+03, -.41642200E+03, 0.20243200E+03, 0.13526900E+03, 0.20570800E+03, -.12070800E+03, -.71701100E+03, 0.32599200E+03, -.15557600E+03, 0.91339200E+03, -.91561400E+03, -.49040500E+03, -.25021600E+04, 0.12460100E+04, 0.10989300E+04, 0.12489400E+04, 0.16460900E+03, 0.16579100E+03, 0.34522000E+03, -.13487600E+04, 0.44372300E+03, 0.19729300E+03, 0.76769500E+03, -.75450600E+04, 0.37617400E+04, 0.36648700E+04, 0.37540000E+04, 0.21056900E+03, -.17057400E+03, -.21022500E+02, -.33253000E+04, 0.15038600E+04, 0.70633000E+02, 0.10887600E+04, -.10350100E+04, 0.52773700E+03, 0.36235600E+03, 0.51432100E+03, 0.55610900E+03, 0.47289200E+03, -.61953900E+02, 0.20913000E+03, 0.40333400E+03, 0.70350000E+02, 0.38153100E+03, -.79468800E+03, 0.40791600E+03, -.23886500E+03, 0.40388300E+03, -.25344000E+03, -.99415700E+03, 0.73769700E+03, 0.69492300E+03, 0.39286100E+03, -.85436600E+03, -.23963100E+03, -.19425600E+04, 0.97481100E+03, 0.64800000E+03, 0.97102500E+03, 0.37196500E+03, -.75366900E+03, 0.60929400E+03, -.18962200E+03, 0.23841400E+04, -.96725200E+03, -.39951300E+03, 0.43806000E+02, -.29426700E+02, 0.25882900E+03, -.19643300E+02, -.38110000E+03, -.38224900E+03, 0.25272100E+03, 0.42342800E+03, -.76024600E+03, -.12516500E+03, 0.14681700E+03, 0.16540100E+04, -.82562400E+03, -.85162200E+03, -.82866600E+03, -.26142100E+03, -.22054500E+02, -.24258800E+03, 0.92668600E+02, -.78072000E+03, 0.44379700E+01, -.29218100E+03, 0.51116100E+02, 0.19206400E+03, 0.20808900E+03, 0.79477100E+02, 0.56006600E+02, 0.10710300E+03, 0.43552500E+02, -.20545200E+03, -.16526400E+03, 0.46369300E+02, -.18157700E+03, 0.26500700E+03, -.30697700E+03, -.44812100E+02, -.21960900E+02, -.34625600E+02, -.63784500E+02, 0.20695600E+02, 0.13293800E+03, 0.11108500E+02, 0.27379200E+03, 0.83937200E+02, -.17938100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.80693700E+00, -.17518100E+01, -.61088400E-02, -.10227700E+01, -.84609200E-01, 0.89329500E+00, -.79699900E+00, 0.20467300E+00, 0.37251400E+01, -.15673600E+00, 0.20019700E-02, 0.29209700E+00, 0.32716000E+00, 0.50083600E-01, -.52027500E+00, 0.22062900E-01, 0.22910900E+01, 0.13771900E+01, -.82964300E-01, -.80396700E+00, -.64098500E-01, 0.20353400E-01, 0.21732600E+01, 0.49010400E+00, 0.29595600E+00, 0.39914100E-02, 0.63263200E+00, 0.17452600E+00, -.56863500E+00, -.21760600E+00, -.88879000E+00, 0.56550900E+00, 0.25355800E-01, 0.14480200E+00, -.47802000E+00, 0.29659700E-01, 0.53381200E-02, -.29643600E-01, 0.45535700E+00, -.82460000E+00, -.33769100E-02, 0.28214500E+00, 0.44012700E+00, 0.27468900E+00, 0.59875900E-01, 0.66571200E-01, -.63919800E+00, 0.11376100E+00, 0.10979200E+01, -.34597500E+00, 0.20142500E+01, -.75808700E-01, 0.38613700E+00, 0.52261500E+00, -.33801900E+00, -.11084800E+01, -.12574700E+01, -.10346700E+00, 0.67133500E+00, -.20427200E+01, 0.12045300E+01, 0.12293800E+00, -.30532200E+00, 0.30069700E+00, 0.17139400E+01, -.30555000E+00, -.46100500E+01, -.47705300E+00, 0.14879800E+00, 0.36333200E-03, -.43615300E-01, 0.26443300E+00, -.14617300E+01, 0.19309900E+01, -.93121700E-01, -.89611100E+00, 0.40684000E+00, -.80793700E+00, -.47864500E-01, 0.12818500E-01, 0.97579600E-03, -.59394600E+00, 0.20267000E+00, 0.27586000E+00, 0.14382400E+01, 0.28496900E+00, 0.16366900E-01, -.16928500E+00, 0.10470300E+00, -.26217600E+00, -.19439600E+01, 0.32814000E-03, 0.23079500E+00, 0.36151800E+00, -.28942000E+00, -.30947600E+00, -.12272100E+04, 0.46318600E+03, 0.92202000E+03, 0.77693500E+02, -.35493600E+02, -.38271200E+03, -.39235300E+02, -.10394000E+03, -.37675100E+03, 0.21567100E+03, 0.38419300E+03, 0.15639600E+03, -.45829800E+03, -.63868600E+03, -.33652000E+03, 0.16979700E+03, -.65185600E+03, 0.16827200E+03, 0.56652400E+02, -.12025100E+03, 0.11364400E+02, -.45696700E+03, 0.25651100E+03, -.19737900E+03, -.52311200E+03, 0.94816600E+02, -.45090900E+02, 0.40498400E+03, -.47161700E+02, 0.40442900E+03, 0.19703300E+03, -.70842100E+02, 0.36358000E+02, -.77874900E+03, 0.23276300E+03, 0.25131100E+03, 0.14472400E+04, -.72588800E+03, -.67862500E+03, -.72491700E+03, -.20576800E+03, -.22483400E+03, -.42077200E+03, -.39084000E+03, -.45240100E+03, -.10952900E+03, 0.58742000E+01, 0.10129300E+04, -.50333600E+03, -.61904900E+03, -.50777900E+03, -.13391600E+03, -.15993700E+03, -.35559400E+03, -.27258200E+03, -.18097800E+03, -.68871000E+02, 0.14916600E+03, 0.36964000E+03, -.17689200E+03, -.69417200E+03, -.18514700E+03, -.50208800E+02, -.28510300E+03, 0.34802800E+03, 0.74844000E+03, 0.40223900E+03, -.48692100E+03, -.82775000E+03, -.10581200E+04, 0.52648400E+03, 0.68937900E+03, 0.52881300E+03, 0.12303600E+03, 0.12104000E+03, 0.20821500E+02, -.51423500E+03, 0.30595000E+03, 0.13451300E+03, 0.46338500E+03, -.33430500E+01, -.41419800E+00, 0.14019400E+04, 0.23267600E+00, 0.67816900E+03, 0.65773700E+03, -.40504300E+03, -.86993900E+03, -.11067600E+04, 0.37248700E+03, -.42206400E+03, -.77414300E+03, 0.38758900E+03, 0.77978500E+03, 0.38675600E+03, 0.96035300E+02, 0.93376500E+02, -.13781600E+03, -.58774800E+03, -.16381200E+03, -.52855500E+02, -.67113900E+02, 0.73106200E+03, -.36625300E+03, -.41824500E+03, -.36518800E+03, -.14467600E+03, -.43649500E+03, 0.19804000E+03, 0.61162200E+03, -.29485700E+02, -.37029800E+03, -.56747700E+03, 0.84363700E+03, -.41731100E+03, 0.54979500E+03, -.42181900E+03, 0.24246300E+03, 0.33404900E+03, -.40368700E+03, -.63993000E+03, 0.19012400E+03, -.65597300E+02, -.17729300E+04, -.10673600E+03, 0.50965000E+02, -.40063500E+02, 0.53648000E+02, 0.13159600E+03, -.12926100E+03, 0.32467400E+03, 0.60942300E+03, -.39205100E+03, -.34358200E+02, 0.24661200E+03, -.69603600E+03, 0.34793700E+03, -.18336200E+03, 0.34801500E+03, 0.22490100E+03, 0.21710200E+02, 0.28001800E+03, 0.10516400E+03, 0.29407600E+02, 0.17262700E+02, 0.23962100E+03, 0.67530200E+02, 0.16250800E+03, 0.18700400E+03, 0.28852200E+02, 0.50384900E+02, 0.70169800E+02, 0.52774000E+02, -.18528000E+03, -.55151700E+02, 0.82117300E+01, -.99530800E+02, 0.12637700E+03, -.40606200E+02, 0.83836000E+02, -.95811400E+02, -.43150300E+02, -.65389700E+02, 0.10137300E+02, -.20815000E+02, -.12999900E+02, 0.11696000E+03, 0.82731800E+02, -.14175900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17039500E+01, -.21524200E+00, -.12552100E+00, -.45765100E-01, -.17534000E-01, -.11335200E+00, 0.99413300E-02, -.35854900E+00, -.19782200E+01, -.39949300E+00, 0.30532200E-01, 0.86036200E+00, 0.38439000E-01, -.17711400E+00, 0.60247700E-01, 0.15784200E+01, 0.39722000E+01, -.16688500E+01, -.39300300E-01, -.25500200E+00, -.79663800E-01, -.11659300E+01, -.90725000E+00, -.10583900E+01, -.42245200E+00, -.31293500E-01, -.16371600E+00, -.99158600E-01, 0.42786200E+00, 0.55818900E+00, 0.12119100E+01, 0.58107300E-01, 0.44224200E-01, 0.10324000E+00, 0.10862000E+00, 0.53750200E-01, -.26157200E-03, -.15702400E+00, -.14147700E+00, -.18729100E+00, -.44497300E+00, 0.73017900E-01, 0.39663900E+00, 0.33490500E+00, -.15819900E-01, -.25795800E-01, -.48025000E-01, -.12255400E-01, 0.12521500E+00, 0.31853500E-01, -.17773000E+00, 0.64988600E-03, -.56947100E-01, 0.37235300E+00, 0.14053200E+00, -.13333200E+00, -.91339000E+00, -.66867300E-01, 0.29523400E-01, -.76048000E+00, 0.85328100E-01, 0.14867500E-01, -.17202300E+00, 0.23570800E+00, 0.65923800E+00, 0.25863900E+00, -.18029100E+01, -.23612500E+00, -.47039900E-01, -.64167100E-03, 0.86782900E-01, 0.94744000E+00, -.20980300E+01, 0.10121900E+01, -.83014300E+00, -.67910000E+00, -.21382500E+00, 0.17035800E+00, -.17008700E+00, 0.15641200E-01, 0.55016300E-04, -.27103900E+00, -.17232800E+00, -.40426000E-01, -.81063300E+00, 0.57602400E+00, -.39624100E-02, 0.20345200E+00, -.64743700E-01, 0.17983900E-01, -.18036000E+01, 0.75763100E-02, -.13470900E-01, 0.40289100E+00, 0.26467900E-01, -.40543900E+00, 0.34327700E+00, -.90273900E+03, -.67329000E+03, -.58671600E+02, 0.27084800E+02, 0.13414700E+03, 0.28007900E+02, 0.20761600E+03, 0.36302300E+03, -.22368000E+03, -.26389800E+03, -.16694300E+03, 0.50826100E+03, 0.21447400E+03, 0.31548000E+04, -.15707100E+04, -.97196100E+03, -.15773700E+04, -.45100700E+02, 0.88029300E+03, -.91484700E+03, -.92353600E+02, -.11977700E+04, 0.10016400E+04, -.97929500E+03, -.19358100E+03, 0.67377600E+02, 0.82867700E+02, 0.95007900E+02, -.11145400E+02, 0.26611800E+03, -.11154900E+03, -.12313400E+03, -.25262700E+03, 0.28682200E+03, 0.91536600E+02, 0.11380900E+04, -.44076200E+03, -.83748200E+03, -.56970400E+03, -.29572400E+03, 0.10355800E+03, -.18336800E+03, 0.10791200E+03, -.44115200E+03, -.63009300E+02, -.78084200E+02, 0.80700900E+03, -.34664800E+03, -.10672200E+04, -.40416500E+03, -.18103500E+03, 0.24065200E+03, -.25782500E+03, -.12519600E+03, -.31956600E+03, 0.90774600E+02, 0.43063600E+03, -.14932000E+03, 0.66468900E+02, 0.86350200E+02, 0.73704500E+02, 0.15944900E+03, 0.41527900E+01, -.68662100E+02, -.30822400E+02, -.18187500E+03, 0.26383600E+03, 0.65283700E+03, 0.17774200E+04, -.88461200E+03, -.11509100E+04, -.88953900E+03, -.17051500E+03, -.17093000E+03, -.95261800E+02, 0.95679000E+03, 0.26193300E+03, -.21912300E+03, -.10721800E+04, -.75418200E+03, 0.36874700E+03, -.41843500E+03, 0.36980900E+03, -.31179000E+03, -.28654800E+03, 0.12151000E+03, -.24767100E+03, -.38994200E+02, 0.29546500E+03, -.26318400E+03, -.65122800E+03, 0.33232300E+03, -.44645300E+02, 0.32802600E+03, 0.14686600E+03, -.16265500E+03, 0.35099400E+03, -.98059300E+02, -.77597900E+02, 0.57538000E+02, 0.51580200E+02, -.21593900E+03, 0.11960200E+03, 0.88409700E+02, 0.11053000E+03, -.24833700E+03, -.48728100E+03, 0.45464100E+03, 0.66667200E+03, 0.30841100E+03, -.63240100E+03, -.19425900E+03, -.49123200E+02, 0.24765900E+02, -.58255500E+03, 0.24454200E+02, -.13163000E+03, -.43279800E+03, 0.11771000E+03, -.30460400E+03, 0.17067600E+03, 0.39404300E+03, 0.22051100E+03, 0.60348000E+03, -.30624400E+03, -.43424500E+02, -.30087100E+03, -.15204800E+02, -.29287900E+03, 0.85843500E+02, 0.53227100E+03, -.30607900E+03, -.48114400E+03, 0.88264400E+01, 0.18121700E+04, -.90529700E+03, -.78612100E+02, -.90673400E+03, -.37310100E+03, 0.80882200E+02, -.40670800E+03, 0.23466200E+03, -.91106900E+03, 0.30388300E+02, -.73213600E+02, -.38658100E+02, -.18102800E+03, -.26953700E+03, 0.22595600E+01, 0.58456600E+02, 0.83973600E+02, -.29504800E+02, 0.27192700E+03, 0.23697300E+02, -.65935200E+02, 0.60841400E+02, -.55326400E+02, -.95020600E+02, -.26858700E+01, -.55999700E+02, -.41572700E+02, 0.14478400E+03, 0.42980900E+02, -.84639500E+01, 0.51112000E+02, -.19867000E+03, -.26053000E+03, 0.17803500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.32328800E+00, 0.10089500E+01, 0.19896600E+00, 0.54406900E+00, -.35676600E+00, -.11538400E+01, -.23157800E-01, 0.77441300E+00, 0.60490900E+01, -.75823900E+00, -.23934300E-02, 0.46932000E+00, 0.11711000E+00, -.43537700E-02, -.88993500E-01, 0.51559800E+00, 0.94384400E+00, 0.15636900E-01, -.11219500E-01, -.23966900E+00, 0.49648400E+00, -.21554400E+00, -.20245500E-01, -.35361600E+00, 0.24364600E+00, -.11257000E-01, 0.84918800E+00, -.91920600E-02, 0.42633500E-01, -.47268300E-01, 0.11851200E+00, 0.51553700E-01, -.25598900E-01, 0.26077500E-01, 0.26279200E-01, -.31669400E-02, 0.10060100E-03, 0.77214200E-04, -.19171300E-01, -.35809400E-01, -.76122200E-01, -.23025700E-01, -.20737500E+00, -.89182800E-01, -.21812000E-01, -.64015700E-02, -.91766700E-01, 0.21447600E-02, 0.11535100E+00, -.23195900E-01, 0.26603900E+00, -.28620900E-01, 0.24413400E+00, -.48347000E+00, 0.10181200E+00, 0.69812800E+00, -.10648900E+00, 0.40752700E-01, 0.21783900E+00, 0.67244300E+00, 0.10625000E+00, -.16191600E-01, -.48655800E-01, -.12776600E+00, -.24684200E-01, -.10040600E+00, -.11531800E+01, 0.42283100E-02, 0.78359100E-01, 0.47043600E-03, 0.27926800E-01, -.15038100E-01, 0.14963200E+00, -.12275400E+00, 0.19309300E+00, -.11825400E+00, -.11256200E+00, 0.37596400E-01, 0.13543300E-01, 0.59991700E-01, -.13759900E-04, 0.13140300E+00, 0.45621700E-01, -.12356900E+00, -.63845400E+00, 0.55857300E-01, -.87611900E-02, -.15846100E+01, 0.33263300E+00, 0.11269400E-01, -.33496400E+00, -.11220900E-02, 0.11397900E-01, 0.46817900E-01, 0.22645500E-01, 0.90935700E-01, -.22502300E+00, 0.25895600E+00, 0.81214300E+03, 0.83523400E+01, -.31539800E+01, -.24400500E+03, -.34505700E+01, -.40407000E+01, -.80195500E+02, 0.98536700E+01, -.46455300E+02, -.26716800E+02, -.64516300E+02, -.21862900E+03, 0.24333300E+03, -.12309700E+03, -.66588300E+03, -.12168600E+03, 0.80148900E+02, 0.13410100E+03, -.19681200E+03, -.31221300E+03, -.15753600E+03, 0.88722000E+02, -.44186000E+03, 0.99698300E+03, -.49322000E+03, -.14771100E+03, -.49733100E+03, 0.12102900E+03, 0.17136300E+02, 0.11597900E+03, 0.25287100E+03, -.40038300E+03, -.50879800E+02, -.46152900E+03, 0.20197500E+03, -.12717200E+03, 0.32348000E+03, -.10080700E+03, 0.29869700E+01, 0.40748200E+01, -.11799000E+03, -.11352000E+03, -.45130800E+02, 0.35622700E+02, 0.25228300E+02, 0.12831400E+03, -.74248700E+02, 0.35664800E+03, -.64000100E+02, -.17914200E+02, -.61200600E+02, -.74127400E+02, -.10011900E+03, 0.37520600E+02, -.17727000E+02, -.17942900E+02, 0.17433900E+03, -.84697000E+02, -.47231000E+03, -.86657100E+02, 0.29714100E+02, -.44409600E+00, 0.68801100E+02, 0.30644900E+03, -.45039900E+00, -.84747500E+02, -.41712200E+03, -.62069700E+02, 0.30275300E+02, 0.68668200E+02, 0.31484100E+02, -.46477300E+02, -.47854600E+02, -.18258800E+02, -.61900100E+02, 0.41200000E+02, -.14878300E+02, 0.30738700E+02, 0.25947500E+04, -.12963700E+04, -.72330400E+02, -.12932600E+04, 0.61977900E+03, 0.62446100E+03, -.29352600E+03, 0.33855500E+03, -.12881200E+04, 0.55065600E+03, -.14730000E+04, -.32925700E+03, 0.16335200E+03, 0.59384200E+03, 0.16513800E+03, -.13344200E+03, -.16171300E+03, 0.71705800E+02, -.14706400E+03, -.57021100E+02, -.14076900E+03, 0.10002500E+03, 0.56007800E+03, -.28208400E+03, -.49841300E+02, -.28154300E+03, -.14042200E+02, 0.10915100E+02, -.96816900E+01, 0.26233600E+03, -.59560300E+02, -.52530600E+02, -.21897600E+03, 0.16698900E+04, -.83356200E+03, 0.25446100E+03, -.83488100E+03, 0.46696300E+03, 0.78709800E+03, -.64796700E+03, -.19616900E+03, -.82276400E+03, 0.70070200E+03, -.14669800E+04, -.11749600E+03, 0.59651100E+02, 0.41681300E+02, 0.58280200E+02, 0.13841000E+03, -.37235300E+02, 0.17459200E+03, 0.14105900E+03, -.92115300E+02, -.73367000E+02, 0.11049300E+03, -.44812100E+03, 0.22391900E+03, 0.65631500E+02, 0.22447000E+03, 0.15970800E+03, 0.53182000E+02, 0.11672000E+03, -.43873100E+02, -.36082700E+02, 0.10179200E+02, 0.25120300E+02, 0.35721700E+02, 0.16840400E+02, 0.49704700E+02, 0.24112600E+01, 0.20837300E+02, 0.16510100E+02, 0.28861700E+02, -.49076500E+02, -.20063200E+02, -.28655300E+02, -.28984300E+02, 0.77813600E+02, 0.18000300E+02, 0.38237300E+02, -.25454600E+02, -.18970700E+02, -.15543900E+03, 0.21460100E+02, -.53013900E+02, -.13992400E+02, -.44083700E+02, 0.70143400E+01, -.39031200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20321800E+00, 0.21667100E+00, 0.58660500E-01, 0.78910700E-01, 0.10591600E+00, 0.24335900E+00, 0.78822800E-01, 0.23320400E+00, -.45287200E+01, 0.32475100E+00, -.22086000E-01, -.42026800E+00, -.18686300E+00, 0.15345800E-01, 0.17185800E+00, -.38377200E+00, -.76458400E+00, 0.26668300E+00, 0.13996000E+00, 0.31134500E+00, -.25375000E+00, 0.19805500E+00, -.74546400E+00, -.82007800E-01, -.52781000E-01, -.32021000E-03, -.25763300E-01, 0.44542300E-01, -.14656300E+00, -.10933600E+00, -.97610700E-01, 0.28624700E-02, -.13425700E-02, -.38403400E-01, -.12250100E+00, -.23912500E-01, 0.32048800E-02, 0.60558300E-01, 0.91065900E-01, 0.22927900E-02, -.18368800E+00, 0.42780200E-01, 0.43054900E+00, 0.19191800E+00, 0.85884700E-02, 0.28243900E-01, 0.13800800E+00, 0.11356300E-01, 0.61030600E-01, -.36451100E-02, -.25227900E+00, 0.34411200E-01, 0.65076400E-01, 0.90814600E-01, 0.56995600E-02, 0.75428600E-01, -.17926600E+00, 0.25463800E-01, 0.78910600E-01, 0.39122200E+00, 0.26241100E+00, -.11789000E-01, 0.31395500E-01, -.10532100E+00, -.11944400E+00, 0.11506000E+00, 0.12955300E+00, 0.97358400E-01, 0.15260600E-01, 0.90982600E-04, 0.54463300E-01, -.10770600E+00, 0.46119900E+00, -.33133200E+00, 0.28820500E+00, 0.18704800E+00, 0.12145400E+00, 0.58147400E-01, 0.16316700E-01, -.15597800E-01, 0.41453300E-03, 0.91647300E-01, 0.40519200E-01, 0.77765400E-01, 0.21245500E+00, 0.10490700E+00, 0.41534000E-01, -.24606500E+00, -.18153000E+00, 0.37783000E-01, 0.39726500E+00, 0.10027900E-01, -.46377000E-01, 0.20075300E+00, 0.54597400E-01, -.81042000E-02, -.25782800E+00, -.75630900E-01, -.19786500E+00, 0.20673500E+03, -.99597200E+02, -.27301600E+03, -.10394300E+03, 0.79344300E+01, -.77483600E+02, -.37611800E+01, 0.47317700E+02, -.95448100E+02, -.89881800E+02, -.80188500E+02, -.41354900E+03, 0.20606400E+03, -.91425600E+02, 0.20679100E+03, 0.29020700E+03, -.49322600E+02, 0.95749800E+02, -.27644700E+03, 0.93946600E+02, -.69809700E+02, -.60231500E+02, 0.65682200E+03, -.31953500E+03, -.22594200E+02, -.32877000E+03, 0.19361700E+03, 0.10823800E+03, -.53758200E+02, 0.19482900E+03, -.27989100E+03, 0.33699700E+02, -.19349200E+03, 0.44836900E+03, -.23984500E+03, -.13854000E+03, -.22501600E+03, -.14921900E+03, -.15764800E+03, -.16959000E+03, -.17815300E+03, -.11208600E+03, -.12284100E+03, 0.47701000E+02, 0.19174600E+03, -.10884700E+03, -.17471900E+03, -.96727700E+02, -.11709100E+03, -.11295500E+03, -.17764300E+03, -.28933100E+03, 0.28589400E+01, -.90532400E+02, 0.13487400E+03, -.20272900E+03, 0.10077900E+03, -.20466400E+03, 0.10092500E+03, 0.95090900E+02, -.30142600E+02, 0.14708500E+03, 0.24132100E+03, 0.34815900E+02, -.59990900E+02, 0.72635900E+02, -.14425400E+02, 0.57058300E+01, 0.33319500E+02, 0.68490400E+01, 0.93152500E+02, 0.48736700E+02, -.18653500E+02, 0.13367900E+03, 0.11826000E+03, 0.52755800E+02, -.57688700E+02, 0.18366100E+04, -.90492400E+03, 0.16847700E+03, -.92110600E+03, 0.15316400E+03, 0.23731200E+03, -.18480000E+03, 0.48012700E+03, -.87131500E+03, 0.17288400E+03, -.69448500E+03, -.11447300E+03, 0.57535800E+02, 0.29808900E+03, 0.57080200E+02, -.95972800E+02, -.14074400E+03, 0.85554200E+01, -.18580700E+03, -.66430800E+02, -.89852400E+02, 0.28566000E+02, 0.40603800E+03, -.20544100E+03, -.32951100E+02, -.20213100E+03, -.28420900E+02, -.20556500E+02, 0.94757700E+01, 0.26688400E+03, -.53512900E+02, -.60637600E+02, -.19030300E+03, 0.82786600E+03, -.40914700E+03, 0.49780500E+03, -.41396500E+03, 0.48989700E+02, 0.25682700E+03, -.21184500E+03, -.20560700E+03, -.46741200E+03, 0.24110200E+03, -.54360700E+03, -.30237200E+03, 0.15281500E+03, 0.63128900E+02, 0.15157700E+03, 0.24237000E+03, 0.11352600E+03, 0.13656900E+03, 0.36561100E+03, 0.11624700E+03, 0.54365500E+02, -.49049100E+02, -.76739700E+03, 0.38321800E+03, 0.30654800E+03, 0.38352400E+03, 0.19802400E+03, 0.52777000E+02, 0.12016600E+03, -.73840900E+02, 0.16168800E+03, 0.38531700E+02, 0.12681500E+03, 0.20798800E+02, 0.38255300E+02, 0.51130500E+02, 0.14245300E+00, 0.39591500E+02, 0.47101900E+02, 0.18131400E+02, -.51355800E+02, -.46579100E+01, -.12446000E+02, -.16142100E+02, -.28676500E+00, 0.25007300E+02, 0.42003400E+02, -.47257500E+02, 0.65146800E+01, 0.18458300E+02, 0.41525900E+02, -.38722300E+02, -.25718200E+01, -.84602400E+02, 0.34208800E+02, -.34803300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36382800E+00, 0.81148900E+00, -.12802600E+00, 0.33163100E+00, -.43846700E+00, -.62475600E+00, 0.77388500E-02, -.27144300E+00, -.88173000E+01, -.61024900E+00, 0.60881900E-01, -.74357100E-01, -.63664000E-01, 0.14284800E-01, -.61045700E+00, 0.27143700E+00, -.17557700E+01, -.15453100E+01, -.15613200E+00, 0.10077200E+01, -.91037900E-02, -.31432700E-01, -.83127300E+00, -.84839600E-02, 0.21062800E+00, -.60684400E-02, 0.24216100E+00, 0.37111200E-02, -.51931400E-01, 0.49819600E-02, -.20226700E+00, -.30066800E-01, 0.64010500E-01, -.61183000E-01, -.11287400E+00, 0.17904000E-01, -.55319100E-03, -.39667000E+00, 0.21127100E+00, -.12014100E+00, 0.17088100E-01, 0.94190400E-01, -.11639100E+00, 0.23565800E+00, 0.89470800E-01, 0.11767600E-01, -.49052000E-01, 0.13031300E-01, 0.16281900E+00, -.39983100E-01, -.43547300E+00, -.17497800E+00, -.82745200E-02, 0.38502100E+00, -.96180900E-01, -.13675200E+01, -.31681600E+00, -.10340900E-01, -.22566700E-01, -.75563500E+00, 0.11644800E+00, 0.19339200E-02, 0.24200500E+00, 0.35833800E-01, 0.58481300E-01, 0.23522100E+00, -.62359900E+00, -.11174400E+00, -.37021700E-01, 0.11256000E-03, -.52454200E-01, -.47152800E+00, -.73756700E+00, 0.25946100E+00, -.18593100E-01, -.40943100E+00, 0.38693100E+00, -.35308000E-01, -.10186400E+00, -.57979200E-01, 0.23242700E-03, 0.26498800E+00, 0.15011500E+00, 0.68164100E-01, 0.56716700E+00, -.22674400E+00, -.16577500E-01, 0.35446100E+00, 0.90153800E-01, 0.18145400E-01, 0.55310700E+00, -.18466900E-02, 0.47084500E-01, -.41441900E-01, -.11015800E+00, 0.19562700E+00, 0.33316200E+00, -.50051300E-02, 0.28718900E-01, 0.71772100E+00, -.42207400E+01, 0.29763300E+03, 0.12920600E+01, -.58708400E+02, 0.97789300E+02, -.39464500E+02, 0.17278500E+02, 0.22114100E+03, 0.12521500E+03, 0.48662600E+02, -.15235500E+03, 0.74919200E+02, 0.94222100E+03, 0.76141000E+02, -.31651900E+03, -.12264300E+03, 0.11693900E+03, 0.44422200E+03, 0.11794300E+03, -.98292000E+02, 0.54497300E+03, -.81142000E+03, 0.39087000E+03, -.11742100E+02, 0.40672400E+03, -.32664600E+03, -.14518200E+03, -.28097200E+02, -.35164100E+03, 0.51768800E+03, -.34906400E+02, 0.37014100E+02, -.97764100E+03, 0.48859500E+03, 0.36484300E+03, 0.49048700E+03, 0.32881900E+03, 0.24520800E+03, 0.27718500E+03, 0.25384100E+03, 0.32903900E+03, 0.18840400E+03, 0.22395300E+02, -.33228500E+03, 0.17803400E+03, 0.43654400E+03, 0.16783300E+03, 0.21048300E+03, 0.22040200E+02, 0.34262800E+03, 0.46066300E+03, 0.86128900E+02, -.77066400E+01, -.40838600E+03, 0.13517200E+03, -.65095000E+02, 0.41688300E+03, -.66612100E+02, -.19394400E+03, 0.38574100E+02, -.20121500E+03, -.47776800E+03, -.87833700E+02, 0.85586500E+02, 0.11758400E+03, -.21163200E+03, 0.10680700E+03, 0.11390700E+03, 0.10662700E+03, -.60778800E+01, -.25564400E+02, 0.88370400E+02, -.14043800E+03, -.10910900E+03, -.10293700E+02, -.35653000E+00, -.23879900E+04, 0.11736200E+04, -.34692100E+03, 0.12004400E+04, -.42492500E+03, -.56604800E+03, 0.23780200E+03, -.38186600E+03, 0.15971000E+04, -.42714600E+03, 0.10986200E+04, 0.47855300E+03, -.24046600E+03, -.66232200E+03, -.23869900E+03, 0.10251700E+03, 0.22553600E+03, -.15774100E+03, 0.34110800E+03, 0.16963300E+03, 0.18392500E+03, 0.84451900E+02, -.64086600E+03, 0.32189900E+03, 0.55904200E+02, 0.31832400E+03, 0.91827700E+02, 0.28591300E+03, -.19656300E+03, -.65445900E+03, -.24953100E+02, 0.32807400E+03, 0.44832000E+03, -.12476700E+04, 0.61797900E+03, -.58273300E+03, 0.62391300E+03, -.28890700E+03, -.61850500E+03, 0.44629000E+03, 0.44172300E+03, 0.72101800E+03, -.60436600E+03, 0.12755300E+04, 0.11665800E+03, -.58637100E+02, -.55251400E+02, -.59199200E+02, -.22101500E+03, 0.71397400E+02, -.30217700E+03, -.75611400E+03, -.13353200E+03, 0.13356600E+03, 0.85229100E+01, 0.26947900E+03, -.13449300E+03, -.34922400E+02, -.13428600E+03, -.13405500E+03, 0.23338000E+02, -.13526300E+03, -.18082100E+03, -.84254700E+02, 0.38685000E+02, -.54629400E+01, -.40006500E+02, -.47623000E+02, -.27808300E+02, 0.59334400E+00, -.57294800E+02, -.76518700E+02, -.34845100E+02, 0.26849200E+02, -.24640500E+01, 0.23891300E+02, 0.26245300E+02, -.21629500E+02, 0.18942200E+01, -.40661600E+02, 0.65978200E+02, -.41980800E+01, -.29360000E+02, -.56896300E+02, 0.61689200E+02, -.10689900E+02, 0.79469200E+02, -.21056700E+02, 0.47644400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18760900E+01, -.21131200E+00, -.16661000E+00, -.54430000E+00, -.36836200E+00, 0.11000300E+00, 0.20330200E+00, 0.13218500E+01, 0.18613600E+02, -.77522500E+00, -.52654100E-01, 0.11898900E+01, 0.28203400E+00, -.50004800E+00, 0.43578700E+00, -.57577600E+00, -.60805300E+00, 0.28198800E-01, 0.40286200E-01, 0.31974300E+00, -.61395000E+00, 0.12314900E+00, -.24444900E+01, -.58873500E+00, 0.87793300E+00, -.25133300E-01, 0.99351500E+00, 0.25143100E-01, -.79515000E-01, 0.46179400E+00, -.17755200E+00, 0.24754800E+00, -.74440000E-01, 0.41618900E+00, 0.50946300E+00, 0.17858200E+00, -.71174100E-02, -.40348900E+00, -.80455600E+00, -.54422100E+00, -.12247700E+01, 0.25190800E+00, 0.59773800E+00, 0.98528000E+00, -.23666000E+00, -.19855400E-01, -.85663900E+00, -.28782100E+00, 0.13138000E+01, 0.16260000E+00, -.21483300E+01, -.59522000E+00, 0.11973800E+01, 0.43908400E-01, 0.12017700E+01, -.28329100E+00, 0.25853200E+01, 0.43254900E-01, -.51357800E+00, -.22281300E+01, -.22049700E+00, -.60587500E-01, 0.51352900E+00, -.37600200E+00, 0.77563900E-01, -.41578100E+00, -.81203800E+01, -.46324500E+00, 0.13549500E+00, 0.12612000E-02, 0.12904600E-02, -.11603700E+01, 0.21568000E+01, -.23565700E+00, -.22757900E+00, -.12215100E-01, -.44156300E-01, 0.80265200E+00, 0.19233400E+00, 0.17096600E+00, -.46726700E-02, 0.15158300E+01, -.81919900E+00, 0.39599500E+00, -.13477000E+01, -.11411700E+01, -.16511100E+00, -.11777200E+01, 0.33237200E-01, 0.34920900E-01, -.24169900E+01, -.98247800E-02, 0.22641300E+00, -.11617100E+01, -.66907000E-01, 0.12280800E+01, 0.91226400E+00, 0.15022000E+00, 0.32262600E+00, -.41898000E+00, -.14860300E+01, 0.13427200E+04, 0.60283300E+01, -.13682900E+03, 0.19329200E+03, 0.12139500E+03, -.38251900E+01, -.15793100E+02, 0.18123000E+03, 0.75975700E+03, -.36894200E+04, 0.18306700E+04, 0.45110600E+04, 0.18445400E+04, -.44159600E+03, -.12271600E+04, 0.17484700E+04, 0.21871600E+04, 0.17744700E+04, -.10814600E+04, 0.34635600E+04, -.44161000E+04, 0.22494500E+04, -.54303400E+03, 0.22150900E+04, -.65684300E+03, -.91395800E+03, -.20059200E+02, -.16036300E+04, 0.24342600E+04, -.66516100E+03, 0.51358600E+03, -.23271400E+04, 0.86424800E+03, 0.10764000E+04, 0.11685600E+04, 0.69903100E+03, 0.16318600E+03, 0.39589700E+03, -.29564100E+03, 0.68975100E+03, 0.19921300E+03, 0.10387200E+03, -.42890900E+03, 0.10036300E+03, 0.14515800E+04, 0.21937300E+03, 0.32009900E+03, -.39129800E+03, 0.57483700E+03, 0.29095500E+03, 0.90889900E+02, -.30937400E+03, -.13708700E+04, 0.10199900E+04, -.49039400E+03, 0.15178100E+04, -.50558100E+03, -.29460900E+03, 0.43047800E+03, -.71099600E+03, -.90370300E+03, -.70398700E+03, 0.56567800E+03, 0.79737600E+03, -.37962900E+03, 0.20010700E+03, 0.69905000E+03, 0.19357200E+03, 0.17961400E+03, -.48917600E+02, 0.32180800E+03, 0.29106200E+03, 0.33134300E+03, -.58255900E+02, -.29567200E+03, -.67103000E+04, 0.33478300E+04, -.13380700E+04, 0.33871000E+04, -.23826600E+04, -.29819800E+04, 0.42537400E+03, -.18233000E+04, 0.39357200E+04, -.28464200E+04, 0.40389100E+04, 0.17360700E+04, -.88720700E+03, -.22001700E+04, -.87032700E+03, 0.29996600E+03, 0.63154400E+03, -.36746000E+03, 0.80824800E+03, -.26114900E+02, 0.55366200E+03, -.75036400E+02, -.12582700E+04, 0.61012800E+03, 0.39545100E+03, 0.61804300E+03, 0.45638500E+03, 0.10900800E+04, -.86118000E+03, -.20063300E+04, -.28678300E+03, 0.13138000E+04, 0.10459300E+04, -.51763700E+04, 0.25799100E+04, -.12444000E+04, 0.25886100E+04, -.21186100E+04, -.27461300E+04, 0.17725900E+04, 0.84917500E+03, 0.22599400E+04, -.26305300E+04, 0.59003900E+04, -.10834300E+04, 0.55405400E+03, -.14458900E+03, 0.53773800E+03, -.10733900E+03, 0.46990500E+03, -.50794700E+03, -.11900600E+04, 0.91134700E+03, 0.55083400E+03, -.14186000E+03, -.40146500E+03, 0.19925400E+03, -.33064000E+03, 0.20347000E+03, -.16364700E+03, -.18306000E+03, -.44559300E+02, 0.15026200E+03, 0.88522500E+03, -.13635900E+03, 0.46321200E+03, -.14443800E+03, -.76845400E+02, -.98402700E+02, -.32744600E+01, -.18333900E+03, -.27579300E+03, -.12029500E+03, 0.94303800E+02, 0.10789800E+03, 0.63145900E+02, 0.12091300E+03, -.37299700E+03, 0.22581500E+03, -.85180400E+02, 0.22459500E+03, 0.28800700E+02, 0.32650700E+02, -.45267100E+02, 0.13092200E+03, -.43786700E+02, 0.90997100E+02, 0.52820400E+02, 0.53861600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54395800E+01, 0.63543500E+01, 0.90422100E+00, 0.13423800E+01, -.32575300E+01, -.17840400E+01, 0.96021500E+00, 0.17771100E+00, -.52691000E+02, 0.68783800E+00, 0.17261600E+00, -.97862600E+00, -.83143400E+00, -.18580900E+00, 0.94517200E+00, -.45839900E+01, -.41074900E+01, 0.16784900E+00, -.12447800E+00, 0.43733500E+01, -.51613700E+01, 0.17057000E+00, -.55801400E+01, -.76223600E+00, 0.12175600E+01, 0.29658800E+00, 0.56022300E+01, 0.12036100E+01, -.10028400E+01, 0.25466500E+00, 0.24589500E+00, 0.55767800E-01, 0.28979900E+00, -.39828500E-01, 0.32565400E+00, 0.38818400E+00, -.19130000E-01, -.69213300E+00, -.10218500E+01, -.17073600E-01, -.17936300E+01, 0.10943800E+00, -.33840800E+00, 0.45259800E+00, 0.67999200E-01, -.31072200E-02, -.12428800E+00, -.83973000E-01, 0.97679200E-01, -.12082500E+00, -.88344300E+00, -.11740900E+00, -.18908800E+01, -.85704100E+00, -.53019700E-02, 0.42853800E+00, -.33012500E+00, 0.21886400E+00, 0.33329900E-01, 0.20388900E+01, -.13153500E+01, -.55853700E-01, -.33344000E+00, -.31712300E+00, -.58896000E+00, -.32982800E+00, 0.47948200E+00, 0.51361800E+00, -.70314100E-01, 0.13983200E-02, -.34932000E-01, -.31216300E+00, 0.28835300E+01, -.21009400E+01, 0.29330400E+00, 0.12664300E+01, -.63764700E+00, 0.12237100E+01, -.19809200E+00, 0.37729300E-01, 0.71627400E-04, 0.11080200E+00, -.18168600E+00, -.21589700E+00, -.94052100E+00, -.16212100E+01, -.25861500E+00, 0.12254600E+01, 0.33244000E+00, 0.36877100E+00, -.11802800E+01, -.10995000E-01, -.31004500E+00, -.84330300E+00, 0.64038300E+00, 0.36597700E+00, 0.11278500E+01, -.84810800E-02, -.14711200E+01, 0.15596200E+01, 0.57904800E+00, 0.38608400E+00, 0.30108600E+02, 0.93918800E+02, -.22202500E+03, -.54370600E+01, -.75144500E+02, -.22158600E+03, -.22608200E+03, 0.40224100E+03, -.29497900E+03, 0.14835700E+03, -.17822400E+04, 0.14749100E+03, -.45596400E+03, -.24259000E+03, 0.57284200E+02, 0.25350400E+02, 0.16687900E+03, -.15321000E+03, 0.17252400E+04, -.54690300E+03, 0.26112500E+03, 0.21080300E+03, 0.27269100E+03, 0.45428600E+02, 0.11517500E+03, 0.10600700E+03, -.36456000E+03, 0.87599900E+02, 0.21134700E+02, -.50639700E+03, -.11967400E+04, 0.70002200E+03, 0.83910200E+03, 0.59923100E+03, 0.16022000E+02, 0.27947100E+03, 0.45865800E+03, 0.33835500E+03, 0.14719700E+03, 0.21656000E+03, 0.23183900E+02, -.20166900E+04, 0.10412500E+04, 0.92776500E+03, 0.10093500E+04, 0.12967500E+03, 0.40172400E+03, 0.46319400E+03, -.12714000E+02, 0.33197200E+03, 0.34770400E+03, 0.44730700E+03, -.94485200E+02, 0.29976000E+02, -.17334900E+02, 0.47355000E+02, 0.21269200E+03, -.29427800E+03, -.12711800E+02, 0.67648500E+03, 0.42886300E+02, -.38156700E+03, 0.79834500E+03, -.43650500E+03, 0.22340800E+03, 0.37285600E+02, 0.21833000E+03, 0.14597700E+03, -.58261500E+02, 0.18600200E+03, 0.19131500E+03, 0.59359500E+03, -.40955700E+02, -.41938400E+03, 0.24567700E+04, -.12121400E+04, -.18356500E+03, -.12285000E+04, 0.26166800E+03, 0.40419400E+03, -.80235200E+03, 0.40586000E+03, -.12061900E+04, 0.30708800E+03, -.20429900E+04, -.43070200E+03, 0.22300800E+03, 0.78119100E+03, 0.18211200E+03, -.48759700E+02, -.38465500E+03, 0.43895200E+03, 0.56964100E+03, 0.13582300E+03, -.37642000E+03, 0.19491000E+03, 0.11866700E+03, -.54401100E+02, 0.58719700E+03, -.58993800E+02, 0.35286700E+02, -.28421800E+03, 0.24664700E+03, 0.53472400E+03, -.18435000E+02, -.36189200E+03, -.59231000E+02, 0.26089100E+04, -.12997300E+04, -.43033900E+03, -.13044600E+04, 0.80631900E+02, 0.58195600E+03, -.83943100E+03, 0.69587800E+03, -.99837200E+03, 0.65716700E+03, -.98933900E+02, -.55802000E+03, 0.28057600E+03, 0.44620800E+03, 0.27891300E+03, 0.17593900E+03, -.17344200E+03, 0.53234500E+03, 0.68714500E+03, 0.51959200E+03, -.25355800E+03, -.31557800E+03, 0.86987300E+03, -.43455000E+03, -.32890300E+03, -.43516300E+03, -.20918200E+03, -.28831200E+03, 0.37560400E+00, 0.40919200E+03, -.12544200E+03, -.24055200E+03, -.74709200E+02, -.10054300E+02, 0.43101900E+02, 0.72183900E+02, 0.46580700E+02, 0.30792200E+02, 0.28235600E+02, 0.46902000E+01, -.70045900E+02, -.10325600E+03, -.10955600E+03, -.13052500E+03, 0.35664700E+03, -.82714800E+02, -.40791900E+02, 0.31388700E+02, -.12765700E+03, -.15429500E+03, 0.14214700E+03, -.93719700E+02, 0.78061400E+01, -.18004300E+03, 0.11588800E+03, -.59071800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.73583100E+00, -.13598400E+00, 0.44034100E+00, 0.83972700E+00, -.68905800E+00, -.34913900E+00, 0.14303800E+00, 0.75312700E+00, 0.68083200E+01, -.24779000E+00, -.12071900E+00, 0.12556400E+00, -.15602200E+00, -.50315000E-01, 0.51944900E+00, -.27980900E+00, -.87426500E+00, -.54378000E+00, 0.63829300E-02, -.86370900E-01, 0.32819000E+00, 0.78468100E-01, -.37312700E+00, 0.20033800E-01, -.26611900E+00, -.73665200E-02, -.14386700E+00, 0.50989700E-01, -.47104500E+00, -.12677000E-02, -.31243700E-01, 0.43776700E-01, 0.13369000E+00, -.68368500E-01, -.16592800E-02, 0.23491800E+00, -.26021700E-02, -.33519500E+00, -.13705400E+01, -.47521700E-01, -.36468200E+00, -.11047400E+00, -.72209200E+00, -.23213800E+00, 0.50482400E-01, 0.30759200E-01, 0.45930800E-01, -.63436700E-01, -.42885900E-02, -.16044500E+00, -.20468500E+00, -.20107500E+00, 0.50765400E+00, -.59770500E-01, 0.44158500E+00, 0.19224600E+01, 0.26225100E+00, 0.10202100E-01, 0.11294000E+00, 0.18993000E+01, -.74708800E-01, -.22370800E-01, -.39966300E+00, -.17398600E+00, -.83827900E-01, -.22062700E+00, 0.45708200E+00, 0.98749400E-01, 0.53577500E-02, 0.81828500E-04, -.37145800E-01, 0.51584100E+00, -.54360700E+00, 0.77557600E+00, -.64218300E+00, -.41828200E+00, -.21476600E+00, -.12752900E-01, -.11650100E+00, -.47764000E-02, 0.85969500E-04, -.94962000E-01, -.16516900E+00, -.20070300E+00, 0.15281100E+00, 0.57634100E+00, 0.33425600E-02, 0.45412800E-01, -.16654600E+00, -.15760200E+00, 0.70219300E+00, 0.17651100E-01, -.15610900E-01, 0.29940700E-01, -.28578300E+00, 0.46175500E-01, 0.31259500E+00, 0.37470600E+00, 0.45936900E+00, -.29603900E+00, 0.75772800E+00, -.10556700E+00, -.46102100E-01, 0.15315300E+03, 0.11091400E+03, -.21630700E+03, -.20436700E+03, -.10386200E+03, 0.93986000E+02, 0.10604000E+02, -.80899600E+03, 0.40335400E+03, -.45535900E+03, 0.40453800E+03, -.23906100E+03, -.25521000E+03, 0.19324900E+03, -.37595500E+03, 0.20104400E+03, -.17413700E+03, 0.31428400E+03, -.26580200E+03, 0.13390200E+03, 0.24624600E+03, 0.13073200E+03, 0.20784300E+03, 0.33953700E+03, -.11219100E+03, 0.28243200E+03, 0.98057300E+02, 0.29524400E+03, 0.77697600E+02, -.43177500E+03, 0.23290100E+03, 0.65187100E+02, 0.21534700E+03, -.85968400E+02, -.94805300E+02, 0.21201800E+03, 0.13276900E+03, 0.14577200E+03, -.67382700E+02, -.92762900E+02, -.72937400E+03, 0.36652000E+03, 0.13178500E+03, 0.36422300E+03, -.13790500E+02, 0.47238900E+02, 0.21163300E+03, 0.13008100E+03, 0.23466300E+03, 0.47770300E+02, 0.11129700E+03, -.53724900E+03, 0.26577800E+03, 0.17005200E+03, 0.26764100E+03, 0.58048700E+02, -.22740200E+02, 0.65801400E+02, -.29494700E+03, 0.14181000E+03, 0.30224800E+02, 0.91192800E+02, 0.38804200E+03, -.19455600E+03, -.28686000E+03, -.19487500E+03, -.71140000E+01, 0.14979000E+02, -.11495800E+03, 0.62324400E+02, -.20406800E+03, 0.78108000E+01, 0.66568500E+02, 0.40294000E+03, -.19750000E+03, -.74634200E+02, -.20923700E+03, 0.17939200E+03, 0.60481500E+03, -.46098400E+03, -.14508700E+03, -.22668000E+03, 0.55906500E+03, -.34653500E+03, 0.75003600E+02, -.36603800E+02, 0.52905800E+02, -.40799300E+02, 0.21832100E+02, 0.23321500E+02, -.43993800E+02, -.38228700E+02, -.37297500E+02, 0.19889600E+01, -.12995200E+03, -.15677800E+03, 0.79276400E+02, 0.71957800E+02, 0.81242900E+02, -.22678100E+02, -.89201800E+02, -.99505300E+01, -.99711600E+02, -.15479500E+02, -.35140700E+02, 0.84794900E+02, 0.45395200E+03, -.22627900E+03, -.18814800E+03, -.22708800E+03, -.10378000E+03, 0.23272100E+03, -.20661500E+03, -.42395600E+03, -.29870700E+03, 0.21290100E+03, -.33131400E+03, -.15637800E+03, 0.78229300E+02, 0.19311400E+03, 0.79081100E+02, 0.63180800E+02, 0.68931900E+01, 0.75436700E+02, 0.15046400E+03, 0.19963500E+03, 0.10881700E+02, 0.69590400E+02, -.17336900E+03, 0.86650300E+02, 0.16597100E+03, 0.85899100E+02, -.76965800E+02, -.12079300E+03, 0.14754300E+03, 0.40777100E+02, 0.20709000E+03, -.62814700E+02, -.23018400E+02, 0.63624900E+01, -.30220800E+02, -.93113100E+01, 0.21488200E+01, 0.15654300E+02, 0.20305300E+02, 0.69552700E+01, 0.95915300E+01, -.20267400E+02, 0.18888700E+02, 0.57206800E+01, 0.47658900E+02, -.27212600E+02, -.18846000E+02, 0.12024400E+02, 0.35144400E+02, 0.82825200E+02, -.26516800E+02, -.41761200E+01, 0.39083700E+01, 0.43603200E+02, 0.16523500E+02, 0.21688900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.87772100E+00, 0.98480700E+00, -.11822000E+00, 0.16682600E+01, 0.96748300E+00, -.13712000E+01, 0.10512600E+01, -.14325000E+00, -.18330900E+01, 0.12441100E+01, -.10184200E+00, -.89529700E+00, -.84306000E+00, 0.11559400E+00, 0.50259900E+00, -.12952500E+00, -.24293200E+01, 0.20542700E+01, 0.74792300E+00, 0.92229700E-01, 0.32319300E+00, 0.63795400E+00, -.11873800E+01, 0.11525000E+00, 0.27313500E+00, -.16535600E-01, -.49716800E+00, -.20307900E-01, 0.10525700E+00, -.33156300E+00, -.28331700E-01, -.55415800E+00, -.33733500E-01, -.14774500E+00, -.32608800E+00, -.18100900E+00, 0.52929400E-02, -.31036700E+00, 0.31861900E+00, 0.23674900E+00, -.28856300E+00, 0.11311100E+00, 0.80875800E+00, 0.43353300E+00, -.19136500E+00, -.15127600E+00, 0.51884300E+00, -.18030800E-01, 0.31032900E+00, 0.12312900E+00, -.19109300E+01, 0.13462100E+00, 0.17076600E+01, -.37574100E+00, 0.14212700E+01, 0.81504200E-01, -.29873100E+00, 0.20775800E+00, 0.15406100E+00, 0.20339400E+01, 0.13501500E+00, -.14723700E-02, 0.27126500E+00, -.48327700E+00, -.62423400E+00, -.47635200E-01, 0.13958600E+01, 0.40057300E+00, -.21970600E-01, 0.11250700E-02, -.10152200E-01, -.11902800E+01, 0.68378300E-01, 0.86271600E-02, 0.10573700E+00, -.44231100E+00, -.33644300E+00, 0.14643100E+00, 0.67733800E-02, -.32071000E-01, 0.71947100E-03, -.88922200E-01, -.53189100E-02, -.95550300E+00, 0.40393900E+00, 0.10023800E+00, -.11117500E+00, -.28531100E+01, 0.53839100E+00, -.15030000E-01, -.20502400E+00, -.12090300E-01, 0.97282000E-01, -.32930600E+00, -.25798900E+00, 0.32139900E+00, 0.20879800E+00, -.23845200E-01, 0.71554200E+00, -.93304200E+00, -.33109000E+00, 0.55141300E-01, 0.22843200E-01, -.33246600E+00, 0.21331500E+03, -.34018800E+03, -.45121400E+03, -.67811300E+02, 0.17489300E+03, 0.63857300E+02, -.16844100E+04, 0.83791000E+03, 0.76817200E+03, 0.84220000E+03, 0.30257800E+03, -.46962600E+03, 0.47129100E+03, -.36743600E+03, 0.52956200E+03, -.40585800E+03, 0.49570000E+03, -.12352400E+02, 0.11663600E+02, 0.84468500E+02, 0.59849000E+01, 0.97665000E+02, 0.24273700E+03, -.30932200E+03, 0.97044900E+02, 0.12485000E+03, 0.18339300E+03, 0.47357300E+02, -.55379400E+03, 0.22125000E+03, -.16915300E+03, 0.27762800E+03, 0.11520700E+03, -.90497000E+02, 0.10314800E+03, -.59595900E+02, 0.20419000E+03, -.46187200E+02, 0.11458800E+03, -.34194500E+02, -.32031200E+01, -.29888400E+03, 0.17862300E+02, 0.58876100E+02, -.15118500E+03, 0.10669400E+03, 0.87651300E+02, 0.36865000E+02, -.11706500E+03, -.23140900E+03, -.76098600E+03, 0.38667700E+03, 0.32972400E+03, 0.38068400E+03, -.61003000E+02, 0.23017900E+03, -.92974000E+02, -.78024200E+03, 0.43268300E+01, 0.31324400E+03, 0.18095400E+03, 0.60606500E+03, -.30720100E+03, -.29211500E+03, -.30288600E+03, 0.14992700E+03, 0.56642500E+02, -.11865600E+03, 0.24333300E+03, -.25678500E+03, 0.73682300E+02, -.18225700E+03, -.20901000E+03, 0.99263900E+02, 0.25120700E+02, 0.10532700E+03, -.51264500E+03, 0.28690000E+03, -.50291300E+03, -.42758800E+03, 0.29684400E+03, 0.20137400E+03, 0.61186900E+03, 0.35377400E+03, -.18040600E+03, -.43108100E+03, -.17552900E+03, 0.27984400E+02, 0.25364300E+03, -.35405700E+03, -.29787300E+03, -.12199500E+03, 0.25478600E+03, 0.10027000E+03, -.39912600E+03, 0.19521300E+03, -.67338800E+02, 0.19939500E+03, 0.17122900E+03, 0.42655600E+03, -.33315100E+03, -.61761500E+03, -.14700300E+03, 0.48814700E+03, 0.32255500E+03, -.72388400E+03, 0.35995300E+03, 0.24159500E+03, 0.36194400E+03, -.46139400E+03, -.22714400E+03, 0.24763600E+03, -.53173100E+03, 0.18211700E+03, -.21734900E+03, 0.55591200E+03, 0.19334400E+00, 0.12142200E+01, -.39377500E+02, -.26192600E+00, 0.81585900E+01, 0.31237400E+03, -.30670000E+03, -.26899200E+03, 0.45497300E+02, 0.33807400E+03, -.10176300E+03, -.81734900E+03, 0.40833400E+03, 0.40011400E+03, 0.40865400E+03, 0.16019700E+03, -.22388900E+02, 0.20178700E+03, -.25271800E+01, 0.46417400E+03, 0.34098200E+02, -.39783200E+02, -.18373800E+02, -.42501300E+02, -.23339800E+02, -.11939100E+02, -.55056500E+02, -.52025700E+02, -.15948600E+02, 0.21997900E+02, 0.20023000E+02, 0.91490800E+02, 0.58836500E+02, -.17609600E+03, 0.82737000E+02, -.31952300E+02, 0.38906600E+02, 0.91732400E+02, 0.18201400E+03, -.61716100E+02, 0.27247200E+02, 0.70394100E+00, 0.89411200E+02, 0.71692500E+00, 0.30465300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42511400E+00, 0.12175300E+01, -.32515000E+00, 0.10365600E+01, 0.25956400E-01, -.46811800E+00, 0.65649800E-01, 0.10220600E+01, 0.58642800E+01, -.42325100E+00, -.19385500E-01, 0.24133300E+00, 0.13324400E+00, -.16927400E-02, 0.31663200E+00, -.19340700E+00, -.13103500E+00, -.45968700E+00, -.30352100E-02, 0.59477000E-01, 0.48749400E+00, 0.76976600E-03, -.14444300E+01, 0.35998200E-01, 0.44794400E+00, -.10460900E-01, 0.31296900E+00, -.10499700E+00, 0.25304900E+00, 0.30003300E+00, -.13112900E+00, -.42833300E+00, 0.39624100E-01, 0.50471700E+00, 0.86844300E+00, 0.14426100E+00, -.95153200E-02, -.29479400E-01, -.21714100E+00, 0.15420900E+00, -.31677200E+00, -.10149800E+00, -.68028800E-01, -.37777300E+00, 0.98166400E-03, -.78001700E-01, -.13780900E+00, -.28902700E-01, -.16087900E+00, 0.59487100E-01, -.13998000E+01, -.30699500E+00, 0.24034400E+00, -.91828900E-01, 0.25123300E+00, -.21800200E+01, -.65297600E+00, 0.59907900E-01, -.45705900E+00, -.98309900E+00, -.18369500E+00, 0.61449100E-01, 0.21450100E+00, 0.21174000E+00, -.25427800E+00, 0.69341700E+00, -.77419200E+00, -.18897100E+00, -.15170100E+00, 0.73974600E-03, -.11237900E+00, 0.63647700E-02, 0.78869900E+00, -.82704100E-01, 0.42499800E-01, 0.80228700E-01, -.19238200E+00, -.51832000E-01, -.11021300E+00, -.15574100E-01, 0.82447400E-03, -.10488000E+01, 0.73429600E-01, 0.28814900E+00, 0.70647700E+00, -.27293600E+00, -.76695100E-01, 0.22985800E+01, -.48669200E+00, -.34460600E-01, -.57444600E+00, -.50192900E-02, -.42172500E-01, -.96044300E-01, 0.18349000E-01, 0.21746200E+00, -.38564700E+00, 0.61617400E-02, 0.59046600E+00, 0.12408900E+01, 0.85000800E+00, 0.17516000E+00, -.35254900E-01, 0.81387300E-01, 0.35309900E+00, 0.16447200E+03, 0.35966000E+03, -.65501900E+02, -.99192600E+02, -.11434700E+03, 0.23261300E+03, -.11055100E+03, -.56142600E+03, -.11627700E+03, -.21662800E+03, 0.13442200E+03, -.11187800E+03, -.10786500E+03, -.13140700E+03, 0.14765600E+03, -.83384700E+03, -.91957400E+03, 0.45777600E+03, 0.20135500E+03, 0.45931000E+03, 0.26797300E+03, 0.17071400E+03, 0.19019400E+03, -.74672400E+02, 0.13502000E+03, 0.36737500E+03, 0.11459000E+04, 0.18808000E+04, -.88545400E+03, -.11265800E+04, -.94220900E+03, -.31416800E+03, -.17980000E+03, -.77121400E+03, -.79602600E+03, -.82480100E+03, -.10579000E+03, 0.13390200E+03, 0.15500500E+04, -.75781100E+03, -.10375900E+04, -.77685700E+03, -.17488000E+03, 0.13393700E+03, -.90841300E+03, -.90011700E+03, -.80391500E+03, 0.17600800E+03, 0.53794300E+03, 0.53203700E+03, -.26848500E+03, -.40987700E+03, -.26681200E+03, 0.15989400E+02, -.50753700E+02, 0.14402300E+03, 0.59593300E+03, 0.78479800E+02, -.17713400E+03, -.20017100E+03, 0.24667100E+03, -.11869100E+03, -.66012900E+02, -.12398100E+03, -.75273300E+02, 0.62646700E+02, -.15568400E+03, -.13055200E+03, -.27437100E+03, 0.53277200E+02, 0.22431100E+03, -.96396900E+03, 0.48615100E+03, 0.25079300E+02, 0.47717800E+03, 0.19398400E+02, 0.52546000E+02, 0.53735300E+03, 0.17343300E+03, 0.39531000E+03, -.74781400E+02, 0.90238500E+03, -.47270400E+00, 0.29937200E+01, -.92104200E+02, -.29984600E+01, 0.18596500E+03, 0.11391600E+03, -.34066000E+02, -.15563200E+03, -.50007200E+02, 0.75963400E+01, -.78008600E+03, -.12686400E+03, 0.66974100E+02, -.12201700E+03, 0.64936100E+02, -.16499300E+03, -.62034800E+03, 0.39393300E+03, 0.53819200E+03, 0.30247300E+03, -.55495000E+03, -.99759300E+02, -.12367900E+04, 0.61819600E+03, -.90160000E+01, 0.61834800E+03, -.72742200E+02, -.15388700E+03, 0.32800700E+03, -.18180000E+03, 0.45336600E+03, -.33321700E+03, -.53028500E+03, 0.17589400E+03, -.91917300E+02, -.79719300E+02, -.87246000E+02, 0.11156000E+03, -.26945900E+03, 0.19126000E+03, 0.53690500E+03, 0.21242700E+03, -.21101900E+03, 0.13001900E+03, 0.64700100E+03, -.32328000E+03, -.37226800E+03, -.32378400E+03, -.16926800E+03, -.12252900E+03, 0.10251900E+02, 0.28718500E+03, 0.15998000E+03, -.71722500E+02, 0.24328800E+02, 0.23253900E+01, 0.46974900E+02, -.22166300E+02, 0.71678500E+00, 0.13346900E+02, 0.26698100E+02, -.69288700E+00, 0.23163200E+02, 0.50749200E+02, -.39739500E+01, 0.17569000E+02, -.24042300E+02, -.26424600E+02, 0.41115200E+02, -.87345000E+02, 0.96705300E+00, -.65930900E+01, -.68568900E+02, 0.39522200E+02, 0.27052300E+02, 0.12413700E+03, -.32030300E+01, -.61690700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.35586500E+01, -.34446500E+01, 0.47311400E+01, -.13079900E+01, 0.11925600E+01, 0.66982300E+00, -.37923000E+00, -.70345000E+01, -.94344100E+02, 0.10969000E+01, 0.47574500E+00, -.38483200E+01, -.19729000E+01, 0.10853300E+00, 0.32235200E+01, -.27893000E+00, 0.13033200E+01, 0.62090800E+01, 0.75119700E+00, 0.30612700E+01, -.66864700E+01, -.74410100E+00, -.47222400E+01, 0.59305800E+00, 0.47413900E+01, -.10122200E+00, 0.15117200E+01, 0.10489000E+00, 0.96924500E+00, 0.11503500E+01, 0.11745100E+01, -.60294300E+00, 0.40006500E+00, 0.10469300E+01, 0.21690200E+01, -.22170000E-01, -.16593000E-01, -.91043300E+00, 0.81833000E-01, 0.25041600E+00, -.45003800E+00, 0.10323500E+01, 0.51014100E+01, 0.26219500E+01, -.98559800E+00, -.60670900E+00, -.21613700E+01, -.31496700E+00, 0.22636800E+01, 0.12533700E+01, 0.37606000E+00, 0.21697800E+01, -.15203900E+00, -.23057100E+01, 0.28038800E+01, -.10672200E+02, -.17840300E+01, 0.14644200E+01, -.25406800E+00, 0.23121600E+00, 0.80178600E-02, 0.68623300E-01, -.75672500E+00, 0.73422000E+00, 0.10569700E+01, 0.72270700E+00, 0.34220700E+00, -.32061100E+00, -.44770700E+00, -.21243800E-02, 0.12264100E+00, 0.85244200E+00, -.29225600E+01, -.94064300E-01, -.87683900E+00, -.25404000E+00, -.45467700E+00, 0.26860400E-02, -.67035100E-01, -.10270300E+00, 0.82927900E-03, -.18132800E+01, 0.41174900E+00, -.10997800E+01, -.91296800E+00, 0.11295100E+01, 0.92845400E-01, -.66713900E-01, 0.98218100E+00, 0.21499500E+00, -.44075400E+01, -.98001800E-01, 0.25012100E+00, 0.68753500E+00, 0.32866100E+00, -.16037700E+01, -.57542100E+00, 0.13856200E+00, -.71974000E+00, -.18417900E+01, 0.27755700E+00, -.29268900E+00, 0.10583200E+00, 0.39113700E+00, 0.38556700E+00, 0.14571800E+01, -.50305400E+03, 0.61606900E+02, 0.14310000E+03, -.22508300E+03, 0.39172500E+03, -.20913900E+03, 0.24870400E+04, -.19600900E+03, 0.15694100E+04, 0.30512000E+03, -.15209200E+03, -.83591700E+02, 0.17432600E+03, 0.17860700E+02, -.15216800E+04, 0.12959900E+04, -.61476300E+03, -.56097600E+03, -.63972500E+03, -.51860300E+03, -.90085100E+03, -.11609900E+03, -.10652000E+04, -.15105200E+04, -.92111300E+03, -.67904100E+03, 0.24561000E+04, -.14890600E+04, -.74515600E+03, -.12263800E+04, -.68381000E+02, -.32496800E+03, -.65258000E+03, -.29362800E+03, -.41783300E+03, -.33466000E+03, -.39457800E+03, 0.36575100E+04, -.19201100E+04, -.15804500E+04, -.18273800E+04, -.39237200E+03, -.93962800E+03, -.50253800E+03, 0.41898700E+02, -.26288800E+03, -.89929200E+03, -.12802400E+04, 0.52987700E+03, -.23867300E+03, 0.15575900E+03, -.26131200E+03, 0.16918400E+03, 0.97592000E+03, -.54336700E+03, -.44538500E+03, -.50820700E+03, 0.90399900E+03, -.77939900E+03, 0.40470300E+03, -.20874000E+03, -.22180100E+03, -.19919100E+03, -.27174300E+03, -.20658500E+03, 0.16494300E+03, 0.58016300E+03, 0.40575200E+03, -.19145200E+03, 0.47786200E+02, -.20451100E+04, 0.10040200E+04, 0.20876800E+04, 0.10515300E+04, -.31467400E+03, -.77969400E+03, 0.13174700E+03, -.26034400E+04, -.16241200E+04, -.29932500E+03, 0.11541700E+04, -.24738900E+03, 0.10516100E+03, 0.81269100E+02, 0.13457900E+03, -.34344300E+03, -.12140800E+03, 0.30014300E+03, -.30468700E+03, -.19694200E+03, 0.70301600E+02, 0.47403900E+03, 0.13146900E+04, -.67064500E+03, -.10652000E+03, -.66804300E+03, -.22643500E+02, 0.89148000E+03, -.57485600E+03, -.33965900E+03, -.52151000E+03, 0.73334500E+03, -.75581900E+03, -.12324000E+04, 0.60692600E+03, 0.20814500E+04, 0.61662500E+03, 0.36170200E+03, -.28987200E+03, 0.76281800E+01, -.10787000E+04, 0.63653600E+03, -.46167100E+02, 0.55538300E+02, -.51414100E+03, 0.26275200E+03, -.12064200E+03, 0.25377500E+03, -.20933700E+03, 0.76710000E+03, -.60291400E+03, -.10738300E+04, -.10344000E+04, 0.58528200E+03, 0.37822800E+03, -.28868300E+04, 0.14425400E+04, 0.11692700E+04, 0.14463800E+04, 0.80586000E+03, 0.86663200E+03, -.22550100E+03, -.13365800E+04, -.76827900E+03, 0.50316000E+03, 0.64274700E+03, 0.26673200E+02, -.40694600E+02, -.54937300E+02, -.40003600E+02, 0.42539900E+02, 0.28949400E+02, 0.14623700E+02, 0.52366400E+02, 0.10047800E+03, 0.14186400E+03, 0.14583600E+03, -.48985700E+03, 0.45328800E+02, 0.13490500E+03, -.61271400E+02, 0.13315100E+03, -.47274700E+02, 0.12293300E+03, 0.44303800E+02, -.49599600E+02, -.45924600E+02, -.13736300E+03, 0.13046300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22937800E+01, -.98091600E+00, -.22583800E+01, 0.15176100E+00, 0.60745000E+00, 0.72660600E+00, -.42096000E+00, -.23727300E+01, -.61490400E+01, 0.13939400E+01, -.16627300E+00, -.86314000E+00, 0.72625500E+00, 0.23320500E+00, -.24420500E+01, -.11776000E+00, 0.79614100E+00, -.49526300E+01, -.11628800E+01, -.11999800E+01, 0.18954500E+01, -.15606400E+00, 0.14373000E+00, -.30517300E+00, 0.57229500E+00, -.32498400E-01, 0.58168200E+00, -.16186800E+00, 0.34704000E+00, 0.57649300E+00, -.66748600E+00, 0.39503100E+00, -.82149600E-01, 0.27646400E-02, 0.77005500E-01, -.12011300E+00, 0.12008700E-02, 0.61410900E+00, 0.72352900E+00, 0.15396400E+00, 0.60303700E+00, -.39090000E+00, -.15226500E+01, -.13358300E+01, 0.17476400E+00, 0.99952300E-01, 0.16036500E+00, 0.11778200E+00, 0.28167200E-01, -.18900500E+00, -.17674100E-01, -.35001100E+00, 0.15921300E+01, 0.88819800E+00, -.10954400E+00, -.14389900E+01, 0.12022700E+01, -.18318000E+00, -.11632500E+00, -.16579700E+00, 0.36068900E+00, 0.24042100E-01, 0.95706100E+00, 0.62887100E-01, 0.74867500E+00, 0.77114600E+00, -.47477600E+01, -.87806800E+00, 0.64287000E-01, -.17961300E-02, 0.13033600E+00, 0.62203200E+00, -.18082800E+01, 0.17509000E+01, -.66280700E+00, -.27156000E+00, 0.21468100E+00, -.55363100E+00, 0.20666900E+00, 0.15248200E+00, -.26690500E-02, 0.79337600E+00, -.15307400E+00, 0.16056900E+01, 0.11814900E+00, 0.85297500E+00, 0.28257300E+00, -.12875400E+01, -.16883600E+00, -.16358100E+00, 0.47597100E+01, 0.11797600E-01, 0.32490400E+00, 0.12922000E+00, -.52902400E+00, 0.31300200E+00, -.87993500E+00, -.60133200E+00, -.69776100E-01, -.24909700E+01, -.76051200E+00, -.37075700E+00, 0.49148300E-01, -.26548000E+00, -.45029700E+00, 0.14853400E+01, 0.94953900E-01, 0.56927000E+03, 0.21586700E+03, -.36738900E+03, 0.27493300E+04, -.13844500E+04, -.42802000E+03, -.13747300E+04, -.45718300E+03, 0.67833500E+03, -.74377400E+03, 0.17807300E+03, -.12496400E+04, 0.59431000E+03, -.11271100E+04, 0.22857800E+04, -.11434400E+04, -.36017000E+03, -.11403600E+04, -.38421900E+03, -.32572700E+02, -.30497000E+02, 0.12901900E+04, 0.20598900E+03, -.28746100E+03, -.15777400E+04, -.22364900E+04, 0.10289500E+04, 0.15155600E+04, 0.11202800E+04, 0.60345100E+03, 0.43427100E+03, 0.83764600E+03, 0.10884600E+04, 0.10938900E+04, 0.26889600E+03, -.11599300E+03, -.14284800E+04, 0.70128700E+03, 0.16599100E+04, 0.71623700E+03, 0.38737800E+03, -.64114400E+02, 0.10010300E+04, 0.13903900E+04, 0.91079800E+03, -.16432500E+03, -.75103900E+03, -.76186300E+03, 0.39439800E+03, 0.36755400E+03, 0.38258200E+03, -.40854000E+03, -.41605000E+03, 0.11088500E+03, -.88870100E+03, 0.78747100E+02, -.11658000E+03, -.11877700E+03, -.98811800E+03, 0.48342100E+03, 0.25996900E+03, 0.49545800E+03, -.33645200E+02, -.23437500E+02, 0.18450600E+03, -.42964000E+03, 0.81733300E+02, -.72437600E+02, 0.44548400E+03, 0.15115800E+04, -.77915500E+03, -.19473900E+04, -.74398700E+03, 0.57550400E+03, -.11326900E+03, 0.59801200E+03, 0.25340200E+04, 0.14988600E+04, 0.16667500E+03, -.16922800E+04, 0.51288000E+03, -.26029600E+03, -.52104400E+03, -.24506000E+03, -.32103200E+03, -.52109300E+03, 0.14074500E+03, 0.70150900E+03, 0.53650800E+03, -.34584300E+03, 0.63615400E+03, -.37827100E+03, 0.18393800E+03, 0.12508700E+03, 0.18504000E+03, 0.74039500E+02, 0.57296700E+03, -.32529500E+03, -.80305800E+03, -.15725800E+03, 0.49063300E+03, 0.42169700E+03, 0.28172200E+04, -.14057000E+04, -.18312600E+04, -.14084600E+04, 0.57301900E+03, 0.46102400E+03, -.37209600E+03, 0.11694200E+04, -.93291000E+03, 0.61999000E+03, -.11821600E+04, -.24808100E+03, 0.12713400E+03, 0.31171900E+03, 0.12255700E+03, -.41025400E+03, -.98098700E+02, -.13210800E+03, -.10444600E+04, -.45683700E+03, -.65876400E+02, 0.70946800E+03, 0.53426100E+03, -.26701300E+03, 0.44107900E+03, -.26612400E+03, -.16649000E+03, 0.25090900E+03, -.28675400E+03, -.44548000E+03, -.83919300E+03, 0.19651400E+03, -.38930700E+03, 0.15380600E+02, -.64579300E+02, 0.45648700E+02, 0.12800300E+02, -.21960900E+02, -.44519900E+02, 0.10883900E+02, -.47146600E+02, -.13967900E+03, -.63434400E+02, -.73662300E+02, 0.39176900E+03, 0.40993300E+01, -.22072500E+02, 0.70658200E+02, -.65597000E+02, -.32714600E+02, -.78445200E+02, -.36215400E+02, -.52262600E+02, -.16024400E+03, -.19286700E+02, 0.84089700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19459600E+01, -.22040000E+01, 0.20762700E+01, -.14037900E+01, 0.75554200E+00, 0.82770000E+00, -.23868800E+00, -.18355200E+01, -.25019900E+02, -.18238300E+00, 0.12692000E+00, -.10301700E+01, 0.12383000E+00, -.12250000E+00, 0.16072300E+01, 0.20150800E+01, 0.22713400E+01, 0.60143000E+01, 0.61881200E+00, 0.99695400E+00, -.10652300E+01, 0.93334500E+00, 0.18499200E+01, 0.19585600E+01, -.15659600E+01, 0.98237700E-01, -.29124100E+01, -.15820100E+00, -.11940100E-01, -.64850200E+00, 0.14629300E+00, 0.40503000E+00, -.86833300E-01, -.26700300E+00, -.67985400E+00, -.38592000E-03, -.56395700E-02, -.14640400E+00, 0.37731900E+00, 0.37064700E+00, 0.43129900E+00, -.31814800E+00, -.77951100E+00, -.55827400E+00, -.97598300E-01, -.19741100E+00, -.99177700E+00, -.24084700E+00, -.84782100E+00, 0.11022500E+00, 0.12983100E+01, 0.35999300E+00, -.21195600E+00, -.10491400E+01, 0.12024300E+01, -.32205800E+01, -.26238900E+01, 0.17810800E+00, -.10447400E+01, 0.59880600E+01, -.15041500E+01, -.10370400E+00, -.16883800E+01, 0.48330900E+00, -.18076200E+01, 0.81164600E+00, 0.53972900E+01, 0.34269600E+00, -.22423600E+00, 0.83418400E-03, -.35532800E+00, -.18890400E+00, -.63364800E+01, 0.29380600E+01, -.26728700E+01, -.19469400E+01, -.26954800E+00, -.10262700E+01, 0.15987300E+00, -.38838900E-01, -.19468700E-02, 0.30005000E+00, 0.63742600E+00, -.27828700E+00, -.21350700E+00, -.87586800E-01, -.10216300E+00, 0.12879700E+01, 0.65133000E-01, -.78279900E+00, 0.38158000E+01, -.94943600E-02, -.49332000E-01, 0.13181000E+01, -.42634500E+00, -.11219400E+01, -.47309200E+00, 0.63126300E+00, 0.47540200E-01, -.17882400E+01, 0.13329700E+01, -.73730100E+00, 0.93588700E-02, -.11956800E+01, 0.12762500E+01, 0.26325300E+01, 0.30549100E+00, 0.11971300E+00, 0.21057200E+03, -.26895800E+02, 0.32870300E+04, -.16470400E+04, -.26605200E+04, -.16434900E+04, -.13804800E+04, 0.92616900E+03, -.74521100E+03, 0.54179200E+03, -.12030900E+04, 0.69437200E+03, -.11221800E+04, 0.11748000E+04, -.62594000E+03, -.30474100E+03, -.58944000E+03, 0.30694400E+03, 0.40318600E+03, 0.30513900E+03, 0.16993500E+04, 0.51965800E+02, 0.29577500E+01, -.16694500E+04, -.20673800E+04, 0.11539900E+04, 0.30507900E+04, 0.10343300E+04, 0.27179500E+03, 0.71338700E+03, 0.86992100E+03, 0.11962600E+04, 0.89453300E+03, 0.42599100E+03, -.96336300E+03, -.29829100E+04, 0.15529900E+04, 0.39088400E+04, 0.14921900E+04, 0.26081200E+03, 0.52626300E+03, 0.12253900E+04, 0.13770500E+04, 0.13438400E+04, 0.28603600E+03, -.55176800E+03, -.19159300E+03, 0.89884800E+02, -.72746200E+03, 0.95274600E+02, -.16921300E+03, -.53542300E+03, 0.29037900E+03, -.33778700E+03, 0.82759500E+02, -.35068600E+03, -.63898300E+03, -.99366700E+03, 0.48370500E+03, 0.55882100E+03, 0.49635100E+03, -.35173000E+03, -.21848500E+03, 0.12431800E+03, -.53125300E+03, 0.48234900E+03, -.28460700E+03, 0.73509600E+03, 0.35481900E+04, -.17935300E+04, -.25216300E+04, -.17792200E+04, 0.21653100E+04, 0.11973200E+04, -.14781600E+03, 0.16211500E+04, -.14984300E+04, 0.15450600E+04, -.32860700E+04, -.19745700E+03, 0.10574100E+03, 0.51967500E+03, 0.99644300E+02, -.43646300E+03, -.60093400E+03, 0.75051300E+03, 0.64586900E+03, -.10451600E+02, -.47518100E+03, 0.36192900E+03, 0.11638000E+04, -.56784700E+03, 0.60334800E+01, -.57983300E+03, -.33123000E+03, -.69228900E+02, -.15711300E+03, -.96159100E+02, -.26509800E+03, -.20439000E+03, -.61019600E+03, 0.43463900E+04, -.21628200E+04, -.23937200E+04, -.21732900E+04, 0.11403900E+04, 0.17876000E+04, -.13832500E+04, 0.47728900E+03, -.19922700E+04, 0.19183500E+04, -.16176500E+04, -.21803700E+04, 0.10898100E+04, 0.78870800E+03, 0.10906700E+04, 0.29300600E+03, -.54282600E+03, 0.87507700E+03, -.37159300E+03, 0.32418400E+03, -.51386200E+03, 0.14678000E+04, 0.83027700E+03, -.41462500E+03, -.33580700E+03, -.41580300E+03, -.11955600E+03, 0.16100200E+03, -.11755300E+03, -.19867300E+02, -.94648500E+03, -.31260300E+02, -.28008200E+03, 0.79537400E+02, -.32630500E+02, 0.77341900E+02, -.23949600E+02, 0.10810500E+03, 0.59051500E+02, 0.59649600E+02, -.75489800E+02, -.14258300E+03, -.14981900E+03, -.12124300E+03, 0.44264800E+03, -.48544800E+02, -.20365400E+02, 0.89868800E+02, -.95417900E+02, -.36364500E+03, -.48253700E+02, -.83743000E+02, -.38476200E+02, -.89714900E+02, 0.10569500E+01, 0.74700800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32878500E+01, -.35610200E+01, -.17820100E+01, -.14012600E+01, -.11641700E+01, 0.23133800E+01, -.11233300E+01, -.60139800E+01, -.88082900E+01, 0.20981200E+01, 0.14106900E+01, 0.85744100E+00, -.10348300E+00, 0.25751700E-01, -.83147200E+00, 0.31753800E+01, 0.20745800E+01, -.33037700E+01, -.25394400E+00, -.19386100E+01, 0.12393500E+01, -.40833500E+01, -.42461500E+01, -.30545700E+01, -.27210700E+00, -.98321400E-01, -.87461400E+00, 0.62180500E-01, -.67377400E+00, -.76080300E+00, -.10936500E+01, -.77477500E+00, 0.15092200E+01, 0.52629100E-01, -.51585600E+00, 0.49464100E-01, 0.52895500E-03, -.32937100E+00, 0.26954400E+00, -.76799300E+00, -.13718300E+01, 0.37312600E+00, 0.11718100E+01, 0.95739800E+00, 0.28175400E+00, 0.91696900E-01, 0.12527400E+01, 0.16590100E+00, -.35635500E+00, -.50968400E-01, -.29135700E+01, -.21766900E+00, 0.37344200E+00, 0.13115500E+01, -.71396600E+00, 0.39719200E+01, -.30076800E+00, -.10216700E+00, 0.58820900E+00, -.14013100E+01, -.20652000E+00, 0.12508900E+00, 0.54020900E-01, 0.80333700E-01, 0.24256800E+01, -.95363000E+00, -.34818900E+01, 0.71765500E-01, 0.23472600E+00, 0.74876800E-03, 0.11410400E+00, -.90663900E-01, -.12192700E+01, -.33196800E+01, -.11143700E+00, 0.10112600E+01, -.18046200E+01, 0.28504100E+00, -.12237800E+00, 0.23268100E+00, 0.47460300E-03, -.41070700E+00, -.13700300E+00, -.45725300E+00, -.22298100E+01, -.47200100E+00, -.94499600E-01, 0.43940400E+01, -.83687800E+00, 0.12199900E+00, -.62202200E+00, 0.20309500E-01, -.49096400E+00, 0.47195400E+00, 0.78273600E+00, -.10918600E+01, 0.12689300E+01, 0.17874800E+01, -.21493200E+01, -.23760200E+00, -.27736500E+01, 0.31457400E+00, 0.24865400E-01, -.10601600E+01, -.84382500E+00, -.20257800E+01, -.85597100E+00, -.43217700E+00, -.17746900E-01, 0.83777400E+03, -.19801300E+04, 0.97920500E+03, 0.40395400E+04, 0.98998900E+03, 0.74070400E+03, -.53279400E+03, 0.72771300E+03, 0.59945500E+03, 0.10452900E+04, -.68337200E+03, 0.22730300E+04, 0.51729400E+03, -.27847100E+03, -.46534800E+03, -.25649400E+03, -.66403900E+03, -.10981900E+04, 0.31593200E+02, -.76713700E+03, -.66705500E+03, -.95381700E+03, -.22333100E+04, -.16035800E+04, 0.80048200E+03, 0.15361400E+04, 0.80540600E+03, 0.74681300E+03, 0.81523200E+03, 0.44899000E+02, -.13993400E+02, 0.30005900E+03, 0.60108500E+03, -.23772600E+03, -.10483400E+04, 0.52613600E+03, 0.15396800E+04, 0.52781000E+03, 0.49328800E+03, 0.22301400E+03, 0.28039900E+03, 0.13465600E+03, 0.25095500E+03, 0.77766600E+02, -.10295400E+04, 0.93807200E+02, -.50401500E+02, 0.36093200E+03, -.44840300E+02, 0.29092500E+03, 0.39949000E+03, -.16102000E+03, 0.12551400E+03, -.21396400E+03, 0.29081000E+03, 0.87489900E+03, -.17766800E+03, 0.80955400E+02, 0.20568100E+03, 0.90549400E+02, -.42647500E+02, -.50695900E+02, 0.17234600E+03, 0.11722200E+03, 0.32794600E+03, 0.63162600E+02, -.10378100E+04, -.37849000E+04, 0.18875500E+04, 0.13666000E+04, 0.19060600E+04, -.54522500E+03, -.27622800E+04, 0.14584000E+04, -.69295800E+03, 0.81364400E+03, -.23370400E+04, 0.16443900E+04, -.13838300E+03, 0.70093400E+02, -.38829700E+03, 0.83690900E+02, -.87872200E+02, -.21133800E+03, 0.44211400E+03, 0.67909500E+03, 0.37846300E+03, -.15957100E+03, 0.51225800E+03, 0.41111200E+03, -.20932800E+03, 0.13652900E+03, -.21003500E+03, 0.38475900E+03, 0.11979700E+04, -.82509900E+03, -.93379900E+03, -.85693000E+03, 0.10521800E+04, -.17427400E+03, -.41542200E+04, 0.20752100E+04, 0.21556000E+04, 0.20772600E+04, -.59899400E+02, -.18754300E+04, 0.14637100E+04, 0.30255800E+03, 0.19454800E+04, -.17082800E+04, 0.51857700E+04, -.38946200E+03, 0.19938400E+03, -.22398500E+03, 0.19289000E+03, 0.40947500E+03, 0.66774800E+03, -.47480800E+03, -.76011700E+03, -.28985300E+03, 0.61063100E+03, -.93768300E+03, -.19965100E+04, 0.99696300E+03, 0.66331100E+03, 0.99923100E+03, 0.73254100E+03, 0.41798100E+03, -.34413000E+01, -.47993900E+03, 0.74585700E+02, 0.23049700E+03, 0.40661900E+03, 0.51580000E+02, 0.64093500E+02, 0.84667600E+02, 0.31395200E+02, -.90598300E+02, -.95563400E+02, 0.40772600E+02, -.87804300E+02, -.67164000E+02, -.92198100E+01, -.21045200E+02, -.23372300E+03, -.38596100E+02, -.42759900E+02, 0.89903200E+02, -.13932300E+02, -.12591700E+02, 0.14479200E+03, 0.13687900E+03, -.43586500E+02, -.16194400E+03, 0.70331400E+02, -.34349200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54398900E+01, -.94071600E+01, -.17350400E+01, -.58247000E+01, -.34910900E+01, 0.23164200E+01, -.20783800E+01, -.92265300E+01, -.43966600E+01, -.15667100E+01, 0.27307300E+01, 0.37303400E+01, 0.12555000E+01, 0.75637700E-01, -.31995600E+01, 0.50182400E+01, 0.53758600E+01, -.60959000E+01, -.13710700E+01, -.21693200E+01, 0.12067900E+01, -.17722100E+01, 0.65551100E+01, 0.15719200E+00, 0.10350900E+01, -.13164000E-01, 0.20905200E+01, 0.38298200E-01, 0.55820000E+00, 0.17324200E+01, 0.21507900E+01, 0.19307600E+01, -.22775000E+01, -.22504400E+00, -.42146300E+00, -.73781400E+00, 0.48746900E-01, 0.18666100E+01, 0.20438000E+01, 0.56367200E+00, -.12079300E+00, -.86646600E+00, 0.27316400E+01, 0.80395900E+00, -.52618000E+00, -.37758000E+00, -.22174700E+00, -.15290900E+00, -.21749700E+00, 0.46492500E+00, -.70220700E+00, 0.70963200E+00, 0.75349600E+00, 0.10196400E+01, -.10242100E+01, 0.63295600E+01, -.12152000E+01, -.15301100E+00, -.44934100E+00, -.29487600E+01, -.28793500E+01, 0.14661800E-01, -.43094200E+00, 0.61128900E+00, 0.11240500E+01, 0.11397500E+00, -.11026900E+02, -.64317600E+00, -.86613800E-01, 0.20629400E-02, 0.77993000E+00, 0.13147700E+00, -.27955800E+01, -.24539200E+01, 0.62705500E+00, 0.22535900E+00, -.19235900E+00, 0.26984600E+00, 0.10091600E-01, 0.17442800E+00, 0.31207100E-02, -.38280100E-01, 0.30843100E-01, 0.13984600E+01, -.39898000E+01, -.11185200E+01, -.36475800E-01, 0.71058400E+01, -.20407600E+01, 0.26047200E+00, -.53751900E+01, 0.14150500E+00, -.90228400E+00, 0.11073300E+01, 0.20699000E+01, -.73734100E+00, 0.11573300E+01, 0.19902200E+01, 0.99517000E+00, 0.79857500E+01, -.25488700E+01, 0.19593900E+01, -.42850600E+00, 0.22703900E+01, -.25106700E+01, -.16666500E+01, -.24636000E+00, -.24349100E+01, 0.56394200E+00, 0.11626000E+01, 0.90174600E+04, -.44796500E+04, -.37440100E+04, -.45085400E+04, -.75629200E+02, 0.20433600E+04, -.24791400E+04, 0.93890500E+03, -.37155200E+04, 0.21175700E+04, -.10191700E+04, 0.14527700E+04, -.82340100E+03, 0.14277300E+03, -.73583500E+03, -.92843500E+03, -.18988700E+03, 0.39116000E+03, 0.18628200E+04, 0.12408500E+04, -.63553700E+03, -.11276300E+03, -.42450200E+04, 0.26015600E+04, 0.50453300E+03, 0.21188100E+04, 0.53771200E+03, 0.92936400E+03, 0.21911900E+04, 0.28036800E+04, 0.14549300E+04, 0.60605800E+03, -.14557700E+03, -.52902000E+04, 0.28676100E+04, 0.72636500E+03, 0.26415500E+04, 0.73600200E+03, 0.11922000E+04, 0.19153700E+04, 0.19021700E+04, 0.10681000E+04, 0.94293600E+03, 0.71390600E+03, -.60464900E+03, 0.27802400E+03, 0.33522800E+03, 0.29738700E+03, -.15003500E+03, -.12757600E+04, -.15403700E+03, -.35232700E+03, -.10377900E+03, -.80929300E+03, 0.63890200E+03, -.15399100E+04, 0.76417800E+03, -.37438400E+03, 0.76568900E+03, -.40185900E+02, 0.16253400E+03, 0.47925100E+03, 0.15312100E+02, 0.93515100E+03, -.17283900E+03, 0.10458700E+04, 0.10944600E+04, -.56050900E+03, -.41592700E+04, -.58485900E+03, -.14454100E+04, -.20976200E+04, 0.15661600E+04, 0.52157800E+04, 0.42247100E+04, -.23622100E+04, -.11376700E+04, -.87988800E+03, 0.47480300E+03, -.10694100E+04, 0.44224300E+03, -.20269400E+03, -.11025000E+04, 0.55623000E+03, 0.89998600E+03, 0.13649500E+04, -.95032600E+03, 0.19047700E+04, -.17601800E+04, 0.90734500E+03, 0.12852800E+03, 0.89349900E+03, 0.55177200E+03, -.39421900E+03, 0.75411000E+03, 0.58004200E+03, 0.45273700E+03, -.49361300E+03, 0.13113000E+04, 0.32210100E+04, -.15932700E+04, -.44069200E+04, -.16110400E+04, 0.41695600E+03, -.10160000E+04, 0.62367300E+03, 0.36357100E+04, -.70851200E+03, -.30323900E+03, -.30641300E+03, 0.27394300E+04, -.13869200E+04, -.19212800E+03, -.13652400E+04, -.14148300E+04, -.13955300E+04, -.26204900E+02, 0.68407200E+03, -.13676800E+03, -.12034900E+04, -.30608000E+03, 0.80412100E+04, -.40172900E+04, -.11678500E+04, -.40240800E+04, -.12718800E+04, -.61564200E+03, -.10039700E+04, 0.20610700E+04, -.14081100E+04, -.27747200E+03, -.27968900E+04, -.11911500E+03, 0.49532000E+02, -.70095100E+02, 0.94484900E+02, -.18473700E+03, -.12917200E+03, -.70776500E+02, 0.73312200E+02, -.20868300E+03, -.25657300E+03, -.28465100E+03, 0.10457600E+04, -.13489500E+03, -.39281200E+03, 0.28339200E+03, -.30977600E+03, 0.47638800E+03, 0.14031400E+02, -.95993000E+02, 0.10168400E+03, -.56633500E+03, 0.89235000E+02, -.19725100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12554700E+01, 0.27375700E+01, -.17994600E+00, 0.28951500E+01, 0.10593000E+01, -.10215700E+01, 0.10613800E+01, 0.16837300E+01, 0.19832400E+01, 0.12481000E+01, -.11352900E+00, -.80910400E+00, -.36065200E+00, -.25714700E+00, 0.12739000E+01, -.10157500E+01, -.39071300E+01, 0.16428400E+00, 0.67324200E+00, 0.15908000E+01, 0.61262400E+00, 0.90153800E+00, -.45615000E+01, 0.71026000E+00, -.78508800E+00, 0.33050700E-01, -.18493900E+01, -.33935300E+00, 0.10594400E+01, -.37248400E-02, 0.57222100E+00, -.14049900E+01, -.38788400E+00, 0.74002200E-01, 0.62536400E+00, -.19953500E-01, -.21535000E-02, 0.35124600E+00, 0.15843000E+00, 0.75196000E+00, 0.13818200E+01, -.42505200E+00, -.10069000E+01, -.41643100E+00, 0.77096300E-02, -.13208900E-01, -.48635000E+00, -.19116200E+00, -.60292400E+00, -.80541100E-02, -.33704700E+01, -.11198900E+01, 0.79719600E-01, -.66213300E+00, 0.12742000E+01, 0.33638100E+01, 0.28439800E+00, -.10726600E+00, -.20821000E+00, -.31422000E+00, 0.28732300E+00, -.38737100E-01, -.21864700E+01, 0.26719100E+00, -.28757200E+00, 0.10840700E+01, 0.74336500E+01, -.24294700E+00, -.90846700E-01, -.56588800E-02, 0.30750400E+00, 0.17441700E+01, -.12811900E+01, 0.10239200E+01, -.13651100E+01, -.13694000E+01, 0.11080100E+00, 0.10434800E+01, -.21157500E+00, -.40838300E+00, -.43994100E-03, -.11532500E+00, -.17621800E+00, -.15616000E+01, -.17908400E+01, 0.56119100E+00, -.14159000E-01, 0.40230400E+01, -.70986200E+00, -.84271300E-01, -.14068000E+01, 0.78696100E-02, -.20145300E+00, 0.15227300E+01, -.28039200E+00, -.88753400E+00, -.86192700E-01, -.10636000E+00, -.12626400E+01, 0.15316800E+01, 0.16699800E+01, -.62047700E+00, 0.30673300E-01, 0.10703700E+00, -.48125900E+00, -.10908300E+01, -.39353100E+00, -.52555600E+00, -.15371700E-01, -.27507300E+00, 0.21355500E+00, -.19517800E+02, 0.31512300E+04, -.15473700E+00, 0.64523400E+03, 0.48246900E+02, 0.24905800E+03, 0.52983300E+03, 0.65168500E+03, -.38369100E+03, 0.11738800E+03, 0.15931900E+04, -.75553200E+03, -.37815500E+03, -.78746800E+03, -.54742000E+03, -.88502500E+03, -.63612100E+03, -.93867900E+03, -.15149500E+04, -.60205000E+03, -.19917300E+04, -.79957100E+02, -.18612300E+03, -.42066300E+02, 0.41262800E+02, 0.19742600E+03, -.48601900E+02, -.46806600E+01, -.16415300E+03, 0.11818400E+03, -.88540500E+02, 0.55478100E+02, 0.45488900E+03, -.31878600E+03, -.15291100E+03, -.22646700E+03, 0.50885100E+02, -.37294900E+03, 0.10305700E+03, -.39979800E+01, 0.21858700E+03, -.38920900E+03, -.52494100E+03, -.20764400E+03, 0.12047400E+03, 0.50698700E+03, 0.10766700E+03, 0.16941000E+03, 0.45367900E+03, -.35984700E+02, 0.22556200E+03, 0.48902300E+02, 0.30049400E+03, 0.24180800E+02, 0.28877300E+03, -.14928100E+03, 0.70487600E+02, -.14101900E+03, -.46465900E+02, -.13476100E+03, -.17693000E+01, 0.24262900E+02, -.76784900E+02, 0.26425800E+02, -.76699100E+03, -.60454900E+04, 0.30183200E+04, 0.30648600E+04, 0.30539200E+04, -.81296400E+03, -.24582300E+04, 0.14709500E+04, -.15140600E+04, 0.62866500E+03, -.17820400E+04, 0.13871400E+04, -.19679700E+03, 0.83416200E+02, -.29323900E+03, 0.10380600E+03, 0.18895400E+03, 0.14941100E+03, 0.60785400E+03, 0.88363200E+03, 0.27481200E+03, -.86762200E+01, 0.11810500E+03, 0.52802000E+03, -.27750100E+03, -.28547100E+03, -.27557100E+03, 0.53534600E+02, 0.50127100E+03, -.37314700E+03, -.32869200E+03, -.39663200E+03, 0.44711000E+03, -.68219700E+03, -.56538900E+04, 0.28221000E+04, 0.32880100E+04, 0.28274200E+04, -.34366200E+03, -.15500500E+04, 0.16290300E+04, -.43462300E+03, 0.27939700E+04, -.14848000E+04, 0.30788800E+04, -.10875500E+04, 0.55073700E+03, 0.10128800E+03, 0.54027500E+03, 0.37218600E+03, 0.21352900E+03, -.17635300E+03, -.64913800E+03, -.39801400E+03, 0.33236100E+03, -.49019400E+03, -.12318200E+04, 0.61513500E+03, 0.38321900E+03, 0.61914200E+03, 0.73195100E+03, 0.54195600E+03, -.18096400E+03, -.43147100E+03, -.44959300E+03, 0.27992600E+03, 0.15721000E+03, 0.69503300E+02, -.41940500E+02, 0.56165600E+01, 0.53611600E+02, 0.20156700E+02, 0.22731100E+02, 0.49677400E+02, -.73301500E+01, 0.18291400E+02, 0.70477200E+02, 0.67565000E+02, -.41436300E+03, -.95638500E+02, 0.76454200E+02, -.39259300E+02, 0.51794400E+02, -.20575300E+03, 0.15356800E+03, 0.23362700E+03, -.81393300E+02, 0.10964000E+02, -.56930500E+02, 0.84014400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.92691000E+00, -.11672100E+01, -.14582200E+00, -.56970800E+00, -.50275100E+00, -.78793300E+00, -.45905300E+00, -.10999100E+01, 0.17582200E+02, -.13151200E+01, 0.79706000E-01, 0.17177500E+01, 0.29647700E+00, 0.17232200E-02, -.69457800E+00, 0.15366000E+01, 0.31960100E+01, -.19486300E+01, -.59472200E+00, -.10710900E+01, 0.12388000E+01, -.61791000E+00, 0.24213100E+01, 0.24594500E+00, 0.11665300E+00, 0.63381000E-03, 0.19677600E-01, -.19616900E+00, 0.51153400E+00, 0.47104600E+00, 0.34415400E+00, 0.57885800E-01, -.13636300E-01, 0.13700900E+00, 0.53989600E+00, 0.87067400E-01, -.12514900E-01, -.10131300E+00, -.42973500E+00, 0.33506600E+00, 0.34288800E+00, -.28238900E+00, -.15451000E+01, -.97450100E+00, -.53203100E-01, -.10868300E+00, -.23951700E+00, -.82551100E-01, -.41892300E+00, 0.10753700E+00, -.59913000E+00, -.15448300E+00, 0.26697700E-01, -.47165300E+00, 0.69520400E-01, -.53134200E+00, 0.78181600E+00, -.83060500E-01, -.75815600E+00, -.13734800E+01, -.93424600E+00, 0.54474300E-01, 0.18514600E+00, 0.21203400E+00, -.69310100E+00, 0.13576300E+00, 0.36402400E+01, -.14785000E+00, -.16791100E+00, -.34956700E-03, -.16297300E+00, -.46207800E+00, -.64689200E+00, -.31798700E-01, -.79433900E+00, -.51823900E-01, -.41716700E+00, 0.26930000E+00, -.62250500E-01, -.36440400E-01, -.13595700E-02, 0.17275200E+00, -.16919000E-02, -.51970300E+00, -.12084800E+01, -.10058000E+01, -.12791600E+00, 0.16448900E+01, 0.39780600E+00, 0.12745500E-01, -.46369700E-01, -.28698300E-01, -.73160100E-01, 0.30356500E+00, 0.96930300E-02, -.31086500E+00, 0.44072900E-01, -.10159000E+00, -.35574200E+00, -.22031100E+00, 0.13592800E+01, -.24175600E+00, 0.25764000E-01, 0.28507700E+00, -.30598600E+00, 0.25580000E+00, 0.22686900E+00, -.70239400E-01, -.93179100E-01, -.24367500E+00, 0.14317000E+00, -.20808700E+00, 0.22575700E+04, 0.98908200E+01, 0.30080600E+03, 0.13946000E+02, 0.28151200E+03, 0.59230600E+03, 0.57998600E+03, -.41544600E+03, 0.27644500E+03, 0.10024600E+04, -.49224200E+03, -.29138300E+03, -.49682500E+03, -.40169900E+03, -.72018900E+03, -.38033400E+03, -.79727400E+03, -.11040800E+04, -.49371500E+03, -.16222400E+04, -.96174200E+03, 0.43086800E+03, 0.80930200E+03, 0.48272900E+03, 0.28964400E+03, 0.26783200E+03, 0.14385500E+03, -.17067500E+02, 0.25862700E+03, 0.17529900E+03, 0.25420200E+02, -.67580800E+03, 0.31241400E+03, 0.79887900E+03, 0.33966500E+03, 0.20729000E+03, 0.54964800E+02, 0.23422000E+03, 0.87559100E+02, 0.30691900E+03, -.17595800E+02, -.30725500E+03, -.22285500E+03, 0.11007200E+03, 0.23963100E+03, 0.11373700E+03, 0.12311900E+03, 0.26665600E+03, 0.94850900E+02, 0.23565900E+03, 0.96233900E+02, 0.14480500E+03, -.96020700E+02, -.10190500E+03, 0.44895600E+02, 0.38856100E+03, 0.52941900E+02, -.69856000E+02, -.10094900E+03, 0.13171000E+02, -.15288400E+03, -.53448900E+02, 0.48638000E+02, -.42865200E+03, -.47656100E+04, 0.23860300E+04, 0.24309200E+04, 0.24003300E+04, -.25370600E+03, -.17832200E+04, 0.11806900E+04, -.13433200E+04, 0.46752000E+03, -.12040700E+04, 0.75906100E+03, -.15992200E+03, 0.77397500E+02, -.92070600E+02, 0.85504100E+02, 0.15090100E+03, 0.17233400E+03, 0.45421000E+03, 0.70891100E+03, 0.22324500E+03, 0.91999500E+01, 0.78965000E+02, 0.43253300E+03, -.22026300E+03, -.26284100E+02, -.22253400E+03, 0.18265700E+02, 0.42524900E+03, -.31687900E+03, -.33212600E+03, -.37995700E+03, 0.39059200E+03, -.58327800E+03, -.40950300E+04, 0.20483500E+04, 0.24755700E+04, 0.20477600E+04, -.61811200E+02, -.90935200E+03, 0.11387700E+04, -.20498500E+03, 0.20707400E+04, -.93786900E+03, 0.23182200E+04, -.15234000E+04, 0.76658100E+03, 0.17752400E+03, 0.75960700E+03, 0.30610300E+03, 0.11631000E+03, 0.59886600E+02, -.64990100E+03, -.68280900E+02, 0.25088400E+03, 0.22523900E+02, -.88615400E+03, 0.44266500E+03, -.35816300E+02, 0.44471400E+03, 0.53389300E+03, 0.36409800E+03, -.71324200E+02, -.24390300E+03, -.24788200E+03, 0.16124600E+03, 0.19355900E+03, 0.68108900E+02, -.34634000E+01, 0.49559500E+02, 0.34321200E+02, 0.13643000E+02, 0.13563500E+02, 0.49237900E+02, -.50816200E+02, -.86601000E+01, 0.27691500E+02, 0.26939800E+02, -.27291700E+03, -.80849400E+02, 0.28158200E+02, -.64861400E+01, 0.27659400E+02, -.28930800E+03, 0.11523100E+03, 0.19761700E+03, -.61174500E+02, 0.42158600E+02, -.13954700E+01, 0.40687800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46031400E+00, 0.58433300E+00, 0.73935400E-01, 0.15262800E+00, 0.86575600E-01, 0.37757800E+00, 0.20782800E+00, 0.28916300E+00, -.11680500E+02, 0.63413100E+00, -.17246400E-01, -.83627100E+00, -.15853200E+00, 0.17494700E-01, 0.25267100E+00, -.86951600E+00, -.15598900E+01, 0.65376900E+00, 0.20502700E+00, 0.67748400E+00, -.74341900E+00, 0.25989000E+00, -.11428000E+01, -.15905800E+00, -.45972400E-02, 0.20001600E-01, 0.30514500E+00, 0.14762200E+00, -.26652000E+00, -.18192400E+00, -.12674900E+00, 0.30159900E-01, 0.15754300E-02, -.79366200E-01, -.24277900E+00, -.41168200E-01, 0.48484900E-02, 0.76202700E-01, 0.22731000E+00, -.11359700E+00, -.19855400E+00, 0.10738300E+00, 0.69293900E+00, 0.41282000E+00, 0.18043200E-01, 0.44686300E-01, 0.10154100E+00, 0.21514600E-01, 0.21847600E+00, -.28635600E-01, 0.19705300E+00, 0.81626700E-01, -.50259700E-01, 0.16693200E+00, -.35477500E-01, -.67948900E-01, -.39893700E+00, 0.55874600E-01, 0.25005800E+00, 0.44209800E+00, 0.28897900E+00, -.28739000E-01, -.35566400E-01, -.11282800E+00, 0.13903500E+00, -.10511000E-01, -.15306900E+01, 0.12037700E+00, 0.46740000E-01, 0.45616700E-03, 0.53403000E-01, 0.11339900E+00, 0.57785900E+00, -.17001600E+00, 0.38787800E+00, 0.16790600E+00, 0.17423900E+00, -.36159200E-01, 0.19438100E-01, 0.28049100E-01, 0.49119400E-03, -.56664900E-01, -.51313500E-01, 0.34009400E+00, 0.52262100E+00, 0.24995000E+00, 0.37851400E-01, -.46949400E+00, -.16395600E+00, 0.14666000E-01, 0.12935700E+00, 0.14296000E-01, -.80961500E-03, -.21430400E+00, 0.55627600E-01, 0.22374500E+00, -.37501700E-01, 0.10858300E-01, 0.10626700E+00, 0.28279000E+00, -.60758100E+00, 0.15839000E+00, -.16023600E-01, -.88059600E-01, 0.73922000E-02, -.11927800E+00, -.12440100E+00, 0.34780700E-01, 0.22424400E-01, 0.10594700E+00, -.57902500E-01, -.12139800E+00, -.13106000E+00, 0.31316600E+02, 0.65354100E+02, 0.20266300E+02, -.43852700E+02, -.10160500E+03, -.43112300E+02, 0.56777700E+02, -.13014700E+03, 0.77905400E+01, 0.57771100E+00, 0.21927800E+02, -.32533400E+01, 0.37111600E+02, 0.37413500E+02, -.30447800E+02, 0.14163200E+02, 0.16148600E+02, 0.28698200E+02, 0.10014500E+03, 0.35659100E+03, -.21085100E+03, -.29167100E+03, -.17855400E+03, -.48873500E+02, -.88816600E+02, -.92624500E+02, -.91376000E+02, -.99451700E+02, -.67387500E+02, 0.16045000E+02, 0.39367200E+03, -.20721900E+03, -.31151100E+03, -.19711500E+03, -.54451400E+02, -.93635600E+02, -.97143100E+02, -.86386100E+02, -.97401900E+02, -.72395900E+02, -.15532600E+02, 0.79758500E+02, -.35071700E+02, -.93359400E+01, -.39719400E+02, -.64967700E+00, 0.34544200E+02, -.41891000E+02, 0.26581200E+01, -.29454200E+02, 0.29231600E+02, 0.47316300E+01, 0.11620500E+03, -.57852600E+02, -.11041900E+03, -.57952400E+02, 0.76879400E+01, -.71051400E+01, -.40989700E+01, 0.67968300E+02, 0.38308700E+01, -.17643900E+02, -.14918900E+02, 0.14907700E+03, -.78445200E+02, -.62286100E+02, -.72927200E+02, -.95475700E+02, 0.11135600E+02, -.29555400E+02, 0.84671100E+02, 0.80684100E+01, -.23191400E+02, 0.12515500E+03, 0.29989300E+02, -.17467800E+02, -.53135400E+02, -.17468800E+02, 0.17242000E+01, -.21217700E+02, -.96814400E+01, -.29604400E+02, -.11039500E+02, -.43269300E+01, -.39010100E+02, 0.49304600E+00, -.17233400E+01, -.61264000E+02, -.88801000E+00, -.41075500E+00, -.29156200E+02, 0.15921600E+02, 0.38408800E+02, 0.27927400E+02, -.31998400E+02, 0.33279800E+02, 0.72400800E+01, -.48755000E+01, -.10323400E+02, -.35895000E+01, -.58553900E+02, -.48006100E+02, 0.30169400E+01, -.63420600E+02, -.43399700E+02, -.28399100E+02, -.66403600E+02, 0.28042800E+03, -.14040000E+03, -.68368100E+02, -.14036400E+03, 0.32308800E+01, 0.57960300E+01, -.66268600E+02, 0.67346700E+02, -.88667100E+02, -.89284300E+01, -.12480000E+03, 0.88812400E+01, -.44996300E+01, 0.89793100E+02, -.42377600E+01, 0.10498000E+02, 0.10379200E+02, -.16686000E+02, -.93838700E+01, -.13831300E+02, 0.12269500E+02, -.53833400E+02, -.49632900E+01, -.82756300E+01, -.14518000E+02, 0.13695500E+01, 0.17425300E+01, 0.14740800E+01, -.36599300E+01, 0.14533500E+02, 0.81110200E+01, 0.75800500E+01, 0.79024200E+01, -.21769300E+02, 0.11827700E+02, 0.13268400E+02, -.12183000E+02, 0.34878100E+01, 0.26719900E+02, -.39700300E+01, -.83981100E+01, 0.36886300E+00, -.72370500E+01, -.17066600E+02, 0.54761300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.44762000E+01, -.14178300E+01, -.15494300E+01, -.57607000E+00, 0.22958700E+00, 0.23337400E+01, -.11077400E+01, -.48232700E+01, -.10316900E+02, 0.17588600E+01, 0.39835400E-01, -.14547000E+00, -.13188900E+01, 0.18289000E+00, -.16158000E+01, 0.82503400E+00, 0.97373900E+00, -.75481200E+01, -.11214800E+01, -.10165300E+01, 0.12252000E+01, -.10422000E+01, -.57998700E+01, -.25840600E+01, 0.68533700E+00, -.10139500E+00, 0.22215600E-02, -.25090800E+00, 0.31496900E+00, 0.72139100E+00, 0.24873900E+00, -.26934000E+00, 0.22947100E-01, -.39360000E+00, -.16530000E+00, -.91866200E-01, 0.13341600E-01, 0.95090500E+00, -.39615300E+00, 0.21913500E+00, 0.17993400E+01, -.50084500E+00, -.68306800E+00, -.91248700E+00, 0.19009400E+00, 0.18568600E+00, -.10322200E+00, -.49664800E-01, 0.42396400E+00, -.29742900E+00, 0.29280200E+01, -.55106500E+00, 0.92523400E+00, 0.68348200E+00, -.32028300E+00, -.30628700E+01, -.33307200E+01, 0.10211300E+00, 0.18255600E+00, -.35174800E+01, 0.68716100E+00, 0.14716800E+00, -.77776700E-01, -.57726900E-01, -.32865300E+00, 0.12656000E+01, -.60242300E+01, -.10033800E+01, 0.18159400E-01, 0.19826000E-02, 0.31966900E+00, -.13179600E+01, -.20173600E+01, 0.18660600E+01, -.32752100E+00, -.22432600E+01, -.75174000E-01, 0.88672400E+00, -.17545700E+00, -.10330500E+00, 0.20933000E-02, 0.34158900E+00, 0.66593700E-01, -.93926800E+00, -.55106700E+00, -.89053700E+00, -.32812300E+00, -.48376200E+00, 0.25863600E+00, 0.76406300E+00, -.18328800E+00, -.50793600E-02, -.27263000E+00, 0.61641700E+00, 0.73154900E+00, -.10848300E+01, 0.15131100E+01, 0.23776300E+01, 0.46139400E+00, 0.43587600E+01, 0.35397700E+01, 0.67125100E+00, -.18080800E+00, 0.21823400E+01, -.67729900E+00, -.12679800E+01, -.39843800E+00, 0.82524400E-01, -.60791100E-01, -.73981900E+00, -.16634800E+00, -.53368300E+00, 0.12509900E+01, -.39705900E+00, 0.26425100E+04, 0.44523400E+03, -.41795900E+03, -.37442500E+03, 0.21278500E+03, 0.16333900E+03, -.13056600E+04, 0.84847300E+02, 0.17967400E+02, 0.66626900E+03, -.41246700E+02, -.55300900E+03, -.99479000E+02, -.90615600E+02, -.20647300E+04, -.14259800E+04, 0.12220500E+03, 0.16389900E+04, 0.55100700E+04, -.29097700E+04, -.49251800E+04, -.27603300E+04, -.11034700E+04, -.14357200E+04, -.11983900E+04, -.78032700E+03, -.14452700E+04, -.11935600E+04, -.62604500E+02, 0.55870200E+04, -.28659800E+04, -.63893600E+04, -.27991200E+04, -.10036500E+04, -.10834600E+04, -.16429000E+04, -.11387600E+04, -.14454500E+04, -.93143100E+03, 0.19780200E+03, 0.11377300E+04, -.54224100E+03, -.24364500E+03, -.57040900E+03, 0.40378300E+03, 0.10554300E+04, -.46368100E+03, 0.32414500E+03, -.43041000E+03, 0.77690200E+03, -.13529100E+03, 0.97528500E+03, -.49163800E+03, -.46207000E+03, -.48885200E+03, -.29827600E+03, -.37633700E+02, -.10933500E+03, 0.10302800E+03, -.49421600E+03, -.39042900E+02, -.19424400E+03, -.27005600E+04, 0.13616700E+04, 0.40942100E+04, 0.13430800E+04, -.16468600E+04, 0.10620800E+04, -.19503900E+03, -.32809300E+04, -.64328500E+03, 0.10627300E+04, 0.37167200E+04, 0.18644700E+03, -.10722400E+03, -.39419600E+03, -.91496600E+02, -.88602200E+02, 0.35153100E+03, -.55446300E+03, -.97425000E+03, 0.11388600E+03, 0.31463500E+03, -.37088300E+03, -.94629200E+02, 0.36731600E+02, -.25833200E+03, 0.48897900E+02, -.20332100E+02, -.20003000E+03, 0.52531000E+03, 0.74612700E+03, 0.32067400E+03, -.23897700E+03, -.41275100E+02, -.21817800E+04, 0.10714200E+04, 0.32991400E+04, 0.10908500E+04, 0.47519200E+03, 0.80380900E+03, -.19375400E+03, -.76730000E+03, 0.10246500E+04, 0.72190400E+03, 0.22701600E+03, 0.20122000E+04, -.10182500E+04, -.11029700E+04, -.10047500E+04, -.87374100E+03, 0.56325000E+03, -.79181700E+03, -.40290000E+03, -.12447700E+04, 0.44097500E+03, -.29334800E+03, -.74186700E+03, 0.37210900E+03, -.21683100E+03, 0.37102300E+03, 0.36550000E+03, 0.34017900E+03, -.99361600E+02, -.38816300E+03, 0.20833800E+02, 0.21326100E+03, 0.26620100E+03, -.81064200E+02, 0.86463500E+02, -.14687700E+03, -.61195700E+02, 0.67730600E+01, 0.77094700E+02, -.73068400E+02, 0.14519500E+03, 0.21865300E+03, 0.21234400E+03, 0.21933400E+03, -.92748400E+03, -.11917700E+03, 0.58331200E+02, -.14400500E+03, 0.17797000E+03, 0.18662700E+03, 0.37992200E+02, 0.11636200E+03, 0.95791800E+02, 0.37306100E+03, -.18186400E+03, -.57128700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15337600E+00, 0.41428400E+00, -.49594000E-01, 0.34232200E+00, 0.49804400E-01, -.12121400E+00, 0.36032100E-01, 0.31542200E+00, 0.18667500E+00, 0.26884800E-01, -.18936700E-01, -.95427800E-01, -.88095300E-01, -.43505600E-02, 0.21337300E+00, -.25159400E+00, -.50275600E+00, -.23960600E-01, 0.38716000E-01, 0.93680300E-01, -.10299800E+00, -.14866000E-01, -.51009800E-01, -.11070500E+00, -.73855400E-01, 0.31974700E-02, -.17811700E+00, 0.75383200E-02, -.80261900E-01, -.45354300E-01, -.27767600E-01, -.16048100E+00, 0.48389600E-01, -.66135800E-03, 0.81707500E-01, 0.17493300E-01, -.84367100E-03, 0.73573800E-01, -.14585400E+00, 0.69502000E-01, 0.26687400E+00, 0.26492700E-01, 0.41255700E+00, 0.10866500E+00, 0.48310200E-01, 0.49620800E-01, 0.14504300E-01, -.16828400E-01, 0.17032800E+00, -.42738400E-01, 0.66384600E+00, -.32075200E-01, -.13417400E+00, 0.95665000E-01, -.18325000E+00, -.51040300E+00, -.66664300E-01, 0.28371600E-01, -.13273300E-01, 0.38518200E+00, -.15667700E+00, -.36374900E-01, -.24123100E-01, 0.44174200E-01, 0.31371100E-01, 0.96557100E-01, -.19992700E+00, 0.13110700E-01, 0.33711300E-01, -.50711800E-03, 0.35380000E-01, 0.41221100E-01, -.40635800E+00, 0.30260200E+00, -.11741400E+00, -.53857600E-01, 0.19354800E-01, -.34987500E-01, 0.11181300E-01, -.81287600E-02, -.13491600E-03, 0.10771200E-01, 0.30978300E-01, 0.88750700E-01, 0.92697900E-01, 0.53162300E-01, 0.73224700E-02, 0.18692500E+00, -.14060100E+00, -.93433300E-02, 0.33550200E+00, -.79332700E-03, 0.37272300E-01, -.92587300E-02, -.23025400E-01, -.32409500E-01, -.34994200E-01, 0.62023100E-01, 0.10098200E+00, 0.27347300E+00, 0.43838200E+00, -.59980900E-01, -.19470200E-02, -.18609100E-02, 0.67938600E-02, 0.14557300E+00, -.17359200E-01, -.26173900E-01, 0.60079300E-02, -.39668400E-01, -.36868600E-01, 0.37096000E-01, 0.22833200E-01, -.71169600E-02, -.12134400E-01, -.39041800E+02, 0.42654600E+02, 0.10006100E+03, 0.10605100E+02, -.18069900E+02, 0.96349200E+02, 0.11836100E+03, -.56589100E+02, -.36510400E+01, -.59356400E+02, -.51496500E+02, -.20928900E+02, 0.67507300E+00, 0.11089300E+03, 0.16359900E+02, -.14514100E+02, -.35443400E+02, -.56206300E+02, 0.18818000E+02, -.93633600E+02, 0.27872800E+02, 0.67250800E+01, -.14628900E+02, 0.40794200E+02, 0.54691900E+02, 0.29928100E+02, -.14454000E+02, -.51140500E+02, -.42067100E+02, 0.19282900E+02, -.11769500E+03, 0.20798600E+02, 0.76589900E+01, -.68742700E+00, 0.23149400E+02, 0.59837600E+02, 0.20884800E+02, -.49014900E+01, -.44300300E+02, -.10866300E+03, 0.56173300E+02, 0.13308900E+03, 0.54180700E+02, -.23099200E+02, -.51787900E+02, -.12321000E+01, -.10146000E+03, 0.92598600E+01, -.11655900E+02, 0.55621800E+02, -.76290300E+02, 0.37209700E+02, 0.17606600E+02, 0.38018300E+02, 0.64254600E+01, 0.57433600E+02, -.17144500E+01, -.38893100E+02, -.23931500E+02, 0.43029400E+02, 0.60133500E+02, -.20943300E+03, 0.10362900E+03, -.88476100E+02, 0.10369300E+03, -.12552000E+03, -.76652500E+02, 0.10622600E+03, 0.23806200E+03, 0.25509100E+03, -.97478500E+02, 0.16142100E+03, 0.74143900E+02, -.37579900E+02, -.10682100E+03, -.36376900E+02, -.64301000E+01, -.16086700E+01, -.28291300E+02, 0.28219400E+02, 0.44679600E+02, -.69181100E+01, 0.12313200E+02, -.12627600E+03, 0.62650900E+02, -.11468700E+02, 0.63476200E+02, 0.32770900E+02, 0.24383500E+02, -.24704700E+02, -.11387400E+03, -.20691800E+02, 0.49591700E+02, 0.67952500E+02, -.12790500E+03, 0.63780000E+02, -.12988300E+03, 0.63939800E+02, -.52050800E+02, -.11436500E+03, 0.12205500E+03, 0.19547400E+03, 0.11455600E+03, -.10240900E+03, 0.15390200E+03, 0.94229900E+02, -.47571700E+02, 0.11217000E+02, -.46979500E+02, -.92487600E+02, 0.20516700E+02, -.52455100E+02, -.12600600E+02, 0.12679700E+02, 0.22229800E+02, 0.41694200E+02, 0.21507700E+03, -.10743100E+03, -.55187900E+02, -.10761300E+03, -.54855000E+02, -.36289700E+02, -.13354300E+02, 0.10080800E+03, 0.71836100E+01, -.11304200E+02, -.26161100E+02, -.71829800E+01, 0.10599900E+02, -.26040300E+00, -.10801100E+01, -.14133100E+02, -.96333100E+01, -.56878400E+01, 0.19518700E+00, -.27476800E+01, -.38497900E+00, -.31505100E+01, 0.16521500E+02, -.13602000E+02, -.17259000E+02, 0.13664800E+02, -.14206000E+01, 0.85178600E+02, -.47428500E+01, 0.49016200E+01, 0.57809500E+01, -.45695800E+01, 0.16686500E+02, -.16548500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.68284200E+00, -.12205100E+01, 0.10638000E+00, -.10981100E+01, 0.41196800E+00, 0.11071800E+01, -.85233300E-01, -.52597600E+00, 0.32446600E+01, 0.12252700E+01, -.65591300E-02, -.27292100E+00, -.85541100E-01, 0.11887100E+00, -.66005800E+00, -.15492700E+00, 0.57842900E+00, 0.40734200E+00, 0.14868500E+00, -.77934400E+00, 0.38113500E+00, 0.18046600E+00, 0.29827000E+01, -.12790100E+00, -.12060100E+01, 0.30225600E-01, -.21252500E+01, -.64674000E-01, -.13136600E+00, -.71484100E-01, 0.53804100E+00, 0.27086500E+00, -.15776900E+00, -.31774300E+00, -.68163600E+00, -.15545600E+00, 0.12910900E-01, 0.65572100E+00, 0.67220300E+00, 0.43200100E-02, 0.80601100E+00, -.28527500E-01, 0.67498600E+00, 0.17218400E+00, -.14255600E-03, 0.79827700E-01, -.24143400E+00, -.71402500E-01, 0.18419900E-01, -.82474300E-02, 0.98111500E+00, -.72891200E-01, -.34912800E+00, -.14197400E+00, 0.22289500E+00, -.85698000E+00, -.18376000E+00, 0.30402600E-01, 0.26629000E-01, -.12381900E+01, 0.61938800E+00, -.10635900E+00, -.43843100E+00, -.38957000E+00, -.72950500E+00, 0.84604100E+00, -.69465600E+00, 0.30692000E+00, -.98792600E-02, 0.69647200E-03, -.22680700E+00, -.44058200E+00, -.94637100E+00, -.58862700E-01, -.10107000E+01, -.28942000E+00, -.10151100E+00, 0.35680600E+00, 0.65221900E-01, -.31336500E-01, -.22930300E-02, 0.16436900E+01, -.40645000E+00, 0.10835500E+00, -.17119600E+01, 0.46201400E+00, 0.82369800E-01, -.21323800E+00, -.10566800E+00, 0.98567700E-01, 0.35255400E+00, 0.29439300E-01, 0.87371700E-01, -.32875600E-01, -.63576900E-01, 0.57703500E+00, -.48732400E+00, 0.77678500E-01, 0.51640100E+00, 0.13600700E+01, 0.65386400E-01, 0.19511600E+00, -.25469400E-01, -.12713900E+00, 0.22779300E+00, -.89200400E-01, -.17393700E-01, -.35363200E+00, 0.17672900E+00, -.57736600E-01, 0.22442000E-01, 0.14049700E+00, -.95876700E-01, 0.30740400E-01, 0.82075900E-02, 0.35752200E+01, -.20034200E+03, -.58926800E+03, -.38498800E+02, 0.25872900E+02, -.56631500E+03, -.21338100E+03, 0.10430300E+03, -.76992800E+02, 0.10758800E+03, 0.10229000E+03, -.22965500E+02, -.77454600E+02, -.32051000E+03, -.22721900E+03, -.13994000E+02, 0.46784200E+02, 0.33840800E+03, -.14795300E+03, -.11157000E+03, -.16913800E+03, -.33418800E+01, 0.16074200E+02, -.28955800E+03, -.41795600E+03, -.24793700E+03, 0.54051200E+02, 0.26374100E+03, 0.46422200E+03, -.23020600E+03, -.47940200E+02, -.23207000E+03, -.16301700E+02, -.43067500E+02, -.25709800E+03, -.40133100E+03, -.23424400E+03, 0.12801100E+02, 0.16683300E+03, 0.45312700E+03, -.23487600E+03, -.35156300E+03, -.22619800E+03, -.40069600E+02, 0.15144900E+03, -.15175300E+02, 0.44329200E+03, 0.43253200E+02, 0.46272700E+02, -.13094500E+03, 0.10106100E+03, -.45495700E+02, -.77578200E+02, -.50208200E+02, 0.58836900E+02, -.16910700E+03, 0.36481600E+02, 0.77617400E+02, 0.13217900E+03, -.99659600E+02, -.30327100E+03, -.51384700E+03, 0.26547900E+03, 0.37287100E+03, 0.25993600E+03, 0.24240900E+03, 0.11327200E+03, 0.13639700E+03, -.47680900E+03, -.43491800E+03, 0.14375300E+03, 0.14502700E+03, -.47038800E+03, 0.23750200E+03, 0.23837400E+03, 0.23467100E+03, 0.95399800E+02, 0.39791300E+02, 0.20497300E+03, -.12606100E+03, -.18409200E+03, 0.45805900E+02, -.91214700E+02, 0.25579700E+03, -.12758100E+03, -.44407600E+02, -.12901500E+03, -.29666400E+02, -.55777100E+00, -.71339600E+01, 0.29730000E+03, 0.31162900E+02, -.68852200E+02, -.16097100E+03, -.24003300E+03, 0.12126700E+03, 0.26161100E+03, 0.12006300E+03, 0.98173100E+02, 0.67418900E+02, -.23228200E+02, -.58000700E+03, 0.45949700E+02, 0.78749800E+02, -.25768900E+03, 0.17922800E+03, -.87262600E+02, -.12355400E+03, -.89948500E+02, 0.20824800E+03, -.39095400E+02, 0.10097400E+02, 0.13464100E+03, -.28491300E+03, -.53621900E+02, -.39271100E+03, -.56406500E+03, 0.28165000E+03, 0.21767200E+03, 0.28234500E+03, 0.10674100E+03, 0.12841200E+03, -.66736100E+02, -.39772900E+03, -.19946100E+03, 0.54792000E+02, 0.37209200E+02, 0.22705500E+02, -.18273500E+02, 0.10113200E+02, 0.31126100E+01, 0.87629700E+01, 0.35951100E+01, 0.18621700E+02, -.97996500E+01, -.63102200E+01, -.98618200E+01, -.53840900E+01, 0.24780800E+02, 0.15999000E+02, 0.40520600E+02, -.40446300E+02, -.35756000E+02, -.29054100E+03, -.38722600E+01, 0.11957300E+02, -.86754500E+01, 0.22972500E+02, -.50054400E+02, 0.38530900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19907300E+01, 0.48043000E+01, -.20809100E+00, 0.34305500E+01, 0.16372400E+01, -.67377700E+00, 0.78251000E+00, 0.61361900E+01, 0.30730500E+02, 0.10824300E+01, -.11878000E+01, -.84548200E+00, -.35142000E+00, 0.96818900E-02, 0.22071700E+01, -.17500100E+01, -.23876500E+00, 0.21220100E+01, 0.90292200E+00, -.77270900E+00, 0.15562800E+01, -.17414500E-01, -.11401800E+01, -.68616900E+00, -.23376500E+01, 0.41444600E-01, -.22528400E+01, -.22248500E+00, -.14226000E+00, -.10814600E+01, -.10525000E+01, -.68259100E+00, 0.13155500E+01, 0.22056400E+00, -.35777900E+00, 0.32176700E+00, -.19109300E-01, -.12768600E+01, -.13411900E+01, -.11335000E+01, -.16569600E+01, 0.58371200E+00, -.87847700E+00, -.10896300E+01, 0.13575600E+00, 0.65533800E-01, 0.15508500E+01, -.80360800E-01, 0.61252400E+00, -.92307500E-01, -.13238400E+01, -.28372100E+00, 0.15674100E+01, 0.15924300E+00, 0.11112700E+01, -.15853400E+01, -.53898100E+00, -.21281800E+00, -.34710900E+00, -.35149800E+01, 0.29987100E+00, 0.43425500E+00, -.56416700E+00, 0.55039100E+00, 0.13843600E+01, 0.37809800E+00, -.85172200E+01, -.15103700E+01, -.39776400E+00, 0.47262100E-02, -.54166400E+00, -.12003700E+00, 0.38946800E+01, 0.53528500E+00, 0.18428700E+01, -.93156500E+00, 0.95191300E+00, -.19239600E+00, 0.72942100E-01, 0.33107500E-01, 0.15476000E-02, -.12217400E+01, 0.58230900E+00, 0.54388400E+00, 0.28965700E+01, -.97938900E+00, -.34696600E+00, -.53983900E+01, -.57575300E+00, -.16009100E+00, -.11203000E+00, -.37142200E-01, 0.18574800E+00, -.19914700E+01, -.93112900E+00, 0.23146100E+01, -.41615900E+00, -.71487300E+00, 0.36032100E+01, 0.23973300E+01, 0.44001700E+01, 0.81475000E+00, -.16112400E+00, 0.20731100E+01, 0.33766000E+00, 0.16421500E+01, 0.16167700E+00, -.27047100E-01, 0.63800600E-01, -.45160600E+00, 0.10442700E+00, -.38318400E+00, -.34436100E+00, 0.10600800E+00, 0.63169300E+00, -.30128600E+01, -.16026100E+01, -.12322700E+04, 0.45276200E+02, -.18429300E+03, -.23887100E+04, -.79136500E+03, 0.38926500E+03, -.74858100E+03, 0.40035100E+03, 0.55679000E+03, -.48329900E+03, 0.17308000E+03, 0.57407700E+03, 0.14006100E+03, -.64695500E+03, 0.14454700E+03, -.10434300E+03, 0.15865700E+02, 0.13394100E+04, 0.58713300E+02, 0.36453300E+03, 0.72274600E+03, -.12872500E+04, -.20480900E+04, -.84998000E+03, 0.65192700E+03, 0.13023600E+04, 0.91531000E+03, -.47559500E+03, 0.12871200E+04, -.45105700E+03, 0.31863500E+03, 0.46577200E+03, -.11870500E+04, -.16111600E+04, -.93062200E+03, 0.47475600E+03, 0.82986400E+03, -.49886600E+03, 0.23753800E+03, -.32219400E+03, 0.25351700E+03, -.26195900E+03, 0.48517100E+02, 0.57108100E+03, 0.48365400E+03, 0.37065700E+03, 0.98165300E+02, 0.12303900E+03, -.19731200E+03, 0.11068300E+03, 0.50189700E+03, 0.10207400E+03, 0.34070700E+03, -.53130800E+02, -.15667900E+03, -.10469400E+03, 0.15415900E+03, 0.81198300E+02, -.15815400E+04, -.20532600E+04, 0.10279000E+04, 0.47558600E+03, 0.10541100E+04, 0.11582900E+04, -.38407000E+03, 0.12610200E+04, 0.27543500E+03, -.13926900E+03, -.21558600E+03, 0.48566300E+03, -.40014900E+03, 0.20115500E+03, 0.33614000E+03, 0.21897800E+03, 0.18287400E+03, -.98724500E+02, 0.66278100E+03, 0.10344600E+03, -.32818400E+03, -.10919500E+03, -.10189700E+04, 0.37044400E+03, -.18696500E+03, 0.69422200E+03, -.19434900E+03, -.36120000E+02, 0.51556400E+03, -.32367600E+03, 0.14056600E+03, -.30561800E+03, 0.35865400E+03, -.70266400E+03, -.12062800E+04, 0.61130400E+03, 0.47385700E+03, 0.60346800E+03, 0.30528000E+03, -.19491400E+02, 0.51813000E+03, -.16031500E+04, 0.32197800E+03, 0.10181200E+03, -.50299200E+03, -.21549500E+04, 0.10882000E+04, 0.32071800E+03, 0.10738200E+04, 0.59489700E+03, -.43899900E+02, 0.49377100E+03, 0.49565400E+03, 0.30499400E+03, -.26609100E+00, 0.69288500E+03, -.17773100E+04, 0.88717300E+03, 0.77091600E+02, 0.89067500E+03, 0.39779900E+03, 0.34540700E+03, -.36812500E+01, -.73864900E+03, -.24886600E+03, 0.13450600E+03, 0.58614700E+03, 0.11509500E+03, 0.45077000E+02, 0.92802000E+02, 0.31235600E+01, -.82555600E+01, -.16331200E+02, 0.90204900E+02, -.93193900E+02, -.72116700E+02, -.53566600E+02, -.53810600E+02, 0.22888200E+02, 0.14079100E+03, 0.12570200E+03, -.15450100E+03, -.45524400E+02, -.27570500E+03, -.74754100E+02, 0.98000000E+02, -.41742800E+02, 0.39195400E+02, 0.12222200E+02, 0.19581100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.45093900E+01, -.56851900E+01, 0.54319500E+01, -.38261000E+01, 0.11989000E+01, 0.13286600E+01, -.67566300E+00, -.65742600E+01, -.64020000E+02, -.43344900E+00, 0.50246600E+00, -.29839900E+01, 0.18409800E+00, 0.55591700E+00, 0.37886700E+00, 0.23115600E+01, 0.89490300E+00, 0.46869600E+01, 0.83417700E-01, -.42350700E-01, -.34172500E+01, 0.46393100E+00, 0.36885900E+01, 0.56769900E+00, -.14173400E+01, 0.83013200E-01, -.22230100E+01, 0.29897500E-01, -.10642500E+01, -.48259400E+00, -.29800300E+00, 0.12462300E+01, 0.20644000E-02, -.14594000E-01, -.79416600E+00, -.12293100E+00, -.87283900E-02, -.15317700E+01, 0.14103900E-02, -.11638100E+00, -.17474200E+01, -.30949300E+00, -.45398800E+00, 0.65426400E+00, -.55319900E-01, -.63758800E+00, -.56590400E+00, -.31212500E+00, -.13565200E+01, 0.11507600E+00, 0.55201700E+01, 0.21289200E+01, -.14877500E+01, 0.41117500E-01, 0.81342500E+00, -.17974300E+01, -.35010500E+01, 0.10560600E+01, -.30738500E+00, 0.11000300E+02, -.31911400E+01, -.19899400E+00, -.52538200E+01, 0.62093500E+00, 0.18847000E+01, -.18736700E+01, -.59691600E+01, 0.48141900E+00, 0.38452100E+00, 0.23293800E-02, 0.31227400E+00, 0.14959200E+01, -.52817900E+01, 0.24185700E+01, -.15265500E-01, -.48269600E+00, -.10126400E+01, -.15500000E+01, -.36476000E+00, 0.42779000E+00, 0.55393200E-02, -.19849600E+01, 0.14262400E+01, 0.96596600E+00, -.12246200E+01, -.20604400E+00, -.11164700E+00, -.33889800E+00, 0.81095200E+00, -.98819200E-01, 0.42048700E+01, 0.32072300E-01, -.20746300E+00, 0.15062400E+01, 0.25234200E+00, -.10918800E+01, -.12906800E+01, 0.23426800E+00, 0.99961800E+00, -.16207300E+01, 0.18435500E+01, -.65317300E+00, -.15875900E+00, 0.14695500E+01, -.27429300E+01, 0.14519500E+01, -.44410400E+00, 0.67001800E+00, 0.85896200E-01, -.72009400E+00, 0.31340300E-01, 0.15726500E+00, 0.18215800E+01, -.57676300E+00, 0.25194200E+00, -.80118400E+01, 0.12360600E+00, 0.34535000E+00, -.10137900E+04, 0.72386800E+03, -.11013000E+03, -.11787700E+04, 0.49422000E+03, 0.80329400E+03, 0.58044300E+03, 0.62027800E+03, 0.10265200E+04, 0.67575700E+03, 0.20188500E+04, 0.16629600E+04, 0.52256300E+03, 0.22567500E+04, 0.34207800E+04, -.15275700E+04, -.38614700E+03, -.17157300E+04, -.27133500E+03, 0.18941400E+03, -.70245900E+03, 0.72233400E+03, -.90428300E+03, 0.59987800E+01, -.19500200E+04, 0.26935000E+04, -.12062300E+04, -.18000700E+04, -.13519900E+04, -.27844700E+03, 0.23525800E+03, -.67578000E+03, 0.71997200E+03, -.52235600E+03, 0.16336900E+02, -.13287700E+04, -.71954400E+03, 0.38563400E+03, 0.81491000E+03, 0.35449200E+03, -.18985500E+03, -.84519600E+03, -.15614400E+03, -.14238500E+04, -.33346500E+03, -.39188500E+03, -.28452800E+03, -.35773900E+03, 0.15810500E+03, -.98187600E+03, 0.17435400E+03, 0.40798100E+03, 0.74774200E+03, 0.10288200E+03, 0.57059000E+03, 0.43679300E+03, 0.29345000E+03, 0.13821900E+04, 0.70225400E+04, -.35875800E+04, -.46692600E+04, -.35501200E+04, -.68310000E+03, 0.90108200E+02, -.91445300E+03, 0.36855200E+04, 0.22779700E+03, -.57442100E+03, 0.16186100E+03, 0.80737500E+03, -.39562100E+03, -.42522100E+03, -.40196900E+03, -.50562500E+03, -.71924700E+03, -.93230400E+03, -.13410000E+04, -.40429600E+03, -.12942800E+03, 0.24240400E+03, 0.12741000E+03, -.43467600E+02, 0.11763500E+04, -.50104500E+02, 0.12767100E+02, 0.10239700E+03, -.37803600E+03, -.55950100E+03, -.42008800E+03, 0.19950700E+03, 0.27246000E+03, 0.56575200E+04, -.28310200E+04, -.35635100E+04, -.28292900E+04, -.11394600E+04, -.93514400E+03, -.59043000E+03, 0.14115600E+04, -.26710100E+04, -.48025100E+03, -.16507400E+04, 0.30949500E+04, -.15656100E+04, -.37039000E+03, -.15427100E+04, -.38151400E+03, 0.78090200E+03, -.10994300E+04, 0.38660800E+03, -.40719800E+03, 0.35475100E+03, 0.35662700E+03, 0.17783400E+04, -.88900400E+03, 0.12841400E+04, -.89258300E+03, -.39572000E+03, -.27748100E+03, -.55280400E+02, 0.11351500E+04, 0.28755200E+03, 0.88588500E+02, -.71863200E+03, -.10209000E+03, 0.13039600E+03, 0.17701700E+02, -.83925600E+02, -.61218400E+02, -.35336600E+02, -.69052100E+02, -.16180900E+02, 0.62141400E+01, -.27958700E+02, -.26305300E+02, 0.36976100E+03, 0.41816100E+02, -.12331200E+03, 0.11077400E+03, 0.40814400E+02, 0.15079800E+04, -.12183700E+02, -.40583000E+03, 0.95921700E+02, -.59740700E+03, 0.13976600E+03, -.24977600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26863400E+00, 0.25328500E+00, 0.12229800E+00, 0.60043500E-01, 0.11549600E+00, 0.28722200E+00, 0.12289500E+00, 0.37409900E+00, -.36125100E+01, 0.39521800E+00, -.29155900E-01, -.32301500E+00, -.22864200E+00, -.19853700E-01, 0.31981700E+00, -.42327500E+00, -.80353000E+00, 0.56661200E+00, 0.22180400E+00, 0.42302800E+00, -.30426000E+00, 0.20638800E+00, -.93235500E+00, -.10057800E+00, -.17275600E-01, -.92686200E-03, -.21567800E-01, 0.42348100E-01, -.11838700E+00, -.67067800E-01, -.15193600E-01, 0.46522800E-01, -.22392100E-01, -.10745600E-01, -.76121100E-01, -.30096500E-01, 0.31575900E-02, 0.33171300E-01, 0.56535600E-01, -.66821900E-01, -.22250800E+00, 0.84103800E-01, 0.52109900E+00, 0.33604400E+00, -.53245700E-01, 0.14034000E-01, -.50304200E-01, -.32983500E-01, 0.32166000E+00, 0.34190500E-01, 0.57785800E-01, 0.15821700E-01, 0.31164300E+00, 0.43389200E-01, 0.24251200E+00, -.14988200E+00, -.13721000E-01, 0.59845200E-01, 0.10941800E+00, 0.48863800E+00, 0.12880500E+00, -.22680100E-01, 0.60695000E-01, -.15842200E+00, -.52750700E-01, -.97245700E-01, -.11073100E+01, 0.13163300E+00, 0.28507100E-01, 0.73746800E-03, -.33336700E-01, -.65212600E-01, 0.51999500E+00, -.13086000E+00, 0.99518900E-01, -.64548100E-01, 0.44075300E-01, 0.11878300E-01, 0.41500800E-01, 0.29722500E-01, -.30018800E-03, 0.15694900E+00, -.64862800E-01, 0.76844400E-01, 0.12129100E+00, -.88361800E-01, -.11654100E-01, -.66238100E+00, 0.26597900E-01, -.52140600E-02, 0.64956800E-01, 0.55073100E-03, 0.31028700E-01, -.20171200E+00, -.12343700E-01, 0.25086600E+00, 0.18492400E+00, 0.75870100E-01, 0.22064900E+00, 0.50048500E-01, -.43908800E+00, 0.16639200E+00, 0.85873400E-02, -.21281800E+00, 0.22137900E+00, 0.48726500E-01, -.19761300E-01, 0.57165600E-01, -.28964700E-01, 0.11995600E+00, -.14810200E-01, -.75578800E-01, -.15010800E-01, 0.48331100E-02, -.61616800E-01, -.11366300E+01, -.12642600E+00, -.51871000E-01, -.62508700E-01, 0.64653900E+02, -.12844000E+03, -.64755000E+02, 0.32905100E+02, 0.63096600E+02, 0.31921300E+02, 0.43729800E+02, 0.49233000E+02, 0.51393800E+01, 0.10649200E+03, 0.26721700E+02, 0.16295100E+02, 0.22080400E+03, 0.37541600E+03, -.19198800E+03, -.21786700E+03, -.18825700E+03, -.67461700E+02, -.50583000E+02, -.85845300E+02, -.97726200E+01, -.12473700E+03, -.42764400E+02, -.11634000E+03, 0.32517100E+03, -.16104400E+03, -.34684500E+03, -.16314800E+03, -.55030300E+02, -.11643500E+02, -.11187200E+03, -.24045000E+02, -.86363900E+02, -.93684400E+01, -.36550800E+02, 0.11956400E+02, -.34299900E+01, 0.98391700E+02, -.63553000E+01, -.37412600E+02, -.49853900E+02, -.32907800E+02, -.78145400E+02, -.10931400E+02, -.14084400E+02, -.26488700E+02, -.48344300E+02, 0.22177500E+02, -.72103000E+02, 0.23854400E+02, 0.49568900E+02, 0.62677500E+02, 0.11359300E+02, 0.22961300E+02, 0.30034600E+02, 0.33338600E+02, 0.74767100E+02, -.51285200E+02, 0.22993200E+02, -.62197800E+02, 0.23061500E+02, -.81911100E+02, 0.86588100E+01, 0.67894700E+02, 0.28439200E+03, 0.77384600E+02, -.67972500E+02, 0.34937800E+03, 0.62239900E+02, -.31651100E+02, -.39247200E+02, -.30869900E+02, 0.75720600E+01, 0.15420600E+02, -.47640400E+02, -.60880400E+02, -.42313600E+02, 0.29446600E+02, -.50969200E+02, -.61183000E+01, 0.35941500E+01, 0.28848400E+02, 0.39133100E+01, 0.68211100E+00, -.22433100E+02, -.29149700E+02, -.41711600E+02, -.33428100E+02, -.32423800E+01, 0.36196800E+02, 0.57032900E+02, -.29088200E+02, -.12881400E+03, -.28549600E+02, -.11011900E+03, -.12285800E+03, 0.84682500E+02, 0.16198100E+03, 0.52253600E+02, -.86176800E+02, -.25266700E+02, 0.49707900E+03, -.24981800E+03, -.10919800E+03, -.24820100E+03, -.50782400E+02, 0.55745700E+02, -.15025900E+03, 0.44024000E+02, -.17909900E+03, 0.20752000E+02, -.64970000E+02, 0.28384400E+03, -.14181000E+03, 0.42545900E+02, -.14211200E+03, -.51105400E+02, -.10595300E+02, -.62064300E+02, 0.61789200E+02, -.92584000E+02, 0.10654800E+02, -.94850500E+02, -.98242900E+01, 0.88200300E+01, -.57057100E+01, -.85113700E+01, -.79174600E+01, -.26929200E+01, -.68465600E+01, 0.59518200E+01, 0.39018600E+01, 0.47204800E+00, 0.41277600E+00, -.30999100E+02, -.10650400E+02, -.11469200E+02, 0.52506200E+01, -.35308600E+01, 0.11055400E+03, 0.12931400E+01, -.95445500E+01, 0.12923600E+02, -.20117500E+02, -.52400300E+01, -.15530700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12900800E+01, -.33966500E+01, 0.15323900E+00, -.23403500E+01, -.38738300E+00, 0.10378000E+01, -.11223400E+01, -.78041400E-01, 0.83973400E+01, -.15291900E+01, 0.78475300E-01, 0.12375000E+01, 0.55928700E+00, 0.24110800E-01, -.68280600E+00, 0.90286900E+00, 0.35429400E+01, 0.13404300E+01, -.28857100E+00, -.50180900E+00, 0.90105200E-01, 0.43514500E-01, 0.27975700E+01, 0.88454800E+00, 0.24085400E+00, 0.13018600E-01, 0.56577200E+00, 0.35336000E-01, -.11536900E+00, -.20516800E+00, -.54544300E+00, 0.57301000E+00, -.85200000E-01, 0.92716400E-01, -.27962600E+00, -.63295100E-01, 0.20806200E-02, 0.30134800E+00, 0.95316600E+00, -.63417300E+00, 0.34651600E+00, 0.55231300E-01, -.86246600E+00, -.50069500E+00, 0.10271200E+00, 0.40958400E-01, -.42956500E+00, 0.21646600E+00, 0.39031500E-01, -.24078300E+00, 0.17593000E+01, 0.56244200E+00, -.84845200E+00, 0.27177100E+00, -.10644700E+01, -.27800300E+01, -.12465300E+00, -.30436200E-01, 0.12373200E-01, -.20469300E+01, 0.19566000E+00, 0.10294700E+00, -.19884800E+00, 0.52211300E+00, 0.97402200E+00, -.58146600E+00, -.99058600E-01, 0.32459100E-01, 0.29923600E-01, 0.10828400E-02, -.38257100E+00, 0.40785400E-01, -.17044400E+01, 0.63700800E+00, 0.46619800E+00, 0.14083300E+00, 0.95730400E+00, -.14216000E+01, 0.16266900E+00, 0.30133300E-01, 0.39488900E-03, -.13272600E+00, 0.51947100E+00, 0.77647400E+00, -.50012000E+00, -.11613400E+01, 0.31954500E-01, -.19070100E+00, 0.73506200E+00, 0.84989800E-01, -.27200100E+00, -.20963600E-01, -.10623500E+00, 0.55556300E+00, 0.46926500E+00, -.46360100E+00, -.47890700E+00, -.56342100E+00, 0.84877700E-01, 0.93807600E+00, 0.11692100E+00, -.10265800E+00, 0.15146200E-01, 0.49988900E+00, -.12402300E+01, 0.96926400E+00, -.24099300E+00, 0.56153900E+00, 0.26255200E-01, 0.76875500E-01, -.62199300E-01, -.12460300E+00, 0.89828900E+00, -.28601200E+00, 0.34526500E+00, 0.28758800E+01, 0.11474400E+01, -.42270800E-01, 0.28587500E+00, 0.24284600E+00, 0.10458800E+04, -.15129700E+03, 0.68297400E+02, -.18063800E+03, 0.77150700E+02, -.29799500E+02, -.12359200E+03, -.19156200E+03, -.25091800E+03, 0.46137100E+03, -.30940300E+03, -.30348200E+03, -.23453000E+04, 0.11878000E+04, 0.98329300E+03, 0.11769700E+04, 0.24822700E+03, 0.20507600E+03, 0.78336700E+03, 0.40738700E+03, 0.74962500E+03, 0.18046900E+03, 0.60793800E+03, -.22156500E+04, 0.11061400E+04, 0.13639900E+04, 0.11122100E+04, 0.22235100E+03, 0.68528900E+02, 0.86178800E+03, 0.31779400E+03, 0.53683200E+03, 0.88428600E+02, 0.35421900E+03, -.23196900E+03, 0.10717000E+03, -.75477400E+00, 0.11805500E+03, 0.86348100E+02, 0.35859300E+02, -.14581700E+03, -.24492500E+03, -.15274900E+03, 0.77540700E+02, 0.27408000E+03, 0.40887900E+03, -.19918500E+03, -.57041500E+02, -.20273900E+03, 0.92125500E+02, -.18923700E+03, 0.11316600E+03, 0.52450300E+03, 0.26902600E+03, -.19555100E+03, -.52751800E+03, 0.18247500E+04, -.90633600E+03, -.57420700E+02, -.89946000E+03, -.10905900E+03, -.11070500E+03, -.99999000E+03, -.35112500E+03, -.39045400E+03, -.13056200E+03, -.16641600E+04, -.12610700E+03, 0.64408000E+02, 0.31802000E+03, 0.60670100E+02, 0.65183700E+02, 0.80746200E+02, -.47510400E+02, 0.19417200E+03, 0.40781100E+01, 0.85165500E+02, 0.54824500E+03, -.11333900E+03, 0.57106500E+02, -.91301600E+02, 0.52590800E+02, 0.79697000E+02, 0.67021800E+02, 0.12260100E+03, 0.19304200E+03, 0.13787500E+03, 0.78087100E+01, 0.13593800E+03, 0.11720900E+04, -.58280600E+03, 0.11255900E+03, -.58591000E+03, -.18793000E+03, 0.12120000E+03, -.39254300E+03, -.43680100E+02, -.57234200E+03, 0.29260900E+03, -.38256600E+02, 0.20792900E+02, -.53527200E+01, -.11645300E+03, -.12235400E+02, 0.71850800E+02, -.19957700E+03, 0.17893600E+03, 0.17628700E+03, 0.24227200E+03, -.18757100E+03, -.56751400E+03, -.14268200E+02, 0.69636000E+01, -.13694300E+03, 0.79269600E+01, -.13072600E+02, -.12921200E+03, 0.83042400E+02, -.30168400E+02, 0.19570800E+03, -.99324900E+02, -.65090000E+02, -.22487500E+02, -.10324000E+03, -.55446700E+02, 0.30056300E+02, 0.23893900E+02, -.87175300E+00, -.13297600E+02, 0.55667500E+02, 0.10852700E+02, -.82934500E+01, -.56996900E+01, -.42871400E+01, 0.13987500E+03, -.10572400E+01, 0.22910300E+02, -.10213600E+02, -.10212400E+03, 0.80686200E+02, -.51662300E+02, -.25725300E+02, -.13216800E+03, -.47508000E+02, 0.99295900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22953800E+01, 0.12724100E+01, -.53020400E+00, -.12991300E+00, 0.66413900E+00, 0.26854800E+01, -.50585500E+00, -.13624500E+00, 0.56028100E+01, 0.17024700E+01, -.14433100E-01, 0.38638100E-01, 0.10502700E+01, -.31511500E+00, -.41004100E+00, 0.19487700E+00, 0.30226900E+01, 0.23348400E+00, -.59362800E-01, -.35449600E+00, 0.97535000E+00, 0.14865600E+00, 0.19228000E+01, 0.53853800E+00, -.19675000E+01, 0.85511900E-01, -.25964400E+01, -.13939600E+00, 0.49988200E+00, -.56566000E+00, -.42268500E+00, -.49137600E-01, -.23202200E+00, -.16189700E+00, -.46233500E+00, -.35471600E-01, 0.85032000E-02, 0.75734500E+00, 0.53092800E+00, -.37485400E+00, 0.22803300E+01, -.41551200E+00, -.10210000E+01, -.10983600E+01, 0.22919500E+00, 0.19671300E+00, -.13513900E+01, 0.21291200E-02, 0.75642200E+00, -.60622800E+00, 0.59823700E+01, -.36089600E+00, -.43754300E+00, 0.40364800E+00, -.11958800E+01, -.38844000E+01, -.13675700E+01, 0.63066600E-01, 0.31799900E+00, -.16981500E+01, 0.20076100E-01, 0.14768200E+00, -.19815100E+01, 0.64200200E+00, 0.20824500E+01, -.11885000E-01, -.76614700E+01, -.12164700E+01, 0.19457300E+00, -.12375600E-03, -.19305500E+00, 0.32503400E+00, -.35195200E+01, 0.24241100E+01, -.20095100E+01, -.87271900E+00, -.38545600E+00, -.90673500E+00, -.27807100E+00, -.73606100E-01, 0.61983800E-03, -.49578400E+00, -.37179400E-01, -.61256400E-01, 0.11711200E+01, 0.85303900E+00, 0.24948300E-01, 0.30695600E+01, -.75071100E+00, 0.61542700E-01, 0.10573000E+01, 0.63190200E-03, 0.79151800E-01, -.19746700E+00, 0.22107300E+00, -.86085600E+00, 0.12723200E+01, 0.71311900E+00, -.87547000E+00, -.94066400E+00, -.34137400E+01, 0.96530600E+00, -.94284900E-01, -.60722500E-01, 0.11249500E+01, 0.46684000E-01, -.49019200E+00, 0.11531100E+01, -.45935800E+00, -.24604800E+00, 0.52976100E-01, -.42770700E-01, 0.58923500E+00, -.18405200E+00, -.65074200E-01, -.44300500E+01, 0.62107200E+00, -.56577100E+00, -.19118500E+00, 0.19313700E+01, -.84779700E+00, -.20213000E+04, 0.92927700E+03, 0.17118900E+03, 0.10068600E+04, -.24424600E+03, -.32293800E+03, 0.78802700E+03, -.12585900E+03, 0.15556500E+03, -.32976000E+03, 0.12651400E+04, 0.12708100E+04, -.36863900E+03, 0.57761600E+03, -.63187000E+03, -.35239100E+02, 0.66045300E+03, -.24728500E+03, 0.41167200E+03, -.52168300E+03, 0.38639900E+03, -.39860400E+03, 0.10752900E+04, -.40733800E+03, 0.34229600E+03, -.53388000E+03, -.52931600E+02, 0.46058600E+03, -.22697200E+02, 0.62403800E+03, -.30706100E+03, 0.24022700E+03, -.13450700E+03, -.22279900E+03, 0.81320900E+02, 0.15965100E+03, 0.11120500E+03, 0.33074900E+03, 0.20794800E+03, -.11668600E+03, -.54767100E+03, -.87707900E+02, 0.14655300E+03, -.18471500E+03, 0.72400900E+03, -.34441300E+03, -.34332700E+03, -.36228800E+03, -.41011300E+03, -.25297700E+02, -.13309200E+03, 0.31456300E+03, 0.10028400E+03, -.87182000E+02, -.60791300E+03, -.22813600E+03, 0.90333200E+02, 0.17908800E+03, 0.10867200E+03, 0.10126100E+04, 0.43921000E+03, -.93219800E+03, -.25209600E+04, -.17940700E+04, 0.64593700E+03, -.13954300E+03, -.38966600E+03, 0.20417900E+03, 0.71515100E+03, 0.19655000E+03, -.19404000E+03, -.67929900E+02, 0.13036500E+03, -.30817100E+03, -.26389300E+03, 0.58142200E+02, 0.10808100E+03, 0.56497600E+03, -.25856600E+03, 0.29183500E+03, -.27981900E+03, -.26848700E+03, -.10862100E+01, 0.12215600E+03, 0.31927900E+03, -.11161400E+03, -.16222200E+03, -.64907000E+03, 0.11243200E+04, -.56667500E+03, -.45596200E+03, -.56230400E+03, 0.89675500E+03, 0.64616400E+02, -.76270300E+03, -.10714900E+04, -.84431800E+03, 0.31536800E+03, -.84235000E+03, -.12076900E+04, 0.61261200E+03, 0.49226900E+03, 0.60407200E+03, -.19440000E+03, 0.25348500E+03, 0.15637900E+03, -.22343000E+03, 0.26388300E+03, 0.11421000E+03, 0.93682900E+03, -.13135000E+04, 0.65790700E+03, 0.22582900E+03, 0.65567300E+03, 0.14939000E+03, 0.21422300E+03, 0.12628500E+03, -.57588200E+03, -.13990600E+03, 0.11934200E+03, 0.93375200E+03, -.37874000E+01, 0.14066100E+01, -.36946800E+02, -.42442600E+02, 0.92973700E+02, 0.87347600E+02, -.62184000E+01, 0.37226100E+02, 0.55361200E+02, 0.52858800E+02, 0.57546300E+02, 0.51772100E+02, -.11212200E+03, 0.36673800E+02, -.42431000E+02, 0.10804800E+03, 0.35169000E+03, 0.35224200E+02, -.82814200E+02, 0.14004400E+02, -.33464600E+02, -.67852300E+01, 0.46882100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.29810400E+00, -.94141600E-01, 0.13032800E-01, 0.90801700E+00, 0.45258900E+00, -.21372500E+00, 0.15177500E+00, 0.13312000E+01, 0.92431700E+01, -.16231500E-01, -.93327300E-01, 0.21888000E-01, -.33265900E-01, -.14073600E+00, 0.19113300E+00, -.17900000E+00, -.77073900E+00, 0.95666100E+00, 0.31153300E+00, 0.38226000E+00, 0.36064800E+00, 0.38119700E+00, -.17910000E+01, 0.55213700E+00, 0.21734700E-01, 0.20383400E-01, -.27700600E+00, -.89396400E-01, 0.18113000E+00, -.21663200E+00, -.36141000E+00, -.34711300E+00, 0.19006000E-01, 0.99503100E-01, 0.50968100E-01, 0.41417500E-01, -.82545200E-02, -.56574900E-01, 0.21950800E+00, -.68854000E-01, -.59761000E-01, 0.32209100E-02, -.31193600E+00, -.63333400E-01, 0.63767700E-02, -.22565000E-01, -.25147700E+00, -.73124300E-01, 0.36671900E+00, -.55918200E-01, 0.22011600E+00, -.32198000E+00, 0.19126800E+00, -.49729500E+00, 0.26814700E+00, -.57312600E-01, 0.48849400E+00, 0.45897200E-01, 0.90176100E-03, 0.17084100E+01, -.37072000E+00, 0.36878700E-03, -.18239400E+00, -.11272300E+00, -.41697800E+00, -.17924000E+00, 0.16974500E+01, 0.31687300E-03, -.18998000E-01, -.46772900E-03, 0.12484700E-01, -.97164800E-01, 0.36009700E+00, 0.12427400E+00, -.88737900E-01, -.13452900E+00, 0.25410500E+00, 0.32924700E+00, -.39409800E-01, -.10923800E+00, -.91413800E-04, 0.72126300E+00, 0.76171800E-02, -.32672800E+00, -.10394200E+00, -.41119200E+00, -.86853000E-01, 0.65255200E-01, -.11284500E+00, 0.57293300E-01, -.81544600E+00, 0.11634700E-01, 0.21846600E-01, -.19943200E+00, 0.94271900E-01, 0.11785300E+00, 0.28699000E+00, -.12479500E+00, -.24532600E+00, 0.41787400E+00, 0.29167700E+00, 0.59537200E-01, -.27813900E-01, 0.37095100E+00, -.16541800E+00, -.39559200E-01, -.20035400E-01, -.23668600E+00, -.42910100E-01, 0.13106600E+00, 0.28056400E-01, -.40995300E-01, 0.57757000E-01, -.18583500E-01, -.55477300E-01, -.39106300E+00, -.10165200E+00, 0.73483100E-01, 0.35452400E-01, 0.34600300E+00, 0.23210800E+00, -.22236500E+00, -.14600700E+02, 0.15587700E+03, -.24938700E-01, -.66590500E+02, 0.62372500E+02, -.35407400E+02, -.22919800E+03, -.19209600E+03, 0.83117100E+02, 0.21478400E+02, 0.83494100E+03, -.36037400E+03, -.48451400E+03, -.41885200E+03, -.15385200E+03, -.25235800E+02, -.17068400E+03, 0.33542400E+02, -.27476000E+03, -.71157900E+02, -.93688800E+02, 0.68417900E+03, -.31331000E+03, -.60681400E+03, -.34355400E+03, -.11555700E+03, 0.25953300E+02, -.17349500E+03, 0.73730200E+01, -.18918200E+03, -.28967700E+02, 0.51895300E+02, -.20345200E+03, 0.95642500E+02, 0.92709900E+02, 0.10118300E+03, 0.84685500E+02, 0.14146900E+02, 0.68462300E+01, -.20764200E+02, 0.35408700E+02, -.18181800E+02, 0.17182200E+03, 0.29521700E+03, -.14337500E+03, -.13163500E+03, -.14804900E+03, -.45517700E+02, -.14888300E+02, -.36236600E+02, 0.12664600E+03, 0.14101300E+01, -.34016400E+02, -.24434900E+03, -.17181200E+03, 0.82314300E+02, 0.22890200E+03, 0.82867300E+02, -.14958800E+03, 0.80221800E+01, -.13706300E+03, -.50995300E+03, -.25578700E+03, 0.11800300E+03, -.32098700E+01, -.89866900E+02, 0.46511700E+02, 0.34762300E+02, 0.44317600E+02, 0.62777400E+02, -.26924500E+02, 0.47172500E+02, 0.19962600E+02, -.19429400E+02, 0.36611700E+02, -.55504400E+02, -.12245400E+03, 0.67238100E+02, 0.20167000E+02, 0.62057300E+02, -.90647500E+02, -.16044800E+03, 0.10559200E+03, 0.10613100E+03, 0.74995200E+02, -.18203300E+03, -.55963100E+02, 0.14003600E+03, -.72370700E+02, 0.72217500E+02, -.70047500E+02, -.66667200E+02, -.68382700E+02, -.11671300E+03, -.17976500E+03, -.10479300E+03, 0.14628900E+02, -.82535300E+02, -.50692000E+02, 0.26365300E+02, 0.41318200E+02, 0.25827800E+02, -.33258000E+02, 0.32981400E+02, 0.22627700E+02, 0.53880400E+02, -.28612300E+02, 0.35099800E+01, 0.13190300E+03, -.29801500E+02, 0.15261100E+02, 0.21536000E+02, 0.14812700E+02, 0.95512500E+01, 0.42273600E+02, -.13885900E+02, -.23181800E+02, -.97547500E+02, 0.27177300E+02, 0.14776300E+03, -.55407500E+01, 0.20280800E+01, -.13283900E+02, -.26828500E+01, 0.27421300E+02, 0.36983000E+02, -.53980100E+01, 0.13260500E+02, 0.10684100E+02, 0.18138900E+02, 0.13375900E+02, 0.97061700E+00, -.37883500E+02, 0.12028100E+02, -.28978000E+02, 0.22954500E+02, 0.10427200E+03, 0.24586500E+02, -.59669900E+01, 0.15180200E+02, -.28593700E+02, -.14971100E+02, 0.35459900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20099700E+01, 0.34612200E+01, 0.62431700E+00, 0.15947400E+01, 0.50934600E+00, -.10660100E+01, 0.64678000E+00, 0.25286200E+01, -.17142500E+02, 0.41015800E-01, -.86365600E+00, -.18828300E+01, -.20196200E+00, 0.37644800E-02, 0.12819400E+01, -.29860900E+01, -.28351000E+00, 0.20136600E+01, 0.31495400E+00, 0.22254900E+01, -.81041500E+00, 0.15876900E+00, 0.86678500E+00, 0.12012100E+01, -.82970400E+00, 0.77201500E-01, 0.64255300E+00, 0.26029300E+00, -.29363500E-01, -.51510500E+00, -.42680600E+00, -.18833800E+00, 0.70673800E+00, -.64640600E+00, -.54490100E+00, 0.23473000E+00, -.25747400E-01, 0.80713700E-01, -.28951500E+00, -.19570300E+00, 0.57020300E+00, 0.48923100E+00, 0.73068200E+00, 0.89748100E+00, 0.38964400E-01, -.98643800E-01, -.13935300E-01, -.16184100E+00, 0.74017600E+00, 0.71199400E+00, -.10256400E+01, -.41990700E+00, 0.23133600E+00, -.20251300E+00, 0.63156900E+00, 0.12299800E+01, 0.13960800E+01, -.14303000E+00, 0.13775300E+00, 0.10022400E+01, -.18584700E+00, 0.78654300E-01, 0.12350600E+01, -.23826800E+00, -.51552800E+00, 0.52487900E+00, 0.98950900E-01, -.62014500E+00, -.16882000E+00, -.26597500E-02, 0.16670800E+00, -.80825900E+00, 0.40879200E+01, -.22795800E+01, 0.24195200E+01, 0.22200000E+00, 0.77245800E+00, -.30622400E+00, -.19689600E-01, -.10165000E-01, -.69179500E-03, -.86242200E+00, 0.59778800E+00, 0.30892600E+00, -.18770500E+01, -.19985100E+01, -.25155200E+00, 0.48367900E+00, -.30068500E+00, 0.10726700E+00, -.34476800E+01, -.52597700E-01, -.31196200E-01, -.17897800E+00, 0.44203500E+00, 0.27127200E+00, -.52074900E+00, 0.10350800E+00, 0.72049600E+00, 0.13365200E+00, -.18996400E+01, 0.62262800E+00, 0.89892600E-01, -.92283100E+00, 0.59821200E+00, 0.20500400E+01, 0.71156000E+00, -.34249400E-01, 0.65683700E-01, 0.32184800E+00, 0.25929300E+00, -.22681800E+00, 0.64450700E+00, -.20534300E+00, -.22863000E+00, 0.19788700E+00, 0.80542400E-01, -.25605200E+00, -.12913000E-02, 0.15495500E+00, -.44955700E+00, -.25852500E+00, 0.38233800E+01, -.85616100E+03, 0.60040800E+00, 0.43602500E+03, -.17667000E+03, -.14276700E+03, 0.64381100E+03, 0.70143100E+03, -.46860900E+03, -.10592500E+03, -.43027900E+04, 0.21117600E+04, 0.24975000E+04, 0.21608200E+04, 0.72275300E+03, 0.41873300E+03, 0.12165600E+04, 0.44616900E+03, 0.13632900E+04, 0.50846200E+03, 0.42581800E+03, -.39336900E+04, 0.19368900E+04, 0.31980100E+04, 0.19767100E+04, 0.56306600E+03, 0.10652600E+03, 0.13550100E+04, 0.56410400E+03, 0.10882300E+04, 0.27230900E+03, -.60795200E+02, 0.67824700E+03, -.33446200E+03, -.43253300E+03, -.33539200E+03, -.33723700E+03, -.58458800E+02, -.15324400E+03, -.15134400E+03, -.30730300E+03, 0.12946200E+03, -.66421000E+03, -.92346600E+03, 0.45658500E+03, 0.68054300E+03, 0.46475600E+03, 0.41942500E+03, -.86793900E+02, 0.26400900E+03, -.43283800E+02, 0.38687300E+03, 0.22785400E+02, -.19411600E+03, 0.32624100E+04, -.16296000E+04, -.11897600E+04, -.16100300E+04, 0.61756500E+03, 0.27710700E+03, -.80228500E+03, 0.11848600E+04, -.47647200E+03, -.14937000E+03, -.15828100E+04, -.62042400E+02, 0.34348500E+02, 0.49656400E+03, 0.31219200E+02, -.23019700E+03, 0.22233800E+03, -.22941900E+03, -.26085700E+03, -.15263400E+03, 0.17984300E+02, 0.59936600E+03, 0.90013100E+03, -.45883300E+03, -.20151300E+03, -.45606900E+03, 0.33257200E+03, 0.73213100E+03, -.38366400E+03, -.99298800E+02, -.35529400E+03, 0.71436000E+03, -.82292300E+02, 0.14608800E+04, -.71748200E+03, -.42702300E+03, -.73024300E+03, -.19574400E+03, 0.47806800E+03, -.24811600E+03, 0.26618300E+03, -.55768100E+03, 0.30452600E+03, -.39939100E+03, -.60108200E+03, 0.30079100E+03, -.10330900E+03, 0.29723600E+03, 0.32425600E+03, -.15877700E+03, 0.25198100E+03, -.54982700E+02, 0.40808300E+03, -.98990300E+02, -.41144800E+03, -.87028300E+03, 0.43378200E+03, 0.13371200E+02, 0.43591400E+03, 0.14989400E+03, -.12583700E+03, 0.18756700E+03, -.25884100E+03, 0.50952100E+03, -.89378800E+02, -.26937300E+03, 0.23582600E+02, -.99465600E+02, 0.19171900E+02, 0.10567100E+02, -.72747000E+02, -.12597400E+03, 0.22446500E+02, -.18265400E+02, -.11331300E+02, -.55957100E+02, -.34460200E+02, 0.45881900E+02, 0.29553200E+03, -.65327100E+02, 0.14507000E+03, -.82995200E+02, -.47842700E+03, -.11943100E+02, -.34490700E+02, -.67614700E+02, -.52309400E+02, 0.22627500E+01, 0.98201500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.28064600E+01, 0.46152300E+01, -.47356600E+00, 0.47849400E+00, -.33223900E+01, -.11351800E+01, 0.39287400E+00, -.12661800E+01, -.42524600E+02, 0.13003100E+01, 0.30695500E+00, 0.61369500E+00, -.10670700E+01, 0.29214000E+00, 0.13107400E+01, -.44619300E+01, 0.45572200E+00, -.28820800E+01, -.54534400E+00, 0.35230500E+01, -.21595200E+01, -.75481500E+00, -.31266300E+00, -.15765600E+01, -.95236900E+00, 0.39163600E+00, 0.51814600E+01, 0.10423500E+01, -.14240700E+00, 0.55318400E+00, 0.93181900E+00, 0.39592000E+00, -.30957900E+00, 0.14651700E+00, 0.59441400E+00, -.55039900E-01, -.12559200E-01, 0.11482600E+01, -.40589100E+00, 0.27648400E+00, -.67308500E+00, -.53216200E+00, -.19210900E+00, -.77115200E+00, -.95821700E-01, -.64341200E-02, 0.23925400E+00, -.23942200E+00, 0.11874900E+01, 0.80167700E-01, -.78555600E+00, -.42910100E+00, 0.16101600E+01, 0.51594400E+00, 0.12014000E+00, -.17664300E+00, -.33459000E+00, -.41467100E-01, -.93411700E+00, -.36320100E+01, -.22464100E+01, 0.36055100E+00, 0.16615400E+00, 0.52728700E+00, 0.12748900E-01, 0.45071300E+00, -.49647100E+01, -.61469600E+00, -.49841600E+00, 0.43748400E-02, -.54358300E+00, -.84839700E+00, 0.30816200E+01, -.15557300E+01, 0.16964600E+01, -.24553700E-01, 0.16795100E+00, 0.15187000E+00, -.16232200E+00, 0.11531000E+00, 0.26424400E-03, -.17656400E+01, 0.61955600E+00, 0.10399200E+01, 0.73777700E+00, -.30457800E+01, -.44407800E+00, 0.45264600E+01, -.22128500E+00, 0.66502200E-01, -.16455300E+01, -.51494100E-01, -.17526600E+00, -.10753200E+01, 0.24820800E+00, 0.14928800E+01, -.43333000E+00, -.74271800E+00, 0.76835900E+00, 0.31649000E+01, 0.14175500E+01, 0.11545500E+01, -.39209300E-01, 0.15028100E+01, -.14595400E+01, 0.12529300E+01, 0.92294200E-01, 0.87802800E-01, -.25754400E+00, -.26069200E+00, 0.24101000E+00, 0.96204600E-02, 0.29535500E+00, -.96820200E-01, 0.25508700E+00, -.47072800E+01, -.50767900E+00, 0.35809100E+00, 0.67031800E-01, 0.69211000E+00, -.26208500E+00, 0.10734700E+00, 0.12455900E+01, 0.11507400E+00, 0.35137500E+02, 0.20898400E+03, -.13505500E+03, -.20238700E+03, 0.40313900E+02, 0.18762600E+03, -.78640800E+02, -.27484100E+03, -.13424000E+04, 0.65724200E+03, 0.21874300E+03, 0.67102800E+03, 0.32396800E+03, 0.12548800E+03, 0.13687300E+03, -.37328500E+03, 0.24807400E+03, 0.19681700E+03, 0.20669900E+03, -.10234200E+04, 0.51071900E+03, 0.60989300E+03, 0.51141000E+03, 0.28262200E+03, 0.80700400E+02, 0.99629800E+02, -.36484500E+03, -.23929800E+02, 0.16942100E+03, -.96151000E+02, 0.61350700E+03, -.29726800E+03, -.34399800E+03, -.30483000E+03, -.16958100E+03, 0.58177000E+01, -.70539700E+02, 0.10210200E+03, -.10721400E+03, 0.31583800E+02, -.35803300E+03, -.42500300E+03, 0.19920800E+03, 0.33674100E+03, 0.21421600E+03, -.27592800E+01, -.11747100E+02, 0.87953800E+02, -.11759900E+03, -.67439400E+01, 0.13936600E+02, 0.79559600E+03, -.12205700E+04, 0.60239200E+03, 0.13380900E+03, 0.62663400E+03, -.13749600E+03, -.30733500E+03, 0.54099800E+03, 0.90259500E+03, 0.12772200E+04, -.43849300E+03, 0.66888100E+03, 0.41199400E+03, -.20312600E+03, -.49686100E+03, -.23951900E+03, 0.67609800E+02, 0.12303500E+03, -.12704600E+03, 0.11938200E+03, 0.14485500E+03, -.25891500E+01, -.11748900E+03, -.50203700E+01, -.19136800E+01, -.34589200E+03, -.36038800E+01, 0.15926300E+03, 0.12521300E+03, -.15940600E+03, -.32592100E+03, -.17234700E+03, 0.22397000E+03, 0.30646800E+03, -.98633500E+03, 0.50034800E+03, 0.57320300E+02, 0.49343300E+03, -.97796200E+02, -.29713800E+02, 0.47129600E+03, 0.47785800E+03, 0.43852600E+03, -.17616300E+03, 0.52484300E+03, 0.67034300E+03, -.33920800E+03, -.44783300E+03, -.33693900E+03, -.30162500E+02, -.22280400E+03, -.14881000E+03, -.56699000E+02, -.12906400E+03, -.10031200E+03, -.34087100E+03, 0.90158300E+03, -.45094400E+03, -.52476400E+03, -.44904900E+03, -.65796000E+02, -.18722600E+03, 0.28007600E+02, 0.48500500E+03, 0.23725700E+03, -.12884700E+03, -.61195400E+03, -.53903400E+01, 0.33795000E+01, 0.20649400E+02, 0.16342900E+02, -.68843300E+02, -.86031100E+02, -.21207500E+01, -.20396400E+02, -.27543700E+02, -.39163200E+02, -.33751900E+02, -.74011500E+02, 0.46364800E+02, -.30356700E+02, 0.44433100E+02, -.53359200E+02, -.30737000E+03, -.26990000E+02, 0.54624600E+02, -.14524100E+02, 0.77494300E+02, 0.65487900E+01, -.30022700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15092800E+01, 0.19621500E+00, -.26445100E+00, 0.78557400E-01, 0.40746700E-01, 0.39212500E+00, 0.48379900E-01, 0.29689200E+00, -.31548800E+01, 0.18367000E+00, -.50201700E-01, -.80653600E+00, 0.42664900E-01, -.26916100E+00, 0.27056800E+00, -.12704200E+01, -.18536500E+01, -.37507400E+00, 0.39258800E-01, 0.86970800E+00, -.79581100E+00, 0.38214700E+00, -.21188100E+01, 0.34657800E-01, 0.14716400E+00, -.49712700E-02, 0.28035800E+00, 0.63884600E-01, -.10832500E+00, -.79662900E-01, -.27670300E+00, -.13629400E+00, 0.16526300E-02, 0.10778100E+00, 0.20207200E+00, 0.13894300E+00, -.35237700E-03, 0.24584400E-01, -.31142800E+00, -.40326500E-01, -.39273600E+00, -.45516100E-01, -.47977900E+00, -.13518000E+00, 0.93212800E-01, 0.87376900E-01, -.47364300E-01, 0.79298800E-01, 0.84527200E-02, -.14547000E+00, -.18223300E+01, -.41167100E+00, -.21685400E+00, -.21462500E+00, -.26160400E+00, 0.61749500E+00, 0.10745300E+01, 0.10177900E+00, 0.30992800E+00, -.43489000E+00, 0.63110900E+00, -.14362800E-01, -.22644600E+00, -.16915800E+00, 0.72785300E+00, 0.19542200E+00, -.20141100E+01, -.15024500E+00, 0.29723900E+00, -.10387800E-02, 0.13837200E+00, -.11108600E+00, 0.13853300E+00, -.16759700E+00, 0.76141400E-01, 0.31432700E+00, -.23438500E+00, 0.30391900E+00, -.54072100E-01, -.39663600E-01, 0.58275600E-03, 0.53794600E+00, -.16778500E+00, -.20284000E+00, -.30278800E-01, 0.50313800E+00, 0.84786500E-01, -.77567400E-01, -.23860100E+00, 0.11514100E+00, 0.49189200E+00, 0.30087300E-01, -.12900200E+00, 0.38047000E+00, 0.69138900E-01, 0.45501300E-01, -.59917500E+00, -.61920000E-01, -.72357800E-01, 0.10921400E+01, -.62232500E+00, -.11741900E+00, 0.81157800E-02, -.92200300E-01, -.23969600E+00, -.37714900E+00, -.10787400E+00, 0.84619600E-01, -.26702600E+00, 0.38490600E-01, 0.30898700E-01, 0.95394500E-01, -.24127300E+00, 0.76618400E-01, -.12153300E+00, 0.15660300E+01, -.30915500E+00, 0.71271200E-01, -.99588800E-01, -.67100900E-02, 0.29500000E+00, 0.18407700E+00, -.43788500E+00, -.29080100E+00, -.13660500E-01, 0.31362300E+03, 0.30135500E+03, -.24544600E+03, -.63253000E+01, -.10180500E+03, 0.20892800E+03, -.19190100E+03, -.50478500E+03, 0.25227300E+03, 0.38961100E+03, 0.25243500E+03, -.20905900E+01, -.11888400E+03, 0.22788600E+03, 0.13923200E+03, 0.27212900E+03, -.51804300E+02, -.18538800E+03, -.59722000E+03, 0.29302400E+03, 0.42730800E+03, 0.29868400E+03, -.34082200E+02, -.15866900E+03, 0.25769800E+03, 0.14426200E+03, 0.36953900E+03, -.96123800E+02, -.21700200E+03, 0.18762300E+03, -.91350700E+02, -.22115900E+03, -.93930600E+02, -.12124500E+03, -.55609700E+02, 0.20265600E+02, 0.21384300E+03, 0.28463900E+02, -.39547100E+02, -.20715400E+03, -.28282800E+03, 0.13819100E+03, 0.82053100E+02, 0.14130800E+03, 0.18650100E+03, -.32947900E+02, 0.82247800E+02, 0.10125800E+02, 0.27214500E+03, -.12177700E+02, 0.38931400E+02, 0.57431900E+03, -.28409200E+03, -.16095000E+03, -.28824200E+03, 0.16601900E+03, 0.31499300E+03, -.72509100E+02, 0.24419000E+03, -.46646800E+03, 0.21797200E+03, -.40200800E+03, -.12155000E+03, 0.62319300E+02, 0.59438300E+02, 0.59683300E+02, -.90045300E+02, -.17305800E+02, -.46460600E+01, -.27566400E+03, -.22392400E+03, 0.18899800E+01, 0.16056300E+03, 0.36433000E+03, -.18379500E+03, 0.41321900E+01, -.18172500E+03, 0.19959400E+02, 0.10585700E+03, -.16425800E+03, -.13216800E+02, -.66092200E+02, 0.11079100E+03, -.11965200E+03, 0.32200000E+03, -.15849600E+03, -.24908800E+02, -.16101700E+03, -.19846700E+03, 0.18807600E+03, 0.21530100E+02, -.16552700E+02, -.17721000E+03, 0.13055700E+03, -.49378000E+02, -.18185300E+03, 0.88121400E+02, -.62177600E+02, 0.91034600E+02, 0.25045200E+03, 0.68855100E+02, 0.96587400E+01, -.80950400E+02, -.10217500E+03, 0.53563200E+02, -.97048200E+02, -.49604800E+03, 0.24755300E+03, 0.25812100E+03, 0.24788200E+03, 0.12160900E+03, 0.68426700E+02, -.47509600E+01, -.15579500E+03, -.22149400E+02, 0.36202700E+02, 0.49097400E+02, 0.18512600E+02, -.53293800E+01, 0.50732200E+02, -.13423600E+02, -.31575300E+01, -.11280900E+02, 0.14169300E+02, -.50153200E+02, -.13209900E+02, -.21140600E+02, -.11903800E+02, 0.13642100E+02, 0.37308500E+02, -.16727400E+02, 0.43295000E+02, -.35531800E+02, -.14281700E+03, 0.37779700E+01, -.30038300E+02, -.84259400E+01, -.20518600E+02, 0.95045700E+00, 0.10231600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.52576900E+00, -.16635900E+01, 0.64961000E-02, -.10694300E+01, 0.35226700E+00, 0.54745800E+00, -.65820600E-01, -.62881000E+00, 0.36087700E+01, 0.62162600E+00, -.38003600E-01, 0.59793000E-01, -.58427500E-01, 0.23813100E+00, -.30940900E+00, 0.53848200E+00, 0.78972800E+00, -.40521900E+00, 0.55385300E-01, -.98333500E+00, 0.86535100E+00, -.36844400E+00, 0.51362900E+01, 0.83586800E-01, -.15571900E+01, 0.26771300E-01, -.21027900E+01, -.31868500E-01, -.43036000E+00, 0.12711800E-01, 0.61296600E+00, 0.60691600E+00, 0.39257400E-02, -.26895100E+00, -.48209200E+00, -.18030900E+00, 0.88181800E-02, -.55414000E-01, 0.10214800E+00, 0.26633000E+00, -.17685700E+00, -.55163100E-01, 0.28844800E-01, -.10624300E+00, -.15600700E+00, -.40962300E-01, 0.55001500E+00, -.67357800E-01, 0.15001200E-01, 0.20151300E+00, -.37712300E+00, 0.33471000E+00, 0.10451800E+01, 0.27564300E+00, 0.68246700E+00, 0.59742000E+00, 0.62974900E+00, 0.17101700E+00, 0.73518600E-01, -.35428100E+00, 0.24140500E+00, -.26729200E-01, -.13164300E+00, -.56469900E+00, -.97483000E+00, 0.15564100E+00, 0.20675200E+01, 0.58592400E+00, -.27539700E+00, 0.17318200E-02, -.27253600E+00, 0.64308900E-01, 0.30960700E+01, -.86935300E+00, 0.32115200E+00, 0.54103500E+00, 0.74161800E-01, 0.16059300E+00, -.19411000E+00, 0.44914500E-02, 0.16798300E-03, -.10682600E+01, -.49489300E+00, 0.69130100E+00, 0.54429700E+00, -.26316900E+00, -.79131000E-01, 0.14259100E+01, -.37130200E+00, 0.12904900E+00, 0.63534800E+00, 0.39144100E-02, -.12648700E+00, -.45299400E+00, 0.17764700E+00, 0.52174400E+00, -.42629500E+00, 0.16788200E-01, -.12067100E+00, 0.13291800E+01, -.57907000E-01, 0.35912300E+00, -.16677900E-01, -.12148900E+00, 0.14777700E+00, -.42583900E-01, 0.12097700E+00, -.16956900E+00, -.45892400E-01, -.32578300E-01, -.79768900E-01, -.16684800E+00, -.96495000E-01, 0.31016200E-01, -.23283400E-01, 0.78324500E+00, 0.50555900E+00, -.52278900E-01, -.19907600E-01, -.68068700E+00, -.18219000E+00, -.13620900E+00, 0.14669700E+01, 0.30575600E+00, -.47174000E-01, 0.12825300E+00, -.16614000E+03, 0.23920200E+03, 0.41717700E+03, 0.18195200E+03, -.15183700E+03, 0.17781200E+03, -.34887800E+03, 0.15523500E+03, 0.28779300E+03, 0.17492400E+03, 0.10802000E+03, 0.12614200E+03, -.54320000E+02, -.13420200E+03, 0.34625500E+02, 0.92265500E+02, 0.24335700E+02, -.24408500E+03, 0.12015500E+03, 0.27195800E+03, 0.12261300E+03, 0.11253000E+03, 0.13850900E+03, -.71630800E+02, -.89973000E+02, -.43297500E+02, 0.10288000E+03, -.38754000E+02, 0.10626200E+03, -.46215100E+02, -.34649100E+02, -.53443300E+02, -.17018000E+02, -.11356100E+02, 0.13107000E+02, -.31594400E+02, 0.12520600E+02, -.42301200E+00, -.18589700E+03, -.27773900E+03, 0.13148600E+03, 0.37464100E+02, 0.13857900E+03, -.87955700E+02, 0.10909900E+03, -.50360200E+02, -.24655000E+03, -.11816900E+03, 0.91960100E+02, 0.64923400E+03, -.66749300E+03, 0.32435100E+03, -.24262500E+03, 0.33054300E+03, 0.85140800E+02, -.24030100E+03, 0.49915800E+03, 0.64318200E+03, 0.62362200E+03, -.24806100E+03, 0.76470200E+03, 0.23396900E+03, -.11833200E+03, -.25394200E+03, -.11599600E+03, -.28323200E+02, 0.61316200E+01, -.78440000E+02, -.80840200E+01, 0.49582700E+02, -.34141100E+02, 0.17654000E+02, -.76846600E+02, 0.37242300E+02, 0.74700200E+02, 0.39753900E+02, 0.41734900E+02, 0.57867400E+02, -.56804000E+02, -.19449800E+03, -.53835400E+02, 0.83104800E+02, 0.18646900E+03, -.71655400E+03, 0.35830900E+03, -.60924500E+02, 0.35822000E+03, 0.17297300E+03, -.79274200E+02, 0.26870700E+03, 0.22147200E+03, 0.27126300E+03, -.87445700E+02, 0.33319600E+03, 0.43132300E+03, -.21727400E+03, -.10816000E+03, -.21537100E+03, -.10341400E+03, 0.42308800E+02, -.18950800E+03, -.91235200E+02, -.16846900E+03, 0.56890900E+02, 0.70336800E+02, 0.56307700E+03, -.28139400E+03, -.80462400E+02, -.28198200E+03, -.28316800E+02, -.38538600E+02, -.15013900E+02, 0.31723000E+03, -.19696900E+02, -.21218800E+02, -.26084700E+03, -.55203800E+01, 0.48097300E+02, 0.31673800E+02, -.37177200E+01, -.19947900E+02, -.15551900E+02, -.37217900E+01, -.31573700E+02, -.14657800E+02, -.18378000E+02, -.17168400E+02, -.25353400E+02, -.27432800E+02, -.11972500E+02, 0.57268800E+01, -.97095700E+01, 0.38794100E+02, -.36537600E+02, 0.70239400E+01, 0.18155700E+01, 0.45878900E+02, 0.35575400E+02, -.62874500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42204700E+01, -.23211900E+01, -.45633100E+00, 0.34890200E+00, 0.23895700E+01, 0.20963800E+01, -.69516300E+00, 0.23929100E+01, 0.62045400E+02, -.48957000E+00, -.31666300E+00, -.26067200E+00, 0.81049300E+00, -.10655300E+00, -.22854700E+01, 0.13817000E+01, -.26990600E+01, -.36480400E+01, 0.54774200E-01, -.26652700E+01, 0.54004900E+01, 0.58322600E+00, -.34807200E+01, -.12298100E+00, -.93808700E+00, -.34332700E+00, -.48089200E+01, -.11039700E+01, 0.88682600E-01, -.70228900E-01, -.16420600E+01, -.98123800E+00, 0.19040600E+00, 0.65108000E+00, 0.10428500E+01, 0.53666900E+00, -.15491300E-01, -.47706300E+00, -.74593500E+00, -.87607200E+00, 0.76572200E+00, 0.16048000E+00, -.10545900E+01, -.14820300E+00, 0.25793100E+00, 0.18247400E+00, -.21786900E+01, 0.77140900E-01, 0.32755400E-01, -.59517200E+00, 0.50070400E+01, -.69345900E+00, -.23272900E+01, -.22509500E+00, -.11808600E+01, -.71181900E+00, -.92036400E+00, -.55365000E+00, 0.36353500E+00, -.40957700E+00, 0.15115700E+01, -.12742200E+00, -.13752000E+01, 0.65355000E+00, 0.81102700E+00, -.20498100E-01, -.43827800E+01, -.14745600E+01, 0.29308700E+00, -.62150700E-02, 0.33210800E+00, 0.11864700E+01, -.20963900E+01, 0.40106800E+01, -.96877600E+00, -.15016000E+01, -.36171900E+00, -.82550200E+00, 0.95135700E-01, -.76618800E-01, -.95116800E-03, 0.24477000E+00, 0.50285200E+00, -.69204400E+00, -.37667400E+00, 0.21307800E+01, 0.17270100E+00, -.14164000E+01, -.61126300E+00, -.56721800E+00, -.24558800E+01, -.68216800E-02, 0.35359700E+00, 0.20398500E+01, -.61467800E+00, -.15123600E+01, -.62112000E+00, 0.21493800E+00, -.57239300E+00, -.27082500E+01, -.23663600E+01, -.67997100E+00, 0.13091100E+00, -.48033000E+00, -.26615500E+00, 0.63662100E+00, 0.28349800E+00, 0.34233900E+00, 0.58488800E+00, 0.39288800E+00, -.23667100E+00, -.59783600E+00, 0.51373900E+00, -.16487800E+00, 0.34398600E-02, 0.88296400E+01, 0.21787800E+01, -.26538700E+00, 0.27803900E+00, -.14785000E+01, 0.86080300E+00, -.22947100E+00, -.62655500E+00, -.19028800E+00, 0.11264300E+00, -.68160200E+00, -.21242000E+01, 0.59986600E+03, 0.14963700E+04, 0.33200800E+03, -.91924000E+02, 0.56127200E+03, 0.98563000E+02, -.73119600E+02, 0.50160400E+03, -.46943700E+02, -.83977000E+02, 0.18478600E+02, -.85951400E+02, 0.62795600E+00, 0.85699000E+02, -.10006000E+03, -.79203700E+01, -.20748400E+03, 0.97599700E+02, 0.42416500E+03, 0.10612400E+03, -.15905700E+02, 0.11916100E+03, -.52939400E+02, 0.69767000E+02, 0.19418700E+03, -.26907100E+02, 0.21789200E+03, -.33510500E+03, 0.17665600E+03, 0.32721800E+03, 0.16843100E+03, 0.55003600E+02, -.15488000E+03, 0.11669200E+03, -.26424400E+03, 0.50974900E+02, -.64468800E+02, -.10397700E+03, -.55370200E+03, 0.27955700E+03, 0.56247200E+02, 0.27755600E+03, -.11534600E+03, 0.26034900E+03, -.18734900E+03, -.61635600E+03, -.16057000E+03, 0.24395300E+03, 0.33292500E+03, 0.48904300E+03, -.25656400E+03, -.10009500E+04, -.23956100E+03, 0.53094200E+03, 0.13798500E+03, 0.15459100E+03, 0.11358800E+04, -.13481100E+03, 0.13185000E+03, 0.79539200E+03, -.92876800E+02, 0.42451600E+02, 0.81836800E+02, 0.88003300E+02, -.22397600E+03, 0.13508400E+02, -.20807000E+03, -.43591100E+03, -.13159200E+03, -.65174400E+01, 0.40582200E+03, 0.30919400E+03, -.15537200E+03, 0.16565000E+03, -.15606400E+03, -.14851800E+03, -.67895000E+02, 0.36897100E+01, -.50536500E+02, -.17751500E+02, -.88478200E+02, -.11580900E+03, -.35640500E+03, 0.17465700E+03, -.42694800E+03, 0.17824100E+03, 0.39113400E+03, -.65361900E+02, 0.17525500E+03, 0.98562500E+02, 0.94214200E+02, -.28022100E+02, 0.43894700E+03, -.44425200E+03, 0.21951700E+03, 0.30802800E+03, 0.22135300E+03, 0.31525500E+01, 0.23967300E+03, -.17490900E+03, -.21308000E+03, 0.61290700E+02, 0.20980000E+03, 0.59302800E+03, -.49899500E+03, 0.24981400E+03, 0.45071900E+03, 0.27973600E+03, 0.14489300E+03, 0.10484000E+03, 0.81292700E+02, 0.15516900E+03, 0.40342400E+02, 0.76502100E+02, 0.28111300E+03, -.28806600E+01, 0.67040400E+02, 0.49906700E+02, -.18208000E+02, 0.67368500E+02, 0.86222900E+02, -.45547400E+01, -.49847100E+02, -.92656700E+01, -.18740600E+02, -.58026600E+01, 0.39085300E+02, -.92997300E+02, 0.46749700E+02, -.64114300E+02, 0.29325900E+02, 0.30150500E+03, -.78204700E+02, -.52744500E+02, -.33952100E+01, 0.44429400E+02, 0.81022200E+02, -.67896900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11485700E+01, -.23353800E+00, -.56038100E+00, 0.17256900E+00, 0.85580900E+00, 0.53066700E+00, -.97736500E-01, -.81182400E+00, -.10822600E+02, 0.10108600E+01, -.57553900E-02, -.78192700E+00, 0.13991800E+00, 0.19846800E-01, -.17479700E+00, 0.29301400E-01, 0.45856800E+00, -.92560900E-01, -.20189900E-01, -.19136200E+00, -.19273300E+00, -.23297700E+00, 0.49277200E+00, -.56009800E-01, 0.25454800E-01, -.46001000E-02, -.20022600E+00, -.29074300E-01, 0.23523300E+00, 0.23431800E-01, -.11546200E+00, 0.34593500E-01, -.51800100E-01, 0.15909700E-02, -.19030600E+00, -.11078600E+00, 0.40129400E-02, 0.11965000E-02, 0.57092900E+00, -.77466200E-01, -.50245900E-01, 0.12648300E+00, 0.12538000E+01, 0.67378000E+00, 0.10762200E-01, 0.72672800E-02, 0.15113600E+00, -.51153000E-01, 0.22386300E+00, 0.13239300E+00, -.39948400E+00, -.18918900E+00, 0.22178600E+01, -.17222200E+00, 0.48124800E+00, -.10330100E+01, -.31201000E+00, 0.13988600E+00, -.16228100E+00, 0.13045300E+01, -.14027400E+00, -.63702800E-01, -.41791200E-01, -.19149100E+00, -.63322600E+00, 0.46933600E+00, -.66813900E+00, 0.66846700E-01, -.60501200E-01, 0.34307100E-03, 0.28081500E-02, -.65366800E+00, -.13876900E+01, 0.59200400E+00, -.88230000E+00, -.36205300E+00, -.30139100E+00, 0.95873000E-01, -.18312800E-01, -.37785100E-01, -.34650600E-03, 0.25285900E+00, -.80740700E-01, -.20045600E+00, -.12928500E+00, 0.17077600E+00, -.40953000E-01, -.77643600E-01, -.11253800E+00, -.98334900E-01, -.52875300E+00, 0.95939600E-02, 0.10419000E+00, 0.27493600E-01, -.13831500E+00, -.15844800E+00, 0.36039300E+00, -.42816700E-01, -.85550200E+00, -.47547000E+00, -.12551600E+00, -.11407500E+00, 0.87693500E-02, -.19507600E+00, 0.41287800E+00, -.49736300E-03, 0.20095600E+00, -.19865700E+00, 0.11052800E+00, 0.98609000E-01, 0.83964000E-01, 0.99117100E-01, -.34381000E+00, 0.10936700E+00, -.19082600E+00, -.78237400E+00, -.22373000E+00, -.17791600E-02, -.64979900E-01, 0.67796000E-01, -.41581400E+00, 0.11791400E+00, -.12988900E+01, -.17523700E+00, 0.39911100E-01, 0.11495300E+00, -.62443300E+00, 0.11223700E+00, -.33289800E+03, -.90187400E+02, -.16535900E+02, 0.86205600E+02, 0.34515500E+03, -.17763400E+03, -.30688500E+03, -.17292000E+03, -.13583300E+03, -.79886000E+02, -.57613100E+02, -.65102200E+02, -.13783300E+03, -.97914000E+02, 0.15207800E+03, 0.38512000E+03, -.19298100E+03, -.40210300E+03, -.19294300E+03, -.10207900E+03, -.12587100E+02, -.10231200E+03, -.90900400E+02, -.14299100E+03, -.41882600E+02, 0.19293400E+03, -.53400000E+02, 0.25086800E+02, -.10249500E+03, 0.26699100E+02, 0.59972500E+02, 0.51541900E+02, -.83818900E+02, -.11837500E+03, -.72684500E+02, 0.36251100E+02, 0.12331300E+03, 0.27597500E+03, -.13585400E+03, -.11476500E+02, -.13797800E+03, 0.13964500E+02, -.14387900E+02, 0.21839000E+01, 0.21523700E+03, 0.28207200E+02, -.40266800E+02, -.18038100E+03, 0.94844700E+03, -.47476500E+03, -.11455000E+03, -.47383400E+03, -.29513500E+03, -.70550800E+02, -.42131500E+03, -.69158400E+03, -.56840900E+03, 0.50694700E+02, -.46541400E+03, 0.80105300E+00, -.19278800E+01, 0.14674900E+02, -.48562200E+01, 0.51292500E+02, -.57916200E+02, 0.82586500E+02, 0.14616300E+03, 0.61831100E+01, -.49179100E+01, -.49699500E+02, -.17801300E+03, 0.90560900E+02, 0.52753400E+02, 0.88771900E+02, -.74496700E+02, -.17149100E+03, 0.19193600E+03, 0.18152000E+03, 0.13510000E+03, -.18478100E+03, 0.11588900E+02, 0.65184000E+03, -.32730400E+03, -.17698400E+01, -.32591000E+03, -.28613400E+03, -.29023400E+01, -.36627400E+03, -.28493300E+03, -.34476300E+03, 0.11135600E+03, -.38766200E+03, -.17517100E+03, 0.89563800E+02, -.81314000E+00, 0.87582900E+02, -.40336700E+01, -.82639000E+01, 0.11471900E+03, 0.10402200E+03, 0.66442800E+02, -.34503200E+02, 0.15471700E+03, 0.12805200E+03, -.63900200E+02, -.12487100E+03, -.67285400E+02, -.26987500E+02, -.97952400E+01, 0.14082100E+02, 0.59860100E+02, -.58025600E+02, -.70667800E+01, 0.80289800E+02, -.13402400E+02, -.77165900E+01, -.20629400E+02, 0.11340500E+01, 0.24847900E+02, 0.26212600E+02, -.11397700E+02, 0.20849500E+02, 0.90352700E+01, 0.15393300E+02, 0.83725400E+01, 0.14537800E+02, 0.34290500E+02, 0.15528300E+02, -.25408500E+02, 0.98908900E+01, 0.64914200E+02, 0.46673500E+02, -.12994200E+02, 0.11302100E+02, -.78160900E+02, -.16353600E+02, 0.11049800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23142700E+01, -.12873700E+01, -.88356200E+00, 0.14150700E+00, 0.65682300E+00, 0.21104700E+00, -.28925000E+00, -.19771000E+01, -.14712500E+02, 0.81266900E+00, -.48297300E-01, -.24943100E+01, -.38517400E+00, 0.41972500E+00, -.11388500E+01, -.35457800E+00, -.19840200E+01, -.31595400E+01, -.30414100E+00, -.64388600E+00, 0.16844600E+01, 0.12013900E+00, -.35686500E+00, -.48203900E+00, -.45668400E-01, -.32597900E-01, 0.27047700E+00, -.68854800E-01, -.20080500E+00, 0.14052300E+00, -.36201900E-01, -.31013100E+00, -.77372200E-01, -.12219000E+00, 0.46937400E-01, -.25033600E-02, 0.37061300E-02, 0.57669900E+00, 0.15591600E+00, 0.49680600E+00, 0.46345300E+00, -.33949500E+00, -.75064600E+00, -.98557600E+00, 0.19244800E+00, 0.12175100E+00, 0.11743500E+00, 0.14132100E+00, -.28722200E+00, -.37993300E+00, 0.15482900E+01, -.29441900E+00, -.79460600E-01, -.77090000E+00, -.55111200E+00, 0.39137800E+00, -.11472900E+01, -.12423700E-02, 0.52177000E+00, 0.38424300E+01, 0.44024700E-01, 0.45832400E-01, -.13380000E+00, -.29872500E+00, -.43046700E+00, -.15867200E+00, 0.17968100E+01, 0.21109900E+00, -.41589600E-01, 0.98674400E-03, -.21660900E+00, -.14587000E+00, 0.17619600E+01, -.10544600E+01, 0.33721600E+00, 0.43327800E+00, -.27700900E+00, -.40079500E+00, -.15856600E-01, -.11077800E+00, 0.20435700E-02, -.65957900E+00, 0.33391300E+00, -.88381200E+00, 0.22181000E+00, 0.47024300E+00, -.12777700E-01, -.64435200E+00, 0.35774300E+00, 0.84249300E-01, -.10418200E+01, -.17508200E-01, 0.63854100E-01, 0.59665100E-01, 0.24152600E-01, -.18379900E+00, 0.12729300E+00, -.18854200E+00, -.27156500E+00, -.15235800E+00, -.35176900E+00, 0.80417200E-01, 0.19647200E-01, 0.12066700E+00, 0.34029400E+00, 0.61504900E-01, 0.11582000E+00, -.12155400E+00, 0.29810600E-01, 0.36579300E-01, -.63189000E-02, -.48168000E-02, -.39424900E-01, 0.12134100E-01, 0.63939800E-01, 0.19970800E+01, 0.19537200E+00, 0.36204200E-01, 0.43041700E-01, -.13417800E+01, -.23253500E+00, 0.11662700E+00, -.13102000E+00, 0.13959600E-02, 0.28989800E-01, -.14388800E+00, -.50658600E+00, 0.76888700E-01, -.99431000E-01, 0.20564800E+03, -.66429300E+02, 0.54090100E+02, -.63017100E+03, 0.31487500E+03, 0.35310800E+03, 0.31600700E+03, 0.78531800E+02, -.11978400E+01, 0.20944900E+03, 0.18946200E+03, 0.29610900E+03, -.95174500E+01, 0.69849900E+02, -.61981200E+03, 0.30760100E+03, 0.38296400E+03, 0.31084000E+03, 0.63994000E+02, -.31841100E+02, 0.23898300E+03, 0.14919600E+03, 0.22009600E+03, -.26740600E+02, -.16623800E+02, -.18568800E+02, 0.84503600E+01, -.77246100E+01, 0.96485000E+01, 0.47252200E+01, -.60083100E+02, 0.16986500E+02, -.73270100E+02, -.68883300E+02, -.68055700E+02, -.15699100E+03, -.21505100E+01, -.31314200E+01, -.55814400E+02, 0.13686900E+01, 0.44138000E+02, -.44221600E+02, 0.60569800E+02, 0.17665200E+03, 0.18540300E+03, -.37450800E+02, 0.17208300E+03, 0.48913200E+03, -.24065400E+03, -.22052800E+03, -.24245100E+03, 0.23483800E+02, -.85585500E+02, 0.45730600E+01, 0.25164600E+03, 0.20372100E+03, -.16365600E+03, -.16698200E+03, -.11014600E+03, 0.56060200E+02, 0.47764000E+02, 0.53495800E+02, -.39027300E+01, 0.21266100E+02, -.43522800E+02, -.32611900E+02, 0.46904600E+02, -.10128600E+02, 0.30795300E+03, 0.11233400E+03, -.57666900E+02, -.20984200E+02, -.56809500E+02, 0.40289500E+02, 0.75484200E+01, -.20216700E+02, 0.33085800E+02, -.38863500E+01, -.93057300E+01, 0.77465200E+02, 0.37915300E+03, -.18751000E+03, -.10393800E+03, -.18955900E+03, -.12031100E+02, -.51997700E+02, 0.53542700E+02, 0.23045100E+03, -.11766600E+03, -.33002900E+02, -.24026600E+03, -.13501400E+03, 0.67739100E+02, 0.77537500E+02, 0.67186200E+02, 0.84411100E+02, -.14109600E+02, 0.35231500E+02, -.10472900E+03, 0.11597800E+03, -.30615500E+01, -.13837800E+03, -.32174400E+03, 0.16094400E+03, 0.10150200E+03, 0.15833900E+03, 0.30756600E+02, -.40880700E+02, 0.88069000E+02, -.77671500E+02, 0.24116000E+03, -.14714100E+02, -.10287600E+03, 0.12050700E+02, -.17663700E+02, 0.20745000E+02, 0.12859200E+01, -.65785900E+01, -.12568400E+02, 0.10961200E+02, -.21096200E+02, 0.10253000E+01, -.13002600E+02, -.83222800E+01, 0.35507700E+02, 0.42219100E+02, -.10733000E+02, 0.21025900E+02, 0.61913100E+01, -.75573000E+02, 0.84453300E+00, 0.97742700E+00, -.40351700E+00, -.48154300E+02, 0.17429500E+02, 0.13537600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.96479600E+00, 0.31404900E+00, -.20204500E+00, -.15392100E+01, 0.25517400E+00, 0.50839500E+00, -.22745800E+00, -.14765900E+01, -.16715500E+02, 0.30534100E+00, 0.11729500E+00, -.87712900E-01, 0.27373000E+00, 0.14765900E+00, -.69037400E+00, 0.11874600E+01, 0.15206500E+01, 0.27211100E+00, -.19315500E+00, -.29231900E+00, -.58581900E+00, -.27120200E+00, -.11585000E+00, -.51130200E+00, 0.72113800E-01, 0.32889600E-01, 0.48561300E+00, 0.60352600E-01, 0.43617800E+00, -.35643300E+00, -.25986900E+00, 0.12925600E+00, 0.97610700E-02, -.20361600E+00, -.68623700E+00, -.14297800E+00, 0.37978300E-02, 0.55040700E-01, 0.80797000E+00, -.13481700E-01, 0.71002100E-01, 0.65923600E-01, -.64121900E+00, -.44065800E-01, -.31593300E-01, 0.37559900E-01, 0.29137300E+00, 0.57142500E-01, -.29640300E+00, 0.13109700E+00, -.27937200E+01, -.28169700E+00, 0.30980600E-01, 0.52027000E+00, 0.19165900E+00, -.12547200E+01, 0.65796900E+00, -.73112600E-01, -.21785400E+00, -.17414800E+01, -.36334100E-01, -.10726300E-01, 0.38903500E+00, 0.40377000E-01, -.37411200E+00, 0.34140200E-01, 0.10457300E+00, -.30427800E+00, -.10061300E+00, -.91970700E-03, 0.37599000E-01, -.33881100E+00, 0.15739700E+01, 0.75517100E+00, 0.10905100E+01, -.38996100E+00, 0.56972200E+00, -.20524200E+00, -.83181500E-03, 0.23009300E-01, -.94370200E-04, -.11775800E+00, 0.15742800E+00, 0.44107400E+00, 0.66772600E+00, -.60985700E+00, -.10255500E+00, 0.29702300E-01, 0.37435900E-01, -.31629600E-01, -.65343600E-01, -.12564300E-01, 0.26116800E+00, -.30254200E+00, -.26349700E+00, 0.88599300E+00, -.47332000E+00, -.58031600E+00, 0.11261300E+00, 0.69505400E+00, 0.15582800E+00, 0.29860600E+00, 0.42289500E-01, -.76575500E+00, 0.21899200E-01, 0.25560500E+00, -.13582500E+00, 0.15583100E+00, 0.18215000E+00, -.28545400E+00, -.14183200E+00, 0.99612100E-01, -.53734100E-01, 0.16761900E-01, 0.29505800E+00, 0.31569600E+01, 0.75953800E+00, 0.23321000E+00, 0.12524100E+00, -.36733300E+00, 0.16176500E+00, -.15758000E-01, 0.60494600E+00, 0.15096100E+00, -.12289300E-01, 0.52293400E+00, 0.74129700E+00, -.17323700E+00, 0.95283600E-02, 0.48490500E+00, 0.12083000E+03, -.14938500E+03, 0.10057800E+04, -.51669500E+03, -.80586700E+03, -.50315800E+03, -.18104800E+02, 0.54683800E+02, -.51920000E+03, -.66964300E+03, -.54464000E+03, 0.33498800E+02, 0.17337100E+03, 0.10358500E+04, -.51949100E+03, -.60203100E+03, -.51822300E+03, 0.22015800E+02, 0.12222500E+03, -.55860700E+03, -.64929900E+03, -.60014300E+03, 0.92839600E+02, 0.17710900E+03, 0.17150100E+03, -.82870400E+02, -.58533400E+02, -.85526500E+02, 0.28583800E+01, 0.94330700E+02, -.75998700E+02, -.42576500E+02, -.40833100E+02, 0.90228900E+02, 0.28135900E+03, 0.65624900E+02, -.27081100E+02, -.74194400E+01, -.32605000E+02, -.97115100E+02, 0.52274400E+01, -.43656500E+02, -.37098000E+02, -.19381200E+03, -.23555000E+01, -.51460500E+00, -.56489600E+03, 0.27394600E+03, 0.78982700E+02, 0.28461100E+03, -.18964900E+03, -.13078800E+03, 0.26234400E+02, -.27256700E+03, 0.30677300E+03, -.31191700E+02, 0.41995000E+03, 0.11531600E+03, -.60623800E+02, -.13287500E+03, -.53195200E+02, 0.59672200E+02, 0.80127500E+01, 0.94184600E+01, 0.60327000E+02, 0.10327900E+03, 0.43944600E+01, -.43428800E+03, -.29390000E+03, 0.14798600E+03, -.27072000E+03, 0.14609700E+03, -.42756800E+02, -.13686600E+03, 0.66953000E+02, -.11893100E+03, 0.98639300E+02, -.10307000E+03, 0.36839000E+02, -.82423700E+03, 0.40926000E+03, 0.49644300E+02, 0.41215700E+03, -.28968000E+02, -.12769500E+03, 0.97938100E+02, -.28041100E+03, 0.23108500E+03, -.17091300E+03, 0.69017800E+03, 0.17748900E+03, -.87231800E+02, -.29852900E+02, -.88953600E+02, -.20145400E+03, -.13184500E+03, -.10323300E+02, 0.14658900E+03, 0.49783200E+02, -.78678200E+02, 0.15112100E+03, 0.33968600E+03, -.16982300E+03, -.13200500E+03, -.16306600E+03, -.90296300E+02, -.27846500E+02, -.43568100E+02, 0.38462000E+02, -.22404300E+02, -.21310500E+02, 0.84491100E+02, -.12021700E+02, 0.11224000E+02, -.39776000E+02, 0.14323800E+02, 0.88751800E+01, 0.13982200E+02, -.11716700E+02, 0.39729100E+02, -.22537800E+01, 0.76858400E+01, 0.40458400E+01, -.17130200E+02, -.14533100E+02, 0.52147100E+02, -.75867600E+02, -.18471000E+01, -.14527500E+02, -.14674600E+02, 0.33755100E+02, -.25273300E+01, 0.58038600E+02, -.38682600E+01, -.14311900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.58129600E+00, 0.23628900E+01, 0.24494700E+00, 0.13640900E+01, -.28036200E+00, -.10903300E+01, 0.48547100E-01, 0.11496100E+01, 0.53197600E+01, 0.12324400E+00, -.89289000E-01, -.11735700E+00, -.30655000E+00, 0.33463500E-01, 0.44617700E-01, -.41791800E+00, -.10586500E+01, -.94913400E+00, 0.39060900E-01, -.82544000E-01, 0.60073200E+00, 0.42348500E-01, -.70976300E+00, -.56088300E+00, -.38825300E+00, -.16362400E-02, 0.16784700E-01, 0.23325500E-01, -.26746100E+00, 0.29777200E-02, 0.34807400E-01, -.15235200E+00, 0.11601500E+00, -.50361400E-03, 0.11509000E+00, 0.14024500E+00, -.27206100E-02, -.84635200E-01, -.62226800E+00, 0.34024400E-01, -.16978200E+00, -.34852700E-01, -.18241300E+00, -.69817100E-01, 0.39387700E-01, 0.57689100E-01, -.14355600E+00, -.58058300E-01, 0.14053200E+00, -.97041500E-01, 0.42668100E+00, -.34931700E+00, -.54900900E-01, -.41077500E+00, 0.13313600E+00, 0.69474000E+00, -.27092300E+00, -.30496200E-01, 0.14986300E+00, 0.33711200E+00, 0.35089500E+00, -.11398000E+00, 0.61449100E-01, -.37261100E+00, -.56740800E+00, 0.37143300E+00, -.27667000E+01, -.50432900E-01, 0.89318300E-01, -.79002000E-05, 0.19035300E+00, 0.52851400E-01, 0.14050900E+01, 0.86494700E+00, -.12057100E+00, -.34560100E+00, -.68065600E+00, 0.16664100E+00, -.16117100E+00, 0.27334800E-01, 0.12613700E-02, -.28312500E+00, -.94810400E-01, -.29399600E+00, -.94681300E+00, 0.31538600E+00, -.80238700E-01, -.11583200E+01, -.20789300E+00, 0.12764200E+00, -.62102800E+00, 0.23400200E-01, -.48547700E-02, -.35498500E+00, -.85772300E-01, 0.63807500E+00, 0.11096100E+00, 0.40036800E+00, 0.88375600E+00, 0.12819500E+01, 0.10865600E+01, 0.22355200E+00, -.62713700E-01, 0.70722700E+00, 0.15590700E-01, 0.20692800E-01, 0.11229600E-01, -.31075000E+00, 0.22428900E-01, -.13035800E-01, 0.87568100E-01, 0.62653800E-01, -.27739300E+00, 0.87559400E-01, 0.37893100E-01, 0.62006400E+00, -.25807800E+00, 0.14363000E+00, -.13548500E+00, -.12674100E+00, -.13796000E+00, -.31127300E-01, 0.77725900E+00, 0.10144600E+00, -.14870900E-01, 0.48800200E-01, 0.21068100E+00, 0.63658700E-01, 0.32064800E+00, -.16820400E-01, -.27216100E+00, -.23629000E+03, 0.10149600E+03, -.68791000E+02, 0.19152300E+03, -.50731900E+02, 0.11512300E+03, 0.10100500E+03, -.12595900E+03, -.69576600E+02, -.52526900E+02, 0.10140200E+03, -.19824000E+03, 0.13406700E+03, -.72471300E+02, 0.98178300E+02, -.66990400E+02, 0.76875300E+02, 0.24470500E+02, -.88274500E+02, -.57968500E+02, -.38259700E+02, 0.38542300E+02, -.26553800E+03, 0.83205500E+02, -.38519300E+02, -.16176700E+02, -.41586900E+02, -.43225500E+02, -.12747100E+02, -.64707800E+00, 0.11020300E+03, 0.28108600E+01, -.35603300E+02, -.41047800E+02, -.16757100E+03, 0.80199800E+02, -.11504900E+03, 0.83800300E+02, 0.23926500E+02, -.26642100E+02, 0.67077800E+02, -.28320200E+01, 0.10079600E+03, -.37445800E+01, 0.12326800E+03, -.19475800E+03, 0.93937800E+02, 0.74341000E+02, 0.97452300E+02, 0.15725400E+03, -.26951400E+02, 0.20830500E+03, 0.43276100E+03, 0.19832700E+03, -.69823600E+02, -.42778200E+01, -.81898300E+02, 0.40676000E+02, 0.11246600E+03, 0.39871800E+02, -.35236900E+02, -.13479400E+02, 0.10937100E+02, -.68196600E+02, -.52929800E+02, -.71212200E+01, 0.40184900E+02, 0.20538300E+03, -.10455500E+03, 0.81630500E+02, -.10268100E+03, 0.42232900E+02, 0.12704000E+03, -.14832600E+03, -.89401500E+02, -.10545000E+03, 0.11238500E+03, -.69252000E+02, -.10223300E+03, 0.51850900E+02, 0.61588800E+02, 0.51119700E+02, 0.14990400E+03, -.20679700E+02, 0.17385300E+03, 0.34612600E+03, 0.15842000E+03, -.71515300E+02, 0.20669500E+03, 0.17440300E+03, -.87207900E+02, 0.49049500E+02, -.87217100E+02, -.11737600E+02, 0.49716500E+02, -.81692400E+02, -.73636700E+02, -.12479800E+03, 0.35522100E+02, -.13462000E+03, 0.10232400E+03, -.51461900E+02, 0.21079100E+03, -.50284000E+02, -.12179900E+02, 0.36329500E+02, -.84046200E+02, -.68141000E+02, -.12091200E+03, 0.24889300E+02, -.13862300E+03, 0.63272200E+01, 0.13051600E+02, 0.24872600E+02, 0.15672700E+00, -.19334500E+02, -.19402100E+02, 0.69640400E+01, -.24889200E+02, -.13004500E+02, -.13608700E+02, -.11861500E+02, 0.12764300E+02, -.81735600E+01, -.54132900E+00, 0.80581800E+01, -.19347500E+02, -.84206900E+02, -.53671100E+01, -.76398600E+01, -.63764100E+01, 0.36394400E+01, 0.16813400E+02, -.17185100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20380800E+00, -.44903500E+00, -.19251000E-01, -.20687300E+00, 0.15641900E+00, 0.39169100E+00, -.31749000E-01, -.35037300E+00, -.18525300E+01, 0.40574700E+00, 0.16716200E-02, 0.40238400E-01, 0.43069500E-01, -.37058500E-01, 0.11855700E+00, 0.93146100E-01, 0.10461000E+00, 0.11668600E+00, -.47884100E-02, 0.45399100E-01, 0.21117500E-02, -.15578200E-01, 0.24364100E+00, 0.28054000E-01, -.44880200E-01, 0.21162900E-03, -.80483600E-01, -.10756400E-01, -.34946900E-02, -.89636700E-02, 0.43750100E-02, 0.14012300E-01, 0.14932300E-01, 0.17355000E-01, 0.61611400E-01, 0.10122700E-01, -.90818400E-03, 0.47487700E-03, -.96883900E-01, 0.52050500E-01, -.19115800E-02, -.29466000E-01, -.13920300E+00, -.78972300E-01, -.80612400E-02, -.42638100E-02, -.59404900E-01, -.13523800E-01, -.53888900E-02, -.85450400E-02, 0.60271000E-01, -.12500600E-01, -.13492600E+00, -.11268400E+00, 0.66735000E-01, 0.82899000E-01, -.32880000E+00, -.20869200E-01, -.15735600E-01, 0.10509400E-01, 0.11566400E-01, 0.10531600E-01, 0.17263400E-01, 0.55978300E-01, -.82244700E-01, 0.12253500E+00, -.10876400E+00, -.68513000E-01, -.43760700E-01, 0.90427100E-04, -.14829800E-01, 0.31876600E+00, 0.53158400E+00, 0.55450600E-01, -.10798700E+00, 0.31919500E-01, -.31386300E-01, 0.53090400E-02, -.28442300E-01, -.15218300E-01, 0.16971100E-03, -.11222700E+00, -.64591600E-01, 0.39199200E-01, 0.11129900E+00, 0.15390600E-01, 0.21597600E-02, 0.73711700E+00, -.95858000E-02, 0.13502600E-01, -.15549100E+00, 0.33441700E-02, -.18792100E-01, -.19358900E-01, 0.12440400E-01, 0.11392900E-01, 0.10204100E+00, -.54953800E-01, -.20810800E+00, 0.22832600E+00, 0.17975300E+00, 0.15209900E-01, -.10196700E-01, 0.10683000E+00, -.43818600E-01, -.10268800E+00, 0.31205100E-01, -.94383500E-01, 0.81458200E-02, 0.62166700E-02, 0.37187600E-01, 0.11702500E-01, -.14579900E+00, 0.46075500E-01, -.88800700E-02, -.43501900E+00, -.92146600E-01, 0.29651000E-01, -.37846500E-01, 0.12757600E+00, -.47046500E-01, -.16837700E-01, -.57733000E-01, -.10669500E-01, 0.59693900E-02, -.45880300E-01, 0.32930400E-01, 0.48098300E-02, 0.19360500E+00, -.14514300E+00, 0.57401100E-01, 0.14383700E+00, -.21563100E+03, 0.11128000E+03, 0.15685800E+03, 0.10805000E+03, 0.21859300E+02, -.75980300E+01, 0.10400400E+03, 0.11917200E+03, 0.11705000E+03, -.48482400E+00, -.47212100E+02, -.22124200E+03, 0.11118100E+03, 0.14720600E+03, 0.11085800E+03, 0.79476700E+01, -.29495800E+02, 0.11827600E+03, 0.12116800E+03, 0.12348700E+03, -.19603000E+02, -.61245700E+02, -.30867800E+01, 0.12626700E+01, 0.18153800E+02, 0.16674400E+01, -.33578300E+01, -.22730300E+00, 0.17123300E+02, 0.11163600E+02, 0.25255400E+00, -.13501500E+02, -.90452800E+02, -.25514100E+02, 0.11521600E+02, 0.18590700E+02, 0.12859700E+02, 0.10978000E+02, -.38308800E+01, 0.32291900E+01, -.12204300E+02, 0.24402900E+02, 0.10674300E+02, 0.21590500E+02, 0.40129800E+02, -.18833400E+02, -.13527100E+02, -.19265500E+02, 0.60772300E+02, 0.51007200E+02, 0.14868400E+02, 0.32678800E+02, -.17820700E+02, 0.15613600E+02, -.63394000E+02, -.31385700E+02, 0.16178100E+02, 0.31973700E+02, 0.16362500E+02, -.22793200E+02, 0.38289500E+01, -.56792600E+01, -.31101900E+02, -.22517500E+02, -.73281200E+01, 0.68126500E+02, 0.75823000E+02, -.38345200E+02, 0.22917600E+02, -.38170400E+02, 0.13430300E+02, 0.35657400E+02, -.20931500E+02, 0.58706700E+01, -.22307800E+02, 0.30763800E+02, -.28175000E+02, 0.12342500E+03, -.61275400E+02, -.29193900E+02, -.61703900E+02, 0.28488000E+02, 0.55027100E+02, -.15136500E+02, 0.33319100E+02, -.25594500E+02, 0.21168100E+02, -.11744700E+03, -.10028800E+03, 0.49894200E+02, 0.22197500E+02, 0.50033300E+02, 0.38796800E+02, 0.23390600E+02, 0.53696300E-01, -.80588900E+02, 0.87197600E+01, 0.22145000E+02, -.28892300E+02, -.18965300E+03, 0.94880000E+02, 0.27406800E+02, 0.94501500E+02, 0.34731100E+02, 0.73933500E+01, 0.33942100E+02, -.29645400E+02, 0.53483600E+02, 0.44360700E+01, 0.23041700E+02, 0.60690700E+01, -.42332800E+01, 0.90633900E+01, -.21315200E+01, -.42010200E+01, -.59328600E+01, 0.46836300E+01, -.92129400E+01, 0.16775900E+01, -.19765000E+00, 0.15802100E+01, 0.39070700E+01, 0.42195200E+00, -.95093700E+01, 0.16262800E+02, 0.44153600E+01, -.28889400E+02, -.40592700E+01, -.34531000E+01, -.25425200E+01, 0.62008400E+01, 0.27526100E+01, 0.63994000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.60482300E+01, -.64685400E+01, -.84426100E+00, -.24897800E+01, 0.22438400E+01, 0.24025800E+01, -.13100500E+01, -.37770600E+00, 0.77234000E+02, -.17894500E+01, -.20911600E+00, 0.34132000E+01, 0.11976700E+01, -.19122800E+00, 0.21305700E+01, 0.58314400E+01, 0.13509500E+02, 0.32170200E+01, -.67745200E+00, -.77327000E+01, 0.29416200E+01, -.38206100E+00, 0.75179500E+01, -.15563600E+01, -.90385800E+00, 0.17726400E-01, -.39393300E+01, -.87937700E+00, 0.50532500E+00, 0.42045200E+00, 0.16020400E+01, 0.11001500E+01, -.42504000E+00, 0.36354900E+01, 0.31574000E+01, 0.27617700E-01, -.15354700E-01, 0.80006000E+00, -.46571300E+01, 0.50912800E+00, -.49174700E+01, -.19479600E+01, -.49646400E+01, -.38800400E+01, -.72592000E+00, -.17297800E+00, 0.21683900E+01, -.40034800E+00, -.27940900E+01, 0.11825300E+01, -.57286100E+01, -.18482500E+00, -.89335600E+00, -.13298600E+00, 0.55250800E+00, 0.31016700E+01, 0.32505000E+01, 0.49139400E+00, -.13315900E+01, 0.94045700E+01, -.42543600E+01, 0.78577700E+00, -.72505300E+00, 0.10594400E+00, 0.44855000E+00, 0.86635400E+00, 0.95742300E+01, -.19627400E+01, -.85534000E+00, -.14102000E-02, 0.85645900E-01, -.15893200E+00, 0.17531400E+01, -.45874000E+01, -.35553300E+00, 0.12841300E+01, 0.62917500E+00, 0.81805700E+00, -.41188300E+00, -.36422500E+00, 0.24134300E-03, 0.22168600E+00, 0.73622700E-01, -.30018800E+00, -.61045700E+01, -.42587000E+01, -.29637200E+00, 0.17665400E+01, 0.11981400E+01, 0.40151900E+00, -.40186200E+00, 0.25834900E-01, -.61133100E+00, 0.15331800E+01, 0.15937500E+01, -.27862900E+01, 0.57942100E+00, -.23572400E+00, -.27990700E+01, 0.10735500E+01, 0.39927300E+00, -.76486900E+00, -.10701700E+00, -.15515300E+01, -.28487300E+01, -.26790500E+01, -.67644100E+00, -.92681000E+00, -.12261400E+01, -.82173500E+00, 0.80357600E+00, 0.16537700E+01, 0.18375400E+01, -.57657600E+00, -.83643800E+00, -.12774000E+02, -.13809600E+01, -.36384000E+00, 0.25481900E+00, 0.54123300E+00, -.26347200E+01, 0.40400000E+00, 0.59477800E+01, 0.20516900E+01, -.20493600E+00, -.21351900E+01, -.29956100E+01, 0.99964500E+00, 0.26314300E+01, -.10852400E+01, -.10693000E+01, 0.49909200E+01, 0.34439600E+00, 0.27847500E+03, -.59090200E+03, 0.29369600E+01, 0.30926200E+03, 0.35162000E+03, -.36168800E+03, -.71158000E+03, -.22099200E+03, 0.25764600E+03, 0.48858200E+03, -.33522400E+03, 0.23960200E+03, 0.11362100E+04, 0.16064300E+03, 0.40796100E+03, 0.45700600E+03, -.34864300E+03, -.90056400E+03, -.50484700E+03, 0.37519800E+03, 0.16235100E+02, 0.54321200E+03, -.29067800E+03, -.11768600E+04, -.27835500E+03, -.80115300E+02, -.13964900E+03, 0.11744600E+03, 0.58859400E+03, -.77394800E+02, -.62699200E+02, 0.19687900E+02, -.20113500E+04, 0.96994600E+03, 0.11785800E+04, 0.99990500E+03, 0.12143600E+03, 0.34370300E+03, 0.34332500E+03, -.12186000E+03, 0.70497100E+03, 0.17310600E+03, 0.26414100E+04, -.62374100E+04, 0.31774500E+04, -.57131300E+03, 0.30693700E+04, -.19349000E+03, -.11681300E+04, 0.32564700E+04, 0.27031200E+04, 0.36052600E+04, -.11197300E+04, 0.35281000E+04, 0.97976800E+03, -.46236600E+03, -.23715200E+04, -.51836300E+03, 0.59244900E+02, -.34302000E+03, 0.31619800E+03, 0.88440700E+03, 0.73737500E+03, -.41326800E+03, -.14654200E+03, -.66762600E+03, 0.33489500E+03, -.98120900E+03, 0.35097700E+03, 0.11092000E+03, -.17412300E+03, -.14579100E+03, -.79519200E+03, -.16489500E+03, -.96428700E+02, 0.10654100E+04, -.37475600E+04, 0.18932200E+04, -.10611200E+04, 0.18731100E+04, 0.48508300E+03, -.88868300E+03, 0.17775900E+04, 0.15056000E+04, 0.18410800E+04, -.69791000E+03, 0.17047500E+04, 0.49934000E+03, -.27145300E+03, -.77010400E+03, -.24357500E+03, 0.36841600E+03, -.15097800E+03, -.25355200E+03, -.10198900E+03, -.12811100E+03, -.31134700E+01, -.60429200E+02, 0.13965500E+04, -.69695200E+03, -.63715800E+03, -.72391100E+03, -.20762300E+03, -.21039600E+03, -.13628400E+03, 0.60204700E+03, 0.35498000E+02, -.11387800E+03, -.99212400E+03, -.15476700E+02, 0.10609900E+03, 0.74859600E+02, 0.48079300E+02, -.13003200E+02, -.29896900E+02, -.14310700E+02, -.76652400E+02, -.66202600E+02, -.74645600E+02, -.61142700E+02, -.81449600E+02, -.66329100E+01, 0.56576900E+02, -.61309200E+02, -.82955000E+02, -.15036100E+03, -.22191500E+03, 0.18453100E+03, 0.73209000E+01, 0.23571300E+03, 0.64364700E+02, -.13838100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.93461900E+00, 0.17537000E+01, -.20798200E+00, 0.90124400E+00, -.41498100E+00, -.11193800E+01, 0.59758900E+00, -.12966200E+01, -.25845700E+02, 0.79496600E+00, 0.67956600E-02, -.99516000E+00, -.31856400E+00, 0.71643000E-01, -.29492100E+00, -.83469800E+00, -.35303100E+01, -.37833800E+01, -.30629300E+00, 0.20544500E+01, 0.77476200E-01, -.36297400E+00, -.80106900E+00, 0.27391400E+00, -.30590500E+00, 0.13571400E-01, 0.26484900E+00, 0.11206100E+00, 0.28623500E+00, 0.18806600E+00, 0.32730400E+00, -.44908700E+00, 0.27364200E+00, -.68619200E+00, 0.12405100E+00, 0.56217900E-01, -.14814300E-01, -.29851700E+00, -.40941400E+00, -.44017600E+00, -.10039200E+01, 0.20298100E+00, -.87085800E-01, 0.22178000E+00, 0.17893600E-01, 0.23599800E+00, 0.25178200E+00, 0.11385200E-01, 0.11750400E+00, 0.29522100E-01, -.36412600E+01, -.78912000E+00, 0.90457700E+00, 0.91589400E+00, 0.44064000E+00, 0.18102100E+01, 0.14965400E+01, -.31286100E+00, -.17186600E+00, -.83012100E+00, -.55848500E-01, 0.88748900E-01, 0.60534000E+00, 0.21619700E+00, 0.44004300E+00, 0.19311000E+00, 0.30012500E+01, -.68043700E+00, -.27150500E+00, -.45785900E-02, 0.19582200E+00, 0.11049900E+01, -.19401600E+01, 0.92874700E+00, -.91800500E+00, -.55224700E+00, 0.53157100E+00, -.56237100E-02, -.11157700E+00, -.24996200E+00, -.62362200E-03, 0.41077200E+00, 0.16643100E+00, -.34576900E+00, -.77403200E+00, 0.11905200E+00, 0.64366700E-01, 0.25079300E+00, 0.81860800E+00, -.53607200E-01, -.28119500E+01, -.19061400E-01, 0.35171500E+00, 0.74534100E+00, -.19737500E+00, -.25300800E+00, 0.17789500E+00, -.27161800E+00, -.17004800E+01, -.14589600E+01, -.12799800E+01, -.33304400E+00, 0.18598900E+00, -.12963000E+01, 0.83764700E+00, -.60083500E+00, -.71350400E-01, 0.17382500E+00, -.17477400E+00, -.32448400E-01, 0.36733700E-01, 0.29198900E+00, 0.11067500E-01, -.48739100E-02, -.31882900E+00, -.36377600E+01, -.90874500E-01, -.35983100E+00, -.12348900E+00, 0.64245100E+00, -.80352900E+00, 0.14331900E+00, -.85609900E+00, 0.21166400E+00, 0.16567600E+00, -.99104000E+00, -.86688700E+00, 0.98106500E-01, 0.51808500E+00, -.63728300E+00, -.54179500E+00, -.18440400E+00, -.41937100E+01, 0.71362600E-01, 0.62047900E+03, 0.28423200E-01, 0.12471600E+03, 0.11554100E+03, 0.28621500E+03, 0.86155300E+03, 0.30624200E+03, 0.75515900E+02, -.57813900E+03, -.69824800E+02, 0.35723100E+02, 0.46178000E+03, 0.35451500E+02, 0.35012400E+02, -.10353600E+02, 0.31626600E+03, 0.75088700E+03, 0.34095500E+03, -.28140200E+02, -.55869800E+03, 0.15878500E+02, -.55777100E+01, 0.73369700E+02, -.58652100E+01, -.45583600E+02, 0.19109900E+02, 0.49915500E+02, 0.55253400E+02, 0.36343300E+02, -.63777900E+02, -.43838100E+03, -.15154500E+03, 0.73907100E+02, -.11322400E+03, 0.77585900E+02, 0.32683900E+02, -.35224600E+02, 0.44663700E+02, 0.72524500E+02, 0.27649800E+03, 0.56044500E+01, 0.20578300E+03, -.34624700E+03, 0.17326100E+03, -.36554800E+02, 0.18993400E+03, 0.32185700E+03, 0.13596800E+03, 0.25271900E+03, 0.73574100E+02, 0.21356900E+02, 0.46540900E+02, 0.12575400E+03, -.21943500E+03, 0.10984600E+03, 0.19890000E+03, 0.12576900E+03, -.94613200E+02, 0.15180200E+02, -.77247500E+02, -.39695800E+03, -.21790500E+03, 0.17607400E+02, 0.30317700E+03, 0.40565600E+03, -.20400200E+03, 0.23507300E+03, -.20910500E+03, 0.82492700E+02, 0.25274500E+03, -.19269600E+03, 0.47510700E+02, -.66411500E+02, 0.19515000E+03, -.24129300E+03, 0.29063000E+03, -.14444400E+03, -.10776400E+03, -.14506800E+03, 0.15568800E+03, 0.20194900E+03, 0.52200700E+02, 0.27852700E+02, -.16530600E+03, 0.10812200E+03, -.17677600E+03, -.16436400E+03, 0.81000400E+02, 0.92170900E+02, 0.80294900E+02, 0.59460400E+02, 0.18864800E+03, -.11968000E+03, -.38584600E+03, -.15684300E+03, 0.15272900E+03, -.80855000E+02, -.91891700E+03, 0.45962000E+03, 0.35845500E+03, 0.46197400E+03, 0.13090900E+03, 0.91492400E+02, 0.86578900E+02, -.28568600E+03, 0.13852600E+03, 0.61921800E+02, 0.12670800E+03, 0.31832500E+02, 0.12177400E+02, 0.67018700E+02, -.20999700E+02, -.36629800E+02, -.40749400E+02, 0.24811300E+02, -.67625800E+02, 0.95658000E+01, -.30029600E+01, 0.55092500E+01, 0.22132600E+02, -.20198400E+02, -.55625600E+02, 0.84190800E+02, 0.15211200E+02, -.12155300E+03, -.10595400E+02, -.32588300E+02, -.56293100E+01, 0.86142900E+01, 0.19968100E+02, -.76670500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30196000E+01, 0.32353200E+01, 0.42360400E+00, 0.10901800E+01, -.13135900E+01, -.12186800E+01, 0.62949400E+00, -.11363500E+00, -.41904400E+02, 0.86673100E+00, 0.13114800E+00, -.16783600E+01, -.60959800E+00, 0.11722600E+00, -.25425900E+01, -.36914000E+01, -.85435200E+01, -.38874300E+01, -.26517900E-01, 0.46518300E+01, -.15539700E+01, 0.30537500E+00, -.52937600E+01, 0.89490400E+00, 0.70570200E+00, -.40083500E-01, 0.25624500E+01, 0.47617500E+00, -.31929500E+00, -.50215500E-01, -.10428800E+01, -.69147100E+00, 0.26183600E+00, -.18069500E+01, -.13770300E+01, 0.14316900E+00, 0.24755900E-01, -.64183200E+00, 0.30140100E+01, -.33289400E+00, 0.24805000E+01, 0.10153200E+01, 0.20761500E+01, 0.19760900E+01, 0.40651600E+00, 0.13164400E-01, -.19223500E+01, 0.20273700E+00, 0.12025300E+01, -.53261000E+00, 0.28924300E+01, 0.38191400E-01, -.97893800E+00, -.46555600E+00, -.64230700E+00, -.43320100E+01, -.23837000E+01, -.17167400E+00, 0.83790800E+00, -.49714800E+01, 0.20276200E+01, -.54306000E+00, -.74171900E+00, 0.14073500E+00, -.20729100E-01, -.51787800E+00, -.34822400E+01, 0.12650500E+01, 0.43037100E+00, 0.12968700E-02, -.22844900E+00, 0.45124600E+00, -.18618700E+01, 0.18262300E+01, -.59825200E+00, -.24157900E+00, -.77136200E+00, -.18957300E+00, 0.14055700E+00, 0.18974000E+00, 0.33667500E-03, -.29779900E+00, -.95190800E-01, -.15518200E+00, 0.28371200E+01, 0.17461700E+01, 0.94880700E-01, -.44679800E+00, -.48977400E+00, -.13744800E+00, 0.12541100E+01, -.30412800E-01, 0.97984800E-01, -.51167200E+00, -.56031800E+00, 0.70871200E+00, -.19037600E+00, 0.71300600E-01, 0.10851300E+01, -.57921000E+00, 0.29255100E+00, 0.17107900E+00, 0.29675500E-01, 0.98064100E+00, 0.11486200E+01, 0.88871100E+00, 0.25204000E+00, 0.34489000E+00, 0.34951600E+00, 0.22822100E+00, -.29426600E+00, -.60512300E+00, -.76393300E+00, 0.23960200E+00, 0.30946400E+00, 0.34613300E+01, -.61035100E-01, 0.23873400E+00, -.14466900E+00, -.59372700E-01, 0.10486000E+01, -.52839700E-01, -.26108000E+01, -.93302200E+00, -.43785700E-01, 0.92583600E+00, 0.13135700E+01, -.40561000E+00, -.90142700E+00, 0.42221800E+00, 0.22411900E+00, -.16220200E+01, 0.16080200E+01, -.30149500E+00, -.28727000E+00, 0.38432300E+02, -.26243300E+02, 0.21580800E+02, -.12536400E+02, 0.75814000E+02, 0.36111500E+01, 0.22816600E+02, -.56354100E+02, 0.13818100E+03, -.71674700E+02, -.14475400E+03, -.63284900E+02, -.25226700E+02, 0.39879100E+02, -.87099700E+02, 0.22931900E+02, -.45370500E+02, 0.38570700E+02, -.77848200E+01, -.28603900E+01, -.47464400E+00, 0.38926300E+02, 0.29396500E+01, -.20446600E+02, -.23985300E+02, 0.32551300E+02, 0.36602100E+02, 0.52492800E+02, -.25577300E+02, -.26659800E+02, -.22196200E+02, 0.14829600E+02, -.80926600E+01, 0.12259800E+02, 0.16759600E+02, -.71777200E+01, -.91593800E+01, -.46082400E+02, -.31759700E+02, -.32705300E+01, -.82885600E+02, 0.12874700E+03, -.63186300E+02, 0.15475800E+03, -.57538700E+02, 0.56338900E+02, 0.67313200E+02, -.10091900E+03, -.21596000E+03, -.14558500E+03, 0.77402700E+02, -.12560400E+03, -.13402000E+03, 0.66693000E+02, 0.18396100E+03, 0.76345600E+02, 0.24573400E+02, 0.48940800E+02, -.52298300E+02, -.16762500E+03, -.84849600E+02, 0.66641100E+02, -.73311000E+01, -.10642200E+02, 0.65286200E+01, 0.69534700E+02, 0.37595200E+01, -.21209700E+01, 0.20402200E+02, -.64168200E+01, 0.57631600E+02, 0.30266900E+02, 0.19939300E+02, -.73585400E+02, 0.11833600E+03, -.59758100E+02, 0.97835200E+02, -.59148000E+02, 0.11253400E+02, 0.55499200E+02, -.63369100E+02, -.13368800E+03, -.90907200E+02, 0.52707300E+02, -.51908700E+02, 0.11945100E+03, -.58789200E+02, -.20790400E+02, -.61031800E+02, -.66213200E+02, 0.17963000E+01, -.35157700E+01, 0.37858600E+02, -.54305800E+02, -.93703700E+01, -.93529100E+01, -.29347200E+02, 0.14499300E+02, 0.99335500E+01, 0.19265700E+02, -.26408300E+02, 0.10392400E+02, -.13783600E+02, -.70244400E+02, -.23093800E+02, 0.53561500E+01, 0.49842200E+02, 0.26692300E+01, 0.11380700E+02, 0.58100500E+01, -.83929700E+01, -.51808700E+01, 0.12168400E+01, 0.23217900E+01, -.55729100E+01, -.16765300E+01, -.49938300E+01, -.52046600E+01, 0.68709000E+01, -.10758900E+02, -.17377100E+02, 0.46936400E+01, -.64403600E+01, -.52494000E+01, 0.15220800E+02, -.12956400E+02, 0.61516500E+01, -.14189800E+02, -.25659600E+01, -.84123600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46636500E+00, -.21015400E+00, 0.28200900E+00, 0.22755000E+00, -.81992800E+00, -.26940400E+00, 0.27521300E-01, 0.12430200E+00, 0.20073900E+00, -.45148400E+00, -.20109600E-01, 0.17138700E+00, -.12187700E+00, -.15287900E-01, 0.39233000E+00, -.35838000E-01, -.16581300E+00, -.34221900E+00, -.87374500E-01, 0.53032500E-01, -.33886300E+00, 0.41443900E-01, -.99626300E+00, -.12582700E+00, 0.46806600E+00, -.14744100E-01, 0.89053600E+00, 0.60245100E-01, -.95705900E-01, 0.20242800E-01, -.37188600E-01, 0.21001000E-01, 0.94590400E-02, -.12056000E+00, -.10221900E+00, 0.45106100E-01, 0.22247400E-03, -.19029500E+00, -.54675100E+00, -.13225200E+00, -.53639200E-01, -.21919800E-01, -.20113300E+00, -.95645800E-01, 0.11123900E+00, 0.22947300E-01, 0.42332000E+00, 0.71424400E-01, -.14629700E+00, -.21598500E+00, 0.12534000E+01, 0.35777100E+00, -.18133200E+00, -.11371800E-01, -.40771600E+00, 0.14390800E+01, -.39816600E+00, 0.63139400E-01, 0.27444500E+00, 0.15983400E+01, -.22620000E+00, 0.87680800E-01, -.14372900E+00, 0.11057100E+00, 0.71837000E+00, -.62970200E+00, -.11804300E+01, 0.30314000E+00, 0.89039200E-01, 0.25451200E-02, -.22484100E+00, 0.22295300E+00, -.13808400E+01, -.39987400E+00, -.23281700E-01, 0.96310300E-01, -.76695700E-01, -.30725200E+00, 0.93927400E-01, 0.98178800E-01, 0.45025300E-03, -.16414500E+00, 0.98452900E-01, -.86571700E-01, -.14369100E+00, 0.99855300E-01, 0.21172400E-02, -.16529600E+01, -.21782600E+00, 0.23298100E-01, 0.50768300E+00, 0.16426900E-02, -.68154200E-01, -.26075100E+00, 0.33021100E-01, -.98323900E-01, 0.23017300E+00, 0.26398800E+00, 0.18947100E+00, -.62477100E+00, -.23441000E+00, -.75686100E-01, -.50024800E-02, 0.43210800E+00, 0.35949700E-01, -.47725000E-01, 0.17976700E+00, -.78004900E-01, -.26032000E-01, 0.11553400E+00, -.19956800E-01, -.15602600E+00, -.60319600E-01, 0.19027700E-01, -.11065400E+00, -.21993500E+00, -.36940500E+00, -.38858300E-01, -.39739200E-01, -.17845800E+00, 0.57825400E-02, -.57062900E-01, 0.26827700E+00, -.86918300E-01, 0.30727000E-02, -.14298900E-01, -.40555800E+00, 0.12571200E+00, -.34174900E-01, 0.37685900E+00, -.28164200E+00, 0.42242800E-01, 0.24718600E+00, -.44156700E-01, -.15454800E+00, 0.15842400E-01, 0.10794700E+03, 0.12301900E+03, -.12110500E+03, -.13001500E+03, -.81962200E+02, 0.11673300E+03, 0.12610700E+03, 0.31346700E+03, -.15585300E+03, 0.45720200E+02, -.15652300E+03, 0.74783000E+02, 0.59369900E+02, -.15320000E+03, -.10163700E+03, -.18176200E+03, 0.65871100E+02, -.27006600E+02, -.25988400E+02, 0.14261500E+02, -.22033100E+02, 0.13065800E+02, 0.69564100E+01, 0.98512900E+01, 0.70475000E+01, 0.68213700E+02, 0.26412300E+02, 0.21123800E+02, 0.90963300E+02, -.16058300E+03, 0.79107800E+02, 0.10651000E+03, 0.80349700E+02, 0.31686600E+02, 0.38606400E+02, 0.19723100E+02, -.48726700E+02, -.20547800E+02, 0.26318500E+02, 0.28640100E+02, -.43126100E+03, 0.21522900E+03, 0.79878500E+02, 0.21600500E+03, 0.13733100E+02, -.68679700E+02, 0.22120700E+03, 0.29891500E+03, 0.27839300E+03, -.63202400E+02, 0.22844300E+03, 0.16850800E+03, -.83267800E+02, -.11308700E+03, -.85567000E+02, 0.18898900E+02, -.19646300E+02, 0.28555600E+02, 0.14504800E+03, 0.65364400E+02, -.23725600E+02, -.18830400E+03, -.15841500E+03, 0.76968300E+02, 0.59449500E+02, 0.79121100E+02, 0.40430100E+02, 0.83920600E+02, -.27626100E+02, -.88575700E+02, -.32371200E+02, 0.87981700E+02, 0.59671600E+02, -.21373600E+03, 0.10714300E+03, 0.19968000E+02, 0.10687200E+03, 0.39935600E+02, -.16879400E+02, 0.70595800E+02, 0.12935800E+03, 0.15043600E+03, -.10217100E+02, 0.12378100E+03, 0.16589100E+03, -.83799000E+02, -.10084400E+03, -.83009500E+02, -.12749600E+02, 0.50974100E+01, -.27268700E+02, 0.81196100E+02, -.29560900E+02, -.41459800E+01, -.30063500E+02, 0.33224500E+03, -.16627300E+03, -.91043600E+02, -.16802900E+03, -.54859400E+02, -.13124700E+02, -.69816400E+02, 0.73661700E+02, -.86858700E+02, -.83890100E+01, -.68947000E+02, -.51024100E+01, 0.83416100E+01, -.12097200E+02, 0.60351100E+01, -.22062200E+02, -.25810300E+02, -.38297500E+01, 0.12202300E+02, -.34187600E+01, 0.22268400E+01, -.14763900E+01, -.27041300E+02, 0.15145500E+01, 0.11776200E+01, -.37562800E+01, -.84883900E+01, 0.23158900E+02, -.14853700E+02, 0.17782500E+02, -.23643200E+01, 0.26573700E+02, -.70513700E+01, -.12284200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13873700E+01, 0.10422500E+01, 0.78421600E+00, 0.23153900E+00, -.16529500E-01, -.25685400E+00, 0.30938800E+00, 0.23161100E+01, 0.19986600E+02, -.72693500E+00, -.22996800E-01, 0.71507800E+00, -.14196900E+00, -.13616300E+00, 0.87590900E+00, -.90227200E+00, 0.12250800E+00, 0.27577100E+01, 0.70394700E+00, 0.28290500E+00, -.76922800E-01, 0.16299400E+00, -.23215100E+00, -.18565900E-01, -.15619600E+00, -.74254000E-02, -.60548700E-01, 0.41653100E-02, -.11708300E-01, -.22243800E-01, 0.13835700E+00, -.91441700E-01, -.43698400E-01, -.10654900E-01, -.22487800E-01, 0.77146200E-01, 0.53270600E-02, 0.17569300E+00, 0.87620800E-01, 0.22621000E+00, -.52442700E-01, 0.10539700E-01, 0.31832800E+00, 0.45266000E-01, -.95072600E-01, -.49160200E-01, -.96488900E-01, -.36078200E-01, 0.46399500E+00, 0.38729900E-01, -.46535900E+00, -.40292500E+00, 0.70026800E+00, -.38828700E+00, 0.45357300E+00, -.14348000E+01, 0.15327800E+00, 0.18982600E-01, 0.40261900E-01, 0.91217300E+00, 0.23641500E+00, -.86997800E-01, 0.86808100E+00, -.42970700E+00, -.11982000E+01, 0.54985700E+00, -.75337600E+00, -.32056100E+00, -.63849000E-01, -.89358500E-03, 0.20309300E+00, -.12821000E+01, 0.23144100E+01, 0.20412600E+00, 0.68256600E+00, -.23376200E+00, 0.67409500E-01, -.38217200E-02, -.10472500E+00, -.37057500E-01, 0.48263200E-03, 0.11951600E+00, 0.44094700E-01, 0.16104300E+00, -.51486100E+00, -.83478500E-01, -.67327700E-01, 0.12310000E+00, -.31078000E+00, 0.10148300E-01, -.97557000E+00, 0.22234900E-01, 0.94871900E-01, -.25167500E+00, -.70618500E-01, 0.67217300E+00, -.36795400E+00, 0.33808900E-02, 0.56044700E+00, -.17607600E+00, -.57128600E+00, 0.20951500E+00, -.15401000E-01, -.61877900E+00, 0.73830700E-01, 0.46215200E+00, -.59689700E-02, -.19628200E+00, 0.22873600E+00, 0.10276300E+00, -.88525900E-01, -.22133500E+00, 0.25437500E+00, -.80441400E-01, -.52385300E-01, 0.21307200E+01, 0.88616200E+00, -.12238300E-01, 0.16814000E+00, -.41788000E-01, 0.13083500E+00, -.37172200E+00, 0.19929500E+01, 0.37501000E+00, -.31379600E-01, -.81152400E+00, -.43842400E+00, 0.15835700E+00, -.51345800E+00, -.74858200E+00, 0.42811500E-01, -.36473700E+00, -.10711000E+01, -.13377600E+00, -.26363800E+00, 0.31645600E-01, 0.15309400E+01, -.18244300E+03, 0.24441500E+03, 0.31163200E+03, 0.22892200E+03, -.17568500E+03, -.35242700E+03, -.38592400E+03, 0.19104700E+03, 0.22841900E+03, 0.19259800E+03, -.48819000E+02, -.24791500E+03, 0.38095000E+03, 0.25510900E+03, 0.31483000E+03, -.23514600E+03, -.47272000E+03, 0.38639500E+03, -.18595200E+03, -.19999900E+03, -.19396000E+03, -.12184200E+03, 0.14926800E+02, -.70997200E+02, -.78150300E+02, -.16474900E+03, -.29812500E+02, -.48437700E+03, -.25824500E+03, 0.11513300E+03, -.19807500E+03, 0.12845800E+03, 0.77566000E+02, -.65214000E+01, 0.88692900E+02, 0.19210400E+03, 0.38885800E+03, 0.19772800E+01, 0.90085100E+03, -.29244500E+03, 0.14546500E+03, -.51329300E+03, 0.14022000E+03, -.13978700E+03, -.32550400E+02, 0.32978700E+03, 0.16495300E+03, 0.17229800E+03, -.15250000E+03, 0.42176900E+03, -.79617800E+01, 0.42504200E+01, -.34715500E+03, -.57590500E+01, -.22616500E+03, -.55492200E+02, -.73390800E+02, -.34576000E+03, -.76355500E+02, -.10561100E+03, 0.67720000E+03, 0.57223300E+03, -.28684200E+03, -.30772500E+03, -.28394100E+03, 0.51162200E+02, 0.14320100E+02, -.12078600E+03, 0.64720000E+01, -.61969100E+02, 0.10146400E+02, 0.61419100E+02, -.18524200E+03, 0.95798500E+02, -.33844000E+03, 0.92531800E+02, -.13288100E+03, -.31853200E+01, 0.24472000E+03, 0.63755700E+02, -.33380600E+02, -.80463000E+02, -.53434700E+01, -.19318200E+03, 0.92349700E+02, 0.17381500E+03, 0.97284800E+02, 0.13526700E+03, 0.92056100E+02, -.13362800E+03, -.47765800E+03, -.10951200E+03, 0.14093400E+03, -.17039300E+03, -.73447700E+03, 0.36768600E+03, 0.48944700E+03, 0.35794100E+03, 0.10102200E+03, -.73623800E+00, 0.16332400E+03, -.13339900E+03, 0.27036700E+03, 0.22339100E+02, -.20738200E+03, 0.14718400E+02, 0.25816300E+01, 0.91121800E+02, -.16386300E+02, -.30296600E+01, -.21159700E+02, 0.10538400E+02, -.91812800E+02, -.49964700E+01, -.23031100E+02, -.97967800E+01, 0.55195900E+02, -.31583700E+02, -.88662500E+01, 0.59022700E+02, -.29126000E+01, -.18897000E+03, 0.12289200E+01, -.19064900E+02, -.24332800E+01, -.17546400E+02, 0.60156700E+02, -.78226400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27876300E+01, -.37484000E+01, 0.33383900E+01, -.16266300E+01, 0.15190000E+01, 0.10555600E+01, -.31715200E+00, -.23544200E+01, -.20056500E+02, -.15466300E+00, 0.31324900E+00, -.13376600E+01, -.64956900E-01, -.29144300E-01, 0.25106800E+01, 0.11468200E+01, 0.28938700E+01, 0.75656800E+01, 0.68174400E+00, -.73273800E+00, -.29599400E+01, 0.61306400E+00, 0.19381600E+01, 0.18621100E+00, 0.65415500E-01, 0.90335000E-02, -.21368700E+01, -.19737900E+00, -.14420500E-01, -.27839200E+00, 0.17015600E+00, 0.57048300E-01, -.31629400E+00, 0.12543400E+01, 0.13383600E+01, -.89097800E+00, 0.11608700E-01, -.50083100E+00, 0.91866900E-01, 0.71138700E-01, -.28163200E-01, -.20797800E+00, -.75109000E-01, 0.45883200E+00, -.95388000E-01, -.51339700E+00, -.49032200E+00, -.11540400E+00, -.85925000E+00, 0.16829000E+00, 0.59487100E+01, 0.15027300E+01, -.20035400E+01, -.51107200E+00, -.27578400E+00, -.20747300E+01, -.52007100E+01, 0.33574300E+00, 0.39742900E-01, -.24673100E+01, 0.42337300E+00, -.80529000E-01, -.29614400E+01, 0.86197900E+00, 0.20223200E+00, 0.10800100E+01, -.39888900E+01, 0.11772700E+01, 0.26534600E+00, 0.73145300E-02, -.44670100E+00, 0.85643400E+00, -.46295900E+01, 0.29713600E+00, -.75087000E+00, -.27208700E+00, -.14146800E+01, -.67003600E+00, -.13031100E+00, 0.12899800E+00, 0.65110100E-02, -.27938800E+01, 0.84580200E+00, -.48746300E+00, 0.64627900E+00, -.22566400E+00, -.23681900E+00, 0.22015000E+01, -.67062400E+00, 0.47423200E+00, 0.23258800E+01, -.52270200E-02, -.43325500E+00, 0.22383000E+00, 0.43234200E+00, 0.43500300E-01, -.16726400E+01, -.19467400E+00, 0.16524300E+01, -.54576200E+00, -.16695600E+01, 0.74077300E+00, -.15306300E+00, 0.88732600E+00, -.66401500E+00, 0.11845100E+01, 0.28707500E+00, 0.31005000E+00, -.10816400E+00, -.23994900E+00, 0.57221100E-01, -.35832200E+00, 0.19278900E+00, -.59808800E-01, 0.32002500E+00, -.16404500E+01, -.39718700E+00, 0.49638100E+00, 0.21699300E+00, -.12563300E+01, 0.21890700E+00, -.11221700E+00, 0.25681300E+01, 0.17189000E+00, -.18085100E+00, 0.12075800E+01, 0.12281400E+01, 0.59597000E-01, 0.23687400E-01, -.67965500E-01, 0.16338300E+00, 0.57727700E+00, 0.40693200E+01, 0.10242100E-01, 0.76338200E+00, -.16273000E-01, -.14632300E+01, -.66850700E+00, -.59069000E+03, -.11797300E+04, -.34301900E+03, 0.36626100E+02, 0.75651100E+03, 0.56060800E+03, -.28751200E+03, -.44086000E+02, -.28091700E+03, -.22910900E+02, -.42243700E+02, -.66557100E+03, -.11504800E+04, -.57536000E+03, -.46498700E+00, 0.40520800E+03, 0.13382000E+03, -.71085100E+02, -.17284200E+03, -.70427000E+02, -.61478900E+02, -.99245000E+02, -.40486700E+02, -.96377000E+02, -.12779700E+03, -.51619500E+01, 0.31977400E+03, 0.71292700E+02, -.47895400E+02, 0.54012100E+02, -.38730700E+02, 0.18040500E+02, 0.37840700E+02, 0.55996900E+01, 0.77074200E+01, -.19694900E+03, -.10334700E+02, 0.25098900E+03, 0.30296400E+03, -.14288700E+03, -.62524500E+02, -.18028600E+03, -.33394700E+03, 0.10335200E+02, -.15695200E+03, 0.13754000E+03, 0.41498800E+02, 0.14119400E+02, 0.48627400E+03, 0.15616700E+03, -.74199600E+02, -.20008800E+03, -.11143500E+03, -.10355700E+01, 0.60446000E+02, -.15139900E+03, 0.36716500E+01, 0.10230600E+03, 0.44756700E+02, 0.12451100E+03, 0.70706100E+02, -.37538300E+02, -.34575600E+03, -.24553500E+02, -.56004000E+02, -.17102200E+03, 0.48569900E+02, -.33950700E+01, -.16769500E+02, -.93772600E+02, 0.33512300E+03, -.36937200E+01, 0.46644400E+01, -.29922800E+02, 0.14174900E+01, -.29654300E+03, -.63335200E+02, -.70901200E+02, 0.26660700E+02, 0.68081300E+02, -.44956900E+02, 0.25128400E+03, 0.64458300E+03, -.32242700E+03, -.21221300E+03, -.31908700E+03, -.14528100E+03, -.20490700E+03, -.39935800E+01, 0.25856400E+03, -.56463100E+02, -.13592500E+03, -.17866400E+03, 0.10355700E+04, -.51822300E+03, -.26095500E+03, -.53166700E+03, -.20690700E+03, -.16226700E+03, -.54013900E+02, 0.29141100E+03, -.84750100E+02, -.77762400E+02, -.37668700E+03, -.30655100E+02, -.69269400E+01, -.27910600E+02, -.26791400E+01, 0.11956600E+02, -.31447500E+01, -.22605000E+02, 0.29057500E+02, -.15992800E+02, -.15107300E+02, -.24727700E+02, -.46660100E+01, -.70366600E+01, 0.69363000E+02, -.75905900E+02, -.28765500E+02, 0.44971900E+02, 0.24677500E+02, 0.65180200E+01, 0.15869000E+02, -.15742200E+02, -.21991300E+01, -.14560900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.67941900E+01, 0.73246400E+01, 0.11665300E+01, 0.32189900E+01, -.17194800E+01, -.27969600E+01, 0.15742100E+01, 0.18526100E+01, -.75162900E+02, 0.16960200E+01, -.19227900E+00, -.36354100E+01, -.16134400E+01, 0.10760000E+00, 0.83140200E+00, -.53134800E+01, -.11421300E+02, 0.56611700E+00, 0.11739000E+01, 0.69739200E+01, -.39678200E+01, 0.91756100E+00, -.85007500E+01, 0.17816100E+01, 0.12801000E+01, 0.29836700E-01, 0.39305800E+01, 0.75989400E+00, -.27704600E+00, -.36747100E+00, -.10149400E+01, -.11923700E+01, 0.61072300E+00, -.31477700E+01, -.35989200E+01, -.34744800E-01, -.50447100E-01, -.42065700E+00, 0.46581500E+01, -.10182800E+01, 0.38912000E+01, 0.25213300E+01, 0.57200200E+01, 0.37945700E+01, 0.94373200E+00, 0.11141700E+01, -.12479800E+01, 0.88353000E+00, 0.45491500E+01, -.20574800E+01, -.70733600E+01, -.29466400E+01, 0.59136700E+01, 0.25061100E+01, 0.12639300E+01, 0.45390400E+01, 0.59501300E+01, -.13029800E+01, 0.86779900E+00, -.39178900E+01, 0.31901700E+01, -.36794400E+00, 0.63677600E+01, -.11095900E+01, -.37712900E+00, -.96674500E+00, -.24957800E+01, -.17802500E+01, -.59055600E-01, -.20025600E-01, 0.14475200E+01, -.68261700E+00, 0.96139200E+00, 0.53635900E+01, 0.13675300E+01, -.25000300E+01, 0.28848100E+01, -.57836300E+00, 0.26886800E+00, -.23586600E+00, -.86970000E-02, 0.34753400E+01, -.48272200E+00, 0.16610700E+01, 0.84723000E+00, 0.41579800E+01, 0.69088000E+00, -.23694900E+01, 0.56538700E+00, -.60729800E+00, -.71118800E+01, -.49359700E-01, 0.16305900E+01, -.35112500E-01, -.16785700E+01, 0.18959900E+01, 0.11935200E+01, 0.85246300E+00, -.59456900E+00, -.18484600E+01, -.17705200E+01, -.49768500E-02, 0.50380300E+00, -.13361900E+01, 0.21509300E+01, -.29634500E-01, -.22482800E+00, 0.47520000E+00, 0.17767000E+01, 0.75794300E+00, -.92794600E+00, -.91291900E+00, -.60779300E+00, 0.18231600E+00, 0.50546900E+00, 0.16953900E+02, 0.52277400E+01, -.74370800E+00, 0.23031900E+00, -.16370800E+00, 0.14398500E+01, -.30051800E+00, -.89015600E+01, -.13478500E+01, 0.67394900E+00, -.17728200E+01, -.12542100E+01, -.57857900E+00, -.30230500E+01, -.15013900E+00, 0.91957600E+00, -.65713700E+01, -.13423300E+02, -.10928000E+01, 0.27323300E+01, 0.40709700E+00, 0.10594100E+01, 0.23343600E+01, 0.69630500E+00, -.53601400E+03, -.22191000E+03, 0.18122900E+02, 0.24540300E+03, -.11321200E+04, 0.57217400E+03, 0.25454100E+03, 0.56795200E+03, 0.23069800E+03, 0.27854200E+03, 0.28324800E+03, -.48707000E+02, 0.28407500E+03, 0.24326000E+03, 0.67019200E+03, -.79496500E+03, 0.40330600E+03, 0.18705900E+02, 0.39980500E+03, 0.41835600E+03, 0.10634000E+03, 0.31331800E+02, 0.27371100E+03, 0.24414100E+03, 0.15879800E+03, 0.10319100E+04, 0.39451900E+03, -.18057500E+03, 0.35555400E+03, -.19525700E+03, -.21765300E+03, 0.70355900E+02, -.10482000E+03, -.17737400E+03, -.47587900E+03, 0.22111100E+02, -.10935500E+04, -.89335000E+03, 0.42827000E+03, 0.20086000E+03, 0.46413400E+03, 0.75936400E+01, -.72883100E+03, 0.31805300E+03, 0.99243100E+03, 0.86043300E+03, -.43973400E+03, -.12335900E+03, 0.67844400E+03, -.34260400E+03, -.44305900E+03, -.32445100E+03, 0.44387700E+03, -.25277500E+03, 0.63552500E+03, 0.17797600E+04, 0.64771100E+03, -.20664600E+03, -.14540300E+04, -.12303200E+04, 0.60889600E+03, 0.46059800E+03, 0.60902800E+03, -.16732800E+03, -.36141800E+03, 0.31691900E+03, -.42694200E+03, 0.51234400E+02, -.35489700E+03, 0.29702500E+03, -.12911400E+04, 0.63932900E+03, 0.30673400E+03, 0.64582100E+03, 0.40194500E+03, -.61773600E+03, 0.30186100E+03, 0.79024400E+03, 0.89135600E+03, -.36040300E+03, 0.61968400E+03, -.26887300E+03, 0.13642300E+03, -.17867200E+03, 0.13233100E+03, 0.14019300E+03, -.15448600E+03, 0.22068200E+03, 0.77871200E+03, 0.45178600E+03, -.20852600E+03, 0.65040300E+03, 0.20216200E+04, -.10105800E+04, -.92191200E+03, -.10050600E+04, -.56648700E+02, -.20025000E+01, -.39781000E+03, 0.77868400E+03, -.55913300E+03, -.58040500E+02, 0.50026600E+02, -.35827200E+02, -.35599800E+02, -.19310300E+03, 0.96302700E+02, 0.73007800E+02, 0.10293400E+03, -.24493200E+02, 0.19255700E+03, 0.44653400E+01, 0.60247300E+02, 0.41443500E+02, -.15038200E+03, 0.13230000E+03, 0.97585400E+02, -.12820900E+03, 0.21148100E+02, 0.38000500E+03, -.11537500E+03, 0.12248400E+03, -.37721800E+02, 0.11515100E+03, -.88063200E+02, 0.20715800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15019100E+01, 0.85078800E+00, 0.85966500E+00, 0.24494100E+00, -.20202400E+00, -.16911900E+00, 0.30847500E+00, 0.20712100E+01, 0.19996400E+02, -.61410700E+00, -.18511100E-01, 0.43455500E+00, -.15835000E+00, -.66822200E-01, 0.13517700E+01, 0.15101200E-01, -.26973900E+00, 0.31954100E+01, 0.92656100E+00, -.30285600E+00, 0.36972900E+00, 0.35290300E+00, -.60945900E+00, -.75208500E-01, 0.19428700E+00, -.14441000E-02, -.22335000E+00, -.10962700E+00, 0.87092100E-01, 0.99942400E-01, 0.41780500E-01, -.28355100E-01, -.14359600E+00, -.34036200E+00, -.27389300E+00, -.15381800E+00, 0.17198500E-03, -.11871200E+00, 0.33934300E+00, 0.26844900E+00, 0.11058800E+01, -.17834700E+00, -.67585900E+00, -.45551900E+00, 0.35857700E+00, 0.11508200E+00, 0.35259700E+00, 0.13500300E+00, -.25784300E+00, -.76487300E+00, 0.12548700E+01, 0.33433800E+00, 0.77694800E-01, -.32043100E-01, -.39853600E+00, 0.21621500E+01, -.99262500E-02, 0.12384400E+00, 0.15675000E+00, 0.10799000E+01, -.29868200E+00, 0.32000500E-01, -.82791400E+00, -.46072300E-02, 0.64846500E+00, -.12026700E+01, 0.11173600E+00, 0.52955700E+00, 0.20059600E+00, 0.19427000E-02, -.10856200E+00, 0.63857000E+00, 0.23398400E+00, -.97531900E-01, 0.29315800E-01, 0.39691400E+00, -.57198800E+00, 0.94473700E-01, 0.75110100E-01, 0.12993500E+00, 0.48823800E-03, 0.59404500E-01, -.94890800E-01, -.34726600E+00, 0.10657000E+01, 0.58965900E+00, 0.61675200E-01, -.73110500E+00, 0.20053600E+00, 0.92374200E-01, 0.61069900E+00, -.55801000E-02, 0.84554300E-02, 0.61576300E-02, -.34636200E-01, -.44789100E+00, 0.38239400E+00, -.81472800E-01, -.56761700E+00, -.22521300E+00, 0.36397600E+00, -.54588300E-01, -.32413900E-01, 0.64708100E+00, 0.47777700E+00, -.59489900E+00, -.12205100E+00, 0.24613900E+00, -.30849800E+00, -.27588700E+00, 0.14831900E-01, 0.15330100E+00, -.30192100E+00, 0.96198400E-01, 0.89829900E-01, -.39050200E+01, -.10239300E+01, 0.39283200E-01, -.19965900E+00, 0.14307000E+00, -.28142300E+00, 0.41396100E+00, -.19695200E+01, -.34330600E+00, 0.24478200E-01, 0.20415200E+00, 0.18529400E+00, -.14682500E+00, 0.26450200E+00, 0.17812300E+00, -.31287300E+00, 0.12917800E+00, 0.87267100E-01, 0.12818300E+00, 0.28927000E+00, -.57713400E-01, -.91798500E+00, -.93438900E+00, -.79424200E-01, -.73512900E-01, 0.82379800E+02, -.16287100E+02, -.15165900E+03, 0.28562600E+03, -.14699800E+03, -.11680600E+02, -.14377900E+03, -.31584500E+02, -.46459800E+02, -.66852200E+01, 0.33425800E+02, -.35578300E+02, -.53141500E+02, -.30681400E+03, 0.11787400E+03, -.59656000E+02, -.84183600E+02, -.59576300E+02, -.38618000E+02, 0.20102500E+02, -.45660900E+02, -.61971100E+02, -.52343700E+02, 0.32212100E+01, -.20696700E+03, -.24847700E+02, 0.53262000E+01, -.11748100E+03, 0.11886400E+02, 0.17321700E+02, -.37271300E+01, 0.33090500E+02, 0.87341000E+02, 0.11222900E+03, -.72025500E+01, 0.35304400E+03, -.68759700E+02, 0.37779600E+02, -.21211000E+03, 0.30012000E+02, -.86471800E+02, -.95065300E+02, 0.12821100E+03, 0.13404300E+03, 0.94906900E+02, -.78063600E+02, 0.88780000E+02, 0.36734000E+02, -.17315200E+02, -.13248400E+03, -.20069000E+02, -.52251200E+02, -.44375500E+02, 0.13019200E+02, -.57253100E+02, -.41420000E+02, -.37638100E+02, 0.10069100E+03, 0.10879000E+03, -.53410400E+02, 0.22696000E+01, -.52935800E+02, -.38937800E+02, -.23353100E+02, -.24337400E+02, -.50175900E+02, 0.19703900E+02, -.19966600E+02, -.19510400E+02, -.79115000E+02, 0.41603300E+02, -.83379400E+02, 0.39503400E+02, -.84617800E+02, -.36620700E+02, 0.70878000E+02, 0.49547600E+02, -.12374900E+02, -.28124300E+02, -.23819800E+02, 0.34140700E+02, -.17666900E+02, 0.47591200E+02, -.16496700E+02, 0.10770100E+02, 0.56953800E+02, -.61049700E+02, -.10382100E+03, -.85854400E+02, 0.54558700E+02, -.44635500E+02, -.61196300E+02, 0.30614700E+02, 0.19213100E+03, 0.30344800E+02, -.41593700E+01, 0.15409300E+02, 0.41368400E+01, -.12871800E+02, -.55597100E+01, 0.15425900E+02, -.90686900E+02, -.28570700E+01, 0.97083000E+01, 0.30056100E+02, -.67511900E+01, 0.14037200E+02, 0.55088500E+01, -.31366300E+01, -.30101700E+02, -.22660700E+01, -.29835000E+01, -.34045800E+01, 0.13739800E+02, -.67915700E+01, 0.84074900E+01, 0.25467300E+01, -.11948800E+01, -.46229300E+02, 0.10235000E+01, -.11977700E+02, -.32567900E+01, -.16108000E+02, 0.17468100E+02, -.12958300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.40789500E+00, -.87710300E+00, 0.12540300E+00, -.43010300E+00, 0.45404600E+00, 0.69905600E+00, -.14873100E-01, 0.15760800E+00, 0.75577200E+01, 0.72842500E+00, -.38104500E-01, 0.22376000E-01, -.10021200E+00, 0.16447000E-01, 0.20641500E+00, -.43099100E+00, 0.11652900E+01, 0.12157200E+01, 0.16522300E+00, -.75858700E+00, 0.51480100E-01, 0.24753800E+00, 0.10504100E+01, -.20374300E+00, -.45256900E+00, -.93712000E-03, -.70623700E+00, -.36186500E-01, 0.80824800E-01, 0.15121600E-01, 0.34657800E+00, 0.13782000E-01, -.18628200E+00, -.85649800E-03, -.83757700E-01, -.66195000E-01, 0.10512300E-01, 0.88455400E+00, 0.16484000E+00, 0.52249100E-01, 0.29853600E+00, -.75914700E-01, 0.78181300E+00, 0.32309700E-02, -.79164100E-02, -.34452000E-01, 0.28831600E-01, -.21725500E-01, -.63866900E-01, 0.10232400E-01, 0.51769500E+00, 0.13410300E+00, -.11821800E+00, -.56059700E+00, -.62035800E-02, 0.64430100E+00, 0.76840700E-01, 0.32128600E-02, -.38227100E-01, -.27577800E+00, 0.68631100E-01, -.57398300E-01, -.15476100E+00, -.11114200E+00, -.45417500E+00, 0.13020100E+00, -.23060900E+00, 0.15484000E+00, 0.62166800E-01, 0.49455900E-03, 0.59503600E-01, -.21067300E+00, 0.77702500E+00, -.63979500E+00, 0.94272500E-01, 0.45581000E+00, -.32441900E+00, 0.25008000E+00, 0.68499800E-01, 0.66059000E-01, -.40017400E-03, 0.43727800E-01, -.21239900E+00, -.48795200E-01, -.12408400E+01, 0.76791600E-01, -.16540600E-01, -.68091200E+00, -.12634600E+00, 0.71685800E-01, -.13216300E+01, 0.89627400E-02, -.56626900E-01, -.14984200E-01, 0.26121400E+00, -.18375300E+00, -.36236000E+00, 0.20607000E+00, 0.38952300E+00, -.11130600E+00, -.90677600E+00, 0.20659800E+00, -.50366700E-01, 0.42798700E+00, -.40759500E+00, -.22147200E+00, 0.59733600E-01, -.18582800E+00, -.40944300E-01, -.16110100E-01, 0.68530100E-01, 0.30121600E-01, -.15097400E+00, 0.48254300E-01, 0.55964000E-01, 0.29245600E+00, -.21702200E+00, 0.11470300E+00, -.39560900E-01, -.26167400E+00, -.11015000E+00, 0.58916500E-02, 0.74352100E+00, 0.13625300E+00, -.29677000E-01, 0.32048400E+00, 0.34375500E+00, 0.17586400E-01, 0.28359000E+00, 0.83817100E-01, 0.19883000E+00, 0.44677500E+00, 0.67595600E+00, -.29338200E-01, 0.25568600E-01, -.18554400E-01, 0.59404600E-01, -.35347500E-01, -.21197000E-01, -.48172900E-01, 0.22016300E+00, 0.30501900E+02, 0.64735200E+02, -.35791300E+02, 0.18878100E+02, 0.13123500E+03, 0.17246500E+02, -.62632100E+01, -.51533200E+02, 0.47525400E+02, 0.38028000E+02, 0.25943900E+02, -.16269300E+02, 0.18958100E+02, -.11794400E+03, 0.59036200E+02, 0.56697400E+01, 0.58371700E+02, 0.24150500E+02, -.40812600E+02, 0.53036100E+02, 0.58503500E+02, 0.25753900E+02, -.12726300E+02, 0.11878400E+03, 0.53844500E+02, -.26738500E+02, 0.12323700E+03, -.27433900E+02, 0.86701400E+00, 0.20207500E+02, -.24504400E+02, -.67042400E+02, -.12902100E+03, 0.15923900E+02, -.13416100E+03, -.16495100E+03, 0.82961000E+02, 0.69522200E+02, 0.78116800E+02, 0.83169500E+02, 0.15394800E+02, 0.83284400E+02, 0.22342300E+03, 0.18000200E+03, -.15738500E+02, -.91506100E+01, 0.42161600E+02, -.20727700E+02, -.75200800E+02, -.24878000E+02, 0.47901400E+02, 0.37096000E+01, 0.26772800E+02, 0.20310500E+03, 0.12578000E+03, -.18299400E+02, -.23147200E+02, -.29244900E+02, 0.14018600E+02, -.89793300E+02, 0.16145000E+02, -.13489300E+02, -.31543600E+02, 0.20504300E+02, -.13474600E+01, -.31586800E+02, -.17732500E+02, 0.53620700E+02, -.42606200E+02, 0.21330800E+02, -.93647000E+00, 0.21245800E+02, 0.84448600E+02, -.43152100E+02, 0.38702900E+02, 0.16343400E+03, 0.15199900E+03, -.46638100E+02, -.58339100E+02, -.58679700E+02, 0.28883800E+02, -.43497800E+02, 0.29881400E+02, 0.62858700E+02, -.66160600E+02, 0.53371700E+02, 0.85494000E+02, 0.97249900E+02, -.47047700E+02, -.61094400E+02, 0.16786400E+03, -.84027900E+02, -.19208600E+03, -.85898400E+02, 0.37251300E+00, -.41963300E+02, 0.87365600E+01, 0.12700300E+03, 0.38856800E+02, -.26762000E+02, -.71794100E+02, -.66795000E+00, -.20039500E+02, -.26616000E+02, 0.11341800E+02, 0.96844500E+01, 0.54914500E+01, -.17889800E+00, 0.26419700E+02, 0.35600000E+00, 0.36953600E+01, 0.17390400E+01, -.16818600E+02, 0.17382300E+02, 0.16369300E+02, -.11929800E+02, 0.16161700E+01, 0.46980700E+02, -.25020400E+02, 0.23640000E+02, -.47874400E+01, 0.28503400E+02, -.13792300E+02, 0.16964000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34000400E+00, -.93509200E+00, -.88212800E-01, -.58549400E+00, 0.22585400E+00, 0.55678000E+00, -.39076000E-01, -.40354700E+00, -.56358000E+00, -.23095600E-01, 0.62102400E-01, 0.91202500E-01, 0.30644400E+00, -.65610200E-01, 0.13680700E+00, 0.44550200E+00, 0.14987200E+01, 0.12459900E+01, 0.13666500E+00, 0.37534500E-01, -.21664600E-01, -.12203500E-01, 0.17674400E+01, 0.59151500E+00, -.60157800E+00, 0.28426900E-01, -.94403000E+00, -.50805600E-01, 0.65460900E-01, 0.75152000E-02, 0.21118200E+00, 0.32884800E+00, -.84649000E-01, 0.75697600E-01, -.79284400E-01, -.74843100E-01, 0.24645600E-03, 0.90861500E-01, 0.43606800E+00, -.55875700E-02, -.36708400E+00, -.41465000E-01, 0.55161500E-02, -.18979000E-01, -.49328600E-01, -.42985700E-01, 0.78362500E-02, -.29048800E-01, 0.84880500E-03, 0.88318100E-01, -.32236800E+00, 0.77245100E-01, 0.31716400E+00, 0.61992800E-01, 0.25870500E+00, 0.22043300E+00, 0.18511400E+00, -.63383200E-03, -.72556000E-01, 0.90834600E-01, -.47690600E-01, 0.26360900E-02, -.20608400E+00, 0.89712400E-01, 0.15207100E+00, 0.53023100E-01, -.50015700E+00, -.12616300E+00, -.32247900E-01, -.32560900E-03, -.66822900E-02, 0.12896300E+00, -.53858200E+00, 0.22184800E+00, -.23017500E+00, -.78201900E-01, 0.14760000E+00, -.17019800E+00, -.20796900E-01, -.91508200E-02, -.28876100E-03, -.63507500E-01, -.53375600E-01, 0.33932000E+00, 0.50748800E+00, 0.29186000E+00, 0.40963400E-01, 0.11411500E+01, -.21075700E+00, -.14049500E+00, -.22271400E-01, 0.88394700E-02, 0.43009900E-01, 0.23292900E+00, -.40013300E-01, -.24618000E+00, -.20068600E+00, 0.24192300E-01, -.30033400E+00, -.75653400E+00, -.91059400E+00, -.17487800E-01, -.29741800E-02, -.19588500E+00, 0.12688600E+00, 0.32431600E+00, 0.21132100E-01, 0.94590300E-01, 0.93444900E-01, 0.78518200E-01, -.35407400E-02, -.33984900E-01, 0.35074100E-01, -.10748500E-01, -.34355100E-01, 0.86544000E+00, 0.39627800E+00, -.64786500E-01, 0.10136900E+00, -.43914600E+00, -.79970800E-01, 0.60757100E-01, -.82083300E+00, -.70578400E-01, 0.23930900E-01, 0.95601600E-01, -.11751600E+00, -.22624500E-01, 0.14356300E+00, -.24632300E-01, 0.18393400E-02, -.35761600E+00, -.12319100E+01, -.48451800E-02, 0.45442500E-01, 0.68552500E-02, -.38289800E+00, 0.20188800E+00, -.12725400E-01, -.31810300E-01, 0.22558700E+00, 0.20163800E+00, 0.17422500E+03, 0.33409800E+01, -.95830600E+00, 0.34279700E+02, -.99049600E+00, 0.65240500E+01, -.49292500E+01, 0.11308400E+02, 0.30503700E+02, 0.20256600E+02, -.49170600E+01, 0.19365700E+03, -.22710900E+03, 0.11128000E+03, 0.11047800E+03, 0.11422000E+03, 0.85283300E+02, 0.65456700E+01, 0.47488100E+02, 0.41999100E+02, 0.49588100E+02, 0.15783100E+01, 0.22561200E+03, 0.12849800E+03, -.58165800E+02, 0.11642400E+03, -.63680700E+02, -.84476800E+01, -.15272800E+02, -.40950200E+02, -.45605100E+02, -.10672300E+03, 0.40061200E+01, -.45566700E+03, 0.29053500E+03, -.14528500E+03, 0.14386500E+03, -.14039200E+03, 0.11270300E+03, 0.90895800E+02, -.25176200E+03, -.17414500E+03, -.22656700E+03, 0.99606700E+02, -.25025500E+03, -.31477700E+02, 0.15239400E+02, 0.16593300E+03, 0.18924700E+02, 0.45253200E+02, -.96280100E+01, 0.16141600E+02, 0.10187400E+03, 0.18360800E+02, 0.17543000E+01, -.12135800E+03, -.12538800E+03, 0.61791900E+02, 0.94550200E+01, 0.60987200E+02, -.20525600E+02, -.35578300E+02, 0.79760500E+02, 0.83612400E+02, 0.67678900E+02, -.49594200E+02, -.25199100E+02, 0.31687000E+03, -.16027400E+03, 0.29545800E+02, -.15836900E+03, 0.62443000E+02, 0.76375700E+02, -.21207200E+03, -.14385800E+03, -.11416200E+03, 0.61443700E+02, -.13158900E+03, -.25261300E+03, 0.12824700E+03, 0.17912400E+02, 0.12570600E+03, 0.19768100E+02, -.44188600E+02, 0.11778100E+03, 0.10672300E+03, 0.12481200E+03, -.54997500E+02, 0.78034900E+02, -.14839000E+03, 0.74125300E+02, -.10533900E+03, 0.76722100E+02, 0.39183800E+02, 0.14521200E+02, 0.23136800E+02, -.30819900E+02, -.11484700E+02, -.32828700E+00, 0.17362200E+03, 0.78823700E+00, -.27697400E+02, -.38808700E+02, 0.95652800E+01, 0.10302500E+02, 0.13263500E+02, 0.49448000E+00, 0.38713900E+02, 0.10148200E+02, 0.15001500E+02, 0.13485600E+02, -.24248900E+01, 0.13990800E+02, 0.16687000E+02, -.23093500E+02, 0.17518200E+02, 0.35850900E+02, -.51413700E+00, -.83245000E+01, -.49726700E+01, 0.14279700E+02, -.30192600E+02, 0.35983000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27887900E+01, -.15983000E+01, -.16937600E+01, 0.14042300E+00, 0.13024300E+01, 0.37627400E+00, -.46344300E+00, -.29151700E+01, -.22335900E+02, 0.12855300E+01, 0.73835200E-01, -.17184100E+01, 0.77616100E+00, 0.25126700E+00, -.11107100E+01, 0.79377000E+00, 0.18837900E+01, -.17406500E+01, -.64948300E+00, -.89902000E+00, 0.97059900E+00, -.58156000E+00, 0.20045900E+01, 0.87984900E+00, -.18795500E+00, 0.89925300E-02, -.15579400E+00, -.70255400E-01, 0.17094100E+00, -.85687500E-02, -.72952800E+00, 0.41630300E+00, 0.84251000E-01, 0.17787200E+00, -.23103900E-02, -.11040600E+00, -.33889600E-02, -.15633600E-01, 0.20679400E+00, 0.38752200E-01, -.88557100E+00, -.29070800E+00, -.14068500E+01, -.92553700E+00, -.13504400E+00, -.11476500E+00, 0.48403400E+00, -.83387400E-02, -.61227200E+00, 0.39141400E+00, 0.22100600E-01, 0.12450300E+00, 0.18275900E+01, 0.48502200E+00, 0.55396600E-01, 0.35235200E+01, 0.15068500E+01, 0.19828900E+00, 0.55364100E+00, 0.67281500E+01, -.86076100E+00, 0.13377200E+00, -.84022700E+00, -.15567400E+00, 0.19291200E+01, -.24737300E+01, -.41046700E+00, -.34963900E+00, 0.25781500E+00, -.99633300E-03, 0.26938700E+00, 0.10375500E+01, 0.20809000E+01, 0.12078900E+01, 0.18816800E+01, -.21434000E+00, 0.12374100E+00, -.60301600E+00, 0.92029800E-02, 0.25486300E+00, 0.13614500E-02, 0.49397000E+00, 0.40450100E+00, 0.37922800E+00, 0.16465000E+01, 0.12019200E+01, 0.17536000E+00, -.34382100E+01, 0.58732100E+00, -.99774700E-01, 0.13664500E+01, 0.11003200E-01, 0.36513400E+00, 0.33344300E+00, -.47742700E+00, -.36422200E+00, -.81886300E-01, -.24076400E+00, -.13423400E+00, -.15760200E+01, 0.12308500E+01, -.59258400E+00, -.13473600E-01, 0.27753200E+00, 0.31500600E+00, 0.76359100E+00, -.13296900E+00, 0.71868200E+00, -.14337300E+00, -.23220700E+00, -.79272600E-01, -.11763200E+00, 0.34424800E+00, -.10911000E+00, 0.95709300E-01, -.36684800E+01, -.63452600E+00, 0.21930200E-01, 0.10681300E+00, 0.27189100E+00, 0.66002500E-01, 0.17681700E+00, -.12628300E+01, -.67973300E-01, 0.40101300E-01, -.79555700E+00, -.71961000E+00, 0.76199600E-01, 0.16009700E+00, -.44570700E-02, 0.89062800E-01, 0.16866000E+00, -.21724600E+01, 0.18125000E+00, 0.53230600E+00, -.77368000E-01, -.20707600E+01, -.30895400E+00, -.11808700E+00, -.20217000E-02, -.50190500E+00, 0.10478400E+01, -.12231000E+01, 0.49958000E+03, -.25391100E+03, -.21500400E+03, -.24962900E+03, -.57479300E+02, -.53239500E+02, -.76513600E+02, 0.68996600E+02, -.73045400E+02, -.52524500E+02, -.13174900E+03, -.10121500E+03, 0.48010000E+02, 0.76812100E+02, 0.50564800E+02, 0.46526200E+02, 0.11215200E+03, 0.65257300E+01, 0.13949100E+03, 0.14960600E+03, 0.67987800E+02, 0.34105100E+02, -.14216000E+03, 0.67310200E+02, 0.30454800E+02, 0.71040400E+02, 0.12744800E+03, 0.33283400E+02, -.29818800E+02, -.13637000E+03, -.17794000E+02, 0.61588000E+02, -.73405600E+01, 0.30990800E+03, -.15112400E+03, 0.79071400E+01, -.15549900E+03, -.17324800E+03, -.33111800E+01, -.10427100E+03, -.24147000E+03, -.37313900E+03, 0.21144900E+02, -.36517600E+03, 0.36102300E+03, -.17954100E+03, -.59445300E+02, -.18582000E+03, -.10344400E+03, -.16910800E+03, 0.78752100E+02, 0.37760600E+02, -.13746700E+03, -.15274800E+03, -.38626100E+03, -.43740600E+03, 0.21781400E+03, 0.40075700E+03, 0.21897500E+03, 0.55861300E+02, 0.14732300E+03, 0.64801800E+02, 0.12023200E+02, 0.27718600E+03, 0.14766500E+03, 0.28635800E+02, 0.19632100E+03, -.98924300E+02, 0.74183300E+02, -.98168700E+02, -.23054800E+03, 0.25957700E+03, -.35198000E+03, -.52632100E+03, -.28380900E+03, 0.20033000E+03, -.29251900E+03, -.61662900E+02, 0.31400500E+02, 0.19609000E+02, 0.30870000E+02, 0.21379900E+02, 0.13308100E+03, 0.18944200E+02, 0.20555200E+02, -.14948900E+03, 0.70046700E+02, -.46065500E+02, -.15514400E+03, 0.77202500E+02, 0.27703500E+03, 0.74353100E+02, 0.10795200E+02, 0.89431300E+02, -.44917900E+02, -.11991300E+03, -.25228500E+03, 0.45651200E+02, 0.13597400E+03, -.11618900E+02, 0.10794500E+01, 0.73002200E+01, -.65372300E+01, -.13126600E+02, -.17360400E+02, -.99693700E+01, -.67662000E+01, 0.37565300E+01, 0.17427800E+02, 0.12242500E+02, 0.51868200E+00, -.33828300E+02, -.14819400E+02, 0.19956300E+02, 0.11122700E+01, -.16940000E+02, 0.32374300E+02, -.52751600E+02, -.16433700E+02, 0.33187800E+01, -.18867000E+02, 0.81514900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26975800E+01, -.11965600E+01, 0.77803500E+00, -.14953600E+00, -.36309400E+00, -.30803000E+01, 0.72462100E+00, 0.61375700E+00, -.23876300E+02, -.19653900E+01, 0.87250800E-01, -.38541000E+00, -.60491100E+00, 0.23051300E+00, 0.18574400E+01, -.76202600E+00, -.97460600E-01, 0.38887500E+01, 0.79644800E+00, 0.29834700E+01, -.78196200E+00, -.51000200E+00, 0.42398800E+01, -.91454300E+00, -.11268400E+01, -.37271600E-02, -.35251800E+00, 0.10310100E+00, 0.24509500E+00, -.15706200E+00, 0.14652500E+01, 0.10131700E+00, 0.24809300E+00, -.64025000E+00, 0.97537800E+00, -.31842600E+00, -.13743400E-01, -.47544500E+00, -.62735600E+00, 0.23767700E+01, -.24738900E+00, -.15169200E+00, 0.72818200E+00, 0.15659700E+00, -.78982700E+00, 0.29653500E+00, 0.47915600E+00, -.15112600E+00, -.21974700E+00, 0.94746600E+00, 0.22566100E-01, 0.55954100E+00, 0.12022300E+00, -.72071700E+00, 0.10319200E+01, -.51547300E+00, 0.33866300E-01, 0.13718700E-01, -.42909300E+00, 0.24872800E+00, -.20263400E+00, 0.11885000E+00, 0.42536200E+00, 0.84924100E-01, -.12312600E+01, 0.15917400E+01, 0.87742100E+00, -.32549700E+00, -.20642600E+00, -.51107800E-03, -.14112700E+00, -.11395300E+01, 0.26299900E+01, -.12116500E+01, 0.19143000E+01, -.39708700E+00, -.12616700E+00, -.89194400E+00, 0.19236900E-01, -.57100000E-01, 0.16540800E-02, -.22170100E+01, 0.10217000E+01, -.27841300E+00, -.82794300E+00, -.16312000E+01, -.30599400E+00, 0.93953500E+00, -.78997700E+00, 0.30313000E-01, -.49123200E+00, -.56274500E-01, -.28938000E+00, -.53285300E+00, 0.15301400E+00, 0.51942300E+00, -.64015500E+00, -.10661700E+00, 0.65293700E+00, -.12379600E+00, -.15114000E+01, 0.47340800E+00, 0.94682900E-01, -.10526500E+01, 0.35620400E+00, 0.14576200E+01, 0.42875900E+00, 0.19871200E+00, -.13987100E+00, 0.73673600E-01, 0.23982500E+00, 0.10303100E+00, 0.16936000E+00, -.54303600E-01, -.15003800E+00, -.10043400E+01, -.25724200E+00, -.17604000E-01, 0.92034700E-02, -.42239700E+00, -.46411900E+00, -.97214700E-01, 0.26901700E+01, 0.70534700E+00, -.16406400E-01, 0.44634400E+00, 0.95915300E-01, 0.21383800E+00, 0.93725000E+00, -.66457800E-01, 0.41333600E-01, 0.12932600E+01, 0.10912200E+01, -.10724700E+00, -.54270100E+00, -.20142700E-02, 0.10177700E+01, -.80188500E-01, -.38669200E+00, 0.19616200E-01, 0.47302000E+00, -.11546500E+01, 0.22345300E+01, -.70168500E+00, -.25587200E+02, 0.33726900E+03, -.30782500E+01, -.44517600E+02, -.77238600E+02, 0.17642700E+02, -.70739400E+02, -.72649000E+02, -.63705000E+02, -.21119700E+03, 0.46293800E+03, -.23018500E+03, -.34727000E+03, -.23492600E+03, -.15713000E+03, -.49146100E+02, 0.16142900E+02, 0.55973800E+02, -.57900700E+02, -.31547400E+02, -.39915400E+03, -.36915400E+03, 0.16085000E+03, 0.86970300E+02, 0.18161000E+03, 0.51550200E+02, 0.72332300E+02, 0.42209500E+02, -.34716400E+02, 0.18118400E+03, 0.34423900E+02, 0.11963300E+04, -.11747100E+04, 0.59923000E+03, -.38748100E+03, 0.56158300E+03, -.20799100E+03, -.72616800E+02, 0.72834200E+03, 0.18543300E+03, 0.54850900E+03, -.15123000E+03, 0.83784300E+03, 0.15289900E+03, -.71225000E+02, -.64999400E+03, -.10214600E+03, -.14342700E+03, -.32810700E+02, -.72094900E+02, -.24891800E+03, 0.10101300E+02, -.92863400E+02, 0.43555100E+03, 0.12823600E+03, -.64334100E+02, -.36999500E+03, -.55020200E+02, 0.10549300E+03, 0.97638600E+02, -.13582800E+03, -.11116500E+03, 0.82122100E+01, 0.13059800E+03, 0.31041800E+03, -.68025300E+03, 0.34626500E+03, -.35118400E+03, 0.33977000E+03, -.14558800E+03, -.12796500E+02, 0.31993400E+03, -.62564800E+02, 0.14893900E+03, -.38564800E+02, 0.16564500E+03, 0.37234900E+03, -.19277000E+03, -.18593200E+03, -.18304800E+03, 0.97467200E+02, 0.20537000E+02, -.14621700E+03, -.25021000E+03, -.23810300E+03, 0.79965900E+02, -.33836800E+03, -.14022300E+03, 0.70172700E+02, 0.96887800E+02, 0.49692800E+02, -.69765500E+01, -.73158300E+02, 0.11691800E+03, 0.39208500E+02, 0.17557900E+03, -.23886800E+02, -.38135600E+03, 0.55855500E+01, 0.36519500E+02, 0.91758100E+02, -.21737200E+02, -.19162000E+02, -.41653600E+02, 0.22950100E+01, -.91566000E+02, -.19542800E+02, -.35287400E+02, -.29751900E+02, 0.14907400E+02, -.46294500E+02, -.15607200E+02, 0.44923300E+02, -.30158900E+02, -.10999200E+03, -.22115000E+02, 0.16388100E+02, 0.88757800E+01, 0.25003400E+02, 0.45777000E+02, -.44986400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.74299900E+00, -.15273300E+01, 0.16939500E+00, -.84444200E+00, 0.21538600E+00, 0.83265000E+00, -.49056600E+00, 0.75373000E+00, 0.18639100E+02, -.68406900E+00, -.49279800E-01, 0.77382700E+00, 0.26648800E+00, -.79249500E-02, -.59379700E+00, 0.69110200E+00, 0.14193900E+01, 0.13086600E+01, -.10734000E-01, -.17297200E+01, -.26667700E+00, 0.36517000E+00, -.16195900E+01, -.26317200E+00, 0.12410400E+01, -.48012300E-01, 0.88069800E+00, -.82248300E-01, -.28617400E+00, 0.12683600E+00, -.59795200E+00, 0.26820800E+00, -.91774900E-01, 0.51627000E+00, -.14750500E+00, 0.64140200E-01, 0.81461700E-02, -.43462900E+00, 0.49635400E+00, -.24770800E+00, 0.38376600E+00, 0.14733000E+00, 0.77983800E-01, 0.33568300E+00, 0.24931700E+00, -.15347000E-01, -.11155800E+00, 0.91355700E-01, -.28372800E-01, -.25628400E+00, -.14704400E+01, -.45151900E+00, -.35900300E+00, 0.29360700E-01, -.27809500E+00, -.75759100E+00, -.76828100E+00, -.10480500E+00, 0.15292900E+00, -.29274800E+01, 0.88166900E+00, -.14788200E+00, 0.36486900E+00, -.11039900E-01, -.29692800E+00, 0.10752400E+01, -.16635400E+01, -.10034700E+00, 0.14311100E+00, -.60527000E-03, 0.31266300E+00, -.17626400E+00, -.46874800E+00, 0.11170200E+01, -.35149800E+00, -.43147800E+00, 0.56602600E-01, 0.20492100E+00, -.12063500E+00, -.15152800E+00, 0.25638200E-02, -.40205600E+00, 0.24918600E-01, 0.92973700E-01, 0.36566800E+00, -.97557900E-01, -.17618800E-01, 0.29775400E+01, 0.32830100E+00, -.10239000E+00, -.71534300E-01, 0.46269900E-01, -.21378200E+00, 0.74080000E+00, 0.14784400E+00, 0.16804400E+00, -.27685400E+00, 0.10135500E+00, 0.76779700E+00, 0.45515700E+00, 0.10699700E+00, 0.12359600E+00, -.10809000E+00, 0.65378900E+00, -.61339900E+00, -.61448100E-02, -.97847700E-01, -.13626500E+00, 0.13080900E+00, 0.25884400E+00, -.46373300E-01, -.34345300E+00, -.13963000E+00, 0.44475800E-01, 0.77374300E-01, 0.16545500E+01, 0.29592000E+00, 0.15382000E+00, 0.98546200E-02, 0.17517800E+00, 0.53535400E+00, -.17753000E+00, 0.10935500E+00, -.25688300E+00, -.58932600E-01, 0.24324200E+00, 0.40963500E+00, 0.84790400E-01, -.38289600E-01, -.20488100E+00, 0.10364800E+00, 0.21496900E+00, 0.15579700E+01, 0.33158900E-01, -.43256900E+00, 0.90021400E-02, 0.13510200E+00, 0.43726300E+00, 0.14777500E+00, -.29963700E-01, -.60047100E+00, 0.48756000E+00, -.58558900E+00, 0.48993000E-01, 0.77459500E-01, -.20279800E+03, 0.15704200E+01, -.62191400E+01, -.10390400E+01, -.22146600E+02, -.62972500E+02, 0.18340300E+02, 0.14143600E+01, 0.12378600E+03, -.20535000E+03, 0.98735700E+02, 0.26977700E+03, 0.10494100E+03, 0.52143200E+02, 0.41901400E+02, -.18449300E+02, -.70618600E+02, 0.55866400E+01, 0.16091500E+02, 0.14477900E+03, 0.24281400E+03, -.11155100E+03, -.85897800E+02, -.11945000E+03, 0.43885000E+01, -.37323300E+02, -.50440400E+02, 0.20275600E+01, -.90971100E+02, 0.62013000E+01, -.73860900E+03, 0.10522600E+04, -.52761500E+03, 0.22122200E+03, -.50877700E+03, 0.77864000E+02, 0.22629900E+03, -.61161900E+03, -.36009200E+03, -.61799800E+03, 0.21207600E+03, -.65229600E+03, -.14524600E+03, 0.70888900E+02, 0.48964200E+03, 0.85954500E+02, 0.21849000E+02, 0.49802200E+02, -.52347300E+02, -.90402800E+02, -.11161100E+03, 0.69567000E+02, -.14471900E+03, -.23641700E+02, 0.12594600E+02, 0.22667700E+03, 0.55795700E+01, 0.62669800E+01, 0.62436500E+02, 0.47908300E+02, 0.14472300E+03, 0.50068400E+02, 0.30698300E+02, -.20597400E+03, 0.77831500E+03, -.39224600E+03, 0.18878800E+03, -.38891300E+03, -.36373500E+02, 0.16361000E+03, -.35912000E+03, -.20516200E+03, -.30956300E+03, 0.11647500E+03, -.31568300E+03, -.32127900E+03, 0.16452200E+03, 0.16116000E+03, 0.15858600E+03, -.51057000E+02, 0.42957300E+02, 0.86225800E+02, 0.29563500E+02, 0.10529600E+03, -.29729000E+01, 0.11600500E+03, -.41436700E+03, 0.20724100E+03, 0.10486100E+03, 0.21572100E+03, 0.69311300E+02, 0.68508000E+02, 0.15166300E+02, -.18184500E+03, -.32366400E+02, 0.34816500E+02, 0.33230000E+03, 0.35989700E+01, -.32522400E+02, -.38733900E+02, 0.69628200E+00, -.69266200E+01, 0.20569600E+01, 0.28855900E+01, 0.38616200E+02, 0.20867500E+02, 0.25573000E+02, 0.23979600E+02, 0.71467100E+01, 0.96581300E+01, -.95297700E+01, -.15285900E+01, 0.27046300E+02, 0.56453900E+02, 0.32520800E+02, -.32427600E+02, -.51406000E+01, -.24061000E+02, -.26646100E+02, 0.45183600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30591100E+01, 0.34589400E+01, 0.57328800E+00, 0.11478300E+01, -.11642100E+01, -.12541500E+01, 0.67365600E+00, 0.33591400E+00, -.40069500E+02, 0.77196000E+00, 0.19767800E+00, -.16292300E+01, -.57926300E+00, 0.39944800E-01, -.20281200E+01, -.44092600E+01, -.69074900E+01, -.19376600E+01, 0.18706200E+00, 0.49727100E+01, -.18745900E+01, 0.78674800E-01, -.37392200E+01, 0.90238700E+00, 0.67209800E-01, -.48892700E-02, 0.23028900E+01, 0.58071300E+00, -.33868000E+00, -.28301300E+00, -.78025000E+00, -.69303500E+00, 0.26119800E+00, -.14248100E+01, -.95975600E+00, 0.19904700E+00, 0.23141100E-01, -.11848500E+00, 0.24663200E+01, -.17963200E+00, 0.17771300E+01, 0.83168900E+00, 0.21935700E+01, 0.18370200E+01, -.52874200E-01, -.26762900E+00, -.20642200E+01, 0.66648800E-01, 0.96931100E+00, 0.35316700E+00, 0.34884400E+01, 0.38995100E+00, -.21555300E+01, -.75682500E+00, -.45664900E+00, -.71844200E+01, -.39031900E+01, -.13198000E+00, 0.56521800E+00, -.64444400E+01, 0.22465100E+01, -.47197600E+00, -.68481800E+00, 0.44406200E+00, -.63122500E+00, 0.13074400E+01, -.35894000E+01, 0.12461300E+01, 0.26163300E+00, 0.22861600E-02, -.51183300E+00, 0.23267900E+00, -.20848900E+01, 0.39689300E+00, -.63024300E+00, -.71066700E-01, -.66689900E+00, -.34503000E+00, 0.17730400E+00, 0.13436900E+00, -.18081900E-03, -.13268200E+01, 0.73456200E-01, -.59375300E-01, 0.20474600E+01, 0.60747300E+00, -.41973000E-01, 0.57007000E+00, -.10700400E+01, -.13687100E+00, 0.30293300E+01, -.56361800E-01, -.27740700E+00, -.83292100E+00, -.32971600E+00, 0.10538600E+01, -.89889000E+00, -.60924500E-01, 0.18613400E+01, 0.25387100E+00, 0.75820600E-01, 0.32867800E+00, 0.57902400E-01, 0.61271200E+00, 0.69037600E+00, 0.19413100E+01, 0.34999600E+00, 0.31592300E+00, 0.38485900E+00, 0.48281500E+00, -.13230900E+00, -.68736600E+00, -.36474400E+00, 0.11182900E+00, 0.28670800E+00, 0.49922500E+01, 0.29071400E+00, 0.29464700E+00, -.51826400E-01, 0.26454400E-01, 0.12731300E+01, -.35470800E+00, 0.18866500E+00, -.46461200E+00, -.77608800E-01, 0.14018400E+01, 0.14968800E+01, -.16949400E+00, -.33591800E+00, 0.42042300E+00, 0.52689000E+00, -.39571500E+00, 0.33604800E+01, -.96519500E-01, -.65665400E+00, 0.21973600E+00, -.70222400E+00, 0.10727500E+00, 0.83758300E-01, -.23340400E+00, -.11092200E+01, 0.20184400E+00, 0.36380100E-01, 0.31144600E-01, 0.20948800E+00, 0.10029900E+01, 0.35722200E+02, 0.18272600E+02, 0.27152200E+02, 0.21784100E+02, 0.16254200E+03, 0.12818800E+02, 0.19714000E+02, 0.23671200E+02, -.22640400E+02, 0.11442900E+02, -.27216400E+02, 0.13314800E+02, 0.54579700E+02, 0.20765900E+02, 0.11445500E+02, 0.20828900E+02, 0.59239700E+02, 0.33960000E+02, 0.35504600E+02, 0.11523600E+03, -.54430300E+02, -.27422900E+02, -.56015500E+02, -.95887700E+02, -.18369300E+01, -.24414600E+02, -.26735000E+02, -.82060300E+02, -.28282400E+02, -.16975600E+02, -.22710700E+03, 0.11136000E+03, 0.27188600E+02, 0.12446100E+03, 0.30353400E+02, -.12541000E+03, 0.80911900E+02, -.53300700E+02, 0.12924200E+03, -.38529000E+02, -.15070100E+02, 0.51326400E+02, -.26420400E+02, -.52137400E+02, -.19685500E+02, 0.60922000E+02, -.23950600E+02, 0.97406400E+02, 0.19986800E+03, 0.68245100E+02, -.77486700E+01, -.15307200E+03, -.17133500E+03, 0.84457500E+02, 0.76391900E+02, 0.82702000E+02, -.32683400E+02, -.64587600E+02, 0.39707200E+02, -.84279700E+02, 0.25016800E+02, -.59467800E+02, 0.27978000E+02, -.33510300E+03, 0.16635800E+03, 0.82323100E+02, 0.16764800E+03, 0.98283000E+02, -.94036700E+02, 0.70440000E+02, 0.14277500E+02, 0.11094400E+03, -.18147100E+02, 0.12065000E+03, 0.14026400E+03, -.69092900E+02, -.57946700E+02, -.71891500E+02, -.32531100E+02, 0.11117800E+01, 0.27202500E+01, 0.14051700E+03, 0.83387300E+01, -.20248400E+02, 0.13509200E+03, 0.39336200E+03, -.19675600E+03, -.15240800E+03, -.19690700E+03, -.52929800E+02, 0.89971000E+01, -.91777000E+02, 0.82821900E+02, -.11327500E+03, -.56314700E+01, 0.12752200E+02, -.16441800E+01, 0.18721500E+02, -.13520100E+02, 0.43030700E+01, 0.35369800E+01, 0.55226500E+01, -.15838600E+01, 0.13718200E+02, -.19523100E+01, 0.38909400E+01, -.10431800E+00, -.21921400E+02, 0.15741600E+02, 0.38251200E+01, -.77312000E+01, -.11603400E+01, 0.70680700E+02, -.14691700E+02, 0.18593500E+02, 0.82877600E+00, 0.80353400E+01, -.56354800E+01, -.20491700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.65491600E+00, -.14746400E+01, -.69478600E-01, -.12402700E+01, 0.42405100E+00, 0.16907900E+01, -.41050200E-01, -.10472800E+01, -.59102800E+00, 0.54800600E+00, 0.42677500E-01, -.51294300E+00, -.12916900E+00, 0.12050100E-01, -.30492100E+00, -.77568000E+00, -.53277200E+00, 0.87516200E-01, 0.23451200E-01, -.24427000E+00, -.63560800E+00, 0.17538400E+00, 0.24065400E+01, -.24953700E+00, -.10507100E+01, 0.24017300E-01, -.19792600E+01, -.62581400E-01, -.15327500E+00, 0.54492500E-02, 0.48254300E+00, 0.10006300E+00, -.13594200E+00, -.19178300E+00, -.46679400E+00, -.80145400E-01, 0.10101200E-01, 0.79059700E+00, 0.60964100E+00, -.79517400E-01, 0.79388100E+00, 0.23576800E-01, 0.83888500E+00, 0.24657400E+00, 0.85667400E-01, 0.11853700E+00, -.33836400E+00, -.40772400E-01, -.29963800E-01, -.58582500E-01, 0.29766300E+00, -.22586900E+00, -.54572100E+00, 0.29000000E+00, 0.56794800E-01, -.19485200E+01, -.62489400E+00, 0.29971200E-01, -.97077500E-01, -.65982600E+00, 0.24758200E+00, -.10163400E+00, -.41196000E+00, -.10852800E+00, -.14212300E+00, 0.76457500E+00, -.13959100E+01, 0.15782100E+00, -.51228000E-02, -.20267100E-03, -.23565600E+00, -.12536600E+00, -.25394400E+01, 0.53227300E+00, -.13568600E+01, -.70772500E+00, 0.22233100E+00, 0.15108400E+00, 0.90414000E-01, -.80776500E-01, -.27106700E-02, 0.18119900E+01, -.13464100E+00, 0.19408300E+00, -.97065500E+00, 0.32779800E+00, 0.12849100E+00, 0.72014100E+00, -.25208600E-01, -.32300900E-01, 0.15233600E+01, 0.14860600E-01, 0.10496100E+00, 0.41864300E+00, -.24156800E+00, 0.22309900E+00, -.15669100E+00, -.23533300E+00, 0.57069000E-01, 0.11920400E+01, 0.87734400E+00, -.13805100E+00, 0.12014000E-01, -.20573000E+00, 0.49761700E+00, 0.53942300E+00, -.77761300E-01, -.89906000E-01, 0.16966000E+00, 0.27612400E-01, 0.78138400E-01, 0.31215400E+00, -.27294900E-01, 0.85743700E-02, -.78330100E-01, 0.15798100E+01, 0.70980500E+00, -.11430500E+00, -.72240600E-01, 0.86520600E+00, 0.24631900E+00, 0.30953400E-01, -.83308700E+00, -.26930600E+00, 0.14412100E-01, -.47361000E-01, -.54138300E+00, -.23850700E-03, -.15230100E+00, -.42705200E+00, -.70667200E+00, 0.85834000E-01, -.21984500E+01, 0.11493900E-01, 0.24031800E-01, 0.37402000E-01, 0.21738900E+00, -.13166000E+00, -.32762600E-01, 0.13843400E+00, 0.25545900E+00, -.13729700E+01, 0.43477800E+00, -.24179000E+00, -.52666000E-01, -.50572800E+00, 0.19310300E-01, -.41989400E+02, -.80598600E+02, 0.87339000E+01, -.82051700E+02, -.11557500E+02, -.62502400E+02, -.28548400E+02, 0.37452800E+01, -.32994000E+01, 0.16180400E+03, -.17451200E+01, -.69037900E+02, 0.47101100E+00, -.22667500E+02, -.16161000E+03, -.82608200E+02, 0.76470900E+01, -.73483600E+02, -.22723400E+02, 0.82302000E+01, 0.20940000E+02, 0.11456200E+02, 0.72805600E+02, 0.19414000E+02, -.17017200E+01, 0.77441500E+01, 0.70301500E+01, 0.49528700E+02, -.16809700E+03, 0.53572400E+03, -.26640700E+03, -.22459100E+02, -.26737300E+03, 0.18726300E+01, 0.30222800E+03, -.31078700E+03, -.21832000E+03, -.28328300E+03, 0.19153900E+03, -.11577900E+03, -.86433400E+02, 0.43277300E+02, 0.17918400E+03, 0.43825300E+02, -.92092100E+02, 0.94972200E+02, -.16424400E+03, -.28394200E+03, -.84811400E+02, 0.53790100E+02, 0.21542300E+03, 0.21593300E+03, -.10647600E+03, -.75957300E+02, -.10806700E+03, 0.50679400E+02, 0.12501200E+03, -.39017100E+02, 0.92747700E+02, -.30273400E+02, 0.10120400E+03, -.10452800E+03, 0.63805100E+03, -.31857000E+03, -.10836500E+03, -.31902900E+03, -.12530900E+03, 0.19200100E+03, -.21744300E+03, -.11601000E+03, -.20627900E+03, 0.10201500E+03, -.18257700E+03, -.18580500E+03, 0.93493700E+02, 0.10322600E+03, 0.92793900E+02, -.47718600E+02, 0.34154600E+02, -.55474500E+00, -.18425200E+03, 0.50781400E+02, 0.47752000E+02, -.65825200E+02, -.52133100E+03, 0.26087600E+03, 0.84038400E+02, 0.25977100E+03, 0.25988100E+02, -.22557900E+02, 0.12496300E+03, -.12992700E+03, 0.19070300E+03, 0.11949400E+01, 0.10179500E+03, 0.39282500E+01, -.20898400E+02, 0.18222700E+01, -.14389500E+02, -.11035000E+02, -.17114000E+02, 0.18022000E+01, -.21926200E+01, 0.16199600E+02, 0.10099600E+02, 0.11980000E+02, 0.14214900E+02, -.73134000E+01, -.11229400E+02, 0.20347400E+02, 0.16982400E+02, -.36511100E+01, 0.16246100E+02, -.15966800E+02, 0.26878000E+01, -.94970900E+00, 0.61511700E+01, 0.26204100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10611000E+01, -.38105500E+00, -.18251500E+00, -.12960200E+00, 0.70149500E-01, -.18043400E+00, -.74814700E-01, 0.46451600E+00, 0.43523300E+01, -.57865700E+00, 0.70069700E-01, 0.82295300E+00, 0.51160100E+00, -.15310500E+00, 0.97304500E-01, 0.16892200E+01, 0.27449900E+01, 0.23250400E+00, -.35054500E-01, -.55735200E+00, 0.10094800E+00, -.43251600E+00, 0.76669600E+00, -.10512200E+00, -.28614600E+00, 0.11500300E-01, -.45366700E+00, -.11327600E+00, 0.36221200E+00, -.15725300E-01, 0.45424700E+00, 0.12954200E-01, -.27890100E-01, 0.36119100E+00, 0.31192900E+00, -.35498800E-01, -.44371400E-02, -.66594200E+00, -.56333100E+00, -.10809400E+01, -.19179500E+00, -.30157100E-01, -.56103900E+00, 0.29160700E-01, -.84027800E-01, -.13447500E+00, -.75797800E-01, -.57972000E-02, -.51169600E+00, 0.17021100E+00, 0.12426500E+01, 0.59002500E+00, -.63300100E+00, -.72646200E-01, -.12640100E+00, -.57690100E+00, -.14014700E+01, 0.82745100E-01, -.10913800E+00, -.11941800E+01, 0.95248000E-01, 0.73865500E-02, -.93435100E+00, 0.39085700E+00, 0.24493400E+00, 0.28282100E+00, -.53260400E+00, 0.46278000E+00, 0.55488900E-01, 0.22980300E-02, -.22274200E+00, 0.10333200E+01, -.18598000E+01, 0.40195000E+00, -.76906200E+00, 0.19274500E+00, -.65285200E+00, -.18102200E+00, 0.92093300E-02, 0.74631700E-01, 0.12992300E-02, -.70413400E+00, 0.33519600E-01, -.19181300E+00, 0.47789400E+00, 0.42444100E+00, 0.59436500E-02, 0.86300900E-01, -.38363100E-01, -.12339800E-01, 0.14927800E+00, 0.30155800E-02, -.17184800E-01, 0.59349600E-02, -.56132100E-01, 0.93075900E-01, -.63729400E+00, -.32253900E+00, -.11963400E+00, -.95652900E+00, -.10200100E+01, -.55127000E-01, 0.18930000E-01, -.25241100E+00, 0.23375400E+00, 0.17805300E+00, 0.22635800E-01, 0.19643200E+00, -.13380000E+00, -.27132700E-01, -.13561000E-04, 0.10877200E-01, -.13243600E+00, 0.42116200E-01, -.63081500E-01, -.18081400E+01, -.34579100E+00, 0.55878500E-01, -.14209100E-02, 0.16485000E+00, -.59776200E-01, -.11362200E-01, -.32000600E+00, -.68640100E-01, -.70010200E-02, 0.17257400E+00, 0.35791600E+00, -.10243500E+00, 0.16543900E+00, -.35794600E+00, -.36705100E-01, -.46069600E+00, 0.11088300E+01, -.56630800E-01, -.24049000E+00, 0.74501600E-02, 0.53839300E+00, 0.31636000E-02, -.19242600E+00, -.59841600E-01, 0.53117000E+00, 0.12997000E+00, 0.46629800E+00, -.27940600E-02, -.61518100E-02, 0.24477100E+00, -.12277600E-01, -.97526300E-01, 0.27945500E+02, -.68966700E+02, -.89340700E+02, -.29525800E+02, 0.23333200E+02, 0.89489800E+01, 0.16256100E+03, -.79926700E+02, -.99649500E+02, -.82049900E+02, -.65893800E+02, -.50088500E+02, -.50274400E+01, -.22854400E+02, -.29930100E+02, -.47529400E+02, -.14305600E+03, -.14866400E+03, 0.72073200E+02, -.30640500E+02, 0.73661200E+02, -.77684400E+01, -.41294200E+01, 0.42813900E+02, 0.46538600E+02, 0.12015300E+03, -.21510100E+02, 0.40988800E+03, -.35439200E+03, 0.17756800E+03, -.27105000E+02, 0.17108900E+03, -.20446900E+02, -.23824800E+02, 0.17308500E+03, -.51408100E+02, 0.11340000E+03, -.26748200E+02, 0.31597100E+03, -.11384500E+03, 0.57158800E+02, -.54157800E+02, 0.53577700E+02, -.17245300E+02, 0.36273500E+02, -.66324700E+02, -.22293800E+03, -.53056000E+02, 0.34633700E+02, 0.17324300E+03, 0.11093700E+03, -.55307000E+02, -.17056100E+03, -.53232300E+02, 0.34924300E+02, 0.86951900E+01, -.53207300E+02, -.81568100E+01, -.18255000E+02, 0.21909800E+02, 0.60419300E+02, -.22239900E+03, 0.11210400E+03, -.56204900E+02, 0.11111000E+03, 0.60634000E+01, -.48118300E+02, 0.15353100E+03, 0.16483300E+02, 0.35875700E+02, -.37964800E+02, 0.12731800E+03, 0.18403600E+03, -.93105300E+02, -.42409400E+02, -.91317800E+02, -.32431800E+02, -.23598800E+02, -.56858000E+02, -.92501100E+02, -.86843700E+02, -.13476400E+01, -.10996800E+03, -.96112400E+02, 0.48111900E+02, 0.71904800E+02, 0.46650300E+02, -.32775200E+02, -.23261500E+02, 0.25246700E+02, -.91839300E+02, 0.64378200E+02, -.43851600E+01, -.10637600E+03, 0.41259100E+01, 0.14863300E+02, 0.29980700E+02, -.91495100E+01, -.13840700E+02, -.11242000E+02, 0.32822100E+01, -.29627700E+02, -.89497400E+01, -.19110200E+02, -.14744300E+02, 0.19090100E+02, -.18675000E+02, -.14936500E+02, 0.11911300E+02, -.13217700E+02, -.61239500E+02, 0.55191900E+01, -.29628600E+01, 0.91236500E+01, -.13036700E+02, 0.16967300E+02, -.16259800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31736800E+00, 0.76481800E+00, -.13196600E+00, 0.39995200E+00, -.26887100E+00, -.53204800E+00, 0.21046700E-01, 0.14603200E-01, -.53874200E+01, -.52157000E+00, 0.47706800E-01, -.10601500E+00, 0.57004000E-01, -.30527000E-01, 0.16401500E+00, 0.24269600E-01, -.69820500E-01, -.30640700E-01, -.14799200E-01, 0.69279500E+00, 0.22236800E-01, -.15947700E+00, 0.49151300E+00, 0.18745700E+00, -.15281200E+00, 0.17206400E-01, -.13666700E-01, 0.14972900E-01, 0.34948600E-02, -.33664900E-01, 0.19989000E-02, 0.84466500E-01, 0.69254900E-01, 0.88786300E-01, 0.11480200E+00, 0.20762500E-01, -.60250900E-02, -.67809100E-01, -.17346600E+00, 0.14279500E-01, -.33487200E+00, -.45473600E-02, -.46089400E+00, -.12600100E+00, -.77063100E-01, 0.41365300E-01, -.40517200E-01, -.27815500E-01, -.81111000E-01, 0.67970900E-01, -.56888100E+00, -.66010600E-01, 0.56067200E-01, -.11759700E-02, 0.27822700E+00, 0.16780000E+01, 0.44500000E+00, -.26188600E-01, 0.11082300E+00, 0.68325500E+00, -.76394400E-01, 0.37954600E-01, -.35405000E+00, 0.44030500E-01, 0.46652100E+00, -.40803300E+00, 0.88679600E+00, -.64541700E-02, -.19801200E-01, -.79731200E-03, 0.19516000E-01, 0.86460800E+00, -.71054700E-01, 0.14101000E+00, 0.17827900E-01, -.27554800E-01, 0.49408700E-01, -.25926700E-01, -.18253800E-02, 0.27119400E-02, -.65482600E-04, 0.11066000E+00, 0.30250400E-01, 0.20820400E-01, 0.67027000E-01, -.34562200E-02, 0.60149400E-02, -.17939000E+00, 0.50500500E-01, 0.93018800E-03, 0.86453100E-01, -.10696900E-02, 0.11776000E-01, 0.47684800E-02, -.12988900E-01, -.19706600E-01, 0.99403500E-01, 0.30685000E-02, -.31626300E+00, -.33017700E-01, 0.12541000E+00, -.65731300E-01, 0.17008600E-01, 0.37284700E-02, -.39347600E-01, -.33700900E-01, 0.24556300E-01, 0.46702400E-01, -.23433300E-01, -.44890700E-02, -.11595700E-01, -.31456500E-02, -.10305300E-01, 0.30866100E-02, -.23139800E-01, -.65610800E+00, -.11646500E+00, -.41197600E-01, -.12181000E-01, -.16864900E+00, -.63328500E-01, 0.17751300E-01, -.13948200E+00, 0.92647900E-03, 0.14712400E-01, -.78584900E-01, 0.15015000E-01, -.15071100E-01, -.76388900E-01, 0.48714200E-01, -.72069500E-01, -.14620200E-01, -.88067400E+00, -.31630000E-03, 0.63876300E-01, 0.22894400E-02, -.17854800E+00, -.69480200E-01, 0.10014600E-01, 0.18731300E-01, 0.44985300E-01, -.54654600E+00, 0.33027100E+00, -.35844600E-01, -.36246900E-01, -.30920300E+00, -.45647400E-02, 0.30339900E+00, -.42826800E+00, -.21493300E+02, -.30959200E+02, 0.24234600E+01, -.35106900E+01, -.41426600E+01, 0.37552900E+02, -.17571800E+02, -.30830100E+02, -.19017000E+02, -.20882700E+02, -.25292600E+02, 0.67345400E+01, 0.37429200E+02, 0.21283800E+01, -.22733200E+02, -.29154300E+02, -.52060600E+02, 0.25123600E+02, -.15778500E+00, 0.25830400E+02, 0.14538900E+02, 0.76359100E+01, 0.85010500E+01, -.97666500E+01, 0.24675700E+02, 0.24218400E+01, 0.10737600E+03, -.16667000E+03, 0.83211600E+02, -.25936900E+02, 0.81779500E+02, -.20540600E+02, -.45338200E+02, 0.15338300E+03, 0.16263000E+03, 0.12567500E+03, -.56926000E+02, 0.84478000E+02, -.83844800E+01, 0.43630500E+01, -.67930200E+02, 0.32327000E+01, 0.78013900E+01, -.47939400E+01, 0.11122600E+02, 0.10641900E+02, 0.15802000E+02, -.45089400E+01, 0.29713200E+02, 0.50150500E+01, -.27260700E+01, 0.30742700E+01, -.20070900E+01, 0.14986700E+02, 0.23147800E+02, -.26414100E+02, -.19719600E+02, -.32099700E+02, 0.31152100E+02, 0.22825300E+02, -.13009800E+03, 0.65275800E+02, -.26144900E+01, 0.65031200E+02, -.38639400E+01, -.44900000E+02, 0.10732100E+03, 0.11404300E+03, 0.89714900E+02, -.43320100E+02, 0.21617400E+02, 0.56517800E+02, -.29260000E+02, -.25445400E+02, -.28043900E+02, 0.39792000E+02, -.31420100E+01, -.24460900E+02, -.12434200E+02, -.28490600E+02, 0.44434700E+01, -.66486500E+02, 0.58214300E+02, -.29124400E+02, -.84479000E+00, -.29995600E+02, 0.75709900E+00, -.66177200E+01, -.91212800E+01, 0.37525100E+02, 0.21131500E+01, -.23234700E+01, -.67624900E+02, 0.17829600E+01, 0.57034600E+01, 0.98968700E+01, 0.12193600E+01, -.51632500E+01, -.46089300E+01, 0.16785500E+01, -.98641400E+01, -.69594000E+01, -.72233200E+01, -.66802200E+01, -.68432000E+00, -.16003600E+01, -.51258800E+01, 0.43527100E+01, -.88217200E+01, -.84266100E+01, -.61438800E+01, 0.78136900E+01, 0.41007700E+00, -.96200300E+00, 0.59712100E+01, -.84580100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46177900E+01, 0.43064300E+01, 0.47588000E+00, 0.27986400E+01, -.13500600E+01, -.22847400E+01, 0.92051800E+00, 0.16144400E+01, -.12874800E+02, 0.69888900E+00, -.59517800E-01, -.13860800E+01, -.15190700E+01, 0.13843800E+00, 0.10988700E+00, -.32824000E+01, -.78350700E+01, -.15123000E+01, 0.12895800E+00, 0.43026800E+00, -.30564800E+01, 0.31089500E+00, -.10579500E+02, -.22451000E+01, 0.37402200E+01, -.13431400E+00, 0.51012100E+01, 0.56087000E+00, -.12238800E+01, 0.47357900E+00, -.93471800E+00, -.91273200E+00, 0.46735200E+00, 0.29378800E+00, 0.19892100E+00, 0.42051200E+00, -.58201200E-02, -.14236600E+01, -.16143600E+01, -.11094400E+01, -.23721500E+01, 0.96136500E+00, 0.22822600E+01, 0.24639300E+01, 0.21390000E+00, 0.76515400E-01, 0.12420400E+01, 0.24816200E+00, -.25905700E+00, -.19015300E+00, -.29971600E+01, 0.10126200E-03, -.12690500E+01, 0.88278600E+00, -.31132000E+00, 0.58776800E+01, 0.56523800E+00, -.16873200E+00, 0.11924500E+01, 0.20133100E+01, 0.65777600E+00, -.47700400E-01, 0.48976400E+00, -.35273400E-01, 0.23215700E+01, -.95610700E+00, -.42150300E+01, 0.37363200E-04, 0.42355900E+00, -.25624800E-02, 0.69718100E+00, 0.14778000E+01, 0.20205300E+01, -.32060600E+01, 0.32367300E+01, 0.10369300E+01, 0.16283700E+01, 0.91426500E+00, 0.17696900E+00, 0.60622800E-01, 0.33341000E+00, 0.10580900E+01, 0.83488400E+00, 0.70525200E+00, -.21169300E+01, -.90410500E+00, 0.12841600E+00, -.53002600E+01, 0.49443100E+00, 0.74786900E+00, 0.81614500E-01, -.22916600E-01, -.12433200E+00, 0.15835600E+00, 0.68188100E+00, 0.42624300E+00, -.57907200E+00, -.73751800E-02, 0.11921500E+01, 0.61582200E+01, -.36984700E+00, 0.12854400E+01, -.49305800E-01, 0.12845200E+01, -.14144900E+01, -.19184000E+01, -.12928900E+01, 0.10685100E+01, 0.69796400E-01, -.65991100E+00, -.53019900E-02, 0.44632500E-01, 0.93605400E-02, -.70389100E-02, 0.96623800E+00, 0.36314800E+01, 0.26396200E+01, -.24990900E+00, -.57175000E+00, 0.15361900E+01, 0.35722500E+00, 0.63603200E+00, 0.45594200E+01, 0.37530400E+00, 0.11833600E+00, 0.11045300E+01, 0.12628300E+01, 0.55333600E+00, 0.14757200E+01, 0.13692000E+00, 0.25302900E+01, 0.90445000E+00, 0.71946300E+01, -.18551200E+00, 0.14403100E+01, 0.50316800E-01, 0.41248000E+01, 0.80074100E-01, 0.12731100E+01, 0.14019300E-02, -.18403400E+01, 0.38509000E+00, -.80964100E+01, -.12009900E+01, -.34062700E+00, 0.28397300E+01, -.62805400E-01, -.13814000E+01, -.39159600E+01, 0.46486800E+01, 0.30831300E+03, 0.11722000E+03, -.54262700E+01, -.76323600E+01, -.59994600E+03, 0.29353000E+03, 0.42419500E+03, 0.29654500E+03, -.49918800E+02, -.30018800E+03, 0.19453000E+03, -.72257100E+02, 0.16595400E+03, -.17023200E+03, 0.16143100E+03, -.58522800E+03, 0.26617600E+03, 0.63177800E+03, 0.28959600E+03, 0.15026100E+03, 0.24064200E+03, 0.80926200E+02, -.29827900E+03, -.15830700E+03, 0.20563600E+03, 0.53225400E+03, -.99728100E+03, 0.50706600E+03, 0.25114300E+03, 0.47022700E+03, -.60858200E+02, -.54434700E+02, 0.10824700E+03, -.71165000E+02, 0.50511500E+03, -.88949600E+02, 0.44069000E+03, 0.31631000E+03, -.15661300E+03, -.13016600E+03, -.18978200E+03, -.86850800E+02, -.18875700E+03, -.25256900E+03, -.57414300E+02, 0.14148500E+03, -.27060700E+03, -.30893900E+03, -.65792400E+03, 0.32882300E+03, -.48655800E+02, 0.33966700E+03, 0.13373600E+03, -.93108900E+01, -.19350600E+02, -.31835100E+03, 0.24835800E+03, 0.95656800E+02, 0.28504800E+03, -.98520100E+02, 0.47906400E+02, -.19933200E+03, 0.48831100E+02, -.13355000E+03, -.10159600E+03, -.12665100E+03, 0.10890600E+03, 0.40262600E+03, -.15800800E+03, 0.10735600E+03, -.24617100E+03, 0.12443300E+03, -.59785700E+02, 0.12621400E+03, 0.68098000E+01, 0.65619500E+02, 0.52748900E+02, -.24379200E+03, 0.46917100E+02, 0.39379100E+02, -.63084200E+02, -.83097600E+03, 0.41575800E+03, -.18735700E+03, 0.39119500E+03, -.31852300E+02, -.58669800E+02, 0.18262600E+03, -.36897600E+03, 0.16818300E+03, 0.12319000E+02, 0.16387300E+03, -.64972400E-01, -.26239300E+02, -.27041000E+02, -.78403500E+01, -.37956900E+02, -.21588000E+02, -.31191800E+00, 0.29043100E+02, 0.15091100E+02, 0.68307700E+01, 0.91282100E+01, 0.70570100E+02, -.43156100E+02, -.35482900E+02, 0.25259000E+02, 0.15021900E+02, 0.20899200E+03, -.96056100E+00, -.64634300E+02, 0.11977000E+02, 0.59337800E+02, -.66801500E+01, 0.48532600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.73657600E+00, -.30007000E+01, 0.98387100E-01, -.20181700E+01, 0.10160600E+00, 0.16520800E+01, -.66512400E-02, -.15680200E+01, -.92012800E+01, -.62688500E-01, 0.69175900E-01, -.27862600E+00, 0.27798100E+00, -.34332700E-01, 0.47217800E-01, 0.41362600E+00, 0.58426800E+00, 0.39414500E+00, -.15789100E-01, 0.10949700E+00, -.75168700E+00, -.11697400E-01, -.43003900E+00, 0.29622300E+00, -.10307800E+00, 0.17579900E-01, -.11199100E+00, -.21428700E-01, 0.47729200E+00, -.14484800E+00, 0.40145200E-01, 0.20350500E-01, -.75087300E-01, -.22757400E+00, -.53714700E+00, -.85938500E-01, 0.23408200E-02, -.19597700E+00, 0.46284900E+00, -.32094500E+00, 0.39731000E+00, 0.75193600E-01, -.51184600E+00, 0.84942600E-01, 0.80046600E-02, -.35344300E-01, 0.91153500E-01, 0.46154900E-01, -.69836300E+00, 0.34881700E-01, -.11547700E+01, 0.24939500E+00, -.30021800E+00, 0.42566900E+00, 0.14141700E+00, 0.15034600E-01, -.46843000E-01, -.36783200E-01, -.26438500E+00, -.23314800E+01, 0.34090600E+00, 0.19284200E-01, -.29777300E+00, 0.43642500E-01, -.10418600E+00, 0.47541700E-01, 0.34400000E+00, 0.81077000E-01, -.69247300E-01, 0.44112700E-03, -.37846000E-01, -.42020800E+00, -.48841600E+00, 0.62358300E+00, 0.16990100E+00, -.51285800E+00, 0.98439600E-01, -.18528000E+00, 0.15488500E+00, -.25642300E-01, 0.22268900E-03, 0.13105200E+00, 0.35819500E-01, -.86658500E-01, -.31347000E+00, -.18870800E+00, -.18132700E-01, 0.81173900E-01, -.90508100E-02, -.26814100E-01, -.43201800E+00, 0.11162500E-01, -.80937400E-02, -.23914100E+00, -.21496900E-01, 0.42219700E+00, -.91494800E-01, -.56436100E+00, -.81463900E+00, 0.14830600E-01, -.10349500E+01, 0.14059600E+00, 0.24721800E-01, -.32467800E+00, -.24161300E+00, -.58928600E+00, -.13146200E+00, -.14894000E+00, 0.23165100E+00, 0.40611100E-01, 0.36064500E-01, 0.26081300E-01, -.43094400E-01, 0.12785000E-01, 0.43015700E-01, 0.34886900E+00, 0.70774800E+00, -.42116600E-02, 0.12869600E+00, 0.22902300E+00, 0.21592000E+00, -.42590000E-01, -.11315000E+01, -.25876800E+00, 0.59944200E-01, 0.10730700E+00, 0.17633400E-01, 0.68752500E-01, 0.49269600E+00, 0.21605900E+00, 0.44202000E+00, -.35529400E+00, 0.21430900E+01, -.66691800E-01, -.31315800E+00, 0.26127200E-01, 0.14112000E+01, 0.74783100E-01, -.25540300E+00, 0.93930000E-01, -.26640000E+00, 0.45832700E-01, 0.55055500E-01, 0.53632800E-01, 0.83226300E-01, 0.13364900E+00, -.13054900E-01, 0.48845200E+00, 0.26456200E+00, -.16158700E+00, -.49637000E-02, -.34214600E+02, 0.26099600E+00, -.18705600E+02, 0.17110000E+03, -.85510300E+02, -.99821600E+02, -.85940600E+02, -.63343700E+02, -.57249100E+02, -.65386300E+01, 0.37008000E+02, -.26020600E+02, -.34805700E+02, 0.50327800E+00, -.11947500E+03, 0.60061600E+02, -.34544100E+02, 0.59412300E+02, 0.24956600E+02, 0.22618900E+02, 0.12782700E+02, -.10164400E+02, 0.54571300E+02, 0.23812300E+00, 0.12675100E+03, 0.11961800E+03, -.59091600E+02, -.48588000E+01, -.62396100E+02, -.59041200E+02, -.26276500E+02, -.27671200E+02, -.43105000E+02, -.32364100E+01, -.11579500E+02, -.96523700E+02, -.11850800E+03, 0.59070000E+02, 0.10980000E+02, 0.52487600E+02, 0.20964400E+02, 0.34920000E+02, -.56585300E+02, -.13134800E+03, 0.11472100E+02, 0.44190400E+02, 0.18269300E+03, 0.12361200E+03, -.60646200E+02, -.13806300E+03, -.60946800E+02, -.88796100E+01, -.68526800E+02, 0.23409300E+01, 0.55490300E+02, 0.97112600E+01, -.53074500E+02, 0.40326200E+02, -.73520400E+02, 0.37457000E+02, 0.51042500E+02, 0.36731200E+02, -.64622200E+02, -.88662800E+02, 0.75571400E+02, -.38254400E+01, -.15195200E+02, -.54201100E+02, -.56410800E+01, 0.15977200E+03, -.80246400E+02, -.62591600E+01, -.79537100E+02, -.14322900E+02, -.52695700E+02, -.14566900E+02, 0.54926000E+02, -.29603700E+02, -.40117100E+02, -.19145000E+02, 0.41330200E+02, -.20682100E+02, 0.88121700E+02, -.22434000E+02, -.13344400E+02, -.23247900E+02, -.22859400E+01, -.45855800E+02, 0.32788600E+01, -.87068600E+01, -.72348000E+02, 0.10025600E+01, -.55403200E+01, 0.78764600E+01, -.17460200E+00, 0.11068900E+01, -.27726100E+01, 0.13475800E+01, -.73141700E+01, -.80988100E+01, -.17574300E+02, -.14001200E+02, 0.19607100E+02, -.11818900E+02, 0.13665900E+01, 0.18216200E+01, -.20244100E+02, 0.14173700E+02, 0.15498300E+02, 0.88892500E+00, 0.40336000E+01, -.35083300E+02, 0.80663600E+01, 0.12816500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34498400E+00, 0.98830400E+00, -.47642800E-01, 0.40099900E+00, -.48270700E+00, -.91481500E+00, -.22173700E-01, 0.83835700E-02, -.78081700E+01, -.19445600E+00, 0.55047700E-01, 0.57604600E-02, -.10373200E+00, 0.84846900E-01, -.85647300E+00, 0.48490500E+00, -.10787500E+01, -.11642800E+01, -.54570300E-01, 0.80184600E+00, 0.42047400E+00, 0.18495800E+00, -.84931500E+00, 0.79393100E-01, 0.17575400E+00, 0.28534400E-04, 0.15227600E+00, -.33435100E-01, 0.46836500E-01, 0.49149100E-01, -.16525600E-01, -.44649600E-01, -.59407200E-01, -.70592700E-01, -.25671000E+00, -.41712100E-01, 0.18543100E-02, -.35178000E+00, 0.45858000E+00, -.12996900E+00, 0.34974500E+00, 0.53678200E-01, 0.97403600E+00, 0.25973400E+00, 0.11320800E+00, 0.66078900E-02, -.50038900E-01, 0.10187500E-01, 0.21489700E+00, -.74193200E-01, -.34139300E+00, -.15278400E+00, 0.29772200E-01, 0.10823400E+00, -.10750100E+00, -.12426100E+01, -.23635300E+00, 0.62290500E-02, -.34784900E-01, -.55801900E+00, 0.12031400E+00, -.43362600E-01, 0.29459800E+00, -.84555500E-01, -.24157500E+00, 0.20755200E+00, -.83124900E+00, 0.66300300E-02, 0.77057100E-02, 0.43082200E-03, -.21015400E-01, -.72883400E+00, -.17518100E+00, -.10681600E+00, 0.13892600E+00, -.15053800E+00, 0.30361400E+00, 0.11848700E+00, -.73117500E-01, -.68885500E-02, -.20624800E-03, 0.51942200E+00, 0.35366600E-01, 0.91300200E-01, -.42727900E-02, -.21057100E+00, -.21727600E-01, -.32458700E+00, 0.61630800E-01, 0.80810000E-01, -.12469000E+00, 0.14893100E-02, 0.52432800E-01, -.11222600E+00, 0.25019800E-01, 0.11124800E+00, 0.26054500E+00, 0.11265300E+00, 0.67708900E-01, 0.73337600E+00, 0.67962100E+00, 0.10237900E+00, -.20428900E-01, 0.28984200E+00, -.24326100E+00, -.17186700E+00, 0.48652700E-01, -.87536700E-01, -.48386500E-01, -.33486400E-01, 0.29856300E-01, 0.32117000E-01, -.11846400E+00, 0.37692400E-01, 0.25800300E-01, -.32682300E+00, -.27282800E+00, 0.47156400E-01, -.36196500E-01, -.27097300E+00, -.11794800E+00, 0.36094600E-01, 0.34135700E+00, 0.91273700E-01, -.55939800E-02, 0.11093600E+00, 0.15791600E+00, -.11823500E-01, 0.45908200E-01, 0.96492200E-01, 0.75054200E-01, 0.26359100E+00, -.35934700E+00, -.32600800E-01, 0.74346300E-01, -.11068300E-01, -.52752700E-01, -.82157200E-01, -.71409200E-02, -.15442500E-01, 0.31228500E+00, 0.82366200E-01, 0.36992300E+00, -.94767700E-01, -.44210800E-01, -.37291200E+00, -.49725000E-02, 0.32046100E+00, -.34800800E+00, 0.95994300E+00, 0.73036900E-02, -.80948300E-01, 0.45755600E+01, 0.25380700E+01, 0.11861000E+02, -.59860500E+01, -.15372600E+02, -.58960000E+01, 0.35908700E+01, 0.61897300E+01, 0.47147900E+01, 0.31526900E+02, 0.15562600E+02, 0.50355800E+01, 0.10074600E+02, -.51650900E+01, 0.28748000E+01, 0.12287600E+02, 0.26150400E+01, 0.36867100E+00, 0.40350600E+01, -.74066400E+01, -.20190400E+02, -.15014500E+02, 0.16428800E+01, 0.19050300E+01, -.27833900E+01, 0.13837000E+01, 0.19908900E+02, 0.17467200E+01, -.75192200E+01, -.28974800E+01, 0.34986000E+00, -.19006100E+02, -.14009500E+02, 0.49084000E+01, -.41915400E+02, 0.22070100E+02, -.11049100E+02, -.13233600E+02, -.10953100E+02, 0.79753800E+01, -.87641500E+01, 0.10797100E+02, 0.19255500E+02, 0.44578000E+01, -.59398600E+01, -.34391400E+02, -.30160300E+02, 0.15016900E+02, 0.20760200E+02, 0.14935200E+02, 0.60329300E+01, 0.41841400E+01, 0.57785400E+01, 0.11891500E+02, 0.21981000E+02, 0.19940200E+00, 0.19047500E+02, -.13718100E+02, 0.67309000E+01, 0.20456400E+02, 0.68655200E+01, -.37364400E+01, 0.92714900E+01, -.19062700E+02, -.42237900E+02, -.16652600E+02, 0.15328700E+02, -.23308800E+02, 0.16515200E+02, -.82387100E+01, -.15910100E+02, -.82900300E+01, 0.38131200E+01, 0.29788600E+00, 0.48954800E+01, 0.24802700E+02, -.10481700E+02, -.44376000E+01, 0.10693300E+02, 0.32461000E+02, -.16268900E+02, -.61595300E+01, -.16220100E+02, 0.30969200E+01, 0.40704500E+01, -.65603100E+01, 0.88963600E+01, -.24071600E+02, 0.22028600E+00, 0.35363100E+00, -.38557200E+00, 0.45146100E+00, -.12380800E+01, 0.97319100E+00, -.36964700E+00, -.61314900E+00, -.14680100E+00, 0.12804500E+01, -.21188800E+00, 0.17668100E+00, 0.20225400E+00, -.33918000E+01, -.18309000E+01, -.38237200E+00, 0.26947900E+00, -.16680600E+01, 0.57776300E+01, 0.79224000E+00, 0.29592300E+00, -.10531500E+01, 0.63586900E+00, -.32789300E+01, -.16036200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22412800E+01, 0.33589100E+01, -.26621500E+01, 0.15257900E+01, -.10703400E+01, -.71987100E+00, 0.27471600E+00, 0.24806100E+01, 0.19531300E+02, 0.25690400E+00, -.19456000E+00, 0.12615900E+01, 0.20128500E+00, 0.50907300E-01, -.11363900E+01, 0.17795400E+00, -.13700100E+01, -.38687100E+01, -.81967900E-01, 0.46442900E+00, 0.30704200E+01, 0.14233300E+00, -.48199400E+00, 0.49276900E+00, -.21477400E+01, 0.83872200E-01, -.52383900E+00, 0.57489800E-01, -.32068500E-01, -.53363600E+00, -.67843000E-01, 0.18580500E-03, -.86139800E-01, -.14723900E+01, -.18455100E+01, 0.36517400E+00, -.47319400E-02, 0.38954000E+00, 0.45687600E-01, 0.49132300E+00, 0.13644400E+01, -.46016700E+00, -.18507400E+01, -.13461500E+01, 0.19221300E+00, 0.16578000E+00, -.12666800E+01, -.11605000E+00, 0.10205200E+01, -.80324900E+00, -.31925700E+00, -.19546400E+01, 0.20031500E+01, -.37109200E-01, 0.53737800E+00, 0.37444400E+01, 0.91276000E+00, 0.13735200E+00, 0.96578700E+00, -.66817400E+00, 0.88487700E+00, 0.40050600E+00, -.10107400E+01, -.37353700E+00, 0.20049200E+01, -.13487000E+01, -.29032200E+01, -.13882900E+01, -.17641700E+00, -.82088700E-03, 0.18231600E+00, 0.89183200E+00, 0.77644000E+01, -.13356800E+01, 0.18795300E+01, 0.86495900E+00, -.17726300E+01, 0.43041500E+00, -.52230300E+00, 0.37545200E+00, 0.73707200E-03, -.15044800E+01, -.95271000E+00, 0.36648300E-01, -.55934300E+00, 0.16591100E+01, 0.16552800E+00, -.41551400E+00, -.18410700E+00, 0.64869100E+00, -.17200200E+01, -.18252400E-01, 0.22095700E+00, 0.17165600E+00, -.40949200E+00, -.46549900E+00, 0.11804800E+01, 0.10869200E+00, -.15065500E+01, -.60197900E+00, 0.10066700E+01, -.67790900E+00, 0.13711500E+00, -.38454600E+00, 0.42771900E+00, -.13504500E+01, -.20983800E+00, -.14759000E+00, -.16898700E+00, -.95427100E-01, 0.32967800E-01, 0.59554400E+00, -.45562900E+00, 0.14341800E+00, -.17661600E+00, -.20698200E+01, -.83147000E+00, -.10149600E+00, -.12720900E+00, 0.34062200E+00, -.79079100E+00, 0.31984800E+00, -.26916600E+01, -.22161900E+00, 0.14854200E+00, -.28791500E-01, 0.12505200E-01, -.29383100E+00, 0.87648900E+00, 0.80019000E+00, -.12737700E+00, -.39712600E+00, -.88798000E+00, -.72418200E-01, -.14459600E+00, 0.33961700E-01, -.25283300E+00, -.32762300E+00, -.45722300E+00, 0.13523900E+00, -.75073900E-01, 0.42763800E+00, 0.24965400E+00, 0.57885100E+00, 0.71837200E-01, 0.83460100E+00, -.40068300E-01, -.35212200E+00, -.34954500E+00, 0.91289300E+00, -.30006300E+00, 0.12179900E+01, 0.12370600E+01, -.10151300E+03, 0.76255200E+02, -.35859500E+02, -.20152400E+03, -.40666000E+02, -.54194100E+02, -.85178300E+02, 0.23224600E+02, -.21022500E+03, -.10802200E+03, -.50291500E+02, -.40311300E+03, -.45082100E+03, 0.20922900E+03, 0.23107000E+03, 0.22316200E+03, -.84716100E+02, 0.19746200E+01, 0.17742400E+03, 0.13443800E+03, 0.24206600E+03, -.31318100E+02, 0.13052900E+04, -.18601700E+04, 0.93451900E+03, -.12990000E+03, 0.90878000E+03, 0.16443000E+03, -.14453300E+03, 0.78310900E+03, 0.38865100E+03, 0.95650700E+03, -.19813000E+03, 0.12196200E+04, 0.36943400E+02, -.16324000E+02, -.45299800E+03, -.22444200E+02, -.12090800E+03, -.57752500E+02, -.22125600E+02, -.82216600E+02, 0.10431000E+03, -.13003000E+03, 0.23407700E+03, 0.85270100E+02, -.43019600E+02, -.37962700E+03, -.34635400E+02, 0.10678400E+02, -.61039700E+02, -.10844600E+03, -.30177100E+03, -.11617000E+03, -.23223900E+02, 0.13622000E+03, -.87139400E+03, 0.43880400E+03, -.46380200E+03, 0.43536400E+03, 0.33277600E+03, -.16814500E+03, 0.50414200E+03, 0.49579200E+03, 0.53599800E+03, -.19361800E+03, 0.38425500E+03, -.63976600E+02, 0.29165400E+02, -.44943200E+02, 0.34313700E+02, 0.48805500E+02, -.20748700E+02, -.57172500E+02, -.34926900E+03, 0.53334500E+02, 0.49934100E+02, -.21877600E+03, -.48195100E+03, 0.24135600E+03, -.61580900E+02, 0.23620200E+03, -.82785500E+02, -.77854200E+02, 0.13255200E+03, -.20116800E+03, 0.34935100E+03, -.22583800E+02, -.20410600E+03, 0.10666600E+02, 0.29256200E+02, 0.49580300E+02, -.67190400E+01, 0.66279800E+01, 0.11612900E+02, 0.79136500E+01, -.49924700E+02, -.23603700E+01, -.19870100E+02, -.10843800E+02, 0.25204000E+02, -.44881700E+01, 0.76579400E+01, -.81906300E+01, 0.11041200E+02, -.17939700E+03, -.58616100E+02, 0.21478200E+02, 0.71814800E+01, 0.79316600E+02, 0.43278600E+02, -.27024000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.50207000E+01, 0.26481000E+01, 0.14899700E+00, 0.21454300E+01, 0.64309200E+00, -.15478600E+01, 0.12109300E+01, 0.35573100E+01, 0.97857200E+01, 0.61518900E+00, -.17964500E+00, 0.15489500E+01, -.88373100E-01, -.36852700E+00, 0.10636300E+01, 0.62822200E+00, 0.97717000E+00, 0.52135600E+01, 0.12249100E+01, 0.32128300E+00, -.19974700E+01, 0.23364100E+00, -.17679900E+01, 0.24931400E+00, -.31063600E+00, 0.40647500E+00, -.89335500E-01, 0.26327300E+00, 0.17933500E+00, -.59423400E+00, 0.80730900E+00, -.34552200E+00, -.67309800E-02, -.42680300E+00, -.17824300E+01, -.38192400E+00, 0.15945100E-01, -.76007700E+00, 0.16660400E+01, -.90264800E+00, -.45807400E+00, 0.77796800E+00, 0.18210400E+01, 0.18589400E+01, -.65200400E-01, -.93512600E-01, 0.15006300E+01, 0.18357300E+00, 0.18172400E+00, 0.86350300E-01, -.33912900E+01, 0.16291700E+00, 0.96270500E+00, 0.14038000E+01, 0.92220300E+00, 0.42578300E+01, -.17317900E+01, -.28959600E+00, 0.10023500E+01, -.24442400E+01, 0.93287800E+00, -.21984800E-01, -.23174400E+00, 0.40781500E+00, 0.26481800E+01, 0.41212800E-01, -.63142600E+01, -.89565000E-01, 0.11253500E+00, -.14631800E-02, 0.48502700E+00, 0.25827900E+01, -.29419200E+01, 0.15618300E+00, -.54418900E+00, -.58733500E+00, 0.12462700E+01, 0.26360900E+00, -.25166900E+00, -.13994200E+00, 0.18036900E-02, 0.39883200E+00, -.13853600E+00, 0.13022500E+00, 0.10136200E+01, 0.12103900E+01, 0.28427800E+00, 0.11072200E+01, -.12277600E+00, 0.41618200E+00, 0.11101600E+00, 0.27664900E-01, -.99741200E-01, -.86968500E+00, 0.40649800E+00, 0.43050200E+00, 0.10251000E+01, 0.69638500E+00, 0.71810100E+00, 0.30799300E+01, 0.15458300E+01, 0.39609900E+00, -.10334700E+00, 0.52939600E+00, 0.11223600E+01, -.48705500E+00, 0.56377400E-01, -.37581200E+00, -.18787100E+00, 0.15859300E+00, -.21940400E-02, 0.23461100E+00, -.10659000E+01, 0.34067800E+00, -.14203900E+00, 0.42601500E+00, -.77290500E+00, -.17097900E+00, -.53765900E+00, 0.28701600E+00, -.83495600E+00, 0.58051800E+00, -.25861000E+00, -.65626400E-01, -.27338000E-01, 0.14745100E+01, 0.12145400E+01, -.54466700E+00, 0.50642300E+00, 0.11126400E+01, 0.65876500E-01, -.86166700E+00, -.44773800E+01, -.53982400E-01, 0.10604000E+01, -.42607900E-02, -.93243900E+00, 0.11968100E+00, 0.65615900E+00, -.46222200E-01, -.75007300E+00, 0.41359300E-02, -.46857200E+00, -.55106000E-01, 0.36690100E+00, 0.17838100E+01, -.74087100E-01, -.19310200E+01, -.26044700E+01, 0.50960900E+01, 0.64856500E-01, 0.16038900E+01, 0.46449200E+01, 0.44007900E+00, -.59715700E+03, 0.28335800E+03, 0.71141200E+03, 0.29754500E+03, -.37741300E+02, -.22473300E+02, -.47182500E+01, -.48897900E+03, -.13882500E+03, 0.30897500E+02, 0.94552400E+02, -.60769100E+02, 0.32969800E+02, 0.92399100E+02, 0.29420900E+02, 0.31769200E+03, 0.41985800E+02, 0.49568000E+02, -.16339200E+02, -.27898500E+03, 0.15670700E+03, -.74053100E+03, 0.90188500E+03, -.44248400E+03, 0.10653200E+02, -.46128800E+03, 0.46148200E+02, 0.45577200E+03, -.49943600E+03, 0.31668900E+03, -.43608700E+02, 0.20967400E+03, 0.16100100E+03, 0.97732500E+02, -.50591900E+02, 0.45122100E+03, -.28882700E+02, -.15047900E+03, 0.24830300E+03, -.34982400E+03, -.20033500E+03, -.56043400E+02, 0.12320200E+03, 0.83828500E+02, 0.38744000E+03, -.19231500E+03, 0.12417300E+03, -.18955200E+03, -.41331500E+02, 0.13010100E+03, -.35536300E+02, -.24031700E+02, -.25115300E+03, 0.10768700E+03, -.38519600E+03, 0.12492800E+04, -.62517300E+03, -.17029100E+03, -.62483000E+03, -.28092900E+03, 0.47040300E+03, -.44183300E+03, 0.39803700E+03, 0.11572200E+03, 0.17645000E+03, 0.20877700E+03, -.15271100E+03, 0.80992300E+02, 0.18730400E+03, 0.77321400E+02, -.10211000E+03, 0.76153900E+02, -.52371200E+02, -.34446500E+03, 0.76792600E+02, 0.13248000E+03, -.26908000E+03, -.51390800E+03, 0.24336700E+03, 0.11247500E+03, 0.28049300E+03, -.25910200E+02, -.12432100E+03, 0.21122300E+03, 0.50237600E+02, 0.35776700E+03, -.17342700E+02, 0.74515000E+02, -.18015300E+02, -.67402000E+02, -.46447000E+02, -.14774800E+02, 0.14735300E+02, 0.12759600E+02, -.14945000E+02, 0.45188700E+02, 0.38159600E+02, 0.44198300E+02, 0.38829900E+02, -.33545800E+02, 0.19174300E+02, 0.13503800E+02, -.13195800E+02, 0.57161900E+02, -.54956100E+02, 0.37443700E+00, -.54884800E+01, 0.59265000E+01, 0.79805600E+02, -.14779400E+01, 0.61255700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40449000E+01, -.94145500E+00, 0.15004300E+01, 0.31752000E-01, -.49800100E+00, -.33187700E+01, 0.10901200E+01, 0.26223200E+01, -.50319200E+01, -.30883400E+01, -.29246800E-01, 0.47377600E+00, 0.94169500E+00, -.12312200E+00, 0.19668100E+01, 0.48711100E+00, 0.99314600E+00, 0.52753100E+01, 0.90728900E+00, 0.16203600E+01, -.15509500E+01, 0.20174900E+00, -.28293200E+01, 0.15300100E+01, 0.90159100E+00, 0.11831400E-01, 0.11628000E+01, -.21702400E-01, 0.40493800E+00, -.93676700E-01, 0.45727500E+00, -.61879900E+00, 0.27608800E+00, 0.14039900E+00, 0.28317800E+00, 0.95773700E-01, -.24538900E-01, -.10834000E+01, 0.33925100E+00, -.16114100E+00, -.21055700E+00, 0.68155600E+00, -.39970700E+00, 0.76275600E+00, -.20805100E+00, -.82095700E-01, -.35927700E+00, -.10229400E-01, -.16948500E+00, 0.27488500E+00, -.33594800E+01, -.11518600E+00, -.79103700E+00, -.11534600E+01, 0.97793500E+00, 0.13923900E+01, 0.30427100E+01, -.45318500E+00, -.68609800E+00, -.11254100E+01, 0.66851100E+00, -.39568000E+00, 0.24129700E+01, -.51748100E+00, -.38860600E+01, -.18745100E+00, 0.14835000E+02, 0.19848300E+01, -.21942500E+00, -.18127600E-02, -.37073200E+00, -.40167200E+00, 0.59843700E+00, -.23872400E+00, -.70439500E+00, 0.80132500E+00, -.65740300E+00, 0.22769100E+00, -.87572000E-01, -.69322900E-01, -.18945200E-02, 0.58963100E+00, -.17261100E+00, -.10646100E+01, -.25365600E+00, -.15131500E+00, -.70313400E-01, -.60628900E+00, -.46291100E+00, -.29481600E+00, -.30391000E+00, -.14595100E-01, 0.23091600E+00, -.32866000E+00, -.86266700E+00, 0.95278600E+00, -.99744700E+00, -.16263000E+01, -.11848900E+01, -.16529700E+01, 0.37222700E+00, -.10449600E+01, 0.23251000E+00, -.14217500E+01, 0.82853500E+00, 0.22357400E+00, 0.47968600E+00, -.55855800E+00, 0.59452400E+00, 0.44130100E+00, -.19764900E+00, 0.66110800E+00, -.19980900E+01, 0.63278400E+00, -.43069800E+00, 0.96191600E+01, 0.55531800E+00, 0.19522500E+00, -.29602900E+00, -.98700000E+00, 0.12793300E+01, -.31613500E+00, 0.20768700E+01, -.27960200E+00, -.34942600E-01, 0.14582600E+01, 0.39236300E+00, 0.22400500E+00, 0.78654100E+00, 0.14947700E+01, 0.17636400E+01, -.58902500E+00, 0.58812500E+01, -.18285100E+00, 0.65665500E+00, 0.70596500E-02, 0.18392300E+01, -.68984500E+00, 0.79045300E+00, 0.11015300E+00, -.17471500E+01, 0.19395400E+00, -.53065800E+01, -.98184000E-01, 0.90114300E-01, 0.15171400E+01, -.58529200E-01, -.14908000E+01, -.42605600E+00, 0.14664100E+01, 0.21661700E+00, 0.11050700E+00, 0.42118300E+00, -.18207000E+00, 0.71246100E+00, 0.25168700E+02, -.32533300E+03, -.86262800E+00, -.30353600E+02, -.55926500E+02, 0.11484200E+03, 0.39742600E+03, 0.15992600E+03, -.49807600E+02, 0.18427200E+03, -.66378000E+03, 0.31672200E+03, 0.43667000E+03, 0.33117300E+03, -.76157700E+02, 0.58926300E+02, 0.66677400E+02, -.28231500E+03, 0.20168100E+03, 0.20404200E+02, 0.62951600E+03, -.10797800E+04, 0.53024800E+03, -.86971800E+02, 0.53407000E+03, -.68611200E+02, -.36012500E+03, 0.60505600E+03, 0.39300000E+03, 0.52018300E+03, -.24691800E+03, 0.30683200E+03, 0.30032500E+03, -.14916500E+03, -.58475300E+03, -.16628800E+03, -.41257100E+02, -.29539500E+03, 0.24043700E+03, 0.37905000E+03, 0.21330100E+03, -.27214000E+03, -.18801400E+03, -.40172100E+03, 0.19923400E+03, 0.15618400E+03, 0.20285900E+03, -.15244900E+01, -.79223200E+02, 0.10505600E+03, -.10254600E+02, 0.16438600E+03, -.66264700E+02, 0.30110900E+03, -.76195300E+03, 0.37972400E+03, -.16133900E+03, 0.38091300E+03, 0.18219400E+03, -.21454000E+03, 0.24767000E+03, 0.10236400E+03, 0.14829700E+03, -.11422800E+03, 0.84123100E+02, -.17924800E+03, 0.81809400E+02, -.14331500E+03, 0.90392600E+02, 0.14841700E+03, 0.18654400E+02, 0.81152400E+02, 0.17812800E+03, 0.57339600E+02, -.18980800E+02, 0.17622900E+03, 0.42352200E+03, -.20227700E+03, -.25154100E+03, -.23140400E+03, -.64072300E+02, 0.40396600E+02, -.14310700E+03, 0.15845600E+02, -.18254400E+03, -.10189600E+02, -.12747600E+03, 0.18135000E+01, 0.64456200E+02, 0.30264900E+02, 0.15112600E+02, 0.20507000E+01, 0.20691400E+01, 0.27142400E+01, -.30426900E+02, -.29331300E+02, -.28009000E+02, -.23262300E+02, 0.25740600E+02, -.15302000E+02, 0.37317500E+01, -.30207100E+01, -.42622200E+02, -.25965500E+02, -.26972400E+02, 0.17634600E+02, -.80290900E+01, 0.12404500E+02, 0.13590600E+02, -.60502700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25007700E+01, -.38025300E+00, -.15690500E+00, -.72215300E+00, -.32195300E+00, 0.11891000E+01, -.61516800E+00, -.15453100E+01, -.48111300E+01, 0.23603300E+00, 0.76885300E-01, -.90634000E+00, 0.23654300E+00, 0.99477100E-01, -.70671900E+00, -.69376500E+00, -.68852100E+00, -.28864700E+01, -.63822300E+00, -.19264000E+00, 0.86753200E+00, -.38024700E-01, -.73329400E-01, -.73943900E-01, 0.11970500E+00, -.55687900E-02, 0.35425200E+00, -.17155100E-01, -.10302900E+00, 0.20230200E+00, -.53637700E+00, 0.94451500E-01, -.12902800E-01, 0.13490400E+00, 0.57623300E+00, 0.20751400E+00, -.46072200E-02, 0.44105300E+00, -.75138200E+00, 0.15058700E+00, 0.53868000E+00, -.34306300E+00, -.83889200E+00, -.88479600E+00, 0.11787300E+00, 0.13964400E+00, -.90806800E+00, -.56303400E-01, 0.22234400E+00, -.23928100E+00, 0.22303500E+01, -.36743600E+00, -.49111900E+00, -.35968300E+00, -.72801500E+00, -.18661100E+01, -.38607100E+00, 0.10223200E+00, -.10380600E+00, -.50071500E+00, 0.20970200E+00, 0.14347300E+00, -.14636000E+00, -.34875800E-01, -.28738000E+00, 0.26126200E-01, 0.39002500E+00, -.63138800E+00, -.22989500E-01, 0.20004600E-03, 0.17486600E-01, -.12874900E+01, 0.99147900E+00, 0.15710800E+00, 0.59554200E+00, -.30627700E+00, -.13896000E+00, 0.35631400E+00, 0.30079100E-01, -.49596500E-01, 0.49381100E-03, 0.13866300E+00, 0.26659000E+00, -.56369800E+00, 0.13965700E+00, -.60002300E+00, -.13237500E+00, -.61162300E+00, 0.53358800E+00, -.15759600E+00, -.67138200E+00, -.46264600E-02, -.19416700E-01, 0.10619300E+01, -.18272500E+00, -.45400000E+00, -.53937500E+00, -.34175500E+00, 0.25818600E+00, 0.62350000E+00, 0.93541500E+00, -.34272300E+00, 0.67432900E-02, 0.36221100E+00, -.25178200E+00, 0.71807900E+00, -.13042800E+00, 0.43716600E+00, 0.11844600E+00, -.25265500E-01, 0.20232400E-01, 0.36600500E+00, 0.13423100E+00, -.41957400E-01, 0.25907000E+00, 0.10594700E+01, 0.91577300E-01, -.90148500E-01, -.10973200E+00, 0.89462800E+00, 0.42516400E+00, 0.20901500E+00, 0.51912200E+00, -.27837700E-02, -.38505800E-01, 0.10063400E+01, 0.10162700E+01, -.21927000E+00, 0.25734700E+00, 0.40874600E+00, 0.88419000E+00, -.61149300E+00, 0.14882600E+01, 0.14215900E-01, 0.39880100E+00, -.20963300E-01, -.10565200E+01, -.42281800E+00, 0.39936000E+00, -.35907200E-01, -.83216600E+00, 0.21486600E+00, -.12643400E+01, -.11927000E+00, 0.25240500E+00, 0.11296100E+01, -.31805200E-01, -.92214700E+00, -.96863300E+00, 0.20483500E+01, -.22307500E-01, 0.53237500E+00, 0.23752600E+00, 0.11432000E-02, 0.31421300E+00, -.15039500E+00, -.16682700E+03, -.85318700E+00, -.15618700E+02, -.76488900E+02, 0.33179400E+02, 0.67456000E+02, 0.24733700E+02, -.28447400E+02, 0.15028900E+02, -.10310200E+04, 0.51551400E+03, 0.43643700E+03, 0.51476700E+03, 0.79383500E+02, 0.11530000E+03, 0.17393300E+03, -.20866100E+03, 0.27694600E+03, 0.90910300E+02, 0.57381700E+03, -.78584900E+03, 0.39613000E+03, 0.43121000E+02, 0.38596600E+03, -.81946800E+02, -.21506900E+03, 0.29558400E+03, 0.34588200E+03, 0.41161600E+03, -.13572700E+03, 0.38904800E+03, 0.24605600E+03, -.12214100E+03, -.31015100E+03, -.12963600E+03, -.48245900E+02, -.80049100E+02, -.12071600E+02, 0.50049100E+02, 0.25756500E+02, -.99895400E+02, -.10447600E+03, -.25453500E+03, 0.12648500E+03, 0.13212700E+03, 0.12989900E+03, 0.16824000E+01, 0.11457100E+01, 0.32297700E+02, -.10543300E+03, 0.40079400E+02, 0.23049400E+02, 0.12171900E+03, -.42001300E+03, 0.21206400E+03, -.12723300E+03, 0.20990600E+03, 0.17926900E+02, -.11349800E+03, 0.18032100E+03, 0.39597700E+03, 0.29323300E+03, -.69296100E+02, 0.23210600E+03, -.56959800E+02, 0.27197000E+02, -.51504600E+02, 0.29255200E+02, 0.48333400E+02, 0.86106100E+02, -.55619000E+02, -.89501600E+02, 0.42129100E+02, 0.65076900E+02, 0.18825000E+02, 0.29891700E+03, -.15302300E+03, -.39716500E+02, -.15828900E+03, -.19047900E+03, -.17693600E+02, -.14091000E+03, -.14514900E+03, -.65398400E+02, -.77962200E+01, -.14128700E+03, -.17973000E+02, 0.44095100E+02, 0.17591000E+02, 0.18432400E+01, 0.24801500E+01, -.49241200E-01, -.13134600E+02, -.17427500E+02, -.10552200E+02, -.18322000E+02, -.11209100E+02, 0.66847300E+01, -.17857700E+02, 0.26124000E+01, -.63491700E+00, -.18748700E+02, -.33448500E+02, 0.12915900E+01, -.15099000E+02, -.63932100E+00, 0.12132600E+02, 0.31125300E+02, -.47195300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40522300E+01, 0.42256300E+01, 0.10641000E+01, 0.11794400E+01, -.14620400E+01, -.10789000E+01, 0.90123200E+00, 0.21978000E+01, -.22588400E+02, -.14705800E+00, 0.31316000E-01, -.39960300E+00, -.91750000E+00, -.23826900E+00, 0.10499300E+01, -.30335300E+01, -.32500800E+01, 0.38344000E+01, 0.78898500E+00, 0.35672600E+01, -.38674800E+01, 0.79173900E+00, -.83696200E+01, -.67309900E-01, 0.10240400E+01, 0.11350800E+00, 0.28072500E+01, 0.52365100E+00, -.19107200E+00, -.42946200E+00, -.36851400E+00, -.91793200E+00, 0.30300400E+00, 0.20012300E-01, -.13936000E+00, 0.23616800E+00, -.14052800E-01, -.82122800E+00, 0.79272500E+00, -.10426000E+01, 0.20121300E+00, 0.84115300E+00, 0.82648800E+00, 0.15229200E+01, 0.16186000E+00, 0.56792400E-01, -.87241500E+00, 0.12470700E+00, 0.49978200E+00, -.26473400E+00, 0.73564300E+00, 0.90408500E-01, -.26660500E+01, -.55605100E+00, -.46201800E+00, -.32427200E+01, -.70447000E+00, -.14366900E+00, 0.34593000E-01, -.21790600E+01, 0.65210500E+00, -.34658100E+00, 0.46967900E+00, 0.40286000E-01, -.15073900E+01, 0.11391700E+00, 0.23711700E+01, 0.78493400E+00, 0.78983300E-01, -.19229000E-02, 0.13521100E+00, -.41347100E+00, 0.41237600E+00, -.31601600E+00, 0.20705400E+00, 0.13047300E+01, 0.13010900E+00, 0.51136600E+00, 0.17323000E+00, -.64006000E-02, -.13509100E-02, 0.11889800E+01, -.50309400E-01, 0.30669400E+00, 0.48177100E+00, -.41840600E+00, 0.26743000E-01, -.41234800E+00, -.68465800E+00, 0.31510900E+00, 0.72853500E-01, -.13483700E-01, 0.43164600E-01, -.51401800E+00, 0.24669800E+00, 0.16482900E+00, 0.13985800E+00, -.71200000E+00, -.21715400E+01, 0.20658000E+01, 0.90628100E+00, -.16131600E+00, 0.90331300E-01, 0.14054300E+00, -.91558900E+00, -.92109700E+00, 0.11668600E+00, -.45668200E+00, 0.43174800E+00, 0.10299400E+00, -.24629200E+00, -.27154500E+00, -.75505700E+00, 0.23634900E+00, 0.61228800E-01, 0.75175900E+01, 0.52102400E+00, 0.72238100E-01, -.20898900E+00, -.96942900E+00, 0.81372200E+00, -.39412100E+00, 0.12749600E+01, -.37385500E+00, 0.84935000E-01, 0.78154100E+00, -.37337200E+00, 0.45732200E+00, 0.36493400E+00, 0.90722100E+00, 0.59316300E+00, -.90776400E-01, 0.51132000E+00, -.30143200E+00, 0.25392800E+00, 0.10892800E+00, 0.31379500E+01, -.20992100E+00, 0.24817700E+00, 0.33075800E+00, -.70180200E+00, -.94548200E+00, -.24634500E+01, -.86014600E-01, -.64920800E-01, -.23137700E-01, -.84910700E-02, 0.67305100E+00, -.71389900E+00, 0.20472000E+01, -.47472600E-01, -.28911400E-01, -.44761100E+00, 0.22366500E+00, 0.59763100E+00, 0.29544000E+00, 0.72252400E+00, 0.31141600E+02, -.20297300E+02, 0.64784700E+01, 0.65229000E-01, 0.21496800E+03, 0.56306400E+02, -.82653500E+02, 0.15420500E+03, 0.95841700E+03, -.48326600E+03, -.42205800E+03, -.47819200E+03, -.10392700E+03, -.10121500E+03, -.19200400E+03, 0.15007800E+03, -.12011200E+03, -.10743900E+03, -.38850300E+03, 0.75752200E+03, -.38069200E+03, -.16862200E+03, -.36886800E+03, -.15889400E+03, -.14571700E+03, -.20605400E+03, -.27565900E+03, -.43073200E+03, -.11227400E+03, -.67810700E+03, -.14187600E+03, 0.71462200E+02, 0.56763300E+02, 0.41879100E+02, 0.75733700E+02, -.12849900E+03, 0.10128100E+03, 0.10129500E+03, 0.89330900E+01, -.53971900E+02, 0.50274700E+02, 0.70166300E+02, -.33436400E+02, -.12379600E+03, -.38798200E+02, 0.17375900E+02, -.99774200E+02, 0.10774300E+02, 0.18293200E+03, 0.91226100E+02, -.97665200E+02, 0.10496000E+03, -.14527000E+02, 0.85428400E+01, 0.22276700E+03, 0.74335000E+01, -.13111500E+03, -.20518500E+03, -.50851300E+02, -.51221200E+03, -.36168700E+03, -.11869300E+03, -.38215800E+03, -.14316700E+03, 0.71874800E+02, 0.56056700E+02, 0.70542000E+02, 0.11352500E+03, -.85725200E+02, 0.98378700E+02, 0.15806400E+03, -.92908100E+02, -.98997500E+02, 0.95468300E+02, -.21958600E+03, 0.11752800E+03, 0.84384900E+02, 0.95671000E+02, 0.31288400E+03, 0.10677700E+03, 0.88340500E+02, 0.14998400E+03, -.10774600E+03, 0.40367500E+02, 0.55610000E+02, 0.17493200E+02, -.26196000E+02, 0.11057800E+02, 0.11757100E+02, -.11341700E+02, -.76107500E+01, 0.14434100E+02, -.10246700E+02, -.14170500E+02, -.84455700E+01, -.10565200E+02, 0.48399100E+02, -.97135900E+01, -.10531200E+02, 0.94801600E+01, -.15531700E+02, 0.72171600E+02, 0.26544200E+02, -.23526200E+02, -.23861500E+01, -.88213900E+02, -.26229900E+02, 0.32592900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29050200E+01, -.64008600E+01, -.22703200E+01, -.36413500E+01, -.19189100E+01, 0.93435600E+00, -.10862400E+01, -.59500300E+01, 0.20363000E+02, -.73122100E+00, 0.13598300E+01, 0.32149900E+01, 0.80135200E+00, 0.32176600E+00, -.31769100E+01, 0.28713900E+01, 0.33295300E+01, -.66117700E+01, -.12810700E+01, -.24221300E+01, 0.33702100E+01, -.11381400E+01, 0.77948900E+01, -.81584300E+00, 0.44601600E+00, -.57332500E-01, 0.38462100E+00, -.14480800E+00, 0.21429700E+00, 0.17335200E+01, 0.20369800E+01, 0.13442800E+01, -.14324600E+01, -.26733800E+00, 0.24361000E+00, -.62320300E+00, 0.37658900E-01, 0.28915200E+01, 0.14041600E+01, 0.18166200E+01, -.13226100E+00, -.10946000E+01, 0.15732800E+01, -.52349500E+00, -.10556300E+00, 0.17523500E+00, 0.88417500E+00, -.42785700E-01, 0.52057800E+00, 0.44570100E-02, -.20790500E+01, -.52706900E+00, 0.23296100E+01, 0.47416200E+00, -.14991700E+01, 0.60605200E+00, 0.18116500E+01, -.21212600E+00, -.12170700E+01, -.53104600E+01, -.26594700E+01, 0.28564500E+00, 0.20094900E+01, 0.21036700E+00, -.54659900E+00, -.28624100E+01, 0.79150000E+00, 0.12610000E-02, -.34456000E+00, 0.61195900E-02, -.71430000E+00, -.34867300E+01, 0.84944500E+01, -.47947100E+01, 0.35450600E+01, 0.18801900E+01, -.14167400E+01, 0.34527100E+00, 0.14401800E+00, 0.52425300E+00, -.20198300E-02, -.12669000E+01, -.31494600E+00, 0.41886100E-01, 0.12148800E+01, -.15944200E+01, -.20234600E+00, 0.22207700E+01, 0.34727800E+00, -.48783600E-01, 0.19896400E+01, -.77342700E-01, -.19241000E+00, -.10810800E+01, -.56474900E+00, 0.13069300E+01, 0.72526900E+00, -.42107500E+00, 0.11472900E+01, 0.22800100E+00, 0.21125000E+01, 0.36862800E+00, 0.62105600E-01, 0.27860600E+00, 0.99339200E+00, -.55288800E+00, -.23082400E+00, 0.76232900E-01, -.53955300E-01, -.25805400E+00, 0.39537000E-01, 0.50283000E+00, -.72185900E+00, 0.22742800E+00, 0.19209100E+00, -.77268200E+00, 0.20545900E+00, 0.14741800E+00, -.34154800E+00, 0.14087900E+00, -.22489400E+00, 0.23161300E+00, -.17341200E+01, -.36782500E+00, -.17272900E-01, 0.39328600E-01, 0.49735100E+00, -.49762300E+00, -.85704200E+00, -.34162100E+00, -.44717800E+00, 0.55893300E+00, 0.20912500E+01, 0.50765900E-01, -.24667000E+00, 0.84666600E-01, -.14486400E+01, -.36551000E+00, -.13744800E+00, 0.88509400E-01, 0.67782800E+00, -.32754400E+01, 0.23469100E+01, -.51245600E+00, -.12291300E+00, -.89323600E+00, 0.39464200E-01, 0.72960300E+00, -.17828700E+00, 0.88825800E+00, 0.45248600E-01, 0.20650200E+01, -.16616700E+01, 0.75409300E-02, 0.68953500E+00, 0.75341100E+00, 0.81811900E+00, 0.90787400E-01, 0.15297900E+03, 0.17557500E+03, -.20761900E+03, -.47174200E+03, -.82668300E+02, 0.26523400E+03, -.10794300E+03, 0.11937300E+04, -.59314800E+03, -.43436600E+03, -.59453300E+03, -.27955800E+03, 0.10537700E+02, -.18843800E+03, 0.35743100E+03, -.43332700E+03, -.10547800E+03, -.38930400E+03, 0.31362000E+02, -.25096500E+02, -.54293400E+02, 0.46289500E+01, -.13164000E+03, 0.17422600E+02, -.28382200E+03, -.55609100E+03, -.10268500E+03, 0.17479700E+03, 0.25637800E+03, 0.64207600E+02, -.32086600E+02, 0.51989600E+01, -.46821100E+01, 0.21030000E+03, 0.16007700E+03, 0.50988400E+02, 0.23503100E+03, 0.10388200E+03, 0.18983200E+03, -.21481300E+03, -.50462200E+02, 0.21585700E+02, -.21918000E+02, 0.17963600E+02, -.59917800E+02, -.77869700E+02, 0.23932200E+02, -.38011300E+02, -.26074500E+01, -.32044300E+02, -.10768100E+03, -.26419100E+03, 0.12939100E+03, 0.16357100E+03, 0.13236600E+03, -.12523300E+03, -.15201200E+03, -.67915300E+02, -.38127700E+03, -.19809600E+02, 0.62893900E+02, 0.38636400E+03, 0.68761900E+03, -.34407300E+03, -.21405300E+03, -.34626800E+03, -.34239500E+03, -.30647600E+02, -.12263200E+03, 0.32054000E+03, -.39523000E+02, -.46441300E+02, 0.34354900E+03, 0.11317700E+04, -.56119300E+03, -.46017600E+03, -.55374000E+03, -.11883000E+03, -.48815200E+02, -.12924300E+03, 0.47595200E+03, -.16272100E+03, -.23163400E+02, -.21769700E+02, -.53369900E+01, 0.61135000E+00, -.90073400E+02, -.11600800E+02, -.13011500E+02, -.14583100E+02, -.54678400E+01, 0.90360600E+02, 0.37082100E+02, 0.58016200E+02, 0.35256700E+02, -.11405400E+03, 0.49774600E+02, -.13656400E+02, 0.11363700E+02, 0.45468900E+02, 0.40275500E+03, -.20495000E+02, 0.65267600E+02, 0.11234600E+02, 0.55687700E+01, -.42147300E+02, -.14574800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.26357200E+01, -.30477800E+01, -.13715400E+01, -.19366100E+01, -.19317000E+01, 0.13255900E+01, -.10011900E+01, -.34486900E+01, 0.12786900E+02, -.37995300E+00, 0.13915500E+01, 0.24709300E+01, 0.10785300E+01, 0.16141900E+00, -.17331200E+01, 0.25107800E+01, 0.33887600E+01, -.51800200E+01, -.63806400E+00, -.19368900E+01, 0.20652000E+01, -.25976600E+01, 0.92038400E+00, -.18481800E+01, -.15371400E+01, -.29920000E-01, -.64330200E+00, -.68469300E-01, -.17721400E-01, -.39604000E-01, 0.89715400E-01, 0.14555000E+00, 0.50488300E-01, -.10887800E+00, -.63310700E+00, -.13025700E+00, 0.14756100E-01, 0.52899100E+00, 0.78955500E+00, -.42317600E+00, -.37381500E+00, -.13241500E+00, -.26609000E+00, -.64282700E-01, 0.27741000E+00, 0.19814000E+00, 0.82749600E+00, 0.19233100E+00, -.35959600E+00, -.32206600E+00, -.21449400E+01, -.55430500E+00, 0.32820800E+00, 0.19540200E+01, -.11032700E+01, 0.25884500E+01, -.15598900E+01, -.50417900E+00, 0.14064800E+00, -.53663000E+01, 0.68813100E+00, 0.19368300E+00, 0.29496400E+00, 0.44820600E+00, 0.21606800E+01, 0.27213400E+00, -.98466800E+01, -.12670800E+01, -.69860900E-01, -.20842800E-03, 0.33728900E+00, 0.52200200E+00, -.15817300E+00, -.16965100E-01, 0.57377300E+00, 0.25708300E-02, -.10875600E+01, -.53485700E+00, -.14691000E+00, 0.10715100E+00, 0.39721700E-02, -.71248300E+00, 0.34727800E+00, 0.47745600E+00, 0.15062300E+01, 0.10472300E+01, 0.11509300E+00, 0.23873600E+01, -.12667600E+01, 0.19994100E+00, 0.15885900E+01, 0.51078700E-01, -.13540000E-01, -.60762800E+00, 0.20085100E+00, 0.83786000E+00, 0.15398000E-01, 0.19771400E+00, -.19682200E+01, 0.70923500E+00, -.22293600E+01, 0.63730400E+00, -.13120100E-02, 0.12965200E+00, -.10645900E+01, -.33909100E+00, 0.76047100E-01, 0.15478400E+00, -.25749900E+00, 0.59338600E+00, -.61671000E-01, -.50892300E+00, -.55909000E+00, 0.17675900E+00, 0.60568600E-01, 0.72494100E+00, -.12546000E+01, 0.19565000E+00, -.21248100E+00, -.25269700E+01, -.47424000E+00, 0.18370100E-01, 0.28323600E+01, 0.50124500E+00, -.85693000E-02, 0.85946700E+00, 0.17342000E+01, 0.16467400E+00, -.18945200E+00, 0.75042600E+00, 0.38512300E+00, 0.12994200E+01, -.20781300E+01, 0.19016200E+00, 0.53831800E+00, -.77165500E-01, -.19653600E+01, -.56116700E+00, 0.33092100E+00, -.11394800E+00, -.12876800E+01, -.81234800E+00, 0.54766800E+00, 0.29062400E+00, 0.12111800E+00, -.67553600E+00, -.35065100E-01, 0.56719000E+00, -.26796700E+01, 0.37530500E+01, -.17361300E+00, 0.72371700E+00, 0.24712700E+01, -.19280700E+00, 0.22389300E+00, -.52733800E-01, 0.12002600E+00, -.22794800E-02, 0.37824000E+00, -.11685000E+03, 0.78538400E+02, 0.36179400E+02, -.56318800E+02, -.20586400E+03, -.50569200E+02, -.32324300E+02, 0.12878200E+02, -.58287100E+02, 0.15229600E+02, -.12744700E+02, -.13466100E+03, 0.11693400E+03, 0.20868400E+03, 0.30567500E+03, -.11578200E+03, 0.22302700E+03, 0.37994700E+03, -.18271200E+03, 0.27544300E+02, -.19786300E+03, 0.18376200E+03, -.59371000E+02, -.38375200E+02, -.42597500E+01, -.33650100E+03, -.61366500E+02, -.17778400E+03, -.41052100E+03, 0.20667400E+03, 0.26607600E+03, 0.18829000E+03, -.64884800E+02, -.98865400E+02, 0.23500000E+02, -.18820600E+03, -.12843200E+03, -.39028400E+02, 0.30120100E+03, 0.32321100E+03, -.16095900E+03, -.11852800E+03, -.15884000E+03, 0.32841300E+02, 0.15045600E+02, -.39026200E+02, 0.12450000E+03, -.10965300E+03, -.45866900E+02, -.45805100E+02, 0.39073900E+03, -.19355000E+03, 0.76239200E+01, -.19546800E+03, 0.22975900E+03, -.19781100E+02, 0.36927400E+02, 0.26672300E+03, -.15997500E+03, -.36304200E+02, -.25401500E+03, -.75133800E+03, 0.37642300E+03, 0.28022400E+03, 0.37665800E+03, 0.28033600E+03, -.44634100E+02, 0.16148300E+03, -.20847500E+03, 0.17635800E+03, -.22469500E+02, 0.45509600E+03, -.75213700E+03, 0.37833600E+03, 0.10433600E+03, 0.36102200E+03, 0.82331000E+02, 0.30560500E+02, 0.10190500E+03, -.31902500E+03, 0.18607300E+03, 0.13360900E+02, 0.24140900E+03, 0.14675300E+02, 0.18045400E+02, 0.64021100E+02, -.71100300E+00, -.10976500E+02, -.98385600E+01, 0.13047100E+02, -.64154100E+02, -.28139800E+02, -.43951800E+02, -.32136800E+02, 0.10416700E+03, -.25373000E+02, -.11631400E+02, 0.12176100E+02, -.99953000E+01, -.23305500E+03, 0.48088000E+02, -.60788700E+02, 0.10642400E+02, -.82204800E+02, 0.50288500E+02, -.50466200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.89958700E+01, 0.65611100E+01, 0.27710700E+01, 0.25319100E+01, -.46457700E+00, -.30287200E+01, 0.21805900E+01, 0.10626500E+02, 0.21260100E+02, -.13994900E+01, -.13293800E+00, -.28174400E+00, 0.92053500E+00, -.51777200E+00, 0.37212100E+01, -.34686700E+01, -.47627400E+01, 0.16686800E+02, 0.27845400E+01, 0.28529400E+01, -.38080100E+01, 0.27002400E+01, 0.80880500E+01, 0.36902500E+01, -.18052300E+01, 0.19827900E+00, -.54288400E+00, 0.67904300E+00, -.10160000E+01, -.20173900E+01, -.95804100E+00, 0.17157100E+00, -.15765100E-01, 0.71058400E+00, -.42901100E+00, 0.15865900E+00, -.71208300E-02, -.13035100E+01, 0.13084000E+01, -.14692100E+01, -.35170600E+01, 0.14336200E+01, 0.37828700E+01, 0.30955300E+01, -.96657100E-02, -.63940300E-01, 0.44413200E+00, 0.27598000E+00, 0.19414100E+00, 0.59069400E-01, -.51573100E+01, 0.73142600E+00, -.19277900E+01, -.14498900E+00, 0.76753000E-01, 0.44275400E+01, -.62930000E+00, -.60918000E-02, 0.10265700E+01, 0.27255500E+01, 0.16447000E+01, 0.16344100E+00, -.61483200E-02, 0.35172200E+00, 0.30049800E+01, -.12128700E+01, -.10388300E+01, -.22163300E+00, 0.26421500E-01, 0.32933800E+00, 0.60362900E+00, 0.96470100E+00, 0.60519800E+01, -.46529800E+01, 0.48901600E+01, 0.33067500E+01, 0.30568600E+01, 0.30932000E-01, -.11821400E+00, -.10284800E+00, 0.38321000E-02, 0.22550800E+00, 0.11803900E+01, 0.14013000E+01, 0.59383700E+01, 0.79197400E+00, 0.53173100E+00, -.13554600E+01, 0.82650300E+00, 0.51608800E+00, 0.13484600E+01, -.43685600E-01, 0.27907000E+00, -.30697700E+00, 0.16546200E+00, 0.40985100E+00, -.53248000E+00, -.38330500E+01, -.21094800E+01, 0.28588400E+01, 0.17365600E+01, 0.52637300E+00, -.94719300E-01, 0.35014400E+01, -.23560500E+01, -.39036200E+00, 0.60770000E+00, 0.98774400E-01, -.21398300E+00, -.70462600E+00, 0.19234600E+00, -.33547500E+00, -.80915600E+00, 0.25214300E+00, 0.92582800E+00, 0.41412200E-01, -.16131700E+01, 0.53037700E+00, -.52548100E+00, -.37762500E+01, -.10407300E+01, -.32912100E+00, 0.52215900E+01, 0.56508400E+00, 0.67214000E-01, 0.87455700E+00, 0.10820800E+01, 0.51093400E+00, -.74909200E+00, 0.56263800E+00, -.12097300E+01, 0.32338000E+01, -.37606600E+01, -.15074000E+00, 0.27780600E-01, 0.99062500E-01, 0.49994300E+00, -.40438700E-01, -.17349100E+00, 0.71380200E+00, 0.14092200E+01, -.86888700E+00, 0.28040300E+01, 0.86105300E+00, -.41100300E+00, -.32267100E+01, 0.71881900E-01, 0.43164700E+01, 0.10750500E+01, -.35264900E+00, -.10890800E+01, -.16260600E+01, -.38484700E+01, -.50896500E+00, 0.16544200E+00, 0.10343500E+00, 0.17338200E+00, -.31714500E-01, -.54898200E+00, 0.16459800E+01, -.44988700E+03, -.97914100E+03, -.27278400E+03, 0.26491600E+03, -.30841100E+03, 0.11130200E+04, -.57465700E+03, -.34996500E+03, -.55448700E+03, -.28634800E+03, 0.24327400E+03, -.17633900E+03, 0.28030000E+03, -.63563900E+03, 0.29881200E+02, 0.52572000E+03, 0.26861400E+03, -.14942000E+03, 0.13098900E+03, -.11622300E+03, -.60929800E+03, 0.50508000E+02, -.84645700E+03, -.52091200E+03, -.96629700E+02, 0.23275400E+03, -.31176700E+02, 0.52967400E+03, -.26829600E+03, -.18330800E+03, -.26680100E+03, 0.25381800E+03, 0.16649800E+03, -.47806300E+03, -.47781600E+02, 0.16018100E+00, 0.14343600E+03, -.41123400E+03, -.48163200E+03, 0.24415900E+03, -.25524200E+03, 0.23419700E+03, 0.68813400E+00, -.22503400E+03, -.74025100E+02, -.45701000E+03, 0.16339300E+03, 0.78976700E+02, 0.17372100E+03, -.39263300E+03, 0.18927400E+03, 0.29750600E+03, 0.19656300E+03, -.65277100E+03, -.36596900E+03, -.15980700E+03, -.14533700E+03, 0.36460000E+03, -.10449700E+03, 0.56118900E+02, 0.15926800E+04, -.79979600E+03, -.42360800E+03, -.79846400E+03, -.46086300E+03, -.63488600E+02, -.37279500E+03, 0.12338100E+03, -.43542900E+03, -.84417900E+02, -.94269600E+03, 0.96688600E+03, -.48146700E+03, -.68009600E+02, -.48696600E+03, -.82018800E+02, -.11465100E+03, -.43223500E+01, 0.30515000E+03, -.30677200E+03, 0.21285100E+01, -.66851800E+03, -.57883300E+02, -.12313200E+03, -.15005400E+03, -.75421300E+01, -.20032900E+02, -.23983900E+02, -.44020700E+02, 0.15378700E+03, 0.69869000E+02, 0.72852300E+02, 0.53325800E+02, -.11606800E+03, 0.85692100E+01, -.19349700E+02, 0.16288000E+02, 0.52469600E+02, 0.75779700E+03, 0.32950400E+02, -.72737000E+02, 0.30999400E+01, -.55265500E+01, -.97923600E+02, 0.10517200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.61370000E+00, 0.18701700E+01, 0.37551700E-01, 0.11466200E+01, -.30644600E+00, -.59496000E+00, 0.88599300E-01, 0.51607100E+00, 0.89564900E+00, -.68635100E+00, -.34605400E-01, -.22667100E+00, -.15964100E+00, -.55857000E-01, 0.28931200E+00, -.45876900E+00, -.14930400E+01, -.10408500E+01, -.93831900E-01, 0.25033600E+00, -.17192700E+00, -.55562000E-01, -.11964400E+01, -.63734100E+00, -.98219100E-01, -.10109400E-01, 0.12000900E+00, 0.11582800E-01, -.24784100E+00, 0.47191300E-01, -.18223500E-01, -.17600800E+00, 0.14890400E+00, 0.10244500E-02, 0.13940400E+00, 0.11975300E+00, -.31053300E-02, -.11235400E+00, -.59994100E+00, 0.14076300E+00, -.17356700E+00, -.51228700E-01, -.13980600E-01, -.63410000E-02, 0.53253200E-01, 0.40939700E-01, 0.90675700E-01, -.59629400E-01, -.38028400E-01, -.37459300E-01, -.21051800E+00, -.29987700E+00, -.59486900E-01, 0.69081000E-01, 0.10586100E+00, 0.21753600E+00, 0.87522700E-02, -.68823100E-01, -.12837800E+00, -.15118500E+00, 0.13427300E+00, -.10653000E+00, 0.29748000E+00, -.26391200E+00, -.76172000E+00, 0.52257200E+00, -.10191500E+01, 0.35666600E-01, -.12048700E-01, -.31248100E-03, 0.13767100E+00, 0.11692800E+00, 0.16321500E+01, 0.11463900E+00, -.21769400E+00, 0.25644800E+00, -.39862600E+00, 0.28541800E+00, -.15947500E+00, -.25597200E-01, 0.72398600E-03, -.31995300E+00, -.25315400E+00, 0.10252100E+00, -.14952100E-01, 0.11053400E+00, -.61088500E-01, 0.98963600E+00, -.67611600E+00, 0.10433300E+00, 0.10417100E+00, 0.25267400E-01, -.49332600E-01, -.47792600E+00, -.34347400E-01, 0.57006900E+00, 0.12271200E+00, 0.11954500E+00, -.88420300E-01, 0.13555600E+01, 0.86521800E+00, 0.27282300E+00, -.68769500E-01, 0.69434000E+00, -.40324200E-01, 0.14888600E+00, 0.61181800E-01, -.30610400E+00, 0.14501800E+00, 0.61805700E-02, 0.31668300E-01, -.81400600E-01, -.15547300E+00, 0.48941200E-01, 0.10724700E+00, 0.14765500E+01, 0.61905700E-01, 0.10909800E+00, -.46330600E-01, -.18267400E+00, -.45958200E-02, -.78262400E-01, 0.71670300E+00, 0.14756800E+00, -.11381900E-01, -.13193500E+00, 0.34685300E+00, 0.59556800E-02, 0.31817000E+00, 0.13573800E+00, 0.16688000E+00, 0.48760300E+00, 0.17343500E+01, -.40207900E-01, 0.56409300E-01, -.75343700E-02, 0.13719200E+00, -.19766300E-02, 0.94339800E-01, -.62641200E-01, -.17067500E+00, 0.29322100E+00, -.12921800E+00, -.13333600E+00, 0.55498800E-01, 0.28853700E+00, -.18494700E-01, -.44706700E+00, -.19573600E+00, 0.10047500E+00, 0.29984200E-01, -.36320200E+00, -.10572800E-02, 0.27155500E+00, -.60632400E-01, -.59063800E-01, -.16432300E+00, -.42149300E-02, -.11471300E+00, -.76821300E-01, -.43308600E-01, 0.15227700E+03, 0.68629500E+02, -.14484200E+02, 0.15444700E+03, -.19577200E+02, 0.13323400E+02, -.93220200E+02, 0.99793800E+01, 0.58904000E+02, 0.42716300E+02, -.32477800E+02, -.47678600E+02, 0.11221200E+01, 0.27997300E+02, -.19865900E+03, 0.24589800E+03, -.12393600E+03, -.10513200E+02, -.12091700E+03, -.12019900E+03, -.87076800E+02, -.72077100E+02, 0.27356100E+02, -.15317900E+03, -.32329900E+02, -.20562600E+03, 0.20087500E+02, -.10228900E+02, 0.25407000E+02, -.10680900E+02, 0.44206300E+02, -.10411800E+02, -.49191100E+01, -.16924900E+02, -.63950000E+02, 0.25277000E+02, -.21830700E+02, -.89209500E+02, 0.44886800E+02, 0.13776500E+03, 0.43795600E+02, 0.14794400E+02, 0.13241600E+02, 0.32229300E+02, 0.99436500E+02, 0.93288100E+02, -.13895500E+01, 0.47440800E+02, -.86312900E+02, 0.43194100E+02, 0.16593900E+03, 0.43194100E+02, -.13080100E+03, -.61489600E+02, -.44359000E+01, -.78502300E+02, -.49776200E+02, -.42076100E+01, 0.18681300E+02, 0.18031300E+03, -.90387100E+02, -.12493500E+01, -.90347500E+02, 0.25215400E+00, 0.30533800E+02, -.31803000E+02, 0.14483200E+03, -.95093400E+02, -.26543500E+01, 0.41088800E+02, 0.36519100E+03, -.18284000E+03, 0.11381500E+03, -.18285900E+03, -.28198400E+02, 0.20968000E+02, -.10214400E+03, 0.78780200E+02, -.19569000E+03, 0.95102100E+01, -.41202800E+02, -.92253700E+01, 0.22571800E+01, -.12523000E+01, 0.11549000E+01, -.61927300E+01, -.66047700E+01, -.65647000E+01, 0.17269500E+01, -.67179300E+01, -.19984100E+01, -.48077100E+01, -.37017400E+01, -.96814000E+01, -.57684900E+01, 0.68859700E+01, -.18111900E+02, 0.92118300E+02, 0.20166000E+02, -.21092300E+02, -.99469900E-01, -.35976800E+02, -.43980500E+01, -.84973800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29383300E+00, -.77850100E+00, -.82071700E-01, -.87750200E+00, -.30659100E+00, 0.89805900E+00, -.10324200E+00, -.69738900E+00, -.35648900E+01, -.50157000E+00, 0.77665300E-01, 0.25504100E+00, 0.58351500E+00, -.10738300E+00, -.12137400E+00, 0.61742400E+00, 0.24466600E+01, 0.77657400E+00, -.17020800E+00, -.15877400E+00, 0.78552500E-01, -.10862100E+00, -.12461500E+00, -.12606700E+00, 0.18691100E+00, -.21494800E-02, 0.43124000E+00, 0.17125300E-01, -.13230000E-01, 0.15024300E+00, -.61585700E-01, 0.87695700E-01, 0.21046700E-02, 0.10344100E+00, 0.12193100E+00, 0.49554200E-01, -.24160900E-02, -.51213400E-01, -.60605400E-01, -.10659700E+00, -.23723500E+00, 0.44368400E-02, -.19126200E+00, -.73174800E-01, 0.77556200E-03, -.78464700E-02, -.72974000E-01, 0.95401400E-02, 0.20387300E-01, -.75911700E-02, -.26638500E+00, -.85356400E-01, 0.53152500E-02, 0.18523200E-01, -.46986300E-01, -.31071500E-01, -.41523600E-01, -.68819500E-01, -.58067600E-01, -.39990400E+00, -.29568800E-01, -.22104600E-01, 0.14511000E+00, 0.57817900E-01, 0.36066300E-01, 0.46354100E-01, -.46638500E+00, -.14251400E-02, 0.20511300E-01, -.11664500E-03, 0.21748800E-01, 0.35651600E+00, 0.99079200E-01, -.72825000E-01, -.14763700E+00, 0.31632100E+00, -.37001200E-01, 0.70891900E-01, -.44075600E-01, 0.27768400E-01, -.16309700E-03, 0.18918100E+00, -.16367200E+00, 0.41183200E+00, 0.86840600E-01, 0.10185700E+00, 0.50296400E-01, 0.13021100E+01, -.16919200E+00, 0.18279000E-01, 0.36014800E+00, 0.18454400E-01, -.57614100E-01, -.12291700E-01, 0.10075900E+00, -.30725800E-01, 0.14244600E+00, 0.15269700E+00, -.35351700E+00, 0.54016900E+00, 0.25395100E+00, -.21432100E-01, -.25902800E-01, 0.14935000E+00, -.29741600E+00, -.57400100E-01, 0.26974200E-01, -.30989900E-02, 0.14536700E-01, 0.50189600E-01, 0.85697500E-02, -.94098600E-01, -.77140500E-01, 0.24601600E-01, -.50371600E-01, -.49698400E+00, -.59893400E-01, -.57462500E-01, -.51109700E-01, 0.27559300E+00, 0.14878100E-02, 0.58570500E-02, -.35034900E+00, -.49282300E-01, 0.32307500E-02, -.73715400E-01, 0.35409600E-01, -.19847400E-01, 0.53707000E-01, -.16692600E+00, -.14999200E-01, -.73210500E-01, -.24301300E+00, -.12743400E-01, 0.11683000E+00, -.15314700E-02, -.15085900E+00, -.43736700E-01, 0.23588200E-01, 0.86380700E-02, -.97598100E-01, -.15600800E+00, -.13195800E-02, 0.55840600E-01, -.10333500E-01, -.18659400E-01, -.12224500E-01, -.51563400E-01, -.36067300E+00, 0.62653800E+00, -.12950500E-01, 0.22320800E+00, 0.33609100E+00, 0.11524500E+00, 0.71055700E-01, 0.56106600E-01, -.15236700E+00, -.59417000E-02, -.11120400E-01, -.41678800E-01, 0.64948900E-03, 0.16571500E+00, -.17473100E+02, -.10036500E+02, -.31876200E+02, -.36572500E+02, 0.17958400E+02, 0.18617800E+02, 0.18086200E+02, 0.15537300E+02, -.45107200E+01, 0.11598500E+02, 0.29089700E+01, 0.37274100E+02, 0.38716400E+01, -.18981100E+02, 0.24015400E+02, -.11830700E+02, -.44353600E+02, -.13866300E+02, -.15432600E+02, -.19357200E+02, 0.82022200E+01, 0.47026600E+02, 0.13998100E+02, -.23536200E+02, 0.55124000E+01, -.30204500E+01, 0.19383300E+01, -.11611300E+02, -.18844900E+01, -.36863100E+01, -.58221900E+00, 0.17047100E+00, 0.46355700E+01, -.12331800E+02, -.38471800E+00, 0.72808700E+01, 0.33875100E+02, -.17121000E+02, 0.15997800E+02, -.16240400E+02, -.28197100E+01, 0.13778000E+02, -.82629000E+01, 0.42916600E+01, -.28743900E+02, 0.61934600E+01, -.28022700E+02, 0.41654300E+02, -.20135100E+02, -.36522200E+02, -.20854300E+02, -.20661400E+02, -.89558900E+01, 0.56831100E+01, 0.48650400E+02, 0.24025000E+01, -.12661100E+02, -.45179900E+00, -.10484300E+03, 0.52176600E+02, 0.12853000E+02, 0.52629500E+02, 0.22580400E+02, 0.18237600E+02, -.86004600E+01, -.66643200E+02, 0.90905700E+01, 0.19808300E+02, 0.43716200E+02, -.19946400E+02, 0.10111000E+02, -.14855800E+02, 0.73806300E+01, 0.11786100E+02, 0.17414900E+02, -.11113600E+01, 0.21873200E+02, 0.13544200E+02, 0.81056100E+01, 0.45425100E+01, -.52515000E+00, 0.86045200E+01, 0.64226500E+01, 0.37287700E+00, 0.21462900E+00, 0.21063400E+00, -.65543300E+00, -.65601200E+01, -.46746500E+00, -.72484300E+00, 0.40331200E+00, 0.26210900E+01, 0.23419600E+01, 0.92447800E-01, 0.18505000E+00, 0.21707800E+01, -.21390700E+02, -.10158200E+01, -.21717100E+01, -.11265100E+00, -.27122800E+01, 0.50892400E+01, -.79650800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21768400E+01, 0.36634300E+01, 0.86097000E+00, 0.14721200E+01, 0.24550000E+00, -.12896100E+01, 0.69341800E+00, 0.20879100E+01, -.28565800E+02, -.11334700E+00, -.92908900E+00, -.24484000E+01, -.25079400E+00, 0.92858300E-01, -.43170600E+00, -.37549900E+01, -.27113200E+01, -.63410900E+00, -.36065800E-01, 0.31459100E+01, -.11591300E+01, 0.51106500E+00, -.10527700E+01, 0.12943600E+01, 0.55920800E-01, 0.30552500E-01, 0.17628100E+01, 0.28608100E+00, 0.22349800E-02, -.10344200E+00, -.56407900E+00, -.33924800E+00, 0.56941500E+00, -.11309100E+01, -.64285000E+00, 0.24787800E+00, -.19326000E-01, 0.11187200E+00, 0.21011200E+00, -.11089300E+00, 0.18975500E+01, 0.47099400E+00, 0.97728900E+00, 0.16324400E+01, 0.49817500E+00, -.19864000E+00, 0.12015200E+00, -.65054500E-01, 0.44179700E-01, 0.61028800E+00, 0.14004500E+01, 0.29091300E+00, -.35536800E+00, -.20151400E+00, -.39538700E+00, -.54240200E+00, -.59821200E+00, 0.69853500E-01, 0.44467300E-01, -.22452300E-01, -.35596500E+00, 0.14173000E+00, 0.45680100E+00, 0.15837800E+00, -.21397500E+00, 0.18764500E-01, 0.58802000E+00, 0.10252700E+00, -.64123200E-01, 0.18650300E-02, -.30955500E+00, -.84359400E+00, 0.38497900E+01, -.25681000E+01, 0.19315600E+01, 0.72586900E+00, -.45988500E+00, -.41932700E+00, 0.10935200E+00, 0.20002300E+00, -.44658100E-03, -.18762600E+01, 0.18331000E+00, 0.18996800E+00, -.56942600E-01, -.10040500E+01, -.11434100E+00, 0.33131700E+01, -.89216900E+00, -.85819300E-01, 0.20010700E+01, -.42113000E-01, -.44187900E+00, -.48003400E-01, 0.80428900E-01, 0.15089200E+00, -.66492800E+00, -.10580500E+00, 0.32925600E+00, -.24406000E+00, -.11725100E+01, 0.13866700E+00, 0.82820500E-01, -.79243200E+00, 0.36927600E+00, 0.14429400E+01, 0.27477000E+00, 0.33257900E+00, 0.70938000E-01, 0.96736200E-01, 0.56104800E-01, -.15277300E+00, 0.60014600E+00, -.19103400E+00, -.60307300E-01, 0.21288700E+01, 0.93262400E+00, -.24782000E+00, 0.53049400E-01, 0.35106900E+00, 0.10547000E-01, -.12867300E+00, 0.21371300E+01, 0.47511100E+00, -.40843900E-01, 0.35145500E+00, -.85776000E-01, 0.20360400E-01, -.22854300E+00, 0.51278600E+00, 0.27337700E+00, -.23300200E+00, 0.44443500E+01, -.29271000E-01, -.63085900E+00, 0.42918600E-01, 0.99178100E-01, -.48888900E+00, -.14329300E-01, 0.13196500E+00, -.64399100E+00, -.14943900E+01, 0.12889200E+01, -.15930900E+00, 0.30356300E+00, -.50812100E-02, -.10463100E-01, 0.65761300E+00, 0.19612700E+00, -.81303800E-01, -.13875700E+00, 0.15628000E+01, -.21030200E+01, -.91443300E+00, -.81648100E-01, 0.27274100E+00, 0.10969500E+01, -.61001300E-01, -.93127000E-01, -.10121100E+01, 0.14922800E+00, -.18773600E+01, 0.30057400E+01, -.14511200E+03, -.19673000E+03, 0.74776500E+03, -.39180600E+03, -.78107900E+03, -.37560500E+03, -.12674200E+03, -.17998000E+03, 0.56512600E+02, 0.59627300E+03, 0.21201000E+03, -.22405700E+03, 0.99457600E+03, -.92729200E+03, 0.47136900E+03, -.29194700E+03, 0.44797800E+03, 0.70039100E+02, -.38244200E+03, 0.77933700E+03, 0.47390400E+03, 0.36669500E+03, -.37175900E+03, 0.66698900E+03, -.17595700E+03, 0.89450800E+02, -.16430100E+03, 0.91654800E+02, -.98027200E+02, -.24564200E+03, 0.18717700E+03, -.57776300E+02, -.76216300E+02, -.16545600E+03, 0.18472000E+03, 0.23721900E+03, -.11800200E+03, -.61550500E+02, -.11290800E+03, 0.64817100E+02, 0.11415600E+00, -.10179200E+03, -.30315000E+02, -.93988500E+01, -.67609800E+02, 0.92831000E+02, -.83876300E+03, 0.42246700E+03, 0.35350100E+02, 0.41914600E+03, 0.31433800E+03, -.22177100E+03, 0.52975300E+03, 0.30847200E+03, 0.23615600E+03, -.17297600E+03, 0.22722000E+03, 0.64599700E+02, -.32950800E+02, 0.27257200E+03, -.30503800E+02, 0.21794400E+03, 0.17336100E+02, -.28501400E+02, -.10776000E+03, -.19461200E+03, 0.41864200E+02, 0.35916900E+03, -.21232200E+03, 0.10861100E+03, 0.42356100E+03, 0.10604000E+03, 0.51453900E+02, -.59911100E+01, 0.54652200E+02, -.36085700E+02, 0.13261700E+02, 0.12380400E+02, -.67037900E+01, 0.17836500E+02, 0.26102900E+02, 0.99396100E+02, -.80524300E+01, -.26415200E+02, -.21845400E+02, 0.16293400E+02, -.99724300E+02, -.34544300E+02, -.32500400E+02, -.33879600E+02, 0.70910300E+02, -.32612500E+02, -.24825800E+02, 0.24209600E+02, -.13074800E+02, -.17960000E+03, 0.11308500E+01, -.31605700E+02, 0.13336100E+02, -.46591100E+02, 0.64950100E+02, -.33818900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.29778400E+01, 0.44746500E+01, 0.14155800E+01, 0.20669500E+01, 0.89680200E+00, -.15482000E+01, 0.10201000E+01, 0.48412000E+01, -.20240900E+01, -.89027500E+00, -.13237400E+01, -.14100800E+01, -.95212700E+00, -.97232900E-01, 0.15420300E+01, -.23020700E+01, -.26717400E+01, 0.33757700E+01, 0.65881500E+00, 0.21147000E+01, -.14255700E+01, 0.18467900E+01, -.42518300E+01, 0.20301500E+00, 0.37399400E+00, 0.12469800E-01, 0.35503900E+00, -.30811300E-03, 0.19063600E+00, -.39961200E+00, -.49266700E+00, -.71189800E+00, 0.58198700E+00, 0.41249900E-01, 0.36394900E+00, 0.28580100E+00, -.22163000E-01, -.11053300E+01, -.55343000E+00, -.13164500E+00, 0.12465000E+01, 0.29664300E+00, -.22603200E+01, -.75445300E+00, -.23343600E-01, -.37481500E-01, -.11046400E+01, 0.86985100E-01, 0.23064100E+00, -.27726800E+00, 0.83919800E+00, 0.12701600E+00, -.48149200E+00, -.95496600E+00, 0.15769600E+01, -.72594500E+01, 0.49894800E+00, 0.49864700E-01, -.39451200E+00, 0.10936500E+01, 0.28988400E+01, -.28352700E+00, 0.19243800E+01, -.10112700E+01, -.29521800E+01, 0.28522200E+01, 0.35844600E+00, -.15606500E+00, 0.57466100E-01, -.34129400E-02, 0.28652800E+00, -.11728600E+01, -.23440100E+01, 0.40641200E+01, -.16255400E+01, -.98259900E+00, 0.59343500E+00, -.18844100E+00, 0.22244900E+00, -.26927900E+00, -.14257300E-02, 0.16583200E+01, -.21211100E+00, 0.29736900E+00, 0.21843000E+00, 0.13666000E+01, 0.21414600E+00, -.54317300E+01, 0.16364500E+00, 0.15842700E+00, 0.22251300E+01, 0.18025000E-01, 0.65288200E+00, -.49246600E+00, -.74300500E+00, 0.10715600E+01, -.20355300E+01, -.16854900E+01, -.88351800E+00, 0.83375300E-01, 0.18196100E+01, -.71920400E+00, 0.84497100E-01, 0.10546000E+00, -.50226100E+00, 0.90404100E+00, 0.35747000E+00, 0.28724900E+00, 0.38608500E+00, -.66324400E+00, -.19274500E+00, 0.21291400E+00, -.79654300E+00, 0.25082300E+00, 0.29768200E+00, 0.56353500E+01, 0.29339200E+00, 0.46011700E+00, 0.38091100E-01, -.12925800E+01, 0.23274600E+00, -.28326800E+00, 0.10086600E+01, -.57636100E-01, 0.91894000E-01, 0.93870700E+00, 0.63716200E+00, 0.19698000E+00, 0.19222500E+01, 0.56807000E+00, 0.15567800E+01, 0.27432500E+00, 0.45252200E+01, -.22747500E+00, 0.11704200E+00, 0.34969000E-02, 0.28695100E+01, 0.10437700E+01, 0.32754200E+00, -.13419700E+00, -.80108300E+00, 0.20000700E+01, -.12751200E+01, -.41080000E+00, 0.11812600E+00, 0.15539200E+01, -.72091100E-01, -.14340800E+01, -.10555200E+00, -.61533200E+00, 0.28823100E+00, -.15175800E+01, -.69840800E+00, -.22348000E+00, -.15265200E+00, -.29828300E+00, 0.99365700E+00, -.16648600E-01, -.53279700E+00, -.25625400E+00, -.58648200E-01, 0.69765700E+00, -.15982100E+01, 0.34692700E+00, 0.27807600E+03, 0.97670600E+03, -.48649300E+03, -.21907100E+03, -.48745500E+03, -.13560800E+03, -.10418500E+03, -.18919200E+03, 0.13656200E+03, -.33634100E+03, -.11543900E+03, -.49913300E+03, 0.10112900E+04, -.50766800E+03, 0.80703400E+01, -.49628700E+03, 0.15655600E+02, 0.21984700E+03, -.50176100E+03, -.65159500E+03, -.56600600E+03, 0.21723900E+03, -.48902500E+03, -.50160800E+03, 0.25102500E+03, 0.34901100E+03, 0.25853300E+03, 0.17269700E+03, 0.17267900E+03, -.34874300E+02, -.12035900E+03, -.11466700E+00, 0.19805700E+03, 0.21108900E+03, 0.21918400E+03, -.10810700E+03, -.30938100E+03, -.11335000E+03, 0.19004700E+02, -.54868900E+02, -.13782100E+02, 0.17881300E+03, -.21633500E+02, -.61303000E+02, 0.14388500E+02, 0.50235300E+03, -.25246900E+03, 0.13626200E+03, -.25101800E+03, -.73694500E+02, 0.94406100E+01, -.22741800E+03, -.54278300E+03, -.36977500E+03, 0.56016000E+02, -.36530800E+03, 0.64625600E+02, -.32043500E+02, -.89361900E+02, -.33223000E+02, -.31147400E+02, -.24297400E+03, 0.13226800E+03, 0.24008600E+03, 0.45663000E+02, -.19014800E+03, -.83961700E+02, -.13409900E+03, 0.73668800E+02, -.19819500E+03, 0.76031700E+02, 0.17136800E+03, -.72197400E+01, 0.14982400E+03, 0.22001200E+03, 0.84667100E+02, -.13803300E+02, 0.65745500E+02, 0.15504600E+02, -.39072900E+02, -.32757400E+02, 0.83788000E+01, -.63032900E+01, -.51705700E+01, 0.12573900E+02, 0.33560900E+02, 0.38864400E+00, 0.18136500E+01, -.43640100E+01, -.60786900E+01, 0.25848700E+02, -.60111900E+01, 0.39822800E+01, -.40934200E+01, 0.56811400E+02, 0.54460100E+01, 0.29523900E+02, 0.60515000E+01, -.38988700E+02, -.45627200E+02, 0.42788000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.89269100E+00, 0.38082600E+01, -.78627600E+00, 0.26694100E+01, -.81348800E-01, -.18570800E+01, 0.47986600E-01, 0.23373100E+01, 0.99561900E+01, 0.38225700E+00, -.10037100E+00, 0.67804700E+00, 0.34984800E-01, 0.36798100E+00, -.26228300E+00, -.12789400E+00, 0.10607400E+01, -.10223600E+01, 0.66706900E-01, -.32456500E+00, 0.22379800E+01, -.18536600E+00, -.16738400E+01, 0.27438400E+00, 0.47435600E-01, 0.23193100E-01, 0.98906600E+00, -.64020100E-01, 0.42640000E+00, 0.78961300E-01, -.39276000E+00, -.25581100E+00, 0.83156400E-01, 0.26347000E+00, 0.36979500E+00, 0.49552600E-01, -.97151900E-02, -.96537200E-01, 0.30018300E+00, -.75710100E-01, -.63089300E+00, 0.98495600E-01, -.82233100E+00, -.27809200E+00, -.66402700E-01, 0.43551000E-01, -.10920200E+00, -.10156000E+00, -.16286200E+00, 0.20068400E+00, -.32544200E+01, -.75973800E+00, 0.95200800E+00, -.27199100E-02, 0.63653100E+00, 0.27071700E+00, 0.89879400E+00, -.44923200E-01, -.36909100E+00, -.46124600E+01, 0.11590800E+01, 0.60951300E-02, 0.65236300E+00, -.45402100E+00, -.77633000E+00, 0.77707700E+00, -.27492100E+01, -.42774900E+00, -.70912400E-01, 0.16807200E-03, 0.40783300E+00, -.72899300E+00, 0.36389400E+01, 0.14881800E+01, 0.12927400E+01, -.76927700E-01, -.55497500E+00, 0.52867600E+00, -.24650700E-01, 0.24575100E+00, 0.31078900E-03, 0.55263500E+00, -.69798100E+00, 0.10656500E+01, -.84029000E+00, 0.48770000E+00, 0.30932600E-01, -.18583500E+01, 0.74002900E-01, 0.26259000E+00, -.24637300E+01, 0.62893600E-01, 0.20546000E+00, -.39566900E+00, -.23294400E+00, 0.12899000E+01, -.56066000E+00, -.77421800E-01, 0.52727000E+00, 0.13177100E+01, 0.16130100E+00, 0.37933600E+00, -.76772100E-01, 0.12333900E+01, -.13224100E+01, -.21220400E+00, -.25491400E+00, 0.36554100E+00, -.24455200E+00, -.21169800E+00, -.37452300E-01, -.56622600E-03, -.11655700E-02, 0.28606500E-03, 0.35154700E+00, 0.20116200E+01, 0.79548900E+00, 0.94977500E-01, 0.11147900E+00, -.49105700E+00, -.11240400E+00, 0.19692700E+00, -.10020100E+01, 0.88756800E-01, 0.42912100E-01, 0.16045700E-01, 0.20610200E+00, 0.59867300E-01, 0.24089700E+00, 0.61138400E+00, 0.67985100E+00, 0.37194900E+00, -.77678800E+00, -.70574300E-02, 0.22238700E+00, -.49653200E-01, -.19935000E+01, -.29380100E+00, -.81488800E-02, -.13010600E-01, 0.53196800E-01, 0.20578800E+00, 0.10067900E+01, 0.21750600E+00, -.86538100E-01, -.90172900E+00, -.27437300E-01, 0.61473100E+00, -.83660700E+00, 0.18026000E+01, -.13367900E+00, -.30452700E+00, -.50497300E+00, -.17342600E+00, 0.28591800E-01, 0.16069700E+00, 0.68330800E+00, -.38987700E-02, 0.22574300E+00, 0.15203800E+00, 0.22713400E-01, 0.35165000E+00, 0.15043500E+01, 0.64224200E-01, -.48806700E+00, 0.86986400E+03, -.44249900E+03, -.16235200E+03, -.43466800E+03, -.13431200E+03, -.69198300E+02, -.18854800E+03, 0.60928200E+02, -.34603600E+03, -.67688100E+02, -.11277000E+03, 0.49596200E+03, -.25107200E+03, 0.14429200E+03, -.24450000E+03, 0.94441300E+02, 0.31777200E+03, -.29270900E+03, -.36672000E+03, -.21516500E+03, 0.22826800E+03, -.32011600E+03, -.17507400E+03, 0.86748100E+02, 0.15912500E+03, 0.80011100E+02, 0.12777800E+03, 0.11357800E+03, -.29049800E+02, 0.20795600E+02, 0.10150500E+03, 0.93979900E+02, -.45628200E+02, 0.14108500E+03, -.68974400E+02, -.30135900E+03, -.72122700E+02, -.28426500E+02, -.96931700E+02, -.32761700E+02, 0.22285600E+02, -.11662100E+02, -.66512100E+02, 0.19782600E+02, 0.26342800E+03, -.13271300E+03, 0.57237900E+02, -.13164500E+03, -.47347200E+02, 0.32077000E+02, -.12821600E+03, -.37359600E+03, -.14035100E+03, 0.27281800E+01, -.35672700E+03, 0.17077000E+03, -.85191200E+02, -.11088600E+03, -.85635800E+02, 0.35674700E+02, -.18332100E+03, 0.71832200E+02, 0.11763800E+03, -.51444900E+02, -.13393000E+03, -.33308400E+03, -.47789500E+03, 0.24202700E+03, -.36014900E+02, 0.24498400E+03, 0.25938900E+03, -.37447100E+01, 0.22032500E+03, 0.13990600E+03, 0.14053100E+03, -.25643400E+01, 0.17054000E+02, 0.22607100E+02, -.79244300E+02, -.34862400E+02, 0.16231200E+02, 0.20443800E+02, 0.22110500E+02, 0.18303800E+02, 0.35394100E+02, 0.15654900E+02, 0.18747300E+02, 0.15672100E+02, -.34311800E+02, 0.33763800E+02, 0.21234900E+02, -.23872900E+02, 0.19797300E+02, 0.52904400E+02, -.33340400E+02, 0.48656700E+02, -.13639100E+02, 0.33420200E+02, -.61955900E+02, 0.84593100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18970600E+01, -.27721500E+01, -.17087500E+00, -.20790800E+01, -.45565600E+00, 0.13565200E+01, -.62343100E+00, -.24738000E+01, -.65619100E+01, -.14168300E+01, 0.13016500E+00, -.31209000E+00, 0.68119200E+00, -.51590000E-01, -.13456800E+01, 0.10158000E+01, 0.17287000E+01, -.27313800E+01, -.79495400E+00, -.19068300E+00, 0.73397300E+00, -.24834000E+00, 0.22397500E+00, -.21504200E-02, 0.49087900E+00, -.41753800E-01, 0.92922400E+00, -.93365300E-01, 0.23001600E+00, 0.62613500E+00, -.32306400E-01, 0.76685800E+00, -.10892700E+00, 0.28821800E+00, 0.54603300E+00, 0.14461600E+00, -.48699300E-02, -.21041600E+00, -.18006500E+00, 0.44043000E-02, -.13134600E+01, -.36163100E+00, -.23821600E+01, -.96979800E+00, -.17015400E+00, -.18295200E+00, -.57907500E+00, -.42409900E-02, -.72880400E+00, 0.18427100E+00, -.25547500E+01, -.20207400E-01, 0.18068600E+00, -.16756500E+00, 0.54320600E+00, -.12138500E+01, 0.49764700E+00, -.11897500E+00, -.69865100E+00, -.32043000E+01, 0.22985100E+00, 0.19076600E+00, 0.37732300E+00, -.25499200E-01, -.56915500E+00, -.13608100E-01, 0.39133000E-01, -.57554100E+00, -.37872900E+00, 0.17364800E-02, -.21356500E+00, -.95043200E+00, 0.26743600E+01, -.92427800E+00, 0.40394100E+00, 0.56953300E+00, -.49711200E+00, 0.23994900E+00, -.79254200E-01, 0.69793600E-01, -.20243600E-03, -.43140200E+00, -.23767000E+00, -.99001100E-01, -.82663400E-01, -.79538900E+00, -.16842600E+00, -.54049400E+00, 0.30427100E+00, -.17674000E-02, 0.16243000E+00, -.10498000E-01, -.61646800E-01, -.39924900E+00, -.14785900E+00, 0.52283400E+00, -.36375400E+00, -.45515900E+00, -.38721200E+00, -.12178500E+01, -.53308300E+00, -.34501300E-02, 0.45982700E-01, -.31958600E+00, 0.12398100E+00, -.91123300E-01, 0.56839700E-01, 0.61076500E-01, -.44160100E-01, -.12561800E+00, 0.15376900E-01, 0.73543700E-01, -.17719500E+00, 0.55620000E-01, 0.43077200E-01, -.25572900E+01, -.19134900E+00, 0.13750000E+00, 0.64477600E-01, -.37612700E+00, -.22728900E+00, -.94046300E-01, 0.81899200E+00, 0.33068300E+00, -.12756300E-01, -.56888700E+00, 0.11689200E+00, -.16869400E-01, 0.11467500E+00, 0.11208800E+00, 0.30470700E+00, 0.47350200E+00, 0.31756400E+01, 0.32519600E-01, -.16554400E+00, -.23142700E-01, -.34922300E+00, -.59577100E-01, 0.61304100E-01, -.12472000E+00, 0.27006500E+00, 0.66707000E+00, -.59111600E+00, -.10931100E+00, -.92948800E-01, -.16836000E+00, 0.29955000E-01, -.35450100E+00, 0.78265800E+00, -.14434200E+01, 0.15719000E+00, -.14217900E+01, -.11880300E+01, -.13050800E+00, -.35832400E+00, -.18202000E+00, 0.29919200E+00, 0.33960300E-01, 0.87313500E-02, -.38440400E+00, -.12991300E+00, 0.32688800E+00, -.71284300E+00, 0.82141200E-01, 0.95183700E-01, 0.70540900E-01, 0.19614700E+02, 0.51111900E+02, 0.10591300E+02, -.20570300E+02, 0.82206100E+01, 0.63433400E+01, -.18657000E+02, 0.23929600E+02, 0.23049500E+01, -.44108800E+02, 0.79671700E+02, -.40939900E+02, 0.11599500E+03, -.34159400E+02, 0.82572200E+02, 0.90613800E+02, -.64001000E+02, -.34664500E+02, -.12305800E+03, 0.89901300E+02, -.40332300E+02, -.28248700E+02, 0.12603700E+02, 0.72611400E+02, 0.19234800E+02, 0.32838300E+01, -.20963600E+02, -.86486800E+00, -.15692000E+02, -.28861900E+02, 0.90432500E+01, -.26412300E+02, -.10437500E+02, 0.60049600E+01, 0.24817400E+02, 0.30880900E+01, 0.21696100E+01, 0.16351500E+02, 0.63427700E+00, 0.17615000E+01, 0.12130400E+02, 0.10839400E+02, -.25743800E+02, 0.14173300E+03, -.73843900E+02, 0.17789600E+02, -.70783300E+02, 0.82911800E+02, 0.67591800E+02, -.58994100E+02, 0.24977800E+02, -.49608500E+02, 0.62495700E+02, -.13049900E+02, -.73024500E+02, 0.36857500E+02, 0.96977300E+01, 0.35877500E+02, 0.64321700E+01, -.98420200E+01, 0.13066700E+02, -.15238000E+02, -.41803200E+01, -.15313000E+02, 0.13222500E+03, -.84665100E+02, 0.40115600E+02, -.16390000E+02, 0.44454600E+02, 0.68167700E+01, 0.19756400E+02, -.99192300E+01, -.68799800E+02, -.65351500E+02, 0.58203400E+01, 0.67066100E+02, 0.65260600E+00, -.47438900E+01, -.53008200E+01, -.12264300E+00, -.38043500E+00, -.26121000E+00, 0.62457200E+00, 0.51026900E+01, 0.27895000E+01, 0.78578800E+00, 0.23817200E+01, 0.29943400E+00, -.32607400E+01, -.45026900E+00, 0.13932100E+00, 0.10354600E+01, 0.25990200E+02, 0.64423900E+01, -.15384400E+02, -.16460200E+01, 0.30670100E+01, -.57971500E+01, 0.11247300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.38464500E+00, 0.28529300E-01, -.79025000E-03, 0.99637100E-01, -.49584700E+00, -.41821500E+00, 0.16271300E-01, -.38917100E+00, -.64771100E+01, -.69401300E-01, 0.11028100E+00, -.89831400E-01, -.18586300E+00, 0.35218400E-01, 0.24709600E+00, -.14821600E-01, -.29814900E+00, 0.64990700E-01, 0.88216200E-01, 0.65094200E+00, 0.12219500E+00, -.59423700E-02, 0.66759100E+00, -.66926200E-01, -.87876200E-01, 0.58199400E-02, -.30636300E-01, 0.16603300E-01, 0.71413000E-01, 0.53146000E-01, 0.26116700E+00, 0.65336800E-01, -.10946800E+00, -.15069800E+00, -.10059700E+00, -.13278300E+00, 0.10950200E-02, 0.57678100E-01, 0.64826800E+00, 0.24288700E+00, 0.26737200E+00, 0.26745300E-01, 0.84433300E+00, 0.26720700E+00, -.79932100E-01, 0.10174500E-01, -.15419300E+00, 0.58623600E-02, -.25319500E+00, 0.19860000E+00, -.16965800E+00, 0.17063900E+00, -.44075100E+00, -.30718400E+00, -.55937700E-01, -.64279500E+00, 0.47654100E-01, 0.94371300E-02, -.13444900E+00, -.62272000E+00, 0.15874800E-01, -.10355700E+00, -.25040000E+00, -.10189400E-01, -.44305400E+00, 0.15616300E+00, 0.13532900E+01, 0.27614500E+00, 0.53217900E-01, -.75099100E-03, -.24143500E-01, -.18277400E+00, -.40799600E+00, 0.40360600E+00, -.23613000E+00, -.23340300E-01, -.17678400E-01, 0.20869500E+00, 0.30875200E-01, 0.13764000E-01, -.13734700E-02, 0.88599800E+00, -.62733600E-01, -.45914400E-01, 0.20705000E-01, 0.17489500E+00, 0.39052300E-01, -.42479000E+00, 0.13750800E+00, -.55568300E-01, 0.19476400E+00, -.18054300E-02, 0.14438600E-01, 0.45831400E-01, -.61285100E-01, -.88612900E-01, 0.89844400E-01, -.48140500E-02, -.40289800E-01, 0.26822100E-01, 0.21681800E+00, -.90716700E-01, 0.73843300E-02, 0.81181200E-01, -.26663800E-01, -.25561000E+00, -.12024900E+00, 0.60447200E-01, -.41857100E-01, -.41683900E-01, 0.84301300E-02, 0.12340500E+00, -.87000100E-01, 0.27450400E-01, 0.36363800E-01, -.21973800E+00, -.62404900E-01, 0.15935600E-01, -.20366300E-01, 0.10444500E+00, 0.28925200E-01, 0.10077900E+00, -.83992200E+00, -.15685100E+00, 0.25026600E-01, 0.14836100E+00, 0.88067300E-01, -.46186500E-02, 0.30280000E+00, 0.84393600E-01, 0.22279200E-01, 0.23356600E+00, 0.18188800E+00, 0.29368900E-01, -.62356400E-01, -.12407500E-01, -.79914900E-01, -.12406500E+00, -.11913300E+00, -.22029500E-01, -.58013400E-01, 0.56921000E-01, 0.23220900E-01, -.64348400E-01, 0.66933700E-01, 0.40278600E-01, -.22366500E-02, -.12818900E+00, -.30084800E+00, 0.59258000E+00, -.64838400E-02, 0.38149700E+00, 0.61060700E+00, -.96678900E-01, 0.92896200E-01, 0.14957100E-01, 0.71871800E-01, 0.34644100E-02, 0.14085500E+00, 0.49444700E-01, -.50631300E-01, -.36708800E+00, -.67904700E+00, 0.14797500E+00, -.31788600E-01, -.11725500E+00, 0.16681900E-01, 0.93234500E+02, -.27330100E-01, -.85396300E+01, 0.10027200E+02, -.31982000E+02, -.66282600E+02, -.20143200E+02, 0.23699100E+02, -.12528100E+03, 0.22111600E+03, -.11227700E+03, 0.46060500E+02, -.10919100E+03, -.11683900E+01, 0.10603700E+03, -.23285500E+03, -.28019800E+03, -.19379200E+03, 0.99238400E+02, -.15729500E+03, -.34210700E+02, 0.16905800E+02, 0.81247100E+02, 0.11012400E+02, 0.14877100E+02, 0.42749700E+02, -.73847500E+02, -.10396600E+03, -.55734000E+02, 0.29971400E+02, -.21901400E+01, -.48512600E+02, 0.24985800E+02, -.69113200E+02, 0.23732900E+02, 0.10201400E+02, -.22602400E+00, -.13992300E+01, 0.90107800E+01, 0.47730900E+02, 0.10499300E+02, 0.13081300E+02, 0.18136100E+03, -.90903000E+02, -.29276800E+02, -.90657700E+02, -.64528200E+02, 0.35252300E+02, -.12996800E+03, -.20807700E+03, -.12965100E+03, 0.23110800E+02, -.13120900E+03, -.84722100E+02, 0.42710800E+02, -.27895000E+02, 0.42218400E+02, -.34023400E+02, -.65951500E+01, 0.20047200E+02, -.44258500E+02, 0.68895800E+01, -.13585200E+02, -.14467300E+03, -.29284700E+03, 0.14744900E+03, 0.21537300E+02, 0.14355700E+03, 0.52638300E+02, 0.34267400E+02, 0.50914900E+02, -.87147600E+02, 0.27807100E+02, 0.17569300E+02, 0.50303100E+02, 0.76460100E+00, -.14110300E+02, -.10091800E+02, 0.12318800E+00, 0.26333400E+01, 0.32013900E+01, -.27236700E+00, 0.10447600E+02, 0.10318400E+02, 0.76278600E+01, 0.93461600E+01, 0.31015100E+01, 0.28093100E+01, 0.23617500E+01, -.24528400E+01, 0.97252000E+01, 0.19104400E+02, 0.33423700E+01, -.16191500E+02, -.33407000E+01, 0.42283700E+01, -.19427000E+02, 0.22075700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.92670700E+00, 0.13911300E+01, 0.92555600E-01, 0.12588200E+00, -.91027700E+00, -.79154400E+00, 0.16179700E+00, -.56445400E+00, -.16670400E+02, 0.54599800E+00, 0.91316600E-01, 0.31274800E+00, -.41169400E+00, 0.15272400E+00, 0.27600400E+00, -.10761700E+01, -.26278500E+00, -.49226200E+00, -.19157600E+00, 0.95405200E+00, -.12365600E+01, -.24376100E+00, 0.64590600E+00, -.27670900E+00, 0.96345400E-01, 0.11723800E+00, 0.15822000E+01, 0.37009700E+00, -.18062800E+00, 0.39742400E-01, 0.33962500E+00, 0.43004000E-01, 0.10420500E-01, -.21163400E+00, -.87188200E-01, -.71660900E-01, 0.62654400E-03, 0.31477800E+00, 0.66291400E-01, 0.37471800E+00, 0.45646600E+00, -.55566500E-01, 0.70831000E+00, -.24098200E-01, 0.22674200E-01, 0.37902400E-01, 0.24513600E+00, -.50484100E-01, 0.33898500E+00, 0.41075800E-01, 0.54845600E+00, 0.82747000E-01, -.31319500E-01, -.21840600E+00, -.25135200E+00, -.80902700E+00, -.85764900E-01, 0.15604100E+00, -.10335200E+00, 0.13637400E+01, -.95237100E+00, -.74210800E-01, 0.71935400E-01, -.45908000E-01, -.40667100E+00, 0.91209500E-01, 0.14192800E+01, 0.51340200E+00, 0.17159500E-01, 0.70795400E-03, -.10608500E+00, 0.11327900E-01, -.62507700E-01, -.65733800E+00, -.12838100E+00, 0.39240900E+00, -.80700800E-01, 0.12884400E+00, -.11123300E-01, 0.19990400E-01, -.27258000E-03, -.11440300E+00, 0.12083500E-01, 0.22144800E+00, -.27691000E+00, -.67636200E+00, -.39356300E-01, 0.13302200E+01, 0.12041100E+00, 0.13572800E+00, 0.50328100E+00, -.13914600E-01, -.13105700E+00, -.13053900E+00, 0.37380400E+00, -.20445500E+00, 0.16711400E+00, -.81759800E-03, -.14462700E+00, 0.10729200E+01, 0.71326100E+00, 0.11288800E+00, -.27034000E-01, 0.40829400E+00, -.46782700E+00, 0.84155800E-02, -.69481200E-01, -.25054700E-01, -.22078000E+00, -.12000400E+00, 0.97581600E-01, 0.22095300E+00, 0.13131100E+00, -.41361700E-01, -.56820800E-01, -.20908600E+01, -.58977300E+00, -.55506800E-02, -.51241600E-01, 0.45560400E+00, -.19958900E+00, 0.18510400E+00, -.11050100E+00, -.49900400E-01, -.13738400E-01, 0.26095200E+00, 0.42083300E+00, -.22441500E+00, -.67285100E-01, 0.33795900E-01, -.19316800E+00, -.10181400E+00, -.10415800E+01, 0.42149900E-01, -.71670400E-02, 0.19249000E-01, 0.35418200E-01, -.10233800E+00, -.69131600E-01, 0.16429800E-01, -.12910100E+00, -.13591000E+00, 0.38161600E-01, 0.21243800E-01, 0.82787900E-01, 0.21406300E+00, 0.17239800E-01, -.10102100E-01, -.30641400E+00, 0.73073800E+00, -.78138300E-01, 0.55621500E+00, 0.40530900E+00, 0.10007200E+00, 0.13865900E+00, 0.69401600E-01, -.14652000E+00, 0.73111700E-02, -.57885200E-01, 0.14786400E+00, 0.47912800E-01, -.75074300E-01, 0.24952300E+00, -.70638100E-01, -.54067300E-01, -.88420000E-01, -.26345400E+00, 0.29423200E+00, 0.33170900E+02, 0.26741400E+02, 0.35184800E+01, 0.88288600E+01, 0.30807900E+02, 0.45006900E+00, 0.17144000E+01, 0.23946800E+02, -.12666900E+02, 0.72610900E+01, -.35472300E+02, 0.10089600E+02, -.14204200E+02, -.12911600E+02, 0.24837700E+02, 0.20663400E+02, 0.21508900E+02, -.12847000E+02, 0.62414900E+02, -.16784000E+02, 0.89494300E+01, -.64133300E+01, 0.11915400E+02, 0.15380500E+01, 0.64217900E+01, 0.49384200E+01, -.90740300E+01, -.50069100E+00, 0.52899900E+01, 0.68741800E+01, 0.38089400E+02, -.19615100E+02, -.36852100E+00, -.20269300E+02, -.52205500E+01, -.53822400E+01, -.12818200E-01, 0.12143500E+02, -.63459500E+01, -.88301200E+01, -.21457700E+02, 0.16029300E+02, -.72078400E+01, -.23655000E+02, -.79717700E+01, -.22605200E+02, -.40519800E+01, 0.34397500E+01, 0.50674900E+01, 0.27546600E+01, -.18377300E+01, 0.44768700E+02, 0.47826700E+01, -.27476000E+01, 0.26450800E+01, -.29043200E+01, -.49761900E+01, -.62845000E+01, -.50406900E+01, 0.57857300E+01, 0.20223200E+01, 0.31223900E+01, 0.57685700E+02, 0.47804100E+02, -.23561900E+02, -.11039800E+02, -.14660000E+02, -.18822200E+02, -.20502100E+02, 0.83748400E+01, 0.58440800E+02, 0.23634000E+02, -.85369900E+01, 0.15205700E+01, -.14862300E+01, 0.22280200E+01, 0.26339900E+01, -.57244300E+00, 0.19914000E+00, -.31318500E-01, -.91817900E+00, -.26509000E+01, -.23471000E+01, -.16258900E+01, -.23580100E+01, 0.12388200E+01, -.72208600E+00, 0.20870300E+00, -.89889800E-01, -.26321300E+01, -.12176300E+02, 0.90484300E-01, 0.39695900E+01, 0.12434500E+01, -.27691000E+01, 0.56015900E+01, -.49267700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.28476400E+01, -.19545800E+01, 0.63758700E-01, 0.90308700E+00, 0.25567200E+00, -.37451900E+01, 0.94661900E+00, 0.30611200E+01, 0.21368800E+02, -.21267600E+01, -.93018800E-01, 0.13959000E+01, -.53673000E+00, 0.31053700E+00, 0.24719200E+01, 0.23568600E-01, 0.74758400E+00, 0.26133600E+01, 0.99532300E+00, 0.81470500E+00, 0.18795000E+01, -.32507500E+00, 0.31695000E+01, -.31561000E+00, -.17541000E+01, -.33577100E-01, -.12855300E+01, -.32405700E+00, 0.43319000E+00, 0.22273800E+00, 0.14644300E+01, -.20074600E+00, -.13873200E+00, 0.56042300E+00, 0.16629300E+01, -.28189500E+00, -.13217500E-02, -.39441900E+00, -.81779000E+00, 0.13243800E+01, -.16941300E+01, -.34119600E+00, -.49913900E+00, -.29616100E-01, -.55031600E+00, -.38997400E+00, 0.15765100E+01, -.25305100E+00, -.12917200E+01, 0.98472200E+00, -.18619300E+01, 0.11045900E+01, 0.14558800E+01, -.73825300E+00, 0.14823500E+01, 0.41993800E+01, 0.19349100E+01, -.10176300E+00, -.11682100E+01, 0.20214100E+01, -.21539600E+01, -.89764600E-01, -.65830400E+00, 0.44671600E+00, -.20974700E+01, 0.72349400E+00, 0.65037300E+01, -.66277800E+00, -.30098500E+00, -.41479500E-02, 0.66749800E+00, -.67442900E+00, 0.93915700E+00, 0.37576000E+01, 0.11194500E+01, -.17133800E+01, -.44344800E+00, -.70654400E+00, -.95310800E-01, -.97413600E-01, 0.42941900E-02, -.18778700E+01, 0.15011800E+01, -.84913300E+00, -.88844200E+00, -.49449700E+00, -.26132000E+00, -.16911000E+01, 0.33596600E+00, -.54859100E+00, -.69944000E+01, -.14549800E-01, 0.21542400E+00, 0.13091300E+01, -.44456700E+00, -.12580200E+01, -.11063600E+00, 0.55232900E-01, -.71304700E+00, -.17934200E+01, -.36175100E+00, -.49736900E+00, 0.41867800E-01, -.58335600E+00, -.43010400E+00, 0.13104500E+00, 0.19210200E+00, 0.52783800E-01, 0.38161600E+00, -.12512300E-01, 0.15731400E+00, 0.15621700E+00, 0.42471200E+00, -.13423200E+00, -.39544200E-01, -.23082000E+01, 0.25206800E-01, -.11550200E+00, 0.38279100E-01, 0.19875600E+00, -.48409500E+00, 0.33530900E+00, -.19751000E+01, -.60869300E-02, 0.37224500E-01, -.55525600E+00, -.40711100E+00, 0.45701900E-01, 0.61908200E+00, 0.15407300E+00, -.12198400E+00, -.40340500E+00, -.13326100E+01, 0.17825800E+00, 0.30413900E+00, -.71807700E-01, -.19412300E+00, -.29765700E+00, -.10109800E+00, -.68028400E-01, -.10248400E+01, -.45424900E+00, -.14347600E+01, -.17178700E+00, -.12506400E+00, 0.63440800E+00, -.69858100E-01, 0.20874400E+00, -.22441800E+01, 0.18939500E+01, 0.19803700E+00, 0.16660700E+01, -.12491400E+01, 0.58876700E+00, 0.47961100E-01, 0.19844600E+00, -.35704800E+00, -.20815800E-01, 0.23224100E+00, 0.89977200E-01, -.63150300E-01, 0.11066200E+01, 0.11064400E-01, 0.22135400E+00, -.23852300E+00, -.12135500E+00, 0.29708000E+00, 0.21306200E+01, -.10612900E+00, 0.16423700E+03, -.67020000E+02, 0.44091800E+01, -.48624000E+02, -.21392900E+03, -.31729500E+01, -.66231100E+02, 0.61633400E+03, -.31171800E+03, 0.24111200E+00, -.31562700E+03, -.13808500E+03, 0.35426900E+00, -.12507400E+03, 0.84551500E+02, -.31114700E+02, -.66689000E+02, 0.12941700E+03, 0.33599400E+02, -.15736900E+02, 0.84732700E+02, -.15847000E+02, 0.26803500E+02, 0.14385800E+03, -.64540000E+02, 0.29323700E+01, -.15963400E+02, 0.11631900E+03, 0.39425100E+02, 0.24189300E+03, -.12234600E+03, -.16457900E+02, -.11828500E+03, -.28745800E+02, 0.45137700E+02, -.27987400E+02, 0.33373400E+02, -.17667200E+03, 0.47776500E+02, -.25541000E+02, 0.30195900E+03, -.14973300E+03, 0.14849800E+03, -.15107800E+03, -.23159900E+03, 0.22808000E+03, -.12786200E+03, 0.54719600E+02, -.18031500E+02, 0.96659600E+02, 0.20780200E+03, 0.46279200E+03, -.23238900E+03, -.16018700E+03, -.23048900E+03, -.71087500E+02, -.84203400E+02, -.70343700E+02, -.91404900E+01, -.16917000E+03, -.20948400E+02, -.20370500E+03, 0.73498800E+03, -.37114900E+03, -.18358900E+03, -.35522500E+03, -.26634100E+02, -.10105900E+03, -.57426800E+01, 0.40426800E+03, 0.38415800E+02, -.53772500E+02, -.36814500E+03, -.10713500E+02, 0.12664800E+02, 0.13150400E+02, -.33037100E+00, 0.85237900E+01, 0.47655700E+01, -.61040200E+01, -.13654400E+02, -.18152600E+02, -.14822300E+02, -.20783100E+02, -.41863400E+02, 0.68360000E+01, 0.78524600E+01, -.65481100E+01, -.22444100E+02, -.23505800E+03, 0.17082800E+02, 0.30184700E+02, 0.63669900E+01, 0.45211500E+01, 0.69685900E+01, -.34608500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23903000E+01, -.75198400E+00, -.36728900E+00, -.31566600E+00, 0.23452200E+00, -.40735400E+00, -.32382600E+00, 0.96429700E+00, 0.25759700E+01, -.12548300E+01, 0.66863500E-01, 0.10847300E+01, 0.90947900E+00, -.23617300E+00, -.10390100E+00, 0.28273000E+01, 0.40447900E+01, -.98822100E+00, -.29968000E+00, -.10215600E+01, 0.12821100E-01, -.10717900E+01, 0.49418800E+01, -.38596100E-01, -.81668400E+00, 0.22629700E-01, -.86515100E+00, -.14843400E+00, 0.35282200E+00, 0.34236500E+00, 0.11800200E+01, 0.65158300E+00, -.75377000E-01, -.17424600E+00, -.30896300E+00, -.12330600E+00, -.58852300E-03, -.17960600E+00, 0.18744900E+00, 0.85617100E-01, 0.35831900E+00, -.10112300E+00, -.32008500E-01, -.16242900E+00, -.19090200E-01, -.77120800E-01, 0.54100600E+00, -.25722200E-01, -.28539200E+00, 0.99282300E-01, 0.68585200E+00, 0.28447000E-01, 0.64126900E+00, 0.95193600E+00, 0.12942300E+00, 0.19600600E+01, -.31472000E-01, -.11356800E+00, 0.14932100E+00, 0.42664800E+00, -.76243900E+00, 0.46688400E-01, -.39533600E+00, 0.21368200E+00, 0.15751500E+01, -.13396300E+01, -.40028200E+01, -.25895500E+00, -.64714200E-01, -.64979400E-05, -.99737400E-01, 0.13091700E+01, -.47663300E-01, 0.50803600E+00, 0.40352600E+00, -.81264500E+00, -.40445100E-01, -.27431100E+00, -.29757100E+00, 0.62232500E-01, 0.14535100E-02, -.13205300E+01, 0.33311800E+00, -.85970400E-01, 0.95537800E-01, 0.29919400E+00, -.70629400E-01, 0.10534700E+01, -.21900700E+00, -.14601700E+00, 0.24816000E-01, -.94180300E-02, -.16587000E+00, 0.33578900E+00, 0.38190800E-01, -.68407700E-01, -.24078100E+00, 0.91938200E+00, 0.12208900E+01, 0.17779300E+00, -.25331000E+00, 0.49464100E+00, -.61713100E-01, 0.50233200E+00, -.19841400E+00, 0.62208800E+00, -.56466800E-01, 0.16952300E+00, 0.20849300E-02, -.82716300E-01, 0.14459100E+00, -.96681900E-01, 0.38586600E+00, -.12294200E+00, 0.19297900E+00, -.30219800E+01, -.92387800E-01, -.26578100E-01, 0.23481300E-01, -.37807500E+00, -.63046000E+00, 0.12772700E+00, 0.12485500E+01, 0.64035300E+00, -.99751200E-02, -.46642200E+00, 0.41214800E+00, 0.59249300E-01, 0.12179900E+00, -.51345600E+00, -.34494100E+00, 0.12119300E+01, -.65053500E+00, 0.11049600E+00, -.52040100E-01, -.17579000E-01, -.59729500E+00, 0.22887100E+00, 0.10899300E+00, -.20482000E+00, 0.29830400E+00, 0.73588300E-01, 0.96587300E+00, -.44754100E+00, 0.45401000E-02, -.91217400E-01, 0.28525400E-01, -.18557900E+00, -.32056500E+00, -.11864800E+01, 0.11280500E+00, -.97660000E+00, -.10122600E+01, -.36256300E-01, -.33598000E+00, -.23836700E+00, -.61523800E-01, 0.16433000E-01, -.60972000E-01, -.22567400E+00, 0.17525500E-01, 0.38875400E+00, -.61738800E+00, 0.44539700E-01, -.43299500E-01, -.15950900E+00, 0.10767600E+00, -.10175200E+01, -.26397000E-01, -.13418300E+00, -.76099900E+02, 0.45881000E+02, 0.38583300E+02, -.18459700E+02, -.43405800E+02, -.11505800E+03, 0.27615200E+03, -.13744300E+03, 0.15011900E+03, -.13506700E+03, 0.46903300E+02, 0.22469300E+03, -.26551900E+03, -.31122700E+03, -.13651800E+03, 0.15534500E+03, -.84278400E+02, -.19891500E+03, 0.99595300E+02, 0.19499300E+03, 0.99781600E+02, 0.86368500E+02, 0.16482100E+03, -.14781100E+03, -.25585700E+03, -.69193700E+02, 0.14592300E+03, 0.33579700E+02, 0.26173700E+02, -.11322100E+02, -.14353000E+03, -.14363000E+02, 0.30785100E+02, 0.59689500E+02, -.63158100E+02, -.77194800E+01, -.22924800E+02, 0.58810200E+02, -.76892500E+01, 0.42099200E+03, -.21097300E+03, -.28462200E+02, -.21044300E+03, -.73874600E+02, 0.14835900E+03, -.14887100E+03, -.13490700E+03, -.10938200E+03, 0.70771000E+02, -.17394400E+03, -.30208200E+02, 0.15401200E+02, 0.14103200E+02, 0.14839700E+02, -.70771500E+02, -.97184800E+02, -.11660100E+01, -.15551100E+03, -.13283500E+02, -.44020600E+02, -.21831500E+03, -.21534000E+03, 0.10716900E+03, 0.31699400E+02, 0.10806500E+03, 0.29548000E+02, -.99201300E+01, 0.48628000E+02, -.81475800E+02, 0.93560100E+02, 0.12048400E+01, -.63157500E+02, 0.20954800E+01, -.31373100E+02, -.18316900E+02, 0.29814600E+01, 0.14941600E+01, 0.53760600E+00, 0.16381100E+01, 0.18476700E+02, 0.12596100E+02, 0.66432600E+01, 0.95849500E+01, -.16235800E+02, 0.11662000E+02, 0.12415200E+01, -.12081900E+01, 0.68735100E+01, -.12153900E+03, -.41154500E+01, 0.64886400E+01, -.16135700E+01, 0.22857800E+02, -.20290700E+02, 0.32353100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22253800E+01, 0.45033700E+01, -.58760500E+00, 0.36682200E+01, 0.12363800E+01, -.15689800E+01, 0.15337300E+01, 0.37884800E+00, -.54720100E+01, 0.24419700E+01, -.47696400E-01, -.17699800E+01, -.10233400E+01, -.13214100E+00, 0.16763000E+01, -.14262800E+01, -.71925800E+01, -.19072200E+01, 0.71585100E+00, 0.17563100E+01, 0.65319200E+00, 0.54714700E+00, -.27614000E+01, -.34877800E+00, -.16353800E+01, -.37258200E-02, -.32086400E+01, -.33236200E+00, 0.64739900E+00, 0.18021900E+00, 0.13493600E+01, -.13382900E+01, -.86417400E-01, -.50056800E-01, 0.12354600E+01, 0.22217400E-02, -.66585100E-02, 0.11210900E+00, -.14162400E+01, 0.19747300E+01, -.11048400E+00, -.60837300E+00, -.16730400E+00, -.37787700E+00, -.56010700E-01, -.55679000E-01, 0.11693600E+01, -.23979200E+00, -.14004500E+01, 0.50423800E+00, -.46488500E+01, -.49002600E+00, 0.13445000E+00, -.62907000E+00, 0.95324700E+00, 0.23964500E+01, 0.22756200E+01, 0.20706500E+00, -.89604600E+00, 0.52014100E+01, -.15564600E+01, -.16722400E+00, 0.11558100E+00, -.38519400E+00, -.15357800E+01, 0.81882500E+00, 0.56697300E+01, 0.14198100E-01, 0.56417700E-01, -.38944900E-02, 0.41379700E+00, 0.64483600E+00, 0.29590900E+01, -.58859200E+00, -.24380700E+00, 0.62043900E+00, -.12067800E+01, 0.16156700E+01, -.11279100E+00, -.74820700E-02, -.15656600E-02, 0.14324700E+01, -.65849300E+00, -.10294500E+01, -.12869000E+01, 0.16323000E+01, 0.11189400E+00, -.86023400E+00, -.52072100E-01, -.20332300E-01, -.10833700E+01, 0.31607600E-01, -.82541000E-02, 0.80938300E+00, 0.13026500E+00, -.71061200E+00, -.25056900E+01, 0.10414000E+01, 0.11667900E+01, -.21331400E+01, -.39917900E+01, 0.16303200E+00, -.38932900E-01, 0.22749400E+00, -.98791600E+00, 0.70632200E+00, -.51333500E-01, 0.97312700E+00, -.40342600E+00, 0.21208400E+00, -.24714700E+00, -.59964200E+00, 0.76977600E+00, -.24210600E+00, -.16698300E-01, 0.46093800E+01, 0.10044500E+01, -.39952300E+00, 0.72944500E-01, 0.26254800E+00, 0.34344000E+00, 0.26378600E+00, 0.11756300E+01, 0.36246100E+00, -.54334900E-01, 0.77785900E+00, 0.74404100E+00, 0.23105900E+00, -.49169000E+00, -.75016300E+00, -.10330500E+00, 0.11350300E+00, -.42297000E+01, -.30966900E-01, 0.71699600E+00, -.43907600E-01, -.16021200E+00, 0.49218900E+00, 0.24648300E+00, -.11012500E+00, 0.36806900E+00, 0.14307600E+01, 0.10455100E+01, -.55419400E+00, 0.12883500E+00, 0.21259900E+00, -.25771400E-01, -.41519600E+00, -.18835000E+01, 0.16774700E+01, -.27756700E-01, -.46247600E+00, 0.14020200E-01, 0.26592900E+00, -.35224800E+00, -.36837200E+00, -.15444900E+00, -.51925000E-01, -.39144800E-01, 0.83388100E-01, -.76226200E-01, 0.10945000E+01, 0.27176900E+01, -.10919500E+00, -.41772800E+00, 0.58843700E+00, -.34403800E+00, 0.79487800E+00, 0.90490000E-01, 0.43042500E+00, 0.65493800E+00, 0.88635700E+02, 0.23045400E+03, 0.11113800E+03, -.42450300E+02, 0.36218500E+03, -.16212100E+03, 0.87414600E+02, 0.12032600E+03, 0.76292000E+02, 0.10933700E+03, -.95590000E+01, -.24464500E+02, -.58641200E+02, -.54910300E+02, -.12676900E+02, 0.84187500E+02, -.57538500E+02, 0.27628400E+02, 0.10778200E+03, 0.35860800E+02, -.75620800E+02, -.12447400E+03, 0.10422400E+01, -.86412000E+02, 0.55009800E+01, -.10542500E+03, -.10272400E+02, -.55313000E+01, 0.41851800E+01, 0.32296000E+02, 0.47657600E+01, 0.33825100E+02, 0.34159700E+01, -.11792200E+02, -.31801600E+02, 0.11305400E+03, 0.11752100E+01, -.30410700E+02, 0.38431600E+03, -.19367000E+03, -.10999500E+03, -.19225000E+03, 0.15087200E+03, 0.73565300E+02, -.18549000E+03, -.63774900E+02, -.13386800E+03, 0.56643800E+02, -.16449300E+03, -.41213500E+03, 0.20681500E+03, 0.17419500E+03, 0.20647200E+03, -.14315000E+02, -.24339900E+02, 0.98197600E+02, -.10860900E+03, 0.15290700E+03, -.19441600E+02, 0.24905700E+03, -.57325000E+03, 0.28642800E+03, 0.13612400E+03, 0.28313400E+03, -.70679100E+02, -.49588100E+02, 0.72208800E+02, -.36408600E+03, 0.80755700E+02, -.81578000E+01, 0.13223300E+03, -.17981900E+01, -.22876900E+02, -.29006500E+01, 0.31639200E+00, -.97445800E+00, -.11845100E+00, -.12253900E+00, 0.31017800E+01, -.22319400E+01, -.10671400E+02, -.51290900E+01, 0.71090200E+02, -.36934900E+02, -.25082200E+00, 0.27020000E+00, -.82911900E+01, -.30069600E+02, 0.32373700E+02, -.41711800E+02, -.77423800E+01, -.17464800E+02, 0.20473300E+02, 0.34231100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30444700E+01, -.12925500E+01, 0.97725300E+00, -.38735400E+00, -.86804500E+00, -.33778100E+01, 0.77162100E+00, -.18496300E+00, -.34259100E+02, -.20322900E+01, 0.22425500E+00, -.77030300E+00, -.86616400E+00, 0.34917500E+00, 0.26885000E+00, -.13713900E+01, -.32143100E+01, 0.16862100E+01, 0.62028100E+00, 0.39667100E+01, -.10108400E+01, -.54693800E+00, 0.27107100E+01, -.14675400E+01, -.37523400E+00, -.69186500E-01, 0.61823400E+00, 0.18645500E+00, 0.12355900E+00, 0.79129700E-01, 0.12177100E+01, -.32068300E-01, 0.25860900E+00, -.10821200E+01, 0.77845300E+00, -.32815600E+00, -.18733600E-02, -.51110700E+00, 0.27415400E+00, 0.20545300E+01, 0.14530700E+00, 0.19933100E+00, 0.23752900E+01, 0.15044000E+01, -.51576700E+00, 0.90189500E+00, -.48021500E+00, -.11550500E+00, 0.56115500E+00, 0.74004600E+00, -.16019200E+01, -.59540200E+00, -.18073000E+00, 0.10413000E+00, 0.47719900E+00, -.10136100E+01, 0.18242700E+01, -.20777700E+00, 0.84254900E-01, 0.56066000E+00, 0.64465100E+00, -.30969900E-01, 0.15764200E+01, -.36586800E+00, -.59093300E+00, 0.89022800E+00, 0.15246100E+01, -.90240200E+00, -.18371400E+00, -.54187100E-02, 0.36556400E+00, -.50862200E+00, 0.12831200E+01, -.54368300E+00, 0.21206600E+00, 0.14617600E-01, 0.92065000E+00, 0.72071800E-01, -.55611600E-01, -.90325100E-01, -.36720700E-02, 0.73993700E+00, -.34749700E+00, 0.29874700E+00, -.24454800E+01, -.20318000E+00, 0.57845200E-01, -.27561000E+01, 0.27817900E+00, -.10223300E-01, -.10710200E+01, -.24587000E-01, 0.24800400E+00, -.24732500E-01, 0.79333600E-01, -.16127200E-01, -.33274500E+00, 0.11673900E+00, 0.19747700E+00, 0.21003200E-01, -.40671000E+00, -.11831500E+00, 0.10617700E+00, -.91076600E+00, -.28368200E+00, 0.47265700E+00, 0.62729300E-01, -.17797000E+00, 0.24547900E+00, 0.24721800E+00, 0.90759600E-01, 0.27337000E+00, 0.18414700E-01, -.68934700E-02, -.94808900E-01, 0.25483000E+01, 0.54941800E+00, -.58850400E-01, 0.92016100E-01, -.27223200E+00, 0.72630500E-01, -.24833700E+00, 0.12213400E+01, 0.36266600E+00, 0.37254400E-01, -.69740900E-01, -.29347200E+00, 0.23860200E+00, 0.63994000E+00, -.49545200E-01, 0.19027900E+00, 0.71160500E+00, -.25479000E+00, -.26648200E+00, -.15420900E+00, 0.27651700E-01, 0.14899800E+01, 0.61406600E+00, -.90866900E-01, 0.17018300E+00, -.70196900E+00, -.58998400E+00, 0.39027200E+00, -.99172600E+00, -.39482900E+00, -.18490900E+01, -.45114600E-01, 0.12125100E+01, 0.15440400E+01, -.21747200E+01, -.17199200E-01, -.66282500E+00, -.23668200E+01, -.54316900E+00, -.57226300E-01, -.12315400E+00, 0.10717600E+01, -.65465900E-02, 0.44915500E+00, -.50312400E-01, -.42977800E+00, 0.10907600E+01, -.10110800E+01, 0.44750700E-01, -.95386200E+00, 0.17021500E+01, -.41765400E+00, 0.16627300E+01, 0.12738800E+00, 0.25282700E+00, -.38116300E+00, 0.90666200E+00, -.13782400E+03, -.41825200E+02, 0.10138800E+02, -.34079500E+02, -.30507900E+03, 0.15578400E+03, -.20459600E+03, 0.15874400E+03, -.20645100E+03, -.26645300E+03, 0.39422800E+03, 0.28808400E+03, 0.15676300E+03, -.22953300E+03, -.22919100E+03, 0.76624900E+02, -.35777900E+02, -.26837100E+03, -.30614700E+02, 0.17403500E+02, -.15063200E+03, 0.59134700E+02, 0.10067000E+03, -.60770600E+02, -.10574100E+03, -.28645000E+02, -.41301100E+03, 0.20722500E+03, 0.23188100E+03, 0.20353200E+03, 0.13503900E+03, 0.14971300E+03, -.50336000E+02, -.13131400E+03, 0.30153500E+02, 0.18519900E+03, 0.14023200E+03, -.43487500E+03, 0.21376600E+03, 0.10551100E+03, 0.21757000E+03, -.28200200E+02, -.27747100E+02, 0.14623200E+03, 0.12849600E+03, 0.18988500E+03, -.24878900E+02, -.22402900E+03, 0.18877600E+02, -.12819200E+02, -.93436000E+02, -.98114600E+01, 0.16062200E+03, 0.70910800E+02, -.36512100E+02, -.17635100E+02, -.15399600E+03, 0.43071700E+02, -.90751100E+02, 0.24290500E+03, -.11900900E+03, -.65491100E+02, -.12810700E+03, 0.91120500E+02, 0.11256200E+03, -.82236600E+02, 0.15449400E+03, -.24361800E+03, 0.47990600E+02, -.56136100E+02, -.49599700E+01, 0.47089600E+02, 0.24234300E+02, -.57870200E+01, -.53928900E+02, -.54776400E+02, -.55949900E+01, -.24217600E+02, -.89635500E+01, -.60676200E+01, -.94139600E+01, -.24051200E+01, -.16859300E+02, -.53859900E+02, 0.54377500E+02, -.77234500E+01, 0.23765100E+02, 0.67316300E+00, -.41528300E+02, 0.15094200E+02, -.88634100E+01, 0.10316700E+01, -.42901800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.47001600E+00, 0.14868200E+01, -.35242500E+00, 0.11768000E+01, 0.40289200E-01, -.73099700E+00, 0.58194100E-01, 0.14736300E+01, 0.89125800E+01, -.14174100E+00, -.59242600E-01, 0.36099900E+00, 0.27434600E+00, 0.81712000E-01, -.76858200E-03, 0.60859000E-01, 0.59981600E+00, -.43020900E+00, 0.24155600E-01, -.33258300E+00, 0.12185400E+01, -.96026800E-02, -.91565100E+00, 0.79565600E-01, 0.26539200E+00, -.55640800E-02, 0.12970400E+00, -.10194400E+00, 0.25748900E+00, 0.19724900E+00, -.16484800E+00, -.34259100E+00, 0.17276600E-01, 0.34342100E+00, 0.64651500E+00, 0.84915600E-01, -.53102000E-02, -.48838900E-01, -.16950500E+00, 0.22004000E+00, -.18753100E+00, -.17885700E+00, -.61366200E+00, -.57310200E+00, -.14305700E-01, -.66465000E-01, 0.33157200E-01, -.16748300E-01, -.40468700E+00, 0.38577100E-01, -.88412000E+00, -.21405900E+00, 0.35106500E+00, -.98518800E-01, 0.17845300E+00, -.14945600E+01, -.54966700E+00, 0.33347200E-01, -.40630100E+00, -.18233800E+01, 0.60649900E-02, 0.11412100E+00, -.18527400E+00, 0.19836500E+00, -.25775700E+00, 0.73261100E+00, -.29328000E+00, -.24855000E+00, -.16011400E+00, 0.12367800E-02, -.14216700E+00, -.20341500E+00, 0.87429600E+00, -.11249400E+00, 0.22265200E+00, 0.13824700E+00, -.47179000E+00, -.12350700E+00, -.13454100E+00, 0.27827500E-02, 0.17144700E-02, -.12447100E+01, 0.13151200E+00, 0.44021000E-01, 0.56915800E+00, -.43708300E-02, -.68317600E-01, 0.11314300E+01, -.23884800E+00, 0.23920100E-01, -.13325500E+01, -.50522600E-02, 0.17575500E-02, -.16373600E+00, -.24581200E-01, 0.18048400E+00, -.40352500E+00, -.23011700E-01, 0.68309100E+00, 0.92953400E+00, 0.83732800E+00, 0.44778900E-01, -.23426300E-01, 0.36401600E-01, 0.42180800E+00, 0.50807800E+00, 0.27152700E-01, -.12352400E+00, 0.37420100E-01, -.11191700E-01, -.26620800E-01, 0.43657400E-02, -.11899500E+00, 0.37804800E-01, 0.25745600E-01, 0.11855500E+01, 0.75285700E-01, 0.72218400E-01, 0.13249700E-01, -.35996400E-02, 0.49445300E-01, -.14601600E-01, -.52792300E-01, -.32874200E-01, 0.65918500E-02, 0.38932900E-01, -.15892500E+00, 0.18820100E+00, 0.40755200E+00, 0.52899800E+00, 0.23437700E+00, 0.41190000E+00, 0.11937900E+01, 0.53546300E-01, -.20994500E+00, -.32913300E-01, -.76106400E-02, -.14478300E+00, -.14046300E+00, -.45395900E-01, -.40008900E+00, 0.75810300E+00, -.58343500E+00, 0.33395200E+00, 0.46736100E-01, 0.18671800E+00, -.50692600E-02, -.25827600E+00, 0.62289200E+00, -.15387400E+01, -.18598500E-01, 0.25203900E+00, -.52452300E+00, -.11858300E+00, -.51336100E-01, -.53600800E-02, 0.12381200E+00, 0.17650300E-02, 0.41275700E-01, -.11884200E+00, -.74302600E-01, -.33044400E+00, 0.98070500E-01, 0.53013200E-01, -.12226800E+00, 0.34798700E+00, 0.21013500E+00, 0.26623300E+00, -.61165800E-01, 0.38476800E-01, 0.22014000E-01, 0.16545800E-01, 0.85489000E-01, -.50604400E+02, -.18033600E+01, -.27983000E+02, -.12418100E+03, 0.62274900E+02, 0.25564100E+02, 0.62408500E+02, -.22921300E+02, -.86823800E+02, 0.50716000E+02, 0.67309500E+02, 0.71577600E+02, -.76820600E+02, 0.37583300E+02, 0.53468100E+02, -.26631900E+02, -.32862200E+01, -.28101000E+02, -.66626800E+01, -.23796500E+01, -.78516400E+01, 0.48334200E+02, 0.74509400E+01, -.91546700E+01, -.90870700E+01, -.21287400E+02, 0.10024700E+02, 0.65340800E+02, 0.10590500E+02, 0.13551200E+02, 0.24175800E+02, -.97388100E+00, -.71248500E+01, -.39131000E+02, 0.17147800E+02, -.20441800E+02, -.17937400E+03, 0.89869900E+02, 0.73467900E+02, 0.89691600E+02, 0.35586800E+02, -.38610400E+00, 0.40678000E+02, 0.63064500E+02, 0.81371300E+02, -.94266200E+01, 0.66064500E+02, -.23362400E+02, 0.11572800E+02, -.79597900E+01, 0.11624000E+02, 0.27043100E+02, 0.97703100E+01, 0.62120900E+01, 0.25226900E+02, 0.41352000E+02, 0.83807000E+01, 0.34985100E+01, 0.20735700E+03, -.10395300E+03, -.86853700E+02, -.10739300E+03, -.33632300E+02, -.25774000E+02, -.19961200E+02, 0.69542000E+02, 0.34438000E+02, -.17105200E+02, -.68996300E+02, -.18588500E+01, 0.14184700E+02, 0.46089400E+01, -.30721400E+00, -.76099100E+01, -.77767700E+01, -.14961100E+01, -.47407400E+01, -.65370000E+01, -.62282900E+01, -.71445500E+01, -.23957000E+01, -.47028300E+01, -.72928700E+01, 0.74723100E+01, -.77592400E+01, -.13546100E+02, 0.76556500E+01, -.33589800E+01, 0.27074600E+01, 0.52075500E+00, 0.10996900E+02, -.19323700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29776900E+01, -.26092300E+01, -.86442100E+00, -.24841600E+01, -.26660200E+01, 0.21857900E+01, -.11376900E+01, -.45786800E+01, -.51498600E+01, 0.26375100E-01, 0.16567800E+01, 0.13822500E+01, 0.42896700E+00, 0.30469400E-02, -.10106500E+01, 0.85556000E+00, 0.16909900E+01, -.26535600E+01, -.39014200E+00, -.26950400E+00, 0.11475000E+01, -.47560200E+00, -.65960200E-01, -.10243400E+01, -.52257300E+00, -.14732500E-01, 0.29243700E+00, 0.15827700E-01, 0.62541800E-01, 0.34757200E+00, 0.14023400E+00, 0.86010700E-01, -.20978500E+00, 0.97169600E-01, 0.18055100E+00, 0.18159200E-01, 0.68007100E-02, 0.19457700E+00, 0.71205700E-01, -.95659100E-01, 0.39495900E+00, -.20894800E+00, -.96134400E+00, -.32636100E+00, -.70933600E-01, 0.63314100E-02, -.94579700E+00, 0.12448200E-01, 0.38348300E+00, -.24421200E+00, 0.13167600E+01, -.23403800E+00, -.42490100E+00, 0.45154300E+00, 0.31302500E+00, -.16829900E+01, -.14257600E+01, -.51870800E+00, -.22192000E+00, -.22143200E+01, 0.10503000E+01, -.58611000E-01, -.85796400E-01, 0.50100900E+00, 0.54861400E+00, 0.15582000E+01, -.70114000E+01, -.12597800E+01, -.12462900E-01, -.32450900E-02, 0.33388200E+00, 0.18694000E+01, -.32205500E+01, 0.39476700E+01, -.17876400E+01, -.14892000E+01, 0.70974700E+00, -.37094400E+00, 0.43598500E-01, -.19306500E+00, -.17317500E-03, 0.14419900E+01, 0.66779400E-01, 0.45528300E+00, -.42699900E-01, 0.15001800E+01, 0.24204100E+00, -.22042600E+01, -.83917000E-01, 0.75792500E-01, -.11960600E+00, 0.37366500E-01, 0.38587600E+00, -.21657200E+00, -.17766400E+00, 0.43093300E+00, -.13280400E+00, -.42549100E-01, -.92462600E+00, -.51527000E-01, -.23876200E+00, -.65091500E-01, 0.22111300E-01, 0.17725300E+00, -.62798200E+00, 0.81612200E+00, 0.50900200E+00, 0.41380000E+00, 0.30100500E-01, -.11323300E+00, -.23484100E+00, -.47117700E+00, 0.23474200E-01, -.71043900E-02, -.17450900E-01, 0.49201300E+01, 0.15971400E+00, -.61636100E-01, 0.20212200E-01, -.16814600E+01, 0.29095700E+00, 0.19503400E+00, 0.15404900E+00, -.11086200E+00, 0.33870100E-01, 0.67405600E+00, 0.46948300E+00, -.26769900E-01, -.58358900E+00, 0.12598300E+01, 0.84487100E+00, -.12271200E+01, -.17236200E+01, 0.12873500E-01, 0.80438500E+00, -.62157400E-01, -.48674400E+00, -.11948300E+00, 0.50870900E+00, -.11202900E+00, -.14409600E+01, -.14182100E+00, -.10146600E+01, 0.67115700E-01, 0.23209300E+00, 0.84765600E+00, -.91282600E-01, -.12635700E+01, -.26597300E+01, 0.38323300E+01, -.10681700E-01, 0.50292700E+00, 0.37584400E+01, 0.22399400E+00, 0.33341100E+00, 0.14479900E-01, -.58557400E+00, -.49577300E-01, -.14466600E+00, 0.97410100E+00, 0.57337700E-01, 0.85326800E+00, 0.84056000E+00, -.35024200E+00, -.26535000E-01, 0.17234400E-01, -.35481000E+00, -.57155500E+00, 0.91022700E-01, 0.48104400E-01, -.35174200E+00, 0.26319200E+00, 0.15704700E+00, -.31404200E+00, 0.22684700E+02, 0.10598700E+03, -.18428300E+03, 0.90896800E+02, -.17320600E+03, 0.89314400E+02, -.17717600E+02, 0.36597700E+01, 0.11243400E+03, 0.25206500E+02, 0.17406300E+03, -.94830600E+01, 0.28484100E+03, -.88662700E+02, 0.45181700E+02, -.64209500E+02, 0.45853000E+02, 0.93656700E+00, 0.71012100E+02, 0.21940600E+02, -.41588400E+02, 0.18540900E+02, 0.25086500E+02, 0.99844200E+02, 0.10508100E+03, -.53367100E+02, -.13591900E+03, -.51420600E+02, -.36886900E+02, -.66582000E+02, 0.23514800E+02, 0.35888400E+02, 0.25288700E+02, -.78602800E+02, 0.16388600E+02, -.19532500E+03, 0.10012300E+03, -.12374500E+03, 0.97614300E+02, -.55593700E+02, -.64986200E+02, 0.12008900E+03, -.26827800E+02, 0.76099000E+02, -.59314400E+02, 0.16558600E+03, 0.29209200E+03, -.14608300E+03, -.92516500E+02, -.14576600E+03, -.63762500E+02, -.82357400E+01, -.47521600E+02, 0.40967900E+02, -.72703800E+02, 0.45808200E+01, -.25764600E+03, 0.28505200E+02, -.13106100E+02, 0.20632000E+02, -.84303100E+01, -.21926500E+02, -.26919300E+02, 0.28831000E+02, 0.12491800E+03, 0.57853400E+02, -.17106200E+02, 0.15482100E+03, 0.26599800E+01, -.33149900E+01, 0.89126800E+01, -.13996100E+01, 0.14198200E+02, 0.14994200E+02, 0.16295300E+01, -.85593400E+01, -.87308300E+00, 0.47866600E+01, 0.58684500E+00, -.15100400E+02, 0.20296000E+02, 0.14355500E+02, -.14518000E+02, 0.12848800E+01, -.41681600E+02, -.31257900E+02, 0.37383200E+02, 0.12955900E+01, 0.20433900E+02, -.45006400E+01, -.19499200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36506900E+01, -.24123300E+01, 0.35838000E+01, -.23469500E+01, -.24254500E+00, 0.13082200E+01, -.65581400E+00, -.41951400E+01, -.52806900E+02, -.36781200E+00, 0.38474500E+00, -.16204400E+01, -.62837800E+00, 0.11404100E+01, 0.48367400E+00, 0.35982200E+00, 0.10385300E+01, 0.72674300E+00, -.89234700E-01, 0.65086500E+00, -.13213600E+01, -.14298900E+00, -.92333400E+00, 0.38999800E+00, 0.99128400E+00, 0.71983200E-02, 0.60638700E+00, -.36767200E-02, 0.25309400E+00, 0.44215100E+00, 0.16156400E+00, 0.20478600E+00, 0.10964100E+00, 0.46989800E+00, 0.79000200E+00, 0.18212200E+00, -.15111800E-01, -.40512500E+00, -.30617800E+00, -.19921500E+00, -.57724000E+00, 0.15115900E+00, -.14152400E+00, -.18452200E-01, -.16819700E+00, -.13865500E+00, -.70028600E+00, -.66791000E-01, 0.22522100E+00, 0.22853600E+00, -.42744200E+00, 0.35736300E+00, -.59233200E+00, -.21702400E+00, 0.25412800E+00, -.27662200E+01, 0.13029600E+01, 0.22428000E+00, -.47063400E+00, -.12943100E+01, -.65902600E+00, 0.75489500E-01, 0.29811400E+00, 0.41042000E+00, 0.99761300E+00, -.35042200E+00, -.15598900E+01, -.30401700E+00, 0.10033800E+00, 0.22130700E-03, -.41929600E-01, 0.61952100E+00, -.55580600E+00, -.26858400E+01, -.63345000E-01, 0.20127400E+01, 0.14106600E+01, 0.54627400E+00, 0.19823700E+00, 0.18395100E+00, -.53104200E-02, 0.25596000E+01, -.71318900E+00, 0.21599400E+01, -.94036300E+00, -.93714600E+00, 0.16093700E+00, 0.20419800E+01, -.78303200E+00, 0.24653800E-01, 0.79090600E+00, 0.40712300E-01, -.10317400E+00, 0.10152000E+00, 0.38758000E+00, -.30154200E+00, -.83186400E-01, 0.65111500E+00, -.23459700E-02, 0.21330300E+01, 0.55152800E+00, 0.33677300E+00, -.14198300E+00, 0.98785000E+00, -.12557500E+01, 0.36594900E+00, -.15494800E+00, 0.20578300E+00, 0.11977600E-01, -.29373600E+00, -.48080600E-01, -.14979000E+00, 0.85984800E+00, -.27103000E+00, 0.13765800E+00, 0.78604200E+00, 0.72360300E+00, -.25275300E+00, 0.21556000E+00, -.25956000E+00, -.17349700E-01, -.73597300E-02, 0.48435900E+00, 0.20909300E+00, -.50786400E-01, -.48223300E+00, 0.30285500E+00, -.30530200E-01, -.88934200E+00, -.36504400E+00, -.61354700E+00, 0.10714800E+00, -.48065000E+01, -.89617300E-02, -.45719100E-01, 0.18914100E-01, -.33609000E+00, -.67854900E-01, -.29129100E+00, 0.20050400E+00, 0.62934400E+00, -.42920100E+00, 0.22057100E+01, 0.33269300E+00, 0.96410600E-01, -.10821100E+01, 0.22883300E-01, 0.83213800E+00, 0.48831900E+00, -.90302100E-01, -.40033700E+00, 0.48532000E+00, -.49866400E-01, -.85396600E-01, 0.16815400E+00, 0.19121000E-01, 0.32490300E+00, -.15503000E-01, -.13430900E+00, 0.70476400E-01, 0.11699400E+00, -.24661700E+00, 0.68396300E+00, 0.14984200E+00, -.23821000E+00, 0.63077400E+00, 0.11617600E+00, 0.97108900E+00, -.29954200E-01, 0.35602600E+00, -.32525000E+00, 0.44480300E+00, -.27346600E+00, -.14529300E+01, 0.23494700E+00, -.56038000E+03, -.29979200E+03, 0.15410700E+03, -.26062800E+03, 0.15768600E+03, -.16352600E+03, -.28105600E+03, 0.14803100E+03, 0.69606300E+02, 0.10969800E+03, -.20252500E+03, -.19887800E+03, -.65147800E+01, 0.55979100E+01, -.65021800E+02, 0.57711900E+01, 0.34710000E+02, 0.14690100E+02, -.21421900E+02, 0.12910200E+02, -.58564900E+02, 0.11250900E+02, 0.60799200E+02, -.15431900E+03, 0.75096700E+02, 0.25197700E+03, 0.74306900E+02, 0.72247200E+02, 0.11295900E+03, -.23291000E+02, -.90791400E+00, -.11028900E+03, 0.92390700E+02, -.11457700E+03, -.52361700E+03, 0.26270700E+03, 0.41461100E+02, 0.26192700E+03, -.31958200E+01, -.11377000E+03, 0.17092200E+03, 0.84463000E+02, 0.14881600E+03, -.64507200E+02, 0.42076500E+02, -.39409300E+03, 0.19634500E+03, 0.12410800E+03, 0.19616500E+03, 0.13417600E+03, 0.74066500E+02, 0.33738100E+02, 0.69356100E+02, 0.21989100E+03, 0.68394100E+02, 0.16143300E+03, 0.23609500E+03, -.11470900E+03, -.14187700E+01, -.13371400E+03, -.38864100E+02, 0.78571600E+01, -.53441300E+02, 0.20941600E+03, 0.13011400E+03, 0.13597900E+01, 0.17103700E+02, -.41006600E+01, 0.40578900E+02, 0.13826200E+02, -.59735000E+01, -.43676100E+02, -.43919700E+02, -.57748200E+01, -.13959000E+02, -.68863000E+01, -.49539700E+01, -.81511200E+01, 0.69417400E+01, 0.29300700E+01, -.43789500E+02, 0.44626500E+02, -.88098000E+01, 0.55250700E+02, 0.43453900E+01, -.19637400E+02, 0.15578600E+02, -.20877700E+02, 0.32697000E+02, -.53772900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.32457300E+01, 0.43485100E+01, -.43002800E+01, 0.19712600E+01, -.12771100E+01, -.38674900E+00, 0.40719500E+00, 0.55280000E+01, 0.69884800E+02, -.65688900E+00, -.40729900E+00, 0.34325100E+01, 0.41373700E+00, -.26155200E+00, -.18798200E+01, -.49051300E+00, -.56430500E+00, -.52458700E+01, -.29676900E+00, -.11988400E+01, 0.37292500E+01, -.58980500E-01, -.44175500E+01, -.14596400E+01, -.52699600E+00, -.14223100E-01, 0.81126300E+00, -.12067000E+00, 0.29845700E+00, -.24349900E+00, -.30406200E+00, -.66578600E+00, 0.20111900E-02, -.32854100E+00, -.41706400E+00, 0.28240600E+00, 0.14670700E-02, 0.65168000E+00, -.66434600E+00, -.85023000E+00, 0.14605700E+01, -.27824900E+00, -.33412200E+01, -.14704500E+01, 0.62998600E+00, 0.58892800E+00, 0.18363000E-01, 0.28664300E+00, 0.77599600E+00, -.12072200E+01, 0.10281200E+01, -.20301700E+01, 0.23766400E+00, 0.52846200E+00, -.16741700E+01, 0.35032500E+01, 0.17405900E+01, -.49381100E+00, 0.13542200E+01, -.31763500E+01, 0.10535000E+01, 0.30464400E+00, 0.14123700E+01, -.51411300E+00, 0.12657300E+01, -.15144900E+01, -.28214400E+01, -.55905100E+00, 0.25358400E+00, 0.22826100E-02, -.30989600E+00, -.13811400E+00, 0.36400000E+01, -.22358300E+01, 0.71834800E-01, 0.97625200E+00, 0.89816200E+00, 0.15882400E+01, 0.42225700E-01, 0.30138900E-01, -.49153200E-02, 0.32756700E+01, -.14811100E+01, 0.17437000E+00, 0.13111700E+01, -.72571200E+00, -.60286500E-02, -.12173400E+01, -.10409400E+01, 0.20878200E+00, 0.32663400E+01, 0.47950500E-01, -.47315800E-01, -.15957800E+01, -.42791600E+00, 0.17935300E+01, 0.18466300E+01, 0.16109800E+00, -.23400300E+00, 0.30932400E+01, 0.24442900E+01, 0.32913600E+00, -.43151600E-01, 0.46236300E+00, -.38841200E+00, -.33546300E+01, -.40465300E+00, -.96227000E+00, -.17796500E+00, -.26344000E+00, -.18961100E+00, 0.23556600E+00, -.10218900E+01, 0.32438000E+00, -.98443900E-01, 0.36434800E+01, -.81735000E+00, 0.22848600E+00, -.21288300E+00, -.20172900E+01, 0.39982900E-01, -.51821900E+00, 0.22851300E+01, 0.96143500E-01, -.59171500E-01, -.10595600E+00, -.15713500E+00, 0.28533200E+00, -.25565100E+00, 0.47731300E+00, 0.83520400E+00, -.29034500E+00, 0.38407100E+01, -.52463200E-01, 0.41282300E-01, -.21565500E-01, 0.15449800E+01, -.45763900E+00, 0.13543800E+00, 0.35069700E-01, -.99591200E+00, -.72871500E+00, -.24226900E+01, -.12301000E+00, 0.20272700E+00, 0.49057000E+00, -.41395000E-01, -.62201600E+00, -.25966300E+00, 0.15030200E+01, 0.11657200E+00, 0.57177000E+00, 0.18016000E+01, -.17092300E+00, 0.65695900E+00, 0.26862600E+00, -.68706500E-01, -.16293900E-01, 0.16537700E+00, 0.39102800E+00, -.47792200E-01, 0.39500500E+00, -.14853200E+01, -.25135200E-01, -.26890200E+00, 0.52139300E+00, 0.59528200E-02, 0.20563500E+00, -.21376300E-01, -.52401300E+00, 0.65752900E+00, -.51308000E-01, -.57682600E+00, -.74252900E+00, -.11905300E+01, -.76826600E+00, -.11284000E+04, 0.56732300E+03, -.93575400E+03, 0.55800300E+03, -.41851300E+03, -.90020600E+03, 0.10524300E+04, 0.73707600E+03, 0.89557400E+03, -.77751800E+03, 0.33077700E+03, 0.25120800E+03, -.11975300E+03, -.74154700E+03, -.12817400E+03, -.90330000E+02, -.24707400E+03, 0.29847200E+03, 0.49595900E+03, 0.20655100E+03, -.27752200E+03, 0.12632600E+03, -.20947100E+03, 0.98585700E+02, 0.34053600E+03, 0.10696200E+03, 0.78407400E+02, 0.76643500E+02, 0.92715300E+00, -.68012600E+02, -.18187500E+03, 0.67226200E+02, 0.59912600E+02, -.15324600E+04, 0.76977000E+03, -.90996500E+02, 0.76615400E+03, 0.18326400E+02, -.43548100E+03, 0.65905000E+03, 0.30256000E+03, 0.45765600E+03, -.30927000E+03, 0.28488300E+03, -.27843900E+02, 0.11261700E+02, -.13716500E+03, 0.14685900E+02, 0.18552800E+03, 0.11888100E+03, -.49432200E+02, 0.19509400E+03, 0.10793000E+03, 0.11678200E+03, -.45234100E+02, 0.12413400E+04, -.61218700E+03, -.46134300E+03, -.64404900E+03, -.96373100E+02, -.55764600E+01, -.14109700E+03, 0.81064700E+03, 0.69516300E+02, -.37493500E+02, -.75858200E+02, -.14538100E+00, 0.14826500E+03, 0.77489300E+02, -.99090200E+01, -.62111200E+02, -.61490900E+02, -.39076100E+01, -.78193300E+02, -.54417100E+02, -.32088200E+02, -.46144500E+02, 0.17561400E+02, 0.83297300E+01, -.61524700E+02, 0.62158000E+02, -.40508800E+02, -.39410600E+02, -.34698500E+02, 0.40977700E+02, 0.33288700E+02, -.45874200E+02, 0.77176500E+02, -.17710800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.47393500E+01, 0.29742600E+01, -.16209700E+01, -.10736400E+01, -.14592700E+00, 0.48593200E+01, -.14189900E+01, -.40164500E+01, -.11763200E+00, 0.35180700E+01, 0.62650700E-01, -.68124400E+00, 0.34807500E+00, 0.77416400E-01, -.33732500E+01, -.12796000E+00, 0.18143400E+01, -.56587000E+01, -.14124600E+01, -.28578000E+01, 0.95687900E+00, -.52956400E+00, 0.16279800E+01, 0.59312600E+00, 0.20221700E+00, 0.49036800E-01, 0.10892100E+01, 0.34352800E+00, -.85620000E+00, 0.27366800E-01, -.16652300E+01, 0.12369300E+01, -.92745900E-01, -.59499900E+00, -.19988100E+01, 0.10330300E+00, 0.15729000E-01, 0.74739400E+00, 0.31886000E+00, -.14766800E+01, 0.44845600E+00, -.13154600E+00, -.55546200E+00, -.52680100E+00, 0.44970900E+00, 0.43020600E+00, -.64885800E+00, 0.11128500E+00, 0.16951700E+01, -.78045200E+00, 0.40326100E+01, -.10035900E+01, 0.12680100E+01, 0.21432300E+01, -.19708900E+01, 0.40831800E+01, 0.27158900E+01, 0.73249900E-01, 0.20070900E+01, 0.60201100E+01, -.73752600E+00, 0.34515100E+00, -.90503200E+00, -.25354500E+00, 0.56726700E+01, -.47635900E+01, -.90376400E+01, -.86817200E+00, 0.46390500E+00, 0.82809400E-03, -.18805200E+00, 0.24763500E+01, 0.18423300E+01, -.11960800E+01, 0.11389700E+01, 0.86942100E+00, 0.14998400E+01, -.11437300E+00, 0.16537800E+00, 0.23799600E+00, -.25692300E-02, 0.24541600E+01, -.55406900E+00, 0.13259400E+01, 0.16435500E+01, 0.11971900E+01, 0.43539400E+00, -.26614500E+01, 0.61685900E+00, 0.15497400E+00, 0.42194000E+01, 0.20642400E-01, 0.30989900E+00, -.65101600E+00, 0.22941000E-01, -.12771200E+00, 0.17874500E+01, -.12727200E+00, -.34961700E+00, 0.72366200E+00, 0.23496400E+01, -.11299800E+00, -.10895900E+00, 0.13538800E+01, 0.56009800E+00, -.10850000E+01, -.58854500E+00, -.23833600E-01, -.37644500E+00, -.35767500E+00, -.45106900E-01, -.35765500E+00, 0.89471700E+00, -.28514400E+00, 0.37643700E-01, -.74464300E+01, -.77123100E+00, -.86127400E-01, 0.46666700E-01, 0.24249000E+01, 0.13106200E+00, 0.31103900E-01, -.12043000E+01, -.33925900E+00, 0.72574300E-01, -.13791100E+01, -.93591900E+00, -.29832400E+00, -.17499200E+01, -.16635500E+01, -.89186200E+00, -.12854500E+00, -.49802900E+01, 0.87546500E-01, 0.49902000E+00, 0.78337400E-01, 0.69771100E+00, -.35184100E+00, -.36677400E+00, 0.58122600E+00, 0.85290900E+00, -.16409600E+01, -.10221400E+00, 0.55794900E+00, -.22204100E-01, -.15606900E+01, 0.10220400E+00, 0.27979100E+01, -.24930000E+00, 0.79816600E+00, -.33575200E+00, 0.52137800E+00, -.65887100E-01, -.11953000E-01, -.73265600E-01, -.46798500E+00, 0.96005900E+00, 0.14939400E-01, 0.27296000E+00, 0.92827200E+00, 0.62262700E-01, -.25763300E+00, 0.12096500E+01, -.13771400E+00, 0.33525100E+00, 0.60902300E+00, 0.32884400E+00, -.21950900E+01, -.10556100E+00, -.37563000E+00, 0.22019600E+00, -.45348100E+00, -.59875600E+00, -.10605600E+01, 0.28996700E+00, -.16030400E+00, 0.43054300E-01, 0.10457100E+02, -.41898500E+03, 0.42103200E+00, -.26009300E+03, -.46285000E+03, 0.41602200E+02, -.23777200E+03, -.79437200E+02, -.36422100E+03, -.66932800E+03, 0.11938800E+03, -.58746900E+02, -.19311900E+03, -.52208200E+02, -.20144100E+03, -.33059300E+03, 0.67000200E+02, 0.73211600E+02, 0.49857100E+02, -.35112800E+03, 0.23106600E+03, -.28521100E+03, 0.13725900E+03, 0.87527600E+02, 0.14275600E+03, 0.81548600E+02, -.80748600E+02, 0.84941100E+02, -.23767600E+02, 0.18720100E+03, -.14337500E+02, 0.11750100E+03, -.23504400E+03, 0.11103500E+03, -.57328400E+02, 0.11750300E+03, -.44538800E+02, -.11726000E+03, -.13459500E+03, -.46348000E+03, -.13389500E+03, -.10184200E+03, -.61295500E+03, -.58212300E+03, 0.29107300E+03, 0.18006600E+03, 0.29084800E+03, 0.15009600E+01, 0.58019600E+02, 0.20831100E+03, 0.67910100E+02, 0.22502200E+03, -.37750400E+01, -.31223200E+03, -.64960700E+03, 0.32665400E+03, 0.24158900E+03, 0.32063500E+03, 0.19441600E+02, 0.59984900E+02, 0.76516100E+02, -.33596500E+03, 0.25239000E+02, 0.42428000E+02, 0.20372100E+02, -.48162500E+01, 0.18498200E+02, 0.88692200E+01, -.55934100E+01, -.28452100E+02, -.25906000E+02, -.63717600E+01, -.81107300E+01, -.13856900E+02, -.19345600E+02, -.17685300E+02, 0.14602900E+03, -.51182000E+02, -.29047000E+02, 0.29319600E+02, -.15786000E+02, -.86351300E+00, 0.51688900E+02, -.90516100E+02, 0.58841400E+01, -.75042200E+02, 0.18081000E+02, -.29463600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.31628900E+01, -.62533700E+01, 0.54306400E+01, -.35146400E+01, 0.92971800E+00, 0.79754800E-01, -.24985900E+00, -.64356100E+01, -.67388900E+02, -.79794400E+00, 0.15467300E+00, -.35319800E+01, -.40327900E+00, 0.37100800E+00, 0.21642000E+01, 0.98795900E+00, 0.13139300E+01, 0.62777200E+01, 0.19130800E+00, 0.75639300E+00, -.38680400E+01, -.82004000E-01, 0.69449000E+01, 0.63751400E+00, 0.21668300E+00, 0.87167500E-02, -.84775900E+00, 0.14542200E+00, -.10038500E+01, 0.41189300E+00, 0.63925700E+00, 0.16187300E+01, 0.49174800E+00, 0.47446500E+00, 0.28690400E+00, 0.12090700E+00, -.14389400E-01, -.10291800E+01, -.62421300E+00, 0.35856200E+00, -.39807900E+01, 0.34355700E+00, 0.29706700E+01, 0.99831400E+00, -.68036400E+00, -.59520500E+00, 0.26459700E+00, -.37161700E+00, 0.19333200E+00, 0.11218000E+01, -.58098700E+01, 0.18920200E+01, 0.18584200E+01, -.97038700E+00, 0.37134800E+01, -.40301100E+01, -.15264700E+01, 0.41716800E+00, -.19906800E+01, 0.11898000E+02, -.30575800E+01, 0.42390400E-02, 0.41738100E+00, 0.61984300E+00, -.18297800E+01, 0.12840900E+01, 0.96394200E+01, 0.10213500E+01, -.77199000E+00, 0.22197800E-02, -.91775300E+00, 0.81844100E+00, -.89754400E+01, -.64025200E+00, -.20917400E+01, -.20790000E+01, 0.10233400E+01, -.15050600E+01, 0.18211500E+00, -.41060400E+00, 0.13238500E-02, -.17350300E+01, 0.22091900E+01, -.10526900E+01, -.16185600E+01, -.23103400E+01, -.31107200E+00, 0.21292400E+01, 0.16502200E+01, -.61058300E+00, 0.39478900E+01, -.10743700E+00, -.30801700E+00, 0.13879700E+01, 0.81561000E-01, -.12211900E+01, -.14243000E+01, -.52733100E+00, 0.97325400E+00, -.12397500E+01, 0.35449600E+01, -.10805500E+01, 0.10587700E+00, -.10479000E+01, 0.14302600E+01, 0.29558900E+01, 0.14977500E+00, -.14173400E+00, 0.82502200E+00, -.30397800E+00, 0.25223100E+00, 0.87288700E+00, -.34139400E+00, 0.10559900E+00, 0.26289300E-01, -.64191200E+01, -.14931600E+01, 0.42590300E+00, -.13072500E+00, 0.24551300E+01, 0.33189500E+00, -.16897200E+00, 0.21802900E+01, -.24983600E+00, -.24707900E-02, 0.12434700E+01, 0.72320300E+00, -.60408800E+00, -.10101100E+00, 0.18605100E+00, 0.28237400E+00, 0.19429600E+00, 0.62886200E+01, 0.11652700E+00, -.77156800E+00, 0.12614500E+00, 0.32186900E+01, 0.40330100E+00, 0.15358100E+00, -.13753200E+00, -.48915100E-01, 0.74630300E+00, -.29277700E+01, -.76344800E+00, 0.96424600E-01, 0.19240500E+01, 0.15493700E+00, -.73718300E+00, 0.19681500E+01, -.59893900E+01, 0.60450400E+00, -.16611000E+01, -.30089500E+01, -.89911300E+00, -.10438200E+01, -.74335600E+00, -.58629600E+00, 0.15144300E-01, -.80972100E+00, -.26088900E+00, 0.76651700E-01, -.19166300E+01, -.38216900E+01, -.49865000E+00, 0.22519000E+00, -.92470900E+00, 0.85947800E-01, -.16689800E+01, -.10723900E-01, -.58363300E+00, 0.58759000E+00, 0.23031300E+00, 0.61493000E+00, 0.40427800E+01, -.41487100E-03, -.68991400E+00, -.70393100E+00, 0.19580400E-01, -.77854100E+03, -.29938200E+01, -.85030900E+02, -.13621500E+03, 0.35567800E+03, 0.22267400E+03, 0.10780100E+03, -.43206800E+02, 0.56853600E+03, -.26588500E+03, 0.13851000E+03, -.27366900E+03, 0.18234000E+03, -.57602400E+02, 0.41919500E+02, 0.21976100E+03, 0.10573700E+03, 0.12093200E+02, 0.30430400E+02, 0.39942800E+03, 0.45867000E+03, -.23582400E+03, -.72979500E+02, -.22784800E+03, -.11923000E+03, -.13910700E+03, 0.11864400E+03, 0.27607700E+03, -.14738000E+03, -.19058900E+03, -.11296700E+03, -.47902400E+03, 0.24722100E+03, -.29427600E+03, 0.23943900E+03, 0.21140000E+02, -.21505000E+03, 0.37894400E+03, 0.23182300E+03, 0.12793400E+03, -.66222600E+02, 0.59718200E+03, 0.30971300E+03, -.15704400E+03, -.87992200E+02, -.15471600E+03, 0.49421400E+01, 0.40079800E+02, -.11481800E+03, 0.25480900E+03, -.15303100E+02, 0.87627200E+02, 0.32289400E+03, 0.12742900E+04, -.63228100E+03, -.27866300E+03, -.60550100E+03, -.17811200E+03, -.48165500E+02, -.11287400E+03, 0.99355400E+03, 0.22741900E+02, -.42195000E+02, -.19950800E+02, -.71106700E+01, 0.11695700E+03, 0.65744300E+02, -.22652700E+02, -.27286400E+01, -.32398800E+01, -.73691000E+01, -.66365000E+02, -.37388300E+02, -.15652800E+02, -.30699900E+02, -.20138500E+02, 0.49990900E+02, -.46151800E+01, 0.50784400E+01, -.29925900E+02, -.23691100E+02, -.49234900E+02, 0.68618700E+02, 0.36475300E+02, -.33650500E+02, 0.62675100E+02, -.15178900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.83841500E+01, 0.10870600E+02, -.21821700E+01, 0.15662800E+01, -.66182500E+01, -.26428600E+01, 0.11307700E+01, -.18880800E+01, -.11214200E+03, 0.26851500E+01, 0.51649100E+00, 0.57181000E-01, -.13711700E+01, -.78653000E-01, -.20126100E+00, -.11112000E+02, -.45307500E+01, -.80868400E+01, -.15657300E+01, 0.10537700E+02, -.77455000E+01, -.75242100E+00, -.94939300E+01, -.12087200E+01, -.54929700E+00, 0.77572000E+00, 0.12699800E+02, 0.23746400E+01, -.35342400E+00, 0.60373600E+00, 0.49360700E+00, 0.18297700E+00, -.17538900E+00, -.20355800E+00, 0.22354100E+00, 0.45283500E+00, -.29990300E-01, 0.76929600E+00, 0.13303200E+01, -.24710500E+00, -.73801600E+00, -.22668600E+00, -.18949000E+01, -.80304700E+00, -.51653700E-01, 0.12852200E+00, -.24994500E+01, -.26411800E+00, 0.27663000E+01, 0.46478700E-02, -.47529700E+01, -.24428400E+01, -.11211600E+01, -.35719700E+00, -.48151400E+00, -.25544300E+01, 0.20414100E+01, -.21832900E+00, -.32175200E+00, -.11397400E+02, -.85680900E+00, -.38093000E-01, 0.19106700E+00, -.10797700E+00, 0.37776700E+00, 0.32941000E-01, -.89971800E+01, -.33442400E+00, -.27594400E+00, 0.70496900E-03, -.53383000E+00, -.13928400E+01, 0.63443100E+01, -.34099400E+01, 0.11807900E+01, 0.10094300E+01, -.64058100E+00, 0.26359300E+01, -.46985500E+00, 0.14307200E+00, -.51233700E-02, -.57173600E+00, -.74473000E+00, 0.34394300E+00, -.29661000E+00, -.55831500E+01, -.79497300E+00, 0.48072400E+01, 0.44118600E+00, 0.80694300E+00, -.20578500E+01, -.15387700E+00, -.46375800E+00, -.19103500E+01, 0.82304400E+00, 0.19724300E+01, 0.85884000E+00, -.17617000E+01, -.99953200E+00, 0.46306200E+01, 0.16433600E+01, 0.17316900E+01, 0.10925000E+00, 0.33751100E+01, -.35866700E+01, -.18387100E+01, -.42025100E+00, 0.22197100E+00, -.19049100E+01, -.10567600E+01, 0.51430400E+00, 0.85762800E+00, 0.16697600E+00, -.60474500E-01, 0.24175700E+00, -.12860400E+02, -.29328400E+01, 0.82830300E+00, -.11988000E+00, 0.79022500E+00, -.81752500E+00, 0.11230400E+00, 0.59650500E+01, 0.37210600E+00, 0.10220900E+00, 0.17554600E+01, 0.29760800E+01, -.57336400E+00, -.53860400E+00, 0.23142800E+00, -.74801900E+00, 0.29369300E+01, 0.42102000E+01, 0.46644000E+00, -.12485900E+01, 0.20389500E+00, -.59476100E+00, -.14071800E+01, -.57894700E+00, 0.34459800E+00, 0.15398900E+01, -.42561900E+00, 0.26566400E+01, 0.95133300E+00, 0.23814800E+00, -.19126100E+01, 0.38131200E+00, 0.26284000E+01, 0.48583100E+01, -.64243400E+01, -.10232200E+01, -.68137800E+00, -.19599300E+01, -.12292200E+01, 0.24202900E+00, -.21068900E-01, 0.14399400E+01, 0.25540700E+00, -.16598100E-01, 0.16129000E+01, 0.46850100E+00, -.19078700E+01, 0.40553600E+00, -.85689000E+00, -.38051100E+00, 0.17550700E+01, -.34650900E+00, -.34749100E+01, 0.28838200E+00, -.10404500E+01, 0.22673600E+00, 0.65636100E+00, 0.12406300E+00, -.13398800E+00, 0.11844500E+01, 0.47407000E+00, 0.30310200E+00, -.71594400E+00, 0.21637300E+00, 0.81540300E+02, -.16399600E+03, -.41902500E+03, -.67603500E+02, -.17414000E+03, -.13374500E+03, -.37697200E+03, -.60193000E+03, 0.39093900E+03, -.19720000E+03, -.11062500E+03, -.19664300E+03, -.25862700E+03, -.39895500E+03, 0.67617900E+02, 0.19812200E+03, 0.78426000E+02, -.40363300E+03, 0.61441100E+02, -.39178000E+03, 0.19453200E+03, 0.12638600E+03, 0.17823300E+03, 0.71868000E+02, -.70475700E+02, 0.11496600E+03, -.31083000E+02, 0.27854000E+03, 0.51663900E+01, 0.18586600E+03, 0.24631400E+02, -.16625100E+02, 0.11388500E+03, -.11627700E+02, 0.21119400E+02, 0.33219800E+02, -.26392000E+03, -.32543500E+03, -.19683500E+03, -.36819100E+02, -.60573500E+03, -.73866300E+03, 0.37130300E+03, 0.18293600E+03, 0.36283900E+03, -.85121400E+02, 0.99243900E+02, 0.25103200E+03, -.17042800E+02, 0.26436400E+03, -.12137900E+02, -.17306000E+03, -.73100700E+03, 0.36034700E+03, 0.90668000E+02, 0.39825400E+03, -.16613900E+02, 0.63768800E+02, 0.23818800E+02, -.63771000E+03, -.49522500E+02, 0.43421700E+02, -.18678500E+03, -.28094400E+01, 0.11281900E+02, -.17414000E+02, -.16931900E+01, -.88419800E+01, -.62745900E+01, -.37160400E+01, 0.17603900E+02, 0.75916500E-01, -.67546800E+01, -.46627300E+01, 0.13833800E+03, -.60382500E+02, -.88662200E+01, 0.90498400E+01, -.49439700E+01, 0.74515900E+01, 0.79769300E+02, -.10779000E+03, -.10010400E+02, -.60433600E+02, 0.33361000E+01, 0.17404000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14032100E+01, 0.48780200E+00, 0.16514900E+00, 0.16622400E+00, -.11247200E+00, 0.35274700E+00, 0.79172100E-01, -.22152000E+00, -.11657800E+01, 0.68225200E+00, -.49055100E-01, -.76670100E+00, -.61950700E+00, 0.11911100E+00, 0.15136300E+00, -.17713100E+01, -.28250300E+01, 0.10913900E+01, 0.17444300E+00, 0.63931800E+00, -.34321000E+00, 0.85474700E+00, -.22732400E+01, 0.42596300E+00, 0.38330200E+00, 0.58728300E-02, -.59244900E-01, 0.91660200E-01, -.51778500E+00, -.12156200E+00, -.77439900E+00, -.17683700E+00, 0.11509800E+00, 0.12843600E+00, 0.20022700E+00, 0.79348900E-01, -.40739200E-02, 0.60464000E-01, -.10579400E+00, 0.35475500E-01, -.34877700E+00, 0.18062500E-01, -.41524100E+00, -.16394700E+00, 0.59256200E-01, 0.56184600E-01, -.10018900E-01, 0.48731300E-01, 0.40629200E-01, -.11005800E+00, -.32108400E+00, -.11479100E+00, -.35375100E+00, -.92449100E-02, -.23269400E+00, -.11592200E+01, 0.55817400E+00, -.23424500E-01, -.13044200E+00, -.19316300E+00, 0.16272300E-01, -.42803900E-01, 0.68926300E+00, -.15551000E+00, -.72508100E+00, -.11535500E+00, 0.41865300E+00, 0.10631200E+00, 0.29480700E-01, 0.39169500E-03, -.20651200E-01, -.96783900E+00, 0.17273700E+01, -.75942900E+00, 0.50784400E+00, 0.68716400E+00, 0.29569100E+00, -.93314400E-01, 0.12911400E+00, -.50444600E-01, -.77691300E-04, 0.30774200E+00, 0.13270500E+00, -.42264100E-01, 0.99668400E+00, -.97857600E+00, -.79460900E-01, -.93334000E-01, -.31596200E+00, 0.72083000E-01, 0.10013800E+01, -.12141500E-01, 0.60646900E-02, -.57051500E+00, -.27930900E-01, 0.36642700E+00, 0.48547600E+00, -.65014200E+00, -.92016700E+00, 0.91484700E+00, 0.80471900E+00, -.55907500E-02, 0.31081300E-01, -.31795700E+00, 0.38724300E+00, -.22150500E+00, 0.11018800E-01, -.14183900E+00, 0.12579700E+00, 0.49343300E-02, -.12593900E+00, -.89094000E-01, -.46858100E-01, 0.14660200E-01, 0.35711000E-01, 0.15232100E+01, -.13030200E+00, 0.68598500E-01, -.28911900E-01, -.12609600E+00, 0.24506100E+00, -.99785900E-01, 0.30339700E+00, -.59804000E-01, -.16684300E-01, -.15976700E+00, -.23146000E+00, -.17856900E-01, -.25724700E-01, 0.63710800E+00, 0.36188800E+00, -.23426500E+00, 0.18027800E+01, -.26151800E-01, 0.28281900E-01, -.89701200E-02, 0.20536500E+00, -.29973700E+00, 0.12779700E+00, -.64627400E-02, -.61067300E+00, -.44780300E-01, -.16674200E+01, 0.10824100E+00, 0.59830300E-01, 0.21161200E+00, -.55077200E-02, -.44999300E+00, -.70842600E-01, -.17603500E+00, 0.85224300E-01, -.88127600E-01, 0.26912600E+00, 0.79805800E-01, 0.87458400E-01, 0.73520500E-01, 0.89008500E-01, 0.13686900E-01, 0.74012800E-01, -.19752400E+00, -.16200700E+00, 0.49616700E-01, -.18740700E+00, 0.14580700E-01, 0.13528900E+00, -.35447700E-01, 0.11461500E+00, -.50121000E+00, -.30904300E-01, -.13069000E+00, -.19297700E+00, -.14263100E+00, -.25827300E-01, 0.46168900E+00, -.10478700E+00, -.24720600E-01, -.22192500E+00, -.10094400E+00, 0.25657300E+00, 0.49636900E-02, -.10988300E+03, -.14355800E+03, -.38638700E+02, -.12241700E+03, -.31661400E+02, -.13184500E+03, -.27556200E+03, 0.10804000E+03, -.54561900E+02, -.52738400E+02, -.71581900E+02, -.69015800E+01, -.80442700E+02, -.36939900E+02, -.10916700E+01, -.29836000E+00, -.83616300E+02, -.53076100E+02, -.19646300E+03, 0.99076600E+02, 0.19462000E+02, 0.98016400E+02, 0.58510800E+02, 0.27513200E+02, -.33145800E+02, -.96560200E+02, 0.51681300E+02, 0.65123800E+02, 0.92429800E+02, -.73999100E+02, 0.34028900E+02, 0.75224400E+02, 0.37015400E+02, -.75190100E+02, -.48972200E+02, -.66280300E+02, -.20787300E+03, -.73630100E+02, -.50126400E+02, -.26315800E+03, -.99285000E+02, 0.49635900E+02, -.28036600E+00, 0.49714100E+02, -.76348500E+01, 0.77377400E+01, 0.27026700E+02, -.45282600E+02, 0.11830100E+01, -.14975200E+02, -.24345500E+03, -.28911800E+03, 0.14614900E+03, 0.75093200E+02, 0.13088300E+03, 0.82983500E+02, 0.49305300E+02, 0.25083800E+02, -.18571600E+03, -.23242000E+02, 0.27367600E+02, -.84063800E+01, 0.12664800E+01, -.13498800E+02, -.10987000E+02, 0.25420000E+01, -.12443500E+02, -.11438700E+02, 0.42462100E+00, 0.11510100E+02, 0.41409700E+01, 0.19534900E+00, 0.24774600E+01, 0.25865200E+02, -.19206500E+02, -.12243700E+02, 0.12070900E+02, 0.33795800E+01, 0.92844900E+01, 0.20140800E+02, -.34352200E+02, -.34251500E+01, -.20014200E+02, -.13641300E+02, 0.22020700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.81417500E+01, -.84426200E+01, -.21160400E+01, -.38894700E+01, 0.10178400E+01, 0.19699800E+01, -.20537900E+01, -.74113900E+01, 0.11833800E+02, 0.22142500E-01, 0.19926000E+00, 0.10629100E+01, 0.17172300E+01, 0.68919800E+00, -.46090000E+01, 0.42175400E+01, 0.50426500E+01, -.13349300E+02, -.29127200E+01, -.48520900E+01, 0.63631700E+01, -.19727900E+01, 0.15850700E+02, -.11818400E+00, -.12269400E+01, -.29022200E-01, -.17055100E+01, -.48873300E+00, 0.20298300E+00, 0.15808700E+01, 0.97189700E+00, 0.23103900E+01, -.61145300E+00, -.14633000E+00, 0.75585300E+00, -.29057800E+00, 0.12640100E-01, 0.16765500E+01, -.77666400E+00, 0.25829400E+01, -.63978600E+00, -.20002800E+01, -.29040500E+01, -.37999800E+01, -.37380800E+00, -.28814800E+00, 0.72987400E+00, -.39544300E+00, -.11723300E+01, 0.83053200E+00, -.25579700E+01, -.16150500E+00, 0.36757900E+01, -.68177500E-01, 0.56682500E+00, 0.65315800E+00, 0.65720800E+00, 0.51585900E+00, -.13156100E+01, 0.16471000E+01, -.33706000E+01, 0.55332400E+00, -.13762300E+01, 0.36075300E-01, 0.10197200E+01, 0.28138200E+00, -.35632600E+00, -.81770000E+00, -.55282900E+00, 0.57502000E-02, -.73132700E+00, -.20245100E-01, 0.78304800E+00, -.16852400E+01, -.13432100E+01, -.74887400E+00, -.10476200E+01, 0.24383300E+00, -.53551800E+00, 0.11737700E+00, -.60600100E-03, -.21836700E+01, -.52965500E+00, -.55092400E-01, -.20448100E+01, -.21591200E+01, -.37114600E+00, 0.50433700E+01, 0.18650600E+01, -.35305400E+00, 0.19543600E+01, -.17319100E-01, -.66039100E+00, 0.61242000E+00, 0.35331100E+00, -.31345800E+00, -.28390600E+00, 0.98087400E+00, 0.32339400E+01, -.24781100E+01, -.58176700E+00, 0.48842400E+00, -.16861500E+00, 0.41562800E+00, 0.21439100E+00, 0.15726100E+01, -.41806700E+00, 0.82565400E+00, -.13540800E+01, -.55095400E+00, 0.71895400E+00, 0.10516300E+01, 0.18417700E+01, -.57894800E+00, -.20107400E+00, -.21519700E+02, -.20699700E+01, -.49796400E-01, 0.46269600E+00, 0.23130400E+01, -.21625600E+01, 0.94734700E+00, -.10896300E+01, 0.10279600E+01, -.19895100E+00, -.14915800E+01, 0.17800200E+01, -.13055900E+01, -.91113400E+00, -.11629300E+01, -.11964300E+01, 0.53115200E+00, -.16124000E+00, 0.77209500E+00, -.84486200E+00, -.15654300E+00, -.68924700E+01, -.13256400E+00, -.56016900E+00, -.73466400E+00, 0.14251900E+01, 0.21517300E+01, 0.45433300E+01, 0.19456000E+00, 0.16450900E+00, -.64093400E-01, 0.15137500E+00, -.13648700E+01, 0.20552400E+01, -.49584100E+01, -.30743300E-01, -.45748600E+00, 0.13226200E+00, -.37277100E+00, -.11763200E+01, -.11533500E+00, -.25495400E+01, 0.32926100E+00, 0.11732700E+00, 0.11105000E+01, 0.10942000E+00, -.20455100E+01, -.59577000E+01, -.16107800E+01, -.14279000E+01, -.14209100E+01, -.49031500E+00, -.27348900E+01, 0.10570600E+00, 0.79528500E+00, -.18440400E+01, 0.94236900E+00, 0.25299300E+00, 0.16477900E+01, 0.23391700E+01, 0.12531600E+00, -.36300800E+00, 0.47847400E+00, -.74434400E+00, 0.69226000E-01, -.27014500E+01, 0.62402200E+03, -.26449400E+03, -.56249000E+03, -.12336700E+03, 0.48888100E+03, 0.12271200E+03, -.56900600E+03, 0.28715100E+03, 0.13086000E+03, 0.31774500E+03, 0.41228200E+03, 0.55842200E+03, -.48725200E+03, -.87397700E+03, -.40696800E+03, 0.54466900E+03, -.49926000E+02, -.16906500E+03, 0.90254500E+02, -.23307300E+03, 0.82561700E+02, 0.17379300E+03, 0.35623000E+03, -.34784100E+03, -.19228400E+03, -.12532600E+03, 0.33422500E+03, 0.61303800E+02, 0.21175500E+03, -.10631200E+03, -.24612300E+03, -.10579200E+03, -.36167400E+03, -.66261900E+01, 0.14925800E+03, -.15733000E+03, 0.11843800E+03, 0.18721900E+02, -.33864000E+03, 0.31468300E+03, -.15943400E+03, -.19264700E+03, -.15714700E+03, -.99784200E+01, -.11011200E+03, -.34585700E+03, -.48915000E+03, -.35967100E+03, 0.20055300E+02, -.77571700E+03, -.13889000E+03, 0.69098500E+02, 0.24159200E+03, 0.93987300E+02, 0.19302800E+03, 0.18717700E+03, 0.31746700E+02, 0.42924100E+03, -.62171200E+01, 0.12447100E+03, -.39615600E+03, 0.26877600E+01, -.30247700E+02, -.32870600E+02, 0.47883800E+01, -.23472700E+02, -.23048500E+02, -.21020200E+01, 0.33633200E+02, 0.56490000E+02, 0.56073700E+02, 0.58413500E+02, -.16668600E+03, 0.91235200E+02, -.23226900E+02, 0.22749900E+02, 0.56116200E+02, 0.66353600E+02, -.10753800E+03, 0.18664300E+02, 0.66200700E+00, 0.98853200E+02, -.80972200E+02, 0.24259900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25698100E+00, 0.76548500E+00, -.14963700E+00, 0.76284500E+00, 0.12381700E+00, -.26775700E+00, 0.58899400E-01, 0.54832200E+00, -.15217200E+01, -.72140600E-01, -.13734800E-01, 0.22445500E-01, 0.15748400E+00, -.11474300E+00, 0.26787500E+00, -.94176400E-03, 0.45462700E+00, 0.93839700E+00, 0.10654400E+00, 0.40062700E+00, -.10549000E+00, -.14526700E-02, -.14725300E+01, 0.81144000E-01, 0.30113600E+00, 0.36445100E-02, 0.70331100E+00, 0.49207800E-02, 0.18373100E+00, -.11341200E+00, -.33868000E+00, 0.66848000E-02, 0.30025300E-01, 0.18278500E+00, 0.86878200E-01, 0.11033800E-01, -.42746300E-02, -.62494400E-01, 0.23906600E+00, -.13094800E+00, -.80396100E+00, 0.79482700E-01, 0.16230100E+00, 0.12824700E+00, -.45514700E-01, -.21645400E-01, 0.74263700E-01, -.22568200E-01, 0.16692400E+00, 0.10623800E+00, -.11953700E+01, -.10853500E+00, 0.10174800E+01, -.24617500E+00, 0.36940000E+00, 0.67682800E+00, 0.62279100E+00, 0.34223800E-01, -.36514500E-01, 0.82477400E+00, 0.12185600E-01, -.46449000E-01, 0.55177500E-01, -.20429500E-01, -.15135300E+00, 0.36128000E-01, -.26786200E+00, 0.29196400E-02, 0.60339100E-01, -.43886700E-03, 0.10349900E+00, 0.98409200E-02, -.27582000E+00, 0.68802500E+00, 0.74210100E-01, -.26161400E+00, -.40651300E-01, -.11277100E+00, 0.33770800E-01, 0.21830800E-01, 0.22257300E-03, 0.31035200E-01, 0.12400100E+00, 0.17660600E-01, -.18706600E+00, 0.11657100E+00, 0.22925000E-01, -.63025600E+00, 0.11841400E+00, -.50525800E-01, 0.20995000E+00, 0.42835900E-02, 0.10369000E-01, 0.35730200E+00, -.94797200E-01, -.19947800E+00, -.84661100E-01, -.12129400E+00, -.11132400E+00, -.31817200E+00, 0.24483500E+00, -.25765500E+00, 0.11734000E-01, 0.92329700E-01, -.13630000E+00, 0.23004200E+00, 0.15153900E-02, 0.16627800E+00, -.68968400E-02, -.89644300E-03, 0.42132500E-01, 0.10551100E+00, -.24144100E-01, 0.75539400E-02, -.12536900E-01, -.96983400E+00, -.21080800E+00, -.94747700E-02, -.27364700E-01, 0.15325500E+00, 0.17456700E+00, -.11620800E-01, -.23105000E+00, -.13898900E+00, -.25087300E-02, 0.13967800E+00, -.45215300E-01, -.80055400E-01, -.24101100E+00, -.32429900E+00, -.22952100E+00, -.92633700E-01, -.91758400E+00, -.27888700E-01, 0.17508100E-01, 0.18816100E-01, 0.11994200E+00, -.39220800E-01, 0.27339300E-01, 0.55727200E-01, 0.16288200E+00, -.50923900E+00, 0.24960400E+00, -.15001100E+00, -.48503800E-01, -.13404200E+00, -.13759600E-02, 0.26528400E+00, -.16228400E+00, 0.60945300E+00, -.35329300E-01, 0.16255100E+00, -.87964200E-01, 0.10905700E+00, 0.90276400E-01, 0.64490200E-01, -.17375200E+00, 0.42513700E-03, -.18883300E-01, 0.97892600E-01, 0.37163700E-01, 0.13393500E+00, -.57133300E+00, -.24934100E-01, -.86208200E-01, -.12833700E+00, -.13272800E+00, 0.49484700E+00, 0.42799300E-01, 0.99649100E-01, -.15886400E+00, 0.11570100E+00, 0.29926100E-01, -.41927900E+00, 0.10628000E+00, 0.81713100E-01, -.21897300E-01, -.35075300E-01, -.89479300E-02, 0.15376300E-01, 0.48079200E-02, -.51329500E-02, 0.38068800E+02, 0.57489600E+02, 0.37082200E+02, -.55589100E+01, -.11673500E+01, -.14626400E+02, 0.75961800E+01, -.57741900E+01, 0.75266900E+01, 0.20880800E+02, 0.88691300E+01, 0.70772100E+01, 0.99394600E+01, 0.27421000E+01, 0.25335700E+02, -.23295900E+02, -.28660400E+01, 0.85724900E+00, 0.27497300E+02, 0.12140300E+01, -.10871200E+02, 0.41184800E+01, -.30582000E+01, -.10404300E+02, -.27785100E+02, 0.31891800E+01, -.15540100E+02, 0.17955200E+02, -.86554500E+01, 0.12268800E+01, -.89664300E+01, 0.12704300E+01, 0.31308600E+01, 0.25099800E+02, 0.59716600E+02, 0.21145700E+02, 0.17203400E+00, -.46861200E+01, -.25773700E+02, 0.12644600E+02, -.11619400E+02, 0.12858600E+02, 0.20966300E+02, -.45699400E+01, -.16469200E+02, -.26677400E+02, -.36925300E+00, 0.48845600E+01, 0.68800400E+02, 0.10172300E+03, -.50593500E+02, -.76751800E+02, -.52361200E+02, 0.39450700E+01, -.42501600E+01, -.10289300E+02, 0.71745600E+02, 0.12376500E+02, -.71868600E+01, -.11876900E+02, 0.13760400E+01, 0.74388900E+01, 0.35590200E+01, 0.11770000E+01, 0.27351900E+00, -.12736900E+00, 0.81320000E+00, -.37906700E+01, -.30442300E+01, -.23775400E+01, -.20751400E+01, -.87289900E+01, 0.36026300E+01, 0.30094000E+00, -.21562000E+00, -.24013300E+01, -.45765400E+01, -.40756200E+01, 0.73465400E+01, 0.19783300E+00, 0.11374500E+01, 0.51770800E+01, -.93815700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54346500E+01, -.65945500E+01, -.78787500E+00, -.30313200E+01, 0.76097400E+00, 0.20897100E+01, -.13340200E+01, -.30439900E+01, 0.49661900E+02, -.14582100E+01, -.49725300E-01, 0.24785600E+01, 0.91110000E+00, 0.16641000E+00, -.29970100E+01, 0.54359100E+01, 0.33628400E+01, -.66272800E+01, -.17383700E+01, -.61119800E+01, 0.30228200E+01, 0.13823300E-01, 0.68470000E-01, -.20499700E+01, 0.21312100E+01, -.13733100E+00, -.71907100E+00, -.82118400E+00, 0.23213500E+00, 0.14153700E+01, 0.20254200E+00, 0.74940100E+00, -.40016300E+00, 0.19546400E+01, 0.21821600E+01, 0.26432300E-01, 0.23613900E-02, -.88129100E+00, -.19842000E+01, -.29563600E+00, -.22449500E+01, -.11350000E+01, -.35233500E+01, -.14838200E+01, 0.67113100E+00, 0.46536500E-01, 0.15854200E+01, 0.28315500E+00, -.36901800E+01, -.59055700E+00, -.24978000E+01, 0.84966900E+00, -.59675400E+00, 0.43326600E+00, -.13137200E+01, 0.39668400E+01, 0.18311000E+00, 0.66937700E+00, -.14372300E+01, 0.61539800E+01, -.42608400E+01, 0.37161200E+00, -.24715400E+01, 0.48729800E+00, 0.89206300E+00, -.15081600E+01, 0.89350300E+01, 0.88597100E+00, -.20934800E+00, 0.79992800E-02, -.28312800E+00, 0.20908700E+01, -.55089800E+01, -.35114700E+00, -.47128500E+01, 0.18402200E+01, -.96538500E+00, 0.16839800E+01, -.30347500E+00, -.90993600E-01, 0.24205200E-02, 0.17882400E+01, -.11889400E+01, -.37447900E+00, -.12022000E+01, -.24857700E+00, 0.15307600E+00, 0.26612500E+01, 0.16594400E+01, 0.13707800E+00, 0.23811200E+01, 0.14756900E+00, -.45609100E+00, 0.18262500E+01, 0.89982300E+00, -.31895800E+01, 0.17255800E+01, 0.13432000E+00, -.36115900E+01, 0.32240500E+00, 0.30120400E+01, -.13586600E+01, -.37790600E+00, 0.15062700E+01, -.28462500E+01, -.51458500E+01, -.12942700E+01, -.90235100E+00, -.68746500E+00, -.89827600E+00, 0.71599200E-01, 0.12009100E+01, 0.20732600E+00, -.57070200E-01, -.26901500E+00, -.97078700E+01, -.14563600E+01, -.68781000E-01, -.19735200E-01, 0.69011300E+00, -.10619900E+01, 0.70957700E+00, -.25310800E+01, -.35626700E+00, -.22248300E+00, -.20648700E+01, -.14826700E+01, 0.11747800E+00, 0.17911400E+00, -.17308100E+00, -.11603000E+01, 0.99332000E+00, 0.42426200E+00, 0.21942200E+00, 0.14264600E+00, -.21745300E+00, 0.95531300E+00, -.51662200E+00, 0.18399600E+00, 0.41851700E-03, 0.13929800E+00, 0.94822300E+00, -.46446300E+01, -.82633100E+00, 0.96320900E+00, 0.22493600E+01, -.50431500E-01, -.26060200E+01, 0.12355300E-01, 0.16639000E+01, 0.92490400E-01, -.17257300E+01, 0.31590200E-01, 0.50746600E+00, 0.48764300E+00, 0.16451100E+00, 0.60106200E+00, 0.16980700E-01, 0.27097300E+00, -.64621800E+00, -.29599900E+00, 0.23053700E+01, 0.43326500E+01, 0.43222900E-01, 0.98402400E+00, -.87350800E+00, -.28320800E+00, 0.36051200E+01, 0.83925700E-01, 0.41967100E+00, 0.23756500E-01, 0.11147500E+01, -.17715900E+00, -.57779700E+00, -.66910000E-01, -.10873200E+00, 0.32599700E+00, -.24208800E-01, -.82614100E+00, 0.50025600E-01, -.32658600E+01, -.26983400E+00, 0.21700000E+01, -.31217500E+03, -.16375600E+03, -.53040300E+02, -.82973000E+03, 0.23449700E+03, -.11601800E+03, -.26232600E+03, -.12532000E+03, -.27547500E+02, -.25883600E+03, -.16924100E+02, -.80799500E+01, 0.56903900E+02, -.25417100E+03, -.15603700E+03, -.26770900E+03, 0.13393000E+03, -.43465100E+03, 0.13228400E+03, 0.29844700E+02, -.21136200E+03, 0.59382300E+01, -.14360800E+03, 0.13853100E+03, -.85298900E+02, 0.21939700E+03, -.59461200E+03, 0.28863100E+03, 0.93764300E+02, 0.29737400E+03, 0.71012000E+02, -.18966800E+03, 0.93702100E+02, -.50207200E+03, -.77736900E+02, -.16438900E+03, -.68841000E+03, 0.19358200E+03, -.97611200E+02, 0.19572400E+02, -.96541100E+02, 0.12241800E+02, -.14491000E+03, 0.41188400E+02, 0.22531200E+03, -.13584600E+03, -.13121500E+03, -.52576800E+03, -.50353400E+03, 0.25967200E+03, 0.41036300E+03, 0.26280900E+03, 0.34166000E+03, 0.12277900E+03, 0.12633400E+03, 0.17328500E+02, -.15523400E+03, 0.65844700E+02, 0.78503000E+02, 0.11013300E+02, -.91456100E+02, -.53342100E+02, 0.72579400E+01, -.15257900E+01, 0.45987700E+01, 0.79129400E+01, 0.54186000E+02, 0.21024900E+02, 0.19089100E+02, 0.21346500E+02, 0.23031600E+02, -.85718400E+01, -.19609100E+01, -.26827100E+01, 0.25940900E+02, 0.58366400E+02, -.84711600E+01, -.63853500E+02, 0.29763500E+00, -.28480600E+01, -.70696200E+02, 0.98146800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.33497400E+00, -.74639700E+00, -.13016000E-01, -.49909600E+00, 0.22308100E+00, 0.34443400E+00, -.50272600E-01, -.15137500E+00, 0.37883600E+00, 0.31634800E+00, 0.22842700E-01, 0.17800700E-01, 0.22870200E+00, -.98629800E-03, -.50689900E-01, 0.38916200E+00, 0.12863100E+01, 0.10891200E+01, 0.14080800E+00, -.14163300E+00, 0.29530900E+00, 0.39671700E-01, 0.20960500E+01, 0.56201800E+00, -.64627100E+00, 0.28385900E-01, -.91644700E+00, -.27027600E-01, -.65086600E-02, -.41547400E-01, 0.10546100E+00, 0.37872000E+00, -.82254400E-01, 0.36667300E-01, -.13273500E+00, -.80435200E-01, 0.15437700E-02, 0.85732000E-01, 0.39320800E+00, -.29622600E-01, -.34480100E+00, -.38833200E-01, -.16853700E+00, -.84752100E-01, -.76354400E-01, -.29167000E-01, -.81906400E-01, -.27787500E-01, 0.89402800E-01, 0.49974300E-01, 0.23358500E+00, 0.97275000E-01, 0.39860000E+00, -.16658300E+00, 0.28661900E+00, 0.71353100E+00, 0.19513900E+00, 0.24764900E-01, 0.11633700E+00, 0.59671800E+00, 0.13256200E+00, -.42531800E-02, -.29934600E+00, -.44892600E-01, 0.25921900E-01, -.92565200E-01, -.89795500E-01, 0.11758000E-01, 0.17178700E-01, 0.11218500E-03, -.44441400E-01, 0.10455000E+00, -.31999600E+00, 0.50990200E+00, -.14091700E+00, -.28100700E+00, -.54374900E-01, -.25146700E+00, -.24033100E-01, 0.22609200E-01, 0.31975800E-04, -.73020900E-01, -.83343600E-02, 0.77000200E-01, -.46412200E-01, 0.42782800E+00, 0.42724900E-01, 0.10589000E+00, 0.13297600E+00, -.10198200E+00, -.20244400E+00, 0.70203400E-02, 0.47273500E-01, 0.28441200E+00, -.59539600E-01, -.15509100E+00, -.26813800E+00, 0.14769700E+00, 0.21775600E+00, -.69125000E+00, -.70444200E+00, -.43095500E-01, 0.28741200E-02, -.15918600E+00, 0.10403300E+00, 0.17481100E+00, 0.25242100E-01, 0.11920700E+00, -.34753800E-03, 0.37898100E-01, 0.74491300E-02, 0.51010700E-02, 0.11194000E-01, -.31082000E-02, -.76506400E-01, 0.11071500E+00, 0.31998600E+00, -.83630700E-01, 0.49178200E-01, -.41693500E+00, -.19277600E+00, 0.98893700E-01, -.83526700E+00, -.78052600E-01, 0.18813200E-01, 0.95345100E-01, 0.27238300E-01, -.81340300E-01, -.46403300E-01, -.14624100E+00, -.17838100E+00, -.41772600E+00, -.21275200E+01, 0.55023100E-02, 0.60888000E-01, 0.11228600E-01, -.48106500E+00, 0.24004600E+00, -.30292200E-01, -.95602000E-03, 0.21120200E+00, 0.13963000E+00, 0.78578300E+00, 0.87272200E-01, -.24868600E-01, 0.10926500E+00, 0.49157900E-03, -.24331700E-01, -.65024900E-01, 0.33916300E+00, -.32022400E-01, 0.29046300E+00, 0.35519800E+00, 0.23210100E-01, 0.12107200E+00, 0.85430400E-01, -.77768300E-01, 0.40196500E-02, 0.20242100E-01, 0.46296300E-01, 0.44473400E-01, -.25493300E+00, 0.27961700E+00, -.26730300E-01, 0.21296300E-01, -.15598300E+00, -.99250700E-01, 0.14646100E+00, 0.34371600E-01, 0.41529000E-01, -.41171600E-01, 0.43109300E-01, -.70217000E-02, -.33416000E+00, 0.21250100E+00, 0.19751800E-01, -.22926400E-02, 0.34373700E-01, -.90498500E-01, 0.24836600E-01, -.25472200E+00, -.87195700E-02, 0.77940700E+00, 0.25215500E-01, -.19759600E+02, -.90038400E+01, 0.98534600E+01, -.58994900E+01, 0.30594500E+01, 0.60010700E+01, 0.32613800E+01, -.47586800E+01, 0.10464400E+01, -.41853800E+01, -.77541100E+01, -.14413500E+02, -.66435800E+01, 0.88159900E+01, -.15422800E+01, 0.96486000E+00, -.83346000E+01, 0.58162000E+00, 0.13182400E+02, 0.12151600E+02, -.12861000E+02, -.10558800E+02, -.11030100E+02, 0.14087000E+02, 0.78129200E+01, -.22171100E+02, 0.10954000E+02, 0.58854600E+01, 0.11094500E+02, 0.51825800E+01, -.35239700E+01, 0.79244300E+01, 0.53414800E+01, 0.47994800E+01, -.12752100E+02, 0.73254800E+01, 0.57567400E+01, -.29879400E+01, 0.40978900E+01, -.29007800E+01, -.12389400E+01, -.29450600E+01, 0.14535700E+01, 0.40937800E+01, 0.27276600E+01, -.20663600E+01, 0.35083200E+00, 0.18991500E+02, -.89523700E+01, 0.20578700E+02, -.10692300E+02, 0.13111500E+01, 0.15084000E+01, -.21396800E+01, 0.27677700E+01, -.12649000E+02, 0.29546500E+01, -.21203700E+02, -.41579400E+00, -.52319600E-01, 0.24159000E+00, -.10599100E+01, -.38553800E+01, -.38908800E+01, -.17590400E+00, -.16508500E+00, -.83254200E+00, -.93624700E+00, -.11766600E+01, 0.28619800E+01, -.14388200E+01, -.39156000E+01, 0.39452100E+01, -.10127400E+01, -.26885000E+01, 0.17088800E+01, -.45519500E+01, 0.18556300E+01, 0.22909900E+00, 0.11073100E+01, -.69150100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.81264700E+00, -.24031500E+01, 0.30753100E+00, -.17332300E+01, 0.22020700E+00, 0.95573300E+00, -.81647200E-01, -.63448900E+00, -.25557400E+01, 0.11381900E+01, -.14491200E-01, -.17864400E-02, 0.19517400E+00, 0.11418800E+00, -.40158200E+00, 0.69834100E+00, 0.19795400E+01, 0.11611800E+01, 0.16481200E+00, -.60672800E+00, 0.45710200E+00, 0.37440900E-01, 0.37487200E+00, 0.43598400E+00, -.33439500E+00, 0.27449300E-01, -.30739300E+00, 0.24736500E-02, 0.40582200E+00, -.29998400E+00, -.11426000E-02, 0.14445000E+00, -.94674100E-01, -.33362100E+00, -.79665200E+00, -.15900400E+00, 0.66850300E-02, -.10635500E+00, 0.67032400E+00, -.38741400E+00, 0.50285400E+00, 0.79529900E-01, -.70458700E+00, -.20985200E-01, -.23957400E-01, -.18847600E-01, 0.99969800E-01, 0.68462200E-01, -.50546400E+00, -.26788600E-03, -.48052000E+00, 0.29717900E+00, 0.53005900E-01, 0.84907000E-01, 0.15327600E+00, 0.75588000E+00, 0.62953200E-01, -.27150900E-02, 0.62173600E-01, -.18736900E+01, 0.60925800E+00, 0.25530200E-01, -.43556100E+00, -.13160100E+00, 0.63499500E-02, -.10817000E+00, -.12141400E+00, 0.19572300E+00, 0.26696600E-01, 0.11757200E-02, -.10152400E+00, -.74486200E+00, -.15147400E+01, 0.81043700E+00, 0.24050700E+00, -.88521800E+00, -.37451800E-01, -.40967000E+00, 0.17683900E+00, 0.29346100E-01, 0.44132000E-03, 0.18159200E+00, 0.18427100E+00, -.28453300E+00, -.74657100E+00, 0.14610700E+00, 0.17333200E-01, -.21957800E+01, 0.64140200E+00, -.30220600E-01, -.37706300E+00, 0.17336300E-02, 0.95818800E-01, -.22659600E+00, -.13421700E+00, 0.45970800E+00, -.73370500E-01, -.65402600E+00, -.10805900E+00, -.13853000E+01, -.14077000E+01, -.36785200E-01, 0.58772000E-01, -.46354300E+00, -.31451300E-02, -.54247700E+00, -.86690300E-01, 0.59786400E-01, 0.19482100E+00, 0.37224300E-01, 0.44401800E-01, 0.37820800E-01, -.24718300E-01, 0.68814700E-02, 0.43917100E-01, -.21965800E+00, 0.62174600E+00, 0.30452200E-01, 0.14970100E+00, 0.58781100E+00, 0.44392700E+00, -.50903400E-01, -.10973800E+01, -.32602400E+00, 0.60195500E-01, 0.86296100E-01, -.45077300E+00, 0.14685900E+00, 0.41695800E+00, 0.20432600E+00, 0.48589600E+00, -.34108500E-01, 0.25491500E+01, -.28275300E-01, -.36125400E+00, 0.11476500E-01, 0.10505300E+01, -.23402300E-01, -.25245800E+00, 0.82799100E-01, -.13926300E+00, -.14922300E+00, 0.42302000E+00, 0.13555700E+00, 0.36575000E-01, -.33254100E+00, -.37616600E-02, 0.63970900E+00, 0.61178600E+00, -.71012300E+00, -.60282900E-01, 0.75309600E+00, -.86744500E-01, -.16830800E+00, -.16078400E-01, 0.20034500E-01, 0.14172900E+00, 0.28167800E-02, 0.21649700E-01, 0.99487800E-01, -.11542500E-01, -.20521800E+00, -.74507600E+00, -.45912200E-01, -.95148300E-01, 0.25758700E+00, -.69408600E-02, -.42977100E+00, 0.95429300E-03, -.19175900E-01, -.16217500E+00, -.11005100E+00, -.59808400E-02, 0.69192400E-01, 0.31258600E+00, 0.14968900E+00, -.92647300E-01, -.19767000E-01, 0.29569700E-01, -.87436000E-02, 0.41743000E+00, -.46180800E-01, -.48875700E+00, -.37589100E-02, 0.88331300E+00, 0.33756000E+02, 0.17728400E+01, -.14758000E+02, 0.76556400E+01, 0.35467500E+01, 0.11278200E+02, 0.24077800E+02, 0.16398400E+02, -.14963200E+02, -.15954400E+02, -.23628500E+02, 0.38715400E+02, -.22917300E+02, -.17427000E+02, 0.86899200E+01, 0.72234500E+02, 0.88652500E+01, 0.34507100E+01, 0.37865500E+02, -.12389800E+01, 0.18603000E+02, -.35214300E+01, 0.22609600E+02, -.32475400E+02, 0.43881800E+02, -.21682200E+02, -.66674800E+00, -.21947600E+02, 0.10129800E+02, 0.32737800E+02, -.85354700E+01, 0.40603400E+02, 0.16896600E+01, 0.56445200E+02, -.22652800E+01, -.85718700E+02, 0.42375300E+02, -.15635800E+02, 0.42879900E+02, 0.47252700E+02, 0.18833000E+02, -.25855800E+02, -.59962700E+02, -.65683800E+01, 0.23801500E+02, 0.69697300E+02, 0.64117300E+02, -.33132300E+02, -.74055600E+02, -.31829600E+02, -.70307600E+01, 0.12711800E+02, -.18693100E+02, 0.56741500E+02, 0.16043900E+02, 0.24532800E+01, -.44751200E+02, -.12838100E+01, 0.17142800E+02, 0.92400800E+01, 0.73970900E+00, -.16239300E+01, -.18607100E+01, -.16646300E+01, -.94788300E+01, -.99146900E+00, -.14737100E+01, 0.72093800E-01, -.11938500E+02, 0.21910900E+01, -.16251800E+01, 0.18787800E+01, -.82867500E+00, -.30513400E+01, -.34714600E+00, -.19532600E+01, -.16855500E+01, -.18238000E+01, 0.56889100E+01, -.17313800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.61308500E+01, -.69149600E+01, -.11424600E+01, -.27455400E+01, 0.17701100E+01, 0.24568100E+01, -.14214900E+01, -.15532000E+01, 0.70522900E+02, -.16247400E+01, -.31821100E+00, 0.33393600E+01, 0.11265500E+01, -.17160600E-01, 0.32892900E+00, 0.68322700E+01, 0.93796600E+01, -.19589300E+01, -.13295300E+01, -.79159000E+01, 0.34821200E+01, 0.10185700E+00, 0.36949100E+01, -.15322300E+01, 0.52055000E+00, -.21939700E-01, -.29172800E+01, -.10313200E+01, 0.50721200E+00, 0.99053700E+00, 0.10097600E+01, 0.10769000E+01, -.40401600E+00, 0.28631500E+01, 0.24148500E+01, -.14694900E-01, -.15508000E-01, -.33794700E+00, -.32351400E+01, 0.20822400E+00, -.35062000E+01, -.15867400E+01, -.54450600E+01, -.36423500E+01, 0.20467500E+00, 0.34728700E+00, 0.20825200E+01, -.17887400E+00, -.23558600E+01, -.53094600E+00, -.69694900E+01, -.92572500E+00, 0.74876300E+00, 0.11717300E+00, 0.32791400E-01, 0.71121400E+01, 0.58898700E+01, 0.45108500E+00, -.10930600E+01, 0.11220800E+02, -.51097300E+01, 0.57351900E+00, -.11119700E+01, -.42741500E+00, 0.11447800E+01, -.25863600E+01, 0.10817800E+02, -.17357800E+01, -.59512400E+00, -.31585200E-02, 0.58173800E+00, 0.12579600E+00, 0.22811800E+01, -.21000100E+01, -.68241900E+00, 0.13642100E+01, 0.29298000E+00, 0.15443000E+01, -.53576800E+00, -.23767800E+00, 0.38747300E-03, 0.25783700E+01, -.48147300E+00, -.31072200E+00, -.48126900E+01, -.26947900E+01, -.92309500E-01, 0.99579000E+00, 0.24065400E+01, 0.44181200E+00, -.34184800E+01, 0.76590000E-01, -.15144800E-01, 0.21641600E+01, 0.13260700E+01, -.34327700E+01, 0.19791700E+01, -.38868000E-01, -.46222600E+01, -.75505000E-01, 0.10849900E+01, -.10462800E+01, -.16970100E+00, -.64478300E+00, -.24578900E+01, -.48653900E+01, -.92934300E+00, -.90945800E+00, -.13565100E+01, -.13623900E+01, 0.51312200E+00, 0.18785000E+01, 0.11424500E+01, -.35381400E+00, -.79394100E+00, -.16536400E+02, -.20846200E+01, -.46952000E+00, 0.10091800E+00, 0.33481500E+00, -.31162600E+01, 0.97539900E+00, 0.90309400E+00, 0.11722800E+01, -.16368400E+00, -.29738700E+01, -.30513700E+01, 0.44850800E+00, 0.13258700E+01, -.80341900E+00, -.16190100E+01, 0.25469000E+01, -.32331300E+01, 0.57764900E+00, 0.57734400E+00, -.23428100E+00, 0.95370500E+00, -.88478900E+00, -.28677100E+00, 0.20455200E+00, 0.22827800E+01, -.23387800E+00, -.66342300E+00, -.19171200E+00, -.73896900E+00, -.24425000E+01, 0.30094900E+00, 0.95278800E+00, 0.12779900E+01, -.16846300E+00, -.77521300E+00, -.31505700E+01, -.54967100E+00, 0.80583200E+00, 0.28672600E+00, -.12757600E+00, 0.31265500E+00, -.53000400E-01, -.97420000E+00, 0.10283600E+01, 0.27720300E+00, 0.31274300E+01, -.46515400E+01, -.10655600E+01, -.47608000E+00, 0.18585100E+01, -.79709500E+00, -.22195100E+01, 0.19123100E+00, 0.47301300E+00, -.14921100E+01, 0.12514000E+01, 0.26729800E-01, -.31442800E+01, 0.57145400E+00, 0.13027100E+01, 0.21883400E+00, -.47306100E+00, -.31293400E+00, -.74757400E-01, 0.19733400E+01, 0.32209100E+00, -.23216800E+01, 0.10085600E+01, -.86380500E+01, 0.18304600E+00, 0.15487700E+04, -.40502200E+03, 0.20701100E+03, 0.33971800E+03, 0.23329000E+03, -.11974300E+03, 0.14168300E+03, 0.11709600E+03, -.19452900E+02, -.58277400E+02, 0.15801700E+03, 0.39960000E+03, 0.52577900E+03, -.26959800E+03, 0.11440000E+03, -.26143100E+03, -.56961600E+02, 0.53554100E+02, 0.10910300E+03, 0.41552200E+03, -.73441900E+02, -.79713100E+02, -.20425200E+03, 0.61917700E+03, -.29711300E+03, -.17136300E+03, -.30966600E+03, 0.94468900E+01, 0.21890700E+03, -.12658700E+03, 0.38071900E+03, -.65524100E+02, 0.86517200E+02, 0.13945700E+04, -.34133700E+03, 0.16886200E+03, -.53962200E+02, 0.17009800E+03, -.29796600E+03, 0.13324900E+03, -.14103500E+02, -.26396000E+03, 0.14841300E+03, 0.12491100E+03, 0.18073200E+04, 0.15494100E+04, -.77480500E+03, -.97319200E+03, -.77987300E+03, -.50110000E+03, -.13345900E+03, -.26701500E+03, 0.26054400E+03, -.65463500E+02, -.80920600E+02, -.19430400E+03, -.29725600E+00, 0.20701000E+03, 0.83456000E+02, -.40044700E+02, -.31419600E+02, -.38545100E+02, 0.47392900E+00, -.85102300E+02, -.48124200E+02, -.48139000E+02, -.53882500E+02, 0.54850400E+02, -.26213500E+02, -.32433000E+02, 0.38689800E+02, -.57717500E+02, -.13070400E+03, 0.48532300E+02, 0.57726700E+02, 0.45364800E+02, -.22353100E+02, 0.13191700E+03, -.21597400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.57878400E+00, -.15212200E+01, -.10230700E+00, -.14096800E+01, 0.10754100E+00, 0.13187400E+01, -.73422000E-01, -.16010700E+01, -.80651000E+01, 0.45307900E+00, 0.79848600E-01, -.59234200E+00, -.23589100E+00, 0.70206900E-01, 0.51654500E-01, -.44513700E+00, -.41039100E+00, 0.79857900E-01, -.26893700E-01, -.89373100E-01, -.10188900E+01, -.22510000E-01, 0.25285800E+01, 0.24220100E+00, -.51385300E+00, 0.15688200E-01, -.11575700E+01, 0.33635700E-01, -.26461300E+00, 0.14499700E+00, 0.38356400E+00, 0.25546400E+00, 0.88057200E-01, -.22619300E+00, -.11719200E+00, -.64720800E-01, -.15283500E-02, -.28882700E+00, -.14888200E+00, 0.15762400E+00, 0.44676100E+00, 0.10670800E+00, 0.55715600E+00, 0.22405900E+00, -.14816300E+00, -.13769100E+00, -.43571900E-03, -.64171400E-01, -.34454500E+00, 0.29520000E+00, 0.24944200E+01, 0.81194800E+00, -.10264100E+01, -.27448900E+00, -.13752800E+00, -.27276800E+01, -.31942200E+00, 0.90064000E-01, -.49710700E+00, -.48450000E-01, -.44293700E+00, -.24519700E+00, 0.31363100E+00, -.15042900E+00, -.77452800E+00, 0.75051100E+00, -.45599200E+01, -.35326800E-01, 0.25945800E+00, -.34940600E-03, 0.31249500E+00, -.89291300E+00, -.86065700E+00, 0.19190500E+01, -.65768000E+00, -.40918200E+00, -.37267800E+00, -.11500500E+00, 0.23183500E+00, 0.40431000E-02, 0.31100200E-04, 0.16964900E+01, 0.28934300E+00, 0.16087800E+00, -.11109300E+01, -.38665500E-01, 0.57530300E-01, -.21536900E+01, 0.18088700E+00, -.77218900E-02, 0.21268000E+00, 0.43725300E-01, 0.82444600E-01, 0.14704500E+00, -.20316400E+00, 0.39931400E+00, 0.18733200E+00, -.29138500E+00, -.70681700E+00, -.18523200E+00, 0.29074100E+00, -.22980800E+00, -.66791300E-02, 0.19449700E+00, -.11721800E+00, 0.63497800E+00, 0.23664300E-01, 0.88720700E-01, -.12559600E-02, 0.15290800E+00, 0.11813500E+00, 0.14225000E+00, 0.14400000E+00, -.45547000E-01, -.10240600E+00, -.20121200E+01, -.31099100E+00, -.93270600E-01, -.62047800E-01, 0.71719900E+00, 0.31159000E+00, -.34595600E-01, -.10724900E+00, -.20587900E+00, -.26648500E-01, 0.19453800E+00, -.16740300E+00, -.15379100E-01, -.12449400E+00, -.33725100E+00, -.66246900E+00, -.34049000E-01, -.22831800E+01, -.21131900E-01, -.29776500E-01, 0.27814500E-01, 0.50814600E+00, 0.58478200E-03, -.94223700E-01, 0.98422100E-01, 0.91716200E-01, -.46074100E+00, -.22600900E+00, -.13168700E+00, -.41736400E-01, -.11574100E-01, 0.70336000E-02, 0.59348400E+00, -.48908500E-01, 0.25303100E+00, 0.33144700E-01, 0.29712800E+00, -.56430800E+00, 0.38615400E-01, 0.58272900E-01, 0.42298500E-01, -.23215500E+00, -.12586900E-01, -.12489800E+00, -.13141900E+00, 0.54585700E-01, -.15408600E+00, 0.42587200E+00, 0.65256300E-01, 0.22427800E+00, -.46853100E+00, -.98763000E-01, 0.82776400E+00, 0.28401300E-01, 0.85926100E-01, -.42805900E-01, 0.13192200E+00, 0.57032800E-01, -.21482900E+00, 0.14789400E-01, 0.34293900E-01, 0.37131100E-01, -.34462900E-01, -.52526100E-01, -.90070300E-02, -.33113700E+00, 0.17131300E-01, 0.98459900E+00, -.12370500E+00, 0.52134000E+00, -.18678000E+00, -.39864400E-01, 0.10470500E+03, -.52368900E+02, -.69292800E+02, -.56194400E+02, -.35631800E+02, -.56151700E+02, 0.31194300E+02, 0.73361400E+02, 0.51088100E+02, -.63877200E+02, -.25341700E+02, 0.27563700E+02, -.14726800E+02, -.88357700E+02, -.13471500E+02, -.24128600E+02, -.68734200E+02, 0.26099200E+02, 0.72185700E+01, 0.19543600E+02, -.46004700E+02, 0.28059100E+02, -.76649000E+02, 0.37473000E+02, -.24396400E+01, 0.38310400E+02, 0.32633100E+01, -.30674700E+02, -.22119800E+01, -.50433200E+02, -.14087400E+02, -.18548800E+02, 0.36036200E+02, 0.11896100E+03, -.59336500E+02, -.51651200E+01, -.59397900E+02, -.42964700E+02, -.12506000E+02, 0.11798800E+02, 0.80364900E+02, -.33971000E+02, -.20375700E+02, 0.55349400E+01, 0.65779300E+01, -.34803200E+01, 0.34216800E+02, 0.27483700E+00, 0.70444900E+01, -.20733500E+01, 0.39926700E+01, -.28272300E+02, -.50059400E+02, 0.14713400E+01, 0.87710300E+01, -.90398400E+00, -.10311700E+02, -.88333700E+01, -.28094800E+00, 0.59184400E+01, 0.64319300E+01, -.13325900E+00, 0.89563000E+01, 0.21597200E+01, 0.27244400E+01, 0.23018500E+01, 0.65737900E+01, -.34804300E+01, 0.58129800E+01, -.63957200E+01, 0.33694200E+01, 0.93040200E+01, 0.11428700E+01, -.55355400E+00, 0.19513300E+00, -.10865900E+01, -.89560000E+01, 0.11439600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18877700E+01, -.25666500E+01, 0.43274300E+00, 0.38550700E+00, 0.75043900E+00, -.25793100E+01, 0.75249000E+00, 0.13751600E+01, -.17775500E+02, -.16318900E+01, -.38904700E-01, -.70573800E+00, -.40395200E-01, 0.47750500E-01, 0.17788200E+01, 0.17785100E+00, -.85708700E+00, 0.36690100E+01, 0.75058600E+00, 0.16268000E+01, -.14662800E+01, 0.26791200E-01, -.10437500E+01, 0.21594000E+00, 0.20528300E+00, -.96566200E-02, -.15032500E+00, -.13998400E+00, 0.56517000E+00, -.16357700E+00, 0.51789600E+00, -.60520200E+00, 0.16392600E+00, 0.36740300E+00, 0.48803500E+00, -.12681600E+00, -.11610900E-01, -.53195100E+00, 0.67420800E+00, 0.20921500E+00, -.93576700E+00, 0.51503900E+00, 0.97694400E+00, 0.10776800E+01, -.17227200E+00, -.23455100E+00, 0.89660400E+00, -.19151900E-01, -.95233100E+00, 0.59996300E+00, -.49172900E+01, 0.31052300E+00, 0.47760400E+00, -.53978000E+00, 0.15821600E+01, 0.13742200E+01, -.93251300E+00, -.68469700E-01, -.52092000E+00, 0.20929300E+00, 0.99187000E+00, -.16906300E+00, 0.15324400E+01, -.41502100E+00, -.28027500E+01, 0.11123900E+01, 0.74317000E+01, 0.87892300E+00, -.23867700E+00, -.91805500E-03, 0.25378700E+00, -.10627000E+01, 0.35912000E-01, 0.55157600E+00, 0.47115900E+00, -.73484000E+00, 0.47329300E+00, 0.47280400E+00, 0.21935400E+00, -.19681700E-01, -.17224900E-02, 0.11837700E+01, -.15570700E+00, -.17409100E+00, 0.17486300E+00, -.42806100E-01, -.44502500E-01, -.17903200E+01, 0.44344900E-01, -.61650000E-01, -.12019400E+01, 0.23205300E-02, 0.10164700E+00, 0.48191500E+00, -.52647400E+00, 0.48628700E+00, -.30222100E+00, 0.19952400E+00, 0.92336100E-01, -.33617700E+00, -.38107600E+00, 0.68118600E-01, 0.69312100E-01, -.22508500E+00, 0.51881100E+00, 0.79045800E+00, 0.31492200E+00, 0.44745800E+00, 0.42280200E+00, 0.12176500E+00, -.11352900E+00, -.18238000E+00, -.29497500E+00, 0.93094400E-01, 0.27637000E+00, 0.49120000E+01, 0.11004500E+01, -.19491300E+00, -.18355700E+00, -.14551400E+01, 0.40016800E-01, 0.34827300E-01, 0.28068900E+00, 0.13687500E+00, 0.25140000E-01, 0.49812900E+00, -.83521500E-01, 0.33880300E+00, 0.73637300E+00, 0.84448100E+00, 0.40261900E+00, -.21175100E+00, 0.92321200E-01, 0.35552800E-01, 0.69586800E+00, -.39842000E-01, -.14672700E+01, -.20389700E+00, 0.71859300E+00, -.14026800E+00, -.76567800E+00, 0.31912200E+00, -.16045100E+01, -.15798700E+00, -.29209400E+00, 0.76527600E+00, -.53584400E-01, -.89491100E+00, -.99974200E+00, 0.49597200E+00, 0.28223000E+00, -.27737900E+00, -.72660400E+00, 0.12985200E+00, 0.59865000E-01, 0.24685400E+00, -.56952100E+00, -.70892800E-02, -.52494400E-01, -.27588600E+00, -.29318800E-01, 0.32824300E+00, 0.16694000E+00, -.10707000E+00, -.31012700E+00, -.13097800E+00, -.44042700E+00, 0.41817400E+00, 0.13713700E+00, -.89416400E-02, -.18928900E+00, 0.13180900E+00, 0.37898900E+00, 0.89683300E+00, 0.13569400E+00, -.11894600E+00, -.22830000E+00, -.81896700E-01, -.74236700E-01, -.23722500E-02, -.37867800E+00, 0.34658500E-01, 0.10376800E+01, -.12352900E+00, 0.20062900E+01, 0.51487500E+00, 0.38424900E-01, 0.11773100E+00, 0.86820700E+01, 0.17194700E+01, -.16408700E+02, 0.38336800E+02, 0.15072400E+02, -.44901000E+02, -.62646900E+02, -.14333700E+02, 0.27551500E+02, -.15113400E+02, 0.47506600E+01, -.45254000E+01, -.23898700E+00, -.23301000E+01, -.77724300E+01, -.20749900E+01, -.29866000E+02, -.45155100E+02, -.15686200E+02, 0.14247700E+02, 0.27300100E+02, -.78603700E+02, 0.40579900E+02, 0.40641600E+02, 0.39308100E+02, -.68172900E+01, 0.14921900E+02, 0.16533800E+02, -.53038600E+02, -.41501500E+02, 0.24388300E+02, 0.21440000E+02, 0.31380900E+03, -.15814500E+03, -.90002400E+02, -.15665500E+03, -.39875400E+01, -.42275300E+01, -.61721700E+02, 0.81742800E+02, -.11191400E+03, -.73948600E+01, -.17916900E+03, 0.99575400E+02, -.48221900E+02, 0.67583800E+02, -.56405300E+02, 0.52223700E+02, 0.46024800E+00, -.61306300E+01, 0.89967500E+02, -.26408200E+02, -.31711500E+01, 0.19953500E+02, 0.28977600E+01, -.18480300E+02, -.43986000E+01, 0.10715800E+01, 0.25948600E+01, 0.31892500E+01, 0.25978200E+01, 0.45278400E+01, 0.47331200E+01, 0.57465700E+01, 0.37436400E+01, -.25529800E+02, 0.58596200E+01, 0.28542300E+01, -.35453500E+01, 0.51362800E+01, 0.12524800E+02, -.53931500E+01, -.20764400E+01, -.21204000E+01, 0.57138200E+01, -.16547000E+02, 0.12652900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16422200E+01, 0.29664700E+01, -.16889800E+01, 0.24144900E+01, 0.44734600E+00, -.27066700E-01, 0.45788100E+00, 0.29471500E+01, 0.69002400E+01, 0.12978200E+01, -.18689900E+00, -.44098400E+00, -.29527900E+00, -.34696300E+00, 0.43730600E+00, -.12569400E+01, -.15344400E+01, 0.20720600E+01, 0.60702900E+00, 0.75912500E+00, -.44818400E+00, 0.57830700E+00, -.54646600E+01, 0.68546700E+00, 0.12964400E+01, 0.17517800E-01, 0.41282000E+00, 0.24683700E-01, 0.50324500E+00, -.35745400E+00, -.62596300E+00, -.11184500E+01, 0.88024500E-01, 0.13317100E+00, 0.12856800E+00, -.94409800E-02, -.50216800E-02, -.16166500E+00, 0.39987700E+00, -.33296200E+00, 0.11106700E+01, 0.25034700E+00, -.19584400E+00, 0.21331000E+00, 0.17854700E+00, 0.11395900E+00, -.94237900E-01, 0.14634500E+00, 0.34568100E-01, -.33408900E+00, 0.16464300E+01, -.53033600E+00, -.35546300E+00, -.15794200E+00, -.23405700E+00, 0.34981300E+00, -.84274800E+00, -.28980700E+00, 0.58946200E+00, 0.93068000E-01, 0.10850300E+01, 0.15045400E+00, 0.48985500E+00, 0.76163200E-01, -.75884900E-01, 0.36550400E+00, 0.41538800E+01, -.23410800E+00, -.75404900E-01, -.13954500E-02, -.16519700E+00, -.47864600E-01, -.28163100E+01, -.12850700E+01, -.13923900E+01, -.41507500E+00, 0.13092100E+01, 0.68505800E+00, 0.18969400E+00, -.35762100E+00, -.35094600E-02, 0.27000100E+01, -.34459700E+00, -.10226700E+01, 0.52533600E+00, 0.20265000E+00, 0.71810600E-01, 0.22038300E+00, -.41428800E+00, -.21217500E-01, 0.80737300E+00, 0.26466900E-02, 0.11368200E+00, -.26602900E+00, -.16209600E+00, 0.38710600E+00, 0.43870800E+00, 0.22351100E+00, 0.16662300E+00, -.11513400E+00, -.82916300E+00, 0.20114500E+00, 0.41100200E-01, -.63987500E+00, 0.11558400E+01, -.24674100E+00, 0.32558700E+00, -.60030600E+00, 0.28588000E+00, 0.39825900E+00, -.13351600E+00, -.31535000E+00, -.29270500E+00, 0.92924300E-01, -.17098700E+00, 0.50106800E+01, 0.75749800E+00, -.12684600E+00, -.55994400E-01, -.83603600E+00, 0.14392000E+00, -.23017500E+00, 0.57910400E+00, 0.17970300E+00, 0.34648800E-01, -.28965800E+00, -.10873100E+01, 0.40817500E+00, 0.25413000E+00, 0.26942400E+00, 0.42054700E+00, -.30534600E+00, -.11967300E+00, 0.19869600E-02, 0.50574000E+00, -.71258700E-01, -.76278100E+00, 0.22681700E+00, 0.58576100E+00, -.27510400E+00, -.37686700E+00, -.47003500E+00, -.40629800E+00, -.62067200E+00, -.17947400E+00, 0.59651800E+00, -.91471200E-01, -.13513000E+01, -.16341000E+01, 0.22433100E+01, 0.42300000E+00, -.45389500E+00, 0.60545400E+00, 0.26207000E+00, 0.99765700E-01, 0.18932900E+00, -.23730000E+00, -.37807600E-03, 0.21023100E+00, -.39984400E+00, -.22920300E+00, 0.69667600E+00, -.16700700E+01, 0.17062600E+00, -.17588400E+00, -.10383900E+00, 0.13712300E+00, 0.11457800E+01, -.53361400E-01, 0.31337000E+00, -.25925800E+00, -.20442400E+00, -.48468600E-01, -.49093900E-01, -.47600000E+00, -.10560800E+00, -.82692300E-01, 0.16734800E+00, 0.19211700E-01, -.28739700E-01, -.32022000E+00, 0.93858600E-01, 0.11761500E+00, -.23468000E-01, -.84070700E+00, 0.21244100E+00, -.14119500E-03, -.67543700E+00, 0.51294900E-01, 0.63746900E+02, -.31227400E+02, 0.90203000E+01, 0.26768300E+02, -.19947700E+02, -.14959600E+01, 0.36985300E+01, 0.13953100E+02, 0.20583100E+02, 0.67610900E+02, -.33482000E+02, -.38149000E+02, -.33709100E+02, 0.50107800E+01, -.35489500E+01, -.19549100E+02, 0.36179600E+01, -.17333100E+02, -.46666100E+01, 0.15855200E+02, -.92475500E+02, 0.45240300E+02, 0.41440700E+02, 0.46249900E+02, -.37332600E+02, -.12280500E+02, 0.99202800E+01, -.57305400E+02, -.13913600E+01, -.13945000E+02, 0.29082000E+02, 0.17779400E+03, -.89847900E+02, -.32923100E+02, -.88578200E+02, -.48536400E+01, -.40721700E+02, -.73687000E+01, 0.46432900E+02, -.46806200E+02, -.31799800E+02, -.48397300E+02, 0.20173300E+03, -.97942200E+02, -.93783000E+01, -.12455300E+03, 0.30894400E+02, -.17731700E+02, -.92919700E+01, 0.49960800E+02, -.54399600E+02, -.11281900E+02, 0.20423200E+02, 0.26597700E+01, -.17913000E+02, -.48624900E+01, -.95219400E+00, -.26281300E+01, -.22089200E+01, 0.26394900E+01, 0.51640000E+01, -.16670100E+01, -.14637700E+01, -.21421700E+01, -.73275500E+01, -.36150100E+01, -.23509400E+01, 0.20259600E+01, -.13655500E+01, -.47504400E+01, 0.40276100E+00, 0.24271400E+01, 0.15324200E+01, 0.24216800E+01, -.71854600E+01, 0.12833500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25662600E+01, -.38548900E+01, -.85346600E+00, -.17023800E+01, -.15921000E+00, 0.14243100E+01, -.78705500E+00, -.20944500E+01, 0.31885600E+02, -.62788700E-01, 0.11396800E+01, 0.27107000E+01, 0.46280400E+00, -.16228400E+00, -.42396100E-01, 0.31150000E+01, 0.40927500E+01, 0.11236800E+01, 0.75362300E-01, -.27484900E+01, 0.12678100E+01, -.58615200E+00, 0.31317400E+01, -.11464900E+01, -.77975700E+00, -.24423300E-01, -.22551700E+01, -.25183500E+00, 0.93086200E-01, 0.18033200E-01, 0.89922800E+00, 0.30332400E+00, -.82560200E+00, 0.12230300E+01, 0.12303100E+01, -.21572500E+00, 0.27277200E-01, 0.63198500E+00, -.10924600E+01, 0.92785200E+00, -.14373000E+01, -.10554300E+01, -.97094800E+00, -.23255200E+01, -.91236400E+00, -.39511300E+00, -.61678900E-01, -.66488300E-01, -.12005200E+01, 0.26384100E+00, 0.66235600E+01, 0.15084100E+01, -.18517400E+01, -.98792800E+00, -.18630100E+01, -.46983400E+00, -.29577700E+01, 0.50090700E+00, -.43177200E-01, -.10128500E+01, -.13445300E+01, 0.92840900E-01, -.26095900E+01, 0.57580200E+00, 0.63124700E+00, -.20234500E+01, -.17480400E+01, 0.12989600E+01, 0.40980300E+00, 0.94433900E-02, -.70554100E+00, -.10513100E+01, 0.32189900E+01, -.23130000E+01, 0.16529500E+01, 0.12629400E+01, -.25506600E+01, -.56661200E-01, 0.11351400E+00, 0.55333700E+00, 0.28134600E-02, -.23516300E+01, 0.54400800E-01, -.76884300E+00, 0.22976100E+01, -.11186500E+00, -.14326200E+00, 0.28297300E+01, -.88698100E+00, -.18128900E-01, 0.53515700E+01, -.17463900E-01, -.72953000E+00, -.28253000E+00, -.53782000E-01, -.31041900E+00, -.10265500E+00, -.17221100E+00, 0.12303700E+01, 0.12943600E+00, 0.12941100E+01, 0.22063800E-01, -.15121000E+00, 0.11287800E+01, -.19422100E+00, -.51231200E-01, -.19212500E+00, 0.42930900E+00, -.42359200E+00, -.52039800E+00, -.18680300E-01, 0.97969700E-01, 0.19468100E+00, -.59249900E-01, 0.29263600E+00, -.85298800E+00, -.39280400E+00, 0.27288600E+00, 0.23622600E-01, 0.10632300E+00, 0.41288700E+00, 0.31799700E+00, -.16808500E+00, -.32543500E+00, -.23446200E+00, 0.11489600E+01, 0.53081700E+00, -.81006200E-01, -.99774500E-01, 0.83840600E+00, 0.32139700E+00, 0.12444200E+01, 0.10071700E+02, 0.90995500E-01, -.18629300E+01, -.31299000E-01, -.45174300E+00, -.17264400E+01, -.65356900E+00, -.98424700E-01, 0.33307200E+00, -.29670300E+01, 0.37355300E+01, -.11735100E+00, 0.40921200E+00, -.17598500E+01, 0.65614000E-02, 0.14164400E+01, -.54689400E+00, 0.21043000E+01, -.53185800E+00, 0.20233900E+01, -.73746800E+00, 0.48665300E+00, 0.49218100E+00, 0.48117400E+00, 0.66512800E+00, 0.34746800E-01, 0.37732700E+00, -.38726200E+00, 0.19689300E+00, 0.11361100E+01, 0.12004600E+01, 0.65465000E+00, 0.39570200E-01, -.18263900E+00, -.22167900E+00, 0.34336600E+00, 0.83432000E-01, -.53874900E+00, 0.11837400E+01, -.53633400E+00, 0.11579500E-01, -.33497500E+00, -.23759400E+00, -.56429400E+00, 0.16083300E+00, 0.13225500E+00, -.10228200E-01, -.16922400E-01, 0.97221400E+00, -.21938900E+00, 0.24242200E+01, -.23786500E+00, 0.20892400E+01, 0.11633200E+01, 0.13113900E-01, 0.23085400E+01, -.92447800E-01, 0.11205100E+01, 0.46476100E+02, -.61224100E+01, -.31166000E+01, 0.53015800E+02, -.34597100E+01, -.10072500E+02, -.11569400E+02, -.31285900E+03, -.12044600E+03, 0.61793600E+02, 0.22312400E+03, 0.60129300E+02, -.18540400E+02, 0.42018700E+02, 0.17057800E+02, -.27090500E+02, -.20532800E+02, 0.68529900E+01, -.14175500E+03, 0.13473900E+03, -.63695400E+02, -.67563800E+02, -.67386900E+02, 0.55817700E+02, 0.29179100E+02, 0.92410200E+00, 0.12056900E+03, 0.26687900E+02, 0.97346800E+01, 0.44189400E+02, -.39552400E+03, 0.20104000E+03, 0.13830100E+03, 0.19726100E+03, 0.77832300E+02, 0.97613400E+02, 0.14105100E+02, -.80607600E+02, 0.15859700E+03, 0.93180000E+02, 0.16737000E+03, -.44976200E+03, 0.22174100E+03, 0.22045600E+03, 0.25735800E+03, -.15349600E+02, 0.28420300E+02, 0.47506700E+02, 0.14399600E+02, 0.18039100E+03, 0.20773600E+02, 0.19225100E+03, -.11222300E+01, 0.18651000E+02, 0.15997100E+02, 0.22753400E+01, 0.22395600E+01, 0.98601800E+00, -.17127900E+01, -.16468500E+02, 0.74671800E+00, 0.50574000E+01, 0.34020500E+01, 0.29251200E+01, 0.14910800E+02, 0.21553700E+01, -.96930900E+00, 0.21545700E+01, -.35023900E+01, -.87269400E+01, 0.21438400E+02, -.23075000E+01, 0.74220500E+01, 0.26298300E+02, -.18654900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11077500E+01, -.28064800E-01, -.38348700E+00, 0.22781300E+01, 0.13576100E+00, -.57695400E+00, 0.31168000E+00, 0.27704500E+01, 0.24256800E+02, -.13623200E+00, -.13848300E+00, 0.21860500E+00, -.14259400E+00, -.27634100E+00, 0.17524500E+01, -.17214700E+01, 0.59879600E+00, 0.22383200E+01, 0.61486900E+00, 0.41667400E+00, 0.88454700E+00, 0.55474700E-01, -.30384500E+00, 0.85320800E+00, 0.52282700E+00, -.70606300E-02, 0.32077300E-01, -.10831200E+00, 0.39516400E+00, 0.19725700E+00, -.92734000E-01, -.48486500E+00, -.33062200E-02, 0.65810200E+00, 0.12711400E+01, -.10893000E+00, -.16905000E-03, 0.72285000E-01, -.32153900E+00, 0.19888600E+00, -.97991400E-01, -.64912200E-01, -.23875500E+00, -.29427000E+00, -.98003100E-01, 0.59924900E-01, 0.46272500E+00, -.21837900E-01, 0.16171500E+00, 0.32109500E-01, 0.23045100E+00, 0.52103400E-01, 0.41775700E+00, 0.45297100E+00, 0.17424300E+00, 0.45111700E+00, 0.11525000E+01, -.13626000E+00, -.15138700E+00, -.29312900E+00, -.11740900E+00, 0.58212200E-01, 0.38393200E+00, 0.88716700E-01, 0.14879900E+00, 0.27268600E+00, -.16113300E+01, -.75003900E+00, 0.45527500E-02, -.17240000E-02, 0.26351200E+00, -.23647800E+00, -.71883000E+00, 0.13553000E+01, 0.46237500E+00, -.76106400E+00, 0.55676000E+00, -.34201800E+00, 0.83249300E-01, -.46049700E-01, 0.40707400E-03, 0.52511200E+00, 0.29994400E+00, 0.34098500E+00, -.84778200E+00, -.26750400E+00, -.39300400E-01, -.13027500E+01, -.27437700E-01, -.51109200E-03, -.12767700E+01, 0.22630700E-01, 0.19897100E+00, 0.30520800E-01, -.49457300E-03, 0.25382100E+00, -.20832400E+00, 0.95252700E-01, 0.27865200E-01, -.57242700E+00, -.17481400E+01, 0.31420500E+00, -.37114500E-02, 0.73072000E-02, -.82508100E+00, 0.47460400E-01, -.91383000E-01, 0.42227600E+00, -.66880600E-01, 0.25091100E-01, -.79973300E-01, -.25581300E+00, 0.56554400E+00, -.17902000E+00, 0.89000700E-01, 0.21816100E+01, 0.83906000E+00, -.78923000E-01, 0.15280800E+00, -.19237500E+00, 0.37495700E-01, 0.52700800E-01, 0.51471800E+00, 0.28219500E+00, 0.12874900E-01, -.43288600E+00, -.72903900E+00, 0.17599800E+00, -.31667800E+00, -.44810900E-03, 0.36087200E+00, -.31640200E+00, -.15763800E+01, -.28730200E-01, 0.41278000E+00, -.48321900E-01, 0.28073700E-01, 0.25776100E+00, 0.27168800E+00, -.14458500E+00, 0.71128800E-01, -.67038800E+00, 0.21436300E+00, -.53631300E+00, -.42507600E-01, -.27231800E+00, -.48578100E-01, -.27044000E+00, -.16355400E+01, 0.21426100E+01, 0.20072600E+00, -.63206100E+00, -.88364900E-01, 0.12675900E+00, -.55812500E-01, 0.27272000E-01, -.12571400E-01, -.14832300E-01, 0.83367000E-01, -.10742600E+00, -.50582600E-01, 0.84941400E+00, 0.18141100E+00, 0.12885300E+00, -.11464500E+00, 0.65005500E-01, 0.13912600E+00, 0.57724500E+00, -.55141300E-01, 0.35757100E+00, 0.41878200E-02, -.16185800E+00, -.12037500E+00, -.69639000E+00, -.40208400E+00, -.25563000E-02, -.46325600E-01, 0.25501200E+00, -.23022000E-01, -.34777300E-01, -.57406800E+00, -.11874800E-01, -.27357800E+00, 0.30342400E-01, -.23359800E+00, 0.33337200E+00, 0.13340000E-01, -.19719400E-01, -.32312000E-02, 0.38642300E+00, -.20814300E+00, 0.50142100E+02, 0.56011300E+02, -.27568800E+02, -.44510100E+02, -.35352300E+02, 0.50276600E+02, -.10737500E+03, -.38843900E+02, 0.21241800E+02, 0.47474800E+02, 0.19363300E+02, 0.17249200E+01, 0.32937300E+02, -.25898400E+02, -.22897500E+02, -.47951600E+01, 0.23354200E+02, -.16300700E+02, 0.29750400E+02, -.12573400E+02, 0.93243500E+01, -.14874200E+02, -.80575500E+02, -.27833500E+02, 0.11590700E+02, -.55587300E+01, -.20798400E+02, -.20807500E+02, 0.16797500E+02, 0.13012100E+01, 0.53686800E-02, -.23963400E+02, -.67172500E+00, 0.15859700E+02, 0.21321700E+02, -.32676300E+02, -.50526200E+02, -.11909800E+02, 0.21615700E+02, -.76752100E+02, -.83790200E+02, 0.42000700E+02, 0.24209100E+02, 0.44695500E+02, 0.24741000E+02, 0.18214500E+02, 0.10197300E+02, 0.29757500E+02, 0.42595600E+02, 0.72415600E+01, 0.59762700E+02, 0.56349000E+00, -.13260400E+01, -.16019800E+00, 0.66427700E+00, 0.12395900E+01, 0.18341600E+01, -.17075200E+00, 0.42753800E+00, 0.35458600E+01, 0.54216600E+01, 0.43240000E+01, -.17347900E+02, 0.58807400E+01, 0.15334400E+01, -.19003400E+01, 0.44751400E+01, 0.54086000E+01, -.53917400E+01, 0.91609200E+01, -.19703400E+01, -.19384600E+01, -.30848600E+01, 0.84293500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31680400E+00, 0.81153200E-01, -.29678600E-01, 0.24799800E+00, -.31222900E+00, -.31431300E+00, 0.34582800E-01, -.79160700E-01, -.39062900E+01, -.24549300E-01, 0.50687000E-01, -.11315500E+00, -.12216300E+00, 0.39539900E-02, 0.92520000E+00, 0.14280200E+00, 0.70557000E+00, 0.10929200E+01, 0.21113600E+00, 0.27062000E+00, 0.10198200E+00, -.49224900E-01, 0.11550100E+01, 0.27658300E-01, -.20616700E+00, 0.17934300E-01, -.23080500E+00, 0.24077500E-02, 0.95453600E-01, 0.21154300E-02, 0.29664200E+00, 0.12139500E+00, -.67784400E-01, -.56935600E-01, -.38181400E-01, -.14418900E+00, -.44282300E-03, 0.52847200E-01, 0.20479700E+00, 0.30406100E+00, 0.14072600E+00, -.54603000E-01, 0.32694300E+00, -.12641700E+00, -.12517000E+00, 0.37935400E-01, 0.11619100E+00, -.46936500E-02, -.21075900E+00, 0.15015600E+00, -.36883100E+00, 0.95536800E-01, 0.81021300E-01, -.11349000E+00, 0.16907500E+00, 0.54542100E+00, 0.39195000E+00, -.17183400E-01, -.60966400E-01, -.25570700E+00, 0.82360600E-01, -.90648600E-02, -.15210800E+00, -.36271500E-01, -.78328500E-01, 0.60977500E-01, 0.58164300E+00, 0.50066000E-01, 0.30215100E-01, -.53767200E-03, -.13234900E-01, 0.46862600E-01, 0.24215200E+00, 0.26367500E+00, 0.17333300E+00, -.15232200E+00, -.15581800E-01, -.38878400E-01, 0.61123900E-01, 0.58640400E-02, -.43160300E-03, 0.25282500E+00, 0.48563400E-01, -.45500100E-02, 0.14349300E+00, 0.11259300E+00, 0.16485800E-01, -.26639300E+00, 0.98920500E-02, -.68746900E-01, 0.38295200E+00, -.20866800E-03, -.31699800E-02, -.38152300E-01, -.11057800E+00, 0.13986600E+00, -.11193800E+00, -.30709800E-01, 0.23600400E+00, -.10869000E-01, 0.47125200E-01, -.28264400E-02, 0.40311100E-02, 0.12507300E-01, 0.11431800E+00, -.62629600E-02, -.49938500E-01, 0.77415000E-01, -.18095800E-01, -.39573000E-01, 0.10664900E-01, 0.55760100E-01, -.67955500E-01, 0.21414100E-01, 0.40689600E-01, -.50701400E-01, 0.12506200E-01, 0.32855500E-01, -.46578600E-02, 0.91106600E-01, 0.82983200E-02, 0.72691200E-01, -.50646800E+00, -.83242800E-01, 0.18594100E-01, 0.14184300E+00, 0.11716400E+00, -.14173600E-01, 0.20351800E+00, 0.97687600E-01, 0.95372400E-01, 0.61214000E-01, 0.35505600E+00, 0.28865200E-01, 0.10343100E-01, -.12318800E-01, -.36412200E+00, -.13618900E+00, -.67009000E-01, -.27595300E-01, -.53887600E-01, 0.44085900E+00, -.97036200E-02, 0.15963000E+00, 0.58408200E-01, 0.40847800E-01, 0.57295200E-02, -.48999300E-01, 0.20274100E+00, -.71789400E+00, -.82912400E-02, 0.20705200E+00, -.56480300E-01, -.96221800E-01, 0.10523300E-01, 0.25817600E-01, -.23283900E-01, 0.52025100E-02, 0.37552000E-01, 0.85738400E-01, 0.22529500E-02, -.18334700E+00, -.75171300E-01, -.30422100E-01, -.90523800E-01, 0.78563500E-01, 0.28383100E-01, -.27632300E+00, -.47589100E-02, -.10354800E+00, 0.68881300E-01, -.56461100E-01, -.19293800E-01, 0.22045500E+00, 0.70669200E-01, -.34022800E-01, 0.66886600E-01, -.51539800E-01, -.36161100E-01, 0.15203800E-01, -.11956200E+00, -.38174000E-02, -.73767600E+00, 0.61649100E-02, -.36140600E+00, -.23837100E+00, -.39903500E-02, -.47117300E+00, 0.24636300E-01, -.13241400E+00, -.20501100E-01, 0.13079300E+00, -.11440100E+02, -.57429700E+01, -.27805600E+01, -.56237600E+01, -.26649800E+01, 0.44631800E+01, 0.31862300E+00, -.10702400E+01, -.24449500E+02, -.39311500E+00, 0.30695500E+01, -.23035900E+01, -.12373900E+02, -.24712000E+02, -.18672800E+02, 0.10341000E+02, 0.68792000E+01, -.83577400E+01, 0.30551600E+01, -.24383100E+01, 0.41907200E+01, 0.10863900E+02, -.50145900E+01, 0.49693800E+01, 0.45964000E+01, 0.89113900E+01, -.31228200E+01, -.83557200E+01, 0.25276300E+02, -.13148200E+02, -.97641500E+01, -.12636800E+02, -.15961900E+02, -.56122000E+01, -.14062500E+02, -.13065700E+02, -.24705400E+02, -.40532100E+01, 0.26713700E+02, 0.32268100E+02, -.15906000E+02, -.10108800E+02, -.16615500E+02, 0.11471700E+02, 0.10090400E+02, -.76642400E+01, 0.51564200E+01, -.29375000E+02, 0.67037600E+01, -.42852400E+02, 0.44696700E+00, 0.39440100E+01, -.25654900E+00, -.51116600E+00, -.36394900E+01, -.34678100E+01, 0.34013100E+00, 0.20227200E+00, -.91037300E+00, -.22134600E+01, -.11682100E+01, 0.22276100E+01, -.13999100E+01, -.38214200E+01, 0.36086500E+01, -.11276900E+01, -.71781400E+00, 0.75227200E+00, -.59030700E+01, 0.15418000E+01, -.68646800E+00, -.40114800E-01, -.32987700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25113500E+00, -.38212200E+00, -.94892900E-01, -.43877400E+00, 0.56684900E-01, 0.55944500E+00, -.45021300E-01, 0.11634900E+00, 0.30589400E+01, 0.57843800E+00, -.20766100E-01, 0.23047700E+00, -.10204200E+00, 0.45828800E-01, -.16209500E+00, 0.15164400E+00, 0.47605000E+00, -.11939600E+00, 0.77103600E-01, -.18790600E+00, 0.43983500E+00, -.38410700E-01, -.18316400E+00, 0.60762700E-01, 0.18763900E-02, -.21980100E-03, 0.80503600E-01, -.26738300E-01, 0.10956800E+00, 0.10768700E+00, 0.15779800E+00, -.31220500E-01, -.31202900E-02, 0.12243700E+00, 0.15958500E+00, 0.48397000E-01, -.32549700E-02, -.19339500E-01, 0.71135100E-01, -.91621400E-01, -.13890700E+00, 0.46570800E-01, -.14190600E+00, -.59274200E-01, -.29543300E-01, -.17742300E-01, -.25241100E+00, 0.65410700E-02, 0.95896300E-01, 0.17570200E-01, -.22788900E+00, -.43010500E-01, -.15160400E+00, -.33844700E+00, 0.43173100E-01, -.26837600E+00, 0.33538100E-03, 0.31681600E-01, 0.52704400E-01, -.43578800E-02, -.26613600E-01, 0.18379800E-01, -.60298300E-01, 0.31591300E-01, 0.34904900E+00, -.13256000E+00, -.82507600E+00, -.51014100E-01, 0.20439400E-01, 0.10691100E-03, -.37586000E-01, -.34129700E-01, -.48926900E+00, 0.94460000E-01, -.12122100E+00, -.13949100E+00, -.52878700E-01, -.26701800E-01, 0.20773800E-02, 0.28291800E-01, -.41815700E-03, 0.11405800E+00, -.10639900E-01, -.20896700E-01, -.12726800E+00, 0.22104900E-01, 0.19301700E-03, -.26927100E+00, 0.85739700E-01, -.10953700E-01, 0.17136600E+00, -.54250400E-02, 0.26053900E-01, -.61997300E-01, -.66021100E-01, 0.52946900E-01, 0.12056500E+00, 0.61850700E-01, 0.14923500E+00, -.34652300E+00, 0.32880000E-01, -.21792900E-01, 0.13358000E-01, -.18451900E+00, 0.14384800E+00, -.59681600E-01, -.69482300E-01, 0.59360100E-01, -.33049500E-01, -.59791500E-01, -.33074400E-02, 0.87677900E-01, 0.46232900E-02, -.13841100E-02, -.76966400E-02, -.39593400E+00, -.14992800E+00, 0.13869400E-01, 0.39136900E-02, -.46734300E-01, -.85414500E-01, 0.60750000E-01, -.21750600E+00, -.21011100E-01, 0.36280600E-02, -.75796500E-01, -.21188400E+00, -.37417900E-01, -.17904000E+00, 0.40401900E-01, -.63323500E-01, -.29381200E-01, -.52237200E+00, 0.19945800E-01, -.11203200E-01, 0.18092500E-02, -.27541000E+00, -.25951500E-01, 0.18160200E-01, 0.48740200E-02, 0.62067700E-01, -.21132900E+00, 0.57879600E-01, 0.35370700E-01, -.15737500E-01, -.20021400E+00, 0.12746500E-01, 0.47472100E-01, 0.64769700E-01, -.14154100E+00, -.19650300E-01, -.18966100E+00, -.14582100E+00, -.88944700E-01, -.35718500E-01, -.74618300E-02, 0.71313200E-01, 0.47586600E-02, 0.28711700E-02, -.62297400E-02, 0.84508300E-02, -.19725100E+00, -.29041200E+00, 0.52726100E-03, -.26584200E-01, 0.12576700E-01, 0.18431100E-01, -.11045000E+00, -.32742300E-02, -.23516500E-01, 0.69493500E-01, -.27120400E-01, -.23622900E-01, -.11454800E+00, -.84070700E-01, 0.48606100E-02, -.72496300E-02, -.61546500E-02, 0.54015400E-01, 0.41165100E-02, 0.88937600E-01, 0.14279800E-02, -.26332600E+00, -.11447600E-01, 0.28592800E-01, 0.18980600E+00, -.41773200E-03, -.81577000E-01, -.69011400E-02, -.40735800E-01, -.42515400E-01, 0.22356500E-01, 0.34207400E+00, 0.75107700E+01, 0.40380600E+01, 0.26405300E+01, -.20861200E+01, -.17976000E+02, 0.89904700E+01, -.44849600E+01, 0.48744700E+01, -.45100400E+01, -.10310600E+02, -.14901200E+02, 0.81543800E+01, 0.63656600E+01, 0.45530200E+01, -.18488000E+02, -.11725700E+02, -.53007300E+01, 0.28576300E+01, -.17033100E+01, 0.26499200E+01, -.73159800E+00, -.25175300E+01, 0.38314400E+00, -.22531800E+01, -.22298900E+01, -.31390200E+01, 0.16586500E+02, -.13773100E+02, 0.71029600E+01, 0.15466200E+02, 0.68577600E+01, 0.11717600E+02, -.13422500E+01, 0.40102500E+01, 0.89740300E+01, 0.87747000E+01, 0.40605100E+01, 0.12800100E+02, -.37183000E+02, 0.18673800E+02, 0.19188500E+02, 0.19276000E+02, 0.68150600E+01, -.55103300E+01, 0.82853300E+01, 0.20933900E+01, 0.16115100E+02, -.30297200E+01, 0.49804700E+02, 0.76155900E-01, -.45840200E+01, 0.14559600E+01, 0.64346200E+00, 0.32011800E+01, 0.32940800E+01, 0.27876700E+00, -.14071500E+01, -.15739500E+00, 0.71046800E+00, 0.33543800E+00, -.23864300E+00, 0.48557500E+00, 0.32646900E+01, -.32915900E+01, 0.54957400E+00, 0.22722400E+00, -.83365400E+00, 0.27904000E+01, -.66338200E+00, 0.77552600E+00, 0.16022100E+01, 0.39406400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.70509500E+00, -.16040200E+01, 0.25976800E+00, -.17334100E+01, -.77351400E+00, 0.36075700E+00, -.46147800E+00, -.79955700E+00, 0.55249800E+01, -.12841800E+01, 0.76621800E-01, 0.12193200E+01, 0.20098800E+00, 0.58028200E-01, -.80462300E+00, 0.11259200E+01, 0.26446000E+01, -.11005000E+01, -.49060400E+00, -.92160600E+00, -.81872000E-01, -.40814000E+00, 0.23809500E+01, -.35757900E+00, 0.54274200E+00, -.36544600E-01, 0.85661800E+00, 0.97295700E-01, -.44530700E+00, 0.28417800E+00, 0.16998500E+00, 0.67428500E+00, -.15130900E-01, -.22998200E+00, -.29316600E+00, -.12729200E-01, 0.74687100E-02, 0.98472800E-02, -.24143800E+00, -.12761700E+00, 0.72523700E+00, 0.35607000E-01, 0.27830500E+00, 0.11849600E-01, -.18608600E-01, 0.71431100E-02, -.34154400E+00, 0.43392400E-01, 0.88947400E+00, -.19130300E+00, 0.34615200E+01, 0.18017100E+00, -.23965100E+00, -.38883200E-01, -.61876900E+00, -.12940700E+01, -.35607900E+00, 0.20711300E-01, 0.50757200E+00, 0.50877200E-01, -.94718800E-01, -.18586200E-02, 0.23528600E+00, 0.56025800E-01, 0.23270500E+00, -.26196300E+00, -.17294700E+00, 0.29494200E+00, 0.64102300E-01, 0.15072000E-02, -.20180700E+00, 0.24419900E+00, 0.94912900E+00, -.10163800E+01, 0.24283400E+00, 0.93939800E+00, -.38257600E+00, -.28886900E+00, -.62329500E-01, 0.93830400E-01, 0.99360700E-03, -.98530100E+00, 0.18165300E+00, 0.58968600E+00, 0.17153900E+01, -.73260100E-01, 0.22911600E-01, 0.13791400E+01, -.19962500E+00, -.43520600E-02, 0.23651400E+01, -.17955100E-01, 0.50804100E-01, -.56791300E+00, 0.27581500E+00, -.15176400E+00, -.23934200E+00, -.32448500E+00, -.58769200E-01, -.15361500E+01, -.11676100E+01, 0.51990700E-01, -.52529200E-05, -.29757100E+00, 0.75661700E-01, 0.79141400E+00, 0.26015600E+00, 0.29909600E+00, -.14528400E+00, 0.22735700E+00, -.96013900E-01, -.39569300E+00, 0.21355100E+00, -.66677100E-01, -.15891700E+00, -.69418400E+00, -.28730300E+00, -.42754500E-01, 0.87353900E-01, 0.80632300E+00, 0.87747500E-01, -.83553400E-01, 0.64550500E+00, 0.10281600E+00, -.47865000E-01, 0.42353500E-01, 0.15238000E+00, -.41118500E-01, 0.84078000E-01, 0.36578000E+00, 0.23919900E+00, -.24482300E+00, 0.13660000E+01, 0.18299800E-02, -.20907900E+00, -.12397200E-01, -.18293500E+00, -.18415100E+00, -.86177000E-01, -.24735800E-01, -.68727600E-01, 0.77029200E+00, 0.23620300E+00, 0.39626500E+00, 0.10461500E+00, -.18956800E+00, 0.16146400E-01, -.18294800E+00, 0.84785400E+00, -.12615000E+01, -.13934800E+00, -.49914500E+00, 0.48227700E-01, -.26905000E-01, -.10337200E+00, -.99552100E-01, -.44795200E-01, -.76084300E-02, -.22164200E+00, -.25475000E+00, -.29353500E-01, 0.32748400E-01, 0.80210900E+00, 0.12121100E+00, 0.12117600E+00, 0.35681100E-01, 0.93863900E-01, -.45855000E+00, -.18777400E-01, -.27526000E+00, 0.17743400E+00, -.32969400E+00, 0.21806200E-01, 0.42909000E+00, -.25165000E+00, -.11082500E+00, 0.19143800E-01, -.20950500E-01, 0.18342700E-01, -.88362900E-02, 0.33040300E+00, -.66804200E-01, -.76006800E+00, -.17302800E-01, 0.10485400E+01, 0.10266200E+01, 0.51778800E-01, 0.55243100E+00, -.75549100E-01, 0.10469900E+00, 0.21567600E+00, 0.27425900E+00, -.80748400E-01, 0.46460000E+01, 0.80320100E+02, 0.10677500E+02, 0.29930000E+00, 0.17836000E+03, 0.14285700E+02, -.76773700E+01, -.99667900E+02, -.72346900E+01, 0.32322600E+02, 0.16930700E+02, -.18719900E+02, -.23595800E+02, -.27884600E+02, 0.46262700E+02, 0.67233600E+02, -.75031300E+02, 0.35411400E+02, 0.31973400E+02, 0.37523800E+02, 0.13851200E+01, -.17496300E+02, 0.17291900E+02, -.36429500E+02, 0.32449600E+02, -.59679100E+01, -.80371000E+02, 0.15475200E+03, -.78478000E+02, -.73921200E+02, -.77250900E+02, -.77968300E+02, -.26804300E+02, -.85312500E+01, 0.28630300E+01, -.43252200E+02, -.47130600E+02, -.20900000E+03, 0.17951200E+03, -.89340800E+02, -.78633200E+02, -.92336800E+02, -.33724900E+02, 0.13580700E+01, -.31267900E+02, -.25130900E+02, -.79325900E+02, -.72451000E+00, -.21434900E+03, 0.35429000E+00, 0.19937100E+01, -.14270300E+02, -.12731800E+01, -.87182000E+01, -.88979700E+01, -.39599800E+00, 0.14192000E+02, 0.49639100E+00, -.37490200E+01, -.24390900E+01, 0.62120100E+00, -.83463600E+00, -.90760300E+01, 0.90275500E+01, -.39508400E+01, 0.30066800E+00, 0.26623500E+01, -.10724300E+02, 0.21807600E+01, -.25053400E+01, -.15294600E+02, -.57776600E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.85265300E+01, 0.12172100E+02, 0.36560000E+01, 0.69789800E+01, 0.54071800E-01, -.16627800E+01, 0.21725100E+01, 0.79214000E+01, -.73338100E+02, 0.32685700E+01, 0.49943900E+00, -.38455900E+01, -.24956300E+01, -.10701100E+01, 0.70054000E+01, -.69165000E+01, -.10434300E+02, 0.16951800E+02, 0.39893600E+01, 0.84813900E+01, -.11310000E+02, 0.27290900E+01, -.23297400E+02, 0.17496400E+01, 0.18011900E+00, 0.73510500E-01, 0.13680600E+01, 0.84559400E+00, -.17893800E+00, -.30787000E+01, -.24438800E+01, -.40344600E+01, -.75859700E-01, 0.44234200E+00, -.13832000E+01, 0.41941300E+00, 0.11884100E-01, -.17874600E+01, 0.19009500E+01, -.34421800E+01, 0.24665800E+01, 0.21555800E+01, 0.48708200E+01, 0.58332600E+01, 0.47286700E+00, 0.23726200E+00, -.30743000E+01, 0.55799200E+00, 0.42631100E-02, -.11217100E+01, 0.10193000E+02, -.30033200E+00, -.82582700E+01, 0.10271500E+01, -.27206100E+01, 0.86853600E+01, -.55355800E+01, -.78818700E+00, 0.51307300E+01, -.27226800E+01, 0.72900100E+01, -.80289300E+00, -.69650300E+01, 0.20866600E+01, 0.78050300E+01, -.14364200E+01, -.87463600E+01, -.53721900E+00, 0.20423500E+01, -.81243800E-01, 0.18732500E+01, 0.60033900E+01, -.16372600E+02, 0.92313900E+01, -.18030900E+01, -.54440000E+01, 0.40625300E+00, -.21395800E+01, 0.75871100E-02, -.44728900E+00, -.16071400E+00, -.44521800E+00, 0.22372700E+01, -.41457100E+01, 0.24994600E+01, 0.88620900E+01, 0.86278500E+00, -.48706800E+01, -.17962900E+01, -.10726200E+01, -.45392800E+01, 0.33934900E+00, 0.55381900E+00, 0.50712700E+01, -.12646800E+01, -.39081600E+01, -.20912700E+00, 0.20934700E+01, 0.17422400E+01, -.33249500E+01, -.33535600E+01, -.17873700E+01, 0.22495700E+00, -.18921100E+01, 0.13270200E+01, -.77457400E+00, 0.20526200E-01, 0.19077400E+00, 0.14167700E+01, 0.11056800E+01, -.93833300E+00, -.22328600E+01, 0.12369600E+01, -.39662800E+00, 0.43922300E+00, 0.24144400E+02, 0.48875100E+01, -.52845100E+00, 0.58838600E+00, -.10742000E+01, 0.30563300E+01, -.10858400E+01, -.40910500E-01, -.75137700E+00, 0.25152400E+00, 0.38938000E+00, -.38214000E+01, 0.22261400E+01, -.91084600E+00, 0.51727900E+00, -.15870800E-01, 0.49595700E+00, -.82944300E+00, -.24779200E+00, -.10276400E+01, 0.44373700E-01, 0.36153200E+00, -.42678900E+00, -.49344600E+00, 0.56715700E+00, -.66059900E-01, -.53509200E+00, 0.32694500E+01, 0.21730100E+01, 0.28664000E+00, -.31476500E+01, 0.22666700E-01, 0.31323900E+01, 0.31852200E+01, -.53401900E+01, -.11678300E+01, -.34087100E+00, 0.18761600E+01, -.57193300E+00, 0.48558900E+00, 0.53426300E-01, -.32465700E+00, -.19718600E-01, -.30640900E+00, 0.90992600E+00, 0.64986900E+00, -.63363700E+00, 0.18578200E-01, -.62674300E-01, 0.22556600E+00, 0.25480200E+00, -.18155900E+00, -.62681700E+01, 0.40217200E-01, -.25730200E+01, 0.29415600E+01, -.23402200E+01, -.18410800E+00, 0.63131500E+00, -.30106000E+00, -.13053800E+01, 0.88857900E+00, -.10287100E+01, -.10871600E+00, -.19825300E+00, 0.22978900E+01, -.81215400E+00, -.74208600E+01, -.48988600E+00, 0.28150400E+01, -.18640500E+01, -.38237500E+00, 0.81638300E+00, 0.79663200E+00, 0.70356200E+00, 0.58520500E+00, -.18797500E+01, -.19257900E+01, -.19591100E+02, -.17067900E+01, -.22738500E+03, 0.12330700E+03, -.24932300E+02, 0.19982900E+02, -.95620900E+01, 0.15174300E+03, -.10274900E+02, -.16368800E+03, -.15635800E+03, 0.11975400E+03, 0.42523800E+02, -.63390000E+02, -.17782900E+03, -.25903500E+03, 0.25412100E+03, -.12305900E+03, -.14495600E+03, -.12705900E+03, 0.10264100E+02, 0.12272200E+03, 0.48633000E+01, 0.29715300E+03, 0.18161100E+03, 0.38961000E+02, -.10117700E+03, -.15098500E+04, 0.75487500E+03, 0.38215000E+03, 0.75440900E+03, 0.19992800E+03, 0.64214200E+02, -.43860200E+02, -.77303700E+03, 0.34010500E+03, 0.20183400E+03, 0.68580500E+03, -.37176600E+03, 0.18419100E+03, -.26345600E+03, 0.17785900E+03, 0.16332800E+02, 0.44827000E+02, 0.27548000E+02, 0.21709600E+03, 0.38830100E+03, 0.94467000E+01, -.64777400E+01, -.28671100E+01, 0.81925700E+02, 0.71656800E+02, -.47561500E+01, 0.32929500E+02, 0.34974200E+02, -.60085300E+01, -.73090700E+02, -.19418800E+02, -.20535900E+02, -.11116600E+02, 0.96224600E+01, 0.14222600E+02, 0.31441400E+02, -.30138200E+02, -.19785000E+02, -.58019000E+02, 0.24861000E+00, -.37182400E+02, 0.31424000E+01, 0.92111700E+01, 0.10198300E+03, -.81181900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.41657900E+01, 0.21400100E+01, -.25966200E+00, -.53469700E+00, -.19096200E+01, -.59454100E+00, 0.47733000E+00, 0.56234400E+01, 0.80101400E+02, -.25210400E+01, -.16514500E+00, 0.51043000E+01, 0.16400200E+00, -.53848200E+00, -.27455200E+00, -.12503400E+01, -.17063100E+00, -.22995800E+01, 0.20503700E+00, 0.43931700E-01, 0.19965000E+01, 0.28472600E-01, -.77941400E+00, -.18305900E+01, -.16472700E+01, -.25899900E-01, 0.29216700E+00, 0.20937400E-01, -.22731900E+00, -.88798300E-01, 0.53594900E+00, -.13204400E+00, -.33869400E+00, -.90884000E-01, 0.40426600E-01, 0.30715300E+00, 0.10153900E-01, 0.49557200E+00, -.13152100E+01, -.29829600E+00, -.62161900E-01, -.23967500E+00, -.59401800E+00, 0.40511300E+00, 0.22212500E+00, 0.33152700E+00, -.71881200E+00, -.81254400E-01, 0.14211100E+01, -.62542400E+00, -.27867200E+00, -.20166500E+01, 0.11847100E+01, -.71469300E+00, -.29014600E+00, 0.26261100E+01, 0.12557600E+01, -.18745600E+00, 0.74011800E+00, -.13662300E+01, 0.20069000E+00, 0.17711800E-01, 0.51873900E+00, -.69444000E+00, -.64633500E+00, -.98069500E-01, -.70404400E+01, -.70869000E+00, 0.86292100E-01, 0.18156700E-02, -.24955200E-01, -.18175700E+01, 0.37625400E+01, 0.11795900E+00, 0.16022200E+00, -.41565600E+00, -.71579600E+00, 0.81223100E+00, -.30311700E+00, -.34871900E-02, 0.15431900E-03, -.40339500E+00, -.63958600E+00, -.84193100E+00, -.75914800E+00, -.10520400E+01, -.38019700E+00, 0.16339200E-01, -.17249500E+00, 0.24031100E+00, -.43214800E+01, -.42024700E-03, 0.81189000E-01, -.11145300E+01, 0.74795500E-02, 0.96906500E+00, 0.10581400E+01, 0.66577600E-01, 0.39377700E+00, 0.14341000E+01, 0.38217300E+00, 0.82407800E+00, -.70469400E-01, 0.74134500E+00, -.32832900E+00, -.17856500E+01, -.51278400E+00, -.61958000E+00, -.16386500E+00, -.47347200E+00, -.78642500E-01, 0.38356000E+00, -.18046400E+00, 0.57276700E-01, 0.12855100E+00, 0.20115800E+01, 0.99765600E-01, 0.36999900E+00, 0.22588800E+00, -.13363100E+01, 0.16723600E+00, -.21538800E+00, 0.79030400E+00, 0.51674600E-02, -.22414500E-01, -.91752400E+00, -.11266500E+00, -.12791900E+00, -.34450700E+00, -.10747500E+01, -.11588900E+00, 0.24987700E+00, 0.17764700E+01, -.23931900E-01, -.16665300E+00, 0.30455900E-01, 0.10743700E+01, 0.73700600E+00, -.53317600E-01, -.13231300E+00, 0.60390000E+00, 0.92588300E+00, -.63382200E-01, 0.40884100E-01, 0.48920100E-01, 0.91076500E+00, 0.32158800E-01, -.14279300E+01, 0.13921100E+01, -.15714200E+01, 0.57392700E-01, 0.34261800E+00, 0.13340900E+01, 0.12040200E+00, 0.48748100E-01, -.28679200E-01, 0.33923800E+00, 0.51558100E-01, 0.28462700E+00, -.47910400E+00, -.21751200E+00, -.58357700E+00, 0.17877200E+01, 0.15229200E+00, 0.59985300E+00, -.24305500E+00, 0.47991800E-01, 0.78767200E+00, 0.12479600E-01, 0.17420900E-01, -.25196500E+00, 0.29547200E+00, -.18441100E+00, -.11511700E+01, -.15092500E+00, 0.28398200E+00, 0.17019600E+00, -.10822900E+00, -.15703400E+00, 0.98190400E-01, -.34920900E+00, -.66036600E-01, 0.19801800E+01, -.15041400E+00, -.47261300E+01, -.21877300E+01, -.24372400E+00, -.93188100E+00, 0.10154000E+00, -.81870000E-01, 0.42499800E+00, -.70010600E+00, -.52953500E+00, -.11560500E+02, -.48291700E+00, 0.25196200E+00, -.75433100E+02, -.90852500E+01, 0.89839100E+02, -.44625200E+02, -.13126400E+03, -.46188800E+02, 0.37263600E+02, -.49984400E+02, 0.12303600E+02, 0.11188800E+03, 0.10329900E+03, -.69200300E+02, 0.40051700E+02, -.22292000E+03, 0.10851900E+03, 0.59611200E+02, 0.11151000E+03, -.37923900E+02, -.72027900E+02, -.22532800E+00, -.17497300E+03, -.10096900E+03, -.53354300E+02, 0.15066000E+03, 0.44096100E+03, -.22103800E+03, -.41130600E+02, -.22075700E+03, 0.39631300E+02, -.67410800E+02, 0.39494800E+02, 0.34792700E+03, -.11337300E+03, -.54215400E+02, -.39804500E+02, 0.11608600E+03, -.57020300E+02, 0.16587800E+03, -.58423700E+02, 0.40397700E+02, -.45686500E+02, 0.82809700E+01, -.25647100E+02, -.13566300E+03, -.20000800E+02, 0.27724300E+03, -.32236300E+01, -.57242200E+02, -.17232400E+01, -.11058300E+01, -.66473100E+01, -.54975700E+01, 0.94836000E+00, 0.33268800E+01, -.45416500E+00, 0.58491000E+01, -.31657900E+00, 0.69023700E+01, -.15870300E+02, -.53500300E+01, 0.39914400E+01, 0.64373700E+01, 0.90527800E+01, 0.67051700E+01, -.78234700E+01, 0.43421400E+01, -.60495700E+01, -.21099500E+02, 0.50767700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14742500E+01, -.39220100E+00, -.70047800E-01, -.14294400E+00, -.79635100E-03, -.27441200E+00, -.37543400E-01, -.83947800E-01, 0.17120400E+01, -.61042100E+00, 0.37116100E-01, 0.81665300E+00, 0.54716600E+00, -.64497600E-01, -.17846000E+00, 0.12566000E+01, 0.28176400E+01, -.14479500E+01, -.23290200E+00, -.61059100E+00, 0.20008300E+00, -.84406300E+00, 0.10382700E+01, -.68034300E+00, -.55130300E+00, -.81920800E-02, -.37303700E+00, -.89777400E-01, 0.26947500E+00, 0.22896800E+00, 0.53660800E+00, 0.16036500E+00, 0.25739000E-01, -.69991500E-01, -.16393200E+00, -.20288000E-01, 0.92637400E-03, -.44980600E-01, -.10218300E+00, -.68754500E-01, 0.18093300E+00, -.22078600E-01, -.46026100E-01, -.34128000E-02, 0.70229300E-01, 0.62076000E-01, 0.25211700E+00, -.25494500E-02, 0.53951400E-01, -.86881800E-01, -.24687700E+00, -.19101200E+00, 0.13618400E+00, 0.92069500E+00, -.11359100E+00, 0.87846100E+00, -.21108900E+00, -.18293100E+00, -.22985600E-01, -.12402600E+01, -.16666700E+00, 0.65697400E-01, -.11223100E+00, 0.30100300E+00, 0.80254800E+00, -.30425400E+00, -.16594100E+01, -.39088300E+00, -.16210000E+00, -.73267000E-03, -.36835100E-01, 0.12072300E+01, 0.13313500E+01, 0.15264300E+00, 0.18731400E+00, 0.46039300E-01, -.26873500E+00, -.27687500E+00, -.28415700E+00, 0.18012800E-01, 0.14273700E-02, -.14273900E+01, 0.58976500E-01, 0.82879200E-01, 0.62322700E+00, 0.52136600E+00, 0.11537500E-01, 0.21052200E+01, -.10873300E+00, 0.11936100E-01, 0.46868900E+00, -.11931200E-01, -.13226500E-01, -.13730800E+00, 0.16472100E-01, 0.13747900E+00, -.35896800E+00, 0.16923900E+00, 0.22749700E+00, -.52929400E+00, -.32885500E+00, 0.21640200E+00, -.60426200E-02, 0.16200300E+00, -.10136300E+00, 0.52155400E+00, -.16566800E-01, 0.23370300E+00, -.12157800E+00, -.34607400E-01, -.42595900E-01, 0.15816400E-01, -.14953000E-01, 0.49362500E-02, 0.64308800E-01, -.99948300E+00, -.14322400E-01, 0.27329200E-01, 0.55286100E-01, -.77210100E+00, -.37385200E+00, -.12639500E+00, 0.14622200E+01, 0.44462800E+00, -.29890600E-01, -.32871200E+00, 0.50033000E+00, 0.56257300E-01, 0.12418700E+00, -.35523900E+00, -.35487500E+00, 0.84901300E+00, 0.42495900E+00, 0.20214600E-01, -.27449000E+00, -.49569600E-02, 0.78425200E-02, 0.23717100E+00, -.85626500E-01, -.74533800E-01, 0.45304500E+00, 0.25261100E+00, 0.74390400E+00, -.22087700E+00, 0.37478100E-01, -.43839900E-01, 0.17890500E-01, 0.40194800E-01, 0.50233200E+00, -.11018700E+01, 0.54484700E-01, -.68442700E+00, -.51466400E+00, -.16908800E+00, -.20958600E+00, -.22285400E+00, 0.23153100E+00, 0.64844600E-02, 0.44075900E-01, -.28998000E+00, -.65890000E-01, -.36652100E+00, -.14673400E+01, 0.22456100E+00, 0.26025800E-01, -.88839800E-01, 0.25210600E+00, 0.41343300E-01, -.77478700E-01, -.51362100E-01, 0.42446900E+00, -.16484200E+00, 0.38630500E-01, 0.54855400E+00, -.35800700E+00, -.57008900E-01, -.15408600E+00, 0.13614300E+00, 0.13611300E+00, -.46473300E-01, 0.25373600E-02, -.43802900E-01, 0.58077400E+00, 0.64588800E-01, 0.10750000E+00, -.47482500E+00, 0.20366500E-01, 0.26895300E+00, -.45103600E-02, 0.20974300E+00, -.82058300E-01, 0.33500100E+00, -.12409800E+01, -.21722900E+00, 0.70275200E-02, 0.11655400E-01, -.72556500E-01, -.47086200E+02, -.62170400E+02, 0.31230000E+02, 0.35304200E+02, 0.31310600E+02, 0.26205500E+02, 0.52057700E+02, -.11161000E+02, -.94509900E+01, -.23546800E+01, 0.43035500E+02, -.10803700E+02, 0.91497500E+01, -.51213100E+01, -.70457800E+01, -.45806100E+01, 0.32660500E+02, 0.65163700E+01, 0.45811500E+01, 0.24479300E+02, 0.22470500E+01, 0.10035200E+02, -.13598400E+02, -.17413700E+03, 0.87177200E+02, 0.30461700E+02, 0.87142800E+02, 0.26075600E+02, 0.64445000E+01, 0.22360900E+02, -.56586400E+02, 0.45672000E+02, 0.96350900E+01, -.47087500E+00, -.10842900E+03, 0.53949200E+02, 0.45142600E+01, 0.53410200E+02, 0.49639700E+01, 0.24558300E+02, 0.40696200E+01, -.41449400E+02, 0.17500300E+02, 0.12985700E+02, -.41157700E+01, -.13628400E+00, 0.79433400E+01, 0.30085000E+01, 0.17659200E+01, -.49902500E+01, -.56556900E+01, -.64753200E+00, -.31779500E+01, 0.34389700E+00, 0.10491300E+01, 0.15531800E+01, 0.16902400E+01, 0.23827700E+01, -.49590900E+01, 0.54960000E+01, 0.92900100E+00, -.15327900E+01, -.16036500E+01, 0.67322600E-01, -.23584800E+01, 0.12349600E+01, 0.20098900E+01, -.44015500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.76456100E+01, 0.55453000E+01, 0.19662700E+01, 0.36077600E+01, 0.81559300E+00, -.15768900E+01, 0.20303100E+01, 0.44154800E+01, -.38138900E+02, 0.30991700E+01, -.10438900E+00, -.33159700E+01, -.20111800E+01, -.77847000E+00, 0.47784000E+01, -.42625900E+01, -.73665400E+01, 0.17918900E+02, 0.31173200E+01, 0.48449000E+01, -.67749700E+01, 0.29365200E+01, -.49396400E+01, 0.29430300E+01, 0.20482600E+01, 0.62805500E-01, 0.64685700E+00, 0.73709400E+00, -.92105300E+00, -.14607300E+01, -.50449300E+00, -.10862600E+01, 0.97276700E-01, 0.24732000E+00, -.37805600E+00, -.87563700E-01, 0.86232400E-02, -.12220600E+01, 0.13491700E+01, -.92312200E+00, -.11603000E+01, 0.14399700E+01, 0.51717900E+01, 0.41570800E+01, -.54850600E+00, -.38951500E+00, -.10911100E+01, 0.47910800E-01, 0.10086200E+01, 0.55583300E+00, 0.10153300E+01, 0.17424800E+01, -.12929200E+01, -.26140500E+01, 0.22419300E+01, -.80088100E+00, 0.13995600E+00, 0.82982600E+00, 0.16597000E+01, 0.90752400E+01, 0.20689300E+01, -.61809700E+00, -.98590500E+00, -.10576800E+01, -.68464200E+00, 0.10152400E+00, 0.51649900E+01, 0.26542100E+01, 0.86863300E+00, -.19631700E-02, 0.18881400E+00, -.75457500E+00, -.10271700E+02, 0.64069400E+00, -.22100500E+01, -.11416200E+01, 0.12652900E+01, 0.32625000E+00, 0.63804700E+00, -.20857600E+00, -.41786700E-02, 0.41783300E+01, -.13151100E+00, -.13108100E+01, -.19072100E+01, 0.20443000E+01, 0.23573300E+00, -.10662000E+02, 0.10117600E+01, -.16177100E+00, -.47567600E+01, 0.78895300E-02, 0.53581900E+00, -.31054400E+00, -.16542700E+00, -.12285800E+01, 0.25034400E+01, 0.93679900E+00, 0.10260600E+01, -.42854900E+01, -.27558100E+01, -.46319500E+00, 0.37982400E-01, -.11249300E+01, 0.15206300E+01, -.20544800E+01, -.61985100E+00, -.39596500E+00, 0.59760700E+00, 0.58065300E+00, -.31301400E+00, -.63221600E+00, 0.47423500E-01, -.16387700E-01, 0.24540500E-01, 0.73891700E+01, 0.98594000E+00, -.57503200E-01, 0.15138600E+00, 0.32723600E+01, 0.19547900E+01, 0.90672600E-01, -.48226600E+01, -.13950200E+01, 0.21291900E+00, -.62561000E-01, -.36299900E+01, 0.17506400E+00, -.34735700E+00, 0.69572500E+00, 0.70549500E+00, -.24366600E+01, -.13324800E+01, -.30448100E+00, 0.56577900E+00, 0.19992700E-01, 0.14014100E+01, 0.37925100E+00, 0.23233600E+00, 0.50851400E-01, -.12467800E+00, 0.21744600E+00, -.17976800E+01, 0.19200100E+00, -.23874400E+00, -.41973100E+00, -.44186000E-01, -.71633800E+00, -.92574100E+00, 0.15445900E+01, 0.81033700E-01, -.15680300E+01, 0.22724500E+01, 0.38756000E+00, -.28769600E+00, -.19416400E+00, -.74019400E+00, -.41563800E-01, -.48219500E+00, 0.24638800E+00, -.96452300E-02, 0.13426000E+01, 0.45639900E+00, -.37663400E+00, 0.36860700E+00, -.47209400E+00, -.89270500E+00, -.15354900E+01, 0.26259900E+00, -.32087600E+00, -.44712900E+00, -.64985200E+00, 0.89898000E+00, 0.46127300E+00, 0.87326000E+00, -.70880600E+00, -.85917500E-01, -.31296600E+00, -.27629500E+00, -.45258200E-01, -.91695400E+00, -.16766500E+00, -.10714100E+02, -.15955200E+00, -.70243600E+01, -.18052700E+01, -.18996700E+00, -.24436900E+01, 0.26554400E+00, -.71496900E+00, -.51735000E+00, 0.95449500E+00, 0.35421200E+01, -.81278000E+01, -.47687700E+00, 0.14802600E+00, -.33473100E+00, 0.28412000E+01, 0.46369000E+03, -.23711900E+03, -.18403600E+03, -.23396700E+03, -.19295100E+03, -.35603200E+03, 0.75824900E+02, 0.75496300E+02, -.13241400E+03, -.33673200E+03, -.13934800E+03, -.38434400E+03, 0.19214600E+03, 0.51532000E+02, 0.19224700E+03, -.77155100E+01, -.10507500E+03, 0.10497000E+03, 0.15516100E+01, 0.53862900E+02, -.12609700E+03, 0.36438900E+03, 0.69161500E+03, -.33468500E+03, 0.21834500E+02, -.33675700E+03, 0.95683100E+02, -.12000400E+03, -.11646600E+03, 0.27107600E+03, -.13888700E+03, -.23681200E+02, 0.70069000E+03, 0.75977500E+03, -.37436200E+03, 0.77511700E+02, -.39553000E+03, 0.60986000E+02, -.15858200E+03, 0.31281000E+02, 0.50056800E+03, 0.59402200E+02, -.85926200E+02, 0.10032100E+03, 0.22002200E+01, -.44755000E+02, 0.19638400E+02, -.54329900E+01, 0.26409900E+02, 0.28996600E+02, 0.59478100E+01, -.19207500E+02, -.19283000E+02, -.20752700E+02, -.17767800E+02, -.42126900E+01, -.15883600E+02, 0.25800100E+02, -.28528500E+02, -.11219900E+02, -.28374700E+02, 0.68219500E+01, 0.40237700E+01, 0.19397800E+02, -.11688100E+01, 0.36209300E+02, 0.76755300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42276900E+01, 0.35433100E+01, -.26487100E+01, 0.78849900E-01, -.53510300E-01, 0.51918800E+01, -.12124800E+01, -.20692000E+01, 0.34276500E+02, 0.41540800E+01, -.37713500E+00, 0.46763800E-01, 0.97655300E+00, -.86416500E-01, -.40778100E+01, -.88479500E+00, 0.15921600E+01, -.89250400E+01, -.17235200E+01, -.40779700E+01, 0.37270000E+01, -.33739700E+00, 0.21767500E+01, -.92276400E+00, -.20584100E+00, 0.35202300E-01, -.28775700E+00, 0.89481800E-01, -.53389400E+00, 0.45799000E+00, -.14366200E+01, 0.82149700E+00, 0.26209600E-01, -.44150300E+00, -.18864700E+00, 0.22251900E+00, 0.26003200E-02, 0.90231700E-01, -.21089500E+01, -.86781400E-01, 0.17362100E+01, -.11903900E+01, -.35303500E+01, -.29251700E+01, 0.37893700E+00, 0.18551900E+00, -.39712800E+00, 0.23992600E-01, 0.35519400E+00, -.97157200E+00, 0.11284500E+02, 0.50513900E+00, 0.19843900E+00, 0.68356500E+00, -.25831000E+01, -.50831300E+01, 0.70481900E+00, 0.39131100E+00, -.61466500E-01, 0.71523300E+00, -.31470600E+01, 0.46494900E+00, -.38537200E+01, 0.10946700E+01, 0.46140200E+01, -.89315000E+00, -.16604500E+02, -.28501700E+01, 0.37009700E+00, 0.13606700E-02, -.93761300E-01, 0.10994000E+01, -.70050100E+00, 0.14078800E+01, -.14627300E+01, 0.89909100E+00, -.56813800E+00, -.74933600E+00, -.35813900E+00, -.89248300E-01, 0.39664700E-02, -.14569100E+01, 0.54147400E+00, 0.60708300E+00, -.30779900E+00, -.32999300E+00, 0.15406700E-01, 0.27684700E+01, -.27636700E+00, 0.34947000E+00, 0.19809400E+01, 0.23438500E-01, -.32805600E+00, -.57688500E+00, 0.12223600E+01, -.17616500E+01, 0.18792900E+01, 0.52065700E+00, -.14597500E+01, 0.18839600E+01, 0.33989000E+01, -.22449600E+00, -.25782100E+00, 0.18034000E+01, -.20179100E+01, -.23456500E+01, -.28733500E+00, -.14457700E+01, -.42129000E+00, -.48178100E+00, 0.26975800E+00, 0.50041200E+00, 0.26320500E+00, -.80963100E-01, -.28855400E+00, -.75719400E+01, -.27797300E+01, 0.40828400E+00, 0.17417500E+00, -.31300900E-01, -.56788300E+00, -.22040000E+00, 0.12085300E+01, -.24277900E-02, -.71000500E-01, -.13151400E+01, -.31539400E+00, -.12645500E+00, -.60300500E+00, -.92439800E+00, -.75968300E+00, 0.47294700E+00, 0.64100200E+00, -.89161600E-01, -.10203500E+01, -.43310900E-01, 0.35065200E+01, 0.73589900E+00, -.10822700E+01, 0.13335000E-01, 0.56317800E-01, 0.80680000E+00, -.45671600E+00, -.23896600E-01, 0.71754700E+00, 0.76720300E+00, -.27993000E-01, -.73076300E+00, 0.12077000E+01, -.16306400E+00, -.11553400E+00, 0.12109600E+01, 0.20745600E+01, -.60960200E-01, 0.25317400E-02, -.43942000E+00, 0.11699500E+00, -.39707100E-01, -.26747600E+00, -.30005800E+00, 0.40607100E-01, -.30293200E+00, 0.21295200E+01, 0.29049700E+00, 0.91751700E+00, -.62122900E+00, 0.67717500E+00, 0.23654700E+01, -.22844500E+00, 0.49271800E+00, 0.59520000E+00, 0.74581300E+00, -.30735600E+00, -.33138400E+00, -.93107000E+00, -.81264000E-01, 0.64218300E+00, -.13059100E+00, 0.24305100E+00, -.14115500E-01, -.13701000E+01, -.10828000E+00, -.17659100E+01, 0.83500300E-01, -.46241900E+01, -.26144000E+01, -.25686600E+00, 0.31034400E+00, 0.17595800E+00, 0.32869900E+00, 0.25469300E+00, -.74585600E+00, 0.29510800E+01, -.16592900E+01, -.19621600E+00, 0.29141200E-01, 0.88693800E-01, 0.17625200E+01, 0.31837300E-01, 0.80793500E+01, 0.98577600E+02, -.23395300E+00, 0.39192100E+02, 0.93216400E+02, -.10092100E+02, 0.69568400E+02, 0.44332000E+02, 0.37942200E+02, -.62938500E+01, 0.28879800E+03, -.14081300E+03, -.55689500E+02, -.14439900E+03, -.17017100E+03, -.26357600E+02, -.76679400E+02, 0.10364500E+02, -.49765600E+02, -.44313300E+02, -.69473400E+02, -.19384300E+03, 0.97444700E+02, 0.18207300E+01, 0.96244800E+02, -.32331200E+02, 0.21115400E+02, 0.45311900E+02, -.68472800E+02, 0.72918000E+02, 0.21648700E-01, 0.24115600E+03, 0.12430300E+03, -.63401000E+02, -.31308500E+03, -.65814200E+02, -.70918100E+02, -.30573300E+02, -.18953500E+02, -.76031400E+02, 0.31546200E+02, -.20692000E+02, -.49114400E+02, 0.59848000E+00, 0.24035700E+02, -.49712800E+01, -.18702900E+01, -.42967200E+01, -.36081600E+01, 0.33557900E+00, 0.50872800E+01, -.24064400E+01, -.15401100E+01, -.10408300E+01, 0.20566500E+02, -.11911000E+02, -.33616400E+01, 0.33590700E+01, -.92962800E+00, -.54191700E+00, 0.85392200E+01, 0.11930400E+01, -.55013600E+00, -.17267000E+02, 0.11075600E+02, -.18564600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.38876800E+01, -.58497200E+01, 0.48412400E+01, -.42995100E+01, 0.49635300E+00, 0.39354000E+00, -.65574000E+00, -.78027600E+01, -.80342600E+02, -.91171300E+00, 0.44572900E+00, -.31149000E+01, -.16889600E+00, 0.74067700E+00, 0.93597600E+00, 0.29114100E+01, 0.13532800E+01, 0.37447300E+01, -.21786400E+00, 0.67275100E-01, -.38750000E+01, -.21137500E+00, 0.54061300E+01, -.84232700E-01, -.75537800E+00, 0.18727000E-01, -.54189600E+00, 0.18717700E+00, -.12039100E+01, 0.67054200E-01, 0.37523100E+00, 0.19192600E+01, 0.27839100E+00, -.24591800E+00, -.10306700E+01, 0.39899500E-01, -.96111000E-02, -.14016500E+01, -.43358900E+00, -.10268400E+00, -.35980700E+01, 0.28939800E+00, 0.18244800E+01, 0.18142900E+01, -.13823900E+00, -.32628000E+00, 0.74604800E+00, -.29374900E+00, -.14123100E+01, 0.69788000E+00, -.38903700E+01, 0.17154600E+01, 0.11083000E+01, 0.19622600E+00, 0.21111000E+01, 0.12052500E+00, -.41694200E+00, 0.13418400E+01, -.54732000E+00, 0.14727900E+02, -.30344700E+01, -.47636600E+00, -.17008300E+01, -.11471200E+01, -.72966100E-01, -.24545400E+01, -.73939600E+01, 0.18293300E+01, 0.41733300E+00, 0.47079400E-02, 0.58592100E+00, 0.29523800E+00, 0.32732600E+01, 0.44980800E+00, 0.26167600E+01, 0.17403500E+01, -.65849800E+00, -.12879800E+01, 0.14132200E+00, 0.91495400E+00, 0.17396200E-02, -.48806400E+00, 0.17708800E+00, 0.36904700E+01, -.15512900E+01, 0.71097200E-02, 0.12427100E+00, -.49956400E+01, 0.86242400E+00, -.20250300E+00, 0.38802500E+01, 0.10038200E+00, -.13830200E+00, -.12748300E+00, 0.20453400E+00, 0.55430300E+00, -.95531500E+00, 0.53855300E+00, 0.58216400E+00, -.16983600E+01, -.68898600E+00, -.12845400E+00, -.14972900E+00, 0.83988800E+00, -.23327300E+01, 0.18848300E+01, -.73170300E+00, 0.16816100E+01, -.13440900E+00, -.37542000E+00, -.42840700E-01, -.17107400E+00, 0.21516200E+01, -.68012100E+00, 0.50430900E-01, -.10996100E+02, 0.74730400E+00, -.48302200E+00, 0.81413800E+00, 0.15891200E+01, -.40297000E+00, 0.60171100E+00, -.55443200E+01, -.34280100E+00, 0.48869100E-01, -.86175800E+00, -.34387900E+00, -.53348700E+00, -.10760600E+01, -.61299800E+00, -.95737100E+00, -.16443700E+01, -.10163100E+02, -.32857800E+00, -.15139600E+00, 0.77596800E-01, 0.28807300E+00, 0.50582000E+00, -.62929800E+00, 0.22193400E+00, 0.15218600E+01, -.11702600E+01, 0.28826000E+01, -.57509600E+00, -.14326200E+00, -.19807100E+01, 0.15294500E-02, 0.20502000E+01, -.35291800E+00, 0.93847900E+00, -.32275700E-01, -.10801800E+01, -.24438000E+01, 0.51116600E+00, -.87119100E-01, 0.21268100E+00, -.76291800E+00, -.97857100E-02, -.63097200E-01, 0.17486800E+00, -.24999400E-01, 0.22613200E+01, 0.26816400E+01, -.46868200E+00, -.55361500E+00, 0.51195100E+00, -.22941200E+00, -.19020500E+01, 0.65783400E-01, 0.25633600E+00, -.10975300E+01, 0.12017100E-01, -.37506100E+00, -.11283200E+01, 0.10942700E+01, 0.38175000E+00, -.31212300E-01, -.81681600E-01, -.63590300E+00, 0.10156100E+00, 0.10145800E+01, 0.33721700E+00, -.11340300E+01, 0.48463900E+00, 0.26674200E+01, 0.33189800E+01, 0.32813300E+00, -.23738700E+01, -.38154900E+00, -.10795000E+01, -.46895800E+00, -.53197100E+00, 0.97987700E+00, 0.17503000E+02, 0.63685400E+00, -.27673500E+00, -.36822000E+00, -.19720100E+01, 0.23583000E-01, 0.20988300E+00, -.36462300E+03, 0.58590400E+00, 0.16253800E+02, -.26959600E+02, -.23762700E+02, -.54066800E+02, -.37056800E+02, 0.67290500E+02, 0.62398700E+02, -.12165700E+03, 0.58595700E+02, 0.98406100E+01, 0.60822400E+02, 0.38701800E+02, -.29371600E+02, 0.27026700E+02, -.40786100E+02, -.11417600E+02, -.10987000E+02, 0.81419300E+01, 0.16200900E+03, -.82753700E+02, -.89590800E+02, -.80594300E+02, -.59337200E+02, 0.48491900E+02, -.17141700E+02, 0.40610400E+02, -.74615800E+02, -.27192000E+01, -.15171000E+02, -.68247300E+02, 0.32292000E+02, 0.13262500E+03, 0.41212300E+02, 0.82130200E+01, 0.58128400E+02, -.12885000E+02, -.48237500E+02, -.79101300E+02, 0.38068900E+02, -.66370400E+02, 0.40673600E+01, 0.14696800E+02, -.36801700E+01, -.62085500E+01, -.19356800E+02, -.21672000E+02, 0.10741300E+01, 0.38101200E+01, 0.27798200E+01, -.10735700E+01, -.23762900E+01, 0.99422500E+00, -.33249800E+00, -.20417300E+02, 0.21298500E+02, -.21438000E+01, 0.35822400E+01, 0.37132900E+01, 0.23732000E+00, 0.80305400E+01, -.50900900E+01, -.12939400E+02, -.11165400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54362800E+01, -.55548700E+01, -.10525500E+01, -.69392000E+00, 0.42517200E+01, 0.22784000E+01, -.91602400E+00, 0.19164500E+01, 0.98080700E+02, -.88577300E+00, -.34736100E+00, 0.12606300E+01, 0.19276700E+01, -.89134900E-01, -.65917000E+00, 0.67712500E+01, 0.63435500E+01, 0.26875000E+01, 0.61610600E+00, -.79032600E+01, 0.70374500E+01, -.11942800E+00, 0.88618200E+01, 0.68930900E-01, -.19988000E+01, -.42829800E+00, -.89596800E+01, -.15168600E+01, 0.29791100E+00, -.58935600E+00, -.42156900E+00, 0.44160800E+00, -.16046200E+00, 0.30151700E+00, -.17451400E+00, -.32540800E+00, 0.34889400E-01, 0.22716200E-01, -.19641100E+01, 0.48771300E-01, 0.89249400E-02, -.75346300E+00, -.18809400E+01, -.10944100E+01, -.39826700E-01, -.13569200E+00, 0.18348000E+01, 0.52015800E-01, -.14354900E+01, -.89307100E-01, 0.80904400E+01, 0.15430400E+01, 0.11766300E+01, 0.11856900E+01, -.64552100E+00, 0.68151400E+01, 0.12635200E+01, 0.59908900E+00, 0.18516100E+01, 0.13898300E+02, -.71534300E+00, 0.35587300E+00, -.24807800E+01, -.37614200E+00, 0.45515900E+01, -.43495400E+01, -.95033200E+01, -.89532500E+00, 0.91710100E+00, 0.38454100E-02, 0.38803900E+00, 0.10045400E+01, 0.15177800E+01, 0.27280300E+01, 0.25162700E+01, -.94014900E+00, 0.31609800E-01, -.18957500E+01, 0.14863600E+00, 0.41095900E+00, 0.60523200E-02, 0.78209300E+00, 0.83240200E+00, -.38130500E+00, 0.18389900E+01, 0.32052600E+01, 0.29742100E+00, -.10865900E+02, -.67491100E-01, -.19202700E+00, -.17822600E+00, 0.98547900E-01, 0.82680400E+00, -.49408500E+00, -.10137500E+01, -.36897500E-02, 0.81322100E+00, 0.41698000E+00, 0.14620300E+01, -.26539100E+01, 0.13095100E+01, -.61654400E+00, -.19524000E+00, -.30772300E+00, 0.24293300E+01, 0.13948000E+01, 0.51791200E+00, 0.75502700E-01, 0.17424600E+00, 0.25335300E+00, -.11321900E+00, -.62258600E+00, 0.97334200E-01, -.25497500E-01, -.37336000E+00, -.69432600E+00, -.12664100E+01, 0.39679800E-03, -.98115100E-05, 0.41298100E+00, 0.34178300E+00, -.42909900E-01, -.20643300E+01, -.31050700E+00, -.17650300E+00, -.11756100E+01, -.24907300E+01, 0.64287000E+00, 0.10570900E+01, -.11553000E+01, -.83661400E+00, 0.69102000E+00, -.21521800E+01, 0.10940200E+00, -.31943700E-01, -.18088600E+00, -.20436400E+00, 0.74367800E-01, -.50135900E+00, -.18100300E+00, -.13537600E+01, -.32582200E+00, -.19057700E+01, 0.45882900E+00, 0.16453400E+00, 0.60159700E+00, -.15497600E+00, -.61420200E+00, -.17596700E+01, 0.29873500E+01, 0.28721200E+00, 0.12304200E+01, 0.12904200E+01, 0.38726400E+00, -.98319800E-02, -.12556100E+00, -.76155100E-01, -.14584200E+00, 0.18218800E+00, -.61235300E+00, -.27150400E+00, -.66861700E+00, -.14796200E+00, 0.64151100E+00, 0.60119300E+00, -.74238800E+00, 0.30248400E+00, 0.26584900E+01, -.19640000E+00, 0.11345300E+01, -.11263100E+01, -.90540100E-01, -.31897600E+00, -.94612400E+00, -.87511700E+00, 0.31135500E+00, -.92148400E-01, 0.48034900E+00, -.26746800E+00, -.32640200E+00, 0.45055200E+00, 0.31759100E+00, 0.23346600E+00, 0.70494500E-01, -.21456900E+01, 0.16702200E+00, 0.81703200E-01, 0.36715400E+00, -.13918800E+00, -.28520100E+00, -.32669900E+00, -.59334600E+00, -.30246300E+01, 0.83251500E+01, 0.58838300E+00, -.20118800E+00, -.22015700E+00, 0.18754000E+01, 0.17444700E-01, 0.16662000E-01, 0.14385300E+00, 0.32209200E+02, -.20757100E+02, -.62505000E+02, 0.94657100E+01, -.40485300E+02, -.81276700E+02, -.50622800E+02, -.25951800E+02, 0.52281500E+01, -.71353500E+00, -.11642700E+02, -.27218600E+01, -.71772900E+02, -.50904700E+02, 0.18860900E+02, 0.25927700E+02, 0.45708200E+01, -.51155800E+02, 0.43697300E+02, 0.32262700E+03, -.16174600E+03, -.81394900E+02, -.16066100E+03, -.50376900E+02, 0.15022600E+02, -.50593500E+02, 0.12647100E+03, -.52190400E+02, -.67610700E+00, 0.14666900E+03, 0.40475900E+03, -.20083600E+03, -.95698900E+02, -.21615200E+03, -.67090800E+02, -.39300200E+02, -.43991700E+02, 0.12896600E+03, -.20990600E+02, -.21971000E+02, -.10448100E+02, 0.20245700E+00, 0.23632100E+02, 0.63735400E+01, -.83790800E+01, -.16863300E+02, -.16199400E+02, 0.68607400E+00, -.61604200E+01, -.10403100E+02, -.11903100E+02, -.12775400E+02, 0.76119800E+01, -.88259200E+01, -.16974800E+02, 0.16008300E+02, -.10627800E+02, -.84533000E+01, 0.89574300E+01, 0.26148500E+01, 0.19057000E+02, -.15469800E+02, 0.15141100E+02, -.32685700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39576500E+01, 0.66978200E+01, 0.13875200E+01, 0.37275400E+01, 0.15448800E+01, -.20661700E+01, 0.12944300E+01, 0.64739800E+01, 0.45243900E+01, -.16276600E+00, -.19520700E+01, -.26703800E+01, -.54914100E+00, -.19228300E+00, 0.16169300E+01, -.29639400E+01, -.43254400E+01, 0.16962900E+01, 0.37275000E+00, 0.11770900E+01, -.90338200E+00, 0.17247300E+01, -.33044500E+01, 0.14267700E+00, 0.17685300E+00, 0.30218100E-01, -.28462700E-02, 0.69123700E-01, -.52890600E+00, -.34581600E+00, -.87623300E+00, -.42077300E+00, 0.99204900E+00, 0.11722400E+00, 0.64272800E+00, 0.62560100E+00, -.35397700E-01, -.15828100E+01, -.27558100E+01, 0.16602000E+00, -.91497100E+00, -.27023500E-01, -.32034700E+01, -.15499900E+01, 0.14818600E+00, 0.38439100E-01, 0.55559000E-01, -.33817400E-01, -.52713400E+00, -.36133300E+00, 0.12076100E+01, -.22976200E+00, -.65967600E+00, -.10676400E+01, 0.13025900E+01, -.10261600E+01, 0.10023400E+01, 0.28934600E+00, 0.36097600E+00, 0.65596200E+01, 0.12865700E+01, 0.62749200E-02, 0.22318800E+00, -.12658200E+01, -.88954900E+00, 0.97574500E-01, -.81097100E+00, -.24165600E+00, 0.15700200E+00, -.11152900E-03, 0.14522100E-01, -.85566500E+00, 0.10327700E+01, 0.23184400E+01, -.81778000E+00, -.10818100E+01, -.24304100E+00, 0.26395300E+00, -.11978800E+00, -.12551400E+00, -.10595500E-03, 0.13466900E+00, -.16951900E+00, -.10903400E+01, 0.31749900E+00, 0.43967600E+00, -.15576600E+00, -.36725800E+01, 0.62000900E+00, -.20951700E+00, -.12999700E+01, -.55171300E-02, 0.24597900E+00, -.24752800E+00, -.81412300E+00, 0.41114100E+00, 0.36217900E+00, -.14924300E+00, 0.12086700E+01, -.13488600E+01, 0.22845000E+01, -.34906500E+00, -.31383600E-01, 0.21319900E+00, 0.12740600E+01, -.39318000E+00, 0.95155000E-01, -.42184000E+00, 0.85867800E-01, -.24572900E+00, 0.18869800E+00, 0.44162900E+00, -.13324800E+01, 0.42203200E+00, -.11831400E+00, -.45453100E+01, -.16084700E+01, 0.55907000E+00, -.33505100E+00, 0.14838100E+00, -.12310200E+01, -.37453700E-01, -.36961200E+00, -.18343100E+00, 0.55730000E-01, -.97430200E-02, -.90473500E+00, 0.19501000E+00, 0.14440800E+01, -.42277100E+00, -.10604100E+00, -.51245900E-01, 0.26048300E+01, -.69723700E-01, 0.21748700E+00, 0.16262200E-01, 0.97072800E+00, 0.68029300E+00, -.14364500E-01, 0.76525100E-01, 0.54204500E+00, 0.16392800E+01, -.15454500E+01, -.15172000E+00, 0.83380900E-01, 0.14324100E+01, 0.99198800E-02, -.76667000E+00, 0.74256100E+00, -.14707500E+01, 0.13875900E+00, 0.18704000E+00, -.30616600E+00, -.32279700E+00, -.18024500E+00, -.10788700E+00, 0.38523100E+00, -.37188500E-01, 0.15828800E+00, -.12380500E+00, 0.99892000E-01, -.13402800E+01, 0.13522200E+01, 0.33508800E-01, -.20022100E+00, 0.40784400E-01, 0.12194400E-01, -.16767800E+00, -.32357400E-01, 0.11565500E+00, 0.29411900E+00, 0.15548900E+00, 0.89922000E-01, 0.18022900E+01, 0.43448900E-01, -.43133100E+00, -.67786000E+00, 0.48813800E+00, 0.49596000E+00, -.99473800E-01, -.44782600E+00, -.20153400E+00, -.70463000E+00, 0.16198500E+00, -.32069500E+01, -.20554600E+01, -.24208200E+00, -.21767600E+01, 0.40442000E+00, 0.24021500E+00, -.27145700E+00, 0.70173300E-01, -.61763600E+01, -.90127000E+01, -.26549200E+00, 0.23235200E+00, -.74384200E-01, 0.25895700E+01, 0.57888500E+00, -.17157500E+00, 0.18571000E+00, -.62333100E-03, 0.12045500E+03, 0.21523600E+03, -.12887800E+03, -.30768900E+02, -.74929000E+02, 0.20857300E+03, 0.65000300E+02, 0.12237700E+03, -.61669500E+02, 0.16133000E+01, -.61176800E+02, 0.39951500E+01, -.58355900E+02, -.63341200E+01, 0.46046200E+02, -.10949200E+02, -.31013700E+02, -.18805000E+03, 0.15862200E+03, -.87091500E+02, -.10291400E+03, -.84831500E+02, -.16399700E+03, 0.24861800E+02, -.31172700E+02, 0.95974400E+02, -.97553300E+02, -.18111700E+02, 0.28518500E+03, 0.42245900E+03, -.21002800E+03, -.22186600E+03, -.20035500E+03, -.40379000E+02, 0.73824500E+02, -.14399300E+03, -.38141800E+02, -.29708700E+03, 0.53496600E+02, -.14112900E+03, -.75268300E+00, 0.47625300E+02, -.18488800E+02, -.34274900E+01, -.34748400E+02, -.34337000E+02, 0.70447100E+00, 0.18725700E+02, 0.11649600E+02, 0.11186300E+02, 0.92186800E+01, -.46512400E+01, 0.72304800E+01, -.34618100E+02, 0.34197200E+02, 0.10376000E+02, 0.23091100E+02, -.58322500E+01, 0.73517600E+00, 0.57385800E+01, -.32308200E+01, -.15755000E+02, -.39060000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22907600E+01, -.57670300E+01, 0.11149000E+01, -.49327200E+01, -.13811300E+01, 0.18785500E+01, -.18827100E+01, -.94320500E+00, 0.14898400E+02, -.34514600E+01, 0.13932200E+00, 0.20195600E+01, 0.98821100E+00, -.55072200E-01, -.29774600E+01, 0.15534300E+01, 0.47641200E+01, -.63570900E+00, -.12057300E+01, -.19216800E+01, -.11109000E+01, -.44689400E+00, 0.46719900E+01, -.29506000E+00, 0.23150400E+01, -.86017000E-01, 0.28346500E+01, 0.34160000E+00, -.12667700E+01, 0.76993100E-01, -.88549700E+00, 0.14520800E+01, 0.18585300E+00, -.19770900E+00, -.62922300E+00, 0.18668800E+00, 0.69178200E-02, -.12443200E+00, 0.29174300E+00, -.97385800E+00, 0.11700200E+01, 0.24110800E+00, -.93059100E-01, 0.33056400E+00, 0.39870200E+00, 0.13919700E+00, -.55455500E+00, 0.48475800E+00, 0.57085300E-01, -.75693700E+00, 0.57057900E+01, 0.76463300E+00, -.24226100E+01, -.10901200E+01, -.20097500E+01, -.29657600E+01, -.28257200E+01, 0.11503800E+00, 0.13474300E+01, 0.16217300E+01, 0.98656700E+00, -.42039100E+00, -.39495600E+00, -.32949600E+00, -.62197400E+00, 0.11154300E+00, -.14208700E+01, 0.15146000E+01, 0.57358100E+00, 0.75855600E-03, -.38147900E-01, 0.53678600E+00, -.34152700E+01, -.17816100E+01, -.14592600E+01, 0.21803900E+01, -.26055200E+00, -.80729500E+00, -.27584200E-01, -.10916900E+00, 0.24279300E-02, -.70281400E+00, 0.14206400E-02, -.14000000E+00, -.14000300E+01, -.26789000E+00, 0.56819900E-01, 0.23277000E+01, 0.10429800E+01, 0.27244500E+00, 0.20303500E+01, 0.22737100E-01, -.66517700E+00, -.57599000E+00, 0.18559600E+01, -.88424500E+00, -.94634800E+00, 0.79903800E+00, 0.15854500E+01, 0.83225000E+00, -.18981400E+01, 0.12916000E+00, -.13070000E+00, -.31551000E+00, -.21245700E+00, 0.86071400E+00, 0.17669900E+00, -.34273000E+00, 0.31610200E-01, 0.63555400E+00, -.12510700E+00, -.67014500E+00, 0.33559600E+00, -.10372800E+00, -.54368600E+00, 0.55622300E+01, 0.77468400E+00, -.35806200E+00, 0.10087500E+00, 0.88659800E+00, 0.81114400E+00, 0.13154900E+00, -.11865800E+01, -.24608300E+00, -.65959300E-01, 0.48159300E+00, 0.15313000E+00, -.18146000E+00, -.65540200E+00, -.92247900E+00, -.39079200E+00, -.18282100E+01, -.59231000E+01, -.21799000E+00, 0.32929600E+00, 0.30488500E-02, 0.13969500E+01, 0.13343200E+01, 0.16776500E+00, -.33331500E+00, -.39820000E+00, 0.14264200E+01, 0.66634200E+00, -.28027300E+00, 0.18472700E+00, 0.20649900E+01, -.10722100E+00, -.24892000E+01, -.19275300E+01, 0.39746400E+01, 0.17957900E+00, 0.14955000E+01, 0.51554400E+01, 0.12923200E+01, 0.48824100E+00, 0.28914000E+00, -.21221800E+01, -.24971300E-01, -.52009800E+00, -.81991300E+00, -.10170500E+00, 0.94391200E+00, 0.42208000E+01, -.11209500E+00, 0.59177500E+00, -.14652700E+01, -.34353800E+00, 0.34343900E+00, 0.12001700E+00, 0.30913600E+00, -.82038600E+00, 0.20158800E+00, -.81895300E-01, -.36478300E+00, 0.67337400E-01, 0.27481000E-02, -.68319300E-01, -.59307000E-01, -.13248500E+00, 0.12630100E+00, 0.25167700E+00, 0.44093600E+00, 0.20005400E+01, -.48046600E+00, -.36468100E+00, -.18364400E+00, -.23362200E+00, 0.54399300E+00, 0.47692700E-01, 0.53779200E+00, 0.36990600E+00, -.10138300E+01, 0.19979900E+01, 0.61510200E+01, 0.29174500E+00, -.13224700E+00, 0.19970300E+00, -.10453000E+01, -.27131100E+00, -.12445500E+00, 0.29077600E+00, -.28730700E-01, -.30217200E+00, -.42336700E+02, 0.56576900E+02, 0.10544500E+03, 0.74066700E+02, -.66896200E+02, -.10822500E+02, 0.13415100E+03, -.65117500E+02, -.47289300E+02, -.67047200E+02, -.91091100E+02, -.25828200E+02, -.92703900E+02, -.12881300E+03, -.87836100E+02, -.49887700E+02, 0.42907600E+02, -.16849500E+03, 0.85688300E+02, 0.41824100E+02, 0.84712000E+02, -.54892000E+02, -.24296200E+02, 0.58581500E+02, -.37765300E+02, 0.80502100E+02, -.13823600E+02, 0.59355700E+03, 0.27424400E+03, -.13096500E+03, -.26098200E+03, -.15336800E+03, -.65956400E+02, -.62778200E+02, -.24558100E+01, 0.37672900E+01, 0.33727500E+02, -.38380800E+02, -.19978400E+02, -.39514600E+01, 0.22561400E+02, 0.46802300E+01, -.79310300E+01, -.11602700E+02, -.10511900E+02, -.24321500E+01, -.46168600E+01, -.94508000E+01, -.14698400E+02, -.11496400E+02, 0.40907200E+02, -.32020400E+02, -.11080300E+02, 0.10446800E+02, -.10014500E+02, -.27487500E+02, 0.21655600E+02, -.30700600E+01, 0.11993600E+02, -.21569800E+02, 0.29226800E+02, -.24288200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17134900E+01, -.63498700E+00, -.22154800E+00, -.26622400E+00, 0.11135600E+00, -.41129500E+00, -.10169700E+00, 0.52026500E+00, 0.41936500E+01, -.10365400E+01, 0.45161000E-01, 0.11762800E+01, 0.91919800E+00, -.18325300E+00, -.16985600E+00, 0.24529700E+01, 0.39564900E+01, 0.22937000E-01, -.15138000E+00, -.67358700E+00, 0.31679200E+00, -.73402900E+00, -.20956600E+00, 0.98911600E-02, 0.33748900E+00, 0.17004600E-02, 0.81492300E+00, -.11983300E+00, 0.95188100E+00, -.24504400E+00, 0.80480500E-01, -.60358700E-01, -.40293000E-01, -.11047000E+00, -.25190500E+00, -.12335100E+00, -.31873100E-02, -.60122900E+00, -.76547000E-01, -.41497300E+00, 0.44516000E+00, -.11237900E+00, -.16315200E+01, -.36728600E+00, 0.10081000E-01, -.13552000E+00, 0.48923900E+00, 0.72594700E-01, -.75574800E+00, -.18006400E-01, 0.16814100E+01, 0.59063000E+00, -.40341300E+00, 0.14966300E+00, -.40350000E+00, 0.29488200E+01, 0.28282300E+00, 0.91396800E-01, 0.42259100E+00, 0.17586600E+01, -.72034600E+00, 0.12520300E+00, -.13240700E+01, 0.42248300E+00, 0.17269900E+01, -.15791500E+01, -.97052500E+00, -.24342000E+00, 0.18568500E+00, -.38654400E-04, 0.17609300E+00, 0.12622400E+01, 0.14820000E+00, 0.10790100E+01, 0.97547800E+00, -.87543000E-01, -.11763600E+00, -.45062400E+00, -.57625600E-02, 0.16943700E+00, 0.20631000E-02, -.47061000E+00, 0.29315800E+00, -.12818900E+00, 0.11595500E+00, 0.31766600E+00, -.10460400E-01, -.22223500E+01, 0.40178800E+00, -.56754700E-01, -.93715400E+00, 0.11528900E-01, 0.12969200E+00, -.86120900E-01, -.10609000E+00, 0.68812900E-01, -.10546600E+00, -.15462600E+00, -.45446700E+00, -.19402400E+01, -.91749200E+00, -.23045500E+00, 0.35497400E-01, -.23351100E+00, -.36356200E+00, 0.44948000E-01, -.67345300E-01, 0.32494700E+00, -.13137300E+00, 0.67432800E-01, -.56549100E-01, -.10682700E+00, 0.12600500E+00, -.40135300E-01, -.38494600E-01, -.24303500E+01, -.44590100E+00, 0.75238800E-01, 0.16130600E+00, -.24432400E+00, 0.25747100E-01, -.65870500E-01, -.31621200E+00, -.57055000E-02, 0.24964400E-01, -.22225200E+00, -.13327800E-01, 0.73500800E-01, 0.49395700E+00, -.94643700E-01, 0.26482100E+00, -.24808900E+00, 0.15260000E+01, -.39170400E-01, -.27512600E+00, -.27821200E-01, 0.42250400E+00, 0.16148900E+00, -.31445600E+00, -.32866200E-01, 0.38685400E-02, 0.53504400E+00, 0.26370500E+00, 0.25231400E+00, 0.60695000E-01, 0.23114200E+00, -.39038900E-01, 0.84351900E-01, 0.66522600E+00, 0.22386600E+00, -.83989800E-02, 0.41107300E+00, -.31699800E+00, -.19887500E-01, 0.19290300E-01, 0.12957700E-01, 0.20215700E+00, -.66792200E-02, 0.50594600E-01, -.15392000E+00, -.19200800E-01, -.47815700E-01, 0.12724600E+00, 0.13623800E+00, 0.71010900E-01, -.57363900E-02, 0.97046300E-01, -.15596700E+00, -.36360800E-01, 0.11053700E-01, 0.30049500E+00, -.17009200E+00, 0.66715300E-01, 0.27372800E+00, -.23656300E+00, -.12230500E+00, -.83219900E-01, 0.12606200E+00, 0.12314200E+00, -.41193700E-01, 0.21317900E+00, -.68844500E-01, 0.61556800E+00, -.28019400E-01, 0.50022100E+00, 0.14955900E+00, 0.12971800E-01, 0.79585600E+00, -.20873700E-01, 0.26840300E+00, 0.12634200E-01, 0.16623800E+00, -.15867200E+01, -.73841900E-01, -.91531300E-02, 0.37037000E-01, -.16548000E-01, 0.52694700E+00, -.70812400E-02, -.57352100E-01, 0.86134400E-01, -.10331000E-01, 0.14515600E+00, 0.32242900E-01, 0.26380400E+02, 0.82886500E+01, -.73058000E+01, -.26844400E+01, -.48401700E+00, -.37540900E+02, 0.18431300E+02, 0.79162300E+01, 0.18781900E+02, -.27738400E+00, -.12712200E+02, 0.19742100E+02, -.37054000E+01, 0.10990700E+02, -.85630100E+01, 0.17551400E+02, 0.74723400E+02, -.36259200E+02, 0.20984900E+01, -.36542600E+02, -.33316400E+00, -.97813100E+01, -.12472000E+02, 0.63931200E+01, -.10453800E+02, -.75616700E+01, -.10730800E+03, -.46084500E+02, 0.23271100E+02, 0.43815800E+02, 0.22149700E+02, 0.13557200E+02, -.39442100E+01, 0.99652200E+01, -.12972800E+02, 0.16735000E+02, -.21134400E+01, -.16291000E+02, 0.76488100E+00, -.95175500E+01, -.29051800E+01, 0.11940900E+01, 0.36912700E+00, 0.82729100E+00, 0.57403500E+00, 0.29308500E+01, -.77050200E-01, -.96493400E-02, -.37231100E-01, -.19664900E+01, 0.29865400E+00, 0.61318300E+00, -.94285900E+00, -.29686100E+00, 0.45323900E+01, -.66339800E+00, -.36954000E+00, -.12906600E+01, -.40981700E+00, -.28765400E+01, 0.86908300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.75695200E+01, 0.39674800E+01, -.21226500E+01, -.81205800E+00, -.44000800E+00, 0.75386800E+01, -.24259100E+01, -.31348800E+01, 0.74670300E+01, 0.45532200E+01, 0.63090700E-01, -.85649700E+00, 0.90497800E+00, -.32367800E+00, -.47073000E+01, -.11434600E+00, 0.16082900E+01, -.10542600E+02, -.22631700E+01, -.39139000E+01, 0.14483700E+01, -.34572400E+00, 0.24626100E+00, -.19884200E+01, -.84574200E-01, 0.65409700E-01, 0.58828300E+00, 0.23256300E+00, -.23594100E+00, -.11783300E+00, -.23775800E+01, 0.95223300E+00, -.36408500E+00, -.49652900E+00, -.15211100E+01, 0.28194300E+00, 0.24526700E-01, 0.88176700E+00, -.85897000E+00, -.15063100E+01, 0.22206000E+01, -.10823900E+01, -.25258300E+01, -.26509400E+01, 0.88602200E+00, 0.52887300E+00, -.89315400E+00, 0.29775400E+00, 0.55037500E+00, -.18847400E+01, 0.12037400E+02, -.56318500E+00, -.14204500E+01, 0.35940100E+01, -.43229700E+01, -.42313300E+01, -.43170800E+01, 0.22761400E+00, 0.15587700E+01, -.31665100E+01, -.14659800E+01, 0.11527200E+01, -.57699700E+01, 0.22770900E+01, 0.10965600E+02, -.26687000E+01, -.32322100E+02, -.48172300E+01, 0.37362600E+00, 0.46399800E-02, -.35324300E+00, 0.19238800E+01, -.31048800E+01, -.40840900E+00, 0.12304100E+01, -.91294500E+00, 0.16165100E+01, -.14910000E+01, -.56640100E-01, 0.13753600E-01, 0.46562600E-02, -.20233100E+01, 0.11389900E+01, 0.13587900E+01, 0.23862000E+01, -.39714200E+00, 0.11705400E+00, 0.43634700E+01, -.18748400E+01, 0.11969800E+00, 0.69100300E+01, 0.26475300E-01, -.79299000E+00, 0.47734600E+00, 0.70503500E+00, 0.20193000E+00, 0.61456900E+00, 0.62065300E+00, 0.53758100E+00, 0.83412100E+01, 0.35036600E+01, 0.90251800E+00, -.20051100E+00, 0.78187600E+00, 0.12522500E+00, 0.46719800E-01, -.21778000E+00, -.68058800E+00, -.74274500E-01, -.42110400E+00, 0.49194700E+00, -.57898000E+00, 0.16904100E+01, -.53873400E+00, 0.15757400E+00, -.10532800E+02, -.10425600E+01, 0.29289800E-01, 0.91761900E-01, 0.72640500E+00, -.13236700E+01, -.18802900E-01, -.94946000E+00, 0.24485900E+00, 0.44059600E-01, -.11262800E+01, -.42756200E+00, -.32642800E-01, -.31833700E+00, -.14128800E+01, -.16881800E+01, 0.18677300E+01, -.35763500E+01, 0.91994700E-01, -.16208800E+01, 0.84548100E-01, 0.55912400E+00, 0.24681800E+00, -.10287600E+01, 0.74013600E-01, 0.12742400E+01, -.35221200E+01, 0.60540100E+01, 0.15262900E-01, -.73016000E-01, -.27454900E+01, 0.70372600E-01, 0.31295800E+01, 0.95540400E+00, -.17035400E+01, -.36060500E+00, 0.64132700E+00, -.80596400E+00, 0.27727700E+00, 0.22345400E+00, 0.17763100E+00, 0.14358000E+00, 0.93800900E-01, 0.42980800E+00, 0.39717300E+00, 0.15480800E+00, 0.34601700E+00, -.34890400E+01, 0.22198200E+00, 0.25912300E+00, -.25375300E+00, 0.21895900E+01, -.37365400E+01, -.67244100E+00, -.21865600E+00, -.72695100E-01, -.16526400E+01, -.23756600E+01, -.21221500E+01, 0.73462100E-01, 0.41349600E+00, 0.65421400E+00, 0.13236000E+01, -.10054600E+01, 0.10670000E+00, 0.13218400E+01, 0.88054100E+00, 0.92377000E+01, 0.31539000E+00, 0.11221600E+02, 0.64500400E+01, 0.44725300E+00, 0.23958500E+01, -.29438900E+00, -.34286600E+00, -.58210600E+00, -.27761500E+01, -.87737800E+01, 0.27216500E+02, 0.62914500E+00, -.38608300E-01, 0.37792900E+00, -.29418400E+01, -.10238200E+01, 0.36319300E+00, 0.10453900E+01, -.49487300E-01, -.12006200E-01, 0.10485700E+01, -.59968500E+01, -.30933100E+03, -.28420700E+03, 0.96790800E+02, 0.88468300E+02, -.33226500E+03, 0.16969200E+03, 0.11883000E+03, 0.16624500E+03, 0.10064200E+03, -.17836900E+03, 0.25572000E+03, 0.14120100E+03, 0.25664700E+03, -.86798600E+02, 0.44785300E+02, 0.15840800E+04, -.77904900E+03, -.22375600E+03, -.77731400E+03, -.14468800E+03, 0.19373500E+01, -.32600000E+03, 0.90695600E+02, -.45252100E+03, -.54091100E+02, -.14026200E+04, -.44853700E+03, 0.22603700E+03, 0.76971800E+03, 0.22678600E+03, 0.21734500E+03, 0.85585700E+02, 0.88720900E+02, -.12884100E+02, -.93133200E+02, 0.69684100E+02, -.20582800E+03, 0.85951400E+01, -.65844600E+02, -.33320200E+02, -.18249000E+01, -.22636500E+02, -.18886600E+02, 0.71106900E+01, 0.33973200E+02, 0.67646300E+01, -.51050400E+01, -.11820200E+01, -.48687300E+02, 0.18572700E+02, -.23961300E+02, 0.19616400E+02, -.33645500E+01, 0.63793700E+02, -.21410100E+02, 0.13597900E+01, 0.78331300E+01, 0.12880900E+01, -.53908000E+02, 0.60483500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.27785200E+01, 0.83283000E+00, -.42752200E+00, 0.36675900E+00, -.19737200E+00, 0.47921900E+00, 0.88112800E-01, -.12191800E+00, 0.74735000E+01, 0.11812300E+01, -.10889700E+00, -.11386400E+01, -.76641400E+00, -.18700600E+00, 0.22964300E+00, -.33943900E+01, -.51244200E+01, -.91177200E+00, 0.84616400E-01, 0.10682000E+01, -.24603600E+00, 0.90706800E+00, -.92446000E+00, -.11040000E+00, -.36814800E-01, -.11356900E-01, 0.68789200E-02, 0.21688200E+00, -.97651000E+00, 0.95942700E-01, -.54211300E+00, -.30664000E-02, -.48385800E-02, 0.31744600E+00, 0.80862000E+00, 0.31826800E+00, 0.95837500E-03, 0.28740000E+00, -.13775900E+01, 0.22937600E+00, -.90784500E+00, -.12613100E+00, 0.29261800E+00, 0.11182800E+00, -.29512900E-01, 0.14157200E+00, -.65500600E+00, -.85080400E-01, 0.13389000E+01, -.11855000E+00, -.35291300E+01, -.69083300E+00, -.96232900E-01, -.68538700E+00, 0.17637300E+00, -.15567200E+00, 0.18538500E+01, 0.12469100E+00, -.55859300E-01, 0.16950500E+00, 0.60612300E+00, -.49729000E-01, 0.48291400E+00, -.59106800E+00, -.18643800E+00, 0.30692200E-01, -.12057500E+01, -.60844300E-01, 0.30907900E+00, -.89425600E-03, 0.50218900E-01, -.86643700E+00, 0.28581100E+01, -.32151100E+00, 0.49608200E+00, 0.18782900E+00, -.76266600E+00, 0.29581000E+00, -.29182500E+00, -.16753000E+00, 0.28068900E-02, -.89844400E+00, -.43327900E-01, -.13885900E+01, 0.66510300E+00, -.20582700E+00, -.16889100E+00, 0.42911400E+00, -.32962900E-01, 0.95106200E-01, -.67009100E+00, 0.49594800E-02, -.30183100E+00, -.10016100E+00, 0.17384600E+00, 0.20701600E-01, -.21778800E+00, -.28576900E+00, 0.29616300E+00, 0.75124000E+00, -.50736100E+00, -.53028600E-01, -.58469800E-02, 0.55360800E-01, -.10426300E+00, -.12098200E+01, -.45490500E+00, -.10728600E+00, -.47906500E+00, -.89833900E-01, 0.57497500E-02, 0.30573000E+00, -.12367000E-01, 0.43317500E-02, -.92965200E-01, 0.17629700E+00, -.60059600E+00, 0.21403800E+00, 0.46795800E-01, 0.75998700E+00, 0.65670900E+00, 0.86417400E-01, 0.26752600E+00, -.27016600E+00, -.68900300E-01, 0.72366900E+00, 0.20518900E+00, -.26532300E+00, -.27622300E+00, -.51490200E-01, 0.17280800E+00, -.26796700E+00, 0.30315400E+01, 0.33720800E-01, -.14714400E+00, 0.50891300E-02, 0.67414700E+00, 0.11972300E+00, -.28420000E-01, -.12271300E+00, 0.77861800E-01, 0.16409900E+01, -.13492000E+01, 0.55881500E-01, 0.20189500E+00, 0.74246700E+00, 0.64483700E-01, -.13006000E+01, 0.19185500E+01, -.37974100E+01, 0.13476300E+00, -.78755900E+00, 0.10572600E+00, -.15170400E+00, -.27176300E+00, -.23477500E+00, -.46926900E+00, 0.20575400E-01, -.14775300E+00, -.12275100E+00, -.17257200E+00, -.38358400E+00, -.68339400E+00, -.40746900E+00, 0.20727600E+00, -.39584900E+00, -.90362600E-01, -.19439100E+01, 0.34648000E-01, -.43394900E+00, -.11118400E+00, -.72191600E-02, 0.19257300E+00, 0.12219500E+01, 0.27053900E+00, -.22926600E+00, -.19941500E+00, -.32015000E+00, 0.27097500E+00, 0.30147000E-01, 0.63690300E+00, 0.58046700E-01, -.20868800E+01, 0.12813200E+00, -.90044000E+00, -.52039800E+00, -.58106500E-01, -.10107900E+01, -.74754100E-01, 0.50760300E+00, 0.39555300E+00, -.46855500E+00, 0.11994000E+01, -.79531500E+01, -.67093200E+00, 0.60616000E-01, 0.10319700E-01, -.77843600E+00, 0.27962900E-01, -.14591700E+00, -.64147200E-01, 0.97754500E-02, -.25042100E+00, -.95694100E-01, 0.67187800E+00, -.13328700E+00, 0.45560100E+02, 0.89482500E+01, -.28314700E+01, 0.22488400E+03, -.11217500E+03, -.48066600E+02, -.11245100E+03, -.58687700E+02, -.56642000E+01, -.10536700E+03, -.81154300E+02, -.79188600E+02, -.10706200E+02, -.63974000E+02, -.51937000E+02, 0.26055400E+02, 0.19350100E+02, 0.25479500E+02, -.63134800E+02, -.99261800E+01, 0.39100100E+02, -.14627000E+02, 0.60626600E+01, -.14039900E+02, 0.27692800E+02, -.20637000E+03, 0.10258400E+03, -.12082300E+02, 0.11004200E+03, -.30647400E+02, -.13740700E+02, 0.18571400E+02, -.19561500E+03, -.22593300E+02, -.14883200E+01, 0.74087300E+02, -.46524300E+01, -.91223400E+01, -.80534900E+01, 0.40983900E+00, 0.23142500E+01, 0.26785100E+01, -.35331400E+01, 0.85400100E+01, 0.27893800E+01, 0.14161800E+00, 0.16470100E+01, 0.24427500E+02, -.14899900E+02, 0.29435400E+01, -.31674100E+01, 0.23172900E+01, 0.60191900E+01, 0.76521300E+01, -.41077900E+01, -.39084200E+01, -.10239900E+02, -.33386400E+01, 0.17697900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14851000E+01, 0.25994100E+01, -.21996300E+00, 0.25040700E+01, 0.49645200E+00, -.16497200E+01, 0.11465900E+01, 0.16432700E+00, -.17643000E+02, 0.12586100E+01, -.53148500E-01, -.12360100E+01, -.65466700E+00, -.78269000E-01, 0.21337400E+01, -.96969600E+00, -.30888400E+01, 0.16008900E+00, 0.53089800E+00, 0.18885500E+01, -.11395300E+00, 0.22391100E+00, -.34111200E+01, 0.44330400E+00, -.33513600E+00, -.99916700E-02, -.51312800E+00, -.12222100E+00, 0.87983300E+00, 0.14375700E+00, 0.63613500E+00, -.10473100E+01, -.11930800E-01, 0.83867900E-01, 0.80895500E+00, 0.44135500E-02, -.63743300E-02, -.14128000E+00, -.83454700E+00, 0.50624400E+00, -.86680200E+00, -.94520100E-01, -.68399300E+00, -.18630700E+00, -.42026200E-01, 0.68771900E-01, 0.88777800E+00, -.11757700E-01, -.76996100E+00, 0.16889800E+00, -.83541900E+01, -.11465800E+01, 0.17041100E+01, 0.52541000E+00, 0.14809700E+01, 0.60333500E+01, 0.14572200E+01, -.35688000E+00, -.20555900E+00, -.28116700E-01, 0.34598800E+00, 0.12880500E+00, 0.39441600E+00, 0.29913600E+00, 0.50716400E+00, 0.82923900E+00, 0.47936000E+01, -.10130500E+01, -.23443800E+00, -.64056600E-02, 0.63828000E+00, 0.16545500E+01, -.42963000E+00, 0.87751700E+00, -.12333000E+00, -.14189400E+01, 0.31026000E+00, 0.29064600E+00, -.11554100E+00, -.37695100E+00, 0.19773100E-02, -.82533200E+00, 0.41191300E+00, -.13390000E+01, -.32062900E+00, 0.44824100E+00, 0.27423400E-01, 0.17260500E+01, 0.50476100E+00, -.16743600E+00, -.24336100E+01, -.15020500E-01, 0.59781900E-01, 0.18086600E+01, -.54122600E+00, -.95524900E+00, 0.19956900E+00, -.33769300E+00, -.24372300E+01, -.88051300E+00, -.38389900E+00, -.66898200E+00, 0.16651900E+00, -.68951600E+00, 0.18251300E+00, -.11844400E+01, -.49940700E+00, 0.31157900E+00, -.24735900E+00, -.22052800E+00, 0.18817200E+00, 0.89021900E+00, -.14508700E+00, 0.44518100E-01, -.40046400E-01, -.49266900E+01, -.23593500E+00, -.26040700E+00, -.21523800E+00, 0.23491500E+00, -.71074700E+00, 0.38339400E+00, -.14354400E+01, 0.14849400E+00, 0.10385000E+00, -.54007500E+00, -.32997400E+00, 0.17096600E+00, 0.14095600E+01, -.11977600E+01, -.43698300E+00, 0.72757700E+00, 0.31166700E+00, 0.89760400E-01, 0.71068600E+00, -.36404800E-02, 0.23096700E+00, 0.21377500E+00, 0.20477100E+00, -.65179000E-01, 0.22662100E+00, -.60108300E+00, 0.73404400E+00, -.58876200E+00, 0.13698600E-01, 0.63499000E+00, -.27803200E-01, 0.16311800E+00, -.99988600E+00, 0.25222200E+01, 0.17913700E+00, 0.48703800E+00, 0.10204600E+01, 0.89001700E-01, 0.94580000E-01, 0.88210000E-01, 0.60853100E+00, 0.15290900E-01, 0.28514900E+00, -.33082100E+00, -.24615100E-01, 0.76114100E-01, -.76086100E+00, 0.46191100E+00, 0.26842300E+00, -.41611200E+00, 0.80934100E-01, 0.13934600E+01, -.25753600E-01, 0.15619600E+00, 0.48969700E+00, -.10866800E+00, -.16894400E+00, -.72141700E+00, -.50646300E+00, 0.66579200E-02, 0.33661900E-01, 0.25355400E+00, -.12832400E+00, -.42587600E-01, -.74421800E+00, -.15318800E+00, 0.21605900E+01, 0.97343800E-01, 0.25050700E+00, 0.82399400E+00, 0.75532700E-01, 0.74878000E+00, -.27493600E-01, -.17774800E+00, -.32813000E+00, 0.79172800E+00, -.31724600E+00, 0.41927700E+01, 0.25768600E+00, -.11354600E-01, 0.35944100E+00, 0.65840200E+00, -.60427000E-01, 0.34439400E+00, -.55218100E-01, 0.18558100E-01, 0.24095300E+00, -.31132800E+00, 0.10861900E+01, -.17054000E+00, -.89077600E+00, 0.45103700E+02, 0.30144900E+02, 0.98437600E+02, -.47088500E+02, -.22060400E+02, -.49227400E+02, 0.33992800E+02, -.12568400E+02, -.38599000E+02, -.51374500E+02, 0.10671300E+02, -.85952600E+01, -.69866200E+02, 0.21606800E+03, -.10453700E+03, -.24306300E+02, -.10431500E+03, -.98732800E+02, 0.29800800E+02, -.38254600E+02, -.41030900E+02, -.65571600E+02, -.61538100E+01, -.24134500E+03, -.28435500E+03, 0.14375700E+03, 0.25994300E+03, 0.14408300E+03, -.13959800E+02, 0.39968600E+02, 0.27775200E+02, -.14462000E+03, -.39598700E+02, 0.31646300E+02, -.14094700E+02, -.30316700E+01, -.29329200E+01, -.13005300E+02, -.37363500E+01, -.55400500E+01, -.65057000E+01, -.31775400E+01, 0.13164900E+02, 0.52240100E+01, -.27350300E+01, 0.79560800E+00, 0.11750200E+02, -.46955400E+01, -.61759300E+01, 0.60990500E+01, -.40991200E+00, 0.99830300E+01, 0.12059500E+01, -.26639800E+01, 0.14933700E+01, -.31888500E+01, -.10525200E+02, 0.87894100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32304700E+01, -.60868100E+01, -.13812800E+01, -.44713300E+01, -.23392700E+01, 0.10495600E+01, -.12788700E+01, -.81526400E+01, -.16077600E+02, -.64117100E+00, 0.19706400E+01, 0.24573300E+01, 0.67248000E+00, 0.36262400E+00, -.27962500E+01, 0.28647300E+01, 0.38503400E+01, -.37562800E+01, -.10663600E+01, -.12505800E+01, 0.35981800E+00, -.14338500E+01, 0.58597200E+01, -.11431400E+01, 0.85976000E+00, -.75645100E-01, 0.16843900E+01, 0.14726600E+00, -.67483900E-02, 0.14668400E+01, 0.18725900E+01, 0.14694700E+01, -.17757300E+01, -.57352100E-01, -.18893100E+00, -.75602800E+00, 0.51834800E-01, 0.29718800E+01, 0.21607400E+01, 0.75168500E+00, -.73909500E+00, -.62088300E+00, 0.37551200E+01, 0.21933500E+01, 0.21494500E-01, 0.20979900E+00, 0.85767000E+00, 0.59951800E-01, 0.28578000E+00, 0.22953000E+00, -.18795300E+01, -.14227900E+00, 0.10926900E+01, 0.19194700E+01, -.20861900E+01, 0.81583500E+01, 0.10083200E+01, -.60414900E-01, 0.73154200E+00, 0.28604600E+01, -.24706400E+01, 0.17428500E+00, 0.69369400E+00, 0.34873400E+00, 0.26328000E+01, -.47023300E+01, 0.32366300E+00, 0.81213100E+00, 0.25263800E+00, 0.31482400E-02, -.13412300E+00, -.11319200E+00, 0.45689300E+01, -.49516600E+01, 0.41975600E+01, 0.19230700E+01, 0.10813600E+00, -.24212400E+00, 0.24337500E+00, 0.61104600E+00, -.11830200E-02, 0.46125900E+00, 0.19323000E+00, 0.81556700E+00, 0.10877200E+01, -.48089300E+00, 0.17898800E+00, 0.14940100E+01, -.20471500E-01, -.39628200E-01, 0.88955800E+00, -.20562000E-01, 0.34118500E-01, 0.41166900E+00, -.16547800E+00, 0.15946900E+00, 0.65227500E+00, -.34815500E-02, -.21247400E+01, 0.29330100E+00, -.16013600E+01, 0.25417900E-01, 0.20664500E+00, -.16787600E+01, 0.13526100E+01, -.22446000E+00, 0.11297700E-01, 0.43835300E+00, 0.83429400E-01, 0.18209600E+00, -.12199300E+00, -.49330500E-01, -.24004700E-01, 0.64508000E-02, -.27921800E+00, -.75267000E+00, 0.10705900E+01, -.87013200E+00, -.34687300E+00, -.45317600E-01, -.47763600E+00, 0.28359600E+00, -.15340600E+01, 0.14001300E+00, 0.90261900E-01, -.46514100E+00, -.41703500E+00, -.49414600E-01, -.49698800E+00, -.11861000E+01, -.11123900E+01, -.13042800E+01, -.79280400E+01, -.11024300E+00, 0.15932400E+01, 0.10977600E+00, 0.11468700E+01, 0.21563700E+00, 0.97640200E+00, 0.31755500E+00, 0.76301200E+00, -.20262000E+01, -.11015700E+01, -.11964800E+01, -.29804900E+00, 0.57233600E+00, -.60460700E-03, 0.36521000E+00, -.21797500E+01, 0.37530100E+01, 0.33890900E+00, 0.32374700E-01, 0.18905700E+00, 0.35105200E+00, -.85351500E-01, -.27818400E-01, -.65089800E+00, -.12479100E-01, -.90326700E-01, -.37764300E+00, -.14992000E+00, -.45978500E+00, 0.81011900E+00, 0.87142000E-01, 0.47389900E-01, -.73235900E+00, -.14162400E+00, 0.21867500E+01, 0.57738200E-01, 0.39538300E+00, -.10135300E+01, 0.51805200E+00, -.93918800E-01, -.73651600E+00, 0.93222600E-01, 0.32406300E+00, -.19244400E+00, -.88177300E-02, -.11341400E+00, 0.81454800E-01, -.14134300E+00, 0.11930600E+00, 0.35926100E+01, 0.21746600E+00, -.16373500E+01, 0.13261200E+01, 0.55319900E-01, -.11623800E+01, -.17681200E+00, -.44892600E+00, -.41907900E+00, -.44271400E+00, 0.22502400E+01, 0.12786500E+02, 0.89277500E+00, -.29627700E+00, 0.54980600E+00, -.77500300E+00, -.26965100E+00, 0.52258800E+00, -.28452300E+00, 0.31884600E-01, -.24482700E+00, -.30258600E+00, -.55297500E+00, 0.95405000E-01, -.98891500E+00, 0.12279500E+01, -.19089900E+03, 0.12260500E+03, -.61667900E+02, -.59271000E+02, -.61329000E+02, -.58865500E+02, 0.46180000E+02, -.63079400E+02, 0.35836400E+02, -.53864200E+02, 0.11299100E+02, -.18001100E+01, -.46282700E+03, 0.22801600E+03, 0.53631300E+02, 0.22738700E+03, 0.33170200E+02, 0.48154300E+02, 0.70748300E+02, -.28192900E+02, 0.14702700E+03, 0.48289000E+02, 0.65747000E+03, 0.26309600E+03, -.13364400E+03, -.22439600E+03, -.13033800E+03, -.79549600E+02, -.76283500E+01, -.60615800E+02, 0.64825900E+02, 0.20878600E+02, 0.57065600E+00, -.11011900E+03, 0.21938500E+01, 0.50667700E+02, 0.16330400E+02, -.53662500E+01, -.11981800E+02, -.12836200E+02, 0.14321900E+01, -.16641200E+02, -.42821200E+01, -.19970500E+01, -.46786700E+01, 0.19690900E+02, -.62776900E+01, -.11722100E+02, 0.12793700E+02, -.28626100E+01, -.25091500E+02, 0.11723100E+02, 0.30179800E+01, 0.50610800E+01, -.63041800E+01, 0.30385500E+02, -.52857800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.46827700E+01, -.57502000E+01, -.90808000E+00, -.42053600E+00, 0.47162200E+01, 0.13921900E+01, -.67078900E+00, 0.18975600E+01, 0.86774400E+02, -.10268700E+01, -.48109100E+00, 0.36060800E+00, 0.14733200E+01, 0.64553200E-01, -.44082800E+01, 0.48490000E+01, -.71102300E+00, -.19633300E+01, 0.12885400E+00, -.56789900E+01, 0.66358300E+01, 0.31175400E+00, 0.32711900E+01, 0.39992100E+00, -.78376500E+00, -.81232300E+00, -.82687800E+01, -.17193100E+01, 0.47907800E-01, -.16594000E+00, -.12993000E+01, -.21921800E+00, 0.28311700E+00, 0.24610100E+00, -.23829200E+00, 0.96857300E-01, -.41649600E-01, -.70246400E+00, 0.11440400E+01, -.94345600E+00, -.78453000E+00, 0.53844300E+00, 0.33787800E+00, 0.11892500E+01, 0.25528900E+00, 0.67457200E-01, 0.99579100E-01, 0.14084100E+00, -.73146900E+00, 0.12417600E+00, -.28528200E+00, 0.90063500E-01, -.43024100E+00, 0.76402400E+00, -.44403300E+00, 0.28044300E+01, 0.32190100E+00, 0.21535100E+00, 0.36005100E+00, 0.64281700E+01, -.10988400E+01, -.17726400E-01, -.61445900E+00, -.21930900E+00, 0.11117900E+01, -.24900200E+01, 0.15485000E+01, 0.54036200E+00, 0.19442700E+00, 0.44153000E-01, 0.10814300E+00, 0.11470000E+01, 0.50986200E-02, 0.10898800E+00, 0.44530600E+00, 0.69272500E+00, 0.17628100E+01, 0.56289400E+00, 0.23869700E+00, 0.25929700E+00, -.23141500E-02, 0.42919100E+01, -.72037600E+00, 0.17878200E+01, 0.10890800E+01, -.86093900E-01, 0.21341100E+00, -.21576600E+01, -.23424000E+00, -.36364200E+00, 0.25967000E+01, -.12629900E+00, 0.22493400E+00, 0.13363400E+00, -.65420700E+00, 0.51431600E+00, 0.10848900E+01, 0.38958800E+00, -.66658800E+00, -.10628100E+01, -.10234000E+00, -.33734100E+00, 0.26868100E+00, -.65088000E+00, 0.12404600E+01, 0.12951200E+01, 0.11114700E+00, 0.56045300E+00, 0.49591200E+00, 0.53457300E+00, -.19140500E+00, -.75465600E+00, 0.71856100E+00, -.24808500E+00, -.26141700E+00, 0.16492000E+01, 0.14550000E+01, -.69478700E+00, 0.24055000E-01, 0.50722200E+00, 0.38385900E+00, -.12828300E-01, -.28700700E+01, -.32854400E+00, 0.37182600E+00, -.12371200E+01, -.27924600E+01, 0.65770700E+00, 0.29502400E-01, -.54529300E+00, -.87289900E+00, -.11908900E+01, -.72578600E+01, -.24989100E-01, 0.11982700E+01, 0.13131600E+00, -.10673900E+01, -.39082200E+00, 0.56838600E+00, 0.17023200E+00, -.22288700E+00, -.15513500E+01, -.13148100E+01, -.56914200E+00, -.18849900E+00, -.28487500E+00, 0.15680000E-01, 0.34623000E+00, -.16177000E+01, 0.17231000E+01, 0.21195400E+00, -.14213100E+00, -.10910700E+00, 0.80408500E+00, 0.22429900E+00, 0.30799200E+00, -.10795200E+01, -.26127200E-01, 0.21054500E+00, 0.20386500E+00, -.25634600E+00, 0.20497000E+01, 0.14981800E+01, -.63513900E+00, -.56393700E+00, 0.29964300E+00, -.41162200E+00, -.14237500E+01, 0.31717500E+00, -.12242400E+00, -.67044900E+00, -.50846400E-01, -.18429700E+00, 0.53575200E-01, 0.69882400E+00, -.40818000E+00, 0.87209500E-01, -.12630300E+00, -.35540400E+00, 0.39403300E+00, -.77032400E-01, 0.32080400E+00, -.15298200E+01, 0.34827700E+00, 0.11343500E+01, 0.15973800E+01, 0.11586900E+00, -.29683300E+01, -.17730700E+00, 0.10966600E+00, 0.12433800E+01, -.75018400E+00, 0.53176100E+01, -.45700400E+01, 0.89900700E-01, -.45423600E+00, -.38675000E+00, -.46524800E+01, 0.10938400E+00, 0.31037600E+00, 0.19672400E+00, 0.42305900E+00, -.48269000E+00, -.36855700E+00, 0.19461800E+01, -.46360700E+00, 0.11298700E+01, 0.12585400E+00, 0.10624900E-01, -.36337200E+03, 0.18085100E+03, 0.81662400E+02, 0.17621200E+03, 0.13635100E+03, -.43448700E+01, 0.10037000E+03, -.27907000E+02, 0.22456000E+02, 0.31298900E+02, 0.11434900E+03, -.72240200E+02, 0.35223800E+02, 0.82414500E+02, 0.33868700E+02, 0.17611100E+03, -.43629100E+02, -.35879800E+00, -.46716900E+02, -.36067600E+02, 0.26129400E+02, -.16238600E+03, -.28315200E+03, 0.14882300E+03, 0.17334400E+03, 0.53633300E+02, 0.23999500E+03, 0.52330800E+02, 0.55833900E+02, 0.30648200E+02, 0.26348900E+02, 0.26005300E+02, 0.34688000E+03, 0.64981700E+01, -.34520500E+02, 0.26864300E+02, 0.36691400E+01, 0.29531100E+01, 0.36496900E+01, 0.70080500E+01, -.26500000E+02, 0.18123600E+00, 0.45817400E+01, 0.29327700E+01, -.28217100E+02, 0.62670300E+01, 0.27119300E+01, -.29388100E+01, 0.45429000E+01, 0.61856500E+01, -.11588500E+02, 0.15599700E+01, -.64244100E+01, 0.16783400E+02, -.85902000E+00, 0.32242100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35459000E+01, -.40327400E+01, -.32814400E+00, -.41793400E+00, 0.71685600E+00, -.30813800E+01, 0.97085100E+00, 0.90453100E+00, -.11090900E+02, -.27721800E+01, -.78022400E-01, -.31444600E+00, 0.30446700E+00, -.24029700E+00, 0.22658400E+01, 0.99437400E+00, -.18779900E+00, 0.42355700E+01, 0.86410900E+00, 0.21712500E+01, -.11018300E+01, 0.65449000E-01, 0.54188500E+00, 0.15260800E+01, -.40991500E+00, -.25796000E-01, -.48050200E+00, -.20722800E+00, 0.36407700E+00, -.54331400E-01, 0.13441600E+01, -.66598800E-01, 0.62129700E-01, 0.39932900E-01, 0.26136800E+00, -.19177300E+00, -.96958600E-02, -.30242900E+00, 0.89117000E+00, 0.70880700E+00, -.12131200E+01, 0.37401600E+00, -.29813300E+00, 0.55846900E+00, -.42844200E+00, -.27600300E+00, 0.72532900E+00, -.38342200E-01, -.42783700E+00, 0.93356000E+00, -.79807900E+01, -.87532900E-01, 0.12779200E+01, -.15335000E+01, 0.19242200E+01, 0.44197300E+01, 0.30713900E+01, -.36476100E-01, -.13789200E+00, -.16848600E+01, 0.15893200E+01, -.51409200E+00, 0.26761700E+01, -.13693800E+01, -.39496000E+01, 0.61339700E+00, 0.10205700E+02, 0.18162400E+01, 0.14624500E-01, -.28135600E-02, 0.51903300E+00, -.12984600E+01, 0.37849300E+01, 0.58036100E+00, 0.72306100E+00, -.90817900E-01, -.68838600E+00, 0.12580100E+01, 0.19789100E-01, -.15042100E-02, -.90472800E-03, 0.78822100E+00, -.71468800E+00, -.90274600E+00, 0.16012800E+00, 0.34123800E+00, -.53413500E-01, -.21581700E+01, 0.10737600E+01, 0.32661300E+00, -.18662100E+01, -.22137800E-01, 0.12692100E+00, 0.43036500E-01, -.22947900E+00, 0.10417900E+00, 0.19544400E+00, -.19691300E+00, -.82451100E+00, -.16344500E+01, -.87842700E+00, 0.10388700E+00, 0.63912400E-01, 0.48247200E+00, -.16332300E+00, -.12521900E+01, -.36910100E-01, 0.56665600E+00, -.29964500E+00, -.39964900E+00, -.70974900E-01, 0.22714500E+00, -.79425000E+00, 0.25134700E+00, 0.45583900E+00, -.65516700E-01, -.60345400E+00, 0.10223800E+00, -.36731500E+00, -.12395000E+01, -.22553200E+00, 0.28041000E+00, 0.21668800E+01, 0.30437200E+00, -.29267100E-01, 0.11643100E+01, 0.11776900E+01, 0.79268100E-01, 0.67060200E+00, 0.91155500E+00, 0.83979700E+00, 0.88089200E+00, 0.44172700E+01, 0.10655100E+00, 0.58642100E+00, -.38070500E-01, -.12294500E+01, -.60103300E+00, 0.49805900E+00, 0.68299000E-01, -.57544000E+00, 0.12743600E+01, -.26465000E+01, 0.51833900E+00, -.16485100E+00, 0.10493500E+00, 0.27848400E-01, -.90529300E-01, -.31606800E-01, -.14397400E+00, 0.22452100E-02, -.11076600E+01, -.92836400E+00, -.27399000E+00, -.12332200E+00, -.13783100E+00, 0.32824300E+00, 0.14149200E-01, -.22187100E+00, 0.27001700E-02, 0.16536800E+00, -.47689200E-01, -.97246800E+00, 0.87684100E-01, 0.19056900E+00, -.22947600E+00, -.70162900E+00, 0.46579600E+00, 0.23668300E+00, -.32266200E+00, 0.69221400E+00, 0.10712100E+00, 0.69209600E+00, -.31007500E-01, -.19817900E+00, -.43620300E-01, 0.24303200E-01, -.29344200E+00, -.12256700E+00, -.30030500E-01, -.12742500E+01, -.32847400E+00, -.33464400E+01, -.91220500E-01, -.17910300E+00, -.66336300E+00, 0.98524800E-02, 0.36207800E+00, 0.27788100E+00, -.14044200E+00, 0.17360300E+00, 0.15291200E+01, 0.37698000E+01, -.27763400E+01, 0.21166600E+00, -.10173000E+00, -.56765600E+00, -.98829100E+00, 0.22028600E+00, 0.46332900E-01, -.28207900E+00, 0.67612500E-02, 0.17478700E+00, -.33651400E+00, 0.22411700E+01, -.30840300E+00, -.85889400E-01, -.39314400E+00, 0.60866700E-03, 0.58864400E+00, 0.11127400E+02, -.27993600E+02, 0.32279300E+01, 0.10612700E+02, 0.80214200E+01, -.27448700E+02, -.39478900E+02, 0.10862800E+01, -.62687800E+00, -.13711000E+02, -.12411700E+01, 0.28688700E+01, -.18597800E+02, 0.50208100E+01, -.64791300E+02, -.46548600E+01, 0.15544800E+02, -.72221900E+01, 0.18943000E+02, -.29666400E+02, -.18370700E+03, -.82497500E+02, 0.37670200E+02, 0.12119100E+03, 0.89988800E+02, -.10867700E+03, 0.14838900E+02, -.55870700E+00, -.74517200E+02, -.24331600E+02, 0.33022100E+01, -.86979700E+02, -.48732300E+01, 0.47824700E+01, -.12853400E+02, -.84936500E-01, 0.29093600E+01, 0.10988100E+01, -.56258200E+01, 0.12757300E+02, -.55284800E-01, -.25852200E+01, -.10117300E+01, 0.12764600E+02, -.67329200E+00, 0.26962700E+01, -.18735900E+01, -.30579300E+01, -.87173600E+01, 0.36865400E+01, -.50962900E+01, -.94840500E-01, -.66230900E+00, -.95296900E+01, -.25005200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54542000E+01, -.25684600E+01, 0.16482700E+01, 0.25410700E+00, -.47313200E+00, -.55256800E+01, 0.14395500E+01, 0.27634200E+01, -.23732900E+01, -.42494000E+01, -.89287200E-01, 0.33256700E+00, -.83524700E+00, 0.11314800E+00, 0.31058400E+01, 0.90922200E+00, -.19525500E+01, 0.61854100E+01, 0.12430800E+01, 0.21161700E+01, -.14348700E+01, 0.11010400E+00, 0.19001500E+01, 0.11079800E+01, 0.59897900E+00, -.27016300E-01, 0.54879700E+00, 0.59453400E-02, -.42377400E+00, 0.29216200E+00, 0.17907100E+01, 0.31007000E+00, 0.37518500E+00, 0.23271100E+00, 0.10191000E+01, -.65379300E-01, -.23197600E-01, -.13568600E+01, -.82186100E+00, 0.15360700E+01, -.39303300E+01, 0.37941300E+00, 0.18176500E+00, 0.10732800E+01, -.63516800E+00, -.47474400E+00, 0.20348700E+01, -.21054200E+00, -.17127600E+01, 0.12656000E+01, -.94598400E+01, 0.85376200E+00, 0.89381800E+00, -.21263600E+01, 0.32276300E+01, 0.69956300E+01, 0.30766000E+01, 0.46756900E-01, -.98473000E+00, 0.66485200E+01, -.55999700E+00, -.40513100E+00, 0.30147700E+01, -.16137400E+01, -.62076700E+01, 0.28239300E+00, 0.20397700E+02, 0.26413700E+01, -.52203500E+00, -.19790100E-03, 0.16273400E+00, -.14873100E+01, 0.53452200E+01, -.74949700E+00, 0.97355400E+00, 0.37658700E+00, -.11671300E+01, 0.98361500E+00, -.21798700E+00, -.49201400E-02, 0.11345200E-02, -.23585800E+00, -.12859800E+00, -.16206800E+01, -.11007900E+01, -.62984000E+00, -.32967900E+00, -.37372500E+01, 0.93588400E+00, -.24831400E+00, -.41623600E+01, 0.52872800E-02, 0.49693000E-01, -.17400400E+00, -.70818800E+00, 0.80570000E+00, -.33414400E-02, -.58441500E+00, -.12147900E+01, -.31785700E+01, -.30546800E+01, -.20091600E+00, 0.17798000E+00, -.18260600E+01, 0.14415100E+01, -.10512400E+01, -.34064300E+00, 0.44581100E+00, 0.14243300E+00, 0.28084400E+00, 0.35538600E-01, 0.20816600E+00, -.99615100E+00, 0.31414700E+00, -.21906500E+00, -.18604600E+01, 0.63496600E+00, -.23569600E+00, -.50075400E+00, 0.82932200E+00, -.57537600E+00, 0.47256900E+00, 0.12925400E+01, 0.48887600E+00, 0.93991300E-01, 0.15823100E+00, 0.24685400E-01, 0.34279900E+00, 0.23833300E+01, 0.13103500E+00, 0.20862200E+01, 0.10540500E+00, 0.62470100E+01, -.22075500E+00, 0.13043900E+01, -.53393200E-01, 0.64182900E+00, 0.41994700E+00, 0.12964700E+01, -.26944000E+00, -.84459800E+00, 0.11597000E+01, -.53392700E+01, -.12894800E+01, -.23094300E+00, 0.20852300E+01, -.98773700E-01, -.24909100E+01, -.33784600E+01, 0.60874200E+01, 0.85122400E+00, -.20966300E+01, 0.10553100E+01, 0.28271900E+00, -.98348700E-01, 0.37379700E+00, -.89884400E-01, 0.22048400E-01, 0.31845300E+00, -.37408700E+00, -.22484600E+00, 0.88585400E+00, -.19916400E+01, 0.10154500E+00, 0.11464900E+00, -.11634200E+01, -.55368200E+00, 0.15444300E+01, 0.17104300E+00, 0.28423600E+00, -.54728800E+00, -.40496400E-01, 0.17372900E-01, -.16394400E-01, 0.18584300E+00, -.27666400E+00, -.10561100E+00, -.52180600E+00, -.34416100E+00, 0.57211800E-01, -.23881400E+00, 0.80233000E-01, -.45269200E+00, 0.66492600E+00, -.22820100E+01, 0.56742900E+00, 0.10199100E+00, -.18091200E+01, 0.86744400E-01, 0.36208300E+00, 0.27354300E+00, -.14970000E+01, -.46977700E+01, 0.82352500E+00, 0.65062300E+00, -.13139000E+00, -.80507800E-01, 0.19458100E+01, 0.36844800E+00, -.17934100E-01, 0.59287200E-01, -.31035700E-01, 0.24760500E+00, 0.47243000E-01, -.25971600E+01, 0.41904100E+00, 0.36793200E+00, -.16272300E+00, 0.27972200E+00, -.11180500E+00, -.61057500E+00, -.69645100E+02, 0.13833000E+01, -.90790300E+02, 0.91513400E+01, -.53544400E+02, -.12324100E+03, 0.23485600E+02, -.20344300E+02, 0.70192600E+02, -.48306900E+03, 0.22868300E+03, 0.16585200E+03, 0.23943300E+03, 0.20408400E+02, -.92053400E+01, 0.65602900E+02, -.18431700E+03, 0.10218900E+03, 0.63437800E+01, -.15552100E+03, -.79832100E+03, 0.39363200E+03, 0.31527700E+03, 0.41834100E+03, 0.35658400E+01, 0.61354100E+02, 0.59917300E+02, -.37312800E+03, 0.42169600E+02, 0.41236600E+02, 0.10748000E+03, -.30164500E+01, -.84723200E+01, 0.42880400E+01, 0.41511800E+01, 0.89331900E+01, 0.79311900E+01, -.39099700E+01, -.40313200E+01, -.61462300E+01, -.10193400E+02, -.65602300E+01, 0.38270000E+02, -.14399100E+02, 0.88988900E+01, -.81141000E+01, -.89942300E+01, -.22557100E+02, 0.12299200E+02, -.54544900E+01, -.57063200E+01, -.62290800E+01, 0.91940000E+01, 0.24710500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35262500E+01, 0.45201400E+01, -.10393900E+01, 0.79701000E+00, -.17384700E+01, 0.54591300E+00, 0.53556600E+00, -.13149100E+01, -.56106400E+02, 0.20350500E+01, 0.14457500E+00, -.16598500E+01, 0.27257000E+00, -.54240000E+00, 0.91993000E-01, -.43091500E+01, -.26789900E+01, -.14187400E+01, -.37709700E+00, 0.42459100E+01, -.45333800E+01, 0.21755400E+00, -.70412100E+01, -.50586600E+00, 0.18185300E+00, 0.29896700E+00, 0.40499800E+01, 0.88975900E+00, -.17835100E+00, -.12356700E+00, -.17493300E+00, -.40758600E+00, 0.98083400E-03, -.16942000E+00, -.26190600E+00, 0.23944100E+00, -.12939600E-01, 0.20155400E+00, 0.57256000E+00, -.74763600E+00, 0.83286200E+00, 0.11260900E+00, -.77098900E+00, 0.52396100E-01, 0.24318400E+00, 0.17938900E+00, -.12737100E+01, 0.13149900E-01, 0.12767200E+01, -.37822100E+00, 0.95877200E+00, -.86823100E+00, -.18199700E+01, -.34206200E+00, -.12567400E+01, -.24128600E+01, 0.59610200E+00, 0.14167500E+00, 0.42868300E+00, -.57414600E+01, -.34738900E-01, -.27012900E+00, -.68744300E+00, -.47659600E-01, 0.11061700E+01, 0.29860200E-02, -.91149600E+01, 0.29994900E+00, 0.47805200E+00, -.91217700E-04, 0.18091400E-01, 0.30101300E+00, 0.12223500E+01, -.10032400E+01, -.62928300E+00, 0.15043700E+01, -.48333800E+00, 0.10746700E+01, -.17453300E+00, 0.15750700E+00, -.27298100E-02, 0.85072100E+00, -.96745800E+00, 0.12346200E+01, -.53663100E-01, -.10121600E+01, -.49944800E-01, 0.44422700E+01, -.43716500E+00, 0.30238000E+00, 0.91939100E+00, 0.20451000E-01, -.24983800E+00, -.12260900E+01, 0.71728200E+00, 0.11353300E+01, 0.21470700E+00, 0.60368600E-01, -.18988400E+00, 0.13614000E+01, -.18017600E+01, 0.84702800E+00, -.21163400E-01, 0.27841000E+00, -.16797100E+01, -.27536900E+00, -.20479000E+00, 0.18278600E+00, -.54631800E+00, 0.31624400E+00, 0.89327600E-02, -.72719200E-01, -.50578500E+00, 0.16027900E+00, -.26318000E+00, 0.56931600E+00, -.34923300E+00, -.19730100E-01, -.12087200E+00, 0.11172700E+00, 0.21985200E+00, 0.53760500E-01, 0.67368700E+00, -.33652800E+00, 0.59301200E-02, 0.19146200E+01, 0.15926400E+01, -.43540100E+00, -.90744000E+00, 0.45155300E+00, -.27565900E+00, -.45394700E+00, -.48710900E+01, -.12776700E+00, -.17377500E+00, 0.10411600E+00, 0.24051600E+00, -.78278000E-01, -.24005400E+00, 0.36621300E+00, 0.53766200E+00, -.10080300E+01, 0.24192300E+01, 0.49405100E+00, 0.47832200E-02, -.12647100E+01, 0.43371200E-01, 0.17858900E+01, 0.69713200E+00, 0.23155500E+00, -.51317600E+00, 0.10167000E+01, 0.12035600E+01, -.15530200E+00, 0.44998200E+00, 0.25256800E+00, -.43144400E+00, 0.13423600E-01, -.18223200E+00, 0.69742000E+00, 0.32303900E+00, -.22308700E+00, 0.34656000E+01, -.39991100E+00, -.29147300E+00, 0.51747100E+00, -.30610700E+00, -.14017700E+01, 0.12490400E+00, -.71356200E+00, 0.53710800E+00, 0.16466300E+00, 0.17442500E+00, 0.15395400E+00, 0.73182400E+00, -.12981600E+00, 0.45099400E+00, -.34043400E+00, -.10787200E+00, 0.11104600E+00, 0.16701200E+00, -.12233800E+00, -.19549000E+01, -.30392600E+00, 0.24593300E+01, -.15043700E+00, -.15522100E+00, 0.52622000E+00, 0.11744100E+00, 0.29264500E-01, 0.46679200E+00, -.21978100E+00, 0.15832600E+01, 0.37630700E+00, 0.22912000E+00, -.37439000E-01, -.52306500E+00, -.14387400E+01, 0.28738000E-01, -.25457000E+00, 0.11725400E+00, -.42392200E-01, 0.51698300E-01, 0.36327200E+00, 0.11676900E+01, -.24148900E+00, 0.42155300E+00, -.25475300E+00, -.22852200E+00, 0.40613000E+00, 0.13459300E+00, -.10627900E+00, 0.32013300E+02, -.51705100E+02, -.14603900E+02, 0.31871100E+02, 0.92600900E+02, 0.30471100E+02, -.18631700E+02, 0.33425500E+02, -.93060300E+02, 0.46606600E+02, -.11644800E+01, 0.48662100E+02, 0.23494400E+02, 0.26457800E+02, -.77860000E+01, -.36506800E+02, 0.10814700E+02, 0.12751600E+02, 0.55670700E+02, -.19102000E+02, 0.37969900E+01, -.30538000E+02, 0.58087400E+02, 0.13987000E+02, 0.21968900E+02, -.27640900E+01, 0.42350300E+02, 0.67746700E+01, 0.14209500E+02, -.19435900E+03, 0.39188500E+01, 0.11520500E+02, -.16279200E+01, -.10076600E+00, 0.84876600E+00, 0.87094800E+00, 0.22858000E+01, 0.14025000E+01, 0.16895700E+01, 0.25010700E+01, 0.19779900E+01, -.44677100E+01, 0.63064600E+01, 0.57090400E+00, -.55777500E+00, 0.14062700E+01, 0.33663200E+01, -.10744100E+01, 0.22967800E+01, -.67525100E+00, -.19537900E+01, -.23882700E+00, -.10216000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.57482400E+01, -.91991100E+01, 0.99126700E+00, -.66635700E+01, -.46581000E+00, 0.15611900E+01, -.17220100E+01, -.87222600E+01, -.39675900E+02, -.36136100E+01, 0.36248900E+00, -.25121100E+00, 0.16888200E+01, 0.20822900E+00, -.42529800E+01, 0.57693400E+01, 0.39931100E+01, -.46585300E+01, -.24300200E+01, -.20573400E+01, -.11490300E+01, -.90055700E+00, 0.63837200E+01, 0.13171600E+01, 0.39104400E+01, -.22828100E-01, 0.24818700E+01, 0.17892600E-03, -.87487300E-01, 0.10363700E+01, 0.44188000E+00, 0.20518800E+01, 0.30257400E+00, -.75719600E+00, -.20439800E+00, -.12242600E-01, -.35433600E-01, -.76775800E+00, 0.19148700E+00, 0.19486900E+01, 0.83986800E-01, -.49462900E+00, -.24559300E+01, -.17837500E+01, -.25023800E+00, -.28506300E+00, -.72391900E-01, 0.15618500E-01, -.22235800E+01, 0.70243700E+00, -.31434800E+01, 0.13165500E+01, -.19146700E+01, -.27315600E+01, 0.22293200E+00, -.73912900E+01, 0.21068600E+01, 0.63775000E+00, -.21678300E+01, 0.31306500E+01, -.16800600E+01, -.47672400E+00, 0.27866300E+01, -.16080700E+01, -.62121700E+01, 0.35793100E+00, 0.19045400E+02, 0.25754800E+01, -.29318500E+00, 0.20714200E-03, -.39602200E-01, -.23590800E+01, 0.39510500E+01, -.38718300E+01, -.24676000E+01, 0.45981700E+01, -.17792600E+01, 0.19718000E+01, 0.13094900E-02, 0.13618300E+00, -.69500400E-02, 0.27503800E+01, -.24081000E+01, 0.13505800E+00, -.38147100E+01, -.17737300E+01, 0.39037100E-01, 0.21248900E+00, 0.20383500E+01, 0.68751700E+00, 0.62415700E+01, 0.14761700E-01, -.65778600E+00, -.45325000E+00, 0.14164200E+01, -.10901800E+01, 0.53321000E+00, -.13884500E-01, -.37476100E+01, -.18943000E+01, -.35690700E+00, -.10907900E+01, 0.98698900E-01, -.14159200E+01, -.48473400E+00, -.20132200E+01, -.41788500E+00, -.94491500E-02, -.60385500E+00, -.31670500E+00, 0.37962000E-01, 0.12796600E+01, -.34559600E+00, 0.11384900E+00, -.51191600E+00, -.72877600E+01, -.16497500E+01, -.43016100E+00, -.12362400E+00, -.25042500E+00, -.94044100E+00, 0.22888000E+00, -.49633200E+00, 0.33380000E+00, 0.14586600E+00, -.88644600E+00, 0.29025000E-01, -.10386900E+00, 0.17071900E+01, 0.11254000E+01, 0.39441000E+00, -.15613000E+00, 0.29632900E+01, 0.19783400E+00, 0.96491600E+00, -.83597200E-01, -.90796500E+00, -.13781100E+01, 0.20466300E+00, 0.14057700E-01, -.14436300E+01, 0.20653800E+01, -.56290700E+01, 0.36496000E+00, -.24813800E-01, -.56990100E-01, 0.67421000E-01, -.22735800E-01, -.14668700E+01, -.77945000E+00, 0.23579100E+00, -.23808600E+01, -.26532000E+01, 0.71084300E+00, -.85926300E+00, -.52885000E+00, -.12471200E+01, -.80454200E-01, -.81760600E+00, -.15759800E+00, -.12579600E+00, 0.20438300E+01, -.38135000E+01, -.41983700E+00, -.27920600E-01, -.48594600E+00, 0.84989000E-01, -.26350400E+01, -.84556800E-01, -.15769300E+00, 0.59175400E+00, -.67568400E+00, -.72110500E+00, -.20337800E+01, -.78833400E+00, -.18782900E+00, 0.74723200E+00, -.11180400E+01, -.27708800E+00, -.15265800E+00, 0.47051900E+00, -.14704300E-01, -.15584900E+02, 0.97462100E+00, 0.33139800E+01, 0.32028800E+01, 0.37521700E+00, -.47544700E+01, -.22290800E+00, 0.16270400E+00, 0.30545300E+00, -.11628500E+01, 0.13253200E+02, 0.77804700E+01, -.15938000E+01, -.25021400E+00, -.15990200E+01, -.55509800E+01, -.20368800E+00, -.22037400E+00, -.24951200E+00, 0.11656600E+00, -.34453600E+00, -.94448200E+00, 0.42929400E+01, -.92669100E+00, 0.14748200E+01, 0.10515200E+01, 0.20431600E+00, 0.88170900E+00, 0.19048400E+00, 0.16298700E+00, 0.12319600E+00, -.22303400E+03, -.14937400E+03, 0.17765800E+01, -.16738800E+03, -.12043300E+03, -.13824000E+03, 0.98664700E+02, 0.54224700E+03, -.25988700E+03, -.27136800E+03, -.26161200E+03, -.11423600E+03, -.13758700E+01, -.35426000E+01, 0.21494700E+03, -.11809900E+03, -.90379700E+02, -.51215400E+02, 0.58333700E+03, -.29647200E+03, -.36842300E+03, -.24339200E+03, -.14978100E+03, -.52003900E+02, -.21720600E+02, 0.12494400E+03, -.65815500E+02, -.58000700E+02, -.54066700E+02, -.58001300E-01, 0.20472800E+02, -.18205100E+02, -.12080900E+02, -.17785900E+02, -.18963900E+02, -.23886500E+01, 0.18846700E+02, -.11117000E+02, -.12433200E+02, -.13248800E+02, 0.21735100E+02, -.30683200E+02, -.17256300E+02, 0.16736200E+02, -.10199500E+02, 0.87859700E+00, 0.19106700E+02, -.31425700E+01, 0.14132900E+02, -.38561500E+02, -.20456000E+02, -.20202400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.38096100E+01, -.58952800E+01, 0.72179500E-01, -.48580400E+01, -.14674100E+01, 0.13942000E+00, -.13587300E+01, -.48736900E+01, 0.38602300E+02, -.34032600E+01, 0.22667900E+00, 0.36250600E+01, 0.11552400E+01, 0.56041700E+00, -.31671900E+01, 0.47848000E+01, 0.68269200E+01, -.73917700E+01, -.19829500E+01, -.38528700E+01, 0.53458600E+01, -.14062300E+01, 0.12901400E+02, -.10619600E+01, -.30836200E+00, -.70835100E-01, -.32099600E+00, -.35849800E+00, -.25621200E+00, 0.16497000E+01, 0.20171700E+01, 0.24533500E+01, -.30189200E+00, -.35758000E+00, 0.74643100E+00, -.20635600E+00, 0.66621300E-02, 0.14263900E+01, -.10702700E+01, 0.20761900E+01, -.11400100E+01, -.12956100E+01, -.19663600E+01, -.27141600E+01, -.38049200E+00, -.17950100E+00, 0.85960300E+00, -.29836200E+00, 0.14402800E+00, 0.62766400E+00, -.38399700E+01, 0.44597900E+00, 0.21218100E+01, -.89387600E+00, 0.55785400E+00, -.39249900E+01, 0.18620400E+01, 0.40926300E+00, -.20744400E+01, 0.26594600E+00, -.37592300E+01, 0.28509900E+00, 0.25030400E+01, -.55213900E+00, -.31540000E+01, 0.26376900E+00, 0.53705700E+01, 0.77977000E+00, -.81958800E+00, 0.99796700E-02, -.94510200E+00, -.26022700E+01, 0.76199300E+01, -.53447100E+01, 0.15776100E+01, 0.28380900E+01, -.13115400E+01, 0.60323400E+00, -.15629900E+00, 0.27833600E+00, 0.13611400E-02, -.21445900E+01, -.20580600E+00, 0.88241300E+00, -.11617500E+01, -.46196000E+01, -.54804100E+00, 0.35982700E+01, 0.13015400E+01, 0.63517000E+00, 0.17496800E+01, -.53945200E-01, -.54792900E+00, -.19380100E+01, 0.12178400E+01, 0.77651900E+00, -.21074900E+00, -.11409800E+01, -.11743000E+01, 0.19929100E+01, 0.17283100E+01, 0.73422400E+00, -.89946500E-01, 0.10685700E+01, -.15358500E+01, 0.11756000E+00, -.10443100E+00, 0.12629300E+00, -.10737700E+01, -.81722000E+00, 0.46247200E+00, 0.11671400E+01, -.84801400E-01, 0.28962800E-01, -.99573500E-01, -.15329100E+02, -.32577900E+01, 0.32963100E+00, -.14967600E+00, 0.12087600E+01, -.14634900E+01, 0.64285000E+00, 0.11130900E+01, 0.51636200E+00, -.17581900E+00, 0.10173400E+00, 0.28733000E+01, -.13829100E+01, -.41625200E+00, 0.28300000E+00, -.46539700E-01, 0.16935200E+00, 0.15618300E+01, 0.14636800E+00, -.28508800E+00, 0.14319600E-01, -.28286800E+00, -.30365300E+00, -.21052500E+00, -.11913500E+00, 0.11946200E+00, 0.79746100E+00, -.77693900E+00, -.12394600E+00, 0.15558200E+00, 0.56731200E+00, 0.80825000E-01, -.67393400E+00, 0.28664000E+00, 0.49783500E+00, 0.10202000E-02, -.33471500E+00, -.77285100E+00, 0.12339400E-01, -.24666100E+00, -.15576500E+00, 0.20084700E+00, 0.33990500E-01, -.24854200E+00, -.25340400E+00, -.41061800E-01, -.16821800E+00, -.91188300E-01, 0.71200900E-01, 0.78122800E-01, -.36691100E+00, -.13055800E-01, 0.27739500E+01, 0.48564000E-01, 0.69840000E+00, -.79564400E+00, 0.10589300E+01, 0.94332200E-01, -.57387400E+00, 0.37804500E-01, 0.66850600E+00, -.16468100E+00, -.95759800E-01, 0.13880100E+00, 0.16846500E+00, -.68262000E+00, 0.15155100E+00, 0.32523700E+01, 0.25196300E+00, -.17248900E+01, 0.51138900E+00, 0.14417100E+00, 0.82413100E+00, 0.90727400E+00, -.90259800E-01, 0.13798800E+01, -.54180200E-01, -.38804900E+01, -.17046300E+01, 0.16488800E+01, -.17794600E+00, 0.21194500E+00, -.33521500E+01, -.63310300E-01, 0.10430400E-01, 0.29484200E+00, -.48187500E-01, 0.32716100E+00, 0.65427500E+00, -.11460200E+01, 0.18595900E+00, 0.16772900E-03, -.10599200E+01, 0.14391800E+00, 0.93154800E-01, -.70014100E+00, 0.50699800E+00, 0.65575600E-01, -.60622700E+00, -.14429400E+03, 0.25702300E+02, -.32963300E+02, 0.14866800E+01, -.10380400E+03, -.67955700E+01, 0.14519900E+03, -.54067100E+02, -.79015600E+02, -.58031700E+02, -.44125800E+02, -.94724600E+02, 0.40214700E+02, -.53175600E+02, -.49936400E+02, -.10370300E+03, -.51979400E+03, -.20766400E+03, 0.10057100E+03, -.48088900E+02, 0.15384500E+03, -.65696300E+02, 0.16611600E+02, 0.71002300E+02, -.18615800E+03, -.38678300E+02, -.11442300E+02, 0.27508500E+02, -.63525400E+01, -.19029000E+02, -.21622700E+02, 0.39632600E+01, 0.50102700E+01, 0.25770000E+01, -.67069200E+01, 0.22081700E+02, -.55034600E+01, -.84693900E+01, -.15020600E+00, 0.24830000E+02, -.16500400E+02, 0.47816800E+01, -.45877100E+01, -.11738000E+01, 0.70522500E+01, 0.13815100E+01, -.13707200E+02, -.58989400E+01, -.19215200E+02, -.30988700E+02, 0.35627600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.75253900E+01, -.89237900E+01, -.10556400E+01, -.14590500E+01, 0.47309900E+01, 0.22380000E+01, -.15829400E+01, 0.24255700E+01, 0.10046200E+03, -.24269500E+01, -.47169600E+00, 0.91034900E+00, 0.19993400E+01, -.88531000E-01, -.22010800E+01, 0.83224600E+01, 0.42792000E+01, -.18417400E+01, -.48058600E-01, -.82237100E+01, 0.81216200E+01, -.12715800E+00, 0.95827400E+01, 0.13499300E+01, -.12074800E+01, -.55758900E+00, -.86755900E+01, -.18815500E+01, 0.80164800E+00, -.28848700E+00, -.80831100E+00, 0.67021000E+00, -.18470300E+00, -.56648500E-02, -.68565000E+00, -.19265200E+00, 0.25525600E-01, -.34899000E+00, -.26623700E+00, 0.24008200E-01, -.14156500E+00, -.43866900E+00, -.19456100E+01, -.15088400E+01, 0.45974500E-01, -.55064000E-01, 0.13423900E+01, 0.31583800E+00, -.20305000E+01, -.24749400E+00, 0.58542800E+00, 0.26911700E+00, 0.20999100E+01, 0.21320000E+01, -.10978400E+00, 0.64081800E+01, 0.50285000E+00, -.20021300E+00, 0.12566400E+01, 0.40655600E+01, 0.10847900E+01, 0.65588000E+00, -.19998400E+01, 0.67129300E+00, 0.51597300E+01, -.25054500E+01, -.52700100E+01, -.22008300E+01, 0.13899100E-02, -.95373000E-03, -.84314700E-01, 0.15059600E+01, -.30016800E+01, 0.25662500E+01, 0.13140100E+01, -.32844300E+01, 0.92964700E+00, -.22842300E+01, -.24031700E-01, -.16547700E+00, 0.55073900E-02, -.24515100E+01, 0.14344200E+01, -.17222100E+01, 0.23698900E+01, 0.27600500E+01, 0.20996600E+00, -.44952800E+01, -.10618800E+01, -.59774400E+00, 0.35156000E+01, -.37342600E+00, 0.86074500E-01, 0.17100200E+01, -.16858200E+01, -.66772800E+00, 0.42432400E-01, 0.26042700E+00, 0.12020800E+01, -.75826100E+00, 0.24716400E+01, -.90341600E+00, 0.34520800E+00, -.17398600E+01, 0.53147500E+01, 0.79380200E+00, 0.71919400E+00, -.52957300E+00, 0.49525700E+00, -.48390900E+00, 0.39216600E+00, 0.24564000E+00, 0.88745900E-01, 0.22439800E-01, -.56402100E-01, -.81812100E+01, -.17073100E+01, 0.18804500E+00, -.13548300E+00, -.10363300E+01, -.14697600E+01, 0.31468200E+00, -.20637600E+01, 0.75089800E+00, 0.18811900E+00, -.30423200E+01, -.37557600E+01, 0.13481100E+01, 0.33512000E+01, -.20590100E+01, -.10581900E+01, 0.38471500E+01, 0.11957000E+02, 0.62139700E+00, -.72894100E+00, -.31855700E+00, -.21685100E+01, -.29723600E+00, 0.57779600E-02, -.92208300E+00, -.81650300E+00, 0.14269000E+00, -.16330100E+01, -.55800400E+00, 0.79929100E-01, 0.12193700E+01, -.27370000E-02, -.26887900E+01, -.42795600E+00, -.19479400E+01, 0.98866200E+00, -.16741000E+01, -.11898600E+01, 0.42886100E+00, -.64287600E+00, -.42723900E+00, 0.94363300E+00, 0.22631900E+00, 0.69751500E+00, -.18249500E+01, -.70338300E+00, -.48148100E+00, -.13120500E+02, 0.12430600E+01, 0.12343300E+01, -.21208000E+01, 0.16739700E+01, 0.35316600E+00, -.59759400E+00, 0.14159800E+01, -.12905500E+01, -.15916400E+01, -.17124000E+01, -.32734200E+01, -.20244500E+01, 0.10757900E+01, -.30904600E+00, 0.65539700E+00, -.76088600E+00, -.13672400E+00, 0.68854100E+00, 0.84453000E+00, 0.22300000E+01, 0.94425100E+00, 0.13494500E+01, 0.53467000E+01, 0.62249300E+00, -.14540000E+01, -.62370900E+00, -.10087600E+01, -.12782700E+01, -.15320300E+01, -.23551600E+01, 0.27633600E+02, 0.52472100E+00, -.34486000E+00, 0.26856400E+00, -.11321000E+01, -.59902600E+00, 0.69919200E+00, 0.18686600E+00, -.61597700E+00, -.19269200E+00, 0.52324300E+00, -.41299400E+01, 0.87990500E+00, -.24249900E+01, 0.87459500E+00, 0.71332000E+00, -.87993100E+00, -.67770700E+00, 0.97502400E+00, 0.45988000E+00, -.40450500E+00, 0.42631100E+00, -.11958300E+03, -.28473500E+03, -.26861200E+03, 0.27120300E+02, -.10299100E+03, 0.89094400E+03, -.43860100E+03, -.32038000E+03, -.45295400E+03, -.17339400E+03, -.41810600E+02, 0.14403600E+02, 0.49735500E+03, -.15559900E+03, -.79996300E+02, -.18876800E+03, 0.10985700E+04, -.53463700E+03, -.36417700E+03, -.69898300E+03, -.24838000E+03, -.12290800E+03, -.13342600E+03, 0.14150300E+03, -.17602600E+03, -.99633900E+02, 0.67144600E+03, -.10732000E+02, 0.37915600E+01, -.14738200E+01, -.12224100E+02, -.21803600E+02, -.23240500E+02, -.78513600E+01, 0.29957700E+01, -.67167300E+01, 0.10948200E+01, -.96292700E+01, -.37664200E+01, -.19923000E+02, -.19844600E+02, 0.20026200E+02, -.31947000E+01, 0.93727700E+01, 0.93984500E+01, -.35491700E+01, 0.17625900E+02, -.95032800E+01, -.22079000E+02, -.17452200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.71454700E+01, -.90187300E+01, 0.21091100E+01, -.54952500E+01, -.13846400E+01, -.15749000E+01, -.17113600E+01, -.50635300E+01, 0.26995800E+02, -.47618100E+01, 0.37799900E+00, 0.39873800E+01, -.84847900E+00, 0.16264800E+01, -.31938900E+01, 0.55316600E+01, 0.61855800E+01, -.69247100E+01, -.20107500E+01, -.42085700E+01, 0.54169100E+01, -.18532000E+01, 0.15817600E+02, -.26646800E-01, 0.12559800E+01, -.28280100E-01, 0.11950600E+01, -.33058600E+00, 0.30495000E-01, 0.18447800E+01, 0.16222600E+01, 0.25171400E+01, -.14720500E+00, 0.26551700E-01, 0.13633700E+01, -.37943900E+00, -.13159000E-01, 0.30461300E+00, -.67244800E+00, 0.30592300E+01, -.24514200E+01, -.12069400E+01, -.85416200E+00, -.22731200E+01, -.72905800E+00, -.65232200E+00, 0.18566400E+01, -.53890000E+00, -.24091900E+01, 0.14772600E+01, -.49346500E+01, 0.18833300E+01, 0.24300700E+01, -.13440400E+01, 0.24217100E+01, -.49906000E+01, -.14671200E+01, 0.15445600E+00, -.43792900E+01, 0.50712500E+01, -.49917000E+01, 0.48506200E+00, 0.27241900E+01, -.64372200E-01, -.78467500E+01, 0.14834500E+01, 0.26734700E+02, 0.77188900E+00, -.20015500E+01, 0.78076100E-02, -.90645900E+00, -.37613500E+01, 0.44726000E+01, -.34245400E+01, 0.84933200E+00, 0.10722300E+01, -.18844100E+00, 0.56229400E+00, 0.65549700E-02, -.34664700E-01, -.90678800E-04, -.11372900E+01, 0.52020400E+00, -.39181000E+00, -.22061600E+01, -.50983000E+01, -.64347200E+00, 0.84511700E+00, 0.19467400E+01, 0.18426000E-01, 0.14242400E+01, -.65615400E-01, -.58520300E+00, 0.73456200E+00, 0.32192300E+00, -.66528900E+00, -.78825100E+00, -.12672900E+01, -.17236900E+01, 0.18931900E+01, 0.58008600E+01, -.73258200E+00, -.22249200E-01, 0.99238500E+00, -.58561700E+00, 0.67259700E+00, 0.91781700E-01, -.38884000E+00, 0.29003000E+00, -.11792100E+01, 0.38157900E+00, 0.10637500E+01, 0.14075500E+01, -.44644500E+00, 0.56484300E+00, -.12654600E+02, -.69184000E+00, 0.23865800E+00, 0.35208400E+00, 0.17140800E+00, -.13386400E+01, -.31656900E-01, 0.23715100E+01, 0.12735200E+01, -.85100100E-01, -.29392500E+01, 0.83892000E+00, -.64942200E+00, 0.22972800E-01, 0.11228400E+01, 0.12135800E+01, 0.75638500E-01, 0.77296600E+01, 0.30035700E+00, -.85245200E-01, -.12513600E+00, -.15254700E+01, -.66181500E+00, 0.33614500E+00, -.55405700E+00, -.84544500E+00, 0.20975500E+01, -.43926600E+01, -.64297300E+00, -.50453400E-01, 0.14679700E+01, 0.41922600E-01, -.24554600E+01, 0.42343200E+00, -.29028300E+01, 0.56638400E+00, -.24325300E+01, -.45242500E+01, 0.65188800E-01, -.74842700E+00, -.18806000E+00, 0.30766900E+00, 0.64438000E-01, -.59834800E-01, -.69314600E+00, -.33449900E+00, 0.14595800E+01, -.27426300E+01, -.18176900E+00, -.28319200E+00, -.35542000E-01, 0.26635500E+00, 0.15963800E+01, -.54206200E-01, 0.51866800E+00, -.49172700E+00, 0.76006300E+00, 0.35037800E-01, 0.12124700E+01, -.66468100E-01, 0.84187900E-01, -.62226700E+00, 0.33234800E-01, 0.61095200E+00, 0.13469900E+00, -.52513500E+00, 0.11744900E+00, 0.70257700E+01, 0.48923700E+00, -.82403600E+00, 0.15402400E+00, 0.22938500E+00, 0.39977500E-01, -.29212000E+00, 0.76599700E+00, 0.16945300E+00, 0.20169600E+00, -.76861900E+00, -.11695600E+02, -.10057900E+01, 0.86135400E-01, 0.10306100E+01, -.10130100E+01, -.33290000E+00, 0.67361400E-01, -.33706500E+00, 0.92433300E-02, -.83225500E-01, -.92965300E+00, -.11860900E+01, 0.24615200E+00, 0.63474200E+00, -.23736500E+00, 0.25439500E+00, -.50034600E+00, 0.64075700E+00, -.59141600E+00, 0.18760400E+00, -.21708100E+00, -.71094100E-01, 0.45350000E+00, -.13592900E+03, 0.96494400E+02, -.19789500E+02, 0.12569500E+03, -.57738800E+03, 0.28442000E+03, 0.29728700E+03, 0.29252300E+03, 0.13470500E+03, -.33456100E+02, 0.45887300E+02, -.38475900E+03, 0.96482700E+02, 0.32147600E+02, 0.76912000E+01, -.13105000E+04, 0.65532000E+03, 0.42567800E+03, 0.65214300E+03, 0.24854600E+03, 0.50475900E+02, 0.20293500E+03, -.40377500E+03, 0.20827500E+03, 0.45887800E+02, 0.12770800E+03, 0.34448400E+01, -.49826600E+02, 0.15534500E+02, 0.96837500E+01, 0.14785100E+02, 0.16222800E+02, 0.40832900E+01, -.15712100E+02, -.36718700E+01, -.14520400E+02, -.30806800E+01, 0.33670500E+02, -.21131800E+02, 0.14149800E+02, -.14612500E+02, -.58814900E+01, -.20022400E+02, 0.66232200E+01, -.25141500E+01, -.13065400E+02, -.19930100E+01, 0.21130000E+02, 0.66387700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33748800E+01, 0.44890400E+01, -.21069400E+01, 0.27235500E+01, 0.30378800E+00, 0.57073500E+00, 0.65103300E+00, 0.28094400E+01, 0.78309100E+01, 0.17080300E+01, -.21969200E+00, -.68102900E+00, 0.38458400E+00, -.93617000E+00, 0.98378300E+00, -.25269800E+00, -.22375500E+00, 0.49996400E+01, 0.97590500E+00, 0.98780800E+00, -.94889500E+00, 0.11935000E+01, -.81019200E+01, 0.95129300E+00, 0.20414600E+01, -.26342000E-02, -.23634100E+00, 0.18477000E-02, 0.43346800E+00, -.21349100E+00, -.85748300E-01, -.10663800E+01, 0.11959000E+00, 0.71194900E-01, 0.18404200E+00, 0.19855000E+00, -.63107300E-02, -.18479100E+00, -.31709300E+00, -.43993400E+00, 0.10629700E+01, 0.18678300E+00, -.48955100E+00, 0.14311700E+00, 0.18808700E+00, 0.14608600E+00, -.70630500E+00, 0.13230200E+00, 0.79450600E+00, -.50663200E+00, 0.68502000E+00, -.82261900E+00, -.65668500E+00, -.66646400E+00, -.12090100E+00, -.10535300E+01, 0.33005200E+00, 0.82067000E-01, 0.90942200E+00, 0.17728100E+01, 0.43329200E+00, 0.67937100E-01, 0.30158200E+00, -.16245700E+00, 0.47214900E+00, -.24832500E+00, 0.44098400E+01, 0.76026100E+00, 0.11600000E+00, 0.79823400E-03, -.65192800E+00, 0.66359500E+00, -.16236100E+01, -.38301200E+01, -.20685600E+01, 0.12361800E+01, 0.29567600E+00, 0.10479200E+01, -.43779100E-02, -.26120400E+00, -.40543800E-02, 0.24303300E+01, -.83344200E+00, -.75992500E+00, 0.10678000E+01, -.37306200E-01, 0.48699100E-01, 0.41423800E+01, -.10343600E+01, 0.21242200E+00, 0.36647000E+01, -.11373400E-04, -.62534500E-01, -.12007200E+01, 0.38989400E+00, 0.29469000E+00, 0.80782000E+00, 0.43221200E+00, -.71776400E+00, -.11721800E+00, -.17946200E+01, 0.43159000E+00, 0.26281100E-01, -.10344300E+01, 0.89057700E+00, -.47027900E+00, -.11151900E+00, -.55657500E+00, 0.58965700E-01, 0.58501100E+00, -.20444700E+00, -.44347600E-01, -.92213800E+00, 0.29320800E+00, -.32332900E+00, 0.40259100E+01, -.29385200E+00, -.68262300E-01, -.27278400E+00, 0.34875900E+00, 0.40375600E+00, -.15867200E+00, 0.20863000E+01, 0.12247500E+00, -.33931000E-01, 0.86186700E+00, 0.11471600E+00, 0.50403800E-01, 0.53628100E+00, 0.11878300E+00, 0.51545200E+00, -.75356600E+00, 0.11205600E+01, -.19466600E+00, 0.67379500E+00, 0.17236200E-02, 0.22772600E+01, 0.50288800E+00, 0.64107600E+00, -.76015300E-01, -.19826800E+00, 0.40778900E+00, -.24958600E+01, -.89316600E+00, 0.11160600E-01, 0.16395800E+01, -.71198000E-01, -.15836500E+01, -.20480600E+01, 0.37636800E+01, 0.42297300E+00, -.78887300E+00, 0.21494000E+01, 0.29374900E+00, -.28952600E+00, -.34592000E+00, -.36637100E+00, -.66040100E-01, -.28712700E+00, -.58131500E+00, -.19721800E+00, 0.31382500E+00, -.16685600E+01, 0.40124400E+00, 0.22371600E+00, -.94038100E+00, -.15225400E+00, 0.22242700E+01, 0.24476300E-01, 0.21962700E+00, 0.13021900E+00, 0.11077100E-01, 0.24422500E+00, 0.22776200E+00, -.73203700E+00, -.41690700E+00, -.26988800E+00, 0.30369900E+00, 0.19309300E+00, -.12320800E+00, -.20179700E+00, -.77512500E-01, 0.13166200E+01, -.19013000E-01, -.31536200E+01, -.54682700E+00, 0.62359800E-01, 0.47010900E+00, 0.93685900E-01, -.44857000E+00, -.53211900E+00, 0.93924000E+00, -.45696500E+01, -.22725300E+01, 0.43347100E+00, 0.30723500E-01, 0.40852300E+00, 0.28000300E+01, 0.46447300E+00, 0.60350000E-01, -.57594700E-01, 0.22700400E-01, 0.19324500E+00, -.21553800E+00, -.15934900E+01, 0.28169100E+00, -.43168900E+00, -.12746500E+00, 0.18499500E+00, -.10664500E+00, -.13309800E+00, -.46367500E+00, 0.14274500E-01, 0.10535800E+00, 0.23443200E-01, 0.25815600E+00, -.55364500E-01, 0.14999800E+03, -.28546700E+02, 0.19688800E+02, -.84007400E+03, 0.40528500E+03, 0.31926400E+03, 0.41540300E+03, 0.58960000E+02, -.54445100E+01, 0.62919100E+02, -.35976300E+03, 0.19387600E+03, 0.37288500E+02, -.52733900E+02, -.11099600E+04, 0.55231800E+03, 0.41268200E+03, 0.59549900E+03, 0.11577700E+03, 0.85571700E+02, 0.11920000E+03, -.32018200E+03, 0.14731700E+03, 0.64894600E+02, -.95574100E+02, 0.28793900E+01, -.21425000E+02, -.44188500E+01, 0.11846800E+02, 0.19158200E+02, 0.19386700E+02, 0.15240000E+01, 0.37769600E+01, 0.67640800E+01, -.23789300E-01, 0.77052400E+01, 0.23321900E+02, 0.75299200E+01, 0.18468800E+02, -.17808900E+02, 0.26711600E+01, -.90516200E+01, -.78364300E+01, -.12951500E+00, -.15258100E+02, 0.12550400E+02, 0.12697700E+02, 0.37885100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10985000E+02, -.12684200E+02, -.17739300E+01, -.71118800E+01, 0.99957900E+00, 0.30199100E+01, -.26469400E+01, -.90841900E+01, 0.87144800E+01, -.21618200E+01, 0.41227300E+00, 0.27161800E+01, 0.13187900E+01, 0.98652400E+00, -.48414200E+01, 0.59049900E+01, 0.97633200E+01, -.10768800E+02, -.27999800E+01, -.41086900E+01, 0.61577500E+01, -.20014500E+01, 0.13646900E+02, 0.29521400E+00, -.64813000E+00, -.44696000E-01, -.92045700E+00, -.80486700E+00, 0.16507100E+01, 0.12722200E+01, 0.95539400E+00, 0.18452200E+01, -.75770100E+00, -.25710200E+00, 0.30805200E+00, -.68742200E+00, 0.11731600E-01, 0.22414400E+01, 0.23865700E+01, 0.18094000E+01, 0.26719100E+01, -.13338800E+01, -.19178800E+01, -.33469700E+01, -.41512400E+00, -.30258400E+00, -.41190900E+00, -.22988300E+00, -.23553200E+00, 0.97390100E+00, -.16927600E+01, 0.48957700E+00, 0.30005100E+01, -.24027500E+00, -.62257500E-01, -.10224000E+02, 0.77328300E+00, 0.57377300E-01, -.31004200E+01, -.82248700E+01, -.22620100E+01, 0.10820800E+00, 0.18383600E+01, 0.44082500E+00, -.35903700E+01, 0.16686300E+01, 0.75486100E+01, 0.33846600E+00, -.86025500E+00, 0.50329400E-02, -.96750100E+00, -.21771900E+01, 0.95898000E+00, -.16192300E+01, -.80497800E+00, 0.14584700E+01, -.25927500E+00, -.29215700E+00, 0.68733600E-01, 0.21424100E+00, -.44445100E-02, -.74570200E+00, -.69675000E+00, 0.19413200E+01, -.22367000E+00, -.33952500E+01, -.20530000E+00, 0.56274800E+01, 0.62392000E+00, -.50734300E-01, 0.58001300E+01, -.48387800E-01, -.41322100E+00, -.22828100E-01, 0.46856300E+00, 0.14730500E+00, -.24556100E+01, -.11812700E+01, 0.87586000E+00, 0.62805100E+00, -.10279700E+01, 0.50830500E+00, 0.28521700E+00, -.34279200E+00, 0.78457000E+00, 0.48527000E+01, 0.10956800E-01, 0.24784800E+01, -.56430100E+00, -.64830900E+00, 0.27066100E+00, -.22217000E+00, 0.37064500E+01, -.11722100E+01, 0.37024900E+00, -.93788400E+01, 0.15263200E+01, -.73338600E+00, 0.46965200E+00, 0.57430600E+01, -.15958100E+00, 0.11038300E+01, -.82304500E+00, 0.69296000E+00, -.18157500E+00, -.46251000E+00, 0.30004900E+01, -.17450400E+01, -.21570100E+01, 0.11603000E+01, 0.11807700E+01, -.22708600E+01, 0.27334300E+01, 0.39909700E-01, -.75007300E+00, -.44850400E-01, -.50368400E+01, -.76644400E+00, 0.64396200E-01, -.68546700E+00, 0.71513000E+00, 0.70402900E+00, 0.42818900E+01, -.69315000E+00, 0.26992300E+00, -.18175100E+00, 0.22743900E-01, -.26601800E+01, 0.20075100E+01, -.31165900E+01, 0.18469100E+00, -.16468900E+01, -.14873600E+01, 0.45323500E+00, -.14670400E-01, 0.79222800E+00, -.11986000E+01, 0.10716400E+00, 0.16760100E+00, 0.53699300E-01, -.34995200E+00, 0.22841200E+01, -.84556600E+01, -.78677100E+00, -.16870300E+01, 0.13745200E+00, 0.10939900E+00, -.17525100E+01, -.11829700E-02, 0.83667400E+00, -.22261200E+01, 0.23420600E+00, -.69589700E-01, -.15260800E+01, 0.89261500E+00, 0.13297000E+01, -.15835900E+00, -.17449000E+01, -.10379400E+00, 0.24520800E+00, 0.24888800E+01, 0.53080200E+00, -.42611200E+01, 0.14159500E+01, -.67920600E+01, 0.24373100E+01, 0.50981400E+00, -.82131500E+01, 0.63491200E-02, -.11249800E+01, 0.82662900E-01, -.45872400E+01, -.12962200E+02, 0.68686500E+01, 0.13964800E+01, 0.34261900E+00, 0.90401000E+00, 0.15886700E+01, 0.47958500E+00, -.14381700E+01, 0.72423500E+00, -.63073700E-01, 0.17501600E+00, -.52800900E+00, -.43202300E+01, 0.75000800E+00, 0.22026200E+01, -.47921800E+00, -.28350100E-01, -.11217700E+01, -.66403400E+00, 0.13143100E+01, -.17986100E+00, 0.11189400E+01, -.12172800E+00, -.91913600E+00, -.26628000E+00, 0.33463900E+00, 0.66108400E+02, -.22821400E+03, 0.40000500E+03, -.20335100E+03, -.18328200E+03, -.21875000E+03, -.25508500E+03, -.13900200E+03, -.23380200E+02, -.56083400E+02, -.96418700E+02, -.51740900E+02, 0.37194500E+03, 0.16513500E+04, -.78994300E+03, -.10550000E+04, -.11314100E+04, -.43837400E+02, -.13402100E+03, -.16916500E+03, 0.34083900E+03, -.17408800E+03, -.92717000E+02, 0.32468800E+03, -.48439900E+01, 0.44746300E+02, 0.75735500E+01, -.28601900E+01, -.13559900E+02, -.79984000E+01, 0.91607300E+00, -.71199700E+01, -.15218600E+02, -.50148100E+01, -.82542700E+01, -.25953300E+02, -.69295400E+01, -.12757700E+02, 0.10082300E+02, -.73765600E+01, -.13371200E+02, -.47596300E+01, 0.39972000E+01, 0.81424300E+01, 0.45352000E+01, 0.19959200E+02, -.60624800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.58938000E+01, 0.11447800E+02, -.13662600E+01, 0.75068200E+01, 0.41176600E+01, -.23460400E+01, 0.19878600E+01, 0.13103700E+02, 0.41533700E+02, 0.17648800E+01, -.35035900E+01, -.32946500E+01, -.26409400E+00, -.39019900E+00, 0.38956000E+01, -.51136300E+01, -.28962000E+01, 0.21946800E+01, 0.10697900E+01, 0.64790200E+00, 0.18172600E+01, 0.64436100E+00, -.45786400E+01, -.28688200E+00, -.35665300E+01, 0.13650000E+00, -.20943100E+01, -.17902600E+00, -.10091200E+00, -.21920400E+01, -.30049700E+01, -.12978400E+01, 0.28376200E+01, 0.41698800E+00, -.13905100E+00, 0.10786000E+01, -.70213500E-01, -.30968900E+01, -.34887400E+01, -.20937900E+01, -.20941400E+01, 0.12518600E+01, -.33540200E+01, -.23198800E+01, 0.60492800E-01, 0.22436300E+00, 0.62567400E-01, -.36392300E+00, 0.22848000E+01, 0.10831600E-01, -.38159300E+01, -.21371000E+01, 0.18325500E+01, -.90382600E+00, 0.18545400E+01, 0.22931300E+01, 0.43154100E+01, -.15656800E+00, 0.52135100E+00, -.33449500E+01, 0.28420500E+01, 0.15667600E+00, 0.23135400E+01, -.19603600E+01, 0.19778000E+00, 0.10720800E+01, -.16643700E+02, -.12834200E+01, 0.25894700E+00, 0.46578000E-02, 0.17947500E+00, -.24822500E+01, 0.10096900E+02, -.12710000E+01, 0.32173200E+01, -.62701700E+00, 0.15632100E+01, 0.18709200E+01, 0.83528700E-01, -.42587900E-01, 0.12627900E-03, 0.32951700E+00, -.54849500E+00, 0.66633000E+00, -.20313300E-01, -.36704500E+01, -.70099400E+00, -.86680700E+01, 0.91010500E-01, 0.44552000E+00, -.61266200E+01, -.47342300E-04, 0.19625000E+00, -.24054900E+01, -.32976600E+00, 0.30205400E+01, 0.15072900E+00, -.14909000E+01, 0.28597000E+01, 0.55160100E+01, 0.44662700E+01, 0.17619900E+01, -.30916600E+00, 0.44410300E+01, -.16471600E+01, -.35625100E+00, -.18568600E+00, -.64885300E+00, -.51203100E+00, -.91228300E+00, 0.56925600E+00, 0.35320900E+00, -.36213600E+00, 0.11125900E+00, 0.11214400E+01, -.78776500E+01, -.27477900E+01, 0.15170400E+01, 0.19137100E-01, 0.11591800E-01, -.68429900E+00, -.28181800E+00, 0.44143600E+01, 0.68442600E+00, -.82060600E-01, 0.32215700E+00, 0.17715400E+01, -.28766700E+00, 0.78599600E+00, 0.23585000E+00, 0.74931500E+00, 0.24138400E+00, 0.66979700E+01, 0.39440200E-01, 0.44708800E+00, 0.28690700E-01, 0.10127500E+01, -.35477700E+00, 0.27474000E+00, 0.32741600E+00, 0.83838400E+00, 0.33812400E+01, -.20030700E+01, 0.29227100E+00, 0.29555300E+00, 0.78956500E+00, 0.12403000E+00, 0.65858300E-01, 0.33272100E+01, -.66150200E+01, -.46845200E+00, -.33123600E+01, -.43799100E+01, -.67675800E+00, -.67109500E+00, -.70101900E+00, 0.13873400E+01, -.53641100E-01, -.57636300E+00, 0.11936400E+01, 0.26313200E+00, -.67374100E-01, -.12591400E+01, -.68630000E+00, -.69749000E-01, 0.16166400E+01, -.38601200E+00, -.33493200E+01, 0.82068600E-01, -.48806500E+00, 0.71547400E-01, 0.62829400E+00, -.28999000E-01, -.60372600E+00, 0.85408600E+00, 0.32256400E+00, 0.81017900E-02, -.47998400E+00, 0.21796900E+00, -.95859100E-01, 0.74507400E+00, -.35063300E+00, -.45397600E+01, 0.54440100E+00, -.72277500E+00, -.11408300E+01, 0.20863800E+00, -.18365200E+01, -.23738200E-01, -.70926300E-01, 0.50058900E+00, 0.15502300E+00, 0.45046400E+01, -.10797200E+02, -.76133600E+00, -.67158000E-02, -.23727200E+00, -.10817600E+01, -.10403500E+00, 0.24898000E+00, -.42381500E+00, 0.68058800E-01, -.26870000E+00, -.53557500E+00, 0.23361500E+01, -.50315200E+00, 0.73456300E+00, 0.64576400E+00, 0.91058300E-01, 0.54861200E+00, 0.22676900E+00, -.22596200E+00, 0.79875400E-01, 0.14955600E+00, 0.66938100E-01, -.33309400E+00, 0.49717600E+00, -.65538100E+00, 0.81541800E-01, -.36750300E+03, -.11799100E+02, -.20594300E+01, -.20452300E+02, 0.11357400E+01, -.16380600E+02, 0.27304900E+02, 0.48255500E+01, 0.21430400E+03, 0.52311700E+02, 0.11494800E+01, -.21436400E+03, 0.17559500E+03, -.93417800E+02, 0.94124000E+02, -.44652700E+02, -.13759500E+03, 0.34676300E+02, -.10928900E+03, 0.49814600E+02, -.88963100E+02, 0.17832100E+02, -.17183700E+01, -.38732000E+00, 0.12263400E+02, -.17754000E+02, 0.21810000E+01, 0.52956400E+01, 0.48923200E+01, -.23456000E+01, 0.17846500E+02, 0.10650500E+02, 0.19990400E+02, 0.12273600E+02, -.19001400E+02, 0.32111400E+02, 0.68378100E+01, -.63883800E+01, 0.12392600E+02, 0.25063200E+02, -.17090200E+02, 0.20151200E+01, -.33472200E+01, 0.12400700E+02, -.18962600E+02, -.14845200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.95474400E+01, 0.11458200E+02, 0.17568300E+01, 0.85975700E+01, 0.23366100E+00, -.18152500E+01, 0.26137000E+01, 0.11507700E+02, -.37995700E+01, 0.34306700E+01, -.36517900E+00, -.20446800E+01, -.23377700E+01, -.12061800E+01, 0.61639500E+01, -.77776000E+01, -.11756500E+02, 0.11312200E+02, 0.36091500E+01, 0.68037400E+01, -.56154200E+01, 0.32532100E+01, -.20073200E+02, 0.22601700E+01, -.49991500E+00, -.19556900E-01, -.77727000E+00, 0.36969700E+00, 0.19453500E+00, -.22493500E+01, -.19120700E+01, -.43490100E+01, 0.10154300E+00, 0.31783400E+00, 0.12012000E-01, 0.62931100E+00, -.16251600E-01, -.14456800E+01, 0.46976500E+00, -.17739900E+01, 0.40833300E+01, 0.11272200E+01, 0.14731700E+01, 0.20558000E+01, 0.28597300E+00, 0.91559400E-01, -.38786100E+01, 0.29998200E+00, 0.64912400E+00, -.13641100E+01, 0.89947200E+01, -.11418900E+01, -.58569200E+01, -.12698700E+01, -.10988600E+01, -.43219300E+01, -.49643500E+01, -.95820100E+00, 0.10906600E+01, -.17548400E+02, 0.68297200E+01, -.64729100E+00, -.41964900E+01, 0.16887300E+01, 0.35879300E+00, 0.55191100E+01, -.66699800E+01, -.18882200E+01, 0.76252100E+00, -.11830500E-02, 0.12829700E+01, 0.11623700E+01, -.13553900E+02, 0.88123400E+01, -.55654900E+01, -.48460400E+01, -.15309200E+01, -.36088200E+00, -.18798300E+00, -.98481600E+00, 0.47507400E-02, -.24311400E+01, 0.73262000E+00, -.40858100E+01, -.15159700E+01, 0.57726600E+01, 0.34191200E+00, 0.36454400E+01, -.17121900E+01, -.56967200E+00, -.67624400E+01, -.77807600E-01, 0.23116500E+00, 0.34458000E+01, -.70346700E+00, -.24782300E+01, -.19116100E+01, 0.78256100E+00, 0.19670400E+01, -.22901200E+01, -.38304900E+01, -.71844700E+00, 0.19145700E+00, -.10570100E+01, -.12455600E+00, -.19848500E+01, -.22576000E+00, -.79508000E+00, 0.96767700E+00, 0.31811900E+00, -.39892400E+00, -.56326000E+00, -.64301800E-01, 0.10690800E-01, 0.67031000E+00, 0.23217100E+02, 0.43701400E+01, 0.52716600E+00, 0.58069500E+00, -.23329500E+01, 0.19738200E+01, -.10328400E+01, 0.27306400E+01, -.26233500E+00, 0.21079600E+00, 0.12224000E+01, -.13010500E+01, 0.17063000E+01, 0.15274500E+01, 0.80397000E+00, 0.20918000E+01, 0.16791800E+01, 0.14432700E+02, -.36116600E-01, -.18096500E+01, -.45375600E-02, 0.14920300E+01, 0.77574600E+00, -.60161100E+00, -.32509900E+00, 0.22887500E+00, 0.21604500E+01, 0.31600400E+01, 0.93204300E+00, -.11322400E+00, -.82299600E+00, 0.56166100E-02, 0.47011500E+00, 0.31043000E+01, -.74186000E+01, -.19519900E+00, -.10693700E+01, -.12829500E+01, -.11751400E+01, -.45044100E+00, -.45590200E+00, 0.16685800E+01, -.28145700E-01, 0.36700100E-01, 0.78867300E-01, 0.31539500E+00, -.11073100E+01, -.49978200E+01, 0.61762700E+00, 0.54985900E+00, 0.79562200E+00, 0.78474900E+00, -.53798600E+01, -.23310500E+00, -.14448900E+01, 0.33293400E+01, -.25907000E+01, 0.46788200E-01, 0.53604800E+00, -.12888900E+01, -.73063300E+00, 0.33074500E+00, 0.10319200E+01, -.25510600E+00, -.37949900E+00, -.11566700E+01, -.63439600E+00, -.40570300E+01, -.90720900E+00, 0.38588400E+01, -.19367100E+01, -.10223000E+00, 0.36490500E+01, 0.87267500E+00, -.13153200E-01, -.75823200E+00, 0.27884300E+01, -.18173700E+01, -.88250800E+01, -.10905200E+01, 0.73215000E+00, -.18409500E+00, 0.31774000E+01, 0.12205700E+00, -.14261900E+01, -.36872400E-01, 0.17073100E+00, 0.85937200E+00, -.54351900E+00, 0.34873200E+01, -.59075600E+00, 0.15169300E+01, -.14595400E+01, -.80676400E+00, 0.41039600E+00, 0.79550300E+00, -.10947700E+00, -.63656900E-01, 0.15269800E+00, 0.52795800E+00, -.69680700E+00, 0.28664100E+00, -.67552100E-01, 0.15423500E+00, 0.22798700E+00, 0.12045400E+04, -.59823000E+03, -.36455200E+03, -.60606900E+03, -.18704900E+03, 0.11664700E+03, -.21064300E+03, 0.29724400E+03, -.23871400E+03, -.22817600E+01, -.74287000E+02, 0.13825100E+04, -.67863000E+03, -.76291000E+02, -.82260600E+03, -.17651600E+03, -.53411900E+02, -.14855300E+03, 0.55749400E+03, -.13004200E+03, -.41638400E+02, -.12267000E+03, 0.16344700E+01, 0.48629600E+02, -.14308700E+02, -.27371300E+02, -.33274500E+02, -.32686800E+02, 0.23072400E+00, 0.14207200E+02, -.28606500E+01, -.80778100E+01, -.13487900E+02, -.34299300E+02, 0.43436700E+01, -.33834600E+02, 0.32963700E+02, -.11467400E+02, 0.10583300E+01, 0.13724200E+01, 0.99105300E+01, 0.32588100E+02, -.14573400E+01, -.22109300E+01, -.81526600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.38044100E+01, 0.12741300E+01, -.13292400E+01, -.30435900E+00, -.41586900E+00, 0.26299400E+01, -.10644400E+01, -.13659900E+01, 0.18299100E+02, 0.87752800E+00, -.47490200E-02, 0.85516200E+00, -.67554800E+00, 0.23057900E+00, -.20188100E+01, 0.16189700E-01, 0.58746600E+00, -.76458000E+01, -.10661000E+01, -.16156900E+01, 0.20288400E+01, -.78926500E+00, -.15041800E+01, -.15905900E+01, -.11522900E+01, -.12670600E-01, -.24943200E+00, -.10423600E+00, -.53709300E-01, 0.12348600E+00, -.63270400E+00, 0.21531800E+00, -.41510400E-01, -.28830800E+00, -.44415500E+00, 0.85101500E-01, 0.66956300E-02, 0.49540400E+00, -.61291500E+00, -.21839700E+00, 0.10680900E+01, -.54280800E+00, -.17657700E+01, -.13905000E+01, 0.46144100E+00, 0.32537800E+00, 0.26363800E+00, 0.10885000E+00, -.15062600E+00, -.71221200E+00, 0.38695000E+01, -.65428200E+00, -.31870200E+00, 0.18900900E+01, -.21146400E+01, 0.55208500E+00, -.18823100E+01, -.34597800E+00, 0.26951400E+00, -.46949900E+01, -.26702700E-01, 0.32868200E+00, -.14003000E+01, 0.93262200E+00, 0.27363900E+01, -.28655300E+00, -.10218500E+02, -.21435500E+01, -.17998300E-01, -.80746900E-03, 0.36768200E+00, 0.13776200E+01, 0.35756600E+01, 0.13244800E+01, 0.13633700E+01, -.92170800E-01, -.27380400E+00, -.45382700E+00, -.24853700E+00, 0.65954200E-02, 0.49298800E-02, -.23294400E+01, 0.50055400E+00, 0.50642100E+00, 0.22237900E+01, 0.56176100E+00, 0.84882000E-01, 0.42448200E+01, -.74469300E+00, 0.77521400E-01, 0.19615200E+01, 0.22137800E-01, -.27695500E+00, 0.73962000E+00, 0.22643800E+00, -.25599000E+00, -.85194200E+00, -.52238900E-01, -.34850600E+00, 0.31354400E+01, 0.17881700E+01, 0.36999100E-01, -.92533500E-01, 0.10046200E+01, -.88845100E+00, 0.23719000E+00, 0.59052000E-01, 0.10974600E-01, -.15093700E+00, -.18462800E+00, 0.21953000E-01, -.53119400E+00, 0.84262400E+00, -.26805600E+00, 0.23269800E+00, -.22980700E+01, -.16338800E+00, -.18369500E-02, 0.62618100E-01, -.66383400E+00, -.61187900E+00, -.33977200E+00, 0.14017400E+01, 0.49576300E+00, -.17852700E-01, -.37581000E+00, 0.93113600E+00, 0.13333200E+00, -.53872600E-01, -.11223700E+01, -.57960900E+00, 0.12242800E+01, -.13103500E+01, -.29177500E-01, -.56659200E+00, 0.21640000E-01, 0.40338700E-01, 0.28292000E+00, -.47175800E+00, 0.96923400E-01, 0.93005500E+00, -.87286400E+00, 0.35094100E+01, -.11232200E+00, 0.76288300E-01, -.10502900E+01, 0.26583800E-02, 0.16558000E+01, 0.11423500E+00, 0.75762300E+00, -.26752700E+00, 0.59523900E+00, -.39052500E+00, 0.23173800E-01, 0.21417400E+00, -.10930700E+00, 0.93283400E+00, 0.23713700E-01, 0.42701500E+00, 0.20966000E+00, 0.41601300E-01, 0.19308000E-01, -.12489100E+01, 0.38515900E+00, -.91641200E-02, 0.36004300E+00, 0.85280900E+00, -.40601800E+00, -.27022000E+00, 0.29618700E-01, 0.46753500E+00, -.48079600E+00, -.94062000E+00, -.12827300E+01, -.67058700E+00, 0.24938100E+00, 0.33175300E+00, 0.40743400E+00, -.19859200E+00, -.22210700E-01, 0.83171800E+00, 0.10048600E+00, 0.37558800E+01, 0.35136300E+00, 0.26474600E+01, 0.14807100E+01, 0.20732200E+00, 0.37761100E+00, -.23273500E+00, 0.19427500E+00, -.13653600E+00, -.12144400E+01, -.60517300E+01, 0.97196900E+01, 0.58953100E+00, 0.62363400E-01, 0.19350200E+00, 0.69525700E+00, -.32753400E+00, -.36582900E-01, 0.33616700E+00, -.18799700E-01, 0.11392200E+00, 0.48526800E-01, -.21261200E+01, 0.34784600E+00, 0.20746700E+00, -.76895500E-01, -.44925600E-01, -.15803200E+00, -.61245300E-01, 0.38508700E+00, -.37204300E-01, 0.14792100E+00, 0.50385100E-01, -.19368100E+00, -.31618200E-02, -.75124600E-01, 0.94796700E-01, 0.59706700E-01, 0.39387800E-01, 0.12982200E+02, 0.19880500E+01, -.19294800E+00, -.19477600E+02, 0.25996500E+01, -.95435900E+01, 0.15398100E+02, 0.37531300E+01, 0.71084100E+01, 0.13487500E+03, 0.18474300E+03, -.87815200E+02, -.82618300E+02, -.11472800E+03, 0.57662100E+01, -.11730800E+02, -.28212200E+02, 0.68075400E+02, -.18886900E+02, -.47866200E+01, -.27721800E+02, -.17610700E+00, 0.74015700E+01, 0.97646000E+00, -.10301500E+01, -.27282600E+01, -.19551600E+01, 0.47471200E+00, -.10377400E+01, -.54984000E+00, -.10466600E+00, -.10422000E+01, -.11104100E+01, -.42513900E-01, -.26287700E+01, 0.23603700E+01, -.61417300E+00, -.24393600E+01, 0.20283900E+00, 0.15514700E+01, 0.19725000E+01, 0.28291300E+00, 0.62607600E+01, -.11173800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30782800E+01, -.28998400E+01, 0.38428600E+01, -.18270600E+01, 0.30757900E+00, 0.19667300E+00, -.46289700E+00, -.38381300E+01, -.47897700E+02, -.10409200E+01, 0.34324400E+00, -.13864200E+01, -.29454700E+00, 0.63499900E+00, 0.10966100E+01, 0.95225300E+00, 0.18869000E+01, 0.14380700E+01, -.49786500E-01, 0.53045200E+00, -.26737300E+01, -.52078000E+00, 0.16170100E+00, 0.33071500E+00, 0.68827800E+00, -.17352400E-02, -.17382400E+00, -.72652200E-01, 0.30474100E+00, 0.27640800E+00, 0.36817000E+00, 0.19572900E+00, 0.21863300E+00, 0.22917200E+00, 0.20200700E+00, -.37547500E-02, -.11291100E-01, -.45624700E+00, 0.14950400E+00, -.63570500E-01, -.44234300E+00, 0.20749600E+00, 0.57217200E+00, 0.12463200E+00, -.51058400E-01, -.16045900E+00, 0.21376600E+00, 0.13230200E-01, -.38929600E+00, 0.22748800E+00, -.12070600E+01, 0.62812800E+00, -.11357700E+00, 0.53241700E+00, 0.40573500E+00, -.28141100E+01, -.10574800E+01, 0.20089500E+00, -.54175400E+00, 0.98856700E+00, -.14252500E+01, 0.24828500E+00, -.21934600E-01, 0.11709500E+01, 0.20983800E+01, -.16533700E-01, -.13163100E+01, -.68015000E+00, -.13866000E+00, 0.23013600E-03, -.18464300E+00, 0.15439700E+01, -.22784200E+01, -.28237700E+01, -.22933000E+00, 0.10787900E+01, 0.17562100E+01, -.23407300E+00, 0.33178700E+00, 0.40442100E-01, -.39520700E-02, 0.12520800E+01, 0.41800800E+00, 0.15259300E+01, -.63324200E+00, -.15841400E+01, 0.17006100E+00, 0.33730300E+01, 0.40753200E-01, -.11734800E+00, 0.23371600E+01, -.35267400E-01, -.10340900E+00, 0.10693000E+01, 0.34244500E+00, -.81020800E+00, -.10456200E+01, 0.34212300E+00, 0.68780900E+00, 0.21415500E+01, 0.19293100E+01, -.90503100E-01, -.12985500E-01, -.48691700E-01, -.34955200E+00, 0.16736100E+01, 0.25546900E+00, 0.17210200E+00, 0.21539700E+00, -.14496500E+00, -.92841000E-02, 0.10717900E+00, 0.41350600E+00, -.13018700E+00, 0.11771200E-01, 0.13900300E+01, 0.26078300E+00, -.17206800E+00, -.45874800E-01, -.71368400E+00, -.28666200E+00, 0.90617000E-01, 0.44933100E+00, 0.18264300E-01, -.41415600E-01, 0.42039300E+00, 0.10541400E+01, -.22235800E+00, -.63807900E+00, 0.20068200E-01, -.34693400E+00, -.49625400E+00, -.34398300E+01, 0.90104100E-01, 0.67771200E-01, 0.32156900E-01, 0.68370100E-01, 0.10442400E+00, -.91655100E-01, 0.25929900E-01, -.35828800E+00, -.41979200E+00, 0.17304100E+00, 0.76476600E-02, 0.24380800E+00, 0.11751700E+01, -.22753400E-03, -.90931100E-01, -.97725000E+00, 0.13870100E+01, 0.58355400E-01, 0.19401800E+01, 0.10066800E+01, -.11826500E+00, 0.41118700E+00, 0.19788900E+00, -.24107200E+00, -.21967400E-01, -.60109700E-01, 0.16987900E-01, 0.18758800E+00, -.15140800E+01, 0.95127400E+00, 0.95948500E-01, 0.66960000E-01, -.25461700E+00, 0.12774400E+00, 0.17836700E+01, -.45066300E-01, 0.46330500E+00, 0.27213800E+00, 0.73034500E+00, -.11802700E+00, -.67521600E+00, -.62402900E+00, 0.36111200E+00, 0.28071800E+00, 0.10204800E+00, 0.25907700E-01, -.11715400E-01, -.93291700E+00, 0.26191300E-01, 0.25734400E+01, -.11931800E+00, 0.64106700E+00, -.28202300E+00, -.23350000E-01, 0.11354200E+01, 0.60075800E-01, 0.12132600E+00, -.14795200E-02, -.11008000E+00, -.19362500E+01, 0.57833100E+01, 0.39882900E+00, 0.79403700E-02, 0.30536300E-01, -.86503400E+00, -.24442700E+00, -.33458700E+00, 0.11876300E+00, -.14874300E-01, 0.22612800E+00, 0.12994700E-01, 0.35329000E+00, -.77349200E-01, -.33357100E+00, -.21379600E+00, -.19657000E+00, -.13116200E+00, 0.20589000E+00, 0.21640400E+00, -.52163600E-01, 0.28119400E+00, 0.38004800E+00, -.35518400E+00, -.42978200E-01, -.25075400E+00, 0.57331200E-01, 0.10827900E+00, -.52276500E-01, -.28656800E+00, 0.10140800E+03, -.70735700E+01, -.17624000E+02, 0.45904300E+02, -.13600100E+02, 0.37807300E+02, 0.15793000E+02, 0.55425400E+02, 0.32327000E+03, 0.26009000E+03, -.11913300E+03, -.31537600E+02, -.22983200E+03, 0.61306800E+02, -.38021400E+01, -.59618900E+02, 0.76648500E+02, -.17647900E+02, 0.87303800E+01, 0.71624700E+02, 0.41190100E+01, 0.13995400E+02, 0.12123900E+02, -.46751600E+01, -.73013300E+01, -.51951800E+01, 0.51325800E+01, -.12363900E+02, 0.86198800E+00, 0.47133900E+01, -.70106500E+00, -.51549600E+01, 0.55104600E+01, -.71738500E+01, 0.65186500E+01, 0.24060400E+01, 0.77046300E+01, -.38314600E+01, 0.76902500E+01, 0.54753100E+01, 0.40580000E+01, 0.23428500E+02, -.24056100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37885300E+01, -.27805900E+01, -.99431400E+00, -.36698100E+00, 0.13823300E+01, 0.96661000E+00, -.77937500E+00, 0.62549900E+00, 0.50452900E+02, -.12943500E+01, -.19370200E+00, 0.14117500E+01, 0.11174300E+01, 0.18964900E+00, -.16876800E+01, 0.30649700E+01, 0.28387100E+01, -.59299500E+01, -.61747400E+00, -.38100400E+01, 0.47512000E+01, -.89812400E+00, 0.13641200E+01, -.10431300E+01, -.15701500E+01, -.19860700E+00, -.35853700E+01, -.88389800E+00, 0.56629400E+00, 0.17027700E+00, -.25539500E+00, -.12302000E+00, 0.18357300E-01, -.14685600E-01, -.10253300E+00, 0.38609100E-01, 0.10237500E-02, 0.29097300E+00, -.67023800E+00, -.13058900E+00, 0.89164300E+00, -.34868300E+00, -.18061100E+01, -.12755100E+01, 0.37160000E+00, 0.28308800E+00, 0.63718000E+00, 0.90159700E-01, -.49905600E+00, -.50195600E+00, 0.63165500E+00, -.97032900E+00, 0.65625300E+00, 0.18414700E+01, -.11467700E+01, 0.29311900E+01, -.25347800E+00, -.56702300E+00, 0.37850800E-01, -.36470900E+01, 0.41949800E+00, 0.28626400E+00, 0.27583400E-01, 0.61864300E+00, 0.16945600E+01, -.29507100E+00, -.50329400E+01, -.17140100E+01, -.13335600E+00, -.16708400E-02, 0.23282200E+00, 0.12347000E+01, 0.29475800E+01, 0.14987000E+01, 0.10296000E+01, -.59992800E+00, -.15028100E+00, -.70537200E+00, -.22912000E+00, 0.13185800E-01, 0.29650700E-02, -.17590500E+01, 0.32247100E+00, 0.24712800E+00, 0.15393100E+01, 0.90467400E+00, 0.96526200E-01, 0.31803300E+01, -.92235000E+00, -.13472200E+00, 0.14131400E+01, 0.18670200E-01, 0.19908400E-01, 0.71292500E+00, -.42963400E+00, 0.37100200E+00, -.11934000E+01, -.91900700E-01, 0.70713200E-01, 0.11505000E+01, 0.66035700E+00, 0.18487800E-02, -.47188100E-02, 0.12561800E+00, 0.93681600E-01, 0.10498600E+01, 0.38652000E+00, 0.19203000E+00, 0.54927200E-01, -.29974300E-01, -.20615400E-02, -.66629700E-01, -.10372000E+00, 0.33525300E-01, 0.21473600E-01, 0.12606800E+01, 0.42184600E+00, -.64051900E-01, -.63819600E-01, -.19742500E+01, -.53344000E+00, -.20752100E+00, 0.16951200E+01, 0.50643400E+00, -.71699700E-01, -.42923000E-01, 0.83956500E+00, 0.33993000E+00, 0.38262800E+00, -.65409400E+00, -.37920000E+00, 0.11638900E+01, 0.29072900E+00, 0.85620600E-01, -.13923100E+00, -.27660900E-01, -.44903600E+00, 0.33847600E-01, -.56689400E-01, 0.45213300E-02, 0.27948200E-01, -.33211300E+00, 0.11242500E+01, -.95446800E-01, 0.83575600E-01, 0.17720300E+00, -.26321000E-01, 0.44302500E+00, 0.18090500E+00, -.54401200E+00, 0.77089000E-02, 0.98648100E+00, -.70867600E+00, -.20225800E+00, 0.17435100E+00, 0.89646300E-01, 0.41729000E+00, -.13124700E-01, 0.34513300E+00, -.14623200E+00, -.10232600E-01, -.85786900E+00, -.56088300E+00, 0.31721800E+00, -.90336200E-01, 0.20455100E+00, 0.50474300E+00, 0.40161500E+00, -.17978300E+00, 0.11353700E+00, 0.33877800E+00, -.25831400E-01, -.50873700E+00, -.25423900E+00, -.61653000E+00, 0.23686200E+00, 0.35886800E-01, 0.26713500E+00, 0.91051200E-01, -.94908600E-01, 0.72283000E+00, 0.45948700E-01, 0.44449200E+01, 0.74885300E-02, 0.35018100E+01, 0.75199600E+00, 0.58062500E-01, 0.10670500E+01, -.68649500E-01, 0.31697600E+00, 0.27709900E+00, -.56780500E+00, -.18776700E+01, 0.31287900E+01, 0.17897900E+00, -.42788500E-01, 0.11318800E+00, -.12245600E+01, -.46294100E+00, 0.37626600E-01, 0.20979300E-01, 0.31031300E-01, -.26780600E-01, 0.71985200E-01, 0.19879400E+00, -.43293300E-01, -.40254200E-01, 0.72325700E-01, -.34482000E-01, 0.57377600E-01, 0.52899600E-01, -.13665000E-01, 0.39704200E-02, 0.84465500E-02, -.10440900E-01, -.57642900E-01, -.27266900E-01, -.72401400E-01, 0.23702900E-01, 0.21917500E-01, 0.12077000E-01, 0.27814200E+00, 0.49250800E-01, 0.35157200E+02, 0.12716200E+02, -.21591500E+01, 0.37947400E+01, 0.45751500E+01, -.12218600E+01, -.28572200E+01, -.90884900E+02, -.96727700E+02, 0.46126700E+02, 0.53806600E+02, 0.58354000E+02, -.57942900E+01, 0.10170300E+02, 0.66570300E+01, -.38604100E+02, -.16239600E+01, 0.51073500E+01, 0.29414400E+02, -.18853700E+00, -.42745700E+01, -.67709400E+00, 0.96435400E+00, 0.16924800E+01, 0.12847600E+01, -.55530300E+00, 0.76520300E+00, 0.60051200E+00, 0.91246300E+00, 0.99598400E+00, -.43373400E+00, 0.14115800E+01, 0.17374600E+01, -.15435100E+01, 0.85697400E+00, 0.23974900E+01, -.10489000E+01, -.76752800E+00, -.13543700E+01, 0.65480400E+00, -.42579900E+01, 0.63183400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.17994300E+01, 0.37227500E+00, 0.49569200E-01, 0.14502200E+00, -.20612000E+00, 0.15841000E+00, 0.50414700E-01, -.39633400E+00, 0.37543600E+00, 0.51465200E+00, -.29424200E-01, -.76812400E+00, -.40091700E+00, 0.76490400E-01, -.80094800E-01, -.18183700E+01, -.33985000E+01, 0.33194100E+00, -.24882900E-01, 0.50057700E+00, -.36725600E+00, 0.80250300E+00, -.23051400E+01, 0.50023000E+00, 0.90137800E+00, -.22133700E-02, 0.62170900E+00, 0.11599600E+00, -.49243700E+00, -.16003700E+00, -.96025100E+00, -.10300500E+00, 0.61290800E-01, 0.93534500E-01, 0.21657800E+00, 0.83345600E-01, -.27511100E-02, 0.81706800E-01, -.29811400E+00, 0.69550500E-01, -.43520400E+00, -.11586100E+00, -.87139000E+00, -.43642400E+00, 0.89017300E-01, 0.60325700E-01, 0.39873700E-01, 0.75192500E-01, -.33643100E+00, -.16780300E+00, 0.12892000E+00, 0.10826100E-02, -.51658600E+00, -.30393400E+00, -.39681300E+00, 0.16313000E+00, 0.76089600E+00, 0.86282800E-01, 0.11613600E+00, 0.93669900E+00, 0.53562100E-01, 0.48438000E-01, -.27995200E+00, -.59528100E-01, 0.16031500E-01, -.96611800E-01, 0.29164500E+01, 0.16671800E+00, 0.17020100E+00, 0.46152300E-04, -.69282000E-01, -.48646700E+00, -.37221300E+00, -.49454400E+00, -.20302100E+00, 0.43508200E+00, 0.79294600E-01, 0.51079800E-02, 0.17864900E+00, -.58875500E-01, -.68460500E-03, 0.10612600E+01, 0.51290500E-02, -.38992400E+00, -.23801700E+00, -.24390100E+00, 0.69291900E-01, -.60221900E+00, 0.40652400E+00, -.28895400E-01, 0.20027200E+00, 0.57558400E-02, -.30826000E-01, 0.41199200E+00, 0.98795400E-01, -.55397500E+00, 0.14497700E+00, -.42651500E+00, -.90786100E+00, -.11860700E+01, -.12001800E+01, -.41079900E+00, 0.54583700E-01, -.61222600E+00, -.26137800E+00, -.41851700E+00, -.35446800E-01, 0.25173700E+00, -.22391900E+00, 0.29462900E+00, -.10945200E+00, -.96565400E-01, -.28205400E-01, 0.99498100E-02, -.25305600E+00, 0.81969400E+00, -.30746900E-01, -.13496400E+00, -.53964800E-01, 0.21084000E+00, 0.58845400E+00, 0.19342300E-01, -.70572500E-01, -.35008000E+00, -.33354900E-01, 0.51787100E+00, -.40958200E+00, 0.15521400E+00, -.35433800E+00, 0.61892500E-01, -.65358000E-01, -.62529200E+00, -.66011000E+00, -.33833600E-01, 0.13508300E+00, -.20695700E-01, 0.49398500E+00, -.15278600E+00, -.10482100E+00, 0.17506300E+00, -.25600100E+00, -.19664600E+00, -.10359000E+01, 0.19497500E+00, 0.74073300E-01, 0.31374900E-01, -.30924300E-01, 0.30597800E+00, -.26443700E+00, 0.13822800E+01, -.11372200E+00, 0.97628900E+00, 0.78393100E+00, 0.20396600E-02, 0.35424700E+00, 0.20605800E+00, 0.13442500E+00, -.23304100E-01, 0.14825800E+00, 0.24249000E+00, 0.27476100E-01, -.37724400E+00, 0.13825100E+01, -.28412600E-01, 0.23356800E-01, 0.15253100E+00, -.20969400E+00, 0.99311900E+00, 0.51292200E-01, 0.24467700E+00, -.37649000E+00, 0.38031000E+00, 0.18472900E+00, 0.48359300E+00, 0.30966700E+00, 0.63323100E-01, -.23682900E+00, -.24696600E-02, 0.23662300E+00, -.29305700E-01, 0.58280500E+00, -.74619900E-01, 0.13267800E+01, -.24340800E-03, -.95712000E+00, -.49992500E+00, -.81735000E-02, 0.99279900E+00, -.10221000E-01, 0.28781000E+00, 0.13084200E+00, 0.11087800E+00, -.84790300E+00, 0.28805600E+00, 0.42157600E+00, -.44368900E-01, -.41714300E-01, 0.12839500E+01, 0.99564600E-01, 0.14696400E+00, -.14957200E+00, -.19636600E-02, 0.19201800E+00, -.15309600E+00, 0.10418300E+00, -.34031900E-01, -.12787700E+00, 0.14468000E+00, 0.30173400E-01, -.19263500E+00, 0.35182200E-01, 0.64569000E-01, -.38946500E-01, -.10607700E+00, -.99689900E-01, 0.12707100E+00, -.11830000E-01, -.17226300E-01, -.45468300E-01, -.89467900E-01, -.77844000E-01, 0.16376500E+00, 0.12650100E-01, 0.49825700E-01, 0.57558000E+02, 0.81449300E+01, -.16637700E+02, -.37349800E+02, -.12573300E+02, 0.13297200E+02, -.68000700E+01, 0.51258200E+02, -.26262100E+02, 0.34364300E+01, -.32913800E+02, 0.39148100E+02, 0.60538800E+01, 0.86345100E+01, 0.63510600E+02, 0.19670800E+02, 0.38554800E+01, -.10991300E+03, 0.25123000E+01, 0.19738600E-01, 0.56128900E+01, -.33523700E+00, -.12575700E+01, -.93654900E+00, 0.19192000E+01, -.56530100E+01, -.15820000E+01, -.13146700E+01, -.80733000E+00, -.36755200E+01, -.19784500E+01, -.13443000E+01, 0.11753100E+01, -.26203100E+00, -.14455000E+01, 0.15527700E+00, 0.86969600E+00, -.39117400E+00, -.62746100E+00, 0.32719900E+01, -.33047400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24640200E+01, 0.17842200E+01, 0.13297600E+01, 0.44390100E+00, -.47367800E+00, -.42599200E+00, 0.50051600E+00, 0.36130600E+01, 0.22247200E+02, -.10054200E+01, -.83973800E-01, 0.12452800E+01, -.33461900E+00, -.36911700E+00, 0.21897700E+01, -.38723500E+00, 0.75428000E+00, 0.58169300E+01, 0.12670100E+01, 0.16278500E+01, -.19876000E+00, 0.83323800E+00, -.86164400E+00, 0.10251500E+01, -.13997500E+01, 0.68347600E-01, -.17869900E+01, -.35538100E-01, 0.19076800E+00, -.75213900E+00, 0.40502900E+00, -.61538600E+00, 0.54053600E-01, 0.32384000E-01, 0.10305300E+00, 0.83245800E-01, -.45088000E-02, 0.44107000E-01, -.51655300E-01, -.15263000E-01, 0.44554100E+00, 0.63131300E-01, -.65636100E+00, -.23756700E+00, -.14717600E-01, 0.28638800E-01, -.69569400E+00, 0.45460200E-02, 0.35042400E+00, -.23419700E+00, 0.49000400E+00, 0.30262900E-01, -.21906900E+01, -.50535100E+00, -.10691800E+00, -.22590300E+01, -.51893900E+00, -.23489100E-01, -.11736300E+00, -.10230600E+01, 0.31907300E+00, 0.31916900E-01, 0.55983800E+00, -.24447200E-01, -.90434800E+00, -.80875700E-01, 0.16819500E+01, 0.82343500E-01, -.15769800E+00, 0.10400300E-02, -.14494200E+00, -.10131300E+01, 0.14600500E+01, 0.32076200E-01, 0.85109500E-01, 0.28938000E+00, -.40376300E+00, -.64715000E-01, -.87498700E-01, -.55651900E-01, 0.11610300E-02, -.95137700E-01, -.57889500E-01, -.80818900E+00, 0.92751200E+00, -.60860200E+00, -.18229900E+00, -.39267700E+00, -.21879200E+00, 0.24092700E+00, -.18059500E+01, -.14897600E-01, 0.37821600E-01, -.73837400E+00, 0.47854100E-02, 0.18627500E+00, 0.11179500E+01, -.50556400E+00, -.18990400E+01, 0.12444800E+01, 0.11939100E+01, -.57303900E-01, 0.49879700E-01, -.86337400E-01, 0.22526700E+00, -.10193200E+01, 0.15259100E+00, -.63532500E+00, 0.55165900E-01, 0.18884600E-01, -.49816800E-01, 0.13183200E+00, -.84643500E+00, 0.26746600E+00, -.95638200E-01, 0.11418700E+01, -.63165400E+00, 0.13659900E+00, -.26884200E+00, -.45945800E+00, 0.27463100E-01, -.13916000E+00, 0.84107600E+00, -.13551200E+00, -.21334300E-02, 0.14401500E+00, -.18140800E+00, 0.84782000E-01, 0.18775400E+00, 0.65288300E+00, -.43219700E-01, 0.48525700E+00, 0.14654500E+01, -.11186600E+00, -.43643300E-01, 0.42031500E-01, 0.97882100E+00, -.53645700E+00, 0.21390400E-01, 0.25717200E+00, -.23030000E+00, -.11204400E+01, -.14356600E+01, 0.28269400E+00, -.76521700E-01, -.74378900E+00, 0.11885700E-01, 0.73631600E+00, 0.28334500E+00, 0.69885800E+00, -.12234600E+00, -.93690900E-01, -.29499800E+00, -.50701400E-01, 0.35020200E+00, 0.18704700E+00, 0.77555700E+00, 0.32660100E-01, 0.93447600E-01, -.16581400E+00, -.13517900E-02, 0.27147500E+00, -.96726500E+00, 0.41371400E+00, 0.19098000E+00, 0.20808100E+00, 0.35341600E+00, 0.14362800E+01, -.89581700E-01, -.75513300E-01, 0.43599700E+00, -.48400800E-01, -.19996700E+00, -.10025300E+01, -.62865600E+00, 0.21480300E+00, 0.18891600E+00, -.82900400E-01, 0.11675200E+00, 0.64170200E-02, 0.16699300E+00, -.24459700E+00, 0.15750500E+01, 0.16138600E-01, -.39750200E+00, -.41256100E+00, 0.15800700E-01, 0.22663700E+00, -.35202200E-02, -.55720400E+00, -.22419600E+00, 0.37174700E+00, 0.29212900E+00, 0.17770000E+01, 0.39878700E+00, -.14106100E-01, 0.15484200E+00, 0.10035400E+01, 0.11319900E+00, 0.22973200E+00, -.87476700E-01, 0.11575700E-01, 0.27368100E-01, -.30187000E+00, -.44013500E+00, 0.23077900E-01, -.72112600E-01, -.60498400E-01, -.55207700E-01, -.69385100E-01, 0.40144000E-01, 0.26593900E-01, -.17199200E-01, -.36556000E-01, 0.26007500E-01, 0.31330400E-01, -.15020500E-02, 0.19825100E+00, 0.97307700E-01, -.43987600E-01, 0.21493700E-01, 0.17270900E+00, -.29463800E+00, -.25367000E-03, 0.44741300E+00, 0.44314200E+02, -.20573800E+02, 0.62036100E+01, -.11682200E+02, 0.26231200E+02, 0.10548300E+03, -.68549700E+00, 0.82156600E+00, 0.43121900E+02, 0.23047200E+01, 0.24789900E+02, 0.33542400E+02, -.19454300E+02, 0.33569600E+02, -.33013200E+02, 0.20379200E+02, 0.37586000E+02, 0.20829100E+01, 0.11823600E+02, 0.22059800E+01, -.34700500E+01, -.38715000E+01, -.35628500E+01, 0.16022800E+01, -.22461900E+01, 0.49478400E+01, 0.34443500E+01, 0.23723400E+01, -.53069300E+01, 0.45317000E+01, -.40559300E+01, 0.40944100E+01, 0.26471000E+01, 0.42990500E+01, -.20613300E+01, 0.32522200E+01, 0.37752500E+01, 0.17719600E+01, 0.20585700E+01, -.11933800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.84331700E+00, -.44608200E-01, -.27825000E+00, -.12742800E+01, 0.45332800E+00, 0.56475400E+00, -.18161900E+00, -.13035900E+01, -.90507800E+01, 0.31877100E+00, 0.12750100E+00, -.35744400E+00, 0.38935600E+00, 0.13046700E+00, -.13311100E+01, 0.20571900E+00, 0.82008700E+00, -.60456900E+00, -.19473200E+00, -.23539600E+00, -.15832700E+00, -.17961800E+00, 0.18296500E+01, 0.30271300E+00, -.38798500E+00, 0.49019600E-01, -.55786200E+00, -.75996900E-02, 0.65791400E-01, 0.35872200E-01, 0.14905000E+00, 0.24077200E+00, -.98573900E-01, -.16856900E+00, -.58119800E+00, -.96532500E-01, -.15059300E-02, 0.33259500E+00, 0.99382900E+00, -.26217000E+00, 0.38955800E+00, 0.53968000E-01, -.86802200E-01, 0.10618200E+00, 0.81944700E-01, -.24761900E-01, -.66383400E-01, 0.19688900E-01, -.11867600E+00, -.14906100E-01, 0.16815800E+00, 0.23988800E-01, -.25561500E+00, 0.36149200E+00, -.62973300E-01, -.17936900E+00, -.40819500E-02, 0.30793700E-01, 0.56841000E-01, 0.99029900E+00, -.40789700E+00, -.36112000E-01, -.40680500E+00, 0.44509200E-02, 0.28353000E+00, -.48045000E+00, 0.11625500E+01, 0.26286600E+00, -.35064100E-01, -.81897200E-03, -.17665000E+00, 0.29335800E+00, -.13862600E+01, 0.26605000E+00, -.32424800E+00, -.27142500E+00, 0.49153700E+00, 0.86200400E-01, 0.65881000E-01, 0.47935500E-01, -.30604100E-02, 0.18449300E+01, -.30874800E-01, 0.49336100E+00, -.13719000E+00, 0.60406900E-01, 0.10560700E+00, -.20476800E+00, 0.21525600E+00, -.91940100E-01, 0.13182400E+01, 0.19040200E-03, 0.18186500E+00, 0.24033400E+00, -.23946800E+00, 0.26801400E+00, -.23330800E+00, -.24045600E+00, -.40797000E-02, 0.56679100E-01, 0.22914900E+00, -.17008100E+00, 0.61191900E-01, -.53051800E+00, 0.40898500E+00, 0.74345100E+00, -.24158800E-01, 0.17528000E+00, 0.17352100E+00, 0.91498600E-01, -.37630100E-01, -.28454200E-01, 0.26114800E+00, -.83704700E-01, -.68148000E-01, 0.14655800E+01, 0.85762500E+00, -.16945000E+00, 0.58228600E-01, 0.49724300E+00, 0.19144300E+00, -.12952300E+00, 0.23704700E+00, 0.17996000E-01, 0.63923700E-01, -.37681100E+00, -.57321900E+00, 0.15100900E+00, -.13022300E+00, -.54421500E-02, -.23115100E+00, -.20607900E+00, -.12095200E+01, 0.89431800E-01, 0.22340600E-01, 0.48312800E-02, -.29211300E+00, -.39202800E-01, 0.48305000E-01, 0.68423800E-01, -.35962000E+00, -.43518400E+00, -.47846600E+00, 0.20044300E+00, -.72125800E-01, -.71010400E-01, 0.13325900E-01, 0.35706900E+00, 0.27745400E+00, -.91155800E+00, 0.24901600E-01, -.11824300E+00, -.31681700E+00, -.10968900E+00, -.13485600E+00, -.83796800E-01, -.16749900E+00, 0.85675300E-02, -.10098300E+00, -.17500600E+00, 0.23385600E-01, -.33446800E+00, 0.34782000E+00, -.60194300E-02, 0.40303300E-01, -.17719600E+00, -.59329400E-01, -.21081300E+00, 0.30455800E-01, -.24068700E+00, 0.29552200E+00, -.65223300E-01, 0.51371100E-01, 0.67635600E+00, -.10136300E+00, -.24006200E+00, 0.46602100E-01, 0.34855600E-01, -.51910900E-01, 0.33024200E-01, -.37410800E+00, -.17281000E-02, 0.11007600E+00, -.59964000E-01, 0.13094800E+01, 0.28067100E+00, -.13172500E-01, 0.51918200E+00, 0.43933500E-01, 0.15793600E+00, 0.47059000E-01, 0.12432100E+00, -.32469200E-01, 0.53613700E-01, 0.26980100E-02, -.10041200E-01, -.72621200E-01, -.34535700E+00, 0.63379700E-02, -.89660400E-02, -.28433400E-01, -.18138700E-01, 0.10949500E+00, 0.27136400E+00, -.19271100E+00, 0.83654800E-01, 0.89196100E-02, -.11622500E+00, 0.10626500E+00, 0.21882300E+00, -.62063900E-01, -.44660000E-02, 0.44178000E-01, -.72030100E-01, -.96951300E-01, -.49582900E-01, 0.12536800E+00, -.15022000E+00, 0.17373400E-01, 0.65737200E-01, -.12032900E-02, 0.15969900E+00, -.23374300E+00, 0.10899700E-01, -.13510600E+00, 0.42739200E+00, 0.17011400E+02, 0.15525500E+02, 0.22492300E+02, -.12310100E+02, -.24244200E+03, -.99478800E+02, 0.47495000E+02, 0.56579600E+02, 0.59724600E+02, -.51467100E+02, -.10198600E+02, 0.16692700E+02, -.44736800E+02, 0.47304900E+02, -.11826300E+02, 0.19255000E+01, -.13313700E+00, -.96358000E+01, -.57383700E+01, 0.35270100E+01, 0.56259800E+01, 0.44301600E+01, -.11527600E+01, 0.56101400E+01, -.65549800E+00, 0.14282100E+01, 0.12006800E+01, 0.49923100E+00, 0.42874000E+01, 0.57457300E+01, -.50951300E+01, 0.57086700E+00, 0.38808100E+01, -.23704900E+01, -.12388500E+01, -.48801700E+01, 0.78463800E+00, -.79455500E+01, 0.10757800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15246300E+02, 0.17802300E+02, 0.20475000E+01, 0.11161200E+02, 0.81051200E+00, -.34526900E+01, 0.45184300E+01, 0.11406700E+02, -.20765900E+02, 0.63158400E+01, -.46650000E+00, -.32301600E+01, -.33560000E+01, -.96749700E+00, 0.82170700E+01, -.11364200E+02, -.13706300E+02, 0.20767500E+02, 0.54580000E+01, 0.85636000E+01, -.84137100E+01, 0.35627300E+01, -.25804300E+02, -.21304800E+00, -.66676900E+00, -.13313100E-01, -.15867000E+01, 0.73500900E+00, -.10088000E+01, -.26183400E+01, -.14751300E+01, -.52577100E+01, 0.76925000E+00, 0.67507900E+00, -.18777800E+00, 0.41839400E+00, 0.70861800E-02, -.12248000E+01, 0.69389800E+00, -.35252600E+01, 0.20827800E+01, 0.30528400E+01, 0.83395500E+01, 0.77208900E+01, 0.49233800E+00, 0.61292800E+00, -.24881900E+01, 0.34273300E+00, 0.36194800E+01, -.90898100E+00, 0.53799500E+01, -.99859500E+00, -.40606900E+01, -.93382200E+00, -.10466000E+00, 0.30378000E+01, -.18551900E+01, -.43543600E+00, 0.40386700E+01, 0.16448200E+01, 0.74238700E+01, -.14343500E+01, 0.10340200E+00, -.72109100E+00, 0.85069200E-01, 0.25111400E+01, -.45438300E+01, 0.20376900E+01, 0.20195000E+01, -.15319300E-01, 0.18860100E+01, 0.33831700E+01, -.90457400E+01, 0.56976800E+01, -.32171800E+01, -.94921900E+00, 0.33121200E+00, 0.18260800E+00, 0.61988900E+00, -.23907200E+00, -.36637900E-02, 0.49892100E+01, -.61046300E+00, -.37925000E+00, -.70103500E+00, 0.76124200E+01, 0.97765400E+00, -.76192900E+01, -.10071500E+00, -.97549100E-01, -.12537500E+02, -.50433800E-01, 0.20215700E+01, -.45042400E+00, -.40506100E+00, -.23653000E+01, 0.12043300E+01, 0.19754600E+01, 0.21044900E+01, -.96404900E+01, -.93001500E+01, -.30074200E+00, 0.10482700E+00, -.45405900E+00, 0.29541000E+00, -.92292300E-01, -.49137500E+00, 0.15525500E+01, 0.35760800E+00, 0.19916000E+01, -.13802100E+01, -.24196200E+01, -.39051400E-02, 0.20464100E-01, -.35874500E+00, 0.34730200E+02, 0.53501900E+01, -.99027500E+00, -.18755500E-01, 0.37204100E+01, 0.42437000E+01, -.10308700E+00, -.68234700E+01, -.27060900E+01, 0.37712100E+00, 0.25310200E+01, -.38556100E+01, 0.11231700E+01, -.44069800E+00, -.18025900E+01, -.99430400E-02, -.50435100E+01, -.14828200E+02, -.10121200E+01, 0.26339600E+01, 0.91917300E-01, 0.43668800E+01, 0.21498700E+01, 0.54389900E+00, 0.61750000E+00, 0.87456800E+00, 0.10591200E+00, 0.14012200E+01, -.86925500E+00, 0.66688600E-01, 0.16225100E+01, -.29394900E+00, -.33511000E+00, -.57158700E+01, 0.12621700E+02, -.83942500E-01, 0.31704500E+01, 0.78287600E+01, 0.71712300E+00, 0.61971600E+00, 0.37953100E+00, -.15245500E+01, -.27122600E+00, 0.31802600E-01, 0.13920100E+01, 0.13983700E-01, -.63444300E+00, 0.71872000E+01, -.24751000E+00, -.76377200E+00, 0.46802800E+00, -.21573100E+01, 0.23316900E+01, 0.51219400E+00, 0.14236800E+01, -.16142200E+01, 0.40682900E+00, 0.18189000E+01, 0.25134600E+00, 0.35080800E+00, -.75514700E+00, -.29807100E+00, 0.89365800E+00, -.74112600E+00, -.42930300E+00, -.28718100E+01, -.19353200E+00, -.17222300E+02, -.34372500E+00, -.17620700E+02, -.63283200E+01, -.28342900E+00, -.45354100E+01, 0.12921500E+01, -.16011600E+01, -.18861000E+01, 0.34619600E+01, -.48601600E+01, 0.37441400E+01, 0.19555400E+01, 0.28944700E+00, -.73831500E+00, 0.15029900E+02, 0.23051300E+01, -.25702600E+00, 0.48547400E+00, -.22464200E+00, 0.12782900E+00, 0.42416000E+00, -.78705600E+00, -.16679000E-01, -.19120500E+01, 0.84639600E+00, -.36583900E+00, -.99237300E+00, 0.13453700E+01, -.10853900E+00, -.10534300E+00, 0.79732200E+00, 0.36794000E+00, -.11154100E+01, -.39145100E+00, -.74813100E+00, 0.44530700E+00, 0.11593000E+00, -.71823700E+00, -.44813200E+01, 0.12780800E+01, -.12691100E+01, 0.37610300E+00, 0.81961100E+00, -.70818500E+01, 0.42022800E+03, 0.16565800E+03, -.19307300E+02, -.11716400E+04, 0.42908500E+03, -.20783800E+03, 0.47084400E+02, -.39327800E+03, -.26121900E+03, -.15963300E+03, -.10529100E+03, 0.17854700E+03, 0.19748100E+03, -.11156600E+03, 0.16725600E+03, -.59731900E+01, -.51318800E+02, -.24121000E+02, 0.19060600E+02, 0.20019500E+02, 0.17382500E+02, -.64652500E+01, 0.23909200E+02, -.13291500E+02, 0.67445700E+01, -.37987700E+01, -.20273700E+02, 0.32369100E+02, 0.22692100E+02, -.20005400E+02, -.36832700E+01, 0.17314400E+02, -.18895100E+02, 0.27077200E+01, -.21419700E+02, 0.11218700E+02, -.13892800E+02, 0.25097300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39838900E+01, -.20725100E+01, -.21091400E+01, 0.19555200E+00, 0.13725400E+01, 0.79027100E+00, -.90944800E+00, -.39019700E+01, -.41250200E+02, 0.16332700E+01, 0.36488500E-01, -.35597200E+01, 0.40414100E+00, 0.39492700E+00, -.23014900E+01, 0.11839000E+01, -.11220200E+01, -.63557300E+01, -.11922300E+01, -.15376800E+01, 0.63238400E+00, -.66511500E+00, 0.32651700E+01, -.21149500E+00, 0.21507800E+00, -.37614000E-01, 0.32735700E+00, -.68665300E-01, -.10858900E-01, 0.34806100E+00, -.15680300E+00, 0.51670300E+00, -.68099000E-01, -.36043800E+00, -.46945800E+00, -.12343000E+00, 0.75922700E-02, 0.11212400E+00, 0.53800900E+00, 0.52892400E+00, 0.18629900E+00, -.32740700E+00, -.45134600E+00, -.81327600E+00, 0.28439000E+00, 0.36570400E-01, 0.14398700E+01, 0.23336700E+00, -.12202500E+01, -.49939300E-01, -.20273400E+01, -.23192600E-01, 0.14383700E+01, 0.82785200E+00, -.71908200E+00, 0.19045400E+01, -.91447900E+00, 0.82569100E-02, 0.22224500E+00, 0.18135100E+01, -.17732000E+00, 0.23178400E+00, -.96398200E+00, 0.50489500E+00, 0.23520700E+01, -.32146100E+00, -.31898900E+00, -.82719800E+00, 0.87643400E-01, -.22749100E-02, 0.26864900E+00, 0.18077900E+01, -.15499300E+01, 0.13510900E+01, 0.13939400E+01, -.10092300E+01, 0.50270100E+00, -.33904500E+00, -.16206000E+00, -.24665400E-01, 0.39416800E-02, -.10972400E+01, 0.81817000E+00, 0.32157900E+00, 0.13114700E+01, 0.15060000E+01, 0.25082500E+00, 0.54484700E+00, -.45745900E+00, -.12469200E+00, 0.36007200E+01, 0.31534000E-01, -.46629700E+00, 0.24047700E+01, -.17057400E+00, -.76996000E+00, -.23780800E+01, 0.45107000E+00, 0.92553500E+00, 0.33119100E+01, 0.21154300E+01, -.62557700E+00, -.35385300E-01, 0.78562900E+00, -.81001800E+00, 0.30106300E+00, 0.33181000E-02, 0.12891300E+00, -.66252500E-01, -.65421200E+00, 0.25084100E+00, 0.29204800E+00, 0.21186700E+00, -.68815600E-01, 0.28452500E+00, -.14703000E+01, -.32033700E+00, 0.12997800E+00, -.10918300E+00, -.12807600E+01, -.46511300E+00, 0.36747200E+00, 0.80036900E+00, 0.29135300E+00, -.87785000E-02, 0.11467500E+01, 0.83904200E+00, 0.15998000E+00, 0.21470200E+00, -.25706500E+00, -.17629700E+00, 0.17862200E+01, -.14712000E+01, 0.18728300E+00, -.17960200E+00, 0.62462200E-02, -.10034500E+00, 0.22545700E+00, 0.30479900E-01, -.25052000E+00, -.29125400E-01, -.32834400E+00, 0.13380700E+01, -.54511300E+00, -.13368900E+00, -.14410100E+00, 0.38494400E-01, 0.42400800E+00, -.72117000E+00, -.66004300E+00, 0.22521500E+00, -.16385200E+00, -.27125900E+01, -.18206800E+00, -.99524600E-01, 0.49708600E-01, 0.53254300E+00, 0.61705100E-01, 0.14925900E+00, -.33311400E+00, 0.73759100E-01, 0.23777600E+00, 0.17844000E+01, 0.31195300E+00, 0.51756200E+00, -.24225300E+00, 0.35156300E+00, 0.42767500E+00, -.74124200E-01, 0.17335200E+00, 0.24079700E+00, 0.89804800E-01, -.44944600E+00, -.14487200E+01, 0.35430600E-01, 0.33479300E+00, 0.26222100E+00, 0.12793200E+00, -.45739000E+00, 0.13923400E+00, -.70331400E+00, 0.25196900E+00, 0.41871800E+01, -.26953200E+00, 0.91087500E+00, -.17296000E+00, -.87568900E-01, 0.75494200E+00, -.91647400E-01, 0.11944000E+00, 0.52738300E+00, -.13282600E+01, 0.19670200E+01, -.54140100E+01, -.56943600E+00, -.18431800E-01, 0.60780000E+00, -.25184100E+01, -.36612800E+00, 0.29137300E+00, -.23993200E-01, 0.70554300E-03, -.49653600E+00, 0.42575000E-01, -.38751700E+00, 0.34644600E-01, -.33864900E+00, 0.14404800E+00, 0.53964900E-01, -.42056300E-01, 0.10741600E-01, -.11306800E+00, -.33504400E-02, -.19478400E+00, 0.67555600E-02, 0.38106700E+00, -.17282100E+00, 0.60457800E+00, -.50361400E-01, -.12340700E+00, 0.24180800E+00, 0.34659400E+00, 0.63077800E-01, 0.22470500E+00, 0.87163900E+00, -.10716100E+01, 0.15196300E+01, 0.12762400E+00, -.91740000E+02, 0.21319800E+02, 0.65807600E+03, -.10593700E+03, 0.49543400E+02, -.94480700E+02, 0.14245500E+03, 0.15034300E+03, 0.59089100E+02, -.12182600E+02, -.28413800E+02, -.18557800E+03, 0.48040600E+02, 0.19804400E+03, -.10583000E+01, 0.21390300E+02, 0.15189400E+02, -.80530600E+01, -.11059500E+02, -.86835700E+01, 0.14877700E+01, -.14619700E+02, 0.57358400E+01, 0.68582600E+00, 0.47477100E-01, 0.45776800E+01, -.11227500E+02, -.11502800E+02, 0.98047100E+01, 0.19346500E+01, -.28918600E+01, 0.66458000E+01, 0.21066700E+01, 0.11992200E+02, -.11860300E+01, 0.87305800E+01, -.10926500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54770600E+01, 0.28179900E+01, -.17413900E+01, -.71618900E+00, 0.33517300E+00, 0.56878300E+01, -.15352800E+01, -.25545200E+01, 0.28163700E+02, 0.35831400E+01, 0.69373700E-01, 0.16083300E+00, 0.75432500E+00, -.15107500E+00, -.43857600E+01, -.71585500E-01, 0.13772600E+01, -.65825800E+01, -.13859300E+01, -.33511800E+01, 0.23825300E+01, 0.54715200E-03, 0.95189000E+00, 0.11200800E+01, -.64994200E+00, 0.11014600E+00, -.58480400E+00, 0.16694400E+00, -.74187600E+00, -.30371200E+00, -.20503700E+01, 0.78697500E+00, -.28574300E+00, -.42457000E+00, -.21455000E+01, 0.26048300E+00, 0.16633600E-01, 0.13783400E+01, 0.69095500E+00, -.18651900E+01, 0.15284800E+01, -.55233800E+00, -.20903200E+01, -.15764300E+01, 0.53325700E+00, 0.33903900E+00, -.21186100E+01, -.48478800E-02, 0.21512600E+01, -.11217600E+01, 0.75964200E+01, -.16138500E+01, -.45719200E+00, 0.16790200E+01, -.25204500E+01, 0.23957900E+00, 0.22814000E+01, 0.34783600E+00, 0.22511800E+01, 0.65111900E+01, -.56804500E+00, 0.28713200E+00, -.16412300E+01, -.93158800E+00, 0.55720900E+01, -.58066500E+01, -.13467200E+02, -.13180000E+01, 0.61187400E+00, 0.10577200E-02, -.12653400E-01, 0.94181800E+00, 0.45635900E+01, -.12130400E+01, 0.13031800E+01, 0.13431200E+01, 0.10482100E+01, 0.90033100E+00, -.47333100E-01, 0.50103500E+00, -.60212600E-02, 0.46499800E+01, -.16371000E+01, 0.14635500E+01, 0.65654800E+00, 0.11362400E+01, 0.36269200E+00, -.64294200E+01, 0.11402200E+01, 0.44800400E+00, 0.36761800E+01, 0.39922600E-01, 0.77846100E+00, -.15370300E+01, -.12891800E+00, 0.12989200E+01, 0.11044800E+01, -.54836700E+00, 0.10937600E+01, 0.17328100E+01, 0.36310000E+01, 0.23689300E+00, -.16261800E+00, 0.18440600E+01, 0.47818100E+00, 0.25478400E+00, -.37106200E+00, -.45995600E-01, -.48931800E+00, -.40960200E+00, -.43754700E-01, -.40372700E+00, 0.84843800E+00, -.27029700E+00, 0.98747800E-01, -.54644300E+01, -.77301800E+00, 0.31088300E+00, 0.24934800E+00, 0.20799600E+01, 0.51610000E+00, -.25258900E+00, 0.30560700E+00, -.28357300E+00, 0.37134100E-01, -.10441700E+01, -.95291000E+00, -.13219400E+00, -.11061600E+01, -.10049800E+01, -.43832400E+00, 0.86481800E+00, -.31017000E+01, 0.20597900E+00, -.23201300E+00, 0.23121100E-01, -.66613700E+00, -.43560100E+00, -.79769900E+00, 0.37510300E+00, 0.29406200E+00, -.12562100E+01, 0.63860600E+00, 0.12390700E+01, 0.90433400E-01, -.18544500E+01, 0.10412200E+00, 0.25008400E+01, 0.80225800E+00, -.80208500E+00, -.42093300E+00, 0.34557700E+00, -.88882700E+00, -.34818200E+00, -.20337000E-01, -.36007200E+00, 0.13686800E+01, 0.25680200E-01, 0.30217300E+00, 0.77824500E+00, 0.61579300E-01, -.90992900E+00, 0.10285300E+01, -.95250200E-01, 0.29688400E+00, 0.99203900E+00, 0.33858200E+00, -.25496000E+01, -.10357900E+00, -.41321900E+00, -.45727100E-02, -.52208000E+00, -.39089200E+00, -.53221100E+00, 0.27100500E+00, -.81073800E-03, -.11809000E+00, 0.39943600E+00, 0.43653500E+00, 0.69484000E-03, 0.19032600E+01, 0.27259600E-01, -.26816400E+00, -.15506600E+00, -.35732900E+00, -.73545800E+00, -.10041300E+00, 0.17837600E+00, -.16363900E+00, 0.59962400E+00, 0.65618300E+00, -.14110100E+01, -.30314500E+01, -.75824400E+01, -.32543200E+00, 0.35120700E-01, -.18322800E+00, 0.21283900E+00, -.57072700E-02, 0.12736300E+01, 0.56692600E+00, -.26871400E-01, -.89036600E+00, 0.10003500E+01, -.33960900E+01, 0.48293200E+00, -.56410900E+00, -.16605500E+00, 0.52901000E-01, 0.38530700E+00, -.69763700E+00, -.94256900E-02, 0.13632500E+00, -.50098200E+00, 0.83220400E-01, 0.46696200E+00, 0.74490700E-01, 0.93235400E-01, -.57700900E-01, 0.29896500E-01, 0.37366800E-01, -.37927900E+00, -.11537600E+00, 0.11336700E-01, -.18291200E+01, -.11957900E+01, -.25234800E+01, 0.32059300E+00, 0.82812700E+00, -.47213000E+02, -.74952400E+03, -.19286400E+03, 0.79941100E+02, 0.27627100E+03, 0.23589600E+03, -.14718700E+03, 0.44278600E+02, 0.32699700E+01, -.98247500E+02, -.80099000E+01, 0.15733700E+02, -.63723700E+03, 0.18815500E+01, -.28647100E+02, -.36882900E+02, 0.17828200E+02, 0.24754000E+02, 0.22433600E+02, -.25905000E+01, 0.36087200E+02, 0.12820600E+02, 0.17731100E+02, 0.19556800E+02, -.94455900E+01, 0.23463700E+02, 0.24870500E+02, -.23629000E+02, 0.17171700E+02, 0.28067100E+02, -.13988900E+02, -.66493500E+01, -.24211900E+02, 0.85564000E+01, -.46680100E+02, 0.34572400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24914900E+01, -.15066700E+01, -.14775700E+01, 0.31266600E+00, 0.16595700E+01, 0.36031000E+00, -.37165900E+00, -.23541500E+01, -.15862500E+02, 0.11712800E+01, 0.27108300E-02, -.17543800E+01, 0.68981300E+00, 0.22663300E+00, -.14673200E+01, 0.64958000E+00, 0.65077300E+00, -.14905300E+01, -.50330600E+00, -.10255200E+01, 0.10780500E+01, -.17197500E+00, 0.69926800E+00, 0.46124100E+00, 0.33105800E+00, -.25780800E-02, -.33339100E+00, -.21681000E+00, 0.29827000E+00, 0.23283100E+00, -.63531700E+00, 0.26493500E+00, -.13779600E+00, 0.24472500E+00, -.25890200E+00, -.20711200E+00, 0.29277700E-02, 0.52793600E+00, 0.14833900E+01, -.19829900E+00, -.53866700E+00, -.11373100E+00, -.17665500E+00, -.25276500E+00, 0.71855000E-01, 0.80577200E-01, 0.27019600E+00, -.41007600E-01, 0.22664800E+00, 0.66408100E-01, -.33077000E+01, -.70857800E+00, 0.22597400E+01, 0.12417200E+01, 0.82096600E+00, 0.29176000E+01, 0.14903100E+01, -.12093900E-01, 0.35917900E+00, 0.47604500E+01, -.43767800E+00, 0.25087600E+00, -.66438800E+00, 0.54381100E-02, 0.18855900E+01, -.15778500E+01, 0.35886700E+01, 0.37893000E-01, -.16246200E+00, -.36773700E-03, -.41731300E+00, 0.16704500E+01, -.65868200E+00, -.15331200E+01, 0.10011500E+01, -.31053500E+00, 0.16921900E+01, -.15805500E+00, 0.52932800E-01, 0.20490400E-01, -.25469600E-02, 0.70605400E+00, 0.16936900E+00, 0.83572100E+00, 0.40950500E+00, -.26920800E+00, 0.92309200E-01, 0.38181300E+00, 0.23862400E+00, -.17019900E+00, 0.15892500E+01, -.27385100E-01, 0.22880800E+00, 0.23775500E+00, -.14020300E+00, 0.87218400E-01, -.78073600E+00, -.46749500E+00, 0.97503600E+00, 0.53934700E+00, 0.60060400E+00, 0.31820300E-02, 0.21767000E-01, -.17025400E+00, 0.22734500E+00, 0.12317400E+01, -.10526800E+00, 0.36418500E+00, 0.10048100E+00, -.27619400E-01, -.91159000E-02, -.10226400E+00, 0.40853200E+00, -.13088100E+00, 0.41429400E-01, 0.43460000E+00, 0.57938500E+00, 0.22877600E-01, 0.15030200E+00, 0.80086500E+00, 0.32514600E+00, 0.28763000E-02, -.30053800E+00, 0.24952700E-01, 0.72338600E-01, -.46490900E+00, -.51031100E+00, -.39508500E-02, -.35664100E+00, 0.10551000E+00, 0.41893800E+00, -.22435400E+00, -.20087300E+01, 0.13997400E+00, 0.54439000E+00, -.27198000E-01, -.15573500E+01, -.15708600E+00, 0.20782500E+00, -.11176000E+00, -.40789300E+00, 0.73370300E-01, -.68618800E+00, 0.10256800E+00, -.29977700E-01, 0.89683500E-01, 0.17107500E-01, -.38936400E+00, -.80750300E+00, 0.30370200E+00, 0.16032700E+00, -.44225500E+00, 0.18340500E+00, -.25622000E-01, -.82603800E-01, 0.36761100E-01, -.14556800E+00, 0.19400000E-01, 0.18606900E+00, 0.32967200E+00, -.13468300E+00, 0.76823400E-01, 0.95017300E+00, -.36455600E+00, -.36035000E+00, 0.47120900E+00, -.10877500E+00, -.13513000E+01, 0.45432700E-01, -.22310500E-01, -.69951100E+00, -.12369400E+00, 0.31507600E-01, 0.89545700E+00, 0.50413200E+00, -.77613700E-01, -.37439700E+00, 0.74961900E-01, 0.20279000E+00, 0.81405100E-01, 0.84190400E+00, 0.20689900E+00, -.30340100E+00, 0.13669000E+00, -.13663700E+01, 0.14881000E+00, 0.19356100E-01, -.13093900E+01, -.11890500E+00, 0.55091500E+00, 0.38929700E+00, -.10704900E+01, -.44681900E+01, -.76155700E+01, -.21972100E+00, 0.44768300E-01, -.29176100E-01, -.30616700E+00, 0.29904100E+00, -.12301900E+00, 0.30314500E+00, -.36954200E-01, 0.34040700E-03, 0.35145300E+00, -.13642400E+01, 0.24846600E+00, 0.32561900E+00, -.30858000E+00, 0.11008600E+00, -.98369900E-01, -.34065900E+00, -.72414400E-01, 0.21356800E-01, -.81393300E-01, -.15926400E+00, 0.18866000E+00, 0.19374000E+00, -.13242400E-01, 0.76625000E-01, 0.47191000E-02, -.15327700E+00, -.80027900E-01, -.13598900E+00, 0.15469300E-01, -.19151400E+00, 0.13661800E+00, -.55104300E-02, -.94249400E-02, 0.17795000E+00, 0.30846000E+00, -.28466300E+03, -.16606200E+03, 0.83922200E+02, 0.74245400E+02, 0.59279000E+02, 0.13654400E+02, -.17584800E+01, 0.14904500E+02, -.71002700E+02, 0.22289900E+02, -.18990300E+01, 0.10056100E+03, -.20128700E+01, -.95748400E+01, 0.33079400E+01, -.17174200E+01, -.53606900E+00, -.66623100E+00, -.18026000E+01, -.31094900E+01, -.52712400E+01, -.47728600E+01, -.55023900E+01, 0.35207500E+01, -.32546600E+01, -.51901800E+00, 0.48641300E+00, -.59317400E+01, -.39651700E+01, 0.22084700E+01, -.94960400E+00, 0.20166300E+01, -.31531500E+01, -.52204800E+00, 0.11046400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11022600E+02, 0.11074900E+02, 0.20561500E+01, 0.76247500E+01, -.73340900E+00, -.37874200E+01, 0.28558200E+01, 0.84617800E+01, -.60085100E+02, 0.28786000E+01, -.37217400E+00, -.35918700E+01, -.33725200E+01, -.68799900E+00, 0.83211800E+01, -.75575600E+01, -.11068000E+02, 0.13284400E+02, 0.36001800E+01, 0.79680400E+01, -.83387400E+01, 0.22291300E+01, -.17903800E+02, 0.12666300E+01, 0.10995600E+01, -.33099500E-01, 0.25939100E+01, 0.72588400E+00, 0.87130700E-02, -.15334600E+01, -.77118800E+00, -.32943000E+01, 0.47054400E+00, -.12526000E+00, -.12225500E+01, 0.26195300E+00, 0.13206400E-01, -.79629700E+00, 0.21765900E+01, -.24279100E+01, 0.10984400E+01, 0.29763700E+01, 0.81102700E+01, 0.55165300E+01, 0.40032900E+00, 0.83704400E+00, -.13826500E+01, 0.55314600E+00, 0.31025100E+01, -.97823300E+00, -.11451100E+02, -.32949100E+01, 0.12904100E+01, 0.14001200E+01, 0.19359500E+01, 0.47126500E+01, -.11653400E+01, -.19960600E+01, 0.17597600E+01, -.17468700E+02, 0.97528700E+01, -.46459300E+00, 0.42946300E+01, 0.72551900E+00, -.46061400E+00, 0.64696000E+01, 0.36779900E+01, -.72529400E+00, -.18239600E+00, -.16262100E-01, 0.79097000E+00, 0.23702400E+01, -.12201800E+02, 0.34201500E+01, -.30791100E+01, -.50205600E+01, 0.23018800E+01, -.86294600E+00, 0.33917100E+00, -.12542300E+01, 0.69227200E-03, -.24599900E+01, 0.73239300E+00, -.21444400E+01, 0.30042600E+00, 0.52262000E+01, 0.62271000E+00, 0.55132200E+01, -.17307300E+01, -.65947800E+00, -.61122100E+01, -.70208600E-01, 0.28773900E+00, 0.33327200E+01, -.10054900E+01, -.15208900E+01, -.13484700E+01, 0.96214600E+00, 0.94118900E+00, -.16488500E+01, -.67195500E+01, 0.65145900E-01, 0.35220000E+00, -.19103800E+01, 0.13099600E+01, -.25693600E+01, -.45191900E+00, -.26005500E-01, 0.11979800E+01, 0.58146100E+00, -.51280900E+00, -.45556000E+00, -.11630600E+01, 0.36219400E+00, 0.84713900E+00, 0.22920300E+02, 0.54887900E+01, -.31614400E+00, -.18897400E+00, -.19414100E+01, 0.10529200E+01, -.28896000E+00, -.13431600E+01, -.37907000E+00, 0.29107900E+00, 0.16340100E+01, -.56598500E-01, 0.66831500E+00, -.37743100E+00, -.59523000E+00, 0.10860400E+01, -.10955600E+01, 0.45267000E+01, -.54417700E+00, 0.88141400E+00, 0.24368700E+00, 0.25299400E+01, 0.15469500E+01, 0.11963300E+01, 0.35760300E+00, 0.25778800E+01, -.94222400E-01, 0.44677100E+01, -.12412300E+01, -.37379700E+00, -.22844300E+00, 0.28732300E-01, 0.56832200E+00, 0.10022300E+01, -.23116500E+01, -.35650900E-01, -.11170800E+01, 0.58372600E+00, -.75574700E+00, -.13536900E+00, -.15996000E+00, 0.11395700E+01, 0.12386500E-01, 0.27256900E+00, 0.41754500E+00, 0.26015700E+00, -.87603200E+00, -.39652500E+01, 0.27155500E+00, 0.32214000E-01, 0.34948300E+00, -.17173800E-01, -.34859800E+01, -.18908000E-01, -.12147400E+01, 0.17223400E+01, -.14289300E+01, 0.16142000E+00, 0.20989000E+00, -.17755000E+00, -.45249800E+00, -.24681300E+00, 0.62506800E-01, 0.23508400E+00, -.25824100E+00, 0.48042700E+00, -.69634300E+00, -.38263600E+01, -.31535000E+00, -.18068000E+00, -.88864100E+00, -.21980000E+00, -.12800600E+01, 0.47065200E+00, -.48659500E+00, -.59573300E+00, 0.11905000E+01, 0.10868300E+01, -.59626800E+01, -.47297800E+00, 0.50612500E+00, 0.49339000E+00, 0.14660900E+01, 0.27427300E+00, 0.17200900E+01, 0.13522500E+00, 0.41144400E+00, 0.69787900E-02, -.61104900E+00, 0.95378000E+00, -.13902200E+00, 0.11653800E+01, 0.98325200E+00, -.32000500E+00, 0.18221800E+01, -.18095400E+00, 0.42982300E+00, 0.30997700E+00, -.83477500E+00, -.95087800E-01, -.53183000E+00, 0.36123800E+00, -.95714500E+00, -.49196600E+00, 0.87329500E+00, 0.61869000E+00, 0.51849900E+00, -.27162100E+01, -.59710500E+00, -.74162200E+01, 0.13107200E+01, -.27308200E+01, -.31128900E+00, -.15597200E+01, -.91557800E+00, -.10979600E+01, 0.19847800E+04, -.98554100E+03, -.76743700E+03, -.10497200E+04, -.13316100E+03, -.73393400E+02, -.21675800E+03, 0.68991200E+03, -.12081400E+03, -.63533400E+02, -.12698600E+04, 0.46456500E+01, 0.56177200E+02, -.21963600E+01, 0.83583100E+01, -.68160300E+00, 0.92720200E+00, 0.17808700E+01, -.10806000E+00, -.18307300E+02, 0.70837900E+01, -.27474000E+01, -.20916900E+02, 0.10107400E+02, -.12063100E+01, 0.71192600E+00, 0.30719700E+01, -.76977000E+01, -.12183500E+02, 0.55569500E+01, -.96005600E+01, 0.84553900E+01, 0.11520500E+02, -.88709900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42669400E+01, -.13220500E+00, -.62404100E+00, -.15326100E+01, -.96383600E+00, 0.27280100E+01, -.11609200E+01, -.24180000E+01, 0.31251100E+01, 0.30746400E+00, 0.11381000E+00, -.15395300E+00, 0.79166600E+00, 0.96500700E-01, -.19114100E+01, -.34506900E+00, 0.86091900E+00, -.69651500E+01, -.13370200E+01, -.97419500E+00, 0.23842800E+01, -.52596600E+00, -.12811800E+01, -.11926500E+01, -.25415300E+00, -.11400100E-01, 0.87437400E+00, -.39770500E-01, -.12530800E+00, 0.60406300E+00, -.94261300E+00, 0.21870000E+00, -.75478700E-02, 0.37284300E+00, 0.10194300E+01, 0.46656100E+00, -.10739100E-01, 0.50998600E+00, -.16358900E+01, -.25372300E+00, 0.81229700E+00, -.54700100E+00, -.20126100E+01, -.16821700E+01, 0.22731200E+00, 0.26586200E+00, -.19242600E+01, -.10339100E+00, 0.78160200E+00, -.65843400E+00, 0.51938900E+01, -.85463400E+00, -.12640300E+01, -.13605800E+00, -.15129900E+01, -.27732500E+01, -.12971000E+01, -.39267600E+00, -.45002200E+00, -.30138200E+01, 0.77528600E-01, 0.22683600E+00, -.33791400E+00, 0.62564300E+00, 0.41440100E+00, 0.26444500E+00, -.69952700E+01, -.20866800E+01, -.53743800E-01, -.68058900E-03, 0.13725800E+00, -.39677500E+00, 0.17050900E+01, 0.16341700E+01, 0.35402700E+00, -.60677400E+00, -.38362200E+00, -.33402000E-01, 0.15906100E+00, -.26858700E-01, 0.70270400E-03, -.12195400E+00, 0.44041100E+00, -.18088500E+00, -.55795800E+00, -.23223700E+00, -.42597100E-01, 0.12337200E+01, 0.33264500E+00, -.16480500E+00, -.22032900E+01, -.59452800E-03, 0.36331100E-01, 0.14803200E+01, 0.11329000E+00, -.10462300E+01, -.70962900E+00, -.31859800E+00, -.74519400E+00, 0.74824100E+00, 0.58488400E+00, -.34265500E+00, -.55671600E-02, 0.10284100E+01, -.16509400E+01, 0.92596000E+00, 0.23016700E+00, 0.30001800E+00, 0.18300800E+00, 0.26770600E-01, -.40584700E-01, -.67114100E-01, 0.57782600E+00, -.18331500E+00, 0.26537000E+00, 0.38559500E+01, 0.62105500E+00, -.95892200E-01, 0.99335000E-01, -.70544900E+00, 0.46816000E+00, -.21886700E-01, 0.26472500E+00, -.79484600E-01, -.83434900E-02, 0.59674200E+00, 0.66899500E+00, -.15441600E+00, -.84419100E+00, 0.72189100E+00, 0.37656000E+00, -.93346900E+00, -.26746900E+01, -.26793300E-01, 0.26000600E+00, 0.14110200E-01, -.84054200E+00, -.24362500E+00, 0.32302300E-01, 0.16971800E+00, -.18387000E+00, -.17285700E+00, 0.62724900E+00, 0.30002700E+00, 0.60034900E-01, 0.90229000E-02, -.20869600E-01, 0.42733000E+00, -.50374800E+00, 0.19377400E+01, -.33988400E+00, 0.11075900E+01, 0.41171100E+00, -.71858200E-01, 0.36714900E+00, 0.14930300E+00, 0.17264600E+00, -.38354400E-01, -.15074600E+00, 0.64448200E+00, 0.26472100E+00, -.36728300E+00, 0.70459000E+00, -.20875000E+00, -.29487100E+00, 0.82070100E-01, 0.14310000E+00, -.58900900E-01, -.61011800E-01, 0.15194000E+00, -.24944900E+00, 0.28968400E+00, -.14438200E+00, -.73435100E-01, 0.50356200E+00, 0.20271000E+00, 0.61662400E-01, 0.54286000E-01, 0.77001700E-01, -.12556500E-01, 0.30796700E+00, 0.11855400E+00, 0.12425000E+01, -.30026500E-01, 0.10606700E+01, 0.39308900E+00, -.21933900E-02, 0.44287400E+00, 0.67156800E-01, 0.20364300E-01, -.43180200E-01, -.57053500E+00, -.24390900E+01, 0.36616000E+01, 0.25214300E+00, 0.47636700E-01, 0.79716300E-01, 0.29295300E+00, -.12248200E+00, -.22504300E+00, 0.10812400E+00, -.92529100E-02, 0.95263100E-01, 0.16743900E+00, -.10100400E+01, 0.14055000E+00, 0.30956200E+00, -.76799600E-01, -.61299700E-01, -.17996200E+00, 0.48955700E-01, -.84308300E-01, -.32086300E-01, 0.22647200E+00, -.84508800E-01, -.19731400E+00, -.77842100E-01, 0.93765200E-01, 0.56897600E-01, -.38981800E-01, -.64464400E-01, 0.13818300E+00, 0.10995100E+00, -.14845900E-01, 0.37262900E+00, -.13123400E+00, 0.23814400E+00, -.32116700E-03, 0.92711300E-01, -.39705500E-02, 0.10156500E+00, -.37893700E-01, 0.12920500E+02, 0.36894600E+01, -.37799100E+02, -.87382700E+01, 0.32511600E+01, -.38242400E+01, -.14983700E+02, -.47864200E+01, 0.16878400E+01, 0.93989900E+01, -.52808600E-01, 0.17865800E+00, -.12457100E+00, 0.76499000E+00, 0.48305900E+00, 0.31060300E+00, 0.19149500E-01, 0.20742900E+00, 0.77239700E+00, 0.97538200E+00, 0.11496000E+01, -.59736800E+00, 0.10150600E+01, 0.49808300E+00, -.34756700E+00, 0.11989300E+01, 0.12049800E+01, -.86301200E+00, -.26480400E+00, -.87060700E+00, 0.80788100E+00, -.10216300E+01, 0.52866300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.63180900E+01, -.90713200E+01, 0.73418300E+01, -.55905400E+01, 0.10618100E+01, 0.10065400E+01, -.12502900E+01, -.88163800E+01, -.11114300E+03, -.15569000E+01, 0.69459400E+00, -.42686600E+01, -.43706800E+00, 0.12956000E+01, 0.13187400E+01, 0.22463700E+01, 0.32433000E+01, 0.54571800E+01, -.30874700E+00, 0.48509300E+00, -.54515900E+01, -.20981500E+00, 0.73670800E+01, 0.19761300E+01, 0.24998800E+00, 0.77323200E-01, 0.16406000E+00, 0.15911600E+00, -.29234700E+00, -.22361900E+00, 0.86449100E-01, 0.16820000E+01, -.32338500E-01, -.46339300E+00, -.15888000E+01, -.73394700E+00, 0.55725500E-02, -.90984700E+00, 0.24937200E+01, 0.60075100E+00, -.13346600E+01, 0.16200900E+00, 0.11582800E+01, 0.18009700E+00, -.44225400E+00, -.74336400E+00, 0.25949300E+01, 0.12524000E+00, -.34050600E+01, 0.12580400E+01, -.10634500E+01, 0.31426900E+01, -.35250400E+00, 0.18558100E+01, 0.54364400E+00, -.30771100E+01, -.80220800E+00, 0.23179300E-01, -.18307900E+01, 0.77863300E+00, -.20790300E+01, -.12221000E+00, -.17710700E-01, 0.12289300E+01, -.69990600E-01, 0.77962500E+00, -.48560100E-01, 0.26982600E+00, -.20858600E-01, 0.80140800E-03, 0.26444900E+00, -.11674300E+01, -.59008400E+01, -.11829900E+01, 0.16668300E+01, 0.32517300E+00, 0.30935200E+01, -.18476500E+01, 0.90779300E+00, 0.51686800E-02, -.11468400E-03, 0.77221600E+00, 0.22744000E+01, 0.23325100E+01, -.12456600E+01, -.40012300E+01, -.14258000E-01, 0.45256200E+00, 0.27999400E+00, -.53503500E+00, -.38269700E+01, -.26111400E-01, -.19785800E+00, 0.29510200E+01, 0.55846700E+00, -.16025900E+01, -.16386900E+01, -.52314100E+00, -.44332400E+00, 0.44158300E+01, 0.44189300E+00, -.74828000E-01, 0.28397000E-01, -.14710000E+00, -.75905500E+00, 0.36915100E+01, 0.10112600E+01, 0.41384900E+00, 0.69699400E+00, 0.62807100E+00, 0.32249500E+00, -.77998100E+00, 0.15226400E+01, -.48433300E+00, 0.27526400E-01, 0.20841400E+01, 0.14536900E+01, -.46255000E+00, -.11983600E+00, 0.81107400E+00, 0.24541800E+00, 0.48217200E+00, -.19245100E+01, -.78001100E+00, 0.23284700E-01, 0.25764200E+01, 0.23742900E+01, -.33260500E+00, -.19289800E+00, 0.18387800E+01, -.80486900E+00, -.12157700E+01, -.97031700E+01, 0.13887600E+00, -.33803700E+00, 0.11498300E+00, -.46206800E-02, -.57279500E+00, -.82087200E+00, 0.41797300E+00, -.15298100E+01, -.12749600E+01, 0.20063100E+01, 0.13437600E+01, 0.37510700E+00, 0.10252900E+01, -.16821800E-01, 0.24563200E+01, -.10342900E+01, 0.21903800E+01, -.53766600E+00, 0.66064600E+01, 0.13546800E+01, 0.18241700E+00, 0.14101600E+01, 0.99882200E+00, -.10234200E+01, -.20495200E-01, -.18916800E+00, 0.12241400E+01, 0.75604600E+00, -.24208100E+01, 0.62217100E+01, -.50320400E+00, 0.32919000E+00, -.47514700E+00, -.30223100E+00, 0.24098400E+01, 0.10237700E+00, 0.75258300E+00, -.91575300E+00, 0.17180700E+01, 0.15892300E+00, 0.19692800E+00, 0.96752200E+00, 0.82801900E+00, 0.68944200E+00, -.39351400E+00, -.61286000E+00, 0.15196800E+00, -.54780300E+00, 0.30872500E+00, 0.77125700E+01, -.24905400E+00, 0.54415100E+01, 0.27457600E+01, 0.15348700E+00, 0.37811500E+01, -.20656500E+00, -.95492800E-01, 0.53314300E+00, -.20853300E+01, -.66198000E+01, 0.15757700E+02, 0.12656000E+01, -.20006000E+00, 0.10086000E+00, -.63834600E+01, -.83459200E+00, -.91597200E+00, 0.59105300E+00, -.83326600E-01, 0.28913700E+00, 0.26639200E+00, -.11013800E+01, 0.15160700E+00, -.45868600E+00, -.72192600E+00, -.29846000E+00, -.23611800E+00, 0.20773700E+00, 0.65394500E+00, -.87418600E-01, 0.65864800E+00, 0.76499800E+00, -.71304200E+00, -.49503600E-01, -.54489600E+00, 0.22329600E+00, 0.22925600E+00, -.13266900E+00, -.20569000E+00, 0.14858100E+01, -.29881200E-01, -.71742400E+00, 0.10268300E+01, 0.76354900E+00, -.95851700E-01, -.71805000E-01, -.57297900E+00, 0.12317400E+01, 0.33576900E-01, -.67413500E+00, 0.17023300E+03, 0.52960100E+02, -.57047100E+02, 0.36464900E+02, -.13520100E+02, -.46832800E+02, -.17058200E+02, 0.38228000E+02, -.61849600E+03, 0.61347900E+01, -.37940200E+01, -.18034100E+02, 0.13812200E+02, 0.16466200E+02, 0.15857600E+02, 0.40952100E+01, 0.17686600E+02, 0.17667600E+02, 0.20286900E+02, 0.22275900E+02, -.73140200E+01, 0.18030100E+02, 0.16741400E+02, -.16225700E+02, 0.22880500E+02, 0.31448700E+02, -.11260800E+02, -.51975600E+00, -.18067900E+02, 0.97170400E+01, -.21475400E+02, 0.34189800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45127900E+01, 0.64747200E+01, -.54203200E+01, 0.35713900E+01, -.11117000E+01, -.66733300E+00, 0.64587000E+00, 0.68004600E+01, 0.82019900E+02, 0.64879400E+00, -.54924600E+00, 0.32113700E+01, 0.92599400E+00, -.19793500E+00, -.26434600E+01, -.21615100E+01, -.17872000E+01, -.91897700E+01, -.60606800E+00, -.21255400E+01, 0.50517600E+01, -.73042700E+00, -.17690500E+01, -.23393100E+01, -.15089000E+01, -.21619300E-01, 0.52891800E+00, -.21602000E-01, 0.19849100E-01, 0.66092300E-02, -.25010100E+00, -.63668600E+00, -.63474400E-01, -.32608100E+00, -.20675300E+00, 0.69678700E-01, 0.13510600E-01, 0.88288100E+00, -.10047200E+01, -.42240700E+00, 0.74460700E+00, -.38153700E+00, -.30099300E+01, -.13576300E+01, 0.62611600E+00, 0.68223600E+00, 0.15346900E+01, 0.33047700E+00, 0.65025800E+00, -.10313100E+01, 0.76139300E+00, -.21518200E+01, 0.66940500E+00, 0.19084700E+01, -.26534600E+01, 0.91960500E+01, 0.38985100E+01, -.60166000E+00, 0.21691100E+01, -.76416500E+01, 0.22376600E+01, 0.35910300E+00, 0.12435600E+01, -.10279700E+01, 0.26862500E+01, -.17691700E+01, -.84415800E+01, -.12365100E+01, 0.40063400E+00, 0.18802500E-03, 0.35786900E+00, -.25370500E+00, 0.10009000E+02, -.91467400E+00, 0.26380000E+01, 0.11864300E+01, -.36232200E+00, 0.14886300E+01, -.52522500E+00, 0.91652800E-01, 0.23345200E-02, 0.15649800E+00, -.16246100E+01, 0.14116200E-01, 0.25266900E+01, 0.10088700E+01, -.55458300E-02, -.66757200E+00, -.14144500E+01, 0.63788400E+00, -.53665800E+01, 0.82777200E-01, 0.20748100E+00, -.21770200E+01, -.23972600E+00, 0.19300700E+01, 0.27255300E+01, 0.11374800E+00, -.11153800E+01, 0.13504800E+01, -.21134800E+01, 0.13169300E+01, -.11464900E+00, 0.15444000E+01, -.93817400E+00, -.49449000E+01, -.58414400E+00, -.65798500E+00, -.13158300E+01, 0.42839300E-01, 0.41516300E-02, 0.14326900E+00, -.11132000E+01, 0.35490300E+00, -.25543100E+00, -.12024500E+01, -.82748600E+00, 0.87738800E-01, -.24020800E+00, -.23236500E+01, -.98983000E+00, -.33923000E+00, 0.26013200E+01, 0.57302900E+00, -.79270100E-01, -.63039100E+00, -.86011500E-01, 0.85454600E+00, 0.15789500E+01, -.15723600E+01, -.70212200E+00, 0.19779500E+01, 0.17607400E+01, 0.13750000E+00, 0.30992200E+00, -.67121700E-01, 0.74081300E-01, -.93476500E-01, -.11877600E+00, 0.16202300E+00, 0.18150200E+00, 0.48707600E+00, -.92174000E-01, 0.25741200E+00, 0.12340500E+00, -.33275700E+00, 0.28867900E-03, 0.70469400E+00, 0.13431200E+00, 0.72689400E+00, -.33307900E+00, 0.73320300E+00, 0.11568700E+01, -.34861800E+00, 0.24498000E+00, -.14454400E+00, 0.10974600E+01, -.38480700E-01, 0.58912600E+00, 0.58661000E+00, 0.33543400E-01, -.99985800E+00, -.29331200E+00, 0.38932800E+00, 0.17400600E+00, 0.44824900E+00, -.33644600E-01, 0.80695600E+00, -.30498000E-01, 0.97155300E-01, 0.30062800E+00, -.73112900E-01, -.71423500E+00, -.19703600E+01, -.38320100E+00, 0.57467700E-01, 0.49499800E+00, 0.37974300E+00, -.52592600E+00, -.11915100E+00, -.11441200E+01, -.26254000E+00, 0.66273900E+00, 0.28352500E+00, -.21026300E+01, -.25941900E+01, -.37033000E-01, 0.56052800E+00, 0.16134200E+00, 0.34512700E+00, 0.19062300E+00, 0.88843400E+00, -.13788100E+01, -.18385500E+02, -.69675000E+00, 0.59827800E-01, 0.11762400E+00, 0.39125000E+01, 0.37045300E+00, 0.39596800E+00, -.52301500E+00, 0.33240200E-01, -.12170200E+00, -.67949500E+00, 0.14759300E+00, -.12831400E+00, -.10288100E-01, 0.49925200E+00, 0.15027200E+00, 0.18818800E+00, 0.32412600E-01, 0.93284500E-01, 0.24961900E-01, 0.43112800E-01, -.79853400E-01, 0.19058100E+00, 0.18285400E+00, -.76342300E-01, 0.67591000E-01, -.13569700E-01, 0.62893200E-01, -.33377500E+00, -.14853900E-01, -.79389700E-02, 0.89645900E+00, 0.11241700E+01, -.14314000E+01, 0.24801400E+00, 0.75912500E-01, -.95305100E-01, 0.94461300E+00, -.13618700E+00, -.79239500E+00, -.40054200E+00, 0.14303000E+03, -.14024400E+03, 0.49277200E+01, -.91440800E+01, -.36950200E+02, 0.26748300E+02, 0.74246300E+01, -.57703700E+03, 0.25039600E+01, 0.75783500E+01, -.14046400E+02, 0.13849600E+02, 0.16926400E+02, 0.15194100E+02, 0.67109300E+00, 0.13415000E+02, 0.11683000E+02, 0.17616100E+02, 0.19107100E+02, -.28903600E+01, 0.14429400E+02, 0.17073500E+02, -.16186800E+02, 0.19561900E+02, 0.27101400E+02, -.76319200E+01, -.30905100E+01, -.17167200E+02, 0.53960200E+01, -.16859900E+02, -.34909600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22110000E+01, -.11961500E+01, -.12513100E+01, -.89834900E-01, 0.26142900E+00, -.99195500E-02, -.37734400E+00, -.19860000E+01, -.89552100E+01, 0.36228800E-01, 0.59638000E-02, -.80121500E+00, 0.43166800E+00, 0.46231600E+00, -.19158000E+01, 0.64017500E+00, 0.55269300E+00, -.61379700E+01, -.96038800E+00, -.15222900E+01, 0.15735300E+01, -.75093600E+00, 0.63727700E+00, -.11558000E+01, -.56671200E+00, -.29608200E-01, 0.15841500E+00, -.12260500E+00, 0.68363200E-01, 0.25573700E+00, 0.94272200E-01, 0.41179600E-01, -.87861100E-01, -.44892100E+00, -.66310000E+00, -.13658400E+00, 0.10720000E-01, 0.64321100E+00, 0.42919000E+00, 0.31831400E+00, 0.93519500E+00, -.39458400E+00, -.12011100E+01, -.10758700E+01, 0.42262300E+00, 0.24815500E+00, 0.11470000E+01, 0.22549700E+00, -.77862500E+00, -.44161800E+00, -.54452300E+00, -.62781400E+00, 0.27741500E+00, 0.13379800E+01, -.11820900E+01, 0.19678100E+01, -.13644200E+01, -.36661600E+00, 0.31820200E+00, -.22075900E+01, 0.44552700E+00, 0.23509700E+00, -.77258100E-01, 0.42368400E+00, 0.12931900E+01, 0.37481200E+00, -.86488500E+00, -.84300400E+00, -.15048900E+00, -.10518100E-02, 0.11041200E+00, 0.13966500E+01, 0.21583000E+01, -.51624900E-01, 0.66830700E+00, 0.17266800E+00, 0.22404400E+00, -.16093100E+00, -.15878600E+00, -.96622700E-01, 0.25180900E-02, -.10353600E+01, 0.11868100E+00, 0.29042300E+00, 0.16703700E+01, 0.76688100E+00, 0.14994200E+00, 0.29395500E+01, -.41478400E+00, 0.10767900E+00, 0.21977000E+01, 0.15669500E-01, -.15105800E+00, 0.44705200E+00, -.46827900E-01, 0.21088500E+00, -.10843300E+01, -.26131400E+00, -.26631800E+00, 0.21517800E+01, 0.12325500E+01, 0.45477600E-02, -.35324200E-01, 0.43631400E+00, -.28182600E+00, 0.23221200E+00, 0.84739600E-01, -.86209600E-01, -.13401000E+00, -.28616600E+00, 0.54685300E-01, 0.22475000E+00, -.32171300E+00, 0.10215100E+00, 0.10598000E+00, 0.42176500E+00, -.26220800E+00, 0.13557100E+00, -.78361400E-01, -.22352800E+01, -.68292000E+00, -.86871700E-01, 0.19505600E+01, 0.39701600E+00, -.51914900E-01, 0.36392200E+00, 0.10404000E+01, 0.20323300E+00, 0.39453200E+00, 0.89459300E-01, -.22150200E+00, 0.12435200E+01, 0.14432900E+01, 0.74507200E-01, -.20296700E+00, -.42891100E-02, 0.14000600E+00, -.15527400E-01, -.12457000E+00, 0.10285100E-01, 0.60567500E-03, -.55754900E-01, 0.93014000E+00, -.11813500E+00, 0.13737900E+00, -.58809200E-01, 0.11768400E-01, 0.67039300E+00, 0.80337500E-01, -.27182500E+00, -.20448900E-01, 0.60844700E+00, -.85237900E+00, -.30772000E+00, 0.11341900E+00, -.11731100E-01, 0.65214300E+00, 0.10063200E-01, 0.31492400E+00, 0.98952500E-01, 0.50859800E-02, -.64854200E+00, -.48395300E+00, 0.20786200E+00, 0.61084000E-01, 0.23587800E+00, 0.29206200E+00, -.75273000E-01, -.97100000E-01, 0.89101500E-01, 0.22420700E+00, -.11447700E+00, -.36268400E+00, -.31815600E+00, -.45961600E+00, 0.11562700E+00, 0.39037000E-01, 0.22220700E+00, 0.23893000E-03, -.30580000E-01, 0.31274000E-01, 0.65279700E-02, 0.84159800E+00, 0.34160400E-01, 0.10351100E+01, -.44580300E+00, -.14052600E-01, 0.11045900E+00, 0.13698700E-01, 0.41387900E+00, 0.23694300E+00, -.15110800E+00, 0.27388800E+00, -.17943100E+01, -.10664600E+00, -.19944300E-01, -.45737300E-01, 0.10621400E+00, -.16752300E+00, 0.13365700E+00, -.60150100E-01, 0.10273500E-01, -.19572300E+00, -.81232700E-01, 0.68337900E+00, -.14268600E+00, -.42417600E-01, 0.15548800E+00, -.39382700E-01, 0.55190500E-01, 0.14111500E+00, 0.11457400E+00, -.97957500E-02, -.16582700E-01, 0.72216600E-01, -.27384400E-01, 0.62671300E-02, -.12077900E+00, 0.74920800E-02, 0.58205300E-01, 0.87047500E-01, -.31678000E-01, 0.11780500E-01, 0.11104000E-01, 0.75474200E-01, 0.61918500E-01, -.49350500E+00, 0.98840200E-01, 0.26523900E-01, -.13312600E+00, 0.45415700E-01, -.13879100E-01, -.20796700E+00, -.73968400E-01, 0.30717200E+00, 0.32564700E+02, 0.14576300E+02, -.11958500E+02, -.62974600E+00, -.41740300E+02, 0.78568500E+01, 0.73097700E+02, 0.26969300E+00, 0.16919900E+00, -.44666900E+00, -.11461400E+01, -.10116800E+01, -.53515100E+00, 0.24299200E+00, 0.57868400E+00, 0.14592700E+00, 0.37298100E+00, -.20405500E+00, -.27847500E+01, 0.10500900E+01, -.10680000E+01, 0.83421700E+00, -.22875500E+00, -.82539700E+00, -.17053100E+01, 0.74453700E+00, 0.13862000E+01, 0.21841300E+01, -.43828200E+00, 0.80345100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17040100E+02, -.21678300E+02, 0.44529900E+01, -.14426300E+02, -.83020200E+00, 0.38905000E+01, -.41151200E+01, -.18484900E+02, -.22115200E+02, -.73780800E+01, 0.90013100E+00, 0.18261600E+01, 0.18670000E+01, 0.17264300E+01, -.91675100E+01, 0.12934600E+02, 0.10258000E+02, -.13288100E+02, -.50294700E+01, -.83299200E+01, 0.49563700E+01, -.24667000E+01, 0.22888600E+02, -.47767400E+00, 0.59560700E+01, -.23636200E+00, 0.11644600E+01, -.69765900E+00, -.27721400E+00, 0.34864600E+01, 0.22587500E+01, 0.43118300E+01, -.24574500E-01, -.41829200E+00, 0.22476700E+01, -.44907900E+00, -.26704500E-01, 0.28416200E+00, -.86009700E+00, 0.48490700E+01, -.71333100E+00, -.22885800E+01, -.33047300E+01, -.44693900E+01, -.54163200E+00, -.11311000E+01, 0.21402000E+01, -.15181200E+00, -.63136600E+01, 0.17923500E+01, 0.73278600E+00, 0.55850400E+01, -.10819600E+01, -.45554000E+01, 0.27350200E+00, -.20144000E+02, -.44323000E+01, 0.18061300E+01, -.62739400E+01, 0.14406900E+02, -.10471700E+02, -.47185000E-01, 0.79342400E+00, 0.13193800E-01, -.11396300E+02, 0.18612600E+01, 0.40780700E+02, 0.43546600E+01, -.18542700E+01, 0.13169800E-01, -.17931800E+01, -.30831700E+01, 0.16134300E+01, -.79475800E+01, -.41671500E+01, 0.81027300E+01, -.33335400E+01, -.73868400E-01, 0.51623000E-01, 0.41274300E+00, -.44530400E-02, -.98657900E+00, -.98852800E+00, 0.21326900E+01, -.47161800E+01, -.49984600E+01, -.19467100E+00, 0.96633400E+01, 0.26301900E+01, 0.17108900E+00, 0.14012800E+02, -.10182300E-01, -.17774200E+01, 0.50379900E-01, 0.28734400E+01, -.34902200E+01, -.17326600E+01, 0.58943100E+00, -.36115900E+01, -.15876100E+01, 0.34168500E+01, -.21765600E+01, -.90329300E-01, -.31308800E+01, 0.20259000E+00, 0.28684100E+01, 0.77293700E-01, -.55250800E+00, 0.63840800E+00, -.24319700E+00, 0.37627200E+00, 0.16461600E+01, 0.92597600E+00, -.28448200E+00, -.98184500E+00, -.17862500E+02, -.22024200E+01, -.95358900E+00, 0.21536700E+00, 0.17403000E+01, -.22623000E+01, 0.13667700E+01, -.65905500E+01, 0.84739300E+00, -.15277600E+00, -.39243800E+01, -.25286400E+00, -.15107000E+01, 0.97605600E+00, 0.17555500E+01, 0.10947900E+01, -.40077300E+01, -.13463100E+01, -.23696500E-01, 0.11558000E+01, -.29827900E+00, -.16806000E+01, 0.33267600E+00, 0.76202500E+00, -.13225600E+01, -.31763500E+01, 0.35072800E+01, -.91014600E+01, -.21887200E+01, -.49405700E-01, 0.49625900E+01, -.26548000E+00, -.74406000E+01, -.78377300E+01, 0.10866600E+02, 0.19069300E+01, -.13784900E+01, 0.63528800E+00, 0.30799100E+01, -.80324900E+00, 0.30228600E-01, -.35646800E+01, -.13773600E-01, -.75337200E+00, -.33882800E+01, -.11057600E+01, 0.64540000E+01, -.13331800E+01, 0.52829800E+00, 0.85458600E-01, -.37781300E+01, 0.11760100E+00, 0.92975900E+01, -.41925700E-02, 0.27987400E+01, -.17513000E+01, 0.12501900E+01, 0.53767500E-01, -.34487600E+00, -.11925200E+01, -.33088900E-02, -.51394100E+00, 0.14348700E+01, -.10423500E+01, 0.36282300E+00, -.68505300E+01, 0.11129800E+01, 0.10041000E+02, 0.92021400E+00, -.13369800E+01, 0.35998100E+01, 0.80013800E+00, 0.17835200E+01, -.90345600E+00, -.34627800E+00, -.22603500E+01, 0.43270400E+01, 0.32801400E+01, 0.30076300E+02, 0.11787500E+01, -.60669000E+00, 0.64730900E+00, 0.19279500E+01, 0.64341500E-01, 0.79469000E+00, 0.17997700E+00, 0.56245300E-01, 0.21715800E+00, -.15990900E+01, -.39244300E+01, 0.94536000E+00, -.10833300E+01, -.51963200E+00, 0.64861500E+00, -.23000100E+00, -.82697600E+00, 0.93096900E+00, 0.22620500E-02, -.11195500E+01, 0.91326600E+00, 0.15890400E+01, 0.68386300E+00, 0.79678900E+00, -.81516900E+00, 0.69456400E-02, 0.39300000E+00, 0.56820400E+00, -.12769000E+01, -.32210200E+00, -.44146400E+01, 0.97981900E+00, -.33998300E+01, -.54088200E+00, -.22695400E+01, -.95950100E+00, -.29475300E+01, 0.53896300E+00, 0.30036300E-01, -.17840400E+01, 0.11265700E+01, 0.69889400E+01, -.18300100E+03, 0.16171700E+03, 0.11952400E+03, 0.40572000E+03, -.73060800E+02, -.11614600E+04, 0.26295100E+01, -.43381800E+02, -.56145100E+01, 0.14931500E+02, 0.15982200E+02, 0.16966000E+02, 0.51687900E+01, 0.43711500E+01, -.57788700E+00, -.76010500E+01, -.74282200E+00, 0.27688600E+02, -.21825400E+02, 0.16733800E+02, -.17237800E+02, -.10555300E+01, 0.26119900E+01, 0.21538300E+02, -.18012600E+01, -.18939600E+02, -.22447100E+02, 0.57915000E+01, 0.22937400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15824100E+01, -.39747100E-01, -.96610000E-02, -.35892900E-01, 0.27832300E-01, 0.52524800E-01, -.13519300E-01, 0.13963000E+00, 0.74623100E+00, -.43906800E-01, 0.27381700E-02, 0.26636000E+00, 0.95553200E-01, -.12744700E-01, 0.54396500E-01, 0.47427500E+00, 0.95073000E+00, -.30560800E+00, 0.21808500E-01, -.16699100E+00, 0.26264900E+00, -.29856900E+00, 0.33998600E+00, -.38059600E+00, -.38331400E+00, -.25535500E-02, -.29036000E+00, -.20459100E-01, 0.34855600E-01, 0.26580200E-01, 0.16968300E+00, 0.34204400E-01, 0.28810700E-01, -.26982400E-02, -.16611500E-01, 0.69440500E-02, 0.53557600E-03, -.43322100E-01, -.17000900E+00, -.93572900E-01, 0.23888200E-01, 0.14892600E-01, 0.13084300E+00, 0.75875100E-01, -.13846200E-01, 0.24329000E-01, -.83560500E-01, -.29538300E-01, 0.19374600E+00, -.52360300E-01, 0.78601000E+00, 0.18338700E-01, -.95887500E-01, 0.30843900E+00, -.26766000E-01, 0.14067800E+00, -.16687900E+00, -.13545600E+00, -.74556500E-01, -.21877800E+00, -.83583100E-01, -.21042900E-01, -.12257900E-01, 0.69902400E-01, 0.45180100E-01, -.14188100E+00, -.19220500E+01, -.18262900E+00, -.54877000E-01, -.14551000E-03, -.15252200E-01, 0.24045000E+00, 0.61622800E+00, -.14511500E+00, -.68125600E-01, 0.79964900E-01, -.10856700E+00, -.14879100E+00, -.51071800E-01, -.14417800E-01, 0.26411400E-03, -.50635300E+00, 0.73008400E-01, -.21934200E+00, -.31378100E+00, 0.98721600E-01, -.15971300E-01, 0.15591700E-01, -.64150200E-01, 0.31602700E-01, -.70301800E+00, -.14640400E-01, 0.16956300E-01, -.18978300E+00, 0.11749300E+00, -.23270600E-01, 0.39447200E-02, 0.91732500E-01, 0.16307700E+00, -.46570600E+00, -.71619300E+00, 0.18434200E+00, 0.10660700E-01, -.89460900E-01, 0.23376000E+00, 0.13106400E+00, 0.81465300E-03, -.57165000E-02, 0.44570600E-01, 0.73471000E-01, -.71663300E-01, -.88125900E-01, 0.20872400E+00, -.66028900E-01, 0.41638100E-01, 0.12357100E+01, 0.39855100E+00, -.44064300E-01, 0.13413000E+00, -.57370500E+00, -.33986000E-01, -.98659600E-02, -.50236100E-01, 0.96654500E-01, 0.10547400E-01, -.32526400E+00, -.13262700E+00, -.39877100E-01, -.19248900E+00, 0.31399300E+00, -.56701600E-01, -.22153700E+00, -.10873000E+01, -.81768300E-02, -.60366300E-01, -.22170700E-02, -.69588900E-01, 0.19091200E+00, -.44721200E-01, -.42235200E-01, 0.12223200E+00, 0.23676000E+00, 0.32882100E+00, 0.46561300E-01, 0.33571800E-01, 0.12806200E+00, -.16747800E-02, -.25775100E+00, 0.35004900E-01, 0.85645200E-01, 0.25531400E-01, -.15606100E-01, 0.10407000E+01, -.14653900E-01, -.45295100E-01, -.99052700E-01, -.16424300E+00, -.51201300E-02, -.65607100E-01, -.74553200E-01, -.29858900E-01, -.32987000E+00, -.96174200E+00, 0.32502000E-01, -.11604300E-01, -.15076600E+00, 0.12750800E+00, 0.28013500E+00, -.41034300E-01, -.79080600E-01, 0.51674700E-01, 0.26793700E-01, 0.66878600E-03, 0.59927600E+00, -.24992700E-01, -.43083500E-01, -.17029600E-01, 0.76568400E-02, 0.10556800E+00, -.17045600E-01, 0.52561700E-01, 0.40006000E-01, 0.73415100E+00, -.88026600E-02, 0.40603700E+00, 0.20292600E-01, 0.45238300E-02, 0.49874500E+00, -.25695200E-01, 0.39565800E-01, -.93513000E-01, 0.11291200E-01, -.10217200E+01, 0.13646500E+01, 0.17747000E-01, -.30267500E-02, -.12597100E-01, 0.11985000E+00, -.53103300E-01, -.61545000E-01, 0.26803100E-01, -.41149000E-02, 0.51263800E-01, 0.80038700E-01, -.59888000E+00, 0.92007100E-01, 0.76191300E-01, -.83609900E-01, 0.26777800E-02, -.59488100E-01, -.90845200E-01, -.57414900E-01, 0.14135500E-02, 0.26750200E-01, -.23422000E-01, 0.21372300E-01, 0.11626500E-01, 0.45732000E-01, -.15260900E-02, -.52061000E-01, -.52269600E-01, 0.46114000E-01, -.14148400E-01, 0.57618000E-02, -.67983900E-01, 0.17399700E+00, 0.15204000E+00, -.53767400E-01, -.51427500E-01, 0.56979200E-01, 0.27735000E-01, -.23850600E-01, 0.10051000E+00, 0.61036700E-01, -.14203300E+00, -.45608000E+00, -.25440300E-01, 0.78988100E+01, 0.84504100E-01, 0.46577400E+01, 0.13477600E+01, -.54432800E+02, -.58918200E-01, 0.14522400E+01, -.40996600E+00, 0.52358200E+00, 0.66672900E+00, 0.62159600E+00, -.32587400E-01, 0.38494300E+00, -.36128000E+00, -.26403700E+00, 0.13766900E+00, 0.94549700E+00, -.95625700E+00, 0.66340100E+00, -.70325100E+00, 0.32404000E+00, -.26988600E+00, 0.65884000E+00, -.46370000E+00, -.65786600E+00, -.66484600E+00, 0.21701000E-01, -.13230600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25956200E+01, 0.45988000E+01, -.21610300E+01, 0.33063700E+01, -.21844800E+00, -.79580300E+00, 0.61563100E+00, 0.49140500E+01, 0.47280300E+02, 0.11809500E+01, -.26347400E+00, 0.15902900E+01, -.55856200E+00, -.36086500E+00, 0.11566700E+01, -.97846700E+00, -.63176800E+00, 0.67243200E+00, 0.82215600E+00, -.65533100E-01, 0.25784400E+01, 0.49481700E+00, -.28160300E+01, -.27001200E+00, -.75473100E+00, 0.33089100E-02, -.12027200E+01, -.17313900E+00, 0.33141000E+00, 0.56943700E-03, 0.21003400E+00, -.76007300E+00, -.16650500E+00, 0.33662200E+00, 0.69110500E+00, 0.15373900E+00, 0.69790100E-02, 0.33994600E+00, -.97722900E+00, -.17591100E+00, 0.64086700E-01, -.31364100E+00, -.30806600E+00, -.31633100E+00, 0.14394000E+00, 0.85956000E-01, -.16696500E+00, -.13356100E+00, 0.52120500E+00, -.42053400E+00, 0.12792300E+01, -.68601400E+00, 0.11548100E+01, 0.43909100E-02, 0.16669000E+00, 0.18492300E+01, -.46401700E+00, 0.17513700E+00, 0.41124900E+00, 0.19838600E+01, -.51034500E+00, 0.28311900E+00, -.11812500E+01, -.58408600E-01, 0.12483100E+01, -.93435800E+00, -.45488400E+01, -.41332700E+00, -.33922900E-01, 0.41535200E-02, -.34005400E+00, -.72857200E-01, 0.17275900E+01, -.10361700E+01, 0.51653100E+00, -.66343000E-01, -.81453800E+00, 0.12199000E+00, -.14240200E+00, 0.12929000E+00, 0.17293400E-02, -.63531800E+00, -.88256800E-01, -.56622700E+00, 0.52300900E+00, 0.62150200E+00, -.70230900E-01, -.11497700E+01, -.43371600E+00, 0.63600400E-01, -.10319900E+01, 0.12029000E-01, 0.99070400E-01, -.99753100E+00, -.29456900E+00, 0.64749300E+00, 0.46227600E+00, 0.15454400E+00, 0.89158500E+00, -.70879300E-01, 0.30565400E+00, 0.13343700E+00, -.37991700E-01, 0.11012800E+00, 0.65533500E+00, -.32332400E+00, -.18163700E+00, -.21329700E+00, 0.52932700E-02, 0.10008100E+00, -.87670200E-01, -.27698500E+00, 0.25390300E+00, -.80705400E-01, -.62396900E-01, -.13751000E-01, 0.24342900E-01, -.12789700E-01, 0.87884200E-01, 0.12535400E+01, 0.12312400E+00, -.43032700E-01, -.10823600E+01, -.38797200E+00, 0.51164200E-01, -.47689100E+00, -.45263700E+00, -.22215500E+00, -.92036200E+00, 0.41922000E+00, -.24507000E+00, -.47271700E+00, -.66220500E+00, -.14660300E+00, -.54282000E+00, 0.58661800E-01, 0.85499600E+00, 0.31320300E+00, -.35089500E+00, 0.19517800E+00, 0.49415600E+00, -.34673500E+00, 0.16628400E+01, 0.48311400E+00, 0.74506500E-01, -.59831700E+00, 0.99677900E-02, 0.50865200E+00, 0.99546700E+00, -.77010800E+00, -.25496200E+00, 0.51493700E+00, 0.17749900E+00, -.12582600E+00, -.55403200E-01, -.74058800E-01, 0.42938900E+00, 0.29114400E-02, -.15335500E-01, -.43265900E-02, 0.47850600E-02, -.63426300E+00, 0.60221400E+00, -.85343900E-02, -.76795000E-01, 0.45882900E+00, 0.42381800E+00, -.58103200E+00, -.12787600E+00, 0.42375200E-01, -.13006100E+00, 0.55315300E-01, -.15926900E+00, 0.76481200E+00, 0.20935000E+00, 0.24792800E+00, -.27452800E+00, 0.19072100E+00, 0.28124700E+00, 0.33628500E-02, 0.79591900E+00, -.60123000E-01, 0.20545600E+00, 0.18737700E+00, -.36752000E+00, 0.89296100E+00, 0.70943400E-01, -.10757400E+01, -.16631800E-01, -.25498700E+00, -.23839600E+00, -.27084000E-01, -.18788000E+01, 0.80107400E+01, 0.74928700E+00, -.11746300E-01, 0.11811700E+00, 0.91775300E+00, -.63209000E-02, 0.90920800E-01, 0.25034800E+00, -.98557200E-02, 0.18412700E+00, -.16267100E-01, -.10647200E+01, 0.13057500E+00, -.23388100E+00, -.10175800E+00, -.70497900E-01, 0.43982700E-01, 0.57673800E-01, 0.27551800E+00, -.99754100E-02, 0.18419400E+00, 0.10292500E+00, -.26957400E+00, -.13058500E+00, 0.15874100E+00, 0.10053200E+00, 0.39864600E-01, 0.14932000E+00, 0.28863400E+00, 0.25426200E+00, 0.30807500E-01, 0.54681100E+00, -.22277500E+00, 0.16867300E+01, 0.94093900E-01, 0.43048000E+00, -.14686700E+00, -.85392900E+00, -.54368600E-01, 0.14140200E+00, -.64242100E-01, -.80502800E-01, -.25676700E+00, -.30423500E-01, -.25490400E+01, -.87707800E+02, -.55665300E+01, 0.10332700E+02, -.32763100E+03, 0.15425800E+01, -.28659700E+01, -.62862700E+01, 0.47978500E+01, 0.50477100E+01, 0.52411600E+01, 0.16037700E+01, 0.61611600E+01, 0.47652400E+01, 0.53700100E+01, 0.73773800E+01, -.45538000E+00, 0.43666500E+01, 0.51292300E+01, -.53290900E+01, 0.77523800E+01, 0.87940400E+01, -.20477300E+01, -.12921000E+01, -.55360100E+01, 0.20359300E+01, -.62280300E+01, 0.42363200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30352200E+01, -.24017400E+01, -.14498700E+01, -.77639700E+00, 0.14624300E+00, 0.63246400E+00, -.55332200E+00, -.54345200E+01, -.27768100E+02, 0.11515800E+01, 0.62102200E-01, -.15175700E+01, -.57996800E+00, 0.52892600E+00, -.29408400E+01, 0.29352000E+00, -.11595400E+01, -.84396200E+01, -.15958800E+01, -.21064100E+01, 0.40662800E-02, -.93459600E+00, -.64966500E+01, -.22735300E+01, 0.33888000E+01, -.15535700E+00, 0.35524700E+01, 0.72808200E-02, -.33143600E+00, 0.14776100E+01, -.48405300E+00, 0.17204100E+00, 0.51532800E-01, -.39739100E-01, -.18161600E+00, -.12548800E-01, 0.33817100E-02, -.68802400E-01, 0.64492100E-01, -.25273600E+00, -.35765100E+00, -.10826100E-02, 0.11588000E+00, 0.17406300E+00, 0.79869400E-01, 0.17736900E-01, 0.42900200E+00, 0.47820800E-01, -.21656800E+00, -.13136000E-01, -.75250900E+00, -.86770800E-01, 0.36484400E+00, 0.11227500E+01, -.10883100E+00, 0.52779600E+00, 0.21040200E+00, -.15736300E+00, -.17729800E-01, -.13511900E+01, -.11339700E+00, 0.33766400E-02, -.82936100E-02, 0.24231300E+00, 0.10912500E+01, 0.89038200E-01, -.98096100E+00, 0.73633700E-01, 0.12912800E+00, -.32975000E-03, -.38463000E-01, 0.15572700E+01, -.20193000E+01, -.82058900E+00, -.74938200E+00, 0.26591300E+00, 0.60406500E+00, 0.37663000E+00, 0.22980300E-01, 0.84371000E-01, -.28867500E-02, 0.75456400E+00, -.50234200E+00, 0.95681900E+00, -.16044200E+01, -.94322200E-01, 0.99968400E-01, 0.50499300E+00, -.25952300E+00, 0.26666600E-01, 0.20381600E+01, 0.17008200E-01, -.20645200E+00, 0.27140000E+00, 0.14136100E+00, 0.38430900E-02, -.36385700E+00, 0.12441400E+01, 0.16919300E+01, 0.45423200E-01, -.56502100E-01, 0.90201200E-01, -.42215800E-01, -.38612600E+00, 0.48857800E-01, 0.31517300E+00, -.52849300E+00, 0.45921900E+00, 0.33326200E-01, -.10260700E+00, -.15130500E+00, -.12431700E+00, 0.79773600E+00, -.25210400E+00, 0.24818100E+00, 0.67765100E+00, 0.65962100E+00, -.35673400E-01, 0.23905300E+00, 0.11438800E+01, 0.83493600E+00, -.13686800E+00, 0.44826400E+00, 0.42794100E-01, -.69420700E-01, -.98971200E-01, 0.48662700E+00, -.25185300E+00, -.69167700E+00, -.64856900E+00, 0.45069900E+00, -.74148900E+00, 0.22745700E+01, 0.61500200E-02, -.58050000E-01, -.25655800E-01, 0.11743900E+00, 0.26836400E+00, 0.93001900E-01, -.22028400E+00, -.58036300E-01, 0.38984800E+00, -.27547000E+00, -.47957000E+00, 0.12097800E+00, 0.81870000E+00, -.16640300E-01, -.11885500E+01, -.17780400E+00, -.26410300E+00, 0.29981800E+00, -.25121700E+00, 0.56585300E+00, 0.12031300E-01, -.18814900E+00, -.14874200E+00, -.55131200E-01, -.78349100E-02, 0.84000100E-01, -.22001300E+00, -.24254000E+00, 0.38329800E-01, -.23114100E+01, -.34643500E-01, -.20325200E+00, 0.29949500E-01, 0.11828700E-01, 0.52661900E+00, -.17566800E-01, 0.13091400E+00, -.64068400E-01, 0.16922200E+00, 0.35463900E-01, 0.49334800E+00, 0.50291200E-02, 0.40140400E-01, -.18056800E+00, 0.25056800E-01, 0.26202600E+00, -.48870600E-01, 0.41900100E+00, -.21432300E-01, 0.36538000E+00, -.13274200E+00, 0.75276300E+00, 0.20071300E+00, -.71673400E-01, -.13004300E-01, 0.51601200E-01, -.13090000E+00, -.23896300E+00, 0.33414000E+00, 0.19243500E+00, 0.29096300E+01, 0.12605700E+00, 0.12219800E-02, 0.34634400E-01, 0.52986000E+00, 0.75597200E-02, 0.42284000E-01, 0.11077600E+00, 0.17901600E-01, 0.20797100E-01, -.10346000E-01, 0.32769600E+00, -.50269500E-01, -.77993900E-01, -.21051100E-02, -.52253100E-01, -.20607700E-01, 0.59358700E-01, -.29339100E-01, -.89514700E-02, 0.10473600E-01, 0.44473600E-01, -.99767200E-01, 0.58928300E-01, -.11790500E+00, 0.43238800E-01, 0.26627000E-01, -.86554100E-02, -.14047400E+00, -.11198000E+00, -.59793000E-01, -.40736300E+00, 0.49322000E+00, -.12281800E-01, 0.61109900E-01, -.63925900E-01, -.15546600E-01, -.45943200E+00, -.37888200E-01, 0.82744100E-01, 0.44722400E-02, -.73544700E-01, 0.83315200E+00, -.21634100E-01, 0.16714400E+01, -.50325500E-01, 0.41431000E+02, 0.30253800E+01, -.13990800E+03, 0.20802300E+01, 0.27215700E+01, 0.12535600E+00, 0.21704700E+00, -.57858100E-01, 0.11896200E+00, 0.14393200E+01, -.25144600E+00, -.46522500E+00, 0.60285600E+00, 0.24891600E+00, 0.11871100E+01, -.10327400E+00, -.17296400E+00, -.96058100E-02, 0.42567900E+00, 0.18203300E+01, 0.38991800E+00, 0.39904300E+00, -.82515400E+00, -.63552000E+00, -.19032100E+00, -.42958900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36505900E+00, -.52142800E+00, 0.58971100E-01, -.74079200E+00, -.20836600E+00, 0.49831500E+00, -.12855800E+00, -.36524100E+00, -.10588500E+01, 0.27845300E+00, 0.44104800E-01, 0.29377200E+00, 0.30971300E+00, 0.15339700E-01, -.36192300E+00, 0.39838200E+00, 0.15411400E+01, 0.12943600E+00, -.12640700E+00, -.34864800E+00, 0.42089700E+00, -.11345500E+00, 0.40589000E+00, -.14487000E+00, 0.15350500E+00, -.36810200E-02, 0.58351600E+00, 0.41810600E-01, -.70316700E-01, 0.19376300E+00, -.79537200E-01, 0.40604800E-01, 0.16673200E-01, 0.22702800E+00, 0.28948700E+00, 0.11284500E+00, -.45157800E-02, -.51118600E-01, -.59897000E-01, -.15850300E+00, -.39072000E+00, 0.74227000E-01, 0.17866000E+00, 0.47771900E-01, -.21014600E-01, -.17108400E-01, -.39437200E+00, 0.13812900E-02, 0.24142900E+00, -.12195700E-01, 0.25830900E+00, -.37790200E-01, -.45846900E+00, -.24968200E+00, -.59805700E-01, -.82661900E+00, -.64146300E+00, -.25218200E-01, 0.31619500E-01, 0.54590500E+00, -.27326500E-01, 0.82106900E-02, 0.46446400E-01, 0.12894900E+00, 0.33792400E+00, -.92320500E-02, -.84459600E+00, -.81666900E-01, 0.12431100E-01, -.11951200E-03, 0.11837100E-01, 0.33364400E+00, -.21165400E+00, 0.27753700E-01, -.20420600E+00, 0.16734100E+00, -.20690800E-01, 0.60521300E-01, -.39049500E-01, 0.28166600E-01, -.30633500E-03, 0.17125700E+00, -.12494200E+00, 0.30296500E+00, 0.14620700E-01, 0.52404800E-01, 0.24677200E-01, 0.98209700E+00, -.18788700E+00, -.23414600E-02, 0.30931700E-01, 0.12278100E-01, -.43555500E-01, -.23891100E-02, 0.71069300E-01, -.71432500E-01, 0.19912700E+00, 0.19003100E+00, -.29208100E+00, 0.35047800E+00, 0.15584000E+00, 0.13103600E-01, -.21609100E-01, 0.11086100E+00, -.21974200E+00, -.30663600E-01, -.16103300E-01, 0.10627600E-02, -.12771100E-01, 0.11808500E-01, 0.76479300E-02, -.37695100E-01, -.35567300E-02, 0.12911600E-02, -.31883000E-01, -.44294100E+00, -.10584400E+00, -.31517600E-01, -.15280600E-01, 0.84696100E-01, -.46334100E-01, 0.26368900E-01, -.23703600E+00, -.23300400E-01, 0.21009400E-04, -.93271000E-01, -.58985000E-01, -.15495700E-01, -.66414900E-01, -.52554700E-01, -.11144500E+00, -.25046300E-02, -.64496400E+00, -.18552800E-02, 0.36159500E-01, 0.18901100E-02, -.21634200E+00, -.65257600E-01, -.24541900E-01, 0.34498200E-01, 0.27365400E-01, -.20150700E+00, 0.18149700E+00, 0.94011700E-01, -.39438600E-02, -.23969000E+00, 0.23165500E-02, 0.14704100E+00, -.35882000E-01, 0.17960500E+00, -.55498400E-01, 0.32288900E-01, 0.23355700E-01, 0.22619000E-02, 0.17539900E-01, 0.16433100E-01, -.77459300E-02, -.27758200E-02, -.98116300E-02, -.52334800E-02, 0.16760300E-01, 0.19321600E-01, 0.68509700E+00, 0.97453500E-03, -.19424800E-02, 0.51913400E-01, 0.12989100E-01, -.54973700E-01, -.32271100E-02, -.14298100E-01, 0.43234600E-01, 0.99583600E-02, 0.60690800E-02, 0.99258900E-02, -.46768900E-01, 0.97574400E-02, 0.64772400E-03, -.17444900E-01, 0.35362900E-01, -.14201300E-02, 0.26968800E-01, 0.13946300E-03, -.51511700E+00, 0.11198800E-01, -.17180200E+00, 0.20169000E-01, 0.99422500E-03, -.61750200E-01, -.12612200E-01, 0.32806100E-01, 0.11430400E-01, -.49074000E-01, 0.19882400E+00, 0.32100100E+00, -.94162900E-02, -.58297300E-02, -.47602200E-01, -.51023700E-01, 0.74263400E-02, -.52151500E-03, -.14402800E-01, -.13417500E-02, 0.71199800E-02, -.16758400E-01, 0.85420300E-01, -.12233000E-01, 0.14089200E-01, 0.28201900E-01, 0.94729000E-02, -.24935900E-01, -.38986500E-02, 0.41299100E-02, -.39588400E-02, -.16108300E-02, -.13025500E-01, 0.97589500E-02, -.73790400E-02, -.19278300E-01, -.11103700E-01, -.76146600E-02, -.17816500E-01, -.52669400E-02, -.18350800E-01, -.69618400E-02, 0.25480800E-01, -.66837500E-01, -.49374600E-01, -.66068000E-02, -.24802200E-01, -.18854300E-01, 0.22510000E-01, 0.82520000E-02, 0.47871300E-02, 0.13727900E-01, -.11969800E-01, 0.76220500E-01, 0.44718600E-02, 0.13124100E+00, -.38998900E-01, 0.43410500E-02, 0.17127000E+01, 0.17216400E+01, 0.19960200E+00, -.19054500E+00, -.55533100E+00, 0.19244000E+00, 0.18369900E+00, 0.16507100E+00, 0.16793800E+00, 0.55084900E+00, 0.72820400E+00, 0.57999200E+00, 0.68523500E+00, -.50927700E+00, 0.57420100E+00, 0.17928700E+00, -.17185800E+00, 0.62647900E+00, 0.77445000E+00, -.43922400E+00, 0.13955500E+00, -.20219800E+00, 0.50405000E+00, -.64748800E+00, 0.84017300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.85670600E+01, 0.46131500E+01, 0.87152300E+00, 0.46762800E+01, 0.19184600E+01, -.35218600E+01, 0.22717800E+01, 0.58168300E+01, -.64896600E+01, 0.19326500E+01, -.28613800E+00, -.39549200E+00, -.11994600E+01, -.53307100E+00, 0.34443200E+01, -.10814800E+01, -.27864700E+01, 0.13402800E+02, 0.27042000E+01, 0.18458600E+01, -.55298200E+01, 0.14343300E+01, -.15909400E+01, 0.22832700E+01, 0.35211800E+00, 0.59847500E-01, -.17285200E+01, 0.28178000E+00, 0.75994800E-01, -.16860400E+01, 0.69720100E+00, -.10463300E+01, 0.11261400E-01, -.86458300E+00, -.27991500E+01, -.70708400E+00, 0.28841500E-01, -.90116700E+00, 0.32357500E+01, -.75533800E+00, -.15326500E+00, 0.12388000E+01, 0.41362400E+01, 0.35317200E+01, -.35135900E-01, -.20327000E+00, 0.27002400E+01, 0.35954800E+00, -.58818800E+00, 0.43207700E+00, -.55168400E+01, 0.88942400E+00, 0.13989200E+01, 0.13094300E+01, 0.14210500E+01, 0.50717800E+01, -.68985400E+00, 0.69131400E+00, 0.23171800E+01, 0.20750800E+01, 0.16812600E+01, -.15250700E+00, -.12772800E+01, -.50049400E+00, 0.31231200E+01, -.71578300E+00, 0.29872300E+01, 0.21516800E+01, 0.47534300E+00, -.99649300E-03, 0.28477700E+00, 0.14543900E+01, -.63322400E+01, -.18278900E+01, -.52086100E+00, -.37421200E+00, 0.17887700E+01, 0.64992500E+00, -.30561500E-01, -.19037300E+00, -.10282000E-03, 0.13308400E+01, -.54735600E+00, -.35159000E+00, 0.22069900E+01, 0.16759900E+01, 0.33014500E+00, -.25388100E+01, -.16054800E+00, 0.42120600E+00, 0.35446300E+01, 0.12187300E-01, -.10690000E+00, -.14591000E+01, -.15983700E+00, 0.99680900E+00, 0.17487600E+01, 0.95514900E+00, 0.23855100E+01, 0.20582300E+01, 0.30534100E+01, 0.11449600E+00, -.83722400E-01, -.35075500E+00, 0.29914400E+01, -.18319700E+01, -.46317800E+00, -.89461700E+00, -.19701300E+00, -.63694100E-01, 0.30703700E-01, 0.70732000E-01, -.79051800E+00, 0.25083600E+00, -.59407000E-01, -.30666700E+01, -.16177700E+01, 0.18491900E+00, -.44086500E+00, 0.20737600E+01, -.37747100E+00, 0.35535500E-01, -.91610200E+00, -.20704600E+00, 0.11170000E-01, 0.56375100E+00, -.42047700E+00, 0.24763000E-01, 0.16842900E+01, -.10348700E+01, -.52308000E+00, 0.99955800E+00, 0.15025700E+01, 0.67641400E-01, 0.18887300E+00, -.14618600E-01, 0.21512200E+00, 0.17097800E+00, 0.23853300E+00, -.15300200E+00, -.30664200E+00, -.36800200E+00, -.32055800E+00, -.14935100E+00, -.54071600E-01, 0.25408200E+00, -.10017000E-01, -.42956000E+00, -.94576300E+00, 0.34135100E+00, 0.23130500E+00, -.12375300E+00, 0.14118100E+01, 0.32349600E+00, 0.15664300E+00, 0.88204500E-02, -.78554300E-01, 0.39606800E-01, 0.36704900E+00, -.13703800E+00, -.18513400E+00, 0.38066300E+00, -.26299900E+01, 0.17410100E+00, 0.25096600E+00, -.19027400E+00, 0.58465300E-01, -.21797900E+01, -.21177500E-01, -.12148600E+00, 0.27460600E+00, -.13028500E+01, -.27539700E+00, -.41838500E+00, -.57252200E+00, -.47121300E+00, 0.68911000E-01, 0.25815000E+00, -.46640900E+00, -.22578200E-01, -.20854900E-01, 0.70997600E-01, -.48008200E+01, 0.69051900E-01, -.10984500E+01, 0.46021800E-01, 0.25776400E-01, -.16673300E+01, 0.17605900E+00, -.14204000E+00, 0.10297000E-01, -.14768600E+00, 0.15979100E+01, -.20149000E+01, -.30923600E+00, 0.21659700E-01, -.27416300E+00, 0.47638200E+00, 0.27337800E+00, 0.23408100E+00, 0.13523900E+00, 0.81080600E-02, -.18599300E+00, 0.11370300E+00, 0.66364900E+00, -.12837200E+00, -.24157900E+00, 0.26320000E+00, -.12068900E-01, 0.25852700E+00, 0.13967000E+00, 0.14576900E+00, 0.23801000E-01, -.32499600E-01, 0.10864400E+00, 0.19522700E-01, -.63032700E-01, -.13656500E+00, 0.69503600E-01, 0.44129900E-01, 0.77779600E-01, -.47952500E+00, 0.95184600E-01, -.65709400E-01, 0.22964700E+00, 0.39578500E-01, -.40230400E+00, 0.15674400E+00, 0.17469900E+00, 0.43703400E-01, 0.11538600E+00, 0.11033400E-01, 0.84462700E+00, 0.92193100E-01, 0.69648000E+00, 0.32027700E+01, 0.27382900E+00, 0.29866800E+00, 0.10787600E+00, 0.23422400E-01, -.77413300E+01, 0.64507300E+03, -.23971300E+01, 0.47442400E+01, 0.10953500E+02, -.11732400E+02, -.14513400E+02, -.15287000E+02, -.21960600E+01, -.10555700E+02, -.45800300E+01, -.96893400E+01, -.10409400E+02, -.10044100E+00, -.52406200E+01, -.14734800E+02, 0.14973300E+02, -.11261400E+02, -.14499500E+02, 0.28187600E+01, 0.15965900E+01, 0.14891000E+02, -.18222500E+01, 0.93550000E+01, -.59845200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.97807400E+00, 0.30752200E+01, -.76079200E+00, 0.23120800E+01, -.16569700E+00, -.10916300E+01, 0.13147000E+00, 0.13216600E+01, 0.72953300E+00, -.96405900E+00, -.66174000E-02, 0.28988700E+00, 0.29054700E-01, 0.11339600E+00, 0.57524400E+00, -.53957000E+00, -.47732500E+00, -.98253700E+00, -.56080700E-01, 0.69953200E+00, 0.29701700E+00, -.20738400E+00, -.27858200E+01, 0.21673800E+00, 0.42225100E+00, 0.13260700E-01, 0.11294500E+01, -.93288300E-01, 0.46001600E+00, 0.24655100E+00, -.33159400E+00, -.40853900E+00, 0.13656600E+00, 0.51388300E+00, 0.76521200E+00, 0.13700100E+00, -.16817900E-01, -.15027600E+00, 0.14733900E+00, -.49576400E-01, -.81961700E+00, 0.13737600E+00, -.39088200E+00, -.19266700E+00, -.57226800E-01, -.36634100E-02, -.18508500E+00, -.10153700E+00, -.67550100E-01, 0.24831400E+00, -.38905700E+01, -.73830900E+00, 0.73325600E+00, 0.12968800E+00, 0.66875200E+00, -.81190100E+00, 0.75588900E+00, -.20763900E-01, -.57942000E+00, -.30705900E+01, 0.60853300E+00, -.42339800E-01, 0.99147000E+00, -.23524600E+00, -.66701800E+00, 0.71378800E+00, -.19350200E+01, -.27987300E+00, -.10021900E+00, -.69633100E-03, 0.33812600E+00, -.34874800E+00, 0.21462100E+01, 0.15872300E+01, 0.84856500E+00, -.22091800E+00, -.23053000E+00, 0.34274700E+00, -.36776000E-01, 0.17861900E+00, -.21189500E-03, 0.43577000E+00, -.47376900E+00, 0.12063800E+01, -.40121700E-01, 0.25796200E+00, 0.30557400E-01, 0.25143400E+00, -.30480500E+00, 0.10877300E+00, -.89280000E+00, 0.49619100E-01, 0.17536400E+00, -.17223500E+00, -.27933100E+00, 0.10236000E+01, -.55798100E+00, -.30882500E+00, -.29390300E-01, 0.65369100E+00, 0.20548500E+00, 0.26659000E+00, -.60545200E-01, 0.12374100E+01, -.11914900E+01, 0.76090600E+00, -.18777300E+00, 0.66206900E+00, -.25515400E+00, -.21341600E+00, -.25330800E-01, 0.38945000E-03, 0.28401800E+00, -.90283100E-01, 0.31822100E+00, -.18425300E+00, 0.54236700E+00, -.58734100E-02, 0.13738600E+00, -.36991400E+00, -.19164700E-01, 0.93161300E-01, -.94833300E-01, 0.22700600E+00, 0.18285800E-01, -.15026800E+00, 0.15706100E+00, -.20932200E-01, -.16671900E+00, -.73173500E-01, 0.28225700E+00, 0.30262900E+00, -.15414800E+01, -.42068300E-01, 0.30102700E+00, -.15127200E-01, -.15540900E+01, -.23544900E+00, 0.15976800E+00, 0.55824300E-01, 0.71695300E+00, -.72244100E+00, 0.17725400E+01, -.27890800E+00, -.15174300E+00, -.13240600E+01, -.68874600E-02, 0.10380300E+01, -.92716900E+00, 0.25284300E+01, -.15293000E+00, -.10662400E+01, -.88255600E+00, -.92421700E-01, -.33851900E-01, 0.49016300E-01, 0.65006000E+00, -.13051900E-02, 0.11307800E+00, 0.21420500E+00, 0.60338500E-01, 0.81010800E+00, -.11752000E+00, 0.77800800E-01, -.42003300E+00, 0.69939500E+00, -.15343100E+00, -.17910900E+00, 0.47070800E-01, -.83753000E-02, -.20843100E-01, -.11802100E+00, -.71706900E-01, -.11817500E+01, 0.10639300E+00, 0.16288300E+00, -.70353200E-01, 0.37658100E-01, -.34237000E-01, -.11839200E-01, 0.64655700E-01, -.60896000E-01, -.56476900E+00, 0.16006500E+00, 0.40308300E+00, 0.10245300E+01, 0.76654300E-01, -.24024400E+00, -.37613100E-01, 0.23022300E+00, 0.12070000E-01, -.35181600E-01, -.75112700E+00, -.26877500E+00, 0.92438300E-02, 0.44969400E-02, -.17813300E-01, 0.29155100E+00, 0.61658200E-01, -.61970500E-02, -.32627000E-01, -.14380200E-02, -.23234000E-01, -.21681800E+00, -.34264000E-01, 0.85041300E-02, -.65919700E-02, 0.17191000E+00, 0.47882300E-01, -.78446200E-01, 0.12058600E-01, -.12384300E-01, -.13740300E-01, 0.11670100E+00, -.38363700E-01, 0.23148500E-01, -.36470300E-01, 0.93493100E-01, -.12796700E+00, 0.85595000E-01, -.23990400E-01, -.32061000E-01, -.17722400E-01, -.97764000E-01, -.44528600E+00, -.67339400E+00, -.10861400E+01, -.10231300E+00, -.28748800E+00, -.22446400E+00, 0.57521900E+00, 0.10534900E+00, -.48984700E-01, -.16451000E+00, 0.10302500E+00, -.99461800E-01, -.49110100E-01, 0.16428500E+00, -.84328700E-01, 0.16711800E+00, 0.29071400E+00, -.42899000E-01, 0.26034700E+01, -.89773600E+01, -.62519600E+01, 0.60229700E+01, 0.63437400E+01, 0.64663200E+01, 0.22586500E+01, 0.62328100E+01, 0.71402900E+01, 0.76496100E+01, 0.82045800E+01, -.62354200E+01, 0.78339100E+01, 0.66679100E+01, -.64804100E+01, 0.79236100E+01, 0.11528300E+02, -.58312700E+01, 0.13358800E+01, -.74540600E+01, 0.61169200E+01, -.75578800E+01, 0.90377900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42971700E+00, 0.12088400E+01, 0.10969800E+00, 0.90148400E+00, -.21831900E+00, -.74099500E+00, 0.28406300E-02, 0.77243100E+00, 0.38625100E+01, -.58326900E+00, -.17484400E-01, 0.21064100E+00, -.11973900E+00, -.52692200E-01, 0.22367300E+00, -.33688200E+00, -.10531200E+01, -.68476300E+00, -.48712700E-01, 0.43245400E+00, -.11811500E+00, -.22818100E-02, -.12295000E+01, -.10925800E+00, 0.97876400E-01, 0.13507500E-02, 0.21903400E+00, -.76177400E-02, 0.36276500E-01, -.11411000E-01, -.12371900E+00, -.10218900E+00, 0.57936100E-01, 0.61181300E-01, 0.22415700E+00, 0.70121600E-01, -.39733200E-02, -.17637200E-01, -.34398300E+00, 0.32527500E-01, 0.29752900E-01, -.41769200E-01, -.35144800E+00, -.13233100E+00, 0.21079000E-01, 0.27416700E-01, -.82270700E-01, -.32777800E-01, 0.10157300E+00, -.25953200E-01, 0.70501800E-02, -.18206300E+00, -.16001100E-01, 0.23351500E-02, -.88838000E-01, 0.33123200E+00, 0.47567200E+00, -.62022300E-01, -.10384000E+00, -.74697200E+00, -.38389400E-01, -.45655800E-02, 0.21502000E+00, 0.24879800E-02, -.33420000E+00, 0.22910900E-02, 0.49943000E+00, -.12622300E+00, -.34609700E-01, -.43640600E-03, 0.57842800E-01, 0.12908800E-01, 0.11174600E+01, 0.12705600E+00, 0.15393400E+00, 0.90376100E-01, -.95014700E-01, 0.12169100E+00, -.59594800E-01, -.15479500E-01, 0.28570700E-03, -.27222600E+00, -.34357600E-01, -.85121900E-01, 0.20436600E+00, -.20965000E+00, -.60295500E-01, 0.63642300E+00, -.23610500E+00, 0.32199000E-01, -.38568000E+00, -.22793200E-02, -.65519700E-02, -.16084500E+00, 0.14090300E-01, 0.82144300E-01, 0.66311500E-01, -.64671300E-01, -.22695800E+00, 0.28707500E+00, 0.22797400E+00, 0.77162700E-01, -.80307700E-02, 0.23190600E+00, -.14586500E+00, -.85150800E-01, 0.60414200E-01, -.85526100E-01, -.63648000E-02, -.15988800E-01, -.17945400E-01, -.48389200E-01, -.30689900E-01, 0.96190100E-02, 0.22507600E-01, 0.42323000E+00, 0.24904900E-02, 0.85124900E-02, -.22579700E-01, -.10758700E+00, -.32241400E-01, -.43491500E-01, 0.46198500E+00, 0.97054900E-01, -.44072000E-02, -.36283600E-01, 0.24308500E+00, -.33226100E-01, -.52424100E-01, 0.49909200E-01, 0.13335700E+00, -.61986000E-01, 0.31471800E+00, -.22862800E-01, 0.80974800E-01, 0.37043400E-03, 0.51379900E-01, 0.32472500E-02, 0.69569000E-01, 0.10674600E-01, -.30130900E-01, 0.19176700E+00, -.12611800E+00, -.24539700E-02, 0.41285100E-02, 0.16521100E+00, -.86512700E-02, -.16921100E+00, -.48715400E-01, 0.21590100E+00, -.30855000E-01, -.10288000E+00, 0.16242100E+00, 0.11434400E+00, 0.17069900E-01, -.10446100E-01, -.85017600E-01, -.48554700E-02, -.78329900E-01, 0.28223500E-01, 0.22792000E-01, 0.35822000E+00, 0.28453400E+00, -.31178700E-01, -.48019600E-01, 0.43314600E-01, -.29623200E-01, -.12186500E+00, 0.95866000E-02, -.43175200E-01, 0.18673700E-01, 0.20177700E-01, -.38012200E-01, -.12018300E+00, 0.79698600E-01, -.15391300E-01, 0.27225600E-01, 0.31422300E-01, -.15959800E-01, 0.93051400E-02, 0.13983400E-02, 0.43660400E-02, 0.21795700E+00, 0.64160200E-02, 0.39513100E+00, 0.76153200E-01, 0.14403800E-01, 0.41899500E-01, 0.17990900E-01, 0.47718000E-01, 0.59483300E-01, 0.69847000E-02, -.88147100E-01, -.34788400E-01, 0.19568400E-01, -.11712600E-02, -.37969700E-02, -.32458300E+00, -.40092600E-01, -.11657700E-01, -.79005800E-03, -.26284700E-02, 0.31978600E-01, 0.66290900E-01, -.34899500E-01, 0.14162900E-01, -.28595400E-01, -.13607500E-01, 0.22031800E-01, 0.49529300E-01, -.11636200E-01, -.66305800E-01, 0.12530700E-01, -.53999000E-02, -.18180500E-01, 0.24294200E-01, -.27014500E-01, 0.75223500E-01, -.12433300E-01, -.29250400E-01, -.11858000E-02, 0.50436900E-01, 0.44420600E-01, 0.39075000E-01, 0.13105100E+00, -.23982500E+00, 0.31176100E+00, 0.10336100E-01, 0.85506200E-01, 0.57667100E-01, -.17829300E+00, -.20189900E-01, 0.74874800E-01, -.25362800E-01, -.48889000E-01, -.15205900E+00, 0.97557200E-04, -.21827700E+00, 0.58205400E-01, -.67527900E-01, -.15460000E+00, -.11926100E-01, -.17760200E+00, -.20499700E+01, -.81835700E+00, 0.34192000E+00, 0.40607000E+00, 0.40826200E+00, 0.82199500E-01, 0.82751300E+00, 0.10607600E+01, 0.94024600E+00, 0.10035500E+01, -.44145200E+00, 0.57063900E+00, 0.42978900E+00, -.42059800E+00, 0.93021700E+00, 0.17553200E+01, -.24299400E+00, -.17187700E+00, -.44656700E+00, 0.34088100E+00, -.11455300E+01, 0.20544600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.53488100E+00, -.73181200E+00, 0.75943000E-01, -.95532300E+00, 0.19556600E+00, 0.54170800E+00, -.10669200E+00, -.14730300E-02, 0.51864800E+01, 0.71438000E+00, 0.20510200E-01, 0.69439800E+00, 0.28315300E-01, -.23404500E-02, -.21978200E-01, 0.66018200E+00, 0.17039600E+01, 0.52501100E+00, 0.19349000E+00, -.29193200E+00, 0.34439300E+00, -.11292200E+00, 0.14639000E+01, 0.32452400E+00, -.70989900E+00, 0.21582500E-01, -.62463000E+00, -.51852100E-01, 0.18117200E+00, 0.29545200E-01, 0.48795800E+00, 0.14261400E+00, -.61373100E-01, 0.67233300E-01, -.48472900E-01, 0.77073200E-02, -.16288200E-02, -.35528800E-01, 0.28559100E+00, -.13779300E+00, -.10432400E+00, 0.35588100E-01, -.19277600E+00, -.96797700E-01, -.14704800E-01, -.41166200E-01, -.16035700E+00, 0.35134500E-01, -.18776200E+00, 0.24187000E-01, -.51422400E-01, 0.13332900E+00, -.51027600E+00, -.37126100E+00, -.10329700E+00, -.35650900E+00, -.50150500E+00, -.63155800E-02, -.17256400E-01, -.79599100E-01, -.44156900E-01, 0.12956900E-01, -.20525900E+00, 0.10876900E+00, 0.31112200E+00, 0.36514800E-01, -.76661800E+00, -.10595300E-01, -.22615500E-02, 0.28468000E-03, -.46278000E-01, -.59104400E-01, -.13947500E+01, 0.38225900E+00, -.26927500E+00, -.30296500E+00, -.34078300E-01, -.16786100E+00, 0.34857200E-02, 0.18811300E-01, -.25166200E-04, 0.61824400E-01, 0.83949600E-01, -.23044000E-02, -.27786600E+00, 0.88789600E-01, 0.22807400E-01, -.23631800E+00, 0.28279100E+00, -.17325700E-01, -.93299400E-01, -.29356800E-02, 0.11799000E-01, 0.21398600E+00, 0.13758600E-01, -.18797500E+00, 0.13949800E-01, 0.64652000E-01, 0.11782200E+00, -.24927300E+00, -.39736300E-01, -.80795300E-01, 0.72511200E-02, -.54204300E-01, -.19675800E-01, 0.96803600E-01, -.19479400E-01, 0.99019100E-01, -.57685000E-01, -.22191000E-01, 0.32988600E-01, 0.88372700E-01, 0.47563800E-01, -.14921600E-01, -.24721700E-01, -.80943200E+00, -.13031400E+00, -.61721200E-02, -.14596600E-02, 0.20208000E+00, -.55310000E-01, 0.72363100E-01, -.29707600E+00, -.56361300E-01, 0.46459000E-03, 0.66859900E-01, -.16178700E+00, -.18540100E-01, -.34788100E-01, -.30821700E-01, -.18169000E+00, 0.96258300E-01, -.79713400E+00, 0.32882600E-01, -.58406000E-01, 0.28367400E-02, -.24989100E+00, -.16302600E-01, -.43781600E-01, 0.39657400E-02, 0.13202100E+00, -.12432700E+00, 0.18290200E+00, 0.50747200E-01, -.40540500E-01, -.21825500E+00, 0.16469600E-01, 0.17662100E+00, 0.20220500E+00, -.47851800E+00, -.26324100E-01, -.85513200E-01, -.31444800E+00, -.12331000E+00, -.49139600E-01, -.12524500E-01, 0.95682800E-02, 0.86676500E-03, -.15820600E-01, 0.22516700E-01, 0.28815000E-01, -.35533100E+00, -.22443200E+00, -.22045200E-01, -.38272100E-01, -.16161300E-02, -.48929800E-02, 0.74787300E-01, 0.26735400E-02, 0.37533200E-01, -.36796200E-01, 0.48781900E-01, 0.73917100E-01, 0.46094700E-01, 0.18039500E-01, 0.40879600E-01, -.19900000E-01, -.39085500E-01, 0.14992300E-01, 0.21887300E-03, -.45531400E-01, 0.10125300E-01, -.48166500E-01, -.33155700E-01, -.41741500E+00, -.89385300E-01, -.92450100E-02, -.27653700E-01, 0.16053700E-01, -.39160500E-01, -.42401700E-02, -.37372200E-01, -.15707200E+00, -.61229800E+00, -.21504100E-01, 0.22338200E-01, 0.49764600E-01, 0.10867000E+00, 0.39654500E-01, -.44126900E-01, 0.17531800E-01, 0.29155100E-03, -.13263200E-02, 0.63588700E-02, -.67459000E-01, 0.76530500E-02, 0.47399400E-01, -.44612700E-01, -.72616300E-02, -.14761300E-01, 0.14965600E-01, -.37470700E-01, -.24603100E-02, 0.30994500E-01, -.24307900E-01, -.12331100E-01, 0.51353000E-02, 0.37984800E-01, 0.29198300E-01, -.72909300E-02, -.29757400E-02, -.12152600E-02, -.15740600E-01, 0.51193800E-03, 0.63327000E-01, 0.45018900E-01, 0.94294200E-01, 0.18457500E-02, 0.66165900E-01, 0.31593600E-01, 0.14088900E+00, -.46824700E-04, 0.31945000E-01, 0.23117900E-01, -.29937100E-01, -.15804300E+00, -.96183200E-02, -.19575700E-01, 0.15266300E-01, 0.12049800E-01, -.15339600E+00, 0.87605800E-02, 0.12606700E-01, -.15422400E-01, 0.81402800E+00, 0.17844500E+00, 0.28004600E+00, 0.29871700E+00, -.21504400E-03, -.75423300E+00, 0.25250400E+00, -.25197400E-01, 0.58706400E-01, -.40073600E-01, -.91228300E-02, 0.29719000E+00, -.28505200E+00, 0.75283100E-01, 0.15815000E+00, -.93683500E-01, -.10744900E+00, -.24138900E+00, 0.11929600E+00, 0.86822800E-01, 0.14186700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16946000E+01, 0.20600400E+01, 0.29192700E+00, 0.14462300E+01, 0.13480700E+00, -.44259100E+00, 0.45860100E+00, 0.18530200E+01, -.38500400E+01, 0.56960900E+00, -.90851200E-01, -.55122100E+00, -.47699900E+00, -.16792500E+00, 0.10046100E+01, -.13850700E+01, -.22496400E+01, 0.19311600E+01, 0.58594400E+00, 0.12808700E+01, -.11228800E+01, 0.49988700E+00, -.35864500E+01, 0.26756100E+00, -.58891500E-01, 0.14049200E-01, -.71988500E-01, 0.82709600E-01, -.13653000E-01, -.42724600E+00, -.37433800E+00, -.73258000E+00, 0.10032600E+00, 0.11134400E+00, 0.66563200E-01, 0.11497400E+00, -.31742200E-02, -.32013200E+00, -.49254800E-01, -.33257800E+00, 0.39273200E+00, 0.26122100E+00, 0.17563700E+00, 0.50108300E+00, 0.55424700E-01, 0.33637700E-01, -.43175400E+00, 0.55594500E-01, -.15599200E-01, -.13161900E+00, 0.90528800E+00, -.16893800E+00, -.11847000E+01, -.55699300E-01, -.20371200E+00, 0.79489600E+00, -.52403600E+00, -.10650200E+00, 0.50698800E+00, -.82467900E+00, 0.10564900E+01, -.10177600E+00, -.57877800E+00, 0.10495600E+00, 0.42499700E+00, 0.16631900E+00, -.13061900E+00, -.82746500E-01, 0.20513500E+00, -.27378900E-02, 0.26254300E+00, 0.51425600E+00, -.13936300E+01, 0.12060100E+01, -.43504600E+00, -.63883600E+00, 0.20890200E-01, 0.45131600E-01, -.16281500E-01, -.94825000E-01, 0.21720000E-04, 0.33442600E+00, 0.49798400E-01, -.56815100E+00, 0.32067200E+00, 0.92792500E+00, 0.79317700E-01, -.56684700E+00, -.27951000E+00, -.96403500E-01, -.67655000E+00, 0.41830000E-02, 0.84787700E-01, 0.45220700E+00, -.21286900E+00, -.28776600E+00, 0.76421600E-01, 0.21473300E+00, 0.75947100E-01, -.39874000E+00, -.55665500E+00, -.16549800E+00, 0.34731600E-01, -.32895200E+00, 0.30988200E+00, -.19850300E+00, -.85674400E-02, 0.29407500E-01, 0.11013400E+00, 0.15424700E+00, -.11347700E+00, -.25427500E+00, 0.12675900E+00, -.40579900E-01, 0.17345000E-01, 0.28849400E+01, 0.52711600E+00, -.78768600E-01, 0.45902300E-01, -.15600400E+00, 0.29825900E+00, -.94685100E-01, -.60900300E-01, -.50071200E-01, 0.29322200E-01, -.52082100E-01, -.58399500E+00, 0.28856600E+00, 0.11880000E-01, 0.16482300E+00, 0.41907100E-01, 0.88884500E-01, 0.11391500E+00, 0.63356800E-02, -.44282900E-01, -.14495200E-01, -.33544500E+00, -.15526900E+00, 0.18099900E-02, 0.25594000E-01, -.16734600E+00, -.14190100E+00, 0.13514000E+00, 0.25520700E+00, -.15453100E-01, -.40496900E+00, -.64875300E-02, 0.28140400E+00, 0.52164900E-01, -.26684500E+00, -.10082100E+00, -.12084100E+00, 0.24823800E+00, 0.40374100E-02, 0.49614400E-01, 0.19848500E-01, 0.31558700E-01, 0.14916900E-02, 0.47982700E-01, 0.72577100E-01, 0.12436400E-01, 0.11634300E+00, -.24192800E+00, 0.31958000E-01, -.30546600E-01, 0.11505000E+00, 0.12951800E-01, -.67874200E+00, -.56266500E-02, -.24754400E+00, 0.28825500E+00, -.35634100E+00, -.87098300E-01, -.63834400E-01, -.81114100E-01, -.15046100E+00, 0.92086700E-01, -.23645500E-02, -.87641600E-01, -.20520200E-01, 0.21910500E+00, -.60375600E-01, -.62485200E+00, -.25419100E-01, 0.76936100E+00, 0.10414000E+00, 0.63240000E-02, 0.74959700E-01, 0.32070900E-01, 0.61535200E-01, -.27744500E-01, -.46602700E-03, -.33069600E+00, -.15677900E+01, -.22544200E+00, 0.89728900E-01, -.29235200E-01, -.12106300E+00, 0.41751500E-03, -.61399000E-01, 0.12801700E-01, -.52249000E-03, 0.20842600E-01, -.54506800E-02, -.71939700E-01, 0.16131100E-01, 0.22518600E-02, -.42558300E-01, -.73882300E-02, 0.30191800E-01, -.13001200E-01, 0.67943100E-02, 0.61703300E-02, -.15439800E-01, 0.21677200E-01, 0.25559000E-01, 0.23666100E-01, 0.48812900E-02, -.81670200E-02, 0.14304600E-01, 0.19866700E-01, 0.18039200E-01, -.11138000E-01, 0.16275100E-02, -.61663400E-01, 0.38267200E-01, 0.58419000E-01, -.57319700E-02, -.19355600E-01, 0.12968200E-02, -.36799600E-01, -.23360000E-02, -.85743700E-02, -.12060100E-01, 0.21575800E-01, 0.18244500E+00, 0.21014000E-01, 0.64236500E-01, -.32341400E-01, 0.68853900E-02, -.11446400E-01, 0.34332200E-02, 0.33190400E+00, -.15154700E+01, 0.10212100E+01, -.19540100E+01, -.21036900E+01, -.22095100E+01, -.13056200E+00, -.43119300E-01, -.92377700E+00, -.97777400E+00, -.11978200E+01, 0.10226700E+01, -.14086400E+01, -.22077200E+01, 0.21559100E+01, -.12382400E+01, -.13738900E+01, 0.14494700E+01, -.16438300E+00, 0.22819900E+01, -.13797200E+01, 0.57065800E+00, -.21969500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.43760400E+00, -.21673500E+00, -.78598500E-01, -.27852200E+00, 0.56263800E+00, 0.40935800E+00, -.31790500E-01, 0.18668100E+00, 0.51959700E+01, 0.10938900E+00, -.29968200E-01, 0.57885000E-02, 0.19861800E+00, -.95636000E-02, -.73453200E+00, -.33971600E+00, 0.16397100E+00, -.21071300E+00, -.93853200E-01, -.40775600E+00, -.68286300E-01, 0.28696200E-01, -.13634700E+00, 0.39671600E-01, -.69701000E-01, -.75237900E-02, -.12801200E+00, -.82426700E-02, -.40880800E-01, -.11732600E-01, -.16766600E+00, -.56230800E-01, -.13953900E-01, 0.19010100E+00, 0.34087000E-01, 0.11359700E+00, 0.45729300E-02, 0.53253000E+00, -.38615500E+00, -.43779800E+00, -.18116600E+00, -.20168300E-01, -.43535400E+00, -.70386000E-01, 0.91847000E-01, -.58162500E-01, -.22731700E-01, -.98709400E-02, 0.12247400E+00, -.14815400E-02, -.67234100E+00, -.25507100E+00, 0.11709500E+00, 0.35152600E+00, -.32035900E-01, -.20001600E-01, 0.36290600E+00, -.28761600E-01, 0.46922500E-01, 0.22639200E+00, 0.96810000E-01, 0.49403200E-01, 0.38165300E+00, -.44653100E-01, 0.33814700E+00, -.32554500E-01, -.70918400E+00, -.34142200E+00, -.20682300E-01, -.57080500E-03, 0.11561300E+00, 0.29353800E-01, 0.49549800E-02, 0.31626300E-01, -.28219700E-01, -.38515800E-01, 0.24851800E+00, -.52298000E-02, -.48399800E-01, -.40361600E-01, 0.23991200E-03, -.10900300E-01, -.56422500E-01, 0.16913300E-01, 0.10705200E+00, -.14257000E-01, 0.20286600E-01, -.67372100E+00, 0.22577900E+00, 0.32855400E-01, -.21698200E+00, -.43688300E-03, 0.10326500E+00, 0.97891400E-02, -.76461200E-02, -.84766900E-01, 0.22288100E+00, -.43109600E-01, -.24687900E+00, 0.15384200E+00, 0.35009900E+00, -.58893000E-01, 0.32788200E-02, -.47747600E-01, 0.27944100E-02, -.16900900E+00, -.27402200E-01, 0.28968000E-02, -.73441900E-01, -.17784200E-01, 0.18222900E-01, 0.79884900E-01, -.68284000E-01, 0.21872900E-01, -.32201200E-01, -.90956700E+00, -.30811100E+00, -.20672700E-02, -.39161100E-01, 0.57828800E-02, -.91204300E-01, 0.54753500E-01, -.31362500E+00, -.36037500E-01, -.18079400E-02, -.16697700E-01, -.49295900E-01, -.10624400E-01, 0.84828500E-01, -.97330100E-01, -.15514700E+00, 0.15726100E+00, -.58736300E+00, 0.14567900E-01, 0.13893700E-01, -.60579600E-02, 0.21561900E+00, 0.76379000E-01, -.29356100E-01, -.17531500E-01, 0.15344100E+00, -.27315700E+00, 0.13486600E+00, -.14845000E+00, -.33903300E-01, -.77633900E-01, -.43601100E-02, -.34755800E-01, 0.18823700E-01, -.41700500E-01, 0.30711400E-01, -.19790200E+00, 0.15192300E+00, -.61595600E-01, 0.15894600E-01, -.10413100E-02, 0.65629100E-01, -.44593400E-02, 0.52473700E-01, 0.14349000E+00, -.37796900E-01, 0.31377300E-01, -.46348600E+00, -.63676400E-01, -.73769800E-01, 0.19723200E+00, 0.48871400E-01, 0.39854400E-01, -.22127800E-01, 0.10601400E+00, -.17420700E+00, 0.55515700E-01, 0.23644300E-01, -.13099900E+00, 0.77991300E-01, 0.12916000E+00, -.31759400E-01, -.57956600E-01, 0.32444800E-01, -.20495600E-01, 0.15682700E+00, 0.38956900E-02, -.58828600E+00, 0.30740800E-01, -.60869300E+00, -.21571300E+00, -.62738700E-02, -.49594900E+00, -.66835200E-02, -.21284400E+00, -.10947600E+00, -.46065500E-01, 0.17615900E+00, 0.33883000E-01, -.17759200E-01, 0.14901500E-01, 0.17920300E-01, 0.19859200E+00, -.67075100E-05, -.36316100E-01, 0.18703500E-01, 0.95234100E-02, -.74066900E-01, -.10963900E+00, 0.13470600E+00, -.66789600E-01, 0.21271500E-01, 0.58377700E-01, -.73328800E-01, -.10770000E+00, 0.51673900E-01, -.29778400E-01, -.22488400E-01, 0.66069800E-01, 0.32507100E-01, -.67972300E-02, -.68919400E-01, 0.85692700E-01, 0.12017700E-01, -.31720400E-01, 0.17818700E-01, -.85013900E-01, 0.14622100E+00, 0.62147400E-02, 0.13373100E+00, -.26545800E+00, -.41168100E+00, 0.13939900E-01, 0.60098600E-01, 0.32002700E-01, 0.30379900E-01, -.11202200E-01, -.50310600E-02, 0.22296900E-01, -.23227200E-01, -.68354100E-01, -.14444600E-01, -.30058000E-01, 0.94454100E-02, -.62547900E-02, 0.14075700E+00, -.10841000E-01, -.11849600E+00, 0.54166700E+00, -.21159600E+00, -.29025200E+00, 0.91521700E+00, 0.11047800E+01, -.56752000E-01, -.80714300E-02, 0.20350400E+00, 0.16773000E+00, 0.13815000E+00, -.43650300E+00, 0.21305100E+00, 0.12141100E+01, -.11766600E+01, 0.96493000E-01, 0.33115700E+00, -.25524900E+00, -.68919600E-01, 0.63422600E-01, 0.25279800E+00, -.13653900E+00, -.63306000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15305600E+00, -.49588600E+00, 0.32167800E+00, 0.44297700E+00, -.24521200E+00, 0.73203000E-01, 0.61781300E-01, 0.60550600E+00, 0.57575600E+01, -.38672900E+00, -.13477300E-01, 0.18001000E+00, -.13739400E+00, -.14296400E+00, 0.11063800E+01, -.86964700E-02, 0.94084500E-01, 0.11400400E+01, 0.23697200E+00, 0.99870400E-01, -.20595900E+00, 0.73851500E-01, -.27328500E+00, 0.43888400E-03, 0.16194000E+00, -.84408600E-02, -.20531000E-01, -.23018500E-01, 0.14019400E-01, 0.20780100E-01, 0.18622200E-01, -.50777900E-01, -.18218700E-01, 0.13911800E+00, 0.13234000E+00, -.25670700E-01, 0.19641300E-02, -.59628200E-01, -.81328000E-01, -.83203700E-01, -.14366800E-01, 0.25325200E-01, 0.14438600E+00, 0.15977300E-01, 0.14071300E-01, 0.14132200E-01, 0.26026500E-01, 0.15133500E-01, 0.14753000E+00, -.87185500E-01, 0.55646400E-01, -.19507400E-01, 0.11615300E+00, 0.77038900E-01, 0.29175000E-01, -.14853300E+00, -.77897100E-01, -.25119500E-01, 0.37898200E-01, 0.98495100E-01, 0.10208000E+00, -.61819100E-02, 0.18533200E+00, -.53087400E-02, 0.11948600E-02, 0.18604000E-01, -.45263000E+00, -.32068300E-01, 0.38382800E-02, 0.11926200E-03, 0.14386300E-01, -.16373200E-01, -.20202600E+00, 0.15004900E+00, -.30151100E-01, -.12973200E+00, 0.82902500E-01, -.93390900E-01, 0.51657800E-02, -.30047500E-01, 0.48992800E-03, -.18983200E+00, 0.61486800E-01, -.36511600E-01, 0.21263000E+00, 0.17415400E-01, -.13117000E-01, 0.25674900E-02, -.51138000E-01, -.28207100E-01, -.10051200E-01, 0.20227600E-02, 0.16507500E-01, -.68628000E-01, -.21587700E-01, 0.97839100E-01, -.12032700E-02, 0.73986000E-02, 0.62611700E-01, 0.16978000E-01, 0.26770100E-01, 0.43901300E-01, -.65619400E-02, 0.29290800E-01, 0.38952600E-01, 0.71758600E-01, 0.30187200E-01, -.20307500E-01, 0.36834900E-01, 0.29617200E-01, -.28131200E-01, -.73760900E-01, -.52266300E-01, 0.16542400E-01, 0.10608700E-01, 0.30332000E+00, 0.96164800E-02, 0.25453000E-01, -.32843800E-02, -.89768200E-01, 0.68394900E-01, -.56540300E-01, 0.18749800E+00, -.40238700E-02, -.10420200E-01, -.27444600E-01, 0.19686600E-01, 0.77618000E-02, -.12841500E+00, -.82467000E-01, -.14522400E-01, -.77471100E-01, -.20199100E+00, -.32803000E-01, -.34406500E-02, 0.10352500E-01, 0.19078900E+00, 0.97412400E-01, 0.32932000E-01, 0.22616200E-04, 0.59743100E-01, -.10761600E+00, 0.17104700E-01, -.47215000E-01, -.19496300E-01, -.37024100E-01, 0.95889300E-03, 0.80273200E-01, -.33046700E-02, 0.13665700E-01, 0.19577200E-01, -.14389900E+00, -.83221300E-01, 0.35260000E-01, -.32358100E-01, -.20673100E-01, -.24609600E-01, -.73401900E-03, -.14535100E-01, -.60803700E-02, -.43601600E-02, 0.12555800E+00, 0.86542900E-01, -.34512200E-01, 0.73821900E-02, 0.25663300E-01, 0.27146700E-02, -.12622900E+00, -.27491700E-02, 0.19241300E-01, 0.15529500E-02, -.34436100E-02, 0.18802200E-01, -.24854500E-02, -.23082600E-01, -.10415600E-01, -.20039500E-01, 0.13618700E-01, 0.22831400E-01, -.52901800E-02, 0.26989400E-01, -.82790300E-02, 0.30646600E-01, -.16686600E-01, 0.13503100E+00, 0.23654700E-01, -.15647100E-01, 0.38719900E-01, -.49633200E-02, 0.12608800E-01, -.60898100E-02, -.22606500E-02, -.11755200E+00, -.32713300E-01, -.32692800E-02, 0.12931300E-02, -.99004700E-02, 0.25871100E-01, 0.63163100E-02, 0.23604200E-02, -.36216100E-02, 0.13035600E-02, -.52371600E-02, 0.78861700E-02, 0.12516400E-01, -.48579100E-02, 0.60544100E-02, 0.13966400E-01, -.18379800E-02, 0.43198200E-02, -.25040700E-02, -.55421000E-02, 0.11775200E-02, 0.95985100E-03, -.10671900E-01, -.28980800E-02, -.30695100E-02, -.41675200E-02, 0.18789100E-02, -.12426800E-02, -.41699300E-03, -.24291300E-02, -.94245000E-02, -.29447700E-04, -.64720000E-02, -.15694400E-01, -.18359900E-01, 0.29214500E-02, 0.95162300E-02, 0.14817900E-01, -.15401000E-04, 0.14799200E-02, 0.45072500E-02, 0.17059200E-02, -.10317100E-01, -.30443200E-01, -.41758700E-02, 0.10314100E-01, -.50446900E-02, 0.97023000E-03, 0.18073800E-01, -.25957800E-02, -.29535000E-01, 0.11110400E+00, -.78305100E-01, -.60139400E-01, 0.41701700E-01, 0.20634800E+00, -.56398700E-02, 0.53611700E-03, 0.52350600E-01, 0.28409500E-01, 0.23675700E-01, 0.76277600E-03, 0.10052500E-01, -.55636100E-01, -.62392200E-01, 0.25339300E-01, 0.85749900E-01, -.31282300E-01, -.12803300E-01, -.13886600E-01, 0.37310800E-01, -.99043900E-02, -.13671000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10517800E+01, 0.10999800E+01, -.87271100E-01, 0.92179600E+00, 0.12681100E+00, -.33250800E+00, 0.29249800E+00, 0.12882700E+01, 0.35612100E+01, 0.30416700E+00, -.15332800E+00, -.17968900E+00, -.27868100E+00, -.58309000E-01, 0.37190000E+00, -.79868800E+00, -.14977100E+01, 0.29092400E+00, 0.23858200E+00, 0.54051300E+00, -.14835000E-01, 0.30144500E+00, -.16791300E+01, 0.14157700E+00, -.17397200E+00, 0.10136200E-01, -.27120400E+00, 0.21170600E-03, -.22809200E-02, -.18064800E+00, -.16848300E+00, -.41059700E+00, 0.10369800E+00, 0.39436300E-01, 0.14648700E+00, 0.80865100E-01, -.42147000E-02, -.15494900E+00, -.21880900E+00, -.23583200E-01, 0.23356700E+00, 0.49725200E-01, -.43075700E+00, -.71048600E-01, 0.39195800E-01, 0.24360400E-01, -.14021600E+00, 0.10601600E-01, -.79839600E-01, -.54723100E-01, -.21132500E+00, -.22472000E+00, -.43152600E+00, -.10680200E+00, 0.33713800E-01, 0.16711700E+00, 0.34965300E-01, -.25202200E-01, 0.13500200E+00, -.58607400E+00, 0.52415300E+00, -.43894300E-01, 0.37309900E-01, -.16125700E+00, -.26320600E+00, 0.30389600E+00, 0.27592800E+00, -.26393000E-01, 0.36395400E-01, -.98266500E-03, 0.12822000E+00, 0.48741600E-02, 0.38506300E+00, 0.31515400E+00, -.21955300E+00, -.59897200E-01, -.31060500E-01, 0.25961400E+00, -.40807600E-01, -.42677500E-01, -.36512900E-03, 0.32565200E+00, -.22229300E+00, -.14614800E+00, 0.14101200E+00, 0.19421400E+00, 0.37247500E-02, -.25318900E+00, -.16012800E+00, 0.36146700E-01, -.36246200E+00, 0.78074100E-02, 0.29370600E-01, -.43411700E-01, -.56128000E-01, 0.98383200E-01, 0.79689100E-01, 0.43871500E-01, -.13070500E+00, 0.71129500E-01, -.31127900E+00, 0.38697900E-01, 0.67388600E-02, -.79745100E-01, 0.61347400E-01, -.18899800E+00, 0.63567500E-02, -.18248300E-02, -.46584200E-01, 0.54933600E-01, -.37031000E-01, -.86399300E-01, 0.31911600E-01, -.99839800E-02, -.19683700E-01, 0.81813300E+00, 0.12035300E+00, -.39518800E-01, 0.66897100E-02, -.17667400E+00, 0.63870500E-02, -.71064800E-02, 0.56034200E-01, 0.51270500E-01, 0.30099800E-02, -.81497200E-01, -.13555600E+00, 0.86509800E-01, 0.52200900E-01, 0.15625700E+00, 0.50557300E-01, -.53851100E-02, -.12022400E+00, 0.11382400E-01, 0.58549200E-01, -.20222700E-01, -.43592500E+00, -.11564000E+00, 0.40967900E-01, -.13615200E-01, -.15281700E+00, -.42205000E-02, -.63916800E-01, 0.10920200E+00, -.12819400E-01, -.14353000E+00, -.12239500E-01, -.39978800E-01, -.16572700E+00, 0.30903600E+00, -.37674900E-01, -.83198000E-01, 0.27301600E+00, 0.65454900E-01, 0.47770400E-01, 0.42130800E-01, 0.36627400E-01, 0.22715600E-02, 0.55036700E-01, 0.15642100E-02, -.29768100E-01, 0.19185300E+00, 0.20834200E-01, 0.32328700E-01, -.51152900E-01, 0.90939400E-01, -.95799300E-02, -.10236700E-02, 0.45070600E-02, -.15006000E-01, -.64033300E-02, -.85396800E-01, -.54048500E-01, -.18548000E+00, -.16670400E-01, -.39534100E-02, 0.34016700E-01, -.87454700E-02, -.70076300E-01, 0.70069600E-02, 0.76615900E-01, -.14337200E-02, -.17006100E-01, 0.26106200E-01, 0.23821800E+00, 0.12552300E+00, 0.21620100E-01, -.59896900E-01, -.63551400E-02, 0.30651500E-01, -.54908200E-03, 0.69200600E-02, -.26711400E+00, -.60661800E+00, -.69158800E-01, 0.14609100E-01, -.42901900E-02, -.15385200E+00, 0.28646300E-02, -.33304000E-01, 0.59372400E-02, -.32196700E-02, 0.14678500E-01, 0.89039600E-02, -.14366100E+00, 0.26763800E-01, -.58498400E-02, -.38224700E-01, 0.22024700E-02, 0.63887200E-02, -.41871800E-01, 0.20004700E-01, 0.45222600E-02, -.20994300E-01, 0.15001500E-01, 0.33072900E-01, 0.11427800E-01, 0.15223000E-01, -.44626800E-02, 0.24269500E-02, -.29238000E-02, 0.26510400E-01, -.67084400E-02, 0.75393700E-02, -.17789700E-01, 0.17816400E-01, 0.74737800E-01, -.68194000E-02, -.12018600E-01, 0.46864400E-02, -.40194300E-01, -.41211000E-02, -.62908100E-02, -.11121800E-01, 0.14223700E-01, 0.13254300E+00, 0.16636700E-01, 0.37281600E-01, -.21888200E-01, -.21585600E-02, 0.97286400E-02, 0.10425500E-02, 0.18311900E+00, -.86477100E+00, 0.57422500E+00, 0.59630500E+00, -.16128400E-01, -.39232700E-01, 0.12106000E+00, 0.36228400E-03, 0.52235300E-01, 0.37202700E-01, 0.48857800E-01, -.46305100E-01, 0.55029200E-01, -.45736900E-02, 0.82236900E-02, 0.70621900E-01, 0.11289000E+00, -.48871800E-01, 0.91246800E-01, 0.12661700E-03, 0.49018800E-01, -.33783100E-01, 0.22365800E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.59562200E+00, 0.80320600E+00, -.22365500E+00, 0.98545200E+00, -.19020200E+00, -.60744000E+00, 0.11015400E+00, -.28009800E-01, -.41258700E+01, -.39420600E+00, -.29308400E-01, -.67029800E+00, -.93033000E-01, 0.44133200E-01, -.24281800E+00, -.74038800E+00, -.19606200E+01, -.10292600E+01, -.23970300E+00, 0.10397200E+00, -.25707700E+00, 0.12967600E+00, -.19324900E+01, -.36876600E+00, 0.83391900E+00, -.24966700E-01, 0.96541200E+00, 0.60152800E-01, -.22410400E+00, 0.63200400E-01, -.50692000E+00, -.11942700E+00, 0.52184100E-01, -.15588300E-01, 0.14305300E-01, 0.21552800E-01, 0.22519400E-03, -.11999700E-01, -.18163700E+00, 0.14229500E-01, -.13184400E+00, 0.75780500E-03, 0.75363200E-01, 0.10174000E+00, 0.52397100E-01, 0.42567600E-01, 0.21805500E+00, 0.15447100E-02, 0.56392900E-01, -.50329400E-01, -.46106700E+00, -.19233600E+00, 0.35089900E+00, 0.30314700E+00, 0.21134000E-02, 0.83122500E+00, 0.42392100E+00, -.53426000E-01, 0.53368500E-01, -.10577400E+00, 0.10731000E+00, -.30977500E-02, 0.20675900E+00, -.71026900E-01, -.11513600E+00, -.39912200E-01, 0.70182600E+00, 0.23702400E-01, 0.90058200E-02, -.33291000E-03, 0.52811200E-01, 0.20865600E+00, 0.13682000E+01, -.58474400E+00, 0.29190200E+00, 0.43595900E+00, 0.14843700E+00, 0.21718200E+00, 0.46068000E-02, -.17924700E-01, -.13680300E-03, 0.24285500E-01, -.13786600E+00, 0.13532500E+00, 0.34155000E+00, -.63921700E-01, 0.35116800E-02, 0.48873500E+00, -.30046700E+00, 0.35296900E-01, 0.24266900E+00, 0.54550600E-02, -.30536800E-01, -.22075400E+00, 0.40762800E-02, 0.21276700E+00, 0.14362000E-01, -.76317600E-01, -.13349300E+00, 0.43537000E+00, 0.14281600E+00, 0.11015700E+00, -.17469100E-01, 0.14169900E+00, -.44422000E-01, -.15339300E+00, -.31518200E-02, -.10695500E+00, 0.57835500E-01, 0.50286600E-02, -.26412600E-01, -.99541100E-01, -.62494000E-01, 0.19584100E-01, 0.57164600E-01, 0.70506400E+00, 0.10269300E+00, 0.22166200E-01, -.92245300E-02, -.17304100E+00, 0.61522000E-01, -.88991500E-01, 0.39017200E+00, 0.64401400E-01, -.13587400E-02, -.64352700E-01, 0.21994400E+00, 0.15779900E-01, 0.53799100E-01, -.37254400E-01, 0.19722000E+00, -.31365900E-01, 0.11427500E+01, -.34419600E-01, 0.58082400E-01, -.23388500E-02, 0.26331400E+00, 0.25077900E-01, 0.45923300E-01, -.12221900E-02, -.11418000E+00, 0.12124600E+00, -.14810000E+00, -.57093500E-01, 0.39311400E-01, 0.20377200E+00, -.16194800E-01, -.15533700E+00, -.20388700E+00, 0.48049400E+00, 0.20200000E-01, 0.57317600E-01, 0.28419500E+00, 0.11928000E+00, 0.46478900E-01, 0.19970900E-03, 0.41859400E-02, -.17411700E-02, 0.95857100E-02, -.62928800E-02, -.23600700E-01, 0.36369100E+00, 0.12202800E+00, 0.23182700E-01, 0.31868600E-01, 0.96018700E-02, 0.41709300E-02, -.43092900E-01, -.30030700E-02, -.35345300E-01, 0.41689600E-01, -.40871600E-01, -.72512800E-01, -.31462700E-01, -.20146000E-01, -.38013700E-01, 0.12370800E-01, 0.43343500E-01, -.95573500E-03, -.30005300E-02, 0.68305500E-01, -.13860300E-01, 0.89918500E-01, 0.22272900E-01, 0.49654300E+00, 0.10309900E+00, 0.58967100E-02, 0.54436100E-01, -.84314400E-02, 0.32856900E-01, -.43543500E-02, 0.62535900E-01, 0.19502000E+00, 0.72598700E+00, 0.25114300E-01, -.22246200E-01, -.47955000E-01, -.10521800E+00, -.42032700E-01, 0.49103900E-01, -.13229700E-01, 0.78928800E-03, 0.96090600E-03, -.64949200E-02, 0.96237400E-01, -.12358200E-01, -.51838400E-01, 0.43945800E-01, 0.36591800E-02, 0.18121300E-01, -.11000400E-02, 0.28671900E-01, 0.19775700E-02, -.31026100E-01, 0.25131300E-01, 0.81933000E-02, -.21367500E-02, -.42068000E-01, -.27203300E-01, 0.74503700E-02, 0.22057900E-02, -.34956300E-02, 0.84725700E-02, -.32969700E-02, -.72919800E-01, -.20682700E-01, -.87137200E-01, 0.23623600E-02, -.64920000E-01, -.32395000E-01, -.16271700E+00, -.28179400E-02, -.21050700E-01, -.21409400E-01, 0.25935400E-01, 0.19970300E+00, 0.76775300E-02, 0.10683000E+00, -.14780100E-01, 0.42463300E-01, 0.13577500E+00, -.65898500E-02, -.11773600E-01, 0.23628200E-01, -.92609500E+00, 0.83946500E-03, -.12441200E-01, 0.50373500E-02, -.12624100E-01, 0.71582600E-01, -.17796500E-01, -.46191600E-02, -.54475800E-02, 0.44012100E-02, -.15832300E-01, 0.34973300E-02, -.20573200E-02, -.80147800E-02, -.30554700E-01, 0.84149400E-02, 0.49312700E-02, 0.38441500E-02, -.10087700E-01, 0.17747600E-03, -.40760600E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30563700E+01, 0.13685200E+01, 0.15479200E+01, -.32865300E-01, -.11803700E+01, -.10093200E+01, 0.49427300E+00, 0.37929200E+01, 0.29356400E+02, -.21587800E+01, -.45444700E-01, 0.21594900E+01, -.29510100E-01, -.47669500E+00, 0.19031000E+01, 0.10972100E+00, 0.70875400E+00, 0.46205200E+01, 0.88410800E+00, 0.14872300E+01, -.37893500E+00, 0.68336000E+00, 0.12678800E+00, 0.98366900E+00, -.10949200E+01, 0.61401900E-01, -.12464100E+01, -.34483200E-02, -.88345800E-01, -.43727900E+00, 0.55093700E+00, -.55195600E-01, 0.19807000E-01, 0.11967200E+00, 0.42181100E+00, 0.19674300E+00, -.95630600E-02, -.21219100E+00, -.86554200E+00, 0.17700100E+00, -.17966900E+00, -.15390600E+00, -.18384100E+01, -.64480600E+00, -.10640800E+00, -.46496000E-01, -.79370400E+00, -.50619600E-01, -.12805300E+00, -.19261000E+00, 0.16087600E+01, 0.58515400E-01, -.25458000E+01, -.75478900E+00, 0.92485500E-01, 0.11462700E+01, -.44495100E+00, -.25296400E-02, 0.36806100E+00, 0.40222800E+00, 0.29626400E+00, -.17073700E-01, -.61421600E+00, -.69878400E-02, -.44898600E+00, -.15903300E+00, 0.24537200E+01, 0.12399100E+00, -.53191100E-01, -.44143300E-03, -.25472300E-01, 0.76937900E-01, -.38933700E+00, 0.15237100E+01, -.58110500E+00, -.85285800E+00, -.85422600E+00, -.15381600E+00, -.24976600E+00, -.81128200E-01, 0.20961400E-02, -.79235200E+00, 0.18806600E+00, -.12481400E+01, 0.29761900E+00, 0.23979500E+00, -.14259800E+00, 0.56609400E+00, 0.11691100E+00, 0.35597800E-01, -.14329000E+01, -.12806500E-01, -.39346700E-02, 0.73606200E-02, 0.25466700E-02, -.42954000E+00, 0.10101300E+01, 0.16618800E+00, -.12798400E+01, -.10527400E+01, -.24475800E+00, -.19608700E+00, 0.59023300E-01, -.31922900E+00, -.78030700E-02, -.94262400E+00, 0.55029800E-02, -.19967600E-01, -.29126400E+00, 0.12654500E+00, -.59605800E-01, 0.48018100E-01, -.63469000E+00, 0.20124100E+00, -.21893300E+00, -.20955200E+01, -.91712500E+00, 0.76371300E-02, -.22036800E+00, -.54126700E+00, -.39174700E+00, 0.41667900E-01, 0.81793600E+00, 0.85069300E-01, 0.11641100E-01, 0.12627300E+00, -.29317900E+00, 0.23813000E+00, 0.38280600E+00, 0.43628200E-01, -.26883200E+00, 0.67404800E+00, -.69853200E+00, 0.29417000E-01, 0.13217700E+00, -.14704000E-01, -.29454900E+00, -.24733900E+00, 0.38915500E-01, 0.18869500E+00, 0.94296700E-02, -.42941200E+00, -.75530600E+00, 0.40686400E+00, -.73004700E-01, -.69427000E+00, 0.10857000E-01, 0.72558300E+00, 0.52845100E-01, 0.68601900E+00, -.22559700E+00, -.38642900E+00, 0.51898600E+00, -.22050400E+00, 0.27174000E-01, -.71801000E-01, 0.36846900E+00, -.64343200E-02, 0.86203800E-02, 0.18154500E+00, 0.10525400E+00, -.70624000E+00, 0.12391900E+01, 0.81215200E-02, 0.12835900E+00, 0.15861600E+00, -.16656100E+00, -.71684500E+00, 0.52758000E-01, -.29759000E+00, 0.21431700E+00, -.11091200E+00, 0.16136300E+00, 0.33718600E+00, 0.92304400E-01, -.18602900E+00, -.15823000E+00, 0.29180100E-01, 0.17983100E+00, -.18882000E-01, 0.51439800E+00, -.97835400E-01, -.44036600E+00, 0.25169200E-01, -.40494200E+00, -.52251100E+00, 0.39849600E-01, 0.55722000E+00, 0.83146000E-02, 0.27480100E+00, 0.20531400E+00, 0.32664300E+00, 0.45366200E+00, -.17976300E+01, 0.78989300E-01, -.67298500E-01, -.23038400E+00, 0.28279300E+00, 0.52624400E-01, 0.15470000E+00, -.19403600E+00, -.41457200E-02, 0.83830700E-01, 0.10072900E+00, 0.38352200E+00, -.47044700E-01, -.22573400E+00, 0.12153500E+00, 0.14346600E+00, 0.12823000E+00, -.36485700E-01, -.13539100E+00, 0.31671800E-01, -.14763000E+00, -.13338000E+00, 0.22678600E+00, -.10508200E+00, 0.25279800E+00, -.48284900E-01, -.16081000E+00, -.23681000E-03, 0.23862300E+00, 0.42581700E-01, 0.16333100E+00, 0.11632100E+01, -.69716400E+00, 0.10516200E+01, 0.93262600E-01, 0.37978500E+00, 0.22563000E+00, -.48356600E+00, -.10315000E+00, 0.66704100E-01, -.63852200E-01, -.59536900E-01, -.49978600E-01, 0.49181400E-02, -.21092300E+00, 0.12020400E+00, -.17499700E+00, 0.61855600E+00, -.26003800E-01, -.56502100E+00, 0.14670700E+01, -.17315300E+00, 0.21260600E+00, 0.11752500E+00, 0.68874500E+00, 0.10636800E+01, 0.29172400E+00, 0.29503000E+01, 0.11472300E+01, 0.14945500E+01, -.95529300E+00, 0.77236800E+00, 0.15172300E-01, 0.17861000E-01, 0.12142400E+01, 0.25632700E+01, -.30118500E+00, -.72141200E-01, 0.86060000E-01, 0.48493200E+00, -.81522200E+00, -.13802800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20078600E+00, 0.53463500E+00, -.40022000E-01, 0.39932400E+00, 0.53273000E-01, -.17708600E+00, 0.49356300E-01, 0.44847700E+00, 0.44795500E-01, 0.11230900E+00, -.29532800E-01, -.12321200E+00, -.90666200E-01, 0.79565300E-02, 0.16371300E+00, -.33130000E+00, -.56308000E+00, 0.50889500E-01, 0.39762400E-01, 0.47485800E-01, -.17295300E+00, 0.17349000E-01, -.51012200E-01, -.80759400E-01, -.49281900E-01, 0.48393200E-02, -.14263600E+00, 0.21052500E-01, -.10589200E+00, -.75271500E-01, -.73860100E-01, -.13341500E+00, 0.45010900E-01, -.36175700E-01, -.26574400E-01, -.31368200E-02, 0.36556000E-03, 0.72055000E-01, -.56443500E-01, 0.11962200E-01, 0.30790500E+00, 0.51209600E-01, 0.44833900E+00, 0.15510000E+00, 0.52615900E-01, 0.52798300E-01, 0.41894200E-01, -.87168000E-02, 0.17059100E+00, -.45586100E-01, 0.67309200E+00, -.63435700E-02, -.11676600E+00, 0.55581700E-01, -.17518700E+00, -.37228000E+00, -.81849200E-01, 0.26867200E-01, 0.33829100E-01, 0.12467000E+00, 0.59707200E-03, -.41225100E-01, -.54168800E-01, 0.32538300E-02, -.15820400E-01, 0.14043000E+00, -.14482900E+00, 0.64398200E-01, 0.50818100E-01, -.36302700E-03, 0.38240700E-01, 0.20138900E-01, -.28595800E+00, 0.27082100E+00, -.11028300E+00, -.99244700E-02, 0.64127000E-02, -.38323500E-01, 0.28480000E-01, -.53945200E-02, -.10930500E-03, 0.56615500E-01, -.54964000E-02, 0.12333200E+00, 0.33224800E-01, 0.11140500E+00, 0.25797400E-01, 0.13928800E+00, -.68299500E-01, -.23424500E-02, 0.28398500E+00, 0.28974400E-02, 0.28495900E-01, 0.12435100E-01, 0.17529800E-01, -.65092300E-01, -.48556700E-01, 0.14467400E-01, 0.43971400E-01, 0.16317200E+00, 0.17092800E+00, -.44628700E-01, -.75151100E-02, -.38089600E-03, -.72438100E-01, 0.60518900E-01, -.39647300E-01, 0.11664400E-02, -.49530300E-02, -.21147500E-01, -.24592600E-01, 0.23266000E-01, 0.37769400E-01, -.11759100E-01, -.15641700E-01, 0.70120700E+00, 0.39059100E-01, -.89184400E-02, 0.13948500E-01, 0.85347700E-01, 0.35156500E-01, 0.13044600E-01, -.20284800E+00, -.47287400E-01, 0.18720200E-02, 0.44604700E-01, -.27657800E-01, 0.20022400E-02, 0.37085700E-01, -.91759900E-01, 0.91342400E-02, -.99566200E-01, -.65606700E-01, -.47778600E-02, 0.20278100E-01, -.69418500E-04, 0.92658600E-01, 0.37612100E-01, -.16285600E-01, 0.37429800E-02, -.10134700E-01, 0.47943500E-01, -.93679500E-03, -.10299300E-01, 0.11394100E-01, 0.55406100E-01, -.30959100E-02, -.18806000E-01, -.73838900E-01, 0.15207800E+00, -.13393600E-02, 0.13606200E+00, 0.14163500E+00, 0.22984400E-01, 0.19751600E-01, 0.24959200E-02, -.15180800E-01, -.23686700E-02, 0.19193700E-01, 0.44248200E-01, -.34383300E-02, 0.26344300E-01, 0.10205700E+00, -.13086300E-01, 0.46685800E-02, -.95391600E-02, -.59081000E-01, 0.63421900E-01, 0.16850200E-01, 0.21241800E-01, -.70170700E-01, 0.16749600E-01, 0.41196600E-02, -.19654600E-01, 0.26356300E-01, 0.10845900E-01, -.15278000E-01, 0.53308100E-02, -.53970400E-02, -.23078000E-02, -.46135700E-01, 0.49472300E-03, -.62609800E-01, -.34637600E-02, -.38965900E+00, -.29923400E+00, -.72298100E-02, -.63673100E-01, 0.12686300E-01, -.56751900E-02, 0.25979700E-02, 0.58747800E-01, 0.14826600E+00, -.84347500E+00, -.10847300E-01, 0.12628800E-01, 0.28981300E-01, 0.26672600E+00, 0.31467900E-01, 0.25063100E-01, -.16088300E-01, 0.27381200E-02, -.16276200E-01, -.44144600E-01, 0.23752300E-01, -.77829600E-02, 0.70850900E-02, 0.52624300E-02, -.22385100E-02, -.30246400E-01, 0.13302700E-01, 0.20669700E-02, -.66520800E-02, -.25498200E-01, -.16281700E-01, 0.16168400E-01, 0.14203000E-01, -.12426800E-01, -.94921000E-02, 0.39597800E-02, -.98647100E-03, -.35853700E-02, -.63096900E-01, -.14533600E-01, 0.15290800E-02, 0.32183300E-01, -.17000800E+00, -.36531100E-02, -.31412200E-01, -.16974200E-01, 0.51834300E-01, 0.10510100E-01, 0.10113400E-01, -.41758900E-01, 0.22021400E-01, 0.75083400E-01, 0.29632200E-02, 0.12390400E+00, -.15399600E-01, 0.70671800E-01, -.67391600E-01, 0.33386600E-02, 0.13303100E+00, -.35578500E+00, 0.12713700E+00, 0.32815200E-01, 0.34819500E-01, -.20889300E+00, -.18768100E+00, 0.35485800E-02, -.23178100E-01, -.18996500E+00, -.64800400E-01, 0.14683500E-01, -.24362600E-01, -.26067200E-01, 0.15008600E-01, -.95263300E-01, -.13512200E+01, -.26199900E-01, 0.25921100E-01, -.80482800E-02, 0.11871700E-02, 0.73452000E-01, 0.18070400E-03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13038500E+00, 0.19651500E+00, -.28859200E+00, 0.58024800E+00, -.90739300E-01, -.39480600E+00, 0.74867300E-02, 0.38600300E+00, 0.15830200E+01, -.99433400E-01, 0.18614500E-01, 0.90308100E-01, 0.67375100E-01, -.18622800E-01, -.13289800E+00, -.49298900E-01, -.12857100E+00, -.46505700E+00, -.45486900E-01, 0.20322200E-01, 0.22073100E+00, -.10778800E+00, -.80188200E+00, -.14750300E+00, 0.16604500E+00, -.82978800E-02, 0.44430400E+00, 0.53608900E-02, 0.13071500E-01, 0.23064200E-01, -.86590800E-01, -.87750800E-01, 0.81298200E-02, 0.41527400E-01, 0.35610100E-01, 0.19540400E-01, -.65672800E-03, 0.31458100E-01, 0.47420000E-01, -.88526000E-01, -.14421000E+00, 0.41169000E-01, 0.10057300E-01, 0.85771300E-01, 0.39668100E-01, 0.29692300E-01, 0.85857700E-01, 0.19311500E-01, 0.10583200E+00, -.22324800E-01, -.74348400E+00, -.19491700E+00, 0.29882800E+00, 0.10360600E+00, -.57848400E-01, 0.72349900E+00, 0.19539800E+00, -.69582500E-01, 0.55555200E-01, -.50227400E+00, 0.92059100E-01, 0.77649100E-02, 0.19086300E+00, 0.83533800E-02, 0.65039600E-01, -.11002200E+00, 0.26975800E+00, -.15524900E-01, -.16163600E-01, -.30398200E-03, 0.40598500E-01, 0.19787100E+00, 0.67138000E+00, -.59527900E-01, 0.27342700E+00, 0.83051600E-01, 0.35622700E-01, 0.56175800E-01, -.51914900E-01, 0.55871100E-03, 0.36279700E-03, -.20052100E+00, -.36122500E-01, 0.47201200E-01, 0.33780300E+00, 0.54867100E-02, -.12012300E-01, 0.38580600E+00, -.15325700E+00, 0.23910800E-01, -.26645100E+00, 0.19743600E-02, -.13064800E-01, -.11760700E+00, -.12296600E-01, 0.13228000E+00, 0.75144500E-01, 0.63302300E-02, -.61129200E-01, 0.24152100E+00, 0.39620600E-01, 0.74712300E-01, -.40629300E-02, 0.13602600E+00, -.83085300E-01, -.13135100E+00, -.41501700E-01, -.24420100E-01, -.26315300E-02, -.63732100E-02, -.17835400E-01, -.25924500E-01, -.31095900E-01, 0.95903700E-02, 0.50318700E-01, 0.52552900E+00, 0.71713500E-01, 0.74594500E-02, 0.19278600E-02, -.19905000E+00, 0.27709200E-01, -.28580800E-01, 0.24482900E+00, 0.69512600E-01, 0.30950400E-02, -.54354600E-01, 0.11933300E+00, -.63789100E-03, -.19226800E-01, 0.11167900E-01, 0.76012600E-01, 0.73710600E-01, 0.29946100E+00, -.80080900E-02, 0.45479700E-01, 0.17880100E-02, -.13011300E-01, 0.29615600E-02, 0.54189900E-01, -.41260100E-02, -.11924900E-01, -.41932500E-01, 0.64724700E-01, -.33865100E-01, -.10985400E-01, -.45994300E-02, -.31002300E-02, -.25966000E-01, -.12409400E+00, 0.26480400E+00, -.99409800E-04, -.12606900E+00, 0.90393500E-01, 0.29081800E-01, -.97001600E-02, -.15030000E-01, 0.25587000E-01, 0.38416200E-03, -.10563400E-01, -.14726800E-01, -.16144300E-03, 0.15869200E+00, -.21268900E-01, 0.34915400E-01, 0.21120000E-01, -.10635500E-01, 0.25636300E-02, -.15846600E-01, 0.15886700E-03, -.49156000E-01, 0.79845600E-01, -.50128400E-01, -.38809700E-01, -.14292800E+00, -.76178900E-01, -.34773300E-01, 0.60448700E-01, 0.76646700E-02, -.39680600E-01, 0.73555800E-03, -.66665400E-01, -.24282100E-02, -.15344400E+00, -.23402800E-02, 0.65675400E-01, 0.33553700E-01, 0.34099500E-02, 0.89899900E-04, 0.22973100E-02, -.15036100E-01, 0.53534800E-02, 0.29119500E-01, 0.18712700E+00, -.67689500E-01, -.26322800E-01, -.91442300E-02, -.11363700E-01, -.10958600E+00, -.10580000E-01, 0.10247400E-01, -.10625600E-01, -.10620400E-03, -.22793200E-01, 0.12219200E-01, -.13248200E-01, -.43483500E-03, -.37583700E-01, 0.41932000E-02, 0.77241700E-02, 0.30839300E-01, -.10765500E-01, 0.72966100E-02, 0.60474700E-02, -.45536100E-02, 0.21957800E-01, 0.94471500E-03, -.26048700E-02, 0.24293400E-02, -.58710500E-02, 0.35754700E-02, 0.65631700E-02, -.24043700E-01, 0.16448200E-01, -.27709900E-02, -.53553500E-01, -.15467800E-01, 0.14958600E-01, 0.89097700E-02, 0.62445700E-02, -.64375700E-02, -.40225600E-01, -.60502600E-02, -.11920000E-01, -.55822100E-02, 0.17079000E-01, 0.45271800E-01, 0.38980200E-02, -.46444100E-02, 0.11770200E-02, -.96727000E-02, 0.63560700E-01, -.20668900E-02, 0.10141100E-02, 0.24215600E-01, -.10297600E+00, 0.73409100E-01, -.30242100E-01, -.42412000E-02, 0.99195300E-01, 0.88888700E-01, 0.99171200E-02, -.65201700E+00, 0.13265700E+00, -.82464200E-01, 0.95607700E-01, -.11230400E-01, 0.77279700E-02, 0.64719400E-01, -.70121900E+00, -.10404100E+00, 0.25592400E-01, 0.17088000E-01, 0.11891700E+00, -.43230100E-01, 0.68233000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15501800E+01, -.15180800E+01, -.23574700E+00, -.12281500E+01, -.15822700E-01, 0.79086100E+00, -.37020600E+00, -.15824800E+01, -.93112100E+00, -.61029800E-01, 0.71956300E-01, -.26604100E-01, -.79865800E-02, 0.15925900E+00, -.67522100E+00, 0.32527700E+00, 0.13807500E+00, -.20505300E+01, -.43499800E+00, -.64594400E+00, 0.27215800E+00, -.27138300E+00, 0.15633100E+01, -.44894800E-01, -.56314900E-01, -.72420800E-02, -.13288100E+00, -.52764200E-01, 0.45254100E-01, 0.17497100E+00, -.82064600E-02, 0.23242200E+00, -.28842900E-01, -.75695100E-01, -.44896800E-01, -.25058400E-01, 0.66149100E-03, 0.77626000E-01, -.21290200E-01, 0.13908700E+00, 0.42663900E+00, -.17566000E+00, -.34289600E+00, -.46704800E+00, 0.48161500E-01, -.11606700E-01, 0.71793100E-02, 0.20980000E-01, -.32794500E+00, -.64121100E-01, 0.11164700E+01, 0.20691900E+00, -.24564700E+00, 0.13926700E+00, -.32090900E+00, -.85082000E+00, -.44180000E+00, 0.36799100E-02, -.18661700E+00, 0.37049600E+00, -.43330200E+00, 0.68220600E-01, -.20865900E+00, 0.19890800E+00, 0.23298200E+00, -.84162700E-01, 0.27392900E+00, -.15148400E+00, -.62133500E-01, 0.40881300E-03, -.11113700E+00, 0.18605800E+00, -.63249700E+00, 0.13839300E+00, -.21302800E+00, 0.40916600E-01, -.16919600E-01, -.26214700E+00, 0.38515400E-02, 0.26746300E-01, -.69841000E-04, -.25813000E+00, 0.60164500E-01, 0.16696700E+00, -.16571400E+00, 0.40939600E-01, 0.26045600E-01, 0.26175200E+00, 0.73490900E-01, -.64353900E-01, 0.73969000E+00, -.27962500E-02, -.39024200E-01, 0.18106700E+00, 0.17565400E-01, -.29463100E+00, -.15868400E+00, 0.24554800E-01, 0.73164000E-01, -.45593700E+00, 0.26870500E+00, -.16506800E+00, -.13029000E-01, 0.58860600E-01, -.10426000E+00, 0.22436000E+00, 0.93478500E-02, 0.56116300E-01, -.56658400E-02, -.81991000E-01, 0.12565900E-01, 0.20981500E-01, 0.23508800E+00, -.74210600E-01, 0.30815800E-02, -.45374300E+00, 0.51187900E-01, -.10844500E-01, 0.85289400E-01, -.16150300E+00, -.24467600E-01, 0.12209600E-01, -.20262200E+00, 0.27831200E-01, -.13761600E-01, -.23350300E+00, -.71886300E-01, -.29627700E-01, -.16835100E+00, -.73315000E-01, -.83251800E-01, -.66704100E-01, -.16950200E+00, 0.13595100E-01, -.95737100E-01, -.99405600E-02, -.11836900E+00, 0.29847800E-01, -.80522300E-01, -.41366700E-01, 0.92963800E-01, 0.15799800E+00, 0.11512800E+00, -.35484000E-01, 0.11867000E-01, -.37200600E-01, 0.38968200E-02, -.11515100E+00, 0.30834600E+00, -.59537300E+00, 0.30965500E-01, -.95908100E-01, -.34060300E+00, -.11087900E-01, -.48818100E-01, -.14770800E-01, -.31813700E-01, 0.38884600E-02, 0.17967800E-01, -.52955700E-01, -.33072800E-01, 0.54606400E-01, -.15729700E+00, -.32917800E-01, -.27671600E-01, 0.84814400E-02, 0.50033100E-01, -.42119500E-01, -.15917400E-01, 0.78026100E-01, -.84222400E-01, 0.40307900E-01, 0.15167900E-01, -.24937700E-01, 0.28829300E-01, 0.73206100E-01, -.81406700E-02, -.24372300E-01, -.15596300E-01, 0.37166800E-02, -.14365100E+00, 0.26737500E-01, -.45428300E+00, 0.79918100E-01, -.49968600E+00, -.31398400E-01, 0.14821300E-01, -.32910100E+00, -.41795800E-01, 0.11771800E+00, -.15025800E-02, -.10998900E+00, 0.20642600E+00, 0.44734300E-01, -.31960000E-01, 0.78703600E-02, 0.57808100E-02, 0.24825100E+00, 0.47447700E-02, -.24680200E-01, -.12813700E-01, -.78156900E-03, -.45408500E-01, -.80427500E-01, -.14911500E-01, -.70853700E-03, 0.93414600E-01, 0.54023100E-01, -.10014300E-01, -.91483300E-01, -.17492800E-02, 0.53954300E-01, -.17674400E-01, 0.36500600E-01, -.23511800E-01, 0.55191300E-02, -.16838700E-01, -.10393200E-01, -.84963700E-02, -.11701100E-01, -.87643700E-02, 0.47583800E-02, 0.86300100E-02, -.18958700E-01, -.45746500E-02, -.13969300E+00, -.25697200E+00, -.11364000E-01, -.22046600E-01, -.27357100E-01, 0.70429100E-01, 0.24212900E-01, -.70318000E-02, -.42529800E-01, 0.50867700E-02, -.77551800E-01, 0.98940600E-03, -.71100500E-01, 0.29657600E-02, -.21936900E-01, 0.10483300E+00, -.11590900E-01, 0.55567500E-02, 0.44934300E+00, -.26940700E+00, -.39008500E+00, -.20480800E-01, 0.35424800E-01, -.43375500E-01, -.80801800E-01, -.73883000E-01, 0.11062800E+01, -.42325600E-01, 0.14124300E+01, -.33522600E+00, 0.41464700E-01, -.21937700E-01, 0.48165400E-01, 0.14211700E+01, 0.35688400E+00, -.24892800E+00, -.23706600E-01, -.50107700E+00, 0.14085300E+00, -.12508900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.84556000E+01, -.53547700E+01, -.84469400E+00, 0.12123200E+01, 0.46969900E+00, -.92672400E+01, 0.22699100E+01, 0.60445400E+01, 0.14910900E+02, -.60333400E+01, -.23351500E+00, 0.22021100E+01, -.98044800E+00, 0.22129600E+00, 0.57373500E+01, 0.60531300E+00, 0.79405900E+00, 0.80653300E+01, 0.21681500E+01, 0.40050400E+01, 0.50218700E+00, -.53506200E+00, 0.42806600E+01, 0.59421200E+00, -.25891000E+01, -.60789600E-02, -.91376200E+00, -.45363400E+00, 0.10159400E+01, 0.29597800E-01, 0.32460300E+01, -.55173600E-01, 0.48391200E-01, 0.64943900E+00, 0.22612500E+01, -.56350800E+00, -.23687200E-01, -.13283600E+01, -.49636400E+00, 0.28024400E+01, -.42972000E+01, 0.87865500E-01, -.81036100E+00, 0.73114700E+00, -.13052100E+01, -.91046500E+00, 0.33775100E+01, -.48946600E+00, -.21546300E+01, 0.24712600E+01, -.12428300E+02, 0.15466400E+01, 0.28970700E+01, -.25140000E+01, 0.46613400E+01, 0.10111700E+02, 0.62289300E+01, -.26538300E+00, -.23392400E+01, -.45098800E+00, -.72264600E+00, -.65947800E+00, 0.33224200E+01, -.12602400E+01, -.81930600E+01, 0.21746600E+01, 0.17014700E+02, 0.11300300E+01, -.41765000E+00, -.62739200E-02, 0.15024600E+01, -.37587900E+01, 0.80714100E+01, 0.48852600E+01, 0.33786700E+01, -.21209500E+01, -.12848600E+01, 0.79761700E+00, -.18016200E+00, -.54258300E-01, 0.52285200E-02, -.16513600E+01, 0.10846400E+01, -.20674200E+01, -.12522200E+01, -.21487600E+01, -.73442700E+00, -.69289600E+01, 0.99322300E+00, -.19670400E+00, -.12557600E+02, -.26646600E-01, 0.33643300E+00, 0.72692500E+00, -.94151500E+00, 0.47618600E-01, 0.54367600E+00, -.64800000E+00, -.28057500E+01, -.36057200E+01, -.27983400E+01, -.14624900E-01, 0.19769400E+00, -.27057600E+00, -.14142500E+01, -.19756100E+01, 0.29475400E+00, 0.80377000E+00, -.24424400E+00, -.34668700E+00, 0.14370100E+00, 0.27510000E+00, -.21343400E+00, 0.66716500E-01, 0.28740100E+00, -.40761300E+01, -.76791900E+00, 0.76149600E-01, -.22467000E+00, -.18791500E+01, -.92948300E+00, 0.74229400E-01, 0.32000500E+01, 0.72344100E+00, -.24869300E-01, 0.33724100E+00, 0.11635300E+01, 0.43986700E+00, 0.16737200E+01, 0.12624900E+01, 0.60878400E+00, 0.13778500E+01, 0.61782200E+01, 0.24957600E+00, 0.15757100E+00, -.90422700E-01, -.96740800E+00, -.10395900E+01, 0.21672200E+00, -.11127600E-01, -.11686200E+01, 0.15272800E+01, -.33455200E+01, 0.51381300E+00, -.41999400E-01, 0.32042000E+00, 0.22058300E-01, 0.18232900E+00, 0.81868800E+00, -.34116900E+01, 0.20634900E-01, -.99285700E+00, -.33745000E+01, -.30458200E+00, -.33456600E+00, -.15223000E+00, 0.15336100E+00, 0.51730700E-02, -.22037300E+00, 0.65522500E-02, 0.15758400E+00, 0.14787100E+00, -.80377400E+00, 0.50004400E-01, 0.52252300E-02, 0.18527400E+00, -.45939100E+00, 0.12333400E+01, 0.15414800E+00, -.15636000E+00, 0.96973800E+00, 0.36160600E+00, 0.44052400E+00, 0.16817900E+00, -.43402800E+00, 0.64007900E-01, 0.53343500E+00, 0.35458600E+00, -.10056700E+01, -.47946800E-01, -.35294000E+01, -.27417600E+00, 0.15154000E+00, 0.11625000E+00, 0.47002300E+01, 0.13519800E+01, 0.42037700E+00, 0.28180700E+01, -.23747800E-01, -.65157000E+00, -.75708400E+00, 0.39510900E+01, 0.36178500E+01, 0.60625400E+01, 0.22556900E+00, -.17399500E+00, -.68357600E+00, -.23629200E+01, -.10896900E+00, 0.16987000E+00, -.24281300E+00, -.20122300E-04, 0.45147600E+00, -.10062900E+01, 0.20285000E+01, -.21414200E+00, -.75867100E+00, -.38525200E+00, 0.21784900E-01, 0.61712400E+00, 0.13766800E+00, 0.28903300E+00, 0.80323400E-01, -.48292900E+00, 0.60100900E+00, 0.21106700E+00, 0.67614400E+00, -.95612600E+00, -.21776100E+00, 0.33405900E+00, -.51226200E-02, -.44401600E+00, -.26305200E+00, -.16674900E+00, -.27132300E+01, 0.19939600E+01, -.24933900E+01, -.15877200E+00, -.14902600E+01, -.22414100E+00, -.66443600E+00, 0.14304700E+00, -.67227900E+00, -.48505400E-01, 0.64083900E+00, 0.34749700E+01, 0.41486700E+00, 0.14645300E+01, -.11170000E+01, -.25572100E+00, -.68047400E+00, -.61904400E-01, -.41653400E+00, -.29472700E+01, 0.11061700E+01, 0.23568400E+01, -.39303900E+00, 0.93211000E+00, 0.16797900E+01, -.34132600E+00, 0.34943700E+00, -.10647800E+02, -.99811400E+00, -.21763100E+01, 0.76157400E+01, 0.28285200E+00, -.26409900E+00, -.79588700E+00, -.11570700E+02, -.13487100E+01, 0.75554000E+00, 0.41345400E+00, 0.41782500E+00, -.48167400E+00, 0.28937500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40355300E-02, -.10609900E+01, -.74094800E-01, 0.26458600E+00, -.29824700E+00, 0.11689800E+00, 0.83841100E-02, -.21858600E-01, 0.17680000E+01, -.12619700E+00, 0.20628900E-01, 0.12769400E+00, -.15813500E+00, -.64360600E-01, 0.75072100E+00, 0.28131200E-01, -.12546500E+00, 0.17336000E+00, 0.42860800E-01, 0.50425700E-01, -.56621200E-01, -.19279000E-01, -.23208800E-01, -.17313800E+00, 0.35575300E-01, -.11528400E-01, 0.29041100E-01, 0.38633000E-02, -.14894100E-01, 0.50114400E-02, 0.60269500E-01, -.14759700E-01, -.16125500E-01, 0.65456700E-02, 0.11305900E+00, -.17316200E-01, 0.24221100E-02, -.27365300E-01, -.11578000E+00, 0.16975500E+00, -.45641800E-01, -.20578000E-01, 0.17242700E+00, -.46149000E-01, -.58521800E-01, 0.43115900E-01, 0.13233100E-01, 0.18071100E-02, 0.52045600E-01, -.11593600E-01, 0.19359600E+00, 0.14991200E-01, 0.85018200E-01, 0.32887000E-02, -.49629100E-01, -.86339800E-01, -.17531300E+00, -.56059900E-02, 0.71548200E-02, -.34995100E+00, 0.70966500E-01, 0.14568200E-01, 0.53863300E-01, 0.36823500E-01, 0.45096600E-01, 0.36897800E-01, -.62573800E+00, -.12693900E-01, 0.12356500E-01, 0.56243700E-03, -.24815300E-01, -.87882000E-01, 0.21045300E+00, -.12853900E+00, 0.14250200E+00, 0.92697600E-02, -.11677600E+00, -.90164000E-01, 0.15292000E-01, 0.10472400E-01, 0.56233800E-03, -.45215600E+00, 0.37678700E-01, -.44227900E-01, 0.16656200E+00, 0.12573200E-01, -.13682600E-01, 0.25816400E+00, -.11177900E+00, -.15606500E-02, 0.17339200E+00, -.24023400E-02, -.52147300E-01, -.60772500E-01, 0.10534300E-03, 0.22688400E-01, 0.69218500E-02, 0.30657700E-01, 0.12090100E+00, 0.63190000E-01, 0.50626800E-01, 0.42188000E-01, -.88125800E-02, 0.15100100E+00, -.43980400E-01, -.26461500E-01, 0.43288400E-02, 0.58507300E-02, -.73854000E-02, -.15878600E-01, -.86184100E-02, -.12103100E-01, -.55557200E-01, 0.17604200E-01, 0.37895900E-01, 0.20086600E+00, -.43622600E-01, 0.34306500E-01, -.98993600E-02, -.71589500E-01, 0.44976200E-01, 0.14220700E-01, -.55710100E-01, -.36898300E-01, -.11640700E-01, 0.12152600E+00, 0.11046900E+00, -.23627100E-01, -.42528700E-01, 0.60689400E-01, 0.46537400E-01, 0.56195600E-01, 0.32344000E+00, -.26216600E-01, -.74541300E-01, 0.90085100E-02, 0.47147300E-01, -.47514500E-01, -.29601000E-01, -.97139300E-04, 0.10037500E+00, -.10879700E+00, 0.27566100E+00, -.55712500E-01, 0.20553800E-01, -.13406100E+00, 0.46932700E-02, 0.10836300E+00, -.66656600E-01, 0.22821700E+00, -.21243500E-01, 0.40579000E-01, 0.12870800E+00, 0.14044800E-01, 0.24120400E-01, 0.18250100E-01, 0.53606700E-01, 0.21801000E-02, 0.22186000E-01, -.41022400E-03, 0.40930300E-02, 0.45965600E-01, -.31773900E-01, 0.22615000E-01, -.57980200E-02, 0.22565400E-01, -.61718700E-02, 0.36309400E-01, 0.24575200E-02, -.52978100E-03, 0.12982000E-01, -.77925800E-02, 0.47794400E-02, -.69585900E-01, -.16362200E-02, 0.49883500E-02, -.52182600E-02, 0.39033900E-02, 0.98869500E-02, -.18164800E-02, 0.83461500E-01, -.62852100E-02, 0.13092000E+00, -.91225700E-02, 0.17939500E-01, 0.31875800E-01, 0.11849400E-02, 0.72122100E-01, -.72167900E-02, 0.23903000E-01, 0.29008200E-01, -.16123000E-01, -.10089200E+00, -.19934700E-01, 0.67449400E-02, 0.16995500E-02, 0.72269100E-02, 0.37555800E-01, 0.35537700E-02, 0.55024200E-02, 0.62338500E-02, 0.12958700E-02, -.12160900E-01, -.13559600E-01, -.90644200E-02, -.52717500E-02, -.27508600E-02, 0.41109200E-02, -.11888200E-01, -.97587800E-02, 0.26440500E-02, -.34117200E-03, -.19717900E-02, 0.21373300E-02, 0.65046100E-02, -.54936400E-03, -.95584900E-02, 0.13448900E-01, 0.27271900E-02, -.56391500E-02, 0.55408200E-02, -.11653100E-01, 0.87004600E-02, -.85198800E-03, 0.10046500E-02, -.20476100E-01, -.48124500E-01, 0.41196700E-02, 0.13761100E-01, 0.40396800E-02, -.49600100E-02, -.13702800E-03, 0.24018700E-03, 0.77540900E-03, -.21434400E-02, -.17067900E-01, -.23116100E-02, -.23355200E-01, 0.11574700E-01, 0.61230600E-03, 0.21780000E-01, -.11005800E-02, -.11342500E-01, 0.16969600E-01, -.14800000E-01, -.17264900E-01, 0.11527700E+00, -.68960000E+00, 0.66535400E-01, -.32579900E-03, -.34584000E-02, 0.94780900E-01, -.26424400E-01, 0.55928900E-01, -.86594000E-02, -.23649900E+00, 0.15213000E+00, 0.16763800E-02, -.69830700E-01, 0.16145900E-01, -.23066100E-01, -.25932200E-01, 0.27315600E-02, 0.41732200E-02, -.11107700E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34642200E-01, 0.43103500E+00, -.12364500E+00, -.52830000E+00, 0.29930700E+00, -.21990400E+00, -.44012500E-01, -.36832100E+00, -.27448500E+01, 0.20586100E+00, 0.81829400E-01, -.68541900E-02, 0.13145300E+00, 0.13761600E+00, -.11257200E+01, 0.45622400E-01, -.38346500E-01, -.50934000E+00, -.10752500E+00, -.13558300E+00, 0.15615100E+00, -.83901000E-01, 0.18181900E+00, -.10860400E+00, -.86042000E-01, -.22106400E-02, -.77717100E-02, 0.10922000E-01, -.31033600E-01, -.20617600E-01, 0.47642700E-02, 0.31811400E-01, 0.51251700E-02, -.35849700E-01, 0.97080400E-02, 0.26010100E-01, -.19363000E-03, 0.35513800E-01, -.68359200E-01, 0.15683800E+00, -.17675200E+00, -.41930900E-01, -.85496700E-01, -.66092000E-01, -.64191200E-01, 0.19776500E-01, 0.73470700E-02, -.16208400E-01, -.31287800E-01, 0.47739300E-01, -.15006600E+00, -.34948300E-01, 0.24014900E-01, -.78147200E-02, 0.66797700E-01, 0.13780600E+00, 0.68866900E-01, 0.34346500E-02, -.14462400E-01, 0.78893000E-01, -.13524000E-01, 0.11868000E-01, 0.83826800E-02, -.12827700E-01, -.22642000E-01, 0.73386000E-01, 0.68583700E-01, -.64407600E-01, -.19903700E-01, -.19396400E-03, 0.27953800E-01, 0.28397600E-01, 0.95493000E-01, -.40257300E-01, 0.27215400E-02, 0.26331900E-01, 0.90646300E-02, 0.25558100E-01, -.13815900E-01, -.10453500E-02, -.74814400E-04, 0.54146000E-01, -.25889700E-01, 0.36828300E-01, -.21475100E+00, -.16943800E-01, 0.23093700E-02, -.74741100E-01, 0.17017400E-01, 0.23290100E-01, -.14682700E+00, 0.23267600E-02, 0.10909200E-01, 0.17579800E-01, 0.20302200E-01, 0.51833800E-02, -.45465200E-01, -.43616300E-02, 0.85821700E-02, -.28676500E-01, -.10589000E+00, 0.14241200E-02, 0.21954300E-03, -.81901500E-01, -.54100700E-01, 0.73652500E-02, -.49626900E-02, -.21197300E-01, 0.11779200E-01, 0.55697300E-02, 0.50649600E-02, 0.88134000E-02, 0.45140600E-01, -.14225300E-01, -.14057500E-01, 0.12348200E+00, 0.86677100E-01, -.11545400E-01, 0.20962600E-01, -.43173500E-02, -.94632800E-02, -.22615300E-01, 0.15450000E+00, 0.41714700E-01, 0.58940100E-03, -.64854000E-01, -.69120000E-01, 0.22701500E-01, -.22338200E-02, -.54376200E-01, 0.65413900E-02, 0.22048300E-01, -.14369900E+00, -.47793500E-02, 0.42306800E-02, -.35563100E-02, 0.10543900E+00, 0.87841900E-01, 0.67450300E-02, 0.13158400E-01, -.46014900E-01, -.16777400E-01, -.23040000E-02, -.10179200E-01, -.98196500E-02, -.55153000E-01, -.48388500E-02, 0.14266200E-01, 0.52135400E-01, -.76039900E-01, -.32615500E-02, -.32071000E-01, -.56647500E-01, -.16632300E-01, 0.10328400E-01, -.10037200E-02, 0.14950000E-01, -.84389400E-03, 0.63054100E-02, 0.26103900E-01, -.42807900E-02, 0.35407700E-01, -.81030600E-01, -.13930400E-01, -.19475700E-01, 0.44654200E-01, -.71051300E-02, 0.21010300E-01, 0.11021000E-02, 0.27108500E-02, -.15364000E-01, 0.20037800E-01, 0.12967900E-01, -.15125100E-01, 0.12141400E-01, 0.14516200E-01, 0.91435000E-03, -.41987000E-02, 0.46077000E-03, -.28624700E-02, 0.36784900E-01, 0.19315400E-02, 0.19581900E-01, 0.48913600E-02, -.47418300E-01, -.20862100E-02, 0.84680900E-02, 0.51140700E-02, -.74515500E-03, -.35938100E-02, 0.52905400E-02, -.13741000E-01, -.12739400E-01, 0.29709000E-01, 0.49044000E-02, 0.61657200E-04, 0.26537300E-02, -.84405400E-02, -.34721300E-02, 0.47801500E-02, 0.42324700E-02, 0.18515000E-03, -.19215500E-02, -.87945200E-02, -.87448300E-02, 0.40289900E-04, -.57059000E-03, -.57639800E-02, -.37713200E-02, -.36783000E-02, 0.23202300E-02, 0.50328400E-03, -.86118400E-03, -.12451400E-02, 0.57822200E-02, 0.22389200E-02, -.11882600E-02, 0.45656800E-02, -.45706200E-03, -.22005200E-02, 0.89658000E-03, -.19739100E-02, 0.61246500E-02, 0.13251400E-02, -.64677700E-03, 0.36689000E-03, -.16314700E-01, 0.14193800E-03, -.71794300E-03, -.16283600E-02, -.43201000E-02, -.48121700E-03, -.24046900E-02, 0.20259700E-02, 0.30680100E-02, 0.13821700E-01, 0.18696200E-02, -.18144300E-01, 0.35241400E-02, -.42202400E-02, -.30511900E-02, 0.33562000E-03, -.56562300E-03, -.27479300E-01, 0.28738100E-01, 0.15971900E-01, 0.30715400E-01, -.57671100E+00, 0.48042400E-01, 0.47741800E-02, 0.37171400E-02, -.30079100E-01, 0.74726500E-04, 0.44549000E-02, 0.13218700E-02, 0.14821600E+00, 0.87961800E-01, -.23369200E-02, -.11692300E-01, -.89905600E-02, 0.21347200E-02, 0.18509100E-02, 0.31401100E-02, -.58125800E-03, 0.69644800E-03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39264600E+00, 0.65990400E+00, -.17272800E+00, 0.87253100E+00, -.54021700E-01, -.36310500E+00, 0.13716900E+00, 0.14677400E+00, 0.14789700E+00, 0.59961200E+00, -.31857800E-01, -.30457300E+00, -.20401300E+00, 0.34024600E-01, -.11339100E+00, -.56159600E+00, -.12474300E+01, -.73095900E+00, -.21175200E-01, 0.13874600E+00, 0.36709400E+00, 0.14382800E+00, -.15679000E+01, -.12185000E+00, 0.17804500E+00, -.66434300E-02, 0.27991500E+00, 0.97214200E-02, -.48229600E-01, 0.34696000E-01, -.17895900E+00, -.17605600E+00, 0.17153400E-01, 0.30861100E-01, 0.15313800E+00, 0.49933100E-01, -.15882000E-02, 0.46395700E-01, -.23212000E+00, 0.66465200E-01, -.22044100E+00, -.60404500E-01, -.25739900E+00, -.11106600E+00, 0.49330300E-01, 0.30241800E-01, 0.15740300E+00, 0.45382600E-02, -.43119500E-01, -.32129300E-01, -.70748400E+00, -.19342400E+00, 0.29869900E+00, -.97211000E-01, -.30251300E-01, 0.87440600E+00, 0.26901800E+00, 0.20929300E-02, 0.37662600E-01, 0.39808600E+00, -.10126700E+00, 0.13640400E-01, 0.74526600E-01, -.58182500E-01, -.23680100E-01, -.96299300E-01, 0.12308000E+00, -.24268100E-01, 0.20411200E-01, 0.27154200E-04, 0.45531600E-01, 0.17603900E-01, 0.64960300E+00, -.36614300E+00, 0.23690100E+00, 0.13837400E+00, -.38965400E-01, 0.16574100E+00, 0.26611500E-02, 0.27610300E-02, 0.16668400E-03, 0.28562100E-01, -.18275000E-01, -.12422400E+00, 0.15997000E+00, -.33236400E-01, -.11378000E-01, -.17722600E+00, -.77159700E-01, 0.44206100E-01, 0.35265800E+00, 0.20807500E-03, -.41925900E-01, -.15668200E+00, 0.28481000E-02, 0.11141300E+00, 0.21352000E-01, 0.41930900E-01, 0.80886100E-01, 0.48860800E-01, 0.69851400E-01, 0.15108500E-01, -.10528000E-02, 0.72722000E-01, 0.56017800E-01, -.20242800E+00, -.21439200E-01, 0.23414800E-02, -.50864300E-01, -.19413800E-01, -.28389500E-01, -.50954700E-01, 0.71875200E-02, -.23165800E-02, 0.91114100E-03, -.15095900E+00, -.14197400E+00, -.30633600E-02, -.13904200E-01, -.83265600E-01, -.27385500E-01, -.10361000E-01, 0.10629400E+00, 0.74439400E-02, -.75735600E-04, -.55206000E-01, -.26598900E-01, -.11260600E-01, -.15358500E+00, 0.70252000E-01, -.72850000E-02, -.33451700E-01, 0.12307100E-01, -.12222600E-02, -.73013600E-02, 0.11970000E-02, 0.33300900E-02, -.14007600E-01, 0.10690800E-01, 0.39949300E-02, -.18500800E-01, -.68268600E-01, 0.40491900E-01, 0.30347900E-01, 0.17515700E-02, -.49492700E-01, 0.40441200E-03, 0.99846800E-02, -.58180700E-01, 0.15780000E+00, -.16012300E-01, -.10018500E-01, 0.18924700E+00, 0.22733900E-02, -.20019300E-02, -.96792700E-02, 0.27274300E-01, 0.60368100E-03, 0.14512900E-01, 0.28679700E-02, -.83117300E-02, -.43831300E-01, 0.15500500E+00, -.56010900E-02, 0.16051600E-01, 0.13849000E-01, 0.70999900E-02, -.17028400E+00, -.20592500E-02, -.41934400E-01, -.19212800E-01, -.30680600E-01, -.41663500E-01, 0.72690500E-02, -.19879800E-01, -.32063700E-01, 0.32836900E-02, 0.10715400E-01, 0.44023500E-02, 0.42080400E-02, 0.12136200E+00, 0.19356900E-01, -.14733500E+00, 0.17523100E-02, 0.17081700E+00, 0.16163100E+00, 0.77418000E-02, 0.13815000E-01, -.42862700E-03, 0.10998900E-01, 0.10322700E-01, -.33467100E-01, 0.35570000E-01, 0.43733400E+00, -.14644000E-01, -.11356100E-01, -.23827000E-01, -.21890300E+00, -.27472000E-01, 0.11393000E-02, 0.82519700E-02, -.26585400E-02, 0.24879900E-02, 0.49237000E-01, -.41422100E-01, 0.69829500E-02, -.51798500E-01, 0.50258000E-02, 0.89877400E-02, 0.25375600E-01, -.10940200E-01, -.10625600E-02, 0.55416500E-02, -.31712100E-02, 0.19623400E-01, 0.49516600E-02, -.12171300E-01, 0.33776900E-02, -.13223500E-01, -.25893100E-02, -.23351500E-03, -.12728500E-01, 0.51362600E-01, 0.57607000E-02, -.11268300E-01, -.10509000E+00, 0.98346000E-01, 0.58876300E-02, 0.23122100E-01, 0.81472700E-03, -.62981600E-01, -.68097800E-02, 0.76667300E-03, 0.11595600E-01, -.71995100E-02, 0.13970300E-01, 0.29158500E-02, -.16792200E-01, 0.35222100E-02, -.26690600E-01, 0.55474600E-01, -.61280700E-03, -.15432400E-01, 0.46419400E-01, -.71899900E-01, 0.95009200E-01, -.39449300E-01, 0.11456400E-01, 0.31942100E+00, 0.42431800E-01, 0.18485500E-01, -.81286200E+00, 0.59276000E+00, -.70890900E-02, 0.51850700E-02, 0.43241100E-01, -.29555700E-01, 0.17755500E+00, -.30726400E+00, -.44884900E-01, -.18903700E-01, -.23439600E-02, 0.58606300E-01, -.14297000E-01, 0.70136000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24493300E+00, 0.68356100E+00, 0.22108300E+00, 0.71195100E+00, -.24717100E-01, -.60305600E+00, 0.17037800E+00, 0.93102500E+00, 0.11370600E+01, 0.79172500E-01, -.34034300E-01, 0.16667600E+00, -.18826600E-02, -.69927900E-01, 0.28679100E+00, 0.30386500E-01, 0.27745100E+00, 0.56082900E+00, 0.17248500E+00, 0.24680400E+00, 0.22302900E-01, -.45110000E-01, -.67416200E+00, -.22305800E-01, -.11188600E+00, 0.94555300E-02, 0.83260900E-01, 0.74055100E-02, 0.93877000E-01, -.42530600E-01, 0.12784900E+00, -.12453600E+00, 0.31833300E-01, 0.33695300E-01, 0.44550300E-01, 0.28927400E-01, -.22771700E-02, -.88245500E-01, -.44625100E-01, -.70906300E-01, -.98359400E-01, 0.63271900E-01, 0.17267800E-01, 0.12870800E+00, -.80439600E-02, -.55690600E-02, -.18989300E-01, -.13799200E-01, 0.10689200E+00, 0.14555200E-01, -.36898200E+00, -.10873900E+00, 0.87223900E-01, -.34334200E-01, 0.15879100E+00, 0.63811500E+00, 0.42525100E-01, -.30545400E-01, 0.82063600E-01, -.12030600E-01, 0.66610900E-01, -.15669500E-01, 0.30288700E-01, -.12736000E-01, 0.59678300E-01, -.13007600E+00, -.18232000E+00, 0.36034300E-02, -.41306700E-02, -.32677900E-03, 0.43166000E-01, 0.19867500E+00, 0.19364800E+00, 0.14178100E+00, 0.10837700E+00, -.16483500E+00, -.70025900E-01, 0.58872600E-01, -.60069100E-01, 0.63120400E-03, 0.34122300E-03, -.20868400E+00, 0.28880000E-01, -.15366600E+00, 0.11968400E+00, 0.10751200E+00, -.28666600E-01, -.56823700E-01, -.10528100E-02, -.24159100E-02, -.50144200E+00, -.38301300E-02, 0.18200000E-01, -.12549400E+00, -.27245900E-01, 0.80110900E-01, 0.77414400E-01, 0.12881000E+00, 0.17149500E+00, -.24456300E+00, -.15793700E+00, 0.82982300E-01, 0.14978100E-02, 0.53777900E-01, 0.11394300E-01, -.48725700E-01, -.21548400E-01, 0.31421100E-01, -.65848100E-02, 0.11565100E-01, -.17237200E-01, -.54611100E-01, -.24598700E-01, 0.75444800E-02, 0.27038000E-01, 0.42931400E-01, 0.96964200E-02, -.31014400E-02, -.62964800E-02, -.63772800E-01, -.51156300E-01, -.15381200E-01, 0.19733900E+00, 0.60139800E-01, 0.10966200E-01, -.50817300E-01, 0.35290900E-01, 0.10544800E-01, -.38079800E-01, -.27411700E-01, -.15895400E-01, 0.10257900E+00, -.19868800E+00, -.10595600E-01, 0.88107500E-02, 0.66850300E-02, -.77010000E-02, 0.45443500E-01, 0.22571500E-01, 0.12875400E-01, 0.10349800E+00, -.90537600E-01, 0.28719000E+00, -.15559200E-01, -.12837400E-01, -.12849800E+00, 0.32274500E-02, 0.11745400E+00, -.37595400E-01, 0.64616600E-01, -.28396500E-01, -.18021600E+00, 0.21244100E-01, -.28202900E-01, -.41281700E-01, -.41995600E-01, 0.40607200E-01, -.12182000E-02, -.31650200E-01, 0.10371000E-01, 0.22798400E-01, 0.10881700E-01, 0.22322200E-01, 0.82606600E-02, -.13052700E-01, 0.38682800E-01, -.60625500E-02, -.25167800E+00, 0.24677500E-02, -.72540700E-01, 0.17416900E+00, -.48075300E-01, 0.50404800E-02, -.36308800E-01, -.31719400E-01, -.38774100E-01, 0.23961000E-01, 0.39624100E-02, -.31781800E-02, -.47782700E-02, 0.34049800E-01, -.23750400E-01, -.46120000E+00, 0.49276200E-02, 0.81578900E-01, 0.13579800E+00, 0.83550300E-02, -.67963400E-01, 0.12993500E-01, -.27658900E-01, -.23877800E-01, 0.63260600E-01, -.14314600E+00, 0.47481900E+00, 0.20699500E-01, -.15103300E-02, -.47220200E-01, -.47099400E-01, 0.86688200E-02, -.29233700E-01, 0.17841300E-01, -.29971100E-02, 0.28959900E-01, 0.29659600E-01, 0.26731000E-01, 0.16526500E-03, -.24095300E-01, -.28268700E-01, 0.11756600E-02, 0.38566500E-01, 0.46441100E-02, 0.65498500E-02, 0.59133400E-02, 0.19133200E-01, 0.27981300E-01, -.33668200E-01, -.12073600E-01, -.56344300E-02, 0.46976400E-02, 0.72516400E-02, -.21540300E-02, -.27673200E-01, 0.54142400E-01, -.45272200E-02, -.35306700E-01, -.31934200E-01, 0.79776300E-01, 0.81236800E-02, 0.70137300E-03, 0.24153200E-02, -.89676700E-01, -.10429200E-01, 0.48786100E-02, 0.10058200E-01, -.81246200E-02, 0.26640400E-01, 0.45005600E-02, -.71127100E-01, 0.99898100E-02, -.22617600E-01, 0.68051000E-01, -.48216600E-02, -.40496700E-01, 0.70637600E-01, -.10355300E+00, 0.11746400E+00, -.32062400E-01, 0.95499100E-01, 0.58693400E-01, 0.11672300E+00, 0.55756000E-01, -.15483200E+01, 0.60099900E-01, -.12811500E+00, 0.13754600E-01, 0.12614900E+00, 0.13303500E-01, -.58988400E-01, -.13891200E+01, -.83174700E-01, 0.32923500E-01, -.34389200E-02, 0.93819600E-01, -.10143400E-01, 0.60671300E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.79670000E+01, 0.10808400E+02, -.52884400E+01, 0.71529500E+01, -.43966100E+00, -.20224400E+01, 0.15667600E+01, 0.10043800E+02, 0.63152900E+02, 0.25539500E+01, -.60280000E+00, 0.19250400E+01, -.56552900E+00, -.11278200E+01, 0.25055700E+01, -.22762100E+01, -.16092200E+01, 0.47823700E+01, 0.18867900E+01, 0.16563400E+01, 0.19462700E+01, 0.16289500E+01, -.11036600E+02, 0.12360200E+01, 0.36549800E+00, 0.93445500E-01, -.22034900E+00, -.61015400E-02, 0.80891100E+00, -.56114800E+00, -.14931100E+00, -.17558000E+01, -.28825800E-01, -.12133800E-01, 0.85449200E-01, 0.26948100E+00, -.65887300E-02, 0.10537100E-01, -.96729600E+00, -.48898000E+00, 0.10384800E+01, 0.11029700E+00, -.14661500E+01, -.16211200E+00, 0.22992800E+00, 0.43101300E+00, -.98889600E+00, -.16517500E+00, 0.20437100E+01, -.87537700E+00, -.12682800E+01, -.29158300E+01, 0.13167000E+01, -.37426700E+00, 0.85154300E+00, 0.40103100E+01, 0.20108800E+01, -.21164000E+00, 0.13117400E+01, -.13792700E+01, 0.18905300E+01, 0.35095400E+00, 0.14140800E+01, -.11063900E+01, 0.44653900E+00, -.74908000E+00, -.42895000E+01, -.82471100E+00, -.10024000E-01, 0.28808700E-02, -.17098700E+00, -.11179600E+01, 0.69709300E+01, -.29927600E+01, 0.75968800E+00, -.44703300E-02, 0.31922700E+00, 0.24978200E+01, 0.72186500E-01, -.59345300E-01, -.43812500E-02, 0.36909600E+01, -.15651300E+01, -.91265700E+00, 0.71283200E+00, -.51390200E+00, -.19325900E+00, -.21803900E+01, -.12702400E+01, 0.64930100E+00, -.80368900E+00, 0.29950100E-01, 0.38423000E+00, -.23268200E+01, -.43449100E+00, 0.26147300E+01, 0.19669800E+01, -.10750600E+00, -.10381500E+01, 0.27080800E+01, -.18227700E+00, 0.14961400E+01, -.28471300E-01, 0.12436300E+01, -.33712300E+00, -.25350900E+01, -.24747700E+00, -.74553000E+00, -.26682600E+00, -.56412200E-01, -.17578600E+00, -.11137200E+00, -.97088100E+00, 0.30601300E+00, 0.32946300E+00, 0.39977700E+01, -.26899700E+00, 0.45271500E+00, -.25571000E+00, -.10725400E+01, -.13638600E-01, -.38409200E+00, 0.36277900E+01, 0.28471800E+00, 0.14910500E-01, 0.41175900E+00, 0.37971500E+00, 0.16602000E+00, 0.18501800E+00, 0.75281600E+00, 0.58391300E+00, 0.10114600E+01, 0.21973800E+01, -.15806700E+00, 0.19512000E+00, 0.27656400E-01, 0.10915400E+01, 0.17726600E-02, 0.34722400E+00, 0.22354200E+00, 0.38126100E+00, -.60283800E+00, -.61491600E+00, -.36185500E-01, -.11180100E+00, -.51358500E+00, -.83625900E-02, 0.57531300E+00, -.59889700E-01, 0.13451400E+01, -.11437800E+00, -.10142300E+01, -.48842600E+00, -.65904300E+00, -.25044900E+00, -.18530600E+00, 0.17102100E+01, -.21388600E-01, 0.16927400E+00, -.30258600E+00, -.29124100E-01, -.11057900E+01, 0.21519400E+01, 0.52132000E+00, 0.18788600E+00, 0.84767800E+00, 0.14858400E+00, 0.14450300E+01, -.47457300E-01, -.13940400E+00, 0.23440700E+00, 0.24780600E+00, 0.41677600E-01, 0.34995800E+00, -.67806500E+00, -.97930500E-01, -.28059100E+00, 0.12836600E+00, 0.33842000E+00, -.76387600E-01, 0.95360600E+00, -.27346400E+00, 0.35916300E+01, 0.88949900E-02, 0.27593600E+00, 0.75675100E+00, 0.54689300E-01, 0.81003000E+00, -.26799700E-01, -.73160100E+00, -.26395500E+00, -.31212900E+00, -.62021600E+01, -.23845900E+01, 0.20977700E-01, 0.67792900E-01, 0.60031200E+00, -.16138300E+00, -.11776700E-01, -.28871700E-01, -.75171100E-01, 0.11186200E-01, 0.26334200E+00, -.20452600E+00, -.14694200E+01, 0.25289200E+00, -.57393200E+00, -.11039600E+00, 0.79882000E-01, 0.96163700E-01, -.12713300E+00, 0.30107300E+00, 0.15792500E-01, 0.13434000E+00, 0.29190400E+00, -.17308100E+00, 0.35612100E-01, -.51608300E-02, 0.86403300E-01, 0.22757000E+00, 0.26088500E-02, 0.10579900E+00, 0.50415400E+00, 0.22915100E-01, -.32214200E+00, 0.38959000E+00, 0.11675800E+01, 0.14417300E-01, -.16792800E+00, -.23584600E+00, -.66015500E+00, -.66187900E-01, -.33593000E+00, 0.30134700E+00, 0.17615000E+00, 0.15477200E+01, 0.14220100E+00, 0.40193100E+00, -.47538100E+00, -.24728000E+00, 0.36762600E+00, -.30284700E-01, 0.10069600E+01, -.39528700E+01, 0.26689800E+01, 0.43352800E+01, -.23748300E+01, 0.53846700E+01, 0.86135600E+00, -.59239300E+00, 0.12285600E+01, -.15196100E+02, 0.53733100E+01, -.48031300E+01, 0.75784800E+00, -.26186800E+01, 0.22402400E+01, 0.55847500E+01, -.18754200E+01, -.51000900E+01, 0.11239200E+01, 0.92169100E+00, 0.36650900E+01, -.42186300E+00, 0.23044100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11250000E+01, 0.11163400E+01, 0.33114500E+00, 0.61736900E+00, -.16132700E+00, -.43754900E+00, 0.24081000E+00, 0.98187800E+00, 0.45307000E+01, -.15841500E-01, -.53191700E-01, 0.14432800E+00, -.31086500E+00, -.65538700E-01, 0.40813400E+00, -.57281800E+00, -.12429600E+01, 0.34737000E+00, 0.21430300E+00, 0.43439400E+00, -.13914000E+00, 0.22025700E+00, -.14881800E+01, -.16011200E+00, 0.16129700E+00, -.13534600E-01, 0.15439700E+00, 0.32905700E-01, -.11883300E+00, 0.35848000E-01, 0.22765200E-01, -.21474300E+00, 0.29606400E-01, 0.12748300E+00, 0.32860700E+00, 0.99042100E-01, -.27233300E-02, -.16824600E+00, -.48679400E+00, 0.56338400E-01, -.42422100E+00, 0.54888000E-01, 0.10443400E+00, 0.28414200E+00, -.42160500E-01, -.11610800E-01, -.45388900E-01, -.35266600E-01, 0.91528100E-02, 0.78132900E-01, -.11525200E+01, -.12653100E+00, 0.26976000E-02, -.25272200E+00, 0.22421300E+00, 0.78818400E-01, 0.21123100E+00, 0.15416000E-01, -.14450700E+00, -.20793300E+00, 0.14014100E+00, -.24318500E-01, 0.27751100E+00, -.15452500E+00, -.48999500E+00, 0.18989100E+00, 0.45366900E+00, 0.98322800E-02, 0.50654300E-02, -.20548900E-03, 0.97726200E-01, -.37397600E+00, 0.84431200E+00, -.15593000E-01, 0.46320400E-01, 0.44549200E-01, -.19533400E+00, 0.23835800E+00, -.44220600E-01, -.22822000E-01, 0.21778600E-03, 0.95710600E-01, -.90597600E-01, -.30401800E+00, 0.67426900E-01, -.11407900E+00, -.49133400E-01, -.14404400E+00, -.43723400E-02, 0.34128800E-01, -.71510100E+00, 0.37834800E-02, -.28952100E-01, -.55374100E-01, -.24603400E-01, 0.92961300E-01, 0.15278700E+00, 0.46286100E-01, -.11319200E+00, 0.29878900E+00, 0.11195300E+00, 0.37078300E-01, -.14874200E-02, 0.32989600E-01, 0.61030200E-01, -.23517600E+00, -.25580500E-01, -.72252700E-01, -.42019400E-01, -.22036100E-01, 0.14088200E-01, 0.69219200E-01, -.51573000E-01, 0.16488700E-01, -.70701100E-02, -.19643100E+00, -.11306500E+00, -.42400000E-02, -.34150900E-01, -.78054000E-01, -.59063400E-01, 0.50589700E-01, -.11706900E+00, 0.53185600E-02, -.47558600E-02, -.15340200E-02, 0.17362100E-01, -.24278800E-01, 0.81195000E-02, 0.34370900E-01, -.24263800E-01, 0.20603700E-01, -.13750700E+00, -.82735400E-04, 0.44253200E-01, -.69040200E-02, -.13761400E+00, -.54567900E-01, 0.24625900E-01, 0.28659400E-02, -.41443000E-01, -.78635900E-01, -.97594200E-01, -.20801400E-01, -.61574900E-02, -.10402400E-01, -.73500500E-02, -.37137900E-01, -.10768700E+00, 0.30445100E+00, -.84095000E-02, 0.37171100E-01, 0.45123300E-01, 0.43332800E-01, 0.35175400E-01, 0.37961800E-01, 0.41910300E-01, 0.12156700E-02, 0.37309300E-01, -.15332600E-01, -.21823800E-01, 0.82968400E-01, 0.68699100E-01, 0.15341200E-01, -.17280700E-01, 0.16975600E-01, -.31003400E-01, 0.23290400E+00, 0.10466900E-01, 0.55806400E-01, -.89277000E-01, 0.66661900E-01, -.15916300E-02, -.79460900E-01, 0.34780300E-01, 0.31361600E-01, -.23901700E-01, -.15599000E-01, -.46610800E-02, 0.92398100E-02, 0.69678800E-01, 0.93777400E-02, 0.45979600E+00, 0.34625900E-01, -.25271500E-01, 0.41657300E-01, 0.18180000E-01, -.34545100E-01, -.22460000E-01, -.18523400E-01, 0.29197000E-02, -.32548200E-01, -.26502700E+00, -.53845900E+00, -.70972900E-01, -.92363500E-02, 0.36205400E-01, -.14965800E+00, -.13808700E-01, -.16760500E-01, -.94988400E-02, -.65266400E-03, 0.81780900E-02, -.20328000E-01, -.10681600E+00, 0.23252000E-01, -.29402100E-02, -.14588900E-01, 0.12482500E-01, -.12894800E-01, -.34848800E-01, 0.28324700E-01, 0.11098100E-03, -.17906800E-01, 0.16232600E-01, 0.25088000E-01, 0.40298300E-02, 0.15524200E-01, -.91704000E-02, 0.11455300E-02, -.55534600E-02, 0.39603300E-01, 0.15816100E-01, 0.97039000E-02, -.68149500E-02, -.25729700E-01, 0.91045300E-01, -.11630000E-01, -.19307400E-01, -.22799600E-01, -.61113900E-01, -.81607700E-03, -.12559900E-01, -.63260900E-03, 0.99410700E-02, 0.10007600E+00, 0.15661500E-01, -.31101400E-02, -.19965300E-01, -.10113300E-01, 0.17778600E-01, -.16207100E-02, 0.17563700E+00, -.80939900E+00, 0.35052600E+00, 0.45098600E+00, -.25271100E+00, 0.25719600E+00, 0.57378200E+00, 0.28894500E-01, 0.24417800E-01, -.20954800E+00, -.12891900E+00, -.23304400E+00, 0.11482000E-01, -.39862000E+00, 0.54525000E-01, -.13402600E+00, 0.23266100E-01, 0.18654600E-01, 0.34671800E+00, 0.11187700E+00, -.10463600E-01, -.20395900E-01, 0.25768700E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.50778000E+00, -.69406200E+00, -.74631300E-01, -.36230100E+00, -.29587600E+00, 0.37672700E+00, -.14522800E+00, -.36859100E+00, 0.54214700E+01, -.31035200E-01, 0.89140000E-01, 0.48693500E+00, 0.71093400E-01, -.12522600E-01, -.46699700E+00, 0.23773400E+00, 0.31499200E+00, -.96627000E+00, -.17895000E+00, -.34466300E+00, 0.31783900E+00, -.10614400E+00, 0.36130200E+00, -.12097200E+00, 0.79700600E-01, -.22487600E-02, 0.19521400E+00, 0.17304400E-01, -.30633100E-01, 0.11959200E+00, 0.65294500E-01, 0.13703300E+00, -.11210200E+00, -.62029200E-01, -.75100500E-01, 0.34947500E-02, 0.23250600E-02, 0.19062400E+00, -.88074300E-01, -.74713300E-02, 0.60413300E-01, -.10376400E+00, -.75457300E-01, -.40506300E-01, 0.41636000E-01, 0.31128000E-01, -.28984000E-01, 0.80482800E-03, 0.12475000E+00, -.82778900E-01, 0.39179300E+00, -.74240700E-01, -.20410200E-02, 0.10189500E+00, -.29915600E+00, 0.31504700E+00, 0.21495800E+00, 0.23380000E-01, 0.68141200E-01, 0.29983700E+00, -.34675500E+00, 0.38991600E-01, 0.22542800E-01, -.15765800E-01, 0.31400400E+00, -.51714600E+00, -.68597500E+00, -.65070900E-01, 0.16416900E-01, 0.45646000E-03, -.18845400E-01, -.32159500E-01, 0.69698400E+00, -.40242300E+00, 0.15049300E+00, 0.30399500E+00, -.13162800E-01, 0.12422500E+00, -.10157900E-01, 0.46340700E-01, -.36486600E-03, 0.22681300E+00, -.14394900E+00, 0.67976300E-01, 0.66725300E-01, -.12690700E+00, 0.32582000E-02, 0.50624500E-01, 0.27055600E-01, 0.43233600E-01, 0.17437800E+00, 0.26141300E-02, -.50618300E-02, -.16047600E+00, 0.31339700E-01, 0.71679000E-01, 0.31580200E+00, -.61564200E-02, -.28452900E+00, 0.17731000E+00, 0.22676200E+00, 0.24643000E-01, -.40129100E-02, 0.89303700E-01, 0.51764200E-01, -.21439300E+00, -.22642100E-01, -.81978400E-01, -.53050800E-01, -.19809100E-01, 0.16513400E-01, 0.39673300E-01, -.74385500E-02, 0.23692200E-02, -.44566600E-01, -.10261800E+01, -.17354100E+00, -.35977400E-01, -.35485000E-01, 0.11572700E+00, -.95553000E-01, -.39311700E-02, 0.11155200E-01, 0.10803600E-02, 0.96585800E-03, -.10073500E+00, -.61595500E-02, -.42706500E-01, -.74794700E-01, -.20938400E+00, -.17992000E+00, -.23367400E-01, -.60722400E+00, -.99292000E-02, 0.30945400E-01, 0.13196300E-01, 0.33940400E+00, 0.42197100E-01, -.12309000E-01, 0.58464100E-01, 0.10999300E+00, -.26747100E+00, 0.20625400E-01, -.71774700E-01, 0.35237100E-02, -.14142600E-01, 0.29370900E-02, 0.17924600E+00, -.41773400E-01, 0.26698900E+00, -.11364700E-01, 0.15061400E+00, 0.37582600E-01, 0.13154500E-01, -.65709800E-03, -.37621400E-01, 0.48479100E-01, -.19738500E-02, -.80080200E-02, -.20159400E-01, 0.38240300E-02, -.11536900E+00, 0.23511400E+00, 0.30031000E-01, 0.83950700E-01, -.64635000E-01, 0.24439600E-01, 0.21851000E+00, -.77002700E-02, 0.27154100E-01, -.15422700E-01, 0.71038300E-01, -.41617200E-01, -.11305600E+00, -.27348500E-01, 0.11187100E-01, 0.27271900E-01, 0.36518200E-01, -.36629500E-03, 0.41699400E-02, -.69147200E-01, 0.42323800E-02, 0.31552800E+00, 0.99015000E-02, -.22317300E-02, 0.68643300E-01, -.34537600E-02, 0.67630800E-01, -.24134200E-01, -.21270400E-01, -.14302300E-01, -.54030800E-01, 0.32963400E+00, 0.11686500E+01, 0.56574300E-01, -.34555800E-01, 0.24339900E-01, -.42493200E-01, -.44236100E-01, 0.84177800E-01, -.27826200E-01, 0.15898600E-02, -.33121700E-01, 0.17284700E-01, -.79372300E-01, 0.13362400E-01, -.10642200E+00, 0.94237000E-01, 0.50248800E-01, 0.15041300E-01, -.37127800E-02, 0.22868200E-02, 0.28080400E-02, 0.91218700E-02, -.18874800E-01, 0.16067500E-02, -.14816700E-01, 0.55907200E-02, -.26917400E-02, -.82680100E-02, -.70946100E-02, 0.29238600E-01, 0.20033100E-01, 0.92850000E-02, 0.22416100E-01, -.54228000E-01, 0.98736000E-01, 0.94840400E-02, 0.32415800E-01, 0.74697800E-02, -.57421000E-01, -.90726400E-02, -.41522000E-03, 0.91260400E-02, -.88124700E-02, -.58781800E-01, -.54777100E-02, -.31890900E-01, 0.14207000E-01, -.60967200E-02, 0.33262700E-01, -.19831800E-02, -.35338500E-01, 0.21229800E+00, -.16619300E+00, -.21013100E+00, -.21510800E+00, 0.16836300E+00, -.22218100E+00, -.19040000E-01, 0.14737100E-01, 0.74164800E-01, -.18004600E+00, -.65984000E-01, -.33951700E-03, -.31126100E+00, 0.34758100E-01, -.10803700E+00, -.16364700E-01, 0.49783700E-02, 0.21185900E+00, 0.19386200E+00, -.41140500E-03, -.19188600E-01, -.28609600E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.93877000E+00, 0.75254400E+00, 0.55934700E+00, 0.80029700E+00, -.64804500E-01, -.96015400E+00, 0.26976800E+00, 0.11501100E+01, 0.24469500E+01, 0.15350400E-01, -.47086600E-01, 0.25318500E+00, -.12946400E+00, -.30587800E-02, 0.51294300E+00, -.42232700E+00, -.82843200E-01, 0.10820700E+01, 0.31186600E+00, 0.48296600E+00, 0.45699600E-01, 0.56655200E-01, -.10003000E+01, -.20589000E-01, -.20253600E+00, 0.68946100E-02, 0.24107800E+00, 0.31456200E-01, -.62548300E-02, -.81767300E-01, 0.26923700E-01, -.14838100E+00, 0.40346400E-01, 0.11985400E+00, 0.13047800E+00, 0.37502700E-01, -.31149100E-02, -.13926300E+00, -.35598500E-01, -.12731900E+00, -.45918500E+00, 0.15943100E+00, 0.22166800E+00, 0.38816400E+00, -.77758800E-01, -.27932800E-01, -.78122600E-01, -.50448000E-01, 0.25314300E+00, 0.12429500E+00, -.10276800E+01, -.12681200E+00, 0.17684600E+00, -.11025900E+00, 0.35761800E+00, 0.69084500E+00, 0.40217500E+00, -.51872700E-01, -.22408400E-01, -.93992600E+00, 0.27588600E+00, -.79424700E-01, 0.29114900E+00, -.11789700E+00, -.34598700E+00, 0.93367900E-01, -.93371000E+00, 0.17812400E-01, 0.22794200E-01, -.51396300E-03, 0.16134300E+00, -.21457400E+00, 0.68894900E+00, 0.48195000E+00, 0.26868400E+00, -.24718400E+00, -.72716000E-01, 0.13175900E+00, -.11844100E-01, 0.13195500E-01, 0.21111800E-03, -.11376100E+00, -.13636200E-01, -.96876700E-01, -.61305300E-01, -.15156300E+00, -.68035600E-01, -.46681600E+00, 0.43763500E-01, 0.23798200E-01, -.16483600E+01, -.37875700E-02, 0.72823300E-01, -.19869400E+00, -.58132900E-01, 0.24610600E+00, 0.22491300E+00, 0.51771300E-02, 0.18208200E-01, -.51576900E-01, -.18240600E+00, 0.18936300E+00, 0.43777200E-02, 0.14073200E+00, -.65411900E-01, -.11954000E+00, 0.19360400E-01, 0.15396900E-01, -.12707200E-01, 0.44263300E-02, -.90680700E-02, -.45828400E-01, -.89119700E-01, 0.27922600E-01, 0.49522800E-01, 0.25350900E+00, 0.32965100E-01, 0.12557500E-01, -.31683000E-01, -.14453100E+00, -.36645400E-01, -.29761700E-01, 0.26194100E+00, 0.17378300E-01, 0.93760800E-02, 0.11319800E+00, 0.14030900E+00, 0.44929600E-01, 0.78208500E-01, 0.67367200E-01, -.17886300E-01, 0.19510200E+00, -.98465000E-01, 0.25399100E-02, -.11649900E-02, 0.10767700E-01, -.69766800E-01, -.76604300E-01, -.96720100E-02, 0.62196200E-01, 0.13183400E-01, -.10876400E+00, 0.21392100E+00, 0.13353300E+00, -.77031200E-02, -.18153400E+00, 0.76779300E-02, 0.34635700E+00, 0.72345600E-01, 0.13190600E-01, -.85097800E-01, 0.12168400E+00, 0.24163200E-01, -.76240200E-01, 0.51205500E-01, 0.20401600E-01, 0.11337100E+00, 0.99858500E-03, 0.41221400E-02, 0.10161200E+00, 0.55894600E-01, -.18717000E+00, 0.33863300E+00, 0.30605300E-02, 0.65894000E-02, 0.11569400E+00, -.44247200E-01, -.17050400E+00, 0.16027800E-01, -.10284600E+00, 0.10245800E+00, -.13838400E-01, 0.23936800E-02, -.47194700E-01, 0.23398400E-01, -.57175300E-02, 0.56368100E-01, -.32951500E-01, -.30498100E-01, 0.15683900E-02, 0.54688500E-01, -.36901000E-01, -.23302400E+00, -.46523800E-01, 0.48705600E+00, 0.43551200E-01, -.13825100E-01, 0.14096000E+00, 0.32965200E-01, -.57944700E-01, 0.44221400E-01, -.13440700E-01, 0.14211000E+00, 0.80088700E-01, 0.13720400E-01, -.58061100E-02, -.68640200E-01, -.29501300E+00, -.15256800E-01, -.17820400E-01, 0.13550600E-02, -.25727600E-02, 0.17616800E-01, 0.45309900E-01, 0.20536800E+00, -.35067900E-01, -.43799000E-01, -.17654100E-01, -.18579500E-01, 0.75747400E-01, 0.34756100E-01, 0.10153500E-01, 0.90840100E-02, 0.21234800E-01, 0.13084900E-01, -.44854100E-01, -.14735700E-01, -.54042500E-01, 0.90191900E-02, 0.15907600E-01, -.75672100E-02, -.25030200E-01, 0.33838300E-01, 0.16697000E-02, -.23772700E-01, 0.67036100E-01, 0.60332100E-01, 0.46458000E-02, -.25038500E-02, -.51740300E-02, 0.25265900E-01, -.10102500E-01, -.29593700E-01, 0.41073300E-01, 0.58588700E-02, -.75929300E-02, -.50952700E-02, 0.62684800E-01, -.32596400E-01, -.44346400E-02, 0.18149800E-02, 0.69793100E-03, 0.37798400E-01, -.25957600E+00, 0.18375700E+00, 0.22435500E+00, -.60918200E-01, 0.11441800E+00, 0.46549200E-01, -.33920700E-01, 0.21881400E-01, -.87864600E+00, 0.26383500E+00, -.28295000E+00, 0.21516700E-01, -.88575500E-02, -.62413000E-02, 0.17819700E+00, 0.15465900E+00, 0.14572700E-01, -.28555800E-01, -.17543300E-02, 0.17087300E+00, -.16620100E-01, -.36669900E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.71675600E+00, -.12853400E+01, 0.17472900E+00, -.10320100E+01, 0.13100000E+00, 0.58470200E+00, -.17925700E+00, -.12294200E+01, -.72274000E+01, 0.38419800E+00, 0.79803300E-01, -.29735500E+00, -.19342500E-01, 0.16195000E+00, -.25146600E+00, 0.28570800E+00, 0.51124500E+00, -.93946000E-01, -.67847500E-01, -.34485000E+00, -.80463700E-01, -.65660600E-01, 0.10644100E+01, 0.12958000E+00, -.72560700E-02, 0.41717000E-04, -.17167900E+00, -.32118400E-02, 0.21037500E-04, 0.60294900E-01, 0.10415500E+00, 0.14711200E+00, -.42357600E-01, -.56703800E-01, -.15732900E+00, -.65087700E-01, 0.25587000E-02, 0.36789400E-01, 0.28791600E+00, 0.90529000E-02, 0.10437000E+00, 0.48208000E-02, 0.15327400E+00, -.15619700E-01, -.99035400E-02, -.25722200E-01, 0.63164400E-01, 0.32875400E-01, -.19101900E+00, 0.31723000E-01, 0.13113600E+00, 0.22713100E+00, -.77073300E-01, 0.10704800E-01, -.33497900E-01, -.62907700E+00, -.32355400E+00, 0.55316700E-01, -.29230000E-01, 0.32320700E+00, -.87281800E-01, 0.25029900E-01, -.14471900E+00, 0.94567500E-01, 0.31879900E+00, 0.71540600E-01, -.26980500E+00, 0.24233500E-01, 0.17675600E-01, 0.36710500E-03, -.69401700E-01, -.38854400E-01, -.12381100E+01, -.17659500E+00, -.16821000E+00, -.36759200E-01, 0.19027200E+00, -.17426600E+00, 0.10191100E+00, 0.15157200E-01, -.58627600E-03, 0.34315300E+00, 0.97024400E-01, 0.18055500E+00, -.37094300E+00, -.71866000E-04, 0.63512200E-01, -.41449800E+00, 0.19390800E+00, -.32643900E-01, 0.62084600E+00, -.19353100E-02, 0.67515400E-02, 0.25208900E+00, 0.84460000E-02, -.13691600E+00, -.25830000E+00, -.24213400E-01, 0.22614200E+00, -.12498100E+00, -.40429100E-01, -.10783000E+00, 0.98371200E-02, -.16084100E+00, 0.30261900E-01, 0.25588700E+00, 0.54785900E-02, 0.88510400E-01, 0.16573700E-01, -.16105700E-01, 0.18604200E-01, 0.80022700E-01, 0.79752500E-01, -.25056500E-01, -.19424600E-01, 0.96003000E-01, 0.42515100E-01, -.12246300E-01, 0.19306600E-01, 0.59423700E-02, 0.57419300E-01, 0.55372800E-01, -.23900400E+00, -.86826500E-01, -.58377000E-02, 0.14912300E+00, -.65624700E-01, 0.19527500E-02, -.65106200E-01, 0.55442300E-01, -.66273100E-01, -.47169600E-01, -.41837800E+00, 0.30109200E-01, -.38302100E-01, -.16951100E-02, -.17110200E-01, -.15425500E-01, -.41478900E-01, -.10926100E-01, -.78627200E-01, -.56086600E-01, -.39491400E-01, 0.68332900E-02, 0.24154400E-01, 0.35636600E-01, 0.54401000E-02, 0.45945400E-01, -.32752500E-03, -.17479400E+00, 0.26855200E-01, 0.27188500E+00, -.11341100E+00, -.10243100E+00, 0.25701900E-01, 0.36453600E-01, 0.49256300E-02, 0.74590800E-03, 0.37136400E-01, 0.38404500E-01, 0.53926300E-03, -.34796500E+00, -.22909600E+00, -.21593100E-01, -.90704600E-02, -.12058400E-01, -.66843400E-02, 0.22174900E+00, 0.96384800E-03, 0.10596000E+00, -.10125500E+00, 0.10193700E+00, 0.33670000E-01, 0.21786700E-01, 0.68304700E-02, 0.79800500E-01, -.18617400E-01, -.26294300E-01, 0.20211200E-01, -.19881800E-03, -.59000900E-01, 0.12064600E-01, 0.75694800E-01, -.30011200E-01, -.14044300E+00, -.34458400E-01, -.18790400E-01, 0.42453800E-01, 0.80784300E-03, 0.11810800E-02, -.72387900E-02, -.11897800E-01, 0.27460800E+00, 0.23109300E+00, 0.71639500E-02, 0.36293600E-03, 0.21853100E-01, 0.62954500E-01, -.35017400E-02, -.13712100E-01, -.32788200E-02, 0.17728500E-02, -.26212400E-01, -.31384700E-01, 0.11716100E+00, -.27263000E-01, 0.87654800E-02, 0.37912300E-02, -.28880000E-01, -.43905900E-01, 0.34433900E-01, 0.25174200E-01, -.12089200E-01, 0.18206900E-01, 0.20313300E-01, -.30407300E-01, 0.10954500E-01, -.49538400E-01, 0.11648800E-01, 0.16214400E-01, -.59171300E-03, -.50693300E-01, 0.26804800E-01, -.17102000E-01, -.21887300E-01, 0.12221700E+00, -.16110900E+00, 0.30583400E-03, -.20223900E-01, -.25202100E-01, 0.11586300E+00, 0.12081100E-01, -.29507300E-01, 0.12100200E-01, 0.20759300E-01, 0.36448500E-01, -.62408500E-02, 0.56669900E-01, -.96335900E-02, 0.40449100E-01, -.12925700E+00, 0.67824000E-02, 0.43549700E-01, -.22708600E+00, 0.91427900E-01, -.15382900E+00, 0.33969700E-01, -.70402500E-01, -.10817600E+00, -.12795300E+00, -.72416900E-01, 0.89011100E+00, -.23466500E+00, 0.16744100E+00, -.16075300E-01, -.34179300E-01, -.23362900E-01, -.87254000E-01, -.30749300E+00, -.10297400E-01, -.25175200E-01, -.46320800E-02, -.10290100E+00, 0.11384800E+00, 0.10458500E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.53909400E+00, -.12348100E+01, -.26702900E+00, -.10242100E+01, 0.52061300E-01, 0.96113300E+00, -.56287300E-01, -.68149800E+00, -.52149500E+00, 0.36269000E+00, 0.22091700E-01, 0.61821700E-01, 0.32606300E+00, -.62944500E-01, -.23688900E+00, 0.36677200E+00, 0.16695300E+01, 0.58884900E+00, -.44329100E-01, -.43251600E+00, 0.19022500E+00, -.74384900E-01, 0.13739700E+01, 0.50080700E-01, -.19494400E+00, 0.24068000E-02, -.25160400E+00, 0.34078500E-02, -.26027100E-01, 0.29103500E-01, 0.10628500E+00, 0.16779100E+00, -.58429600E-01, -.64899700E-01, -.17853900E+00, -.56699400E-01, 0.37263600E-02, 0.59996100E-01, 0.20526600E+00, -.18890800E-01, 0.53269500E-01, -.10486700E-01, 0.19106000E+00, 0.24106200E-01, -.14453100E-01, -.12384500E-01, 0.15337200E-01, 0.11185900E-01, -.90529200E-01, 0.15103700E-01, 0.24074500E+00, 0.15049900E+00, -.26043900E-01, 0.74522300E-01, 0.25778700E-02, -.42193700E+00, -.39131200E+00, 0.27331000E-01, -.43753100E-02, 0.27311100E+00, -.49549500E-02, 0.87797300E-02, -.19471900E+00, 0.28746300E-01, 0.22155800E+00, 0.50938000E-01, -.77493700E+00, 0.12398200E-01, 0.16487700E-01, 0.40603200E-03, -.48263000E-01, -.92201100E-01, -.95534000E+00, 0.94539700E-01, -.13980300E+00, -.17874500E+00, 0.86980300E-02, -.13196300E+00, 0.59787600E-01, 0.20086500E-01, -.20508200E-03, 0.17859400E+00, 0.62675400E-01, 0.76557700E-01, -.25454800E+00, 0.13180800E+00, 0.43643400E-01, -.53545800E+00, 0.26166800E+00, -.49481200E-01, 0.32238300E+00, 0.13029200E-02, 0.46411800E-02, 0.22381700E+00, -.12950700E-01, -.11378300E+00, -.14180400E+00, 0.14997200E-01, 0.16968200E+00, -.36588500E+00, -.27107900E+00, -.10277300E+00, 0.12494300E-01, -.23308300E+00, 0.51772100E-01, 0.15144600E+00, -.52027800E-01, 0.12286000E+00, 0.16036600E-01, 0.25183000E-01, 0.18229600E-01, 0.50451300E-01, 0.53207700E-01, -.16790800E-01, -.15300500E-01, -.44555900E+00, 0.17719000E-01, -.10048200E-01, 0.29827200E-01, 0.15681400E+00, 0.78609000E-01, 0.34340200E-01, -.44653300E+00, -.97378800E-01, 0.29498700E-02, 0.44219300E-01, -.18645100E+00, 0.19323700E-01, 0.30233000E-01, -.59660800E-01, -.79224400E-01, 0.80507500E-02, -.16130900E+00, 0.21699300E-01, -.81372700E-01, -.14637200E-02, -.74589400E-01, -.13203200E-01, -.66223600E-01, -.14179100E-01, -.83667700E-03, -.16235000E+00, 0.55709400E-01, -.12826900E-02, -.31531800E-02, -.12158200E+00, 0.68737200E-02, 0.14501600E+00, 0.36338800E-01, -.17861400E+00, 0.34883100E-01, 0.11458800E+00, -.18914600E+00, -.11763700E+00, -.25980900E-01, 0.67176100E-02, 0.86860900E-01, 0.30752300E-02, 0.71206700E-01, -.25378900E-01, -.22346700E-01, -.36379700E+00, -.25177300E+00, 0.23826200E-01, 0.42427400E-01, -.63693900E-01, 0.32845400E-01, 0.16876500E+00, -.11271000E-01, 0.41179300E-01, -.21720600E-01, 0.16542100E-03, 0.49917600E-01, 0.19679300E+00, -.72753100E-01, -.14519800E-02, -.29527500E-01, -.32860100E-01, 0.29824000E-01, -.10567000E-01, 0.39060000E-02, -.17962900E-02, -.60035900E-01, -.91074800E-02, -.35215500E+00, -.71552300E-01, -.14171100E-01, 0.22138300E-01, -.19703600E-01, -.49538600E-01, -.71026200E-01, -.14100300E-02, -.43505200E-01, 0.23348000E+00, -.31391700E-02, 0.12973600E-02, 0.10780100E-01, 0.34764800E+00, 0.32548300E-01, 0.24458200E-02, 0.19698300E-02, 0.22596000E-02, -.23353000E-01, -.63045300E-01, -.25764700E-01, -.42532800E-02, 0.32963700E-01, 0.36071400E-02, -.22851800E-01, -.61876700E-01, 0.62784100E-02, 0.60467300E-01, -.13859900E-01, 0.98500300E-02, 0.16616800E-01, -.26615100E-01, 0.28967600E-01, -.69800600E-01, 0.13073300E-01, 0.26022400E-01, -.36135400E-02, -.41869900E-01, -.44123600E-01, -.38941500E-01, -.13425400E+00, 0.25337600E+00, -.29544100E+00, -.13954900E-01, -.88693500E-01, -.55159800E-01, 0.17170100E+00, 0.17836300E-01, -.63369300E-01, 0.24979000E-01, 0.35443600E-01, 0.10655000E+00, -.32016300E-02, 0.25760500E+00, -.59767800E-01, 0.71746200E-01, 0.18990100E+00, -.93689700E-03, 0.17852400E+00, -.10529900E+01, -.11682900E-01, 0.65517300E-02, -.34357700E-02, 0.27501100E-02, 0.34828600E-01, -.22994100E-01, 0.15538900E-01, -.12511400E+00, 0.71250800E-01, -.80031100E-02, 0.20034900E-02, -.38619900E-03, 0.43926400E-03, 0.45462800E-01, 0.31212200E-01, -.96886200E-04, -.18024700E-01, -.20152200E-01, -.28685000E-01, -.18148300E+00, 0.84208600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
    },
    {
        { -.14039900E+07, 0.68764600E+06, 0.73977800E+06, 0.68221900E+06, 0.18055300E+06, 0.21331800E+06, 0.10450200E+06, -.34927200E+06, 0.15189200E+06, 0.19851500E+06, 0.48897200E+06, 0.87350300E+06, -.42813300E+06, -.57704600E+06, -.43339600E+06, -.10623100E+06, -.12329000E+06, -.67566000E+05, 0.22367900E+06, -.76592500E+05, -.12189200E+06, -.29619600E+06, 0.15577800E+06, -.75654400E+05, -.11284700E+06, -.75701900E+05, -.17911900E+05, -.19887900E+05, -.13632700E+05, 0.37394700E+05, -.16112800E+05, -.19981100E+05, -.50855200E+05, 0.10216800E+07, -.50206900E+06, -.75838800E+06, -.48987200E+06, -.13421600E+06, -.12557900E+06, -.92628100E+05, 0.22773100E+06, -.12625700E+06, -.13175000E+06, -.30663600E+06, -.10871100E+07, 0.52896700E+06, 0.67017000E+06, 0.52607700E+06, 0.13494500E+06, 0.14000500E+06, 0.90161400E+05, -.28757000E+06, 0.78403900E+05, 0.13961400E+06, 0.33942200E+06, -.22034000E+07, 0.10703900E+07, 0.15788900E+07, 0.10674400E+07, 0.23345000E+06, 0.27021200E+06, 0.21005600E+06, -.52897700E+06, 0.22254600E+06, 0.27041000E+06, 0.72811700E+06, 0.91604300E+06, -.44919500E+06, -.67351400E+06, -.43855100E+06, -.12566600E+06, -.11280400E+06, -.84874200E+05, 0.19315800E+06, -.12377100E+06, -.11958100E+06, -.26135900E+06, 0.78172100E+06, -.37820000E+06, -.49997200E+06, -.38595600E+06, -.65226100E+05, -.58221500E+05, -.10311500E+06, 0.16439300E+06, -.10798400E+06, -.64449300E+05, -.24560000E+06, -.12682100E+07, 0.61772800E+06, 0.87810100E+06, 0.61344400E+06, 0.16005400E+06, 0.19293200E+06, 0.65068900E+05, -.37605100E+06, 0.98466600E+05, 0.18655100E+06, 0.44446700E+06, -.35064300E+06, 0.16554400E+06, 0.24578100E+06, 0.17207500E+06, 0.29685100E+05, -.87299200E+04, 0.60530600E+05, -.65232300E+05, 0.75715100E+05, 0.12338900E+04, 0.59240800E+05, 0.16956700E+07, -.82286000E+06, -.14583100E+07, -.82385300E+06, -.17288600E+06, -.14746800E+06, -.18749000E+06, 0.42990000E+06, -.11649000E+06, -.17727500E+06, -.39884500E+06, 0.15915800E+07, -.77576200E+06, -.11172100E+07, -.77484200E+06, -.17180400E+06, -.19350000E+06, -.13754000E+06, 0.38188500E+06, -.21565700E+06, -.19490900E+06, -.53826800E+06, 0.15933900E+07, -.77889600E+06, -.11229800E+07, -.77856600E+06, -.19689600E+06, -.23756600E+06, -.95145200E+05, 0.44544000E+06, -.12434600E+06, -.23322100E+06, -.55873300E+06, -.51801100E+06, 0.25415300E+06, 0.34797300E+06, 0.25800000E+06, 0.57973400E+05, 0.70283900E+05, 0.42737000E+05, -.13023700E+06, 0.49905300E+05, 0.68825700E+05, 0.18116600E+06, -.16336800E+07, 0.79675000E+06, 0.10629700E+07, 0.79910500E+06, 0.19091900E+06, 0.21543600E+06, 0.11184900E+06, -.44263100E+06, 0.18579800E+06, 0.21356900E+06, 0.56060300E+06, -.24673300E+07, 0.12055500E+07, 0.15049800E+07, 0.11951600E+07, 0.30188500E+06, 0.34219900E+06, 0.20276300E+06, -.61457800E+06, 0.24477000E+06, 0.33144800E+06, 0.82355900E+06, -.47835900E+06, 0.22547700E+06, 0.34535600E+06, 0.23364300E+06, 0.32390900E+05, -.23869300E+04, 0.80201500E+05, -.87529300E+05, 0.99049200E+05, 0.26684700E+04, 0.12911300E+06, -.21247900E+07, 0.10307400E+07, 0.13816200E+07, 0.10412700E+07, 0.20660900E+06, 0.20988500E+06, 0.24546900E+06, -.46792200E+06, 0.25379700E+06, 0.21729700E+06, 0.67377500E+06, -.18947200E+07, 0.91760500E+06, 0.15004100E+07, 0.92324200E+06, 0.14832700E+06, 0.16134100E+06, 0.23690600E+06, -.38738500E+06, 0.27399700E+06, 0.16508700E+06, 0.62921300E+06, -.14875000E+07, 0.72188800E+06, 0.10799900E+07, 0.72243000E+06, 0.17153600E+06, 0.18770300E+06, 0.13227600E+06, -.36725100E+06, 0.13132200E+06, 0.19091100E+06, 0.47878100E+06, 0.41300700E+06, 0.30419700E+04, 0.14183900E+04, 0.72743900E+05, 0.19915600E+06, 0.11229500E+06, -.37188600E+05, -.21449100E+06, 0.18243600E+06, 0.17062400E+05, 0.38786000E+06, 0.28214500E+06, -.12224800E+05, 0.46674500E+04, -.37630400E+05, 0.40964600E+05, 0.54286600E+05, -.36944800E+06, 0.13877100E+06, 0.20156800E+06, -.30467100E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.75504100E-02, -.27189800E+04, -.14518800E+05, 0.58011500E+04, -.43816400E+05, -.21946700E+05, 0.13610600E+05, 0.46510200E+04, 0.16853400E+05, -.22666100E+05, 0.43755600E+05, 0.18352400E+05, -.84306900E+04, 0.21445600E+04, -.10086400E+05, 0.18379300E+05, 0.79780400E+04, -.88678900E+04, -.23413800E+04, -.16610200E+05, 0.96666900E+04, -.32735400E+05, -.22081300E+04, 0.14300500E+04, 0.18117400E+04, 0.46154900E+03, 0.82757900E+04, 0.40518700E+04, -.20900000E+04, -.58333300E+03, -.16421300E+04, 0.39425500E+04, -.49735200E+04, -.71322300E+05, 0.35731200E+05, 0.33772500E+05, 0.29537600E+05, 0.56689400E+05, 0.36674200E+05, -.18053400E+05, -.33469200E+05, -.78554100E+04, 0.36851500E+05, -.10165900E+05, 0.11619700E+05, -.77361400E+04, -.14963700E+05, -.68342000E+03, -.47329000E+05, -.25353000E+05, 0.10381800E+05, 0.11314600E+04, 0.94891200E+04, -.24270200E+05, 0.36785100E+05, -.19969300E+05, 0.47561800E+04, 0.13339700E+05, 0.20034000E+05, -.82537100E+05, -.23436000E+05, 0.15493300E+05, -.16139400E+04, 0.25851400E+05, -.26177200E+05, 0.80107900E+05, -.91514600E+05, 0.46275700E+05, 0.40050600E+05, 0.40061800E+05, 0.53223400E+05, 0.34385700E+05, -.13285500E+05, -.32789300E+05, -.99282300E+03, 0.34826400E+05, 0.55483100E+03, 0.51649500E+05, -.24128400E+05, -.11460600E+05, -.27229000E+05, 0.17662100E+05, -.31335700E+04, -.26736300E+04, 0.17225300E+05, -.13373800E+05, -.12316700E+04, -.53434100E+05, -.20734800E+05, 0.82157100E+04, -.11202900E+05, 0.16428400E+05, -.52189100E+05, -.29235600E+05, 0.26290200E+05, 0.11020200E+05, 0.35023700E+05, -.29771200E+05, 0.49031100E+05, -.26736800E+05, 0.13201900E+05, -.16436600E+05, 0.14328900E+05, -.29923300E+05, -.16443800E+05, 0.39055500E+04, -.17580500E+05, 0.82843000E+04, -.11624100E+05, 0.41996000E+05, -.55266200E+05, 0.30800500E+05, 0.23510600E+05, 0.20594400E+05, 0.10966100E+06, 0.49982000E+05, -.16025400E+05, -.56633700E+04, -.12726500E+05, 0.48395000E+05, -.69983400E+05, -.18767800E+04, 0.41810800E+04, 0.71454000E+04, -.52375500E+04, 0.80452100E+05, 0.41944600E+05, -.26722800E+05, -.45064900E+04, -.19895800E+05, 0.41354500E+05, -.56714200E+05, 0.22223600E+05, -.89649200E+04, 0.12141100E+05, -.16313200E+05, 0.65288700E+05, 0.41803600E+05, -.37921500E+05, -.20412800E+05, -.42006300E+05, 0.41736200E+05, -.58903700E+05, -.32542000E+05, 0.16145700E+05, 0.49756900E+04, 0.16538600E+05, -.65866800E+04, 0.50456900E+03, 0.48559800E+04, -.35488300E+04, 0.13507800E+05, -.13663600E+04, 0.28505100E+05, 0.17005000E+05, -.11277900E+05, -.11551200E+05, -.33125100E+04, -.78467700E+05, -.44034000E+05, 0.26359900E+05, 0.86179100E+04, 0.18419600E+05, -.43753600E+05, 0.48483300E+05, 0.39652200E+05, -.25246600E+05, -.25171400E+05, -.85171200E+04, -.10018200E+06, -.50046300E+05, 0.24603400E+05, 0.13035900E+05, 0.20863600E+05, -.50248100E+05, 0.67305600E+05, -.48167200E+05, 0.23563800E+05, -.68780400E+04, 0.25716100E+05, -.31093100E+05, -.14205200E+05, 0.65875700E+04, -.21445400E+05, 0.13743000E+05, -.97618800E+04, 0.51012200E+05, -.84581500E+05, 0.37703800E+05, 0.14060600E+05, 0.48411400E+05, -.60686300E+05, -.70718500E+04, 0.12300300E+05, -.22806400E+05, 0.35620900E+05, -.11248100E+05, 0.11807900E+06, -.73471400E+05, 0.32696800E+05, 0.38168200E+05, 0.43805300E+05, -.83712100E+05, -.20809400E+05, 0.15974600E+05, -.22459200E+05, 0.27148900E+05, -.21327500E+05, 0.99289200E+05, 0.30601100E+05, -.18550500E+05, -.17344000E+05, -.90460100E+04, -.79729400E+05, -.40994000E+05, 0.20564900E+05, 0.84578900E+04, 0.12896100E+05, -.39612500E+05, 0.43917700E+05, -.48459100E+04, 0.13153000E+05, 0.96051000E+05, 0.36792000E+04, 0.51009300E+05, 0.11994900E+04, 0.31127200E+05, -.58026800E+05, -.32514400E+05, -.41528100E+05, -.74242700E+04, -.33427800E+04, -.62317000E+04, -.56907500E+05, 0.97561100E+05, -.49528200E+04, -.59242500E+04, 0.12960500E+05, -.28161400E+05, -.25312900E+05, -.76878900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12180900E-01, -.26414700E+00, 0.19942200E+05, -.45357500E+03, 0.56565600E+04, 0.84947800E+04, -.40297000E+03, 0.10844700E+04, -.30626200E+04, 0.44781100E+04, -.28117900E+04, 0.91553600E+04, -.53570500E+04, -.39757200E+04, -.45310900E+04, -.21526300E+04, -.69247100E+04, 0.78924200E+03, 0.29343100E+04, -.43073700E+03, -.49184800E+04, -.29345700E+04, -.18556100E+04, 0.77411400E+03, -.84963900E+03, 0.97840600E+03, -.12729500E+04, -.19701900E+04, 0.44621600E+03, -.74077800E+03, 0.74735600E+03, -.12546100E+04, 0.14581400E+04, -.12561500E+05, 0.50475800E+04, 0.23006600E+03, 0.67426700E+04, -.11298900E+04, -.64070300E+04, 0.13419900E+04, -.30241900E+04, 0.31259900E+04, -.36331900E+04, 0.84517100E+04, 0.20349200E+05, -.91899900E+04, 0.85016900E+04, -.10575200E+05, 0.11785500E+05, 0.16140800E+05, -.56066700E+04, 0.53889300E+04, -.95451900E+04, 0.11069900E+05, -.14456500E+05, -.41166800E+05, 0.21037800E+05, 0.16682200E+05, 0.19798300E+05, 0.52304900E+04, 0.13097300E+05, 0.16853800E+04, -.98669700E+04, 0.68556900E+04, 0.85090300E+04, 0.15067800E+05, -.91732100E+04, 0.31430900E+04, 0.11989900E+04, 0.50187300E+04, 0.67853800E+03, -.24335100E+04, -.97257000E+03, -.34311900E+04, 0.66389000E+03, -.29625000E+03, 0.64912800E+04, 0.15146100E+05, -.81400500E+04, -.96838300E+04, -.74758700E+04, -.64102200E+04, -.74541900E+04, -.26476300E+03, 0.18170200E+04, -.12622600E+04, -.51856700E+04, -.23722300E+04, 0.69600700E+04, -.17649900E+04, 0.63351600E+04, -.39532600E+04, 0.60717800E+04, 0.14011500E+05, -.36368800E+04, -.19478100E+01, -.38603200E+04, 0.93135700E+04, -.60456000E+04, 0.69210400E+05, -.31881000E+05, 0.68462900E+04, -.34683400E+05, 0.27186700E+05, 0.34127300E+05, -.17768200E+05, 0.16360400E+05, -.24238200E+05, 0.25338300E+05, -.44806300E+05, -.21345900E+05, 0.76019100E+04, 0.25192800E+04, 0.11224700E+05, -.20032100E+05, -.27238300E+05, 0.66256700E+04, -.10428100E+05, 0.80965600E+04, -.18005300E+05, 0.21366000E+05, -.21898200E+05, 0.99033700E+04, -.57764000E+04, 0.11443900E+05, -.11496800E+05, -.20559300E+05, 0.58467200E+04, -.51079900E+04, 0.91302500E+04, -.13780900E+05, 0.15848600E+05, -.12488900E+05, 0.41104200E+04, -.41229900E+04, 0.66062600E+04, -.61902600E+04, -.17503500E+05, 0.46910300E+04, -.83092600E+03, 0.63057000E+04, -.11770900E+05, 0.82240200E+04, -.10116100E+05, 0.52891500E+04, 0.35288300E+04, 0.50456200E+04, 0.18036400E+04, 0.50521200E+04, -.62004200E+03, -.29626300E+04, 0.10622400E+04, 0.38295700E+04, 0.39651200E+04, 0.23579900E+05, -.10174400E+05, 0.26422700E+04, -.12191300E+05, 0.10431000E+05, 0.18838900E+05, -.51494100E+04, 0.56984100E+04, -.94563900E+04, 0.12746500E+05, -.16137800E+05, -.29121800E+04, 0.14701100E+04, 0.19659400E+05, 0.56681100E+03, 0.90436400E+04, 0.13166600E+05, 0.10568800E+04, 0.35702800E+04, -.30289600E+04, 0.67062800E+04, -.39652500E+04, 0.55414100E+05, -.24006900E+05, 0.11559300E+05, -.27837900E+05, 0.26414500E+05, 0.30315700E+05, -.14465400E+05, 0.15156700E+05, -.20628000E+05, 0.21764100E+05, -.38790600E+05, -.34711800E+05, 0.18355400E+05, 0.21631600E+05, 0.16905500E+05, 0.13455900E+05, 0.16899000E+05, 0.11810100E+04, -.36798400E+04, 0.39993800E+04, 0.11091600E+05, 0.76499500E+04, -.12231700E+05, 0.86827700E+04, 0.13187700E+05, 0.55649800E+04, 0.16667300E+05, 0.27734500E+05, -.70619000E+04, -.37385300E+04, -.33836700E+04, 0.19891900E+05, -.30629800E+04, 0.15845000E+05, -.63367200E+04, 0.44924700E+04, -.84116800E+04, 0.11261800E+05, 0.17227800E+05, -.33321500E+04, 0.67900700E+04, -.66402800E+04, 0.10820700E+05, -.12865900E+05, -.46513100E+04, -.86344700E+04, -.59833400E+04, -.33398600E+03, -.66881900E+04, 0.15741300E+04, -.65335400E+04, 0.63599000E+04, 0.12378700E+05, 0.75773800E+04, 0.20340000E+04, 0.65689000E+04, -.10536100E+04, 0.61552400E+04, -.74757200E+04, 0.23856000E+04, 0.11508700E+05, -.10264700E+05, 0.10663900E+05, 0.67333000E+04, -.49919000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.82562000E-02, 0.62236300E+00, 0.15138000E+01, -.67767700E+04, 0.34823000E+05, 0.31592600E+05, -.34654500E+05, -.57226500E+05, -.64937300E+05, 0.34948800E+05, -.29119200E+05, -.59212800E+05, 0.30509900E+05, -.17297900E+05, 0.30734800E+05, -.15132000E+05, -.78344100E+04, 0.23343300E+05, 0.26326100E+05, 0.61957800E+05, -.11294900E+05, 0.46718100E+05, -.81943400E+04, 0.42163300E+04, -.33172500E+04, 0.48468400E+04, -.34784300E+04, -.19886000E+04, 0.51735600E+04, 0.66741100E+04, 0.11187300E+05, -.29547000E+04, 0.72545400E+04, -.35296700E+05, 0.18657800E+05, -.40293200E+05, 0.24835700E+05, -.35362200E+05, -.24275000E+05, 0.38899900E+05, 0.53769300E+05, 0.75308800E+05, -.28103300E+05, 0.47568500E+05, -.16816400E+05, 0.73985300E+04, 0.27501800E+05, 0.24190200E+04, 0.22995300E+05, 0.20978100E+05, -.25499900E+05, -.53334400E+05, -.50555700E+05, 0.25211400E+05, -.15376900E+05, 0.20521800E+06, -.10282700E+06, 0.20444600E+05, -.11435000E+06, 0.45398400E+05, 0.11977900E+05, -.61402000E+05, -.54746200E+05, -.16877000E+06, 0.21282400E+05, -.14430800E+06, -.21729300E+05, 0.12144800E+05, -.39210300E+05, 0.17542000E+05, -.34077300E+05, -.26914700E+05, 0.37789600E+05, 0.52251400E+05, 0.67616700E+05, -.30250400E+05, 0.38130100E+05, -.10479900E+06, 0.52674900E+05, 0.14656300E+05, 0.54071600E+05, -.40580900E+04, -.23823500E+02, 0.24401700E+05, 0.12237500E+05, 0.55994800E+05, -.26861800E+04, 0.61382500E+05, 0.49848900E+05, -.26326800E+05, 0.41823400E+05, -.32005100E+05, 0.34937400E+05, 0.16824000E+05, -.30995200E+05, -.37775500E+05, -.90472500E+05, 0.24014400E+05, -.59841100E+05, -.13322400E+05, 0.43307600E+04, -.69587300E+03, 0.55467300E+04, -.17782600E+05, -.13190200E+05, -.20645200E+04, -.22609600E+05, -.54593800E+04, -.79242000E+04, 0.11568900E+05, -.11807300E+06, 0.61432300E+05, -.82999000E+05, 0.67255700E+05, -.35454500E+05, -.18515500E+05, 0.61191600E+05, 0.80978500E+05, 0.14612600E+06, -.31493100E+05, 0.10551900E+06, -.96202100E+05, 0.48837800E+05, -.20980900E+05, 0.55286500E+05, -.31483500E+05, -.10555200E+05, 0.44658700E+05, 0.46481500E+05, 0.99107500E+05, -.19604300E+05, 0.76580700E+05, -.72432200E+05, 0.38115700E+05, -.52951000E+05, 0.42401800E+05, -.44473600E+05, -.22651200E+05, 0.47443700E+05, 0.58046500E+05, 0.11641400E+06, -.30852800E+05, 0.79856200E+05, 0.60086200E+05, -.30400900E+05, 0.37966800E+04, -.30379100E+05, 0.52559000E+04, -.11654800E+04, -.13266700E+05, -.94396200E+04, -.40875600E+05, 0.15929500E+04, -.38423800E+05, 0.20840300E+05, -.11556300E+05, 0.37968100E+05, -.16493900E+05, 0.38207600E+05, 0.19790900E+05, -.34765300E+05, -.50112700E+05, -.82206600E+05, 0.28059000E+05, -.48923300E+05, 0.43903100E+05, -.22055400E+05, 0.34043000E+05, -.35149800E+05, 0.65574600E+05, 0.55677900E+05, -.72453700E+05, -.10614200E+06, -.14096500E+06, 0.63626900E+05, -.76456300E+05, 0.42034500E+05, -.24147500E+05, -.13698000E+05, -.22916500E+05, -.16175000E+05, -.78763100E+04, -.16207300E+05, -.24750700E+05, -.27726700E+05, -.20275400E+04, -.13398300E+05, 0.22353900E+06, -.11232500E+06, -.11299200E+05, -.11898900E+06, 0.28000800E+05, 0.13369700E+05, -.68677100E+05, -.58056500E+05, -.15706900E+06, 0.21624700E+05, -.14729900E+06, 0.28870400E+06, -.14606000E+06, -.13860100E+05, -.15261500E+06, 0.16713500E+05, -.18847000E+05, -.58447900E+05, -.31273300E+05, -.16296000E+06, -.62848200E+04, -.16237700E+06, 0.60070100E+05, -.31392700E+05, 0.42912400E+05, -.37341100E+05, 0.36076400E+05, 0.23501400E+05, -.50548400E+05, -.69318600E+05, -.10331500E+06, 0.32103600E+05, -.62388900E+05, -.21631900E+05, 0.26720900E+05, -.55971400E+05, -.25129300E+04, -.66236900E+04, -.35129800E+05, -.20263900E+05, 0.15711500E+05, 0.82609800E+04, -.16715400E+05, -.23715700E+05, -.66411100E+04, 0.28831200E+05, 0.10871300E+05, -.53058000E+05, 0.48953400E+05, -.24324700E+05, 0.22933600E+05, 0.28789200E+04, 0.26179600E+05, 0.18731100E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.27956900E-01, 0.41108900E+00, -.74800500E+00, 0.34106000E+00, -.17400500E+05, -.37006100E+05, 0.35742100E+05, 0.44344300E+05, 0.36354600E+05, -.40580200E+05, -.54472500E+04, 0.10567500E+05, -.51520100E+04, 0.86445700E+04, -.52953000E+04, 0.13670500E+05, 0.27520800E+05, -.23851500E+05, -.23050500E+05, -.26990100E+05, 0.27687700E+05, 0.46110200E+03, 0.11947600E+04, -.52184200E+03, 0.16363800E+03, -.59720200E+03, 0.22209000E+04, 0.63170100E+04, -.61703600E+04, -.67784300E+04, -.55257200E+04, 0.65973500E+04, 0.11162200E+04, -.93570000E+03, 0.15568400E+04, 0.15023100E+05, 0.45747500E+03, 0.27232800E+05, 0.49387300E+05, -.41684300E+05, -.39496200E+05, -.36045300E+05, 0.48552000E+05, 0.60986900E+04, -.19479300E+05, 0.90976800E+04, 0.69116300E+04, 0.97398500E+04, -.84161900E+04, -.36272000E+05, 0.36593000E+05, 0.39973600E+05, 0.39601300E+05, -.38459000E+05, -.30334400E+04, -.44097500E+05, 0.21309500E+05, 0.69740500E+04, 0.22048900E+05, -.25272800E+05, -.49580700E+05, 0.52271900E+05, 0.50113300E+05, 0.59015700E+05, -.50029900E+05, 0.37209600E+04, -.51725000E+04, 0.30647900E+04, 0.16083900E+05, 0.25773700E+04, 0.27037400E+05, 0.50650800E+05, -.43287500E+05, -.41699700E+05, -.35427700E+05, 0.49776600E+05, 0.88773300E+04, 0.84152900E+05, -.40997600E+05, -.29761800E+05, -.42082700E+05, -.38566600E+04, 0.17220400E+05, -.28028100E+05, -.10811600E+05, -.36631700E+05, 0.17555500E+05, -.24239900E+05, 0.27241300E+05, -.13991000E+05, -.24093100E+05, -.13620000E+05, -.26417500E+05, -.48700000E+05, 0.34965400E+05, 0.37104000E+05, 0.32117600E+05, -.49565100E+05, -.14777800E+05, -.81252300E+05, 0.39331900E+05, 0.42021900E+05, 0.40625000E+05, 0.22853900E+05, -.23039000E+05, 0.31855700E+05, 0.19107000E+05, 0.37935400E+05, -.23962700E+05, -.91077100E+02, 0.62932600E+05, -.30244100E+05, -.14838700E+05, -.31466200E+05, 0.17194900E+05, 0.77928800E+05, -.81206700E+05, -.80476300E+05, -.83067900E+05, 0.81509400E+05, 0.36866600E+04, -.21348100E+04, 0.14069000E+04, 0.11147900E+05, 0.10722700E+04, 0.24311200E+05, 0.56378800E+05, -.52508700E+05, -.52374900E+05, -.40571100E+05, 0.58327500E+05, 0.17333200E+05, -.35413400E+05, 0.17906400E+05, 0.33615000E+05, 0.17684700E+05, 0.37012400E+05, 0.61021900E+05, -.46693700E+05, -.51606600E+05, -.40378500E+05, 0.62242100E+05, 0.15930700E+05, -.16106700E+05, 0.77118300E+04, -.15985700E+04, 0.80572700E+04, -.58021400E+04, -.12989100E+05, 0.12447500E+05, 0.99463500E+04, 0.16075600E+05, -.13102000E+05, 0.40194700E+04, 0.37356100E+05, -.19567400E+05, -.21243300E+05, -.18676400E+05, -.28947700E+05, -.59974000E+05, 0.45707700E+05, 0.51302500E+05, 0.34053800E+05, -.61765600E+05, -.26254400E+05, -.90053600E+04, 0.46906700E+04, -.47486900E+04, 0.45001900E+04, -.36169100E+05, -.77615800E+05, 0.76259200E+05, 0.89802200E+05, 0.74583100E+05, -.84342100E+05, -.90817200E+04, -.12489600E+06, 0.60904100E+05, 0.58175600E+05, 0.62446700E+05, 0.23753700E+05, -.26237400E+05, 0.44850800E+05, 0.22211100E+05, 0.54154200E+05, -.28894600E+05, 0.20330800E+05, -.15073300E+06, 0.73451100E+05, 0.49657400E+05, 0.75380100E+05, -.46989400E+04, -.51572200E+05, 0.72088900E+05, 0.48993900E+05, 0.88595000E+05, -.53909000E+05, 0.43769400E+05, -.12603900E+06, 0.61594000E+05, 0.49355400E+05, 0.63020900E+05, -.45120600E+04, -.40903500E+05, 0.59688700E+05, 0.37214200E+05, 0.68803800E+05, -.41778700E+05, 0.22350000E+05, -.58608200E+04, 0.22942200E+04, -.42865500E+04, 0.29304600E+04, -.23220700E+05, -.60440700E+05, 0.58847000E+05, 0.66345000E+05, 0.53406500E+05, -.63792500E+05, -.12519700E+05, 0.22245200E+04, 0.23722100E+05, 0.65762700E+04, -.50151200E+04, -.25182200E+05, -.14025600E+05, 0.42146100E+05, 0.16797200E+05, -.37302500E+05, 0.11995500E+05, -.45670400E+04, -.95574300E+04, -.25473100E+05, 0.13759500E+05, 0.76572300E+04, -.22205200E+05, -.19343000E+05, 0.15406300E+05, -.33916300E+05, -.37554000E+05, 0.39465100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.70193600E-01, 0.20142000E+00, 0.99843400E+00, -.89615900E-01, -.83754500E+00, -.30132100E+05, 0.38724100E+05, 0.70090400E+05, 0.39363500E+05, -.31692100E+05, -.18973100E+05, -.37975500E+05, 0.20673700E+05, 0.47839300E+04, 0.19008200E+05, 0.73615500E+04, 0.20261600E+05, -.17108800E+05, -.42132200E+05, -.98750600E+04, 0.19262500E+05, 0.23578300E+05, -.21338500E+04, 0.14431700E+04, -.25912700E+04, 0.10666200E+04, -.23606800E+03, 0.52422800E+04, -.59875400E+04, -.10899100E+05, -.42465200E+04, 0.53006400E+04, 0.38388800E+04, -.18630000E+05, 0.13107900E+05, -.10024800E+05, 0.93269100E+04, 0.85188900E+04, 0.25213100E+05, -.28449900E+05, -.49649300E+05, -.17106100E+05, 0.23469800E+05, 0.16096200E+05, 0.25226600E+04, -.39282000E+04, 0.85130400E+04, -.12614000E+04, 0.38372800E+04, -.29442000E+05, 0.37087300E+05, 0.69325000E+05, 0.34911300E+05, -.31049400E+05, -.19267400E+05, 0.86329500E+05, -.45024300E+05, 0.11629100E+05, -.43165500E+05, -.51937000E+04, -.45670200E+05, 0.44199900E+05, 0.10948300E+06, 0.23359400E+05, -.41389600E+05, -.68687200E+05, -.24752900E+04, 0.45242900E+04, -.14944900E+05, 0.12461900E+04, 0.69553200E+04, 0.26322800E+05, -.33218400E+05, -.50253500E+05, -.22148900E+05, 0.25101400E+05, 0.11885600E+05, 0.45390200E+04, 0.19297300E+03, -.13047300E+05, -.22593900E+04, -.60601300E+04, 0.18518200E+05, -.25634300E+05, -.47291300E+05, -.21988100E+05, 0.18491700E+05, 0.10715000E+05, 0.99052300E+05, -.53088900E+05, -.20687700E+05, -.49526300E+05, -.10804000E+05, -.32684400E+05, 0.14088000E+05, 0.54027200E+05, -.20286600E+04, -.31253200E+05, -.44854400E+05, -.47411300E+05, 0.17112900E+05, 0.31297500E+05, 0.23708700E+05, 0.18724000E+05, -.21782700E+05, 0.35442100E+05, 0.52279200E+05, 0.33381000E+05, -.25022000E+05, 0.10364100E+04, -.20702100E+05, 0.17406000E+05, -.53459100E+05, 0.10349100E+05, -.66941400E+04, 0.72402700E+05, -.81246700E+05, -.14529300E+06, -.53957600E+05, 0.72470300E+05, 0.60017200E+05, -.65397000E+05, 0.35015600E+05, 0.25358700E+04, 0.32687200E+05, 0.14890000E+04, 0.38604100E+05, -.38211800E+05, -.88088300E+05, -.17512800E+05, 0.38303600E+05, 0.51714900E+05, -.11350400E+06, 0.60870100E+05, 0.20325500E+05, 0.56789300E+05, 0.16210200E+05, 0.38611900E+05, -.21872400E+05, -.72616100E+05, -.22227900E+04, 0.37049100E+05, 0.52196000E+05, 0.27517800E+05, -.14756700E+05, -.34709700E+04, -.13766100E+05, -.44049200E+04, -.11658100E+05, 0.84110100E+04, 0.24262500E+05, 0.33732000E+04, -.10646900E+05, -.15883700E+05, 0.98852800E+05, -.53497800E+05, -.18921200E+05, -.49430900E+05, -.39989500E+04, -.36652400E+05, 0.24359500E+05, 0.76570300E+05, 0.77214400E+04, -.36813000E+05, -.55242000E+05, 0.63903200E+04, -.29721200E+04, 0.15100800E+05, -.31910000E+04, 0.56358000E+03, -.64379400E+05, 0.80523900E+05, 0.14342600E+06, 0.72124800E+05, -.67269400E+05, -.43210700E+05, -.85664000E+05, 0.34198500E+05, 0.42779900E+05, 0.42835100E+05, 0.20363800E+05, -.30008300E+05, 0.55493500E+05, 0.70143900E+05, 0.53590900E+05, -.35247900E+05, 0.15319600E+05, -.57285600E+04, -.15399500E+04, 0.34820900E+05, 0.28408900E+04, 0.85097300E+04, -.54180300E+05, 0.73121400E+05, 0.13130200E+06, 0.60608600E+05, -.53915500E+05, -.33227400E+05, 0.41945300E+05, -.27428700E+05, 0.41431800E+05, -.20973700E+05, 0.58257200E+04, -.45087500E+05, 0.57161500E+05, 0.11909900E+06, 0.32132800E+05, -.41354700E+05, -.59767600E+05, 0.24160200E+05, -.15761800E+05, 0.23263400E+05, -.12079800E+05, 0.72281800E+03, -.49327300E+05, 0.56726400E+05, 0.10511800E+06, 0.41497700E+05, -.50403800E+05, -.37701400E+05, -.66611200E+04, 0.15773500E+05, -.33565600E+05, -.74723500E+04, -.54984600E+05, -.14887500E+05, 0.27189900E+05, 0.49461100E+05, -.41311700E+05, 0.36860500E+05, -.10483700E+05, -.26921600E+04, -.37302500E+05, 0.41318000E+05, -.31609900E+05, -.27150300E+05, -.17034000E+05, 0.22910000E+05, -.30875100E+05, -.32122300E+05, 0.10768900E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15898800E-01, -.98607300E+00, -.55387400E+00, -.32064200E+00, 0.54654200E+00, -.33087500E+00, 0.74802200E+04, 0.12502800E+05, 0.10632900E+03, 0.29863200E+04, -.45015000E+04, -.16227600E+05, 0.84739400E+04, -.26555700E+04, 0.80536900E+04, 0.11270600E+04, -.96499600E+03, -.33679900E+04, -.11271700E+05, 0.61867300E+04, -.27023600E+04, 0.89398000E+04, -.32064800E+04, 0.16795800E+04, -.54778200E+03, 0.16040700E+04, 0.57935400E+03, 0.14777800E+03, -.90892100E+03, -.22994400E+04, 0.11549000E+04, -.23622900E+03, 0.16821200E+04, -.21806600E+05, 0.11379500E+05, -.58568100E+04, 0.10872800E+05, 0.44302900E+04, -.12575200E+04, -.68833900E+04, -.16981600E+05, 0.89108300E+04, -.37104500E+04, 0.10412700E+05, 0.15725700E+05, -.83351200E+04, -.12699900E+04, -.78624300E+04, -.20476300E+04, 0.24233800E+04, 0.27518400E+04, 0.12326300E+05, -.58891100E+04, 0.41731900E+04, -.84268000E+04, 0.46943600E+05, -.23623000E+05, 0.85502100E+04, -.23470400E+05, -.56655300E+04, -.42884300E+04, 0.10356400E+05, 0.31653000E+05, -.15353600E+05, 0.11943900E+04, -.25946000E+05, -.19295600E+05, 0.10336900E+05, -.57986000E+04, 0.96266800E+04, 0.38697300E+04, -.97517300E+03, -.71964700E+04, -.15758800E+05, 0.79123200E+04, -.30811800E+04, 0.10036700E+05, -.22001000E+05, 0.11210000E+05, 0.28667400E+04, 0.10971300E+05, 0.14199200E+04, -.26503900E+04, -.62221800E+03, -.12530300E+05, 0.62014600E+04, -.38136200E+04, 0.78867800E+04, 0.43423600E+05, -.22593000E+05, -.52634800E+04, -.21711600E+05, -.44198700E+04, -.72891300E+03, 0.69206000E+03, 0.12364500E+05, -.17391500E+05, 0.21384500E+04, -.18400200E+05, 0.29485600E+05, -.16111100E+05, -.10390300E+05, -.14750100E+05, -.52512200E+04, 0.77651200E+04, -.47053500E+04, 0.91901200E+04, -.99113800E+04, 0.72158900E+04, -.30123100E+04, -.53898200E+05, 0.28531500E+05, -.11514200E+05, 0.26952600E+05, 0.83150200E+04, 0.39670300E+03, -.72461800E+04, -.28181300E+05, 0.21554900E+05, -.47855700E+04, 0.27763500E+05, -.44128100E+05, 0.22598300E+05, 0.22440800E+04, 0.22092000E+05, 0.67743400E+04, 0.23956600E+04, -.71356800E+04, -.22954600E+05, 0.14408800E+05, -.16381500E+04, 0.20564800E+05, -.41629300E+05, 0.21928400E+05, -.70865200E+03, 0.20713100E+05, 0.60434000E+04, 0.17444100E+04, -.60507100E+04, -.19575300E+05, 0.16082000E+05, -.21797400E+04, 0.19203400E+05, 0.10360800E+05, -.51892000E+04, 0.15151700E+04, -.51589000E+04, -.35583300E+03, 0.72125200E+03, 0.16450500E+04, 0.69156000E+04, -.38604400E+04, 0.17604900E+04, -.55219300E+04, 0.48189100E+05, -.24882700E+05, -.69356200E+04, -.24083900E+05, -.45509100E+04, 0.81762300E+03, 0.15362700E+04, 0.15997900E+05, -.17961700E+05, 0.41673200E+04, -.21339600E+05, 0.15366600E+05, -.77202200E+04, 0.59336800E+04, -.76949900E+04, -.21963300E+04, -.20278000E+04, 0.14419600E+05, 0.26670200E+05, -.59233900E+04, 0.41269400E+04, -.15397500E+05, 0.31976700E+05, -.17879600E+05, -.14471500E+05, -.15995900E+05, -.67315000E+04, 0.47103800E+04, -.18268800E+04, 0.14948600E+05, -.87872000E+04, 0.47346600E+04, -.48236900E+04, 0.40453200E+05, -.20578800E+05, 0.18193800E+04, -.20162100E+05, -.41281700E+04, 0.21373300E+04, 0.86735900E+04, 0.33746500E+05, -.11295400E+05, 0.63013300E+04, -.19633100E+05, 0.67566500E+05, -.35037100E+05, 0.22014200E+04, -.33779200E+05, -.10088500E+05, -.37098100E+04, 0.86551500E+04, 0.40172800E+05, -.18828900E+05, 0.13547600E+04, -.29935700E+05, 0.27409900E+05, -.14524200E+05, 0.70091100E+04, -.13705400E+05, -.52396200E+04, -.13030400E+04, 0.92219800E+04, 0.21870900E+05, -.96868500E+04, 0.24552400E+04, -.14482900E+05, -.84588300E+04, -.94541400E+03, 0.17868800E+04, -.10286900E+04, -.48781900E+04, -.12884800E+04, -.35308200E+04, 0.30348700E+04, -.97664900E+04, 0.70198600E+04, -.57066100E+04, 0.27243000E+03, -.31115000E+04, 0.57991900E+04, 0.34882700E+04, -.63120200E+03, -.64859300E+03, 0.35360000E+04, -.45796500E+04, 0.31505700E+03, 0.52468800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.52647800E+00, -.43326400E+00, -.38584800E+01, -.26683300E+01, -.48777100E+01, 0.35104600E+01, -.52783500E+01, -.10832400E+06, -.13956600E+06, 0.47683900E+04, -.64292900E+05, 0.64181900E+05, -.35627700E+05, 0.38132500E+05, -.32194400E+05, 0.15795600E+04, 0.25027900E+05, -.25188900E+05, 0.69438600E+05, 0.65936600E+05, 0.17547600E+05, 0.31904000E+05, -.89952300E+04, 0.38258500E+04, 0.15518600E+05, 0.44993100E+04, 0.22971800E+04, 0.47748800E+04, -.29985500E+04, 0.10824200E+05, 0.17062000E+05, 0.36390600E+04, 0.13092900E+05, -.66538800E+05, 0.26799900E+05, 0.12995900E+06, 0.33116600E+05, 0.38390400E+05, 0.85113900E+05, -.60138300E+05, 0.32755700E+05, 0.80035800E+05, 0.72469700E+05, 0.11686800E+06, -.12266000E+06, 0.65018000E+05, 0.26594800E+05, 0.61362900E+05, 0.20066100E+05, 0.15066900E+05, 0.65039600E+04, -.11920700E+06, -.76471400E+05, 0.17264500E+05, -.14139800E+05, -.64624600E+05, 0.35056700E+05, -.14214900E+06, 0.32309900E+05, 0.29670800E+04, -.24221000E+05, 0.14621800E+05, -.18495900E+06, -.21445700E+06, -.10020600E+05, -.92866800E+05, -.11481300E+06, 0.50795000E+05, 0.14297400E+06, 0.57261200E+05, 0.47891400E+05, 0.91930900E+05, -.57654800E+05, 0.22381300E+05, 0.79092000E+05, 0.78678300E+05, 0.12700500E+06, 0.15047300E+06, -.78000400E+05, -.18549400E+05, -.75302700E+05, -.17417200E+05, -.65127700E+04, -.23432500E+04, 0.10110600E+06, 0.39111100E+05, -.99060600E+04, -.13509200E+05, 0.13527300E+05, 0.77716300E+03, -.91164200E+05, -.67477400E+04, -.15414400E+05, -.62488200E+05, 0.65234500E+05, -.56125400E+05, -.11270700E+06, -.50609300E+05, -.11075200E+06, -.67862400E+05, 0.44994200E+05, 0.35768000E+05, 0.33928100E+05, 0.37546400E+05, 0.99317800E+04, -.52480600E+04, -.64685300E+05, -.63608400E+04, 0.12353300E+05, -.51700300E+05, 0.17689600E+06, -.10130200E+06, 0.12213600E+06, -.88460400E+05, -.26092400E+05, -.59150000E+03, -.30407600E+05, 0.20201300E+06, 0.12597500E+06, -.59518600E+04, 0.62896200E+05, -.15477700E+06, 0.72562300E+05, 0.18057000E+06, 0.77412700E+05, 0.44403500E+05, 0.96087800E+05, -.63469600E+05, 0.57737500E+05, 0.15369000E+06, 0.81553500E+05, 0.16814500E+06, -.14519400E+05, -.19702100E+04, 0.12921100E+06, 0.70405600E+04, 0.29491300E+05, 0.83155900E+05, -.84829500E+05, 0.73254900E+05, 0.13907300E+06, 0.69078200E+05, 0.12474600E+06, -.57888900E+05, 0.30606400E+05, -.18736000E+05, 0.28976800E+05, 0.45736700E+04, -.95332900E+04, 0.12091400E+05, -.45227200E+05, -.37467200E+05, -.52541100E+04, -.94047400E+04, 0.77088500E+05, -.31155500E+05, -.11564700E+06, -.38540700E+05, -.33027200E+05, -.82459500E+05, 0.72874000E+05, -.65364500E+05, -.14745100E+06, -.68312200E+05, -.15346700E+06, -.77219700E+04, 0.35982200E+04, -.81432100E+05, 0.38359900E+04, -.12379100E+05, -.13468300E+05, 0.13110900E+05, -.20172800E+06, -.24398600E+06, -.46234600E+04, -.11365000E+06, -.73810000E+05, 0.51845200E+05, 0.23742500E+05, 0.36901000E+05, 0.33094900E+05, 0.96049200E+04, -.12387800E+05, -.87024300E+05, -.20609700E+05, 0.13059400E+05, -.38062200E+05, -.25433300E+06, 0.13215300E+06, -.12952400E+05, 0.12730000E+06, 0.33334000E+05, 0.15915600E+05, -.18284600E+04, -.24334500E+06, -.15409500E+06, 0.24935700E+05, -.99895700E+04, -.10450900E+05, 0.17157300E+05, -.18403000E+06, 0.52457000E+04, 0.87002500E+04, -.30485500E+05, -.22029300E+04, -.17262300E+06, -.19154500E+06, -.18438700E+05, -.10501400E+06, 0.19446700E+05, -.33458800E+04, -.11898800E+06, -.97198100E+04, -.16025100E+05, -.32636100E+05, 0.30132000E+05, -.11792000E+06, -.14234100E+06, -.25597300E+05, -.95890000E+05, -.25651000E+05, 0.74224100E+05, 0.23116200E+05, -.98707500E+04, 0.29348100E+05, -.91011400E+05, 0.48761900E+05, -.44207000E+05, -.31332400E+05, -.51485800E+05, -.31086200E+05, -.68673100E+05, 0.10864500E+06, -.96783300E+04, 0.27350500E+05, 0.81424900E+05, -.56971500E+05, 0.24784500E+05, -.47872400E+05, -.13398900E+05, 0.52967000E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14302200E-01, -.29707700E+00, -.78920400E+00, 0.60121500E-01, 0.57207900E+00, -.32263500E+00, 0.62675000E+00, 0.41117000E-01, -.11525300E+05, 0.21755600E+04, 0.47200100E+04, -.62092100E+04, 0.29080000E+04, -.15717300E+04, 0.31412000E+04, -.50927800E+03, -.18859000E+04, 0.29238400E+04, 0.24563000E+04, 0.12288200E+05, -.38572500E+04, -.18660400E+04, -.34670300E+04, 0.17145300E+04, -.18566200E+03, 0.17330200E+04, 0.55609800E+03, 0.49354800E+03, 0.21656000E+03, -.68198900E+03, 0.25879400E+04, 0.77553200E+02, 0.11355500E+04, -.37970000E+05, 0.18814400E+05, 0.59101500E+04, 0.19003100E+05, 0.66859900E+04, 0.39165000E+04, 0.44901400E+04, -.44603500E+04, 0.20706400E+05, 0.38865900E+03, 0.10876300E+05, 0.86916500E+04, -.42549200E+04, 0.17602800E+04, -.43473300E+04, 0.69330700E+03, 0.10313500E+04, -.13078400E+04, 0.24238200E+04, -.13151600E+05, 0.31309300E+04, 0.20189800E+03, 0.38740000E+05, -.19355600E+05, 0.82620200E+04, -.19370700E+05, -.11077000E+05, -.71798300E+04, -.37812800E+04, 0.80732500E+03, -.34224200E+05, -.45719000E+03, -.10826300E+05, -.32720300E+05, 0.16096500E+05, 0.48136900E+04, 0.16372700E+05, 0.60944000E+04, 0.44030100E+04, 0.33868600E+04, -.44593900E+04, 0.17226900E+05, 0.12632300E+04, 0.92067400E+04, -.18479600E+04, 0.96308900E+03, -.19831300E+04, 0.94168100E+03, -.13173500E+04, 0.48349400E+03, -.17056900E+03, -.15560800E+04, 0.64380500E+04, -.16250100E+04, -.23355600E+04, 0.21757000E+05, -.10582500E+05, -.10995500E+04, -.10878600E+05, -.26622500E+04, 0.39298400E+03, -.40953500E+04, -.12157300E+03, -.20419400E+05, 0.35923700E+04, -.28031200E+04, 0.10748000E+05, -.50530500E+04, -.67039000E+04, -.53699800E+04, 0.51450300E+04, 0.10895400E+04, 0.53142600E+03, 0.93172700E+04, -.39235200E+04, 0.17713900E+04, -.25599800E+04, -.52664900E+05, 0.25943300E+05, -.96400500E+04, 0.26330900E+05, 0.69885700E+04, 0.70789400E+04, 0.18845700E+04, -.14345900E+05, 0.31886800E+05, 0.14548000E+04, 0.17163200E+05, -.45750900E+05, 0.22716900E+05, 0.53289500E+04, 0.22859700E+05, 0.77640300E+04, 0.49501200E+04, 0.38109700E+04, -.80361100E+04, 0.26395700E+05, 0.26680500E+03, 0.14858000E+05, -.29674400E+05, 0.14411800E+05, 0.92902000E+03, 0.14897500E+05, 0.34635200E+04, -.81782200E+03, 0.61094600E+04, 0.84039500E+03, 0.27728600E+05, -.49058300E+04, 0.50392500E+04, 0.30448400E+04, -.14646100E+04, 0.86751300E+03, -.15355800E+04, 0.67172400E+03, 0.14095600E+04, -.17963100E+04, -.17033900E+04, -.71744600E+04, 0.25307900E+04, 0.12511700E+04, 0.40550600E+05, -.20084000E+05, -.58632300E+04, -.20281200E+05, -.61574200E+04, -.21815100E+04, -.46041700E+04, 0.53968100E+04, -.26878500E+05, 0.19376800E+04, -.11174600E+05, 0.29020600E+05, -.14491500E+05, 0.20768000E+04, -.14503300E+05, -.52136500E+04, -.27211000E+04, -.22775300E+04, 0.51389600E+04, -.31341500E+05, 0.22166400E+04, -.47538800E+04, 0.17115500E+05, -.81008000E+04, -.77501400E+04, -.85536100E+04, 0.55521300E+04, 0.19950800E+04, -.23355900E+03, 0.11351500E+05, -.71024000E+04, 0.27676400E+04, -.55424500E+04, 0.12069200E+05, -.60906300E+04, 0.63047400E+04, -.60730900E+04, 0.73371300E+03, -.20288100E+04, -.70024500E+03, 0.32670200E+04, -.21314100E+05, 0.31471100E+04, 0.18162800E+04, 0.66365500E+05, -.32871300E+05, -.15039200E+04, -.33185500E+05, -.11861400E+05, -.83897400E+04, -.54748600E+04, 0.10316800E+05, -.36859400E+05, -.19461000E+04, -.24443100E+05, 0.34215400E+05, -.16909700E+05, 0.26460100E+04, -.17107600E+05, -.51478300E+04, -.33457800E+04, -.31159700E+04, 0.58451100E+04, -.25359000E+05, 0.34553500E+03, -.10432000E+05, -.88498300E+04, 0.94287000E+04, 0.30780000E+04, -.88681300E+03, 0.17262100E+04, -.91435200E+04, 0.14070900E+04, -.17332500E+04, -.67262800E+04, -.40185600E+04, -.79112300E+04, -.19688800E+04, 0.28793600E+04, -.27165600E+04, 0.36203300E+04, 0.56864400E+04, -.70400900E+04, 0.69023900E+04, -.63570100E+04, 0.73741000E+03, 0.75340500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.61679700E-01, 0.60459900E-01, -.84057200E+00, 0.38873700E+00, -.28160300E+00, -.16380700E+00, 0.77240900E+00, 0.82893200E-01, 0.50890300E+00, -.84540100E+04, 0.12336300E+04, 0.49740200E+05, -.26566900E+05, 0.36798400E+05, -.24834100E+05, -.46625300E+04, -.11194900E+05, 0.48769800E+03, 0.10906000E+05, -.18225000E+05, -.41652800E+04, -.25128300E+05, 0.75841400E+04, -.41192100E+04, 0.84806600E+04, -.37925500E+04, -.26792800E+04, -.31826300E+04, 0.18780500E+03, 0.53877000E+03, -.34711800E+04, -.12964300E+04, -.35133800E+04, 0.44110600E+05, -.24771300E+05, 0.73812200E+05, -.22039200E+05, -.77724200E+04, -.11909900E+05, 0.15401200E+04, 0.73545100E+04, -.25149800E+05, -.19429200E+04, -.23982300E+05, -.10535800E+05, 0.73857100E+04, -.29981700E+05, 0.52658800E+04, 0.16555400E+05, 0.17156200E+05, -.30543300E+04, 0.29977000E+04, 0.58800700E+04, 0.62696700E+04, 0.26555600E+04, -.18325700E+06, 0.92672200E+05, -.99498600E+05, 0.91628000E+05, 0.22562300E+05, 0.39790800E+05, -.10952300E+04, -.41812700E+05, 0.62129000E+05, 0.19317000E+05, 0.91981000E+05, 0.38345100E+05, -.22245100E+05, 0.66337700E+05, -.19162100E+05, -.47899600E+04, -.61000300E+04, -.60164000E+03, 0.49165500E+04, -.24537300E+05, 0.24796700E+04, -.21723300E+05, 0.58201000E+05, -.30372200E+05, 0.16932700E+05, -.29083400E+05, -.10363900E+05, -.11101200E+05, -.20454400E+04, 0.10270100E+05, -.15979300E+05, -.37338500E+04, -.22515800E+05, -.71198300E+05, 0.39221900E+05, -.56660400E+05, 0.35599300E+05, 0.11777700E+05, 0.22002100E+05, 0.64222600E+03, -.91587900E+04, 0.32146700E+05, 0.95715000E+04, 0.33250900E+05, 0.48830900E+05, -.18638700E+05, -.19175700E+05, -.24411400E+05, 0.36850800E+05, 0.30843500E+05, -.12265000E+05, 0.19648200E+05, -.14307000E+05, 0.19686900E+05, -.44293600E+05, 0.15637100E+06, -.84658100E+05, 0.15369000E+06, -.78187500E+05, -.53187800E+05, -.59912200E+05, 0.90107700E+03, 0.95918700E+04, -.69873000E+05, -.30363200E+05, -.70071100E+05, 0.60216700E+05, -.32321400E+05, 0.83030400E+05, -.30124100E+05, -.23909600E+05, -.33779100E+05, 0.61338500E+04, 0.72908500E+04, -.26865600E+05, -.15484400E+05, -.28194500E+05, 0.79649400E+05, -.44327400E+05, 0.85300900E+05, -.39766300E+05, -.14848000E+05, -.29752500E+05, 0.27970100E+04, 0.13167000E+05, -.35694900E+05, -.13576600E+05, -.40333500E+05, -.39125700E+05, 0.20110900E+05, -.20938900E+05, 0.19549800E+05, 0.30691100E+04, 0.83557900E+04, -.23292700E+03, -.89615500E+04, 0.12700900E+05, 0.40500500E+04, 0.19579400E+05, -.33684500E+05, 0.20287500E+05, -.70117100E+05, 0.16836300E+05, 0.18883000E+05, 0.28897800E+05, -.49587200E+04, -.72946400E+03, 0.18175700E+05, 0.12491000E+05, 0.15136800E+05, -.63213200E+05, 0.31620900E+05, -.62066200E+05, 0.31613400E+05, 0.12629100E+05, 0.14370900E+05, 0.29852700E+04, -.42964800E+04, 0.28214100E+05, -.55977800E+04, 0.33317700E+05, 0.90981800E+04, 0.32649600E+04, -.13376200E+05, -.45448900E+04, 0.38472200E+05, 0.27500500E+05, -.43940800E+04, 0.16692000E+05, -.21843100E+04, 0.15425600E+05, -.27503100E+05, -.14331100E+06, 0.73930500E+05, -.59769600E+05, 0.71618300E+05, 0.24229900E+05, 0.28944000E+05, 0.27757100E+04, -.26238700E+05, 0.44791800E+05, 0.91012300E+04, 0.63750600E+05, -.19003000E+06, 0.10048400E+06, -.11431700E+06, 0.95012400E+05, 0.46141400E+05, 0.62509200E+05, -.81485500E+04, -.42854300E+05, 0.60095300E+05, 0.37764900E+05, 0.84109000E+05, -.72564900E+05, 0.39635500E+05, -.85409800E+05, 0.36282600E+05, 0.25729800E+05, 0.30786400E+05, -.18274200E+04, -.54312500E+04, 0.33020000E+05, 0.12497000E+05, 0.33569700E+05, 0.19696000E+05, -.35814400E+05, -.38145100E+04, 0.61628100E+03, -.35684900E+04, 0.15787400E+05, 0.16918900E+02, 0.20490100E+04, 0.29817900E+05, 0.13390000E+05, 0.24718500E+05, -.32137500E+04, 0.18399400E+05, 0.50474100E+04, -.10964600E+05, -.15649600E+05, 0.32567000E+05, -.28763600E+05, 0.23211200E+05, -.24064300E+04, -.11085700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12373900E+00, 0.47229100E+00, -.38929800E+01, 0.58370500E+00, 0.69040000E+00, 0.29211700E+00, -.11807900E+00, -.16612300E-01, -.87277900E+00, 0.86142200E-01, 0.47538000E+05, 0.83927000E+05, -.42961000E+05, 0.31384000E+05, -.42101300E+05, -.10930900E+04, -.74979400E+04, -.38382200E+04, 0.19068200E+05, -.27108600E+05, -.88882600E+04, -.86544400E+05, 0.10314600E+05, -.52513600E+04, 0.66099000E+04, -.51553000E+04, -.20705700E+04, -.18707800E+04, -.67243100E+03, 0.79255000E+03, -.42548400E+04, -.14984200E+04, -.12517400E+05, 0.50185900E+05, -.25138700E+05, 0.73018900E+05, -.25176800E+05, 0.41757700E+04, 0.21472500E+04, -.51892100E+04, 0.65085400E+04, -.28583500E+05, -.10305000E+04, -.88371600E+05, -.10845200E+05, 0.57708800E+04, -.27309100E+05, 0.54233500E+04, 0.15073000E+05, 0.55307100E+04, 0.26365900E+03, 0.51196300E+04, 0.59422900E+04, 0.50842600E+04, 0.58970500E+05, -.20589100E+06, 0.10229000E+06, -.83201800E+05, 0.10294900E+06, 0.40386000E+04, 0.30543000E+05, 0.43067000E+04, -.46836300E+05, 0.72104000E+05, 0.27283100E+05, 0.19628300E+06, 0.41159800E+05, -.21986200E+05, 0.67760400E+05, -.20642500E+05, 0.65817100E+04, 0.72203000E+04, -.59699800E+04, 0.51363400E+04, -.26686300E+05, 0.40548400E+04, -.81760100E+05, 0.86087500E+05, -.42007300E+05, 0.12094900E+05, -.43112700E+05, -.82236000E+04, 0.65244200E+03, -.10738000E+05, 0.96235700E+04, -.27399100E+05, -.18497700E+04, -.80645500E+05, -.10796100E+06, 0.55908500E+05, -.44083400E+05, 0.53982500E+05, 0.73342800E+04, 0.16764200E+05, 0.83688600E+04, -.13528100E+05, 0.43937900E+05, 0.15872800E+05, 0.10908200E+06, 0.37328700E+05, -.16832600E+05, -.24393600E+05, -.18681900E+05, 0.40122800E+05, 0.81304700E+04, -.37432700E+04, 0.25589300E+05, -.90552400E+04, 0.82660000E+04, 0.36612200E+05, 0.16347100E+06, -.84169300E+05, 0.13681900E+06, -.81726900E+05, -.38482200E+05, -.33238900E+05, -.82115300E+04, 0.77663000E+04, -.74830500E+05, -.27052800E+05, -.20017500E+06, 0.85730300E+05, -.43781200E+05, 0.65418800E+05, -.42798000E+05, -.16365700E+05, -.24957000E+05, -.50237400E+03, 0.13535300E+05, -.33176400E+05, -.22866000E+05, -.11939600E+06, 0.13315200E+06, -.69475500E+05, 0.66882300E+05, -.66820900E+05, -.65123500E+04, -.20015300E+05, -.94093300E+04, 0.20869700E+05, -.51836000E+05, -.19558800E+05, -.13533700E+06, -.66503100E+05, 0.33079300E+05, -.16571700E+05, 0.33299900E+05, 0.24039700E+04, 0.82770800E+04, 0.23359900E+04, -.14945000E+05, 0.19798800E+05, 0.84487100E+04, 0.58785100E+05, -.65706700E+05, 0.33662100E+05, -.52466600E+05, 0.32878900E+05, 0.12325400E+05, 0.18438300E+05, 0.50195800E+04, -.38936800E+04, 0.27088600E+05, 0.17822700E+05, 0.10490300E+06, -.43898200E+05, 0.22271700E+05, -.52853000E+05, 0.21921300E+05, 0.67448200E+04, 0.14811400E+05, 0.37575800E+02, -.29619900E+04, 0.19249400E+05, 0.12013200E+05, 0.12042700E+06, 0.16129100E+05, -.52000600E+04, -.16588300E+05, -.80826400E+04, 0.46710300E+05, 0.11039800E+05, -.24340800E+03, 0.27015700E+05, -.32954200E+04, 0.10199100E+05, 0.39392100E+05, -.19221500E+06, 0.94240600E+05, -.45203100E+05, 0.96261900E+05, 0.17447700E+05, 0.77329300E+04, 0.17809800E+05, -.25148800E+05, 0.66485500E+05, 0.93684800E+04, 0.18977200E+06, -.20355900E+06, 0.10311800E+06, -.10208900E+06, 0.10178900E+06, 0.29628900E+05, 0.44671500E+05, -.30692700E+04, -.45618400E+05, 0.67468500E+05, 0.40060000E+05, 0.19916600E+06, -.85628500E+05, 0.44044300E+05, -.70256200E+05, 0.42813200E+05, 0.18996400E+05, 0.20580700E+05, 0.39124500E+04, -.64987100E+04, 0.35425200E+05, 0.16592500E+05, 0.11524700E+06, 0.27485300E+05, -.28196700E+05, 0.14261800E+05, 0.41353200E+04, 0.54194200E+04, 0.27511300E+05, -.61489600E+04, -.75907000E+04, 0.37565500E+05, 0.11032700E+05, 0.31393600E+05, 0.11618700E+05, 0.10374500E+05, -.27016700E+04, 0.78439100E+04, -.21777600E+05, 0.25395400E+05, -.30857400E+05, 0.29919200E+05, 0.28514200E+04, -.40330700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.94387500E-01, 0.61325700E+00, 0.41647400E+01, 0.24725700E+00, -.43577400E+00, 0.12550900E+01, -.34142500E+01, 0.87213300E-01, -.29864100E+00, -.26802800E+01, -.64443200E+00, 0.20242700E+06, -.10068100E+06, 0.61678800E+05, -.10135400E+06, -.11260200E+05, -.10843700E+05, -.20202300E+05, 0.30502600E+05, -.74618700E+05, -.89933900E+04, -.98667400E+05, 0.46373400E+05, -.22907600E+05, 0.13244200E+05, -.23184700E+05, -.50849400E+04, -.22689800E+04, -.49939500E+04, 0.55934300E+04, -.17449800E+05, -.14911200E+04, -.21962400E+05, 0.30501700E+06, -.14976300E+06, 0.11481600E+06, -.15257000E+06, -.29223700E+05, -.15624700E+05, -.31718200E+05, 0.40808500E+05, -.11718400E+06, -.12354100E+05, -.14406200E+06, -.18325700E+06, 0.89581200E+05, -.11394900E+05, 0.91620900E+05, 0.16700500E+05, -.10758300E+05, 0.28765700E+05, -.18636700E+05, 0.69209300E+05, -.95370400E+04, 0.84270300E+05, -.58366300E+06, 0.29001300E+06, -.27376000E+06, 0.29183600E+06, 0.60928900E+05, 0.70003200E+05, 0.39464000E+05, -.93066100E+05, 0.21748300E+06, 0.55382100E+05, 0.29145200E+06, 0.26535400E+06, -.13085200E+06, 0.10332700E+06, -.13271500E+06, -.26724900E+05, -.12568700E+05, -.26717900E+05, 0.36749900E+05, -.10205900E+06, -.99054600E+04, -.12581300E+06, 0.19367100E+06, -.94144900E+05, 0.22724900E+05, -.96902200E+05, -.10354600E+05, 0.44592900E+04, -.27124500E+05, 0.24799700E+05, -.68991700E+05, 0.36710800E+04, -.88399300E+05, -.33658600E+06, 0.16629600E+06, -.93687400E+05, 0.16829200E+06, 0.25156000E+05, 0.22411600E+05, 0.33738600E+05, -.44830100E+05, 0.12858400E+06, 0.17265900E+05, 0.15779500E+06, -.19481000E+06, 0.92622500E+05, 0.12250000E+06, 0.97385400E+05, 0.12829700E+05, -.62711000E+05, 0.55660600E+05, -.31284300E+04, 0.74600600E+05, -.53204800E+05, 0.63578400E+05, 0.89715300E+06, -.44351500E+06, 0.24126400E+06, -.44856400E+06, -.98049200E+05, -.38639600E+05, -.99873400E+05, 0.10833800E+06, -.33842600E+06, -.25091200E+05, -.42626800E+06, 0.42996500E+06, -.21340800E+06, 0.11590100E+06, -.21491000E+06, -.41222500E+05, -.20006800E+05, -.43785600E+05, 0.59556400E+05, -.15818900E+06, -.15612500E+05, -.20076800E+06, 0.44003300E+06, -.21819100E+06, 0.13532400E+06, -.22025500E+06, -.32985300E+05, -.31680400E+05, -.42808700E+05, 0.60387200E+05, -.16590400E+06, -.25073100E+05, -.21041100E+06, -.13550100E+06, 0.67248200E+05, -.39236200E+05, 0.67801000E+05, 0.66514700E+04, 0.94544700E+04, 0.12791900E+05, -.20714400E+05, 0.48920700E+05, 0.76326400E+04, 0.65563500E+05, -.36834500E+06, 0.18102300E+06, -.73533400E+05, 0.18420200E+06, 0.31118000E+05, 0.56912700E+04, 0.44803900E+05, -.50544200E+05, 0.13435600E+06, 0.57140800E+04, 0.16702300E+06, -.30089000E+06, 0.15076800E+06, -.12801500E+06, 0.15041800E+06, 0.33187200E+05, 0.20286900E+05, 0.30189500E+05, -.37768700E+05, 0.11481900E+06, 0.13675800E+05, 0.14896100E+06, -.20971700E+06, 0.98748000E+05, 0.82674100E+05, 0.10483800E+06, 0.17981500E+05, -.47104100E+05, 0.52447000E+05, -.73448600E+04, 0.80587900E+05, -.41627700E+05, 0.77381300E+05, -.48513000E+06, 0.23788300E+06, -.11763300E+06, 0.24271700E+06, 0.33632100E+05, 0.11220600E+05, 0.56081700E+05, -.64374800E+05, 0.17879200E+06, 0.73369800E+04, 0.23227000E+06, -.72462600E+06, 0.35736600E+06, -.26175200E+06, 0.36232000E+06, 0.77446900E+05, 0.57566700E+05, 0.61898900E+05, -.11106100E+06, 0.26700400E+06, 0.43438700E+05, 0.35342200E+06, -.45447700E+06, 0.22461300E+06, -.13636700E+06, 0.22723700E+06, 0.49272400E+05, 0.23447500E+05, 0.47968000E+05, -.56915500E+05, 0.17081900E+06, 0.15768700E+05, 0.21686000E+06, 0.12028300E+06, -.61262500E+05, 0.10392800E+05, 0.10297600E+05, 0.25438100E+05, 0.64281300E+05, 0.41130100E+04, -.30370900E+05, 0.56737400E+05, 0.38835500E+05, 0.10266500E+06, -.11769300E+04, 0.38247000E+05, 0.10660900E+05, -.27293900E+04, -.64597300E+05, 0.46079600E+05, -.82245400E+05, 0.42880700E+05, -.58961700E+04, -.66946200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.62636100E-01, -.14121700E+00, 0.18136900E+00, -.28323600E+00, -.58909300E+00, -.50403800E-01, 0.20014700E+00, 0.28769100E-01, 0.59041900E+00, 0.64376400E+00, -.54984400E-01, -.81594100E-01, 0.13373200E+04, -.12228500E+05, -.21756100E+02, -.20246300E+03, 0.32012400E+03, -.65750200E+03, -.43644900E+03, 0.13310500E+04, 0.84056600E+03, -.86238200E+03, 0.21410800E+04, -.82775000E+03, -.27873600E+04, -.10702400E+04, 0.86206000E+03, 0.17604000E+04, -.10739600E+04, 0.61186900E+02, -.80047800E+03, 0.14678000E+04, -.12747100E+04, 0.81929100E+04, -.18868700E+04, -.20838900E+05, -.41070000E+04, 0.15352400E+04, 0.34301200E+04, -.39970900E+04, 0.17483400E+03, -.19699300E+04, 0.36411600E+04, -.55010000E+04, -.22959700E+05, 0.98447300E+04, 0.16155000E+05, 0.11480300E+05, -.74981400E+04, -.12446000E+05, 0.74174800E+04, -.29104500E+04, 0.84849000E+04, -.10458300E+05, 0.13284700E+05, 0.25805700E+05, -.13810500E+05, 0.15373400E+05, -.12902300E+05, 0.35673600E+03, -.52212700E+04, 0.44103200E+03, 0.85427400E+04, -.77695900E+04, -.51697700E+04, -.10550800E+05, 0.48366200E+04, -.12554500E+03, -.17713600E+05, -.24253700E+04, 0.77672200E+03, 0.18310100E+04, -.32698800E+04, -.50946700E+03, -.84877700E+03, 0.22398700E+04, -.38765300E+04, -.10759900E+05, 0.63480500E+04, -.46478300E+04, 0.53695000E+04, 0.26798200E+04, 0.47859900E+04, -.43402000E+03, -.35559800E+04, 0.15201300E+04, 0.47145300E+04, 0.28430400E+04, -.28519100E+04, -.12465500E+04, 0.17455800E+05, 0.14259200E+04, -.36010800E+04, -.96947900E+04, 0.52885600E+04, 0.82837200E+03, 0.38529600E+03, -.82501100E+04, 0.22524700E+04, -.62321700E+05, 0.26896600E+05, 0.29918900E+05, 0.31158100E+05, -.20062100E+05, -.30765800E+05, 0.18330700E+05, -.79545000E+04, 0.23323200E+05, -.25623000E+05, 0.36992500E+05, 0.29267700E+05, -.99730200E+04, -.47867600E+05, -.14632400E+05, 0.17357000E+05, 0.32435800E+05, -.16420500E+05, 0.23992800E+04, -.10325300E+05, 0.27112700E+05, -.18319400E+05, 0.17144100E+05, -.69517900E+04, -.25105700E+05, -.85615300E+04, 0.91299400E+04, 0.17486200E+05, -.99574400E+04, 0.60825800E+03, -.75117900E+04, 0.14997200E+05, -.11666600E+05, 0.90732600E+04, -.12173200E+04, -.25423300E+05, -.45734400E+04, 0.45019900E+04, 0.11060300E+05, -.71366100E+04, -.39319900E+03, -.24460700E+04, 0.96588100E+04, -.52969700E+04, 0.28783300E+04, -.20235500E+04, 0.68446300E+04, -.14313900E+04, 0.18363800E+03, -.88039900E+02, -.14186600E+03, 0.74454400E+03, -.16586700E+04, -.43032800E+03, -.69278000E+03, -.26257500E+05, 0.10574400E+05, 0.25278300E+05, 0.13132800E+05, -.84436800E+04, -.18099600E+05, 0.10841900E+05, -.29394200E+04, 0.10191900E+05, -.15327800E+05, 0.15430900E+05, -.73142600E+04, 0.36731300E+04, 0.16352100E+05, 0.36529100E+04, -.24436600E+04, -.71550200E+04, 0.41815100E+04, -.64537900E+03, 0.27758500E+04, -.61920200E+04, 0.36116100E+04, -.51151800E+05, 0.19878200E+05, 0.27486000E+05, 0.25573000E+05, -.18611700E+05, -.26095500E+05, 0.15097200E+05, -.81976800E+04, 0.19781500E+05, -.21628900E+05, 0.31717000E+05, 0.18589900E+05, -.11145400E+05, 0.15281300E+05, -.92715600E+04, -.52249800E+04, -.10746900E+05, 0.24997000E+04, 0.71419600E+04, -.32463400E+04, -.10077900E+05, -.56227600E+04, -.33996300E+04, -.23402400E+04, 0.31866000E+05, 0.17011400E+04, -.98597800E+04, -.21575400E+05, 0.10064600E+05, 0.53878400E+04, 0.46340100E+04, -.18308100E+05, 0.58545500E+04, -.22666600E+05, 0.88898800E+04, 0.27642300E+05, 0.11333100E+05, -.83902400E+04, -.17100800E+05, 0.10669400E+05, -.12228100E+04, 0.82689000E+04, -.14092600E+05, 0.12851300E+05, 0.54806800E+04, 0.10849000E+05, 0.21111500E+04, 0.62563700E+03, 0.23536500E+04, -.44304400E+04, 0.79055300E+04, -.29986000E+04, -.10193800E+05, -.48840000E+04, -.64109800E+03, 0.24919700E+04, -.69266300E+04, -.23091600E+04, 0.20001100E+04, -.32968700E+02, -.95590100E+04, 0.91092300E+04, -.89754900E+04, -.61591600E+04, 0.18352000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36224600E-01, -.14047200E+00, 0.23580100E+01, -.73815000E-01, -.17307900E+00, -.56064400E+00, 0.11060200E+01, -.74928900E-01, 0.28712500E+00, 0.14783200E+00, -.17088900E+00, -.15190900E+00, 0.69445500E+00, 0.18768900E+05, 0.96288100E+02, -.11664900E+04, -.85385400E+03, -.22085700E+03, -.27524700E+04, -.29043100E+04, -.47396300E+03, -.31595600E+04, 0.37374900E+03, -.16731300E+03, 0.45502600E+04, -.18822900E+03, -.11247600E+04, -.25619000E+04, 0.12389300E+04, 0.82283700E+03, 0.17827300E+02, -.22547300E+04, -.14325000E+04, 0.20339400E+05, -.99765700E+04, 0.27506100E+05, -.10120500E+05, -.92937100E+04, -.11335300E+05, 0.32161800E+04, 0.25612900E+04, -.62480100E+04, -.98342700E+04, -.17461700E+05, 0.38762300E+04, -.20910600E+04, -.15041000E+05, -.19374500E+04, 0.55454300E+04, 0.14548000E+05, -.60985800E+04, -.20850200E+04, -.19779600E+04, 0.12719000E+05, 0.44768800E+04, -.68201100E+05, 0.34008200E+05, -.44050300E+05, 0.34097900E+05, 0.12861800E+05, 0.68683400E+04, 0.61101000E+04, -.95243500E+04, 0.24358100E+05, 0.61394900E+04, 0.33108900E+05, 0.18714500E+05, -.92116300E+04, 0.24436300E+05, -.93233700E+04, -.84222500E+04, -.10547000E+05, 0.35206900E+04, 0.28024200E+04, -.52452000E+04, -.94325800E+04, -.16021600E+05, 0.13391800E+05, -.64208800E+04, 0.79532500E+04, -.66491600E+04, -.52525400E+03, -.60939800E+04, 0.48723400E+02, 0.42146900E+04, -.26923600E+04, -.60740400E+04, -.11939700E+05, -.76296400E+04, 0.37118600E+04, -.28543800E+05, 0.38146200E+04, 0.51214400E+04, 0.99845500E+04, -.41248500E+04, -.48085000E+03, 0.36064500E+04, 0.84290200E+04, 0.11694000E+05, 0.92508800E+05, -.46641600E+05, -.31979400E+05, -.46241900E+05, 0.46595100E+04, 0.46552000E+05, -.32333200E+05, -.30342500E+04, -.38069600E+05, 0.42197000E+05, -.13014600E+05, 0.36813900E+05, -.17985200E+05, 0.75794900E+05, -.18413600E+05, -.20342000E+05, -.47006500E+05, 0.16923600E+05, 0.19496000E+05, -.87678700E+04, -.41642600E+05, -.39585700E+05, 0.10571700E+05, -.52000000E+04, 0.40051500E+05, -.53329800E+04, -.12122800E+05, -.20565500E+05, 0.85817000E+04, 0.37544600E+04, -.17706200E+04, -.18096900E+05, -.16750900E+05, 0.14042700E+05, -.69537500E+04, 0.36442400E+05, -.68563600E+04, -.86754300E+04, -.11992600E+05, 0.46111000E+04, 0.69381800E+03, -.65284800E+04, -.96583000E+04, -.13654500E+05, 0.20245300E+04, -.10273300E+04, -.12282100E+05, -.10465600E+04, -.24773600E+03, -.68735300E+03, 0.62753800E+03, 0.22515600E+04, 0.15173300E+04, -.76484700E+03, 0.10117600E+04, 0.56518900E+04, -.30505900E+04, -.33419700E+05, -.28441700E+04, 0.10392000E+05, 0.20345300E+05, -.10470500E+05, -.16320200E+04, -.34056200E+04, 0.17605700E+05, 0.86741000E+04, -.36049800E+05, 0.18059800E+05, -.26899700E+05, 0.18043800E+05, 0.68846100E+04, 0.85425400E+04, 0.34416400E+03, -.74390700E+04, 0.12390400E+05, 0.71550000E+04, 0.22469300E+05, 0.38115600E+05, -.19568400E+05, -.22686600E+05, -.19045000E+05, 0.35600900E+04, 0.28366400E+05, -.15718300E+05, -.15384100E+04, -.16878900E+05, 0.25804700E+05, 0.69310600E+04, -.42827800E+05, 0.21012700E+05, -.26262100E+05, 0.21309200E+05, 0.44295400E+04, 0.11900100E+05, 0.11764500E+04, -.11608300E+05, 0.11748500E+05, 0.11441900E+05, 0.27966000E+05, -.52876900E+05, 0.26068700E+05, -.58020300E+05, 0.26432500E+05, 0.17714500E+05, 0.24840600E+05, -.25189700E+04, -.11261000E+05, 0.15703200E+05, 0.21712500E+05, 0.39300700E+05, -.10546300E+05, 0.50691700E+04, -.43028100E+05, 0.52740900E+04, 0.11459200E+05, 0.23524800E+05, -.10497300E+05, -.75697700E+04, 0.29985800E+04, 0.20291100E+05, 0.16785700E+05, 0.76408500E+03, -.18398300E+05, -.38067400E+04, 0.77647100E+03, -.13002000E+04, 0.14024400E+05, -.97209900E+04, 0.18498900E+04, 0.15821400E+05, 0.51206800E+04, 0.10853500E+05, -.30650800E+03, 0.11427500E+05, 0.20525700E+04, -.46844000E+04, -.31316200E+04, 0.15495400E+05, -.20529100E+05, 0.15028900E+05, 0.73515100E+04, -.35204600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.78925900E-01, 0.56381500E-01, 0.11720700E+01, 0.13797500E+00, -.75369800E+00, -.16404500E+00, -.12976300E+01, -.17635000E+00, 0.19612700E+01, 0.60532300E+00, -.43449400E+00, -.14662700E+00, 0.62999400E+00, 0.66731600E+00, -.29309000E+03, 0.67060900E+04, 0.89581100E+04, -.36545400E+04, -.30397200E+03, -.19556700E+04, 0.71094000E+04, -.77835900E+03, 0.48746200E+04, -.23464300E+04, -.26651400E+04, -.24331800E+04, 0.24590900E+03, 0.20496400E+04, -.14465000E+04, 0.10157200E+03, -.16939400E+04, 0.17463200E+04, -.23476600E+04, 0.18843200E+05, -.87860400E+04, -.12995600E+05, -.95933900E+04, 0.54547400E+04, 0.87740300E+04, -.57454300E+04, -.40351400E+02, -.51834600E+04, 0.64587900E+04, -.85623900E+04, -.30811200E+05, 0.14713400E+05, 0.15298900E+05, 0.15414600E+05, -.35516100E+04, -.14979400E+05, 0.85671700E+04, -.28841200E+04, 0.11218000E+05, -.13007400E+05, 0.16195800E+05, 0.19130100E+05, -.10114000E+05, -.27496800E+04, -.95590200E+04, -.73961500E+04, -.43549000E+04, -.74161000E+03, 0.19558700E+04, -.59701500E+04, -.41611700E+04, 0.16595500E+04, 0.68648700E+04, -.30475800E+04, -.79345200E+04, -.35602400E+04, 0.42625500E+04, 0.64512400E+04, -.13219900E+04, 0.19964500E+04, 0.38426100E+02, 0.46662700E+04, -.41131100E+04, 0.11856400E+05, -.51139500E+04, -.54366000E+04, -.60740200E+04, 0.39765800E+04, 0.80547500E+04, -.40708000E+04, 0.15848600E+04, -.28232700E+04, 0.75004600E+04, -.11461400E+05, -.24178000E+05, 0.11456700E+05, 0.14352200E+05, 0.12093400E+05, -.21849400E+04, -.11754100E+05, 0.90760200E+04, -.10590700E+04, 0.86678100E+04, -.87231700E+04, 0.39865800E+04, -.93510400E+05, 0.45162200E+05, 0.40216800E+05, 0.46721400E+05, -.74985300E+04, -.46662400E+05, 0.30701300E+05, -.17322800E+04, 0.36275300E+05, -.40545800E+05, 0.45053000E+05, 0.78038000E+05, -.37341900E+05, -.45741100E+05, -.39005700E+05, 0.55484000E+04, 0.34970600E+05, -.20408100E+05, 0.90427700E+04, -.22855800E+05, 0.29980600E+05, -.39975400E+05, 0.41527200E+05, -.20256500E+05, -.23363200E+05, -.20631600E+05, 0.31078500E+04, 0.14896400E+05, -.89411700E+04, 0.69609100E+04, -.10705900E+05, 0.11955700E+05, -.21837400E+05, 0.39775500E+05, -.19364400E+05, -.21265300E+05, -.20393700E+05, 0.69390700E+04, 0.16073000E+05, -.14252200E+05, -.71997700E+03, -.14976200E+05, 0.11608600E+05, -.10912400E+05, -.36406400E+04, 0.18610400E+04, 0.38046000E+03, 0.19240100E+04, -.33885300E+04, -.44085900E+04, 0.26817000E+04, -.42094100E+01, 0.18389400E+04, -.35628500E+04, 0.27165600E+04, -.51411100E+05, 0.24704400E+05, 0.25606800E+05, 0.25754700E+05, -.15056800E+04, -.17214300E+05, 0.12130800E+05, -.78645500E+04, 0.15653700E+05, -.13529100E+05, 0.19485600E+05, -.12968200E+05, 0.65526200E+04, 0.12827900E+05, 0.64259500E+04, 0.72759700E+03, -.40305600E+04, 0.22172400E+04, -.26127900E+04, 0.31548600E+04, -.33548400E+04, 0.63104300E+04, -.64546800E+05, 0.30225000E+05, 0.32266600E+05, 0.32238400E+05, -.64662700E+04, -.33963600E+05, 0.22211300E+05, -.13048100E+04, 0.25559100E+05, -.29776100E+05, 0.34089100E+05, -.17535000E+05, 0.72992600E+04, 0.11941600E+05, 0.90878200E+04, -.94138400E+04, -.15729200E+05, 0.92540700E+04, 0.16218100E+04, 0.52178500E+04, -.14448000E+05, 0.19932300E+05, -.21347200E+05, 0.91080200E+04, 0.16441600E+05, 0.10696100E+05, -.11556300E+05, -.22499200E+05, 0.10946500E+05, -.21194800E+04, 0.64977100E+04, -.19246900E+05, 0.25761400E+05, -.48015000E+05, 0.23116700E+05, 0.26941300E+05, 0.24006300E+05, -.27153000E+04, -.17969400E+05, 0.13331900E+05, -.20252200E+04, 0.16513700E+05, -.15053100E+05, 0.22464500E+05, 0.12632000E+05, 0.10453500E+05, 0.78358400E+04, 0.71623200E+03, 0.31781800E+04, -.45910900E+04, 0.99145800E+04, -.41707200E+04, -.10817200E+05, 0.42081500E+03, 0.30598300E+04, 0.25865400E+04, -.55991000E+04, 0.88561100E+03, 0.10137200E+05, -.34410100E+04, -.95760600E+04, 0.94518500E+04, -.98258000E+04, -.80230100E+04, 0.32384900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.81829400E-01, -.25249600E+00, 0.27482300E+00, -.45186900E+00, -.85436400E+00, -.22275700E+00, 0.10756300E+01, -.95125400E-01, 0.33859200E+00, 0.14794400E+01, 0.87664800E-02, -.18439700E+00, 0.12245800E+01, 0.22268200E-01, -.83118000E-01, 0.34484300E+04, 0.12050500E+05, -.65825100E+04, -.49167200E+04, -.40124800E+04, 0.10360600E+05, 0.25707800E+04, 0.34928800E+04, -.17027200E+04, -.10003900E+04, -.17464500E+04, -.16464500E+03, 0.78085400E+03, -.70409000E+03, 0.60386000E+03, -.11147400E+04, 0.60319600E+03, -.14402800E+04, 0.36359700E+05, -.17878900E+05, -.11431500E+05, -.18183200E+05, -.33562200E+04, 0.71748000E+04, -.82326800E+04, 0.18460600E+04, -.11367600E+05, 0.60921500E+04, -.12951700E+05, -.27109400E+05, 0.13244700E+05, 0.10170200E+05, 0.13559300E+05, -.16984300E+04, -.65394000E+04, 0.51066800E+04, -.61969300E+04, 0.91467100E+04, -.53733100E+04, 0.11883200E+05, -.99484200E+04, 0.47829300E+04, -.44812700E+04, 0.49735800E+04, 0.40186900E+04, -.73680200E+04, 0.94630100E+04, 0.81812000E+04, 0.72184100E+04, -.70462700E+04, 0.27664100E+04, 0.30480200E+05, -.14972100E+05, -.90257800E+04, -.15244100E+05, -.40235600E+04, 0.44810900E+04, -.58744500E+04, 0.20099700E+04, -.85131000E+04, 0.35268200E+04, -.99824600E+04, 0.99505100E+04, -.44738300E+04, -.40433300E+04, -.49758300E+04, 0.40997800E+04, 0.62433400E+04, -.48308000E+04, 0.82461700E+03, -.46675100E+04, 0.57102400E+04, -.55904100E+04, -.12751300E+05, 0.61111400E+04, 0.56238800E+04, 0.63763500E+04, 0.70492900E+03, -.10120100E+05, 0.44654400E+04, -.21620000E+04, 0.41287500E+04, -.85008900E+04, 0.18695500E+04, -.45118900E+05, 0.21754300E+05, 0.24083000E+05, 0.22560700E+05, -.93954000E+04, -.17847200E+05, 0.96976500E+04, -.14601900E+05, 0.15049700E+05, -.14195800E+05, 0.20262000E+05, 0.61923400E+05, -.30043700E+05, -.16283500E+05, -.30963700E+05, 0.64960600E+03, 0.14769200E+05, -.11629200E+05, 0.13873300E+05, -.19761600E+05, 0.11796300E+05, -.28937600E+05, 0.37791700E+05, -.18665000E+05, -.11209400E+05, -.18899500E+05, -.19773700E+04, 0.10376500E+05, -.79413200E+04, 0.55273500E+04, -.11906800E+05, 0.89677500E+04, -.14792800E+05, 0.24986200E+05, -.12279300E+05, -.10570500E+05, -.12491900E+05, -.13876900E+03, 0.14775700E+05, -.88653300E+04, 0.42808300E+03, -.94922700E+04, 0.12410300E+05, -.69286100E+04, 0.34740200E+04, -.16796000E+04, -.87473100E+03, -.17370300E+04, -.29844300E+04, -.85355200E+04, 0.44619500E+04, 0.40778800E+04, 0.18440700E+04, -.74016400E+04, -.30395700E+04, -.36578300E+05, 0.17796200E+05, 0.12599100E+05, 0.18287300E+05, 0.17879700E+04, -.11158600E+05, 0.64221700E+04, -.82873000E+04, 0.11224900E+05, -.94969000E+04, 0.14147600E+05, -.26873600E+05, 0.13475600E+05, 0.37465000E+04, 0.13436800E+05, 0.30393500E+04, -.18072600E+04, 0.41790000E+04, -.42582300E+04, 0.89805200E+04, -.15287600E+04, 0.11281500E+05, -.44834200E+05, 0.21341300E+05, 0.21106300E+05, 0.22418300E+05, -.98317500E+04, -.15804600E+05, 0.90886900E+04, -.15689500E+05, 0.14910400E+05, -.12563200E+05, 0.21189300E+05, -.19056300E+05, 0.87847200E+04, 0.60289400E+04, 0.95274100E+04, -.70207400E+04, -.12191200E+05, 0.10959500E+05, 0.13955800E+04, 0.95278900E+04, -.10880900E+05, 0.10461300E+05, -.45824300E+05, 0.22127500E+05, 0.11437800E+05, 0.22913300E+05, 0.81762500E+02, -.16685900E+05, 0.17837400E+05, 0.48106100E+03, 0.18346400E+05, -.14676900E+05, 0.19296700E+05, -.39165700E+05, 0.19121700E+05, 0.11532700E+05, 0.19583300E+05, 0.17401500E+04, -.73845500E+04, 0.75252100E+04, -.59897900E+04, 0.13142900E+05, -.57842300E+04, 0.16193200E+05, 0.88735000E+04, 0.34655200E+04, -.28833100E+04, 0.61013100E+03, -.18983600E+04, 0.32002200E+03, 0.55123800E+04, 0.80614400E+03, -.57619600E+04, -.58694300E+03, 0.44642400E+04, 0.81437300E+03, -.12597000E+04, 0.31143500E+04, -.15272700E+04, -.14399700E+04, -.37374300E+04, 0.32851700E+02, -.40849800E+04, -.39118800E+04, 0.13833000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57940100E-01, 0.45796200E+00, 0.27821900E+00, 0.26320700E+00, 0.33118600E-01, 0.15421500E+00, -.25057700E+00, -.63746300E-01, -.31276100E+00, -.32858800E+00, 0.64890900E-01, 0.35089600E-01, -.56182300E+00, 0.14258900E-01, 0.12685100E+00, -.27355300E+00, 0.32047100E+04, -.24376100E+04, -.26895400E+04, -.12407200E+04, 0.29587400E+04, 0.24298500E+04, 0.15932500E+04, -.78782100E+03, -.43121800E+02, -.79662200E+03, -.32038500E+03, 0.11853100E+03, -.29819700E+03, 0.25874700E+03, -.52060800E+03, 0.94758900E+02, -.48605800E+03, 0.18849900E+05, -.94092900E+04, -.35707000E+04, -.94294200E+04, -.36383800E+04, 0.12085600E+04, -.43813800E+04, 0.13116200E+03, -.66631000E+04, 0.16254000E+04, -.51139200E+04, -.12282800E+05, 0.60877200E+04, 0.31991700E+04, 0.61433900E+04, 0.35295100E+03, -.88711800E+03, 0.15851200E+04, -.31556000E+04, 0.39626900E+04, -.72416100E+03, 0.41426900E+04, -.93640400E+04, 0.46900300E+04, -.55365600E+04, 0.46816400E+04, 0.50892600E+04, -.28528800E+04, 0.49507200E+04, 0.42665900E+04, 0.56369400E+04, -.28840000E+04, 0.27527400E+04, 0.16883700E+05, -.83590700E+04, -.30187000E+04, -.84468600E+04, -.35432200E+04, 0.55660900E+03, -.38223600E+04, 0.12966000E+03, -.55714600E+04, 0.87911100E+03, -.39815400E+04, 0.74397800E+03, -.30171900E+03, -.33919900E+03, -.37271500E+03, 0.23054900E+04, 0.28954100E+04, -.15382700E+04, -.22943200E+03, -.18246600E+04, 0.27896400E+04, 0.53799900E+03, -.35476400E+04, 0.17194300E+04, 0.41824100E+03, 0.17745800E+04, 0.18035600E+04, -.38588800E+04, 0.19398100E+04, -.68214700E+03, 0.84675400E+03, -.33553200E+04, -.10080300E+04, -.15082400E+05, 0.73682100E+04, 0.89416900E+04, 0.75419900E+04, -.27463600E+04, -.38791700E+04, 0.25220500E+04, -.59212300E+04, 0.52266500E+04, -.32947000E+04, 0.82724900E+03, 0.28105600E+05, -.13829400E+05, 0.40468800E+03, -.14054100E+05, -.35131100E+04, 0.27951500E+04, -.48595000E+04, 0.49452600E+04, -.10554500E+05, 0.26194400E+04, -.97546200E+04, 0.16574100E+05, -.82358200E+04, -.91244500E+03, -.82891700E+04, -.31072700E+04, 0.34955100E+04, -.41744600E+04, 0.16206800E+04, -.59705200E+04, 0.34822100E+04, -.40147700E+04, 0.87524800E+04, -.43097900E+04, -.15799600E+04, -.43772300E+04, -.23325400E+04, 0.44792700E+04, -.36367500E+04, -.44179000E+03, -.32462600E+04, 0.40568000E+04, -.12972400E+04, 0.29288200E+04, -.14285200E+04, -.56956400E+03, -.14645600E+04, -.53402100E+03, -.26595900E+04, 0.15284600E+04, 0.24388500E+04, 0.14883000E+03, -.24318000E+04, -.28990100E+04, -.14608000E+05, 0.72102600E+04, 0.17400900E+04, 0.73028400E+04, 0.29966100E+04, -.32775800E+04, 0.27493200E+04, -.33611600E+04, 0.47182800E+04, -.31681600E+04, 0.40430300E+04, -.16723900E+05, 0.83606800E+04, -.98123300E+02, 0.83618000E+04, 0.28497400E+04, -.20897600E+03, 0.24698800E+04, -.24535700E+04, 0.61211500E+04, -.27387700E+03, 0.66323500E+04, -.19162400E+05, 0.93307700E+04, 0.89685100E+04, 0.95819300E+04, -.40103700E+04, -.45243700E+04, 0.28484600E+04, -.82081000E+04, 0.65014600E+04, -.35761800E+04, 0.36683400E+04, -.37805100E+04, 0.18283900E+04, -.56126600E+03, 0.18907200E+04, -.31627100E+04, -.53077500E+04, 0.41380800E+04, 0.18207400E+04, 0.42880600E+04, -.49325000E+04, 0.61748600E+03, -.25835700E+05, 0.12771400E+05, 0.68165500E+03, 0.12918700E+05, 0.41941100E+04, -.54711500E+04, 0.85577500E+04, 0.11003600E+04, 0.11574500E+05, -.52746600E+04, 0.67325600E+04, -.19315400E+05, 0.95464600E+04, 0.15443600E+04, 0.96580100E+04, 0.32658400E+04, -.96348600E+03, 0.33125700E+04, -.29075400E+04, 0.65082100E+04, -.78383400E+03, 0.65268900E+04, 0.40148800E+04, 0.37493900E+02, -.45974700E+04, 0.11749300E+03, -.31561200E+04, 0.10855500E+04, 0.15454100E+04, 0.25427800E+04, -.15079800E+04, 0.14051200E+04, 0.26363800E+04, -.11358100E+03, 0.38750100E+03, 0.35054600E+04, -.45247400E+04, -.79844600E+03, -.43071400E+03, -.16823800E+04, -.63522000E+03, -.12066700E+04, 0.47936300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10658200E+00, -.35201800E+00, -.17089400E+01, -.43484600E+00, 0.88140600E+00, -.14127000E+00, 0.12230300E+01, 0.12323100E+00, -.10606800E+01, -.19104200E+00, 0.26549600E+00, -.13565700E+00, -.77019700E+00, 0.20386300E+00, -.31035100E+00, -.88841300E+00, 0.94848100E+00, 0.32422400E+04, 0.61754700E+04, 0.77335700E+03, -.21624400E+03, -.17978100E+04, 0.48691900E+04, -.24091500E+04, -.14439800E+04, -.24346200E+04, 0.25651900E+03, 0.10963100E+04, -.49837400E+03, 0.99498500E+03, -.15427800E+04, 0.94414400E+03, -.20675000E+04, 0.96510600E+04, -.47755900E+04, -.39605100E+04, -.48144400E+04, -.15402700E+04, -.24529300E+04, 0.74405100E+04, 0.12006700E+05, 0.43366000E+03, -.28227800E+04, -.49271500E+04, -.25697700E+05, 0.12660000E+05, 0.10913600E+05, 0.12846400E+05, -.57009000E+04, -.12292700E+05, 0.69843800E+04, -.30901600E+04, 0.10373000E+05, -.11114600E+05, 0.12771600E+05, 0.19685800E+05, -.98874800E+04, -.23183600E+05, -.98422100E+04, -.34331800E+04, 0.19970400E+04, -.78321100E+04, -.70631700E+04, -.57663000E+04, 0.69769300E+03, -.38574700E+04, 0.85889000E+04, -.41995500E+04, -.42022200E+04, -.42822700E+04, -.35832100E+04, -.48218200E+04, 0.89732300E+04, 0.11210700E+05, 0.14519900E+04, -.47789400E+04, -.38716600E+04, -.40752500E+04, 0.20922600E+04, 0.82974600E+03, 0.20394000E+04, 0.18911700E+04, 0.42537700E+04, -.59920800E+03, 0.84796900E+03, -.55446800E+03, 0.49889000E+04, 0.71907100E+03, -.28283100E+05, 0.13869200E+05, 0.64618700E+04, 0.14139800E+05, 0.35799700E+03, 0.87259700E+03, -.17333900E+04, -.92827400E+04, 0.67961100E+04, 0.13710700E+04, 0.14544100E+05, -.79785200E+05, 0.39410200E+05, 0.37828400E+05, 0.39891200E+05, -.15262700E+05, -.39654200E+05, 0.26182900E+05, -.24115500E+04, 0.31443200E+05, -.35021900E+05, 0.33086300E+05, 0.84981300E+05, -.41965100E+05, -.25172300E+05, -.42488100E+05, 0.72416100E+04, 0.24401200E+05, -.15863000E+05, 0.99676900E+04, -.31664300E+05, 0.22045300E+05, -.37778900E+05, 0.45529100E+05, -.22596600E+05, -.16083900E+05, -.22760900E+05, 0.28980000E+04, 0.63226600E+04, -.13860800E+03, 0.15298700E+05, -.11753300E+05, 0.45860200E+04, -.20912900E+05, 0.33548500E+05, -.16488700E+05, -.91051900E+04, -.16770300E+05, -.80338900E+03, -.86320300E+03, 0.41543800E+04, 0.14900600E+05, -.75062300E+04, -.20294000E+04, -.17466100E+05, 0.19327800E+04, -.90362500E+03, -.14445100E+04, -.96593400E+03, -.47664700E+03, -.41621700E+03, -.15622800E+04, -.35638000E+04, -.76385600E+03, -.32410600E+03, 0.27889100E+03, -.53575500E+05, 0.26533600E+05, 0.17696500E+05, 0.26789900E+05, -.33248900E+04, -.78007600E+04, 0.29690700E+04, -.13894400E+05, 0.14457900E+05, -.55939800E+04, 0.25583700E+05, -.18558800E+05, 0.92534500E+04, 0.59713900E+04, 0.92799100E+04, 0.68509900E+03, -.22270500E+04, 0.89396800E+03, -.35742000E+04, 0.56646900E+04, -.19132900E+04, 0.70742600E+04, -.56338600E+05, 0.27511600E+05, 0.29400300E+05, 0.28168000E+05, -.11642400E+05, -.28933300E+05, 0.20364100E+05, 0.10921900E+04, 0.23587100E+05, -.27005000E+05, 0.22670600E+05, 0.81663900E+04, -.42118500E+04, -.62039200E+04, -.40851000E+04, -.39452400E+04, -.81092200E+04, 0.20323900E+03, -.20855600E+04, 0.15484600E+04, -.94706500E+04, -.11531700E+04, -.16805600E+05, 0.80195700E+04, -.80001600E+04, 0.84010900E+04, -.10896200E+05, -.15221500E+05, 0.38900100E+04, -.10370900E+05, 0.76307100E+04, -.14238100E+05, 0.98570400E+04, -.48853800E+05, 0.24143000E+05, 0.14820700E+05, 0.24426300E+05, -.22384100E+04, -.10140200E+05, 0.46656100E+04, -.10473000E+05, 0.15076400E+05, -.84815800E+04, 0.20994400E+05, 0.12837600E+05, 0.51618500E+04, 0.31381400E+04, 0.13416100E+04, 0.83330300E+04, -.10935600E+04, 0.51096500E+04, -.64210600E+04, -.50775500E+04, -.51104300E+04, 0.45224200E+04, 0.93746600E+03, -.93520100E+03, -.59307900E+04, 0.36798700E+04, -.28441900E+04, -.49204700E+04, 0.62203900E+04, -.48449600E+04, -.49639100E+04, 0.53869900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12238500E+00, 0.25682800E+00, 0.57946000E+00, 0.46570600E+00, 0.74055600E+00, -.10338200E+00, 0.71319600E+00, -.19980900E+00, -.26501100E+00, -.39043400E+00, -.13932200E+00, 0.13783100E+00, -.12596800E+01, -.11103200E+00, 0.82721400E-02, 0.83237000E-01, 0.29724400E-01, -.70601800E+00, -.18849600E+04, -.17517200E+04, 0.65907600E+03, -.38068600E+04, 0.48726400E+04, -.23950700E+04, -.13549600E+04, -.24363300E+04, 0.31485000E+03, 0.11665600E+04, -.86764600E+03, 0.73590700E+03, -.16462900E+04, 0.96377000E+03, -.26343600E+04, 0.22107400E+05, -.10794300E+05, -.93240900E+04, -.11056900E+05, -.32623900E+04, -.12552000E+04, -.14678500E+03, 0.46745800E+04, -.50738500E+04, -.86090800E+03, -.12194400E+05, -.31014400E+05, 0.15152600E+05, 0.12281600E+05, 0.15511900E+05, -.54019700E+04, -.11602300E+05, 0.72336600E+04, -.47214900E+04, 0.11354000E+05, -.99289400E+04, 0.17950000E+05, -.71476800E+04, 0.33425700E+04, -.99309100E+04, 0.35732800E+04, 0.22207800E+04, -.23793500E+03, 0.25433400E+04, 0.37619700E+04, 0.56220700E+04, -.18872900E+04, 0.83625300E+04, 0.19153000E+05, -.94345400E+04, -.83274500E+04, -.95803700E+04, -.42228500E+04, -.29682300E+04, 0.52084700E+03, 0.36851100E+04, -.40108200E+04, -.24475300E+04, -.10389500E+05, 0.60557100E+04, -.27894300E+04, -.36474000E+04, -.30284000E+04, 0.14685800E+04, 0.41793100E+04, -.27090500E+04, -.93438900E+03, -.32606100E+04, 0.44992800E+04, -.64482500E+04, -.18642300E+05, 0.89816900E+04, 0.43517200E+04, 0.93218000E+04, -.16408500E+03, -.44758700E+04, 0.19402600E+04, -.47576100E+04, 0.60877300E+04, -.39076300E+04, 0.11886100E+05, -.68976400E+05, 0.33742400E+05, 0.28891600E+05, 0.34489300E+05, -.17339300E+05, -.33811400E+05, 0.19126600E+05, -.11242800E+05, 0.25040100E+05, -.28140900E+05, 0.41719100E+05, 0.82797800E+05, -.40670100E+05, -.24305800E+05, -.41400700E+05, 0.69549200E+04, 0.21979200E+05, -.15884000E+05, 0.13197400E+05, -.29074100E+05, 0.18648800E+05, -.45321700E+05, 0.47878900E+05, -.23705300E+05, -.15950800E+05, -.23942700E+05, 0.32531100E+04, 0.10403700E+05, -.68010200E+04, 0.91846200E+04, -.14447600E+05, 0.86922800E+04, -.27099300E+05, 0.27097500E+05, -.13236500E+05, -.73341100E+04, -.13547800E+05, -.15592700E+02, 0.42406700E+04, -.19510300E+04, 0.60641300E+04, -.88332100E+04, 0.38000900E+04, -.16932900E+05, 0.26021800E+04, -.13116700E+04, -.12942800E+04, -.13011100E+04, -.35113700E+03, -.12465400E+03, -.30799500E+02, 0.19745300E+04, 0.57087300E+03, -.60545300E+03, 0.14552600E+04, -.50369800E+05, 0.24760800E+05, 0.15379500E+05, 0.25183200E+05, -.43697500E+04, -.13641400E+05, 0.85792100E+04, -.10402700E+05, 0.16534200E+05, -.11268200E+05, 0.28248800E+05, -.21109000E+05, 0.10558500E+05, 0.74318700E+04, 0.10554500E+05, 0.10044300E+04, -.18909700E+04, 0.25241700E+04, -.39508300E+04, 0.72363700E+04, -.15541900E+04, 0.10119600E+05, -.52350300E+05, 0.25225500E+05, 0.27336200E+05, 0.26176200E+05, -.13264100E+05, -.25239800E+05, 0.13522300E+05, -.11324100E+05, 0.18643700E+05, -.21079100E+05, 0.32146900E+05, -.15314300E+05, 0.71322000E+04, 0.56377500E+04, 0.76565900E+04, -.20264200E+04, -.78377600E+04, 0.58337600E+04, 0.17883700E+04, 0.81025000E+04, -.82794600E+04, 0.12738800E+05, -.49367400E+05, 0.24038200E+05, 0.76114500E+04, 0.24684700E+05, -.48674100E+04, -.15279600E+05, 0.12639500E+05, -.43880900E+04, 0.18493200E+05, -.13866500E+05, 0.29566000E+05, -.49323900E+05, 0.24245900E+05, 0.14027000E+05, 0.24662300E+05, -.29314800E+04, -.10882600E+05, 0.85312400E+04, -.77000500E+04, 0.16796700E+05, -.88802600E+04, 0.26050700E+05, 0.12641200E+05, 0.47207800E+04, 0.21222000E+04, 0.13868300E+04, 0.40465800E+04, 0.37768700E+03, 0.65187000E+04, -.40459000E+04, -.44534500E+04, -.37129300E+04, 0.56972000E+04, 0.20618000E+04, -.20713000E+04, -.28444300E+04, 0.14832400E+04, -.35546800E+04, -.44650600E+04, 0.31730200E+04, -.41407200E+04, -.52562100E+04, 0.94237900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.60311400E-01, -.21027100E+00, -.92689800E+00, -.32522000E+00, 0.33145100E+00, -.12298800E+00, 0.16940800E+00, -.35392300E-01, -.11627200E+01, -.28047700E+00, 0.70275900E-01, 0.23989200E+00, -.56763000E+00, -.62564500E+00, -.39351100E+00, 0.19118200E+00, -.89954900E+00, -.36168800E+00, 0.34902100E+00, -.19423200E+04, -.11902000E+03, 0.24253600E+03, -.50712600E+04, 0.25175200E+04, 0.65716300E+03, 0.25356400E+04, 0.31388100E+03, -.68847100E+03, 0.11318900E+04, -.30583300E+03, 0.19833600E+04, -.61673700E+03, 0.20445100E+04, -.17922000E+05, 0.88837200E+04, 0.15087800E+04, 0.89528800E+04, 0.29061300E+04, -.23881500E+04, 0.51704700E+04, 0.25061200E+03, 0.86971400E+04, -.24929800E+04, 0.58071800E+04, 0.22880800E+05, -.11296000E+05, -.53222000E+04, -.11437100E+05, 0.69416500E+03, 0.71571800E+04, -.58294500E+04, 0.17541400E+04, -.85874900E+04, 0.58020400E+04, -.88234400E+04, 0.53895900E+05, -.26878300E+05, -.35030500E+04, -.26948600E+05, -.11011100E+05, -.69050700E+04, -.67184300E+04, 0.26604000E+04, -.18218400E+05, -.52867900E+04, -.22262500E+05, -.13537500E+05, 0.67103000E+04, 0.18564400E+02, 0.67597100E+04, 0.23204900E+04, -.27526500E+04, 0.53509600E+04, 0.12069600E+04, 0.81387500E+04, -.28648400E+04, 0.40376800E+04, -.15714100E+05, 0.78082600E+04, 0.67184600E+04, 0.78557400E+04, 0.20472600E+04, -.11181600E+04, 0.27113600E+04, -.43420000E+03, 0.37282200E+04, -.65743100E+03, 0.30506300E+04, 0.19529900E+05, -.95587900E+04, -.10922900E+04, -.97636000E+04, 0.36845400E+03, 0.39641600E+04, -.51129000E+04, 0.18163400E+04, -.90428200E+04, 0.40956000E+04, -.79322800E+04, 0.54981500E+05, -.27141100E+05, -.21505000E+05, -.27489500E+05, 0.55467300E+04, 0.24208900E+05, -.15582700E+05, 0.57010500E+04, -.19999200E+05, 0.20088800E+05, -.17159600E+05, -.79918400E+05, 0.39612000E+05, 0.80781300E+04, 0.39957000E+05, 0.52884600E+04, -.12816200E+05, 0.16946900E+05, -.66120600E+04, 0.31015700E+05, -.11058900E+05, 0.31134600E+05, -.46340800E+05, 0.23058000E+05, 0.80377700E+04, 0.23167000E+05, 0.22603900E+04, -.68871500E+04, 0.10753500E+05, -.28868700E+04, 0.19382900E+05, -.61825600E+04, 0.17797800E+05, -.20190600E+05, 0.98830300E+04, 0.31007600E+03, 0.10093200E+05, -.63507100E+03, -.43130800E+04, 0.59211100E+04, -.10155000E+04, 0.85647600E+04, -.44294100E+04, 0.94161200E+04, -.44155400E+03, 0.19004800E+03, -.48841300E+03, 0.22048400E+03, -.82353800E+02, -.66748800E+03, 0.68873800E+03, 0.35992600E+03, 0.21820800E+04, -.57562100E+03, 0.39489200E+02, 0.46052400E+05, -.22844500E+05, -.62774300E+04, -.23028100E+05, -.58267000E+03, 0.95621900E+04, -.11655400E+05, 0.38738400E+04, -.19521800E+05, 0.84119400E+04, -.18385900E+05, 0.18626500E+05, -.93141200E+04, 0.61366800E+03, -.93135600E+04, -.40888500E+04, -.51399100E+03, -.30047300E+04, 0.15522800E+04, -.75934100E+04, -.28467900E+03, -.77194200E+04, 0.29072900E+05, -.14077300E+05, -.15087500E+05, -.14535200E+05, 0.32356000E+04, 0.13873800E+05, -.61256000E+04, 0.78500000E+04, -.90853100E+04, 0.10654200E+05, -.68086000E+04, 0.35684000E+05, -.17689800E+05, -.10745000E+05, -.17841000E+05, -.49874000E+04, 0.43630400E+03, -.55315200E+04, 0.14179100E+04, -.95502700E+04, -.15946300E+03, -.99146400E+04, 0.77340300E+05, -.38370400E+05, -.96032000E+04, -.38668700E+05, -.10808300E+05, -.98486700E+02, -.10745200E+05, 0.73029300E+04, -.26454900E+05, -.95291300E+02, -.29802700E+05, 0.45041500E+05, -.22336300E+05, -.41159200E+04, -.22520200E+05, -.26635400E+04, 0.65360500E+04, -.10435400E+05, 0.26577300E+04, -.18183500E+05, 0.58040600E+04, -.18114800E+05, -.13147000E+05, -.45451300E+03, 0.14243900E+04, -.87590900E+03, 0.17849600E+04, -.22200600E+04, -.33593300E+04, -.12379600E+04, -.12158600E+04, -.24191100E+04, -.75304400E+04, -.11890300E+04, 0.16420800E+04, -.23922800E+04, 0.15900400E+04, 0.60425300E+04, 0.93138500E+03, 0.27188500E+04, -.55529900E+02, 0.17419900E+04, -.67459900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.83300500E+00, 0.61576600E+00, -.45834700E+01, 0.17239000E+01, 0.26370800E+01, -.22584200E+01, 0.51679900E+01, -.67776600E+00, 0.32103400E+00, 0.32084900E+01, 0.40407300E+01, -.10622200E+01, 0.29538000E+01, 0.23442200E+01, -.86397700E+00, -.28171600E+00, 0.75076600E+01, -.56638000E+00, -.44833800E+01, 0.42218900E+01, 0.67086600E+04, 0.20822600E+05, 0.66601900E+05, -.33301000E+05, -.12156800E+05, -.33301100E+05, -.11643400E+04, 0.11050400E+05, -.12242200E+05, 0.71199800E+04, -.24041300E+05, 0.10512800E+05, -.22320400E+05, 0.30133400E+06, -.15352100E+06, -.82106900E+05, -.15064100E+06, -.49553300E+05, -.17201400E+05, -.22423800E+05, 0.53519900E+05, -.93488200E+05, -.53802900E+04, -.57183500E+05, -.34771600E+06, 0.17382300E+06, 0.10963000E+06, 0.17387200E+06, -.44241300E+05, -.11185400E+06, 0.81804900E+05, -.40617500E+05, 0.13399900E+06, -.10349300E+06, 0.11932900E+06, -.20905300E+06, 0.10653300E+06, -.17641400E+06, 0.10452500E+06, 0.80384100E+05, 0.47570600E+05, 0.16912700E+05, -.69910800E+04, 0.93715000E+05, 0.21208600E+05, 0.88945500E+05, 0.23733300E+06, -.11926600E+06, -.66291700E+05, -.11864000E+06, -.55407700E+05, -.30468100E+05, -.69466400E+04, 0.47944200E+05, -.70615500E+05, -.18034900E+05, -.33826100E+05, 0.50897600E+05, -.29101500E+05, -.24983600E+05, -.25444900E+05, 0.61656200E+04, 0.27536200E+05, -.20921500E+05, -.85820300E+04, -.27900300E+05, 0.37855500E+05, 0.23144800E+05, -.27828300E+06, 0.13710900E+06, 0.38888400E+05, 0.13913800E+06, 0.67041700E+04, -.36215700E+05, 0.44965800E+05, -.39770800E+05, 0.10206000E+06, -.40761300E+05, 0.58945100E+05, -.89025800E+06, 0.44431600E+06, 0.43032500E+06, 0.44513100E+06, -.15363700E+06, -.38834000E+06, 0.26470000E+06, -.73131900E+05, 0.34259800E+06, -.34868400E+06, 0.19977300E+06, 0.10966500E+07, -.54737200E+06, -.16850000E+06, -.54832900E+06, 0.80521200E+04, 0.23041100E+06, -.21928500E+06, 0.11520200E+06, -.42325000E+06, 0.22005000E+06, -.37927600E+06, 0.64232300E+06, -.32070700E+06, -.14940200E+06, -.32116900E+06, -.85239700E+04, 0.95558000E+05, -.10224200E+06, 0.95013800E+05, -.22149500E+06, 0.90838100E+05, -.19810700E+06, 0.35979200E+06, -.17678800E+06, -.58888600E+05, -.17987200E+06, -.10934600E+05, 0.29672000E+05, -.49551400E+05, 0.49868600E+05, -.12402500E+06, 0.34392000E+05, -.10541300E+06, 0.17733900E+05, -.73020100E+04, -.75015200E+04, -.88652200E+04, -.36787600E+04, -.13025300E+04, -.17254600E+03, 0.32294400E+04, -.69993500E+04, -.52888600E+04, -.20897400E+05, -.65286300E+06, 0.32709300E+06, 0.15832200E+06, 0.32642900E+06, -.26489100E+04, -.12035000E+06, 0.11692500E+06, -.98652100E+05, 0.23214100E+06, -.10918800E+06, 0.20151300E+06, -.35313600E+06, 0.17564900E+06, 0.21729000E+05, 0.17657000E+06, 0.39518700E+05, -.25844300E+05, 0.50282400E+05, -.49506500E+05, 0.13063400E+06, -.27344100E+05, 0.13620000E+06, -.62890400E+06, 0.31273300E+06, 0.31809700E+06, 0.31445400E+06, -.13622900E+06, -.27149400E+06, 0.17601300E+06, -.88663700E+05, 0.24195500E+06, -.25114200E+06, 0.12715200E+06, -.13584100E+06, 0.73376300E+05, -.14652200E+05, 0.67907800E+05, -.56628600E+04, -.48768900E+05, 0.43822100E+05, 0.15770300E+05, 0.74527700E+05, -.67440200E+05, 0.51319500E+04, -.65398100E+06, 0.32801700E+06, -.60359200E+04, 0.32699100E+06, 0.19098800E+05, -.10106000E+06, 0.12494100E+06, -.75766500E+05, 0.24993800E+06, -.11059100E+06, 0.21052000E+06, -.67136600E+06, 0.33496900E+06, 0.11728100E+06, 0.33568300E+06, 0.10931900E+05, -.10659500E+06, 0.12029900E+06, -.79119500E+05, 0.24430500E+06, -.99275200E+05, 0.23277200E+06, 0.17269500E+06, 0.29298100E+05, -.37861900E+04, 0.12078300E+05, 0.23878100E+05, 0.78798000E+04, 0.63775200E+05, -.23670100E+05, -.39559400E+05, 0.81672200E+04, 0.80972200E+05, 0.31598000E+04, -.12598300E+05, 0.67372700E+04, -.43021700E+04, -.61448400E+05, -.33992900E+05, 0.16437200E+05, -.37293500E+05, -.54952500E+05, 0.62006900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28745500E+00, -.30093600E+01, -.71637800E+01, -.24580700E+01, 0.27899400E+01, -.26093100E+01, 0.89890400E+00, 0.17896600E+00, 0.32856100E+01, 0.19736200E+01, 0.80409100E-01, -.91287100E+00, -.52573100E+00, -.12450600E+01, 0.37216100E+00, 0.37335800E+00, 0.93036400E+00, 0.11524700E+01, -.11254100E+01, 0.21323500E+01, 0.28629200E+00, -.20131900E+05, 0.49559900E+04, -.25314400E+04, -.12143500E+04, -.24780700E+04, 0.21440900E+04, 0.10938100E+04, -.89891400E+03, 0.21374800E+04, -.14757400E+04, 0.53859200E+03, -.79578500E+04, 0.15405100E+05, -.88077500E+04, 0.33782600E+04, -.76670000E+04, 0.33506500E+04, 0.82091600E+03, -.49089300E+04, 0.68962200E+04, -.31849700E+04, -.39331900E+03, -.46648600E+05, -.57537300E+05, 0.29418100E+05, 0.29316300E+05, 0.28755500E+05, -.13880900E+05, -.14872700E+05, 0.14029500E+05, -.98524500E+04, 0.18877200E+05, -.98808800E+04, 0.60119900E+05, -.11997300E+05, 0.68846800E+04, -.29224000E+05, 0.60007900E+04, -.52871200E+04, -.45452000E+04, -.75735700E+04, -.22111500E+05, 0.41624500E+04, 0.92863400E+03, 0.34784300E+05, 0.12758200E+05, -.65015900E+04, 0.31735100E+04, -.63401000E+04, 0.14330600E+04, -.17280900E+04, -.47362000E+04, 0.45078000E+04, -.12954700E+03, -.22118200E+04, -.43478600E+05, -.50069400E+04, 0.13290500E+04, 0.30010900E+04, 0.25091600E+04, 0.11352700E+05, 0.85922300E+04, -.61873400E+03, 0.17400600E+04, -.56097200E+04, 0.58539800E+04, -.32736500E+05, -.46668200E+05, 0.23340600E+05, 0.11595400E+05, 0.23328400E+05, -.99255400E+04, -.79965000E+04, 0.12097600E+05, -.45321400E+04, 0.13792000E+05, -.31259100E+04, 0.58894500E+05, 0.16352000E+05, -.72676400E+04, 0.30952500E+05, -.81802100E+04, -.44597200E+05, 0.48165200E+04, -.90950400E+04, -.14868900E+05, -.11010300E+05, 0.12467600E+05, 0.12284200E+06, 0.14122700E+06, -.71196900E+05, -.30712300E+05, -.70605500E+05, 0.36508700E+05, 0.20648200E+05, -.19795000E+05, 0.50450700E+05, -.34795600E+05, 0.86930500E+04, -.16021800E+06, 0.35356700E+05, -.17794900E+05, -.43189800E+04, -.17667300E+05, 0.28602100E+05, 0.22844700E+05, -.14488800E+05, 0.11328400E+05, -.18098300E+05, 0.14957700E+05, -.78895500E+05, 0.49128900E+05, -.24233600E+05, -.12143000E+05, -.24551200E+05, 0.96613800E+04, 0.13954700E+05, -.14437200E+05, 0.90891200E+04, -.16813300E+05, 0.90757300E+04, -.58054200E+05, 0.95008700E+04, -.42836500E+04, -.38915900E+04, -.47489400E+04, -.67335800E+03, -.84789600E+02, -.17200200E+04, 0.15862400E+04, -.12611000E+04, -.23828100E+03, 0.84217500E+04, -.51446900E+05, 0.26365200E+05, 0.26600300E+05, 0.25730000E+05, -.22638900E+05, -.16122400E+05, 0.13813500E+05, -.11895600E+05, 0.17128200E+05, -.90712900E+04, 0.79763400E+05, -.71879900E+05, 0.35732200E+05, 0.74698800E+04, 0.35941600E+05, -.99604300E+04, -.17020700E+05, 0.16385100E+05, -.13635700E+05, 0.24227000E+05, -.14660200E+05, 0.54183700E+05, -.10832600E+06, 0.55079300E+05, 0.51145700E+05, 0.54158900E+05, -.40369800E+05, -.37441800E+05, 0.38431900E+05, 0.51427500E+04, 0.46459700E+05, -.29479400E+05, 0.15712800E+06, -.38607300E+05, 0.21535300E+05, 0.35742600E+04, 0.19297100E+05, -.17359100E+05, -.20785900E+05, 0.78731600E+04, -.15816200E+05, 0.21243100E+05, -.14962900E+05, 0.70568500E+05, -.32392400E+05, 0.17193200E+05, -.17241500E+05, 0.16190900E+05, -.29427000E+05, -.25893000E+05, 0.48467200E+04, -.18749000E+05, 0.23440600E+05, -.15536600E+05, 0.98398100E+05, -.54544200E+05, 0.27648800E+05, 0.11705700E+05, 0.27270300E+05, -.19689200E+05, -.13892900E+05, 0.11047800E+05, -.19603600E+05, 0.15771800E+05, -.84974500E+04, 0.76939900E+05, 0.12784800E+05, 0.42821800E+04, 0.19769200E+05, 0.46690400E+04, 0.18735600E+05, 0.10889900E+05, 0.43783200E+04, -.20804200E+05, -.26649000E+04, -.15128200E+05, 0.17729800E+05, 0.11733200E+05, -.18905900E+04, -.18049700E+05, 0.18767700E+05, -.22278400E+04, -.40164600E+04, -.63345600E+04, -.17475500E+04, -.46641700E+04, -.14456800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.67406400E-02, -.17997300E+00, 0.11193700E+01, -.55099500E-01, -.18876400E+00, 0.12280100E+00, -.19065800E+00, 0.23769800E-01, -.11859500E+00, -.21709200E+00, -.66038000E-01, 0.53935400E-01, -.13257600E+00, 0.13501500E+00, 0.23121500E-01, -.97457000E-01, 0.15171900E+00, 0.18833100E-01, 0.47975800E-01, -.14783400E+00, 0.19902700E-01, 0.22661700E-01, -.36707400E+04, 0.18347800E+04, 0.16333500E+03, 0.18353800E+04, -.29656200E+03, -.43370200E+03, 0.43169200E+03, -.97941800E+03, 0.11792600E+04, -.29381800E+03, 0.19865000E+04, -.14746300E+05, 0.74861600E+04, 0.20973500E+04, 0.73734400E+04, 0.28308000E+04, 0.19396000E+04, 0.37209000E+03, -.34598500E+04, 0.42718900E+04, 0.16117300E+04, 0.65924500E+04, 0.21853700E+05, -.10927500E+05, -.53056100E+04, -.10927600E+05, 0.49389700E+04, 0.64840600E+04, -.40547300E+04, 0.52930100E+04, -.73939800E+04, 0.50821800E+04, -.11692200E+05, 0.21604500E+05, -.10887800E+05, 0.10464900E+05, -.10802100E+05, -.53807700E+04, -.30984500E+04, -.16251200E+04, 0.29727300E+04, -.84044200E+04, -.24056700E+04, -.11870600E+05, -.11627700E+05, 0.58191700E+04, 0.14720700E+04, 0.58142300E+04, 0.30781000E+04, 0.28601400E+04, -.11961200E+03, -.27082900E+04, 0.31931700E+04, 0.23483100E+04, 0.51223600E+04, -.91245700E+03, 0.57577500E+03, 0.41411200E+03, 0.45628200E+03, -.13462700E+04, -.32011700E+03, 0.11079200E+03, -.61174000E+03, 0.45926800E+03, -.38052700E+03, 0.15213800E+04, 0.14079200E+05, -.69664200E+04, -.68000700E+03, -.70396800E+04, 0.58401700E+03, 0.15027900E+04, -.13472900E+04, 0.38899300E+04, -.44478500E+04, 0.98570800E+03, -.68736100E+04, 0.39116600E+05, -.19514400E+05, -.15743000E+05, -.19558600E+05, 0.19134800E+05, 0.17897900E+05, -.76240700E+04, 0.15396100E+05, -.11548100E+05, 0.13547000E+05, -.23547100E+05, -.62593200E+05, 0.31231100E+05, 0.26899000E+04, 0.31297000E+05, -.61337500E+04, -.80691100E+04, 0.73542100E+04, -.17344600E+05, 0.20563900E+05, -.55635900E+04, 0.34771300E+05, -.38103300E+05, 0.19031500E+05, 0.55228200E+04, 0.19052400E+05, -.30256500E+04, -.63246900E+04, 0.53099700E+04, -.87869900E+04, 0.12428400E+05, -.46730100E+04, 0.19372000E+05, -.20248200E+05, 0.10007900E+05, 0.20737700E+04, 0.10123600E+05, -.61605800E+02, -.22802400E+04, 0.21995600E+04, -.48111000E+04, 0.64499100E+04, -.15445100E+04, 0.96492800E+04, -.18680700E+04, 0.86183200E+03, 0.59262700E+03, 0.93401600E+03, 0.22992500E+03, 0.77778600E+02, 0.16708500E+03, -.35474600E+03, 0.58312800E+03, 0.81507700E+02, 0.85107700E+03, 0.39637000E+05, -.19834800E+05, -.58588000E+04, -.19818100E+05, 0.40453100E+04, 0.82229800E+04, -.63186900E+04, 0.90280600E+04, -.13124300E+05, 0.60756500E+04, -.20063800E+05, 0.20996400E+05, -.10464600E+05, 0.97201500E+03, -.10498200E+05, -.24836700E+04, -.63397100E+02, -.21014200E+04, 0.41284000E+04, -.72403500E+04, -.38242600E+03, -.10421800E+05, 0.28965700E+05, -.14393500E+05, -.14979300E+05, -.14483100E+05, 0.12029500E+05, 0.13034900E+05, -.65953400E+04, 0.84566100E+04, -.93336700E+04, 0.10653900E+05, -.15521000E+05, 0.78308900E+04, -.41150200E+04, 0.19070000E+04, -.39151600E+04, 0.13231900E+04, 0.38746200E+03, -.85870600E+03, 0.20330100E+04, -.31995300E+04, 0.47115400E+03, -.59515200E+04, 0.45050300E+05, -.22549500E+05, 0.31150600E+04, -.22525400E+05, 0.50499800E+03, 0.51586300E+04, -.65521400E+04, 0.87005200E+04, -.16061400E+05, 0.41372800E+04, -.23511400E+05, 0.38750400E+05, -.19337000E+05, -.22568100E+04, -.19375300E+05, 0.23934400E+04, 0.49883900E+04, -.51427500E+04, 0.90851200E+04, -.12881900E+05, 0.34963900E+04, -.20247000E+05, -.94883000E+04, -.31612200E+03, -.34779700E+04, -.13326700E+04, -.48598100E+04, -.28048900E+04, -.21411700E+04, 0.47531200E+04, 0.71255600E+03, 0.30782600E+04, -.54986300E+04, -.35338200E+03, -.12970900E+04, 0.33188000E+04, -.35937800E+04, 0.26432500E+04, 0.80393200E+03, 0.13171800E+04, 0.52576500E+03, 0.15909600E+04, 0.18066200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42073800E+00, 0.32163300E+01, 0.46259400E+01, 0.33825000E+01, -.26803400E-01, 0.21593700E+01, -.11280100E+01, -.34994400E+00, -.39871500E+01, -.25485000E+01, -.64822500E-02, 0.64465600E+00, -.38497900E+01, 0.12170300E+01, 0.72834800E+00, -.24562500E+01, 0.13951500E+01, -.35605100E+00, 0.10847200E+01, -.14204700E+01, 0.27765400E-01, -.36848900E+00, 0.12419300E+01, -.44992900E+03, 0.78819100E+03, -.49197400E-01, 0.19385000E+02, -.45146400E+03, -.24503700E+03, 0.38685500E+03, -.73362300E+02, -.58647900E+03, -.22232300E+02, -.36560200E+04, -.96598600E+03, 0.44569600E+04, 0.18280200E+04, 0.18226500E+04, 0.75754800E+04, -.83301700E+04, -.63266100E+04, -.43311400E+04, 0.65230100E+04, 0.32579300E+04, -.53612600E+04, 0.55910400E+04, -.11557500E+04, 0.26851900E+04, 0.28822300E+04, 0.37518600E+04, -.77784800E+03, -.54560000E+04, -.93152500E+03, 0.56707600E+04, 0.35503400E+03, -.76855400E+05, 0.40486400E+05, 0.27413600E+05, 0.38426800E+05, 0.97457300E+04, -.24564100E+04, 0.17725900E+05, 0.26698200E+04, 0.28832200E+05, -.60752100E+03, 0.23842600E+05, -.28436100E+04, -.98599900E+03, 0.44893600E+04, 0.14210300E+04, 0.26433000E+04, 0.85719600E+04, -.10132600E+05, -.65170100E+04, -.51165200E+04, 0.73355500E+04, 0.38886200E+04, 0.21946600E+05, -.14174700E+05, -.73301700E+04, -.10973400E+05, -.34400100E+04, -.74871400E+03, -.33737100E+04, 0.18325200E+04, -.70944800E+04, -.26161600E+04, -.38224300E+04, 0.67560800E+04, 0.29991100E+03, -.42493100E+04, -.33777100E+04, -.25099200E+04, -.42722500E+04, 0.22058800E+04, -.95632200E+03, -.15394300E+03, -.35421700E+04, -.89428300E+02, 0.26783600E+05, -.56097500E+04, -.18200700E+05, -.13389900E+05, 0.21838800E+03, 0.19046300E+05, -.18257300E+05, -.23124800E+05, -.17334600E+05, 0.21863200E+05, -.84185000E+04, -.46730200E+04, -.64708100E+04, 0.14077700E+05, 0.23337400E+04, -.30948900E+04, -.11780000E+05, 0.23876400E+04, 0.97489300E+04, 0.24803000E+04, -.14919700E+05, 0.16200100E+04, 0.66827300E+04, -.61533700E+04, 0.42321600E+04, -.33471000E+04, 0.14453700E+04, 0.61670700E+04, -.10577900E+05, -.37952700E+04, -.85387300E+04, 0.45757500E+04, -.60171100E+03, -.13758800E+05, 0.34189000E+04, 0.79855800E+04, 0.68848700E+04, 0.42209500E+04, 0.62117400E+04, -.45507900E+04, -.30897500E+04, 0.14533500E+04, 0.59467600E+04, 0.25141000E+04, -.30652000E+04, 0.11787000E+04, 0.17527700E+04, 0.15328700E+04, 0.62300700E+03, 0.10513600E+04, -.91880600E+03, -.92070500E+03, 0.47860500E+03, 0.90500200E+03, 0.13532700E+04, 0.36083500E+04, 0.31831900E+04, -.82982000E+04, -.18070300E+04, -.28153200E+04, -.61202500E+04, 0.63574300E+04, 0.53838300E+03, 0.29378900E+04, -.45931000E+04, -.13945900E+03, -.16262900E+03, -.15977300E+03, -.55981800E+04, 0.81606600E+02, 0.15028000E+04, 0.26363800E+04, 0.20806700E+04, 0.10690500E+04, 0.14464900E+04, 0.28424200E+04, -.27975800E+03, 0.14665500E+05, 0.30351500E+04, -.81978300E+04, -.73308900E+04, 0.63319600E+04, 0.13570600E+05, -.14134300E+05, -.18884700E+05, -.12488400E+05, 0.16863600E+05, -.88294600E+04, -.51335700E+05, 0.31132000E+05, 0.18331800E+05, 0.25664900E+05, 0.79185200E+04, 0.34574200E+04, 0.80362400E+04, -.38733900E+04, 0.16345000E+05, 0.68222300E+04, 0.12059000E+05, -.69960900E+05, 0.42883100E+05, 0.22005600E+05, 0.34981800E+05, 0.13839500E+05, 0.51718900E+04, 0.11785000E+05, -.27120200E+04, 0.25517500E+05, 0.71452500E+04, 0.19330000E+05, 0.41064500E+04, 0.24081100E+04, -.98699100E+04, -.20526400E+04, -.93717200E+02, 0.32380200E+04, 0.29677100E+04, -.10573000E+04, -.35319200E+02, 0.41853900E+04, -.19373100E+04, -.13937400E+03, -.38400300E+04, 0.11077500E+04, 0.28824000E+03, -.22759300E+04, 0.42528300E+04, -.18653700E+04, 0.76362600E+03, 0.63212300E+04, -.11794800E+04, 0.29849900E+04, -.75502600E+03, 0.18073600E+04, 0.46139100E+02, 0.80097800E+03, 0.13551200E+03, 0.31770900E+04, -.10607300E+05, 0.47522700E+04, 0.41146500E+04, 0.55860900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22590000E+00, -.43002300E+00, -.50461000E-01, -.93851300E+00, -.72348400E+00, 0.76884500E-01, -.83348500E+00, 0.16939200E+00, 0.10388400E+01, 0.43591500E-01, -.11991800E+00, -.44231700E-01, 0.18660600E+01, -.86137200E+00, -.30426100E+00, 0.36797000E+00, 0.51613800E+00, 0.13943400E+00, -.38535600E+00, 0.52599400E+00, -.10006900E+00, 0.63807400E-01, -.15063300E+01, 0.87103700E-01, 0.30818800E+04, -.17834000E-02, -.23414500E+04, -.21327900E+04, 0.10632000E+04, -.27503700E+03, -.38608800E+02, -.15705000E+04, 0.28306400E+03, 0.12219400E+05, -.58705500E+04, 0.12742100E+05, -.61026100E+04, -.93676700E+04, -.95899900E+04, 0.61673100E+04, 0.39291000E+04, -.23120900E+04, -.85568100E+04, -.45139600E+04, 0.19044700E+05, -.96355500E+04, -.18068400E+05, -.95256500E+04, 0.11806400E+05, 0.12744700E+05, -.64442500E+04, 0.65597100E+04, -.44671500E+04, 0.85795800E+04, -.99393100E+04, -.16908900E+05, 0.82728900E+04, -.38034300E+05, 0.84551100E+04, 0.13819100E+05, 0.14096400E+05, -.68143300E+04, -.92810300E+04, 0.28364400E+04, 0.10119400E+05, 0.10670200E+05, 0.11571900E+05, -.58479000E+04, 0.11335800E+05, -.57779400E+04, -.82572800E+04, -.83614100E+04, 0.68676300E+04, 0.48048700E+04, -.24104500E+04, -.76772900E+04, -.54026000E+04, 0.62203500E+04, -.28104800E+04, 0.17120000E+03, -.31090200E+04, -.49898800E+04, -.53453000E+04, 0.11668900E+04, 0.20013100E+04, 0.25983900E+04, -.38359800E+04, -.23255800E+04, -.51622900E+04, 0.27194700E+04, -.14912800E+05, 0.25799200E+04, 0.90019100E+04, 0.11498000E+05, -.45415100E+04, 0.20566700E+04, 0.37618900E+04, 0.82631800E+04, -.11436600E+04, 0.52521200E+05, -.26291200E+05, -.19445400E+05, -.26262000E+05, 0.26276100E+05, 0.24278700E+05, -.98722300E+04, 0.22435800E+05, -.15192100E+05, 0.16504200E+05, -.32573700E+05, 0.10245900E+05, -.52361400E+04, 0.55198400E+05, -.51206600E+04, -.43583300E+05, -.37853600E+05, 0.14628300E+05, -.31007000E+04, -.42379400E+04, -.27523900E+05, 0.12788000E+03, 0.34542400E+03, -.25579000E+03, 0.28656600E+05, -.16904700E+03, -.25386500E+05, -.28549300E+05, 0.15097900E+05, 0.98770500E+03, 0.43449000E+04, -.22885200E+05, 0.27313200E+04, 0.51417600E+04, -.28164500E+04, 0.15439000E+05, -.25696500E+04, -.11914000E+05, -.15042900E+05, 0.76664500E+04, -.58163200E+03, -.21469000E+04, -.11628800E+05, 0.16544300E+04, -.23647200E+04, 0.10407200E+04, 0.27406700E+04, 0.11825800E+04, -.55739000E+03, -.66746100E+03, 0.10558300E+04, -.55087600E+03, -.11865200E+03, -.45047000E+03, 0.97863800E+03, 0.68403400E+04, -.34294200E+04, -.27042700E+05, -.34181300E+04, 0.22864600E+05, 0.26286400E+05, -.12160600E+05, 0.38217500E+04, -.32101700E+04, 0.20473800E+05, -.91023900E+04, -.11901300E+05, 0.59988500E+04, -.20286800E+05, 0.59508900E+04, 0.12084200E+05, 0.10238400E+05, -.46614900E+04, -.33553000E+04, 0.33708300E+04, 0.76352700E+04, 0.64506900E+04, 0.41020800E+05, -.20462300E+05, -.20725800E+05, -.20511700E+05, 0.18112600E+05, 0.20196400E+05, -.92765000E+04, 0.14109000E+05, -.13370000E+05, 0.13843800E+05, -.21050100E+05, -.87992100E+04, 0.38455600E+04, -.12841300E+05, 0.43990500E+04, 0.11593800E+05, 0.11779900E+05, -.49109200E+04, -.53845700E+04, -.40357900E+04, 0.81139700E+04, 0.42940400E+04, -.25896700E+04, 0.12797200E+04, -.52515900E+05, 0.12934200E+04, 0.27889800E+05, 0.30322500E+05, -.14181500E+05, -.68847800E+04, -.64843200E+04, 0.22667300E+05, 0.54192600E+04, 0.21768600E+03, -.80277200E+02, -.30610900E+05, -.10935000E+03, 0.22809000E+05, 0.21495900E+05, -.11014100E+05, 0.14697600E+04, 0.60341300E+03, 0.15910100E+05, -.21274000E+04, -.47918400E+02, -.14116100E+05, -.14194200E+05, -.96714400E+03, -.10769100E+05, 0.58355100E+04, -.93351900E+04, 0.12428800E+05, 0.14905600E+05, 0.13248200E+05, 0.51016700E+04, -.13007900E+02, 0.66291500E+04, 0.11433600E+05, -.13887800E+05, -.38776900E+04, 0.12107600E+05, -.96152600E+04, 0.13118900E+05, 0.59521800E+04, -.24005700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.80048300E-01, 0.63100100E-01, 0.56803800E+00, 0.37823800E+00, 0.69678800E+00, -.48189700E+00, 0.66750600E+00, -.11554400E+00, 0.12996900E+00, -.81365100E-02, -.24103400E-01, -.30042300E-01, 0.82275900E-01, 0.44960600E-01, 0.32221100E-01, 0.87080100E-02, -.17983100E-01, 0.25859800E-01, 0.14436800E-01, 0.75419700E-02, -.72875700E-02, 0.17650800E-02, -.62992200E-01, -.25483200E-02, -.33976800E-02, 0.28344600E+02, -.65411900E+01, 0.40175400E+02, -.39695500E+02, -.50458900E+02, -.16352200E+02, 0.44296600E+02, 0.56650600E+02, -.63509200E+03, 0.32045600E+03, 0.37354600E+03, 0.31889000E+03, 0.15847000E+03, 0.36564800E+03, -.16140900E+03, -.11834000E+03, 0.19253700E+03, 0.32995500E+03, 0.66388500E+03, -.55203700E+03, 0.27611600E+03, 0.29321400E+03, 0.27889100E+03, 0.24367300E+03, -.68197700E+01, 0.19885500E+03, 0.22180600E+03, 0.14473200E+03, -.25781200E+02, -.85809600E+02, 0.14712100E+03, -.75337000E+02, 0.13133200E+02, -.73469600E+02, -.24942000E+02, 0.19695500E+03, -.23134000E+03, -.20378000E+03, -.84892500E+02, 0.21003100E+03, -.33875100E+03, -.41150700E+03, 0.20626000E+03, 0.26421800E+03, 0.20723500E+03, 0.17142800E+03, 0.43078500E+03, -.26228100E+03, -.14903100E+03, 0.13655600E+03, 0.39000600E+03, 0.58027500E+03, 0.16178900E+03, -.74211300E+02, -.77537500E+02, -.80678800E+02, -.13711300E+03, 0.10377000E+03, -.72329200E+02, -.22434000E+03, -.33926300E+03, 0.10127200E+03, 0.27541800E+03, -.11156500E+03, 0.57930300E+02, -.11303300E+03, 0.55563300E+02, -.10774700E+03, -.46369800E+02, 0.20568200E+03, 0.15214400E+03, 0.14513800E+03, -.97805000E+02, 0.80016800E+02, -.13120900E+04, 0.65599400E+03, 0.84954800E+03, 0.65586200E+03, 0.72168700E+03, -.57548200E+03, 0.81571100E+03, 0.10731100E+04, 0.84699400E+03, -.66142600E+03, -.73218200E+03, 0.49335600E+03, -.24626900E+03, -.94910000E+02, -.24635100E+03, -.29692700E+03, 0.75962900E+03, -.82758600E+03, -.11737400E+04, -.82027900E+03, 0.79107400E+03, 0.79986500E+03, -.89051700E+02, 0.43670400E+02, 0.80692200E+01, 0.45007500E+02, 0.33451800E+02, 0.19413100E+03, -.34276000E+03, -.33361500E+03, 0.16930100E+03, 0.25034000E+03, 0.69689500E+03, -.85434500E+03, 0.42348000E+03, 0.49452600E+03, 0.42761100E+03, 0.15697700E+03, 0.69254900E+02, -.46711400E+02, -.15042900E+03, 0.19129300E+03, 0.12723300E+03, 0.31360500E+03, -.13165500E+03, 0.65916100E+02, 0.55485700E+02, 0.65880800E+02, 0.18417600E+02, 0.36575300E+02, -.24731500E+02, -.54798700E+02, 0.27324800E+02, 0.36284500E+02, 0.43688000E+02, 0.10629500E+03, -.53961600E+02, -.76518400E+02, -.52867900E+02, -.43431400E+02, -.13218000E+03, 0.34870400E+03, 0.38487500E+03, 0.16371600E+01, -.18118300E+03, -.49699900E+03, 0.76313400E+03, -.38045400E+03, -.46724900E+03, -.38151000E+03, -.20270700E+03, -.36614800E+03, 0.16870100E+03, 0.39652100E+03, 0.42038100E+02, -.36359900E+03, -.47952700E+03, -.46151000E+03, 0.23100000E+03, 0.18350500E+03, 0.23058200E+03, 0.41454500E+03, -.31455600E+03, 0.45909600E+03, 0.72608700E+03, 0.49556700E+03, -.40792600E+03, -.70832600E+03, -.34082000E+02, 0.79030700E+01, -.50946900E+02, 0.16827700E+02, 0.24447500E+03, -.15487400E+03, -.42350500E+01, 0.27979400E+03, 0.48422300E+03, -.15341300E+03, -.54284100E+03, 0.62365300E+03, -.31394800E+03, -.20615900E+03, -.31204400E+03, 0.13561100E+03, 0.94829900E+02, -.19057900E+03, 0.15170900E+03, -.65496700E+02, 0.30373800E+02, -.11019700E+04, 0.70826300E+02, -.35033600E+02, -.42993100E+02, -.35487400E+02, 0.73205600E+02, -.27438400E+03, 0.27327800E+03, 0.32310800E+03, -.54605000E+01, -.32062800E+03, -.47936500E+03, 0.57565300E+01, 0.16303600E+03, -.16133800E+03, -.63871500E+02, -.24713300E+03, -.19560800E+03, 0.11618300E+03, 0.20704300E+03, -.81007100E+02, 0.17919700E+03, -.12904300E+03, -.14536400E+03, -.45486600E+02, 0.15639200E+03, -.16734200E+03, -.11131400E+03, -.16986300E+03, 0.28268000E+03, -.15297200E+03, -.16184500E+03, 0.10701600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35928000E+00, 0.35805400E+01, 0.47192900E+01, 0.33749200E+01, -.20946800E+01, 0.33924700E+01, -.18900700E+01, -.25351100E+00, -.45468400E+01, -.21820600E+01, 0.23686600E+00, 0.10619000E+01, -.49387300E+01, -.25235900E+01, -.69097600E+00, -.13742800E+01, 0.18183200E+01, -.12677600E+01, 0.11964800E+01, -.16254400E+01, 0.10820600E+00, 0.26195700E-01, 0.57235600E+01, 0.60405700E-01, 0.15582200E+01, 0.37085700E-02, 0.46204100E+04, 0.46059100E+03, 0.10785600E+04, 0.49023300E+04, 0.12830800E+04, -.79258100E+03, -.43120500E+04, 0.13351900E+05, -.67392500E+04, -.18737900E+05, -.67393800E+04, 0.32794300E+04, -.19807500E+04, -.36223100E+04, -.12683900E+04, -.25223000E+04, -.15914000E+04, -.24019100E+05, -.48181800E+05, 0.24050500E+05, 0.19510200E+05, 0.24115700E+05, -.32498900E+05, -.12527400E+05, 0.12319600E+04, -.36880700E+05, 0.75989300E+04, -.30128500E+04, 0.42570000E+05, -.66958500E+05, 0.33508000E+05, 0.40855800E+05, 0.33475000E+05, 0.91771800E+04, -.19881900E+05, 0.26609200E+05, 0.12036100E+05, 0.24826800E+05, -.13218700E+05, 0.23063200E+05, -.28347100E+04, 0.14246700E+04, -.10691500E+05, 0.13474800E+04, 0.22361000E+04, -.76238700E+04, -.12163600E+03, -.16411600E+04, 0.31952300E+04, -.64235400E+04, -.13450900E+05, -.24442100E+05, 0.12118700E+05, 0.43608100E+04, 0.12210800E+05, 0.10715100E+05, -.59639300E+04, 0.78755100E+04, 0.73985900E+04, 0.11795200E+05, -.95452000E+04, -.28743000E+04, 0.28695200E+05, -.14327100E+05, 0.39777400E+04, -.14337300E+05, -.13460200E+05, -.15169000E+05, -.26198800E+04, -.99660500E+04, -.16037700E+05, -.84563900E+04, 0.45027200E+04, 0.19508200E+05, -.97630800E+04, -.28206200E+05, -.97457200E+04, -.11348700E+06, 0.11516500E+05, -.51016600E+05, -.13038700E+06, -.43169700E+05, 0.33898400E+05, 0.99511900E+05, -.16289500E+04, 0.79350400E+03, -.11438500E+05, 0.79925000E+03, 0.87281500E+05, 0.53023600E+03, 0.26601600E+05, 0.94922200E+05, 0.28617800E+05, -.21635900E+05, -.77309100E+05, 0.45646800E+05, -.22827800E+05, -.25057200E+05, -.22845700E+05, 0.40380100E+05, 0.36910700E+05, -.14566300E+05, 0.26058100E+05, -.10581600E+05, 0.23563400E+05, -.56476800E+05, 0.15087900E+05, -.75268200E+04, -.18745500E+05, -.75651400E+04, 0.14780000E+05, 0.24649600E+05, -.10219600E+05, 0.69705700E+04, -.23891100E+04, 0.17771000E+05, -.21121700E+05, 0.77655000E+04, -.38947900E+04, -.43019500E+04, -.38853000E+04, 0.19304400E+03, -.61345700E+03, -.94608700E+03, 0.25136000E+04, -.14235700E+04, -.72663100E+03, -.33255500E+04, -.40571800E+05, 0.20313400E+05, 0.19451400E+05, 0.20272900E+05, -.42833300E+05, -.41872300E+05, 0.10731400E+05, -.33829600E+05, 0.79733800E+04, -.27661400E+05, 0.58065900E+05, -.23902900E+05, 0.11925800E+05, 0.12040200E+05, 0.11948700E+05, -.64975000E+04, 0.47866600E+03, 0.12151400E+04, -.15663400E+05, 0.49806200E+04, 0.50830300E+04, 0.21682800E+05, -.14809900E+05, 0.74019100E+04, 0.92307800E+04, 0.74129400E+04, -.67012300E+05, -.11653100E+04, -.24479400E+05, -.79099500E+05, -.18690400E+05, 0.15863900E+05, 0.74298200E+05, 0.12569300E+05, -.61246200E+04, 0.82590200E+04, -.62743600E+04, -.17946000E+05, 0.60778600E+04, -.47188200E+04, -.13572300E+05, -.11578900E+05, 0.14295600E+05, 0.13065800E+05, -.10309400E+06, 0.51633800E+05, 0.58119800E+05, 0.51557300E+05, -.26822900E+05, -.33844800E+05, 0.27388200E+05, -.19020100E+05, 0.29480600E+05, -.17327300E+05, 0.70994100E+05, -.25941300E+05, 0.12946600E+05, 0.10047800E+05, 0.12974100E+05, -.41963700E+05, -.12406100E+05, -.10561000E+04, -.40639800E+05, -.31031800E+03, -.18764800E+03, 0.48579400E+05, -.65022400E+03, 0.48357300E+04, 0.36834300E+05, 0.55250200E+04, 0.34396500E+05, 0.11207700E+05, 0.26171100E+04, -.35823700E+05, -.65251900E+04, -.37928600E+05, 0.20542100E+04, -.31408600E+03, 0.76528000E+04, -.33805600E+05, 0.36634000E+05, 0.12053700E+05, -.45951000E+04, -.10434600E+05, -.35698500E+04, 0.45591000E+04, -.15285100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.53544000E-01, -.38685600E+00, 0.31035400E+01, -.20287500E+00, 0.50770700E-01, -.11655200E+01, 0.16057300E+01, -.13483000E+00, 0.10025600E+01, 0.65269800E+00, -.33366500E+00, -.30684300E+00, 0.10680100E+01, 0.90361500E+00, -.16990900E-01, 0.55286900E+00, -.17109900E+00, -.20970200E-01, 0.22878700E+00, 0.53121800E-01, 0.94772600E-02, 0.14855300E+00, -.53727600E+00, 0.69459000E-01, -.31250600E-01, 0.65738200E-03, -.76244500E-01, 0.79904000E+03, -.46479300E+03, -.89095500E+03, -.23141100E+03, 0.79230100E+03, 0.30283700E+03, -.70712900E+04, 0.35428600E+04, 0.17171400E+04, 0.35259900E+04, 0.82461300E+03, -.12738700E+04, 0.14659200E+04, -.16997400E+04, 0.23555300E+04, -.81517400E+03, 0.13444700E+04, 0.49838500E+04, -.24732300E+04, -.48562700E+04, -.24901000E+04, -.10649900E+04, -.27949300E+04, 0.29830500E+03, 0.34582100E+04, -.87813200E+03, -.29833700E+04, -.28741300E+04, 0.12248000E+05, -.61177100E+04, 0.33877600E+04, -.61244600E+04, 0.13878100E+04, 0.30336100E+04, -.79523900E+03, 0.62963600E+04, -.34171900E+04, 0.14341900E+04, -.44521300E+04, -.71719000E+04, 0.36024000E+04, 0.16871600E+04, 0.35754900E+04, 0.87495300E+03, -.99140400E+03, 0.12719100E+04, -.20634300E+04, 0.20489900E+04, -.48235000E+03, 0.18665400E+04, -.10658200E+05, 0.53147300E+04, 0.40064700E+04, 0.53275700E+04, -.42133100E+03, -.16352800E+04, 0.19235900E+04, -.29509700E+04, 0.40110000E+04, -.10334400E+04, 0.49884200E+04, 0.14913800E+05, -.74656600E+04, -.39332300E+04, -.74554300E+04, -.96634900E+02, 0.34875100E+02, -.21544000E+04, 0.30385200E+04, -.48348200E+04, -.71610800E+03, -.59900600E+04, -.27314000E+05, 0.13668400E+05, -.21368800E+04, 0.13657800E+05, -.16535800E+04, -.20375100E+05, 0.13279600E+05, 0.10336900E+05, 0.12342000E+05, -.19802000E+05, 0.59338300E+04, -.66771500E+04, 0.33440200E+04, -.34593400E+04, 0.33368600E+04, -.88486400E+03, 0.11151000E+05, -.67398700E+04, -.17924900E+05, -.17763000E+04, 0.11490800E+05, 0.94152900E+04, -.80720800E+04, 0.40439300E+04, 0.26675300E+04, 0.40338800E+04, -.49667900E+02, 0.22739100E+04, -.25342700E+03, -.48090400E+04, 0.27917300E+04, 0.27372400E+04, 0.39843700E+04, -.10019200E+05, 0.50264100E+04, 0.26969500E+04, 0.50051600E+04, 0.61906800E+03, 0.64057200E+03, 0.10695800E+04, -.24204600E+04, 0.31122300E+04, 0.98639100E+03, 0.33854000E+04, -.15294300E+03, 0.70372500E+02, 0.16026300E+03, 0.76020600E+02, 0.13056100E+03, 0.14834300E+03, -.64467200E+02, -.17494500E+03, -.10437300E+03, 0.18132300E+03, 0.11390800E+03, 0.69047500E+04, -.34558100E+04, -.76155400E+04, -.34537300E+04, -.11945800E+04, -.42021200E+04, 0.65586200E+03, 0.42252900E+04, -.17095200E+04, -.41160100E+04, -.24049800E+04, 0.99205800E+04, -.49585800E+04, -.12973700E+03, -.49607700E+04, 0.17261300E+04, 0.11149300E+04, -.11523100E+04, 0.52498900E+04, -.26872600E+04, 0.14296100E+04, -.60991900E+04, 0.27777900E+05, -.13883100E+05, -.12770000E+05, -.13888100E+05, -.60309900E+03, 0.16703300E+04, -.67386100E+04, 0.45090500E+04, -.11109000E+05, 0.63304200E+03, -.15213600E+05, 0.22699500E+05, -.11315900E+05, -.57233400E+04, -.11347500E+05, 0.89142300E+03, 0.33403000E+04, -.34282900E+04, 0.78118700E+04, -.77928400E+04, 0.22547100E+04, -.11101900E+05, 0.14661500E+05, -.73444300E+04, 0.55253200E+03, -.73295200E+04, 0.10194500E+04, 0.17759700E+04, -.12032900E+04, 0.77393500E+04, -.56710600E+04, 0.35559300E+03, -.79010200E+04, 0.15983100E+04, -.79497700E+03, -.45567200E+03, -.79875700E+03, -.30131900E+03, -.61397300E+04, 0.33582900E+04, 0.75029300E+04, 0.13192300E+04, -.58067100E+04, -.29184500E+04, -.16767300E+02, 0.27016600E+04, -.24465000E+04, -.88986000E+03, -.33785500E+04, -.40244300E+04, 0.25795600E+04, 0.34004200E+04, -.40262500E+04, 0.15251300E+04, -.38614400E+04, -.18220000E+04, -.20049000E+04, 0.23162600E+04, -.24611200E+04, -.20787700E+04, -.26970900E+04, 0.67713000E+04, -.33900500E+04, -.33852600E+04, 0.23016700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42180900E-01, -.96846900E-01, -.57308700E+00, -.16444500E+00, 0.18158900E+00, 0.49256900E-01, 0.22792000E+00, 0.53786300E-01, -.44853100E+00, -.20467800E+00, 0.10187400E+00, 0.87861100E-01, -.22253700E+00, -.31934900E+00, -.28987600E+00, 0.18897500E+00, -.12474900E+00, -.35417900E+00, -.33247200E+00, 0.39370100E+00, 0.16952000E-01, 0.10256100E+00, -.44307900E+00, -.21456000E-01, -.11210600E+00, 0.15138200E-03, -.12227300E+00, -.27295500E+00, 0.33085800E+03, 0.17701500E+03, 0.17543800E+03, -.54539000E+02, -.46222800E+01, 0.23360500E+03, 0.61085800E+02, -.28228400E+04, -.12595200E+03, -.19637400E+04, -.37692200E+04, 0.50311500E+04, 0.17498000E+04, 0.19966800E+04, -.34791600E+04, -.12889900E+04, 0.17306100E+04, -.98361900E+03, -.20431700E+04, -.86190900E+03, -.21287600E+04, -.14757100E+04, -.98359000E+03, -.12455100E+04, -.42214700E+03, -.13870100E+04, 0.65563800E+02, 0.72347200E+04, -.37623400E+04, 0.15276000E+04, -.36177900E+04, 0.89311700E+03, -.44789200E+03, 0.22465100E+04, 0.58121300E+04, -.26768500E+04, -.14365200E+04, -.41573500E+04, -.83129500E+01, -.52424200E+02, -.26075800E+04, -.57711900E+01, -.24290300E+04, -.47214900E+04, 0.56382500E+04, 0.14316800E+04, 0.17373000E+04, -.44012600E+04, -.57295100E+03, -.26929000E+04, 0.15106100E+04, 0.34099900E+02, 0.13450000E+04, -.50370800E+03, -.15082900E+04, 0.27511600E+03, 0.22892900E+03, 0.31904500E+04, -.11558100E+04, 0.91303700E+03, 0.86805300E+04, -.42346400E+04, -.21200200E+04, -.43388400E+04, 0.15904400E+04, 0.18380300E+04, -.54010600E+04, -.20216200E+04, -.47381900E+04, 0.15328100E+04, -.28883700E+04, -.10413600E+05, 0.51756700E+04, -.58304700E+04, 0.52076400E+04, -.66841500E+04, -.84680600E+04, 0.16670500E+04, -.65834000E+04, 0.19006700E+04, -.67449900E+04, 0.77778100E+04, -.71805500E+04, 0.34701100E+04, -.14133400E+04, 0.35886000E+04, 0.16963400E+04, 0.10470100E+03, 0.40759500E+04, 0.56904800E+03, 0.38300900E+04, -.26434400E+03, 0.29291700E+04, 0.55020000E+04, -.28182000E+04, -.40205800E+04, -.27531400E+04, -.25245500E+04, -.26971900E+04, 0.51465600E+04, 0.42505600E+04, 0.29469000E+04, -.28306400E+04, -.31859700E+04, -.57781600E+03, 0.11243600E+03, -.12446600E+04, 0.28482200E+03, -.22962300E+04, -.25750600E+04, 0.57315200E+04, 0.34104700E+04, 0.26205700E+04, -.23732900E+04, -.82707200E+03, 0.13542700E+03, -.21398200E+03, -.23750200E+03, -.68132100E+02, -.16306000E+03, -.41353900E+03, 0.63658000E+03, 0.18197900E+03, -.22576900E+03, -.36869800E+03, 0.37721800E+02, -.38652300E+04, 0.19405000E+04, -.11214900E+04, 0.19312800E+04, 0.46384500E+03, -.35030500E+03, -.42812700E+04, -.43333800E+04, -.16318500E+04, 0.12321800E+03, 0.40016900E+04, 0.59275800E+04, -.29325700E+04, 0.24109400E+04, -.29642400E+04, 0.18397200E+04, 0.36058000E+04, -.34808500E+04, 0.29425500E+03, -.31260900E+04, 0.37526100E+04, -.37653900E+04, 0.15321100E+05, -.76191000E+04, -.64509800E+04, -.76597700E+04, -.25591000E+04, 0.17915700E+04, -.69747700E+04, -.68123000E+04, -.92140600E+04, 0.24394200E+04, -.51952400E+04, 0.10687200E+05, -.57036200E+04, -.65531800E+03, -.53415800E+04, 0.60852100E+03, 0.24503200E+04, -.62999200E+03, 0.19422800E+04, -.64615700E+04, 0.18699500E+04, -.50816900E+04, 0.52070400E+03, -.23009900E+03, 0.34392700E+04, -.25914900E+03, 0.19451100E+02, -.11237600E+04, 0.22708700E+04, 0.13117000E+04, -.48277400E+04, -.11553900E+04, -.17643600E+04, -.21838400E+04, 0.11117300E+04, 0.15633400E+04, 0.10923100E+04, 0.97663000E+02, 0.47584100E+03, -.30341000E+04, -.18214000E+04, -.57683200E+03, 0.10067600E+04, 0.10222800E+04, -.38943200E+01, 0.35344000E+03, -.29771700E+03, 0.72884400E+02, 0.10029400E+04, -.70589000E+03, 0.22191600E+03, -.24846600E+02, -.10899400E+04, -.22746600E+04, -.16527800E+04, -.51040700E+03, 0.66267100E+03, -.12896300E+04, -.20636300E+03, 0.56462400E+03, -.26181900E+03, 0.18888300E+04, -.42434000E+03, 0.13628600E+03, 0.37009000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13839300E+00, -.96588800E+00, -.26384600E+01, -.16695600E+01, 0.19612000E+00, 0.81714300E-01, -.67445400E+00, 0.12947900E+00, -.19868400E+01, -.73404900E+00, 0.12814800E+00, -.25765100E+00, -.10598700E+01, 0.68991100E+00, 0.26955600E+00, -.14715100E+01, 0.99104500E+00, 0.11812900E+01, -.60541200E+00, -.12386300E+00, -.31381100E-01, 0.89100100E-01, -.55407800E-01, -.61093700E-01, -.24284100E+00, -.87216800E-03, 0.11028000E-01, 0.11046300E+01, 0.20649700E+00, 0.46003100E+03, 0.14960300E+03, 0.69202500E+01, 0.49531700E+03, 0.21974100E+04, -.96698900E+03, 0.59716500E+03, -.10782400E+04, 0.10895200E+04, 0.56983900E+04, -.28949600E+04, 0.22714100E+04, 0.52574400E+03, 0.44466800E+04, 0.74846600E+04, -.61202800E+04, 0.29970300E+04, 0.59175200E+04, 0.30565400E+04, 0.31513600E+04, 0.11009600E+03, 0.12373300E+04, -.77504500E+03, 0.20521800E+04, -.85210400E+02, -.71615100E+03, 0.12578000E+05, -.63991000E+04, -.17384900E+05, -.62881400E+04, -.70034700E+04, -.53222200E+04, -.37049000E+04, -.59212400E+04, -.33770200E+04, -.45763000E+04, -.52490400E+04, 0.56239500E+04, -.28620500E+04, -.71533000E+03, -.27898700E+04, 0.79603200E+03, 0.56338300E+04, -.34895800E+04, 0.27026800E+04, -.17906200E+03, 0.43301800E+04, 0.47743000E+04, 0.13786700E+05, -.67401700E+04, -.35551000E+04, -.68901300E+04, -.13296600E+04, 0.40518900E+04, -.30548400E+04, 0.82527000E+03, -.77824600E+04, 0.43934100E+04, -.34364100E+04, -.16676600E+05, 0.83883900E+04, 0.35146000E+04, 0.83351800E+04, -.29539200E+03, -.20302400E+04, 0.40268100E+04, -.28984300E+04, 0.58904100E+04, -.14504000E+04, 0.25816200E+04, -.39038200E+04, 0.19239700E+04, 0.19763000E+05, 0.19502400E+04, 0.99184200E+04, 0.56965200E+04, 0.16784600E+03, -.97288100E+03, 0.35533400E+04, 0.48393400E+04, -.12698100E+05, 0.15508300E+05, -.78221800E+04, 0.19916000E+03, -.77507100E+04, -.28177100E+04, 0.15928100E+04, -.22153700E+04, 0.91049800E+04, -.61251600E+04, 0.19559200E+04, 0.34702900E+03, 0.43059600E+04, -.21985500E+04, -.10480100E+04, -.21488600E+04, 0.12846000E+04, 0.28112800E+04, -.22765500E+04, 0.36282400E+04, 0.34937400E+02, 0.25153700E+04, 0.63696000E+04, 0.27851200E+04, -.15097100E+04, 0.14826400E+04, -.13827500E+04, 0.64093400E+03, 0.11210000E+04, -.13063300E+04, 0.23395800E+04, -.29210500E+03, 0.80730000E+03, 0.30270000E+04, -.14775200E+04, 0.67440900E+03, 0.49810600E+03, 0.73973900E+03, 0.78936700E+02, 0.22684800E+03, 0.62782200E+02, -.37072300E+02, 0.68234800E+03, 0.14437200E+03, 0.56296500E+03, -.57773600E+04, 0.28760300E+04, 0.77816800E+04, 0.28913400E+04, 0.71364700E+03, -.17605900E+03, 0.26634300E+04, -.26112300E+04, 0.84276200E+03, -.29495000E+03, -.68786400E+04, -.47779400E+03, 0.27744800E+03, -.42672700E+04, 0.23993600E+03, -.31102700E+04, -.38090000E+04, 0.15757400E+04, -.29044000E+04, 0.57256800E+02, -.42745800E+04, -.90432300E+03, -.46013900E+05, 0.23028200E+05, 0.21853500E+05, 0.23005400E+05, 0.71796600E+04, -.11165400E+05, 0.15430500E+05, 0.25882800E+04, 0.21699200E+05, -.10833100E+05, 0.65966500E+04, -.20271300E+05, 0.98161000E+04, 0.96821200E+03, 0.10130800E+05, 0.14799000E+04, -.75345600E+04, 0.35953300E+04, -.40837100E+04, 0.11920600E+05, -.81891500E+04, 0.66020600E+04, -.21904800E+03, 0.83658100E+02, -.88651200E+04, 0.10699200E+03, -.43837900E+04, -.89428400E+04, 0.56027100E+03, -.64719500E+04, 0.26848900E+04, -.83804500E+04, -.63199100E+04, -.14177500E+04, 0.73974200E+03, 0.44886900E+03, 0.70807600E+03, 0.76886800E+03, 0.87348300E+02, -.45430000E+02, -.49047400E+04, -.14938300E+04, -.30659200E+03, -.42966900E+04, 0.56018300E+02, 0.10865900E+04, 0.60585500E+03, -.59010700E+02, 0.15755900E+04, -.84596000E+03, 0.14697300E+04, -.18886900E+04, 0.98336200E+03, -.42191200E+03, 0.45515300E+03, -.11084600E+04, 0.18538200E+04, -.60834000E+03, 0.51426800E+03, 0.20074000E+04, -.10201700E+04, -.29386800E+01, -.53967200E+03, -.10018100E+04, -.16829200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17803100E+00, -.36123500E+00, -.16270000E+01, -.61046600E+00, 0.10142000E+01, 0.16351100E-02, 0.17167100E+01, 0.17053000E+00, -.18177000E+01, -.92297500E+00, 0.28868700E+00, 0.20061700E+00, -.13664900E+01, 0.61622000E-01, -.78107800E+00, -.96796700E+00, 0.15515800E+01, 0.27561700E+00, -.49690300E+00, 0.52552900E+00, 0.51624400E-01, 0.27706400E+00, -.10673400E+01, -.15745800E+00, -.54153100E+00, 0.60691000E-03, -.46229500E+00, -.79142100E+00, 0.51479600E+00, -.55698900E+00, 0.25978400E+03, -.30776300E+03, 0.49785200E+03, -.22705300E+04, 0.17978300E+04, -.47618900E+04, 0.11127600E+04, -.11222500E+04, -.35109500E+02, 0.25142700E+04, -.31470600E+04, 0.19380900E+04, -.96574400E+03, 0.19549300E+04, -.29810200E+04, 0.11610600E+04, -.17788800E+04, 0.15013000E+04, -.40879300E+03, -.75394200E+03, -.82954300E+03, -.46666200E+04, -.38494400E+03, 0.12020600E+04, -.16065300E+04, -.45906700E+05, 0.22396400E+05, 0.30314500E+05, 0.22951900E+05, 0.62731900E+04, -.84477200E+04, 0.27626200E+05, 0.22454700E+05, 0.18699100E+05, -.81859900E+04, 0.49233900E+04, -.10537500E+04, 0.34327300E+03, -.41684100E+04, 0.50214700E+03, -.22299100E+04, -.18798000E+04, 0.29061400E+04, -.32455700E+04, 0.51596700E+03, -.27066900E+04, 0.29614000E+04, 0.23352100E+05, -.11073800E+05, -.96506400E+04, -.11679700E+05, -.60839900E+04, -.24488100E+04, -.70582700E+04, -.17705500E+04, -.43316700E+04, -.31358900E+04, -.27182400E+04, 0.22715400E+05, -.11016800E+05, -.35338200E+04, -.11354100E+05, 0.11336700E+04, -.18324700E+04, -.83343700E+04, -.47500900E+04, -.10868800E+05, -.74256300E+03, -.10731300E+05, -.10799200E+05, 0.53617600E+04, -.19575600E+05, 0.54024300E+04, -.92092300E+04, -.67545600E+04, -.65917900E+04, -.28278000E+05, -.43303600E+04, -.60010000E+02, 0.66371200E+04, -.20740000E+05, 0.99326800E+04, -.20185800E+04, 0.10364800E+05, -.30241900E+03, -.36349900E+04, 0.45729300E+04, 0.12875400E+04, 0.10439500E+05, -.77212100E+04, 0.15393700E+05, 0.14543300E+05, -.74763800E+04, -.92101500E+04, -.72791700E+04, -.45069400E+04, 0.65053400E+03, 0.45032500E+03, 0.25982800E+04, 0.26360000E+04, -.14314200E+04, -.12580400E+04, -.11071800E+05, 0.49298200E+04, -.35166600E+03, 0.55280400E+04, -.41520000E+03, 0.12523300E+04, 0.67491800E+04, 0.28572300E+04, 0.70918400E+04, 0.35715800E+03, 0.41787400E+04, -.12218000E+04, 0.12940400E+03, 0.62234600E+03, 0.60997800E+03, 0.67129500E+02, -.17096400E+03, 0.54246500E+03, -.27403500E+03, -.29938400E+03, -.23580200E+03, 0.10569600E+04, -.14896400E+04, 0.72639800E+03, -.40689100E+04, 0.74041400E+03, -.49520500E+03, -.70897200E+04, -.30010200E+04, -.66084900E+04, -.44094300E+04, -.43553200E+04, 0.50437800E+03, 0.20132900E+05, -.99196600E+04, 0.17758800E+04, -.10067400E+05, 0.43873800E+04, 0.94286700E+04, -.49890500E+04, 0.47271800E+04, -.82610800E+04, 0.97135400E+04, -.14035300E+05, 0.34972500E+05, -.17247200E+05, -.15186700E+05, -.17483500E+05, 0.31947300E+04, 0.10459200E+05, -.21974800E+05, -.26217700E+05, -.24509500E+05, 0.16074700E+05, -.19599000E+05, -.35230600E+05, 0.16302900E+05, 0.21073400E+05, 0.17619100E+05, 0.10549500E+05, 0.47611600E+04, 0.14991800E+05, 0.98441900E+04, 0.82207100E+04, 0.62530800E+04, 0.60008400E+03, -.55789800E+05, 0.27900900E+05, 0.32833200E+05, 0.27898400E+05, 0.88868700E+04, -.55317800E+04, 0.24527100E+05, 0.10155100E+05, 0.11299900E+05, -.23915500E+04, 0.55748400E+04, -.30687300E+04, 0.16623800E+04, 0.26058100E+04, 0.15355500E+04, 0.71366800E+03, 0.13567300E+04, 0.44994300E+03, 0.12440400E+04, -.59411000E+03, 0.37410000E+04, -.36809300E+04, -.14837100E+03, -.44182300E+03, -.12041300E+04, -.68800100E+02, -.11946300E+04, 0.53164200E+03, 0.14066700E+04, 0.18670300E+04, -.23885100E+03, -.34025000E+04, -.21172300E+04, -.15690600E+04, 0.12175600E+04, -.19716100E+03, -.12624200E+04, 0.10768900E+04, 0.31341900E+03, -.31140600E+04, 0.54723300E+03, 0.17322600E+04, 0.23583500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15060200E+00, 0.26283700E+00, -.35923000E+00, 0.16378200E+00, -.24767800E+00, 0.66544000E-02, -.80069900E+00, 0.17486600E+00, -.61985500E+00, 0.10999900E-01, 0.46433200E-01, -.18140400E-01, -.24448100E+00, 0.54644500E+00, 0.93368600E-01, -.57734700E+00, -.29247500E-02, 0.55078300E+00, -.21453700E+00, 0.74129300E-01, -.33431500E-01, -.87734700E-01, -.11767900E+01, -.13438500E+00, -.24770000E+00, -.97061100E-03, -.23280200E+00, -.35922700E-01, -.18928800E+00, 0.37956200E+00, -.20722900E+00, -.17215400E+03, -.65035100E+03, 0.11725400E+04, -.42218800E+03, -.15868900E+04, -.60025300E+03, -.12919100E+04, -.22272900E+04, -.37716000E+03, -.38718800E+04, -.30547700E+04, -.19930800E+04, -.73130700E+04, 0.89102100E+03, -.47348800E+03, -.28619800E+04, -.44021900E+03, -.23849200E+04, -.74765100E+03, -.67361000E+03, -.23318700E+04, -.91140100E+03, 0.69881800E+03, 0.29837000E+04, -.32924700E+05, 0.16321800E+05, 0.21514000E+05, 0.16461600E+05, 0.93892700E+04, -.61741800E+03, 0.93337800E+04, 0.37018400E+04, 0.94286300E+04, 0.89645900E+02, 0.12387700E+05, -.29749800E+04, 0.14917200E+04, 0.65530500E+03, 0.14722700E+04, -.79135100E+03, -.20438300E+04, 0.44051000E+03, -.37146400E+04, -.22976000E+04, -.17790300E+04, -.43934600E+04, -.33674700E+04, 0.18556300E+04, -.51588400E+02, 0.16815000E+04, -.53994600E+03, -.29833300E+04, 0.24075700E+04, 0.36439600E+04, 0.67707300E+04, -.43107100E+04, -.44923300E+03, 0.16386500E+05, -.80665300E+04, -.14147300E+04, -.81910600E+04, 0.46209900E+02, -.23436100E+04, -.14742400E+04, 0.29807600E+04, -.53122800E+04, -.14473000E+04, -.25168800E+04, 0.93069400E+04, -.45991700E+04, -.15989100E+05, -.46520400E+04, -.10021800E+05, 0.10410700E+04, -.67671700E+04, -.10737800E+05, -.87104300E+04, 0.44918100E+04, 0.13178100E+05, -.10746800E+05, 0.52709400E+04, -.44630400E+03, 0.53706200E+04, 0.21397200E+04, -.19877600E+04, 0.24649800E+04, 0.87713000E+03, 0.79494200E+04, -.52810900E+04, -.49778500E+04, 0.34887900E+04, -.17754400E+04, -.16376700E+04, -.17480700E+04, -.19033900E+04, 0.11746900E+04, -.12550500E+04, -.14641300E+04, -.22856600E+04, -.36329000E+03, -.95929200E+04, -.35913700E+04, 0.16155400E+04, -.23878800E+04, 0.17898000E+04, 0.30806700E+03, 0.27437600E+04, -.15293400E+04, -.37849000E+04, -.14922800E+03, 0.20393500E+04, -.30368000E+04, 0.20276500E+03, -.21807000E+03, 0.41861300E+03, -.10201100E+03, 0.23932800E+03, 0.18901200E+03, -.16317300E+03, -.21521700E+03, -.70137000E+03, 0.21073200E+03, -.72170200E+02, 0.14631700E+04, -.75034600E+03, -.25293300E+04, -.73382500E+03, 0.78674700E+02, -.34651400E+04, 0.22777600E+03, 0.31299100E+03, 0.15253900E+03, -.17562300E+04, 0.88499000E+04, -.13753800E+03, 0.10913900E+03, 0.20570800E+04, 0.68103200E+02, 0.37490100E+04, 0.43967600E+04, -.15784400E+04, 0.41776200E+03, -.11610200E+04, 0.48950300E+04, 0.19735600E+04, 0.31176300E+05, -.15461200E+05, -.14733300E+05, -.15586800E+05, -.45768000E+04, 0.97269100E+04, -.14726900E+05, -.10883000E+05, -.18872500E+05, 0.12904000E+05, -.28506900E+03, -.60199000E+03, 0.57049100E+01, 0.62084900E+04, 0.30390400E+03, 0.17827400E+04, 0.47164100E+04, -.11681900E+04, -.35323900E+04, -.89610800E+04, 0.73255900E+04, 0.15100500E+04, -.28559600E+05, 0.14258500E+05, 0.17994900E+05, 0.14281700E+05, 0.87901900E+04, 0.38058100E+04, 0.50592900E+04, -.75470700E+02, 0.37226000E+04, 0.58741400E+04, 0.17445400E+05, 0.80600100E+03, -.36586200E+03, -.69729100E+03, -.40236700E+03, -.57829400E+03, -.30440900E+03, 0.33771200E+03, 0.11080300E+04, 0.69832900E+03, 0.13002800E+04, 0.57411300E+04, -.15424100E+03, -.47694000E+03, -.83366500E+03, 0.22154800E+03, -.23140300E+04, 0.16493600E+04, -.73421200E+03, 0.24002000E+04, 0.15644500E+04, -.20244300E+03, 0.48546500E+03, 0.87544000E+03, -.10317900E+04, 0.10575200E+04, -.87326700E+03, -.43886800E+03, 0.29174000E+03, -.34943500E+04, 0.14155500E+04, 0.23946900E+04, 0.79423400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24027600E+00, 0.14679400E+01, 0.11888200E+01, 0.46404200E+00, 0.63316400E+00, 0.25662800E+00, -.70500800E+00, -.58922200E-01, -.49774100E+00, -.12485900E+01, 0.18123200E+00, -.21223600E-01, -.47224200E+00, -.55367200E+00, -.63914600E+00, 0.46441200E+00, -.46032700E+00, -.21091200E+00, -.10726000E+00, -.46979200E+00, -.31652600E-01, -.16276800E+00, -.36761800E+00, -.64995800E-01, -.78380700E+00, -.13486700E-02, -.35664400E-01, -.70688300E+00, 0.12998600E+01, -.79029600E+00, 0.46970500E+00, -.15871600E+01, -.14998600E+04, 0.13901800E+05, -.71821600E+04, -.15079900E+03, -.69351400E+04, -.12430900E+04, -.32719900E+04, -.33600800E+04, -.99222100E+03, -.53098600E+04, -.28814200E+04, -.14558200E+05, -.46223800E+04, 0.24507000E+04, 0.46378600E+04, 0.23092500E+04, -.14003900E+04, -.73507900E+02, 0.16948000E+04, 0.15489800E+04, 0.23854800E+04, -.16809000E+03, 0.97540200E+04, 0.79709100E+04, -.37976100E+04, -.16461900E+05, -.39850600E+04, 0.52434300E+03, -.80352400E+03, -.11596700E+05, -.17617000E+05, -.95350000E+04, 0.14559700E+04, 0.59389100E+04, 0.54061300E+04, -.26106200E+04, 0.28981100E+04, -.26862300E+04, -.56475900E+03, -.21093700E+04, -.61307900E+03, 0.14458800E+04, -.15372200E+04, -.17334600E+04, -.12086500E+05, -.10845900E+05, 0.52548400E+04, 0.78274000E+04, 0.54254000E+04, 0.36193100E+04, 0.26757700E+03, 0.64960900E+04, 0.78775100E+04, 0.82074000E+04, -.72746200E+03, -.45741800E+04, -.10507100E+05, 0.51978900E+04, 0.80164200E+03, 0.52512300E+04, -.32904300E+03, -.32575200E+04, 0.91266800E+04, 0.93459700E+04, 0.61580000E+04, -.19004300E+04, 0.80533100E+04, 0.30694100E+05, -.15290000E+05, 0.11630900E+05, -.15347800E+05, 0.13427900E+04, 0.15514600E+05, -.50674900E+04, 0.15031600E+05, -.99074000E+04, 0.13399800E+05, 0.11534800E+05, 0.20785900E+05, -.10239100E+05, 0.17141300E+04, -.10391100E+05, 0.45199000E+04, 0.30598000E+04, -.33621900E+04, 0.63950800E+04, -.18584500E+04, 0.17119500E+04, -.31750600E+05, -.24713000E+03, 0.19841700E+03, 0.40127200E+04, 0.12509500E+03, 0.14495500E+03, -.77893500E+03, -.12210200E+04, -.96492500E+03, -.66559600E+02, -.18738900E+04, -.14764300E+05, 0.17974800E+05, -.88303300E+04, -.39304600E+04, -.89784100E+04, 0.20348100E+03, 0.24704400E+04, -.10982800E+05, -.96857700E+04, -.99589200E+04, 0.16010100E+04, -.95123800E+04, 0.93851300E+03, -.30266000E+03, -.20465800E+03, -.46846900E+03, 0.29011300E+02, 0.37989900E+02, -.17453300E+03, 0.18335200E+03, -.43145400E+03, 0.13793700E+03, -.10086400E+04, 0.27394600E+03, -.13221300E+03, 0.86954400E+04, -.13574700E+03, 0.38121900E+04, 0.45832600E+04, 0.25336100E+04, 0.50435700E+04, 0.41876600E+03, 0.47940100E+04, 0.81159700E+04, -.26983400E+05, 0.13436100E+05, -.31000300E+04, 0.13492600E+05, -.23317800E+04, -.64879400E+04, 0.46946500E+04, -.69077800E+04, 0.83051700E+04, -.61496800E+04, 0.21677400E+05, -.17993600E+05, 0.89648500E+04, 0.60527400E+04, 0.89961000E+04, -.69427800E+04, -.18460900E+04, 0.10157000E+05, 0.12942000E+05, 0.94190000E+04, -.19503000E+04, 0.35341000E+05, 0.68211500E+04, -.29623300E+04, -.14906400E+05, -.34151600E+04, -.73872800E+04, -.47371700E+04, -.87584700E+04, -.16459000E+05, -.10713500E+05, -.26032600E+04, 0.13297600E+05, 0.17709900E+05, -.88603900E+04, -.16990500E+05, -.88565200E+04, -.18849500E+04, 0.26936500E+04, -.13206800E+05, -.12205000E+05, -.12009400E+05, 0.42052300E+04, 0.19873200E+05, -.26907700E+04, 0.12918900E+04, -.93679200E+03, 0.13449400E+04, -.90476200E+03, -.55637100E+03, 0.53971800E+01, -.15915200E+04, 0.96346700E+03, -.59695600E+03, 0.15751900E+05, -.14730200E+03, 0.26568400E+03, 0.10887200E+02, 0.40449400E+03, -.60913500E+03, 0.19419400E+04, -.30513900E+03, -.54309600E+02, 0.16161700E+04, 0.48902000E+04, 0.41992900E+04, 0.26937300E+04, -.79025300E+03, 0.26311700E+04, 0.81622300E+02, -.84160500E+03, -.55337600E+03, -.31024000E+04, 0.12852300E+03, 0.54189600E+03, -.37695700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12224800E+00, 0.57246000E+00, -.48231700E-01, 0.25913400E+00, 0.75203600E+00, 0.33512200E+00, -.34356400E+00, 0.11737200E+00, -.12257400E+01, -.73200200E+00, 0.22509300E+00, -.17666600E-01, -.30644800E+00, -.51290000E+00, -.29192000E+00, -.79562500E-01, 0.15502800E+00, 0.25888100E+00, -.15027500E+00, -.74292500E+00, -.21773100E-01, -.63862200E-01, 0.90759100E+00, 0.46570000E-02, 0.41154500E+00, 0.22028100E-02, 0.25739500E+00, 0.18301100E+00, -.36273700E+00, 0.66049900E-01, -.23053000E+00, 0.98030400E-01, -.93534100E-01, -.10772600E+05, 0.53290700E+04, 0.50358800E+04, 0.53797400E+04, 0.14347300E+04, 0.21443300E+04, 0.17862800E+04, -.84905600E+02, 0.31032600E+04, 0.21385600E+04, 0.37954000E+04, -.24220800E+04, 0.12578400E+04, 0.18688700E+04, 0.12092700E+04, 0.51987700E+03, 0.26698600E+03, 0.95285300E+03, 0.70784900E+03, 0.74594500E+03, 0.47123100E+03, 0.66933400E+03, -.71053400E+04, 0.36109500E+04, 0.92096200E+03, 0.35528700E+04, 0.66679100E+03, 0.96561100E+02, 0.38221300E+03, -.35716400E+04, 0.17350900E+04, 0.95475800E+03, 0.10331600E+03, -.70324700E+04, 0.35425800E+04, 0.31805400E+04, 0.35095000E+04, 0.13959200E+04, 0.23966700E+04, 0.56878300E+03, -.12099500E+04, 0.18156100E+04, 0.23966700E+04, 0.24402600E+04, 0.32812900E+04, -.16803400E+04, -.10039500E+04, -.16416300E+04, -.18590100E+03, 0.41227800E+03, -.12877300E+04, 0.14697300E+03, -.20344800E+04, -.10811400E+02, 0.35554100E+02, -.49678000E+04, 0.24548900E+04, 0.86663800E+03, 0.24847600E+04, -.58425700E+03, 0.77336600E+03, -.31265900E+02, -.11477900E+04, 0.59643100E+03, 0.87406700E+03, 0.43680700E+04, 0.28733100E+04, -.14259400E+04, 0.42206800E+04, -.14370800E+04, 0.11200300E+04, 0.21052100E+04, 0.16179200E+03, 0.30354300E+04, -.25270500E+03, 0.19904500E+04, -.12719400E+04, 0.53823800E+04, -.26366700E+04, 0.17742600E+02, -.26909000E+04, 0.10369400E+04, 0.20396700E+04, -.28686700E+04, -.21457000E+04, -.31869800E+04, 0.16063600E+04, -.20183400E+04, -.35426800E+03, 0.19998600E+03, 0.81084000E+03, 0.17868100E+03, 0.10456500E+04, 0.72621700E+03, -.40529100E+03, -.48184100E+03, -.17566100E+03, 0.56319600E+03, -.41189100E+03, -.36723100E+04, 0.18855400E+04, 0.23769100E+04, 0.18304100E+04, 0.60425100E+03, -.53492900E+03, 0.22312000E+04, 0.22614600E+04, 0.23911500E+04, -.51681400E+03, -.47122800E+03, 0.75022300E+02, 0.93010600E+01, -.46885200E+03, -.37913400E+02, 0.45078200E+02, 0.10755800E+03, -.10756000E+03, -.24801900E+03, 0.22467100E+03, 0.79493700E+02, -.46917700E+02, 0.63193700E+03, -.32099800E+03, 0.12422800E+04, -.31539000E+03, -.98593500E+03, 0.66482100E+03, -.28049800E+03, 0.85926300E+03, -.62056900E+03, 0.56261000E+03, 0.19100800E+04, -.11425000E+04, 0.55918000E+03, -.23096900E+04, 0.57078700E+03, -.10412400E+04, -.18975800E+04, 0.13929000E+04, 0.13337500E+04, 0.11956600E+04, -.18180900E+04, 0.83837400E+03, -.30926700E+04, 0.15259300E+04, 0.11616500E+04, 0.15459000E+04, 0.20265900E+03, -.46630800E+03, 0.23579700E+04, 0.33357600E+04, 0.24074500E+04, -.25477600E+03, 0.13009400E+04, -.41038000E+04, 0.21686300E+04, -.41533800E+03, 0.20549100E+04, 0.43372100E+03, -.12170700E+04, 0.12895600E+04, -.15980000E+04, 0.27716200E+04, -.44069700E+03, -.13862400E+04, -.20386600E+04, 0.10049200E+04, -.72211600E+03, 0.10194500E+04, 0.45353200E+03, -.24991100E+03, 0.50502700E+03, -.12670100E+04, 0.19707700E+04, 0.45749100E+03, -.26544400E+04, 0.50839100E+03, -.26505200E+03, -.55005300E+03, -.25423200E+03, 0.15565400E+02, -.60629500E+02, -.34452000E+03, -.28100600E+03, -.59664100E+03, -.97452200E+02, 0.15914100E+02, 0.49646100E+02, 0.43914300E+02, 0.11786100E+03, 0.13429100E+02, -.30279100E+03, 0.31497800E+03, -.28010900E+03, 0.46270800E+03, 0.94176600E+02, -.68800600E+03, 0.53269600E+03, -.35422900E+02, 0.43966200E+02, -.97609800E+03, 0.12875200E+03, -.10628500E+03, -.16102300E+03, -.72936900E+03, 0.58078300E+02, 0.27997900E+03, 0.24961000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.59852800E-01, 0.25862200E+00, 0.12433900E+01, 0.78271800E-01, -.50764500E+00, 0.55694100E+00, 0.12442500E+00, -.44093800E-01, 0.35702000E-01, -.68937900E-03, 0.38930400E-01, -.37400100E-01, 0.36669900E+00, 0.47702500E+00, 0.58763200E-01, -.10589400E+00, 0.11340900E+00, -.28491600E+00, 0.25420100E-01, 0.25402200E+00, 0.76371400E-01, 0.99898000E-01, 0.44932200E+00, -.40574100E-01, -.11596200E+00, 0.33550600E-03, -.18334900E+00, 0.26990600E+00, -.11154500E+00, -.92037300E-01, -.72644800E-02, 0.38138900E+00, -.19190600E+00, 0.23915200E+00, 0.17640500E+03, 0.37020600E+03, 0.11340900E+01, -.33271200E+03, -.34343400E+02, -.30277800E+03, -.56095700E+03, -.25189100E+03, -.13705200E+02, -.21084500E+02, -.20603800E+04, 0.96956700E+03, 0.20123000E+04, 0.10313500E+04, 0.18626800E+03, 0.15491700E+03, 0.24826600E+03, -.21293400E+02, 0.80796100E+03, 0.93148200E+02, 0.12575600E+04, -.52309400E+04, 0.24758800E+04, -.17531800E+04, 0.26152700E+04, -.78572500E+03, -.20371700E+04, 0.11191800E+04, -.63728700E+03, 0.18406800E+04, -.21471100E+04, 0.39020000E+04, -.11558500E+03, 0.50481600E+02, 0.75046800E+03, 0.58822400E+02, -.12968000E+03, 0.30069100E+03, -.36724100E+03, -.40688800E+03, -.31498100E+03, 0.19209500E+03, 0.46506400E+03, 0.22936600E+04, -.89295800E+03, -.76314100E+03, -.11466800E+04, -.16322000E+03, 0.25294700E+03, 0.58511100E+02, 0.57899300E+03, -.55764000E+03, 0.31930000E+03, -.19109600E+04, 0.52587300E+03, -.12066500E+03, -.10988200E+04, -.26302800E+03, 0.61811400E+02, -.15132500E+03, 0.61408300E+02, -.13843200E+03, 0.21262200E+03, -.19029400E+03, 0.19150000E+04, 0.19079500E+04, -.94911400E+03, 0.46846800E+04, -.95357300E+03, 0.10013000E+04, 0.18892500E+04, -.76907900E+02, 0.26068500E+04, 0.36197200E+03, 0.17363700E+04, -.20963700E+04, 0.46697400E+04, -.24122200E+04, -.53618000E+02, -.23354000E+04, 0.16820900E+03, 0.10197100E+04, -.18754900E+04, -.18219500E+04, -.34653200E+04, 0.12718000E+04, -.22359200E+04, 0.30836200E+04, -.15983000E+04, -.11402900E+04, -.15430600E+04, 0.78931900E+02, 0.16823600E+03, -.66952000E+03, 0.32549100E+03, -.31262100E+03, 0.29092700E+03, -.16638700E+04, -.25230000E+04, 0.10386200E+04, 0.13894800E+04, 0.12634200E+04, -.33155800E+03, -.55619200E+03, 0.59441200E+03, 0.23307800E+03, 0.74549300E+03, -.37382600E+03, -.98993700E+03, -.37871000E+03, 0.89478300E+02, 0.19236000E+03, 0.18946800E+03, -.18343300E+02, 0.36485400E+00, 0.49485600E+02, 0.10262000E+02, -.41400900E+01, -.36500600E+02, 0.19114200E+03, 0.39592200E+03, -.22130300E+03, 0.13853700E+04, -.19854900E+03, -.72166300E+02, 0.55892600E+03, -.15880500E+02, -.26441100E+03, -.30637900E+03, 0.63856900E+02, 0.17640000E+04, -.21089300E+04, 0.11042300E+04, 0.16911000E+03, 0.10545900E+04, -.14605700E+03, -.74275900E+03, 0.50325500E+03, -.92057400E+03, 0.70455600E+03, -.80564600E+03, 0.34821400E+03, -.64149800E+04, 0.32768600E+04, 0.31395200E+04, 0.32078900E+04, 0.14552400E+04, -.60085000E+03, 0.77224600E+03, -.17109400E+04, 0.21682800E+04, 0.42239100E+03, 0.92623300E+03, -.49541600E+04, 0.20568200E+04, 0.51324600E+03, 0.24760700E+04, 0.19222900E+03, -.98044700E+03, -.11471400E+01, -.16320300E+04, 0.14502100E+04, -.10521500E+04, 0.39756700E+04, -.11589200E+05, 0.57704100E+04, 0.19722700E+04, 0.57948100E+04, 0.66544800E+03, -.12958400E+04, 0.17456100E+04, -.22396500E+04, 0.26398900E+04, -.10584400E+04, 0.34486800E+04, -.61039700E+03, 0.33434300E+03, 0.34211400E+03, 0.30530500E+03, 0.54593400E+02, 0.18672100E+03, -.18297100E+03, -.71187200E+03, -.14891100E+02, 0.78144600E+02, 0.27101200E+03, 0.18155600E+02, 0.20522100E+03, -.20179100E+03, 0.26290600E+01, -.36878800E+03, 0.18291600E+03, 0.81855300E+03, 0.35512600E+03, 0.51662400E+03, -.27898900E+03, 0.42153600E+03, 0.69123900E+02, 0.60281900E+02, -.83142400E+02, -.22385900E+03, 0.15737500E+03, -.18048300E+03, -.86994800E+03, 0.60481800E+02, -.73134100E+02, -.54345800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16791900E+00, 0.73027200E+00, 0.44128000E+01, 0.31129900E+00, 0.76642000E-01, 0.12073400E+01, -.40130500E+01, 0.41605800E-01, 0.22326100E+00, -.26906500E+01, -.51300400E+00, 0.80492400E+00, 0.10987200E+01, 0.13682300E+01, 0.58088800E+00, -.12844300E+01, 0.19658300E+01, -.26627100E-01, -.61707300E+00, 0.14798800E+01, 0.10639600E+00, 0.16515700E+00, -.11114700E+01, -.15057500E+00, 0.24526900E+00, -.17412600E-02, -.81270500E-01, -.60231500E+00, -.12697700E+01, -.40785500E+00, 0.35865800E+00, -.74643700E+00, -.26973600E+00, 0.12386300E+00, 0.20357900E+01, -.95756200E+04, 0.62172700E+01, -.62562700E+03, -.12640700E+04, 0.14980400E+03, -.13637200E+04, -.12372800E+04, -.10011800E+04, -.14582400E+04, 0.18118400E+05, -.90184500E+04, -.15550800E+05, -.90602700E+04, -.28058800E+04, -.28641200E+04, -.33718900E+04, -.93302000E+03, -.62663700E+04, -.24705000E+04, -.79823000E+04, 0.15134800E+05, -.75842300E+04, 0.25911600E+05, -.75667200E+04, 0.75404200E+04, 0.16071400E+05, -.85827700E+03, 0.14591600E+05, -.38207400E+04, 0.11800000E+05, -.78893500E+04, -.14209300E+04, 0.70913000E+03, -.76574200E+04, 0.71751700E+03, -.57332400E+03, -.15548600E+04, 0.87060800E+02, -.20338300E+04, -.17851700E+04, -.10571400E+04, -.69755300E+03, -.20354900E+05, 0.10162300E+05, 0.52511300E+04, 0.10178500E+05, -.12333600E+04, -.44942000E+04, 0.53338300E+04, 0.34557100E+03, 0.10957800E+05, -.39834300E+04, 0.96065300E+04, 0.20397400E+05, -.10203900E+05, -.42448600E+03, -.10199800E+05, 0.14911200E+04, 0.15749200E+04, -.55708600E+04, -.69239600E+03, -.75249900E+04, 0.40090000E+03, -.10234400E+05, -.31430200E+05, 0.15769900E+05, -.49771800E+05, 0.15713700E+05, -.10162400E+05, -.26422500E+05, 0.53470200E+04, -.20425600E+05, 0.58682900E+04, -.22601400E+05, 0.18575700E+05, -.56363200E+05, 0.28162600E+05, -.88818900E+03, 0.28183900E+05, -.86721100E+03, -.10046700E+05, 0.12317200E+05, -.40080400E+04, 0.24606800E+05, -.91182100E+04, 0.28393400E+05, -.14702300E+05, 0.73740000E+04, -.14066500E+04, 0.73549100E+04, -.34071300E+04, -.33734400E+04, 0.37739400E+04, -.22671700E+04, 0.18889900E+04, -.23201900E+04, 0.53832900E+04, -.46299100E+04, 0.23298600E+04, -.41215800E+04, 0.23155800E+04, -.14111800E+03, 0.42085900E+03, 0.74521900E+03, -.12000000E+04, 0.13671900E+04, 0.10187700E+04, 0.20958800E+04, -.10153800E+04, 0.51168900E+03, 0.71040400E+03, 0.50787600E+03, 0.38193600E+03, 0.59801800E+03, -.26356300E+03, -.59964600E+03, -.21343300E+03, 0.67755500E+03, 0.57174000E+03, -.60726200E+04, 0.30332600E+04, -.16197900E+05, 0.30383600E+04, 0.69130300E+03, -.49668800E+04, 0.10434500E+04, -.15504700E+04, 0.42923200E+04, -.38550800E+04, 0.46916500E+04, 0.38548800E+05, -.19279100E+05, 0.16426400E+05, -.19274200E+05, 0.48478700E+04, 0.14482900E+05, -.10088200E+05, 0.70225000E+04, -.15202100E+05, 0.14046200E+05, -.19769800E+05, 0.61960700E+05, -.30918700E+05, -.23943500E+05, -.30981700E+05, -.29121500E+04, 0.58859300E+04, -.21060900E+05, -.10762000E+05, -.29378900E+05, 0.43180300E+04, -.26118100E+05, 0.45701700E+05, -.22818100E+05, 0.27793600E+04, -.22851100E+05, 0.25452700E+04, 0.13840300E+05, -.95251100E+04, 0.75918500E+04, -.21413200E+05, 0.12272100E+05, -.23474200E+05, 0.21301100E+05, -.10671000E+05, 0.12957300E+05, -.10651900E+05, 0.56077900E+04, 0.13561000E+05, -.32450100E+04, 0.12049500E+05, -.73433900E+04, 0.98824700E+04, -.90262600E+04, 0.80005900E+04, -.39901200E+04, -.79791800E+02, -.40007900E+04, -.31986600E+03, 0.91001500E+03, -.12805900E+03, 0.40441500E+04, -.11748100E+04, 0.13613400E+04, -.43069900E+04, 0.36662700E+01, -.66638900E+03, -.33484100E+03, -.45611700E+01, -.93054500E+03, -.18946200E+04, -.39330500E+04, 0.11350300E+04, 0.62771800E+03, -.12897900E+04, -.52426900E+04, -.27672800E+00, -.98051600E+03, 0.34396400E+03, -.39624000E+03, -.69340300E+03, 0.19546300E+04, 0.68443800E+04, 0.13781500E+04, 0.14052900E+04, 0.38520600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.52743000E+00, 0.15950700E+01, 0.46802200E+01, 0.37878400E+01, 0.51077200E+01, -.30596300E+01, 0.51539800E+01, -.91736200E+00, 0.32521200E+00, 0.18558900E+00, -.24793500E-01, -.23333800E+00, -.58657400E+00, 0.67657200E+00, 0.76643000E+00, -.11919900E+01, 0.11690300E+01, 0.32140500E+00, -.90487600E-01, -.24440900E+00, 0.94168500E-02, 0.50005900E-02, -.22121000E+01, -.90189300E-01, 0.34064300E-01, -.98572000E-02, -.22526000E+00, 0.28121800E+00, -.16452600E+01, 0.14495800E+00, 0.10246200E+00, 0.11814600E+01, -.36860900E+00, 0.30699800E+01, 0.15981100E+01, 0.33716000E+00, 0.12380700E+03, 0.42953300E+03, -.13418000E+04, 0.80095400E+03, 0.12495400E+04, 0.25733200E+04, -.17857800E+04, -.23338900E+03, -.95089800E+04, 0.46182000E+04, 0.51555000E+04, 0.47821900E+04, -.25262000E+02, 0.71591900E+03, 0.79912600E+03, -.24529600E+04, 0.27376600E+04, 0.19474200E+03, 0.55017600E+04, 0.17981600E+05, -.90133200E+04, -.12174900E+05, -.89889300E+04, -.31455300E+04, -.66295800E+04, 0.10935500E+04, 0.89221900E+04, -.17233200E+04, -.68449000E+04, -.10170200E+05, 0.81795200E+03, -.51439000E+03, -.84765600E+03, -.30746300E+03, -.69717000E+03, -.31296400E+04, 0.75759500E+03, 0.11129400E+04, 0.28858000E+04, -.37041700E+04, 0.18031400E+03, 0.22310900E+04, -.13220200E+04, -.15647200E+03, -.11007200E+04, 0.17349200E+04, 0.27716400E+04, -.23442900E+04, -.33967000E+04, -.38665900E+04, 0.34733000E+04, -.19347900E+04, 0.95991600E+04, -.48806700E+04, -.67362200E+04, -.48136000E+04, -.16787900E+04, -.24153600E+04, -.21971900E+04, -.14832600E+04, -.24214300E+04, -.21745700E+04, -.39171400E+04, 0.59948100E+04, -.30801100E+04, 0.31935000E+04, -.30008600E+04, 0.69189200E+03, 0.59836300E+04, -.38369300E+04, -.42422300E+04, -.36121400E+04, 0.51774000E+04, 0.40425200E+04, 0.80871600E+04, -.41513600E+04, -.10670100E+04, -.40338700E+04, 0.19218100E+03, -.69055300E+03, 0.11529600E+04, 0.53738100E+04, -.36369300E+04, -.55874500E+03, -.58780800E+04, 0.47994900E+04, -.24223500E+04, -.91287600E+03, -.23934300E+04, -.51299100E+03, -.42170600E+02, 0.59447800E+03, 0.33468900E+04, 0.22575800E+04, -.17749900E+02, -.98034900E+03, -.52666500E+04, 0.27160100E+04, 0.38089300E+04, 0.26903500E+04, 0.16004600E+04, 0.27886000E+04, 0.14646400E+04, 0.16126400E+04, 0.14099200E+04, 0.25457800E+04, 0.31205400E+04, -.58767800E+03, 0.17426200E+03, 0.13306900E+03, 0.29868500E+03, -.67537500E+02, -.49830100E+03, 0.23671500E+03, -.90673600E+02, 0.23547700E+02, -.47792700E+03, 0.19764800E+02, 0.35216800E+03, -.12200500E+03, 0.14931200E+04, -.17013100E+03, -.29690600E+03, -.12800400E+04, -.15861200E+04, -.50201000E+04, -.20489100E+04, -.86980400E+03, -.18581300E+04, -.13092900E+05, 0.65212400E+04, 0.14270800E+04, 0.65518400E+04, -.11769600E+04, -.25143500E+04, 0.26065600E+04, -.23768200E+04, 0.64529200E+04, -.26103100E+04, 0.62552000E+04, -.19461500E+05, 0.96813000E+04, 0.75393500E+04, 0.97276500E+04, -.39012900E+04, -.21040300E+04, 0.30960800E+04, -.71268000E+04, 0.66780100E+04, -.27833400E+04, 0.19159200E+05, -.99827100E+04, 0.51242000E+04, 0.83124800E+03, 0.49621400E+04, -.30490300E+04, -.59202300E+04, 0.58884900E+04, 0.59107200E+04, 0.91917100E+04, -.70237700E+04, 0.53246400E+04, 0.69604800E+04, -.33490000E+04, -.53881100E+04, -.34889100E+04, -.46785700E+04, -.67563200E+04, 0.26608300E+04, 0.52900900E+04, -.58634100E+03, -.74387200E+04, 0.83073500E+03, -.59017400E+04, 0.29485800E+04, 0.25218600E+04, 0.29484600E+04, 0.27618200E+03, 0.28897100E+03, 0.94365900E+03, -.93046800E+03, 0.15896000E+04, 0.17917400E+03, 0.32052000E+04, -.97461400E+02, 0.20140700E+03, 0.68014200E+03, -.18673500E+02, 0.13163000E+04, 0.57544800E+03, 0.17928300E+04, -.13206600E+04, -.24101400E+04, -.20630300E+04, 0.10385100E+04, 0.13595000E+03, 0.66602000E+03, -.89535700E+03, 0.65057400E+03, 0.10709600E+04, -.31534500E+03, -.33354200E+03, -.13847900E+04, -.19249800E+04, -.65989000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.47309100E+00, 0.13230000E+01, -.22100900E+00, 0.74216400E+00, -.64965700E+00, 0.98466200E+00, 0.26885700E+00, 0.13787600E+00, -.17107200E+01, 0.44141200E+00, 0.39567300E+00, -.13006000E+00, -.16717900E+01, -.11847700E+00, 0.29844900E+00, -.16581600E+01, 0.31687900E+01, 0.28625500E+00, -.63970000E-01, -.16383500E+01, -.70333800E-01, -.54944900E-01, 0.44783800E+00, 0.52774200E-01, -.66462100E+00, 0.50831900E-02, -.12940800E+00, -.35796400E+00, 0.57362500E+00, -.15046900E+00, -.23606500E-01, 0.55636000E+00, 0.17542200E-01, 0.22000100E+01, -.11612800E+01, -.16234900E+01, 0.54121100E-01, -.50573200E+04, -.78160000E+04, 0.38945900E+04, 0.40496400E+03, 0.15598000E+03, -.71234400E+04, -.54914400E+04, 0.25624500E+05, -.12803300E+05, -.22774400E+05, -.12812700E+05, -.73499800E+04, -.56035200E+04, -.43093500E+04, -.12104500E+04, -.83793000E+04, -.52696600E+04, -.10305000E+05, 0.15872000E+05, -.79759800E+04, 0.42145700E+05, -.79351200E+04, 0.19571800E+05, 0.25979900E+05, 0.37551400E+03, 0.24652600E+05, -.60984200E+04, 0.18087800E+05, -.12483600E+05, -.24276000E+04, 0.10859200E+04, 0.32959800E+04, 0.12161400E+04, -.49179400E+04, -.91310000E+04, 0.32861500E+04, -.17625500E+04, -.19007100E+04, -.81429500E+04, -.39588000E+04, -.31589400E+05, 0.15602700E+05, 0.11906400E+04, 0.15795000E+05, -.55489800E+04, -.11445700E+05, 0.91017100E+04, -.13575100E+04, 0.21442700E+05, -.99150600E+04, 0.15232500E+05, 0.49997800E+05, -.25159600E+05, -.20207900E+04, -.24999400E+05, 0.24794200E+03, 0.19941400E+04, -.11067400E+05, 0.15726300E+04, -.15809400E+05, -.68005000E+03, -.22701700E+05, -.43029600E+05, 0.21551900E+05, -.68566300E+05, 0.21513000E+05, -.25682600E+05, -.38737900E+05, 0.53989300E+04, -.34541200E+05, 0.51738600E+04, -.32166800E+05, 0.32294200E+05, -.75783400E+05, 0.37793700E+05, -.28497200E+04, 0.37894400E+05, -.31384000E+04, -.15798900E+05, 0.17564300E+05, -.24848900E+04, 0.36475700E+05, -.14795000E+05, 0.36056100E+05, -.11164400E+05, 0.56245800E+04, -.68665500E+04, 0.55875400E+04, -.41880000E+04, -.50164100E+04, 0.46893000E+04, -.17008300E+04, 0.12842700E+04, -.35912200E+04, 0.13420600E+04, -.21220000E+05, 0.10776600E+05, -.16084600E+04, 0.10606000E+05, -.43172100E+03, 0.80287600E+03, 0.45205200E+04, -.17610400E+04, 0.63223400E+04, 0.25831500E+04, 0.91034100E+04, -.12293700E+04, 0.57944000E+03, 0.54192300E+04, 0.61453000E+03, 0.21533100E+03, 0.23871400E+03, -.44461100E+03, -.14229700E+04, -.15951400E+04, 0.55208600E+03, 0.58658800E+03, -.11609900E+05, 0.58301100E+04, -.21421500E+05, 0.58076600E+04, -.24785600E+04, -.90110200E+04, 0.24045400E+04, -.32054600E+04, 0.82095700E+04, -.76179800E+04, 0.10206600E+05, 0.49802500E+05, -.24935800E+05, 0.23462200E+05, -.24901400E+05, 0.93021600E+04, 0.21135700E+05, -.13223300E+05, 0.84727100E+04, -.20877400E+05, 0.20422500E+05, -.26110000E+05, 0.95664500E+05, -.47770300E+05, -.36557100E+05, -.47834000E+05, -.11553000E+05, 0.98767200E+04, -.35141900E+05, -.22879000E+05, -.48573500E+05, 0.82293700E+04, -.32148900E+05, 0.69574500E+05, -.34635600E+05, 0.15161500E+05, -.34785000E+05, 0.11945100E+05, 0.27912200E+05, -.17099400E+05, 0.11529000E+05, -.40924900E+05, 0.24108700E+05, -.37414500E+05, 0.16624300E+05, -.83015900E+04, 0.26050400E+05, -.83135700E+04, 0.15830300E+05, 0.25138400E+05, -.54914800E+04, 0.14007200E+05, -.14366700E+05, 0.18787100E+05, -.50722000E+04, 0.11802200E+05, -.58688400E+04, -.13993500E+04, -.59016700E+04, -.50287900E+03, 0.21656800E+03, 0.36817500E+03, 0.57643700E+04, -.11285800E+04, 0.96007500E+03, -.59834700E+04, -.76892000E+02, -.10779100E+04, -.18763300E+04, -.22685200E+02, -.18443200E+04, -.29252400E+04, -.55185000E+04, 0.28952800E+04, 0.27258300E+04, -.36404600E+04, -.76142800E+04, 0.27720200E+03, -.15797800E+04, -.13696700E+02, -.17479100E+04, -.11049400E+04, 0.27756900E+04, 0.96415000E+04, 0.32430600E+04, 0.27837300E+04, 0.94129600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15488500E+00, 0.38202400E+00, 0.21209900E+01, 0.12429100E+01, 0.91299300E+00, -.11133800E+01, 0.13129100E+01, -.20323700E+00, 0.24940400E+01, 0.88751900E+00, -.25369700E+00, -.39178700E+00, 0.12389600E+01, 0.10402700E+01, 0.41108900E+00, 0.11066600E+01, -.24204900E+01, -.69608700E-01, -.56083100E+00, 0.11087000E+00, 0.64108000E-01, -.28766100E-02, -.19942100E+01, -.12750600E+00, -.21997500E+00, -.21957500E-02, -.25902300E+00, 0.69129400E+00, -.10016900E+01, 0.10932600E+01, 0.43356700E+00, 0.36615800E+00, 0.64177300E+00, 0.14048300E+01, 0.15401500E+01, 0.77402100E+00, -.22174900E+00, -.40418000E+00, -.49892500E+04, 0.23564800E+04, 0.19978500E+04, 0.59525300E+04, -.39539500E+04, -.56976700E+04, -.14438200E+04, 0.58583000E+03, -.32675000E+04, 0.73863800E+03, -.14193400E+04, 0.93569500E+03, -.26790300E+04, -.52694300E+04, -.16874800E+04, 0.78626300E+03, 0.23006500E+04, 0.83068800E+04, -.41713900E+04, 0.14587900E+05, -.41552400E+04, 0.47873100E+04, 0.14656600E+04, 0.54477700E+04, 0.20517600E+05, 0.38828400E+04, -.58901600E+03, -.51753100E+04, -.33690000E+04, 0.16023200E+04, 0.10027400E+04, 0.16771300E+04, -.51611800E+03, -.72172300E+04, 0.24678100E+04, 0.10459600E+04, 0.70822800E+04, -.62440300E+04, -.20090300E+04, -.13937000E+05, 0.66397100E+04, -.20055200E+04, 0.69674100E+04, 0.40284300E+04, 0.98516800E+03, -.44569900E+03, -.80129300E+04, 0.61720900E+03, 0.14924500E+04, 0.35511900E+04, 0.22085700E+05, -.11154700E+05, -.23344100E+04, -.11041400E+05, -.15085200E+03, -.45739300E+03, -.64426400E+04, -.53535300E+04, -.96437500E+04, -.96344000E+03, -.94153800E+04, -.82823500E+04, 0.40799700E+04, -.23531700E+05, 0.41448500E+04, -.10646900E+05, -.77079200E+04, -.24908700E+04, -.16661900E+05, -.21362400E+04, -.67229500E+04, 0.13995700E+05, -.16665400E+05, 0.81893300E+04, -.37153500E+04, 0.83271200E+04, -.21968700E+04, -.70409400E+04, 0.84450400E+04, 0.32843400E+04, 0.81995800E+04, -.60685700E+04, 0.42317800E+04, -.15982900E+04, 0.79731600E+03, -.17231000E+04, 0.78846100E+03, 0.10099800E+04, 0.11494400E+04, 0.68213500E+03, 0.10460400E+04, 0.15662200E+04, 0.21100000E+04, -.35173500E+04, -.56164900E+04, 0.29508500E+04, -.19548200E+04, 0.28142600E+04, 0.62121700E+03, 0.30615500E+04, 0.20580700E+04, 0.46610300E+04, 0.41597700E+04, 0.30010600E+04, 0.22719900E+04, 0.22527100E+04, -.13069800E+04, 0.18292600E+03, -.11263000E+04, -.30792500E+03, -.90968700E+03, 0.72039600E+02, 0.12986700E+04, 0.28407100E+03, -.90020000E+03, -.63387100E+03, 0.14813100E+04, -.67531800E+03, -.11120900E+05, -.74615000E+03, -.39653800E+04, -.63860200E+04, -.14164300E+04, -.66342000E+04, -.16992600E+03, -.59190100E+04, 0.40635800E+04, 0.16935700E+04, -.87643200E+03, 0.10496000E+05, -.84662800E+03, 0.35709700E+04, 0.45851600E+04, -.19154800E+04, 0.37915100E+03, 0.43412300E+03, 0.48362800E+04, -.34161200E+04, 0.22853700E+05, -.11446100E+05, -.98489800E+04, -.11423300E+05, -.85898400E+04, 0.51777100E+04, -.14066800E+05, -.19635500E+05, -.14246600E+05, 0.43601600E+04, 0.14863000E+03, 0.19388000E+05, -.93993300E+04, 0.13049800E+05, -.96974500E+04, -.43953200E+04, 0.14708700E+04, 0.23122500E+04, 0.16798700E+05, -.14354600E+02, 0.48591300E+03, -.69504600E+04, -.97539000E+03, 0.65289300E+03, 0.13188100E+05, 0.49071100E+03, 0.62296700E+03, 0.90736000E+02, 0.55225500E+04, 0.14561500E+05, 0.53885400E+04, -.16910100E+04, 0.44268800E+04, -.20664900E+04, 0.10386600E+04, 0.22162200E+04, 0.10344400E+04, 0.41437000E+03, 0.14495700E+03, 0.11392800E+04, 0.96059400E+03, 0.10139500E+04, 0.55784900E+03, 0.73948500E+03, -.10683500E+03, 0.62220500E+02, 0.80847000E+03, -.28754600E+02, 0.14928200E+04, -.84382900E+00, -.21324400E+03, -.19675200E+04, -.36704300E+04, -.44906500E+04, -.17293200E+04, 0.49341900E+03, -.28252000E+03, -.12493500E+04, 0.80924800E+03, 0.93320500E+03, 0.32352200E+03, 0.22564000E+04, -.63746700E+03, -.91007100E+03, 0.92794800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.72151800E-01, 0.11907900E+00, -.14026100E+01, 0.51228700E-01, 0.90887400E+00, 0.28761200E-03, 0.65712300E+00, 0.16377400E+00, -.21481900E+01, -.65683100E+00, 0.53831900E+00, 0.17612600E-01, -.36450500E+00, 0.12290500E+00, -.59910500E+00, -.60670500E+00, -.75000400E-01, 0.53594800E+00, -.50888000E+00, 0.76257800E-01, 0.17408100E-01, -.12842600E+00, -.66535600E+00, -.10840300E+00, -.18013100E+00, -.55814100E-03, -.13186900E+00, 0.52284600E-01, -.65836500E+00, 0.51544100E+00, 0.29589900E+00, 0.23125200E+00, 0.35141500E+00, -.71896700E-01, -.14188000E+00, 0.76604900E-01, -.13656000E+00, 0.91855600E-01, 0.33819800E+00, 0.95733600E+03, 0.18527300E+04, 0.36667700E+03, 0.47919600E+03, 0.24434800E+03, -.36535200E+04, 0.18604600E+04, 0.33701200E+04, 0.18276600E+04, 0.99901500E+03, 0.97982900E+03, 0.10786600E+04, 0.16636100E+04, 0.10627100E+04, 0.10619500E+04, 0.15728600E+04, -.70815800E+04, 0.35691300E+04, -.41048100E+04, 0.35407900E+04, -.21601800E+04, -.24745300E+04, -.19050100E+04, -.78027800E+04, 0.40767900E+03, -.81887600E+03, 0.49556700E+04, -.11698000E+04, 0.64408700E+03, -.80511900E+02, 0.58270100E+03, 0.52733100E+03, 0.10570400E+04, 0.64691300E+03, 0.17377000E+04, 0.72002300E+03, 0.14376700E+04, 0.88565600E+03, 0.60422500E+04, -.29370900E+04, -.12490900E+04, -.30214400E+04, 0.68203900E+03, 0.73924000E+03, -.66899700E+03, 0.61714400E+03, -.27163600E+04, 0.32174400E+03, -.34722500E+04, -.14822600E+05, 0.74551500E+04, 0.32395400E+04, 0.74115700E+04, -.66998700E+03, -.55345000E+03, 0.51050000E+04, 0.14404700E+04, 0.56930900E+04, 0.78127600E+02, 0.73952700E+04, 0.89487400E+04, -.44697800E+04, 0.11737400E+05, -.44743900E+04, 0.36957500E+04, 0.66122200E+04, -.57301800E+02, 0.91561900E+04, -.77133100E+03, 0.51513800E+04, -.64423200E+04, 0.14328000E+05, -.71037200E+04, 0.24308800E+03, -.71640800E+04, 0.93010600E+03, 0.31918900E+04, -.43777900E+04, -.17309100E+04, -.69357500E+04, 0.27733500E+04, -.72739000E+04, 0.27433400E+04, -.13741900E+04, 0.59953300E+03, -.13715400E+04, 0.13059000E+04, 0.68436100E+03, -.19953800E+04, -.16192500E+04, -.14557300E+04, 0.35163000E+03, -.13298800E+04, 0.81095600E+04, -.40932400E+04, -.15301200E+04, -.40562500E+04, -.12724300E+03, -.78010000E+03, -.21850900E+04, 0.31731400E+03, -.28160600E+04, -.11110600E+04, -.40913700E+04, 0.49296500E+03, -.21341200E+03, -.11928500E+04, -.24658800E+03, -.21703700E+02, 0.61973000E+02, -.15052200E+03, 0.25781400E+03, 0.87688400E+02, 0.38192200E+01, -.10158600E+03, 0.52317300E+03, -.27484300E+03, 0.44699400E+04, -.26158400E+03, -.37315000E+03, 0.15987300E+04, 0.20457500E+04, 0.35732000E+04, 0.64799200E+03, 0.15069300E+04, -.38483700E+02, -.10508000E+05, 0.52637900E+04, -.47245800E+04, 0.52538800E+04, -.12797300E+04, -.42108900E+04, 0.29914800E+04, -.15204100E+04, 0.42505000E+04, -.36630400E+04, 0.50054000E+04, -.12074500E+05, 0.60194300E+04, 0.40149400E+04, 0.60372300E+04, 0.18594500E+04, -.69049600E+03, 0.58911300E+04, 0.67254600E+04, 0.71735100E+04, -.57005600E+03, 0.29509000E+04, -.94214700E+04, 0.46689600E+04, -.31877300E+04, 0.47115000E+04, -.11247200E+04, -.27641400E+04, -.45266600E+03, -.45937200E+04, 0.35842500E+04, -.17637200E+04, 0.61687500E+04, -.34995800E+04, 0.17129800E+04, -.29991800E+04, 0.17499200E+04, -.11194300E+04, -.14259300E+04, -.20349900E+04, -.48296200E+04, 0.12666400E+04, -.22693000E+03, 0.99336800E+03, -.60222800E+03, 0.28789200E+03, -.89605200E+03, 0.30114000E+03, -.91956700E+02, -.43654500E+03, -.27153300E+03, -.12489600E+04, -.34641900E+02, -.43005400E+03, 0.22885800E+03, 0.21259100E+02, 0.19475500E+03, 0.53415200E+02, 0.25295500E+01, 0.42237600E+03, 0.51056300E+03, 0.38205300E+03, -.30451900E+03, 0.54177500E+03, 0.15485500E+04, 0.14116500E+04, 0.63554500E+01, 0.28366500E+02, 0.30916700E+02, 0.35219800E+01, -.53234300E+03, -.63202200E+03, -.18076900E+04, -.98865000E+02, 0.27858200E+03, 0.29384000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11091200E+00, 0.27228300E+00, -.91937100E-01, 0.46118900E+00, 0.11252400E+01, -.12625100E+00, 0.19448500E-01, -.79066800E-01, -.96406000E+00, -.62796500E+00, 0.34813900E-01, 0.47564500E-01, -.96980400E+00, 0.60051200E-01, 0.69896700E-01, 0.19700800E+00, -.59288600E+00, -.55376700E-01, 0.11990600E+00, 0.13411100E+00, 0.44418900E-01, 0.30858800E-01, 0.64743400E+00, 0.18873300E-02, 0.19226200E+00, -.24246900E-03, 0.10001800E+00, 0.14624700E+00, -.37971000E+00, 0.13796900E+00, -.49149400E-01, 0.32385500E+00, -.19877300E+00, 0.45138900E+00, -.18900800E+00, -.53494700E-01, 0.79002300E-01, 0.12399300E+00, -.88340500E-01, -.43171200E+00, 0.10647000E+04, 0.12486000E+03, 0.10675100E+03, 0.95852200E+03, -.19286400E+04, 0.99879200E+03, 0.23964500E+04, 0.96277200E+03, 0.13332100E+04, 0.10228700E+04, 0.40316700E+03, 0.11896200E+04, 0.32400700E+03, 0.10958700E+04, 0.10906100E+04, -.23989200E+04, 0.12163500E+04, -.41989400E+04, 0.11991000E+04, -.48330700E+04, -.20071500E+04, -.31823100E+04, -.76630200E+04, -.42899100E+03, -.56281800E+03, 0.59798100E+04, 0.27274300E+03, -.50374000E+02, -.43304800E+03, -.13599600E+03, 0.54782700E+03, 0.12514500E+04, -.62440100E+03, 0.10377700E+04, 0.66575300E+02, 0.12756900E+04, 0.10596300E+04, 0.22816900E+04, -.10529200E+04, 0.60041100E+03, -.11407800E+04, 0.17782700E+04, 0.16462400E+04, 0.11579400E+03, 0.80959900E+03, -.19608600E+04, 0.11603900E+04, -.31112700E+04, -.10994900E+05, 0.55697400E+04, 0.10014800E+04, 0.54974700E+04, -.22259300E+03, 0.12073700E+03, 0.32060000E+04, 0.10009900E+03, 0.42373700E+04, 0.64920300E+03, 0.63499600E+04, 0.54053700E+04, -.26831000E+04, 0.83335800E+04, -.27019400E+04, 0.55819200E+04, 0.42927300E+04, 0.12542100E+04, 0.96247000E+04, 0.57799900E+03, 0.29756400E+04, -.62337200E+04, 0.99584700E+04, -.49303800E+04, 0.32019800E+03, -.49802700E+04, 0.33062500E+03, 0.23383200E+04, -.30947800E+04, -.25108800E+04, -.58134100E+04, 0.20514200E+04, -.45992800E+04, 0.77303400E+03, -.38822300E+03, 0.66690600E+03, -.38876500E+03, 0.10843900E+04, -.12562300E+03, -.89884300E+03, 0.32025300E+02, -.13572600E+03, -.39281400E+03, -.24006400E+02, 0.48135600E+04, -.24722300E+04, 0.13188800E+03, -.24042300E+04, -.29170600E+03, -.10819300E+04, -.13224500E+04, 0.76809700E+03, -.17878200E+04, -.14824500E+04, -.32450400E+04, 0.24605200E+03, -.94108700E+02, -.89546400E+03, -.12289200E+03, 0.83254100E+02, 0.31370000E+03, -.25837500E+03, 0.15556200E+03, 0.14721000E+02, 0.21104600E+03, -.11566300E+03, 0.77907800E+03, -.40973100E+03, 0.22035700E+04, -.39064100E+03, 0.13290300E+03, 0.23568300E+04, 0.71979800E+03, 0.13605300E+04, -.26372700E+03, 0.22653100E+04, -.10000100E+03, -.50827000E+04, 0.25608600E+04, -.27757700E+04, 0.25415000E+04, -.14573400E+04, -.29118800E+04, 0.14493700E+04, -.11319400E+04, 0.21742400E+04, -.24102400E+04, 0.21773000E+04, -.92503900E+04, 0.46318800E+04, 0.30535700E+04, 0.46259200E+04, 0.37843400E+04, -.71254900E+03, 0.50555000E+04, 0.68742100E+04, 0.57634300E+04, -.71551400E+03, 0.21393700E+03, -.48958500E+04, 0.24064000E+04, -.38089500E+04, 0.24465700E+04, -.31775800E+04, -.34392700E+04, -.10675300E+04, -.36769300E+04, 0.31863600E+04, -.24067600E+04, 0.67250600E+04, -.24130700E+03, 0.90662300E+02, -.35447300E+04, 0.12114900E+03, -.29177500E+04, -.94741500E+03, -.30076300E+04, -.49665100E+04, 0.22118300E+03, 0.58540500E+02, 0.11626800E+04, 0.23655500E+03, -.12510300E+03, -.45616100E+03, -.11805900E+03, -.56616700E+02, 0.12538700E+02, -.42822500E+03, -.10313300E+04, -.58502000E+03, 0.20353500E+02, -.89459400E+02, 0.70575600E+02, 0.31176700E+03, 0.28095800E+03, 0.95503100E+01, 0.43777100E+03, 0.33335900E+03, 0.16344200E+03, -.45534900E+03, 0.16590500E+03, 0.11189500E+04, 0.99628100E+03, 0.10583800E+02, 0.24999400E+03, 0.12401400E+01, 0.20214800E+03, -.18250000E+03, -.51032800E+03, -.11011100E+04, -.25516300E+03, 0.29352500E+03, 0.13047800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15538500E+00, -.82088400E+00, -.33462800E+00, 0.31672800E-01, 0.12423500E+00, -.52919100E+00, 0.86508800E+00, -.45109100E-01, 0.69202000E+00, 0.83549900E+00, 0.75277600E-01, -.89142900E-01, 0.10919700E+01, 0.45892900E+00, 0.34637900E+00, 0.64436100E+00, -.15930000E+01, -.17825900E+00, -.14227700E+00, 0.18993600E+00, 0.66135100E-01, -.91840000E-01, 0.96404400E+00, 0.12553800E+00, -.94971200E-01, 0.10267700E-02, 0.28398700E+00, 0.44647300E+00, -.72709700E-01, -.27899400E+00, -.50745100E+00, -.55333400E+00, -.40822900E+00, 0.96760900E-01, 0.50576700E+00, -.10571600E+00, 0.76158000E-01, -.17978800E+00, -.25081600E-01, 0.16958600E+00, -.32278200E+00, -.11438600E+04, -.27551000E+03, -.50355300E+03, 0.84952700E+04, -.42118200E+04, -.53598800E+04, -.42540200E+04, -.67187700E+03, -.10778900E+04, -.88210900E+03, 0.78797100E+03, -.20690200E+04, -.10602400E+04, -.37052600E+04, 0.80863300E+04, -.40375800E+04, 0.17243600E+04, -.40425500E+04, -.23416900E+04, 0.28831500E+04, -.12447100E+04, 0.96926300E+03, -.26149800E+04, 0.18567900E+04, -.11762600E+04, 0.13509400E+04, -.65469300E+03, -.77559800E+02, -.67198600E+03, -.29396500E+03, 0.88910000E+01, -.13559700E+03, -.37073600E+03, -.19255900E+04, -.21715400E+03, -.10647200E+04, -.30585300E+04, 0.15111400E+04, 0.44928900E+04, 0.15297700E+04, 0.22722500E+02, -.69765300E+03, 0.21181800E+04, 0.35501300E+04, 0.33077800E+04, -.50883200E+03, 0.44377700E+03, 0.16394500E+04, -.83087400E+03, -.16734300E+04, -.82032800E+03, -.15831200E+02, 0.73833300E+02, -.12513100E+04, -.75955900E+03, -.61385100E+03, 0.13183600E+03, 0.34507200E+03, -.81999300E+04, 0.41287700E+04, -.12829900E+05, 0.40987200E+04, 0.23809300E+04, -.65202900E+04, 0.24102900E+04, -.21067000E+04, 0.24555700E+04, -.58554000E+04, 0.19927900E+04, -.15621600E+05, 0.78170800E+04, 0.34611500E+03, 0.78127300E+04, 0.74041800E+03, -.16726600E+04, 0.18727500E+04, -.26392800E+04, 0.66870100E+04, -.13669800E+04, 0.94039100E+04, -.44288500E+04, 0.22312200E+04, 0.26430200E+03, 0.22180100E+04, -.99113700E+03, -.16564700E+04, 0.16649800E+04, 0.34849600E+03, 0.30453000E+03, -.16057600E+04, 0.12430200E+04, 0.10700800E+04, -.50886000E+03, 0.99242500E+03, -.53645100E+03, 0.31023800E+03, -.43741000E+02, 0.45009800E+03, 0.64756700E+03, -.45574500E+03, -.16883900E+03, -.21666300E+04, -.25093100E+03, 0.13049900E+03, 0.76237400E+03, 0.12548700E+03, 0.56854500E+02, 0.20462500E+03, -.10651300E+02, -.32764200E+03, -.24200200E+03, 0.21244200E+03, -.10819000E+03, -.15622500E+04, 0.77825100E+03, -.33822700E+04, 0.78299600E+03, 0.11695800E+04, 0.18314100E+03, -.38935300E+03, -.67629700E+03, 0.59629400E+03, 0.58517600E+03, 0.20716800E+04, 0.10544000E+05, -.52721500E+04, 0.53633900E+04, -.52719800E+04, -.26564900E+03, 0.44770800E+04, -.30931800E+04, 0.13584300E+04, -.52777500E+04, 0.41686500E+04, -.50687000E+04, 0.12727000E+05, -.63387300E+04, -.49955400E+04, -.63647200E+04, 0.16142700E+04, 0.80510600E+03, -.37055700E+04, -.34950800E+03, -.59111300E+04, 0.23366000E+03, -.73455400E+04, 0.88543800E+04, -.43765600E+04, -.50982600E+04, -.44263600E+04, -.10200300E+04, 0.24883000E+04, -.32666300E+04, -.29900800E+04, -.59781900E+04, 0.19063200E+04, -.29245100E+04, 0.87592100E+04, -.44043400E+04, -.46782400E+03, -.43806900E+04, -.13687300E+04, 0.28888000E+04, -.15290700E+04, 0.65786200E+03, -.39768200E+04, 0.18473200E+04, -.25865500E+04, 0.34751500E+04, -.17332400E+04, -.21167200E+03, -.17380000E+04, -.24980800E+03, 0.64953400E+03, -.48066000E+03, 0.11766600E+04, -.62816800E+03, 0.67622500E+03, -.15631000E+04, 0.65651900E+02, -.18374600E+03, 0.30811400E+03, 0.67863300E+01, 0.20712200E+03, -.70591400E+03, -.63862000E+03, -.10170300E+02, 0.34620100E+03, -.26036200E+03, -.12680100E+04, -.12467300E+03, -.19739800E+03, -.25329200E+03, 0.35958900E+03, -.14194600E+03, 0.70392600E+03, 0.17727600E+04, 0.35440700E+02, 0.12061100E+03, -.70460700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30740000E+00, 0.23384200E+00, 0.21896700E+01, 0.66167100E+00, 0.76103800E+00, 0.12958600E-01, -.35860800E+00, -.55815600E-01, -.72207200E+00, -.11470400E+01, -.14759100E+01, 0.18698700E+00, -.32373800E+01, 0.63554800E+00, 0.12366900E+01, -.14557500E+01, -.50094600E+00, 0.82296800E+00, 0.13550200E+01, -.13402100E+01, -.21155000E+00, -.76364200E-01, -.12466000E+01, -.28939500E+00, -.15177000E+00, -.32354900E-02, -.66688300E-01, 0.90720700E+00, -.23105800E+01, 0.46946200E+00, -.24826000E+00, 0.19232100E+01, -.27891100E+00, 0.93676100E+00, 0.36676800E+01, 0.39269700E+00, 0.98693200E-01, -.64403000E+00, 0.34911100E-01, 0.28124700E+01, -.12988900E+01, -.20592800E+01, -.30420600E+04, -.16542300E+04, 0.39905100E+05, -.20039300E+05, -.30793800E+05, -.19973400E+05, -.33531300E+04, -.73997000E+04, -.58905800E+04, -.12161200E+04, -.11508400E+05, -.74460900E+04, -.17290600E+05, 0.62324700E+05, -.31210100E+05, 0.27016400E+05, -.31161400E+05, -.14240400E+04, 0.23053600E+05, -.12463600E+04, 0.33517400E+05, -.13347700E+05, 0.14186500E+05, -.33424700E+05, 0.94050700E+04, -.49096400E+04, -.17600600E+04, -.46844300E+04, -.30156000E+04, -.41150300E+04, -.88986400E+03, -.18438600E+04, -.45033000E+04, -.65339100E+04, -.72293600E+04, -.17453300E+05, 0.80482400E+04, 0.92382800E+04, 0.87293200E+04, -.50349300E+04, -.37918200E+04, 0.30351400E+04, 0.42947300E+03, 0.11920200E+05, -.17843900E+04, 0.99720100E+04, 0.43260600E+05, -.22024500E+05, -.11156200E+05, -.21632900E+05, 0.14282300E+04, 0.29437100E+04, -.19311100E+05, -.90859200E+04, -.16083500E+05, 0.39940000E+03, -.24519200E+05, -.59008900E+05, 0.29492600E+05, -.90997600E+05, 0.29502700E+05, -.30149100E+04, -.46466100E+05, 0.76658700E+04, -.44349300E+05, 0.86093400E+04, -.39108000E+05, 0.40254200E+05, -.10177800E+06, 0.50631000E+05, -.16077300E+04, 0.50892300E+05, -.56193600E+04, -.21310600E+05, 0.26863500E+05, 0.54046600E+04, 0.49675900E+05, -.19677500E+05, 0.52955800E+05, -.29598300E+05, 0.14874600E+05, -.11089200E+03, 0.14803800E+05, -.58597600E+04, -.91170700E+04, 0.13692600E+05, 0.52712100E+04, 0.78469400E+04, -.78770400E+04, 0.13165000E+05, -.16237400E+05, 0.85836700E+04, 0.57757400E+04, 0.81254900E+04, 0.16165300E+04, 0.22392500E+04, 0.91506400E+04, 0.44664300E+04, 0.61428600E+04, 0.32871400E+04, 0.11049000E+05, -.37337800E+04, 0.16648200E+04, 0.67107600E+04, 0.18676400E+04, 0.32335800E+03, 0.63096100E+03, 0.26119900E+03, -.20112500E+04, -.46095200E+03, 0.88395300E+03, 0.74251900E+03, -.96563700E+04, 0.49197000E+04, -.30334700E+05, 0.48309800E+04, 0.21083800E+04, -.76685800E+04, -.57126200E+04, -.12836500E+05, 0.31634700E+04, -.46441000E+04, 0.10905100E+04, 0.77671300E+05, -.38898700E+05, 0.30014000E+05, -.38834900E+05, 0.23760500E+04, 0.27953400E+05, -.20095800E+05, 0.12566800E+05, -.32012100E+05, 0.25793300E+05, -.36837700E+05, 0.88479400E+05, -.44187100E+05, -.33775300E+05, -.44241400E+05, 0.20547200E+04, 0.34550100E+04, -.30194900E+05, -.19192400E+05, -.44220400E+05, -.13441300E+04, -.23920400E+05, 0.43501500E+05, -.21132100E+05, 0.97686500E+04, -.21754100E+05, 0.69310700E+04, 0.17958400E+05, -.23954700E+04, 0.17625800E+05, -.21023800E+05, 0.12512100E+05, -.27973200E+05, 0.66581300E+05, -.33153800E+05, 0.76242400E+04, -.33293000E+05, -.30646400E+04, 0.16944000E+05, -.36240600E+04, 0.25437700E+05, -.21905700E+05, 0.89490100E+04, -.19044800E+05, 0.17554700E+05, -.87110600E+04, 0.17475800E+03, -.87781400E+04, -.38213200E+03, 0.27777600E+04, -.26577800E+03, 0.96033000E+04, -.30524900E+04, 0.31709600E+04, -.83613000E+04, 0.10174900E+03, -.16974400E+04, 0.12969100E+04, 0.15015600E+02, 0.18367500E+04, -.46518200E+04, -.51570300E+04, -.12342900E+04, -.51593100E+03, -.60718400E+04, -.93268100E+04, -.16125700E+02, -.62823900E+03, -.18649100E+04, 0.15507300E+04, 0.46098100E+03, 0.46108900E+04, 0.14346500E+05, 0.11532700E+04, -.29847100E+03, -.13088500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31239100E+00, 0.38477600E+00, 0.28732300E+01, -.63024300E+00, -.15606200E+01, 0.13947500E+01, -.28337800E+01, 0.48160300E+00, -.97833600E-01, -.14864300E+01, -.17382800E+01, 0.30317100E-01, -.21125800E+01, 0.70001100E-01, 0.13181100E+01, -.15790800E+01, -.68573200E+00, 0.97785700E+00, 0.14460800E+01, -.19944900E+01, -.27154000E+00, 0.78689500E-01, 0.65503300E-01, -.15461300E+00, 0.30012600E+00, 0.61380800E-02, 0.15622700E+00, 0.10569100E+01, -.16661000E+01, 0.33735000E+00, -.47894100E+00, 0.15561700E+01, -.10387600E+01, 0.15559400E+01, 0.29653400E+01, 0.12527000E+00, 0.85820900E-01, -.25226300E+00, -.16237300E-01, 0.19104300E+01, 0.60737400E+00, -.10159300E+01, 0.87674400E+00, 0.53884700E+04, -.12448300E+05, 0.62345800E+04, 0.84101200E+04, 0.62197700E+04, -.76910900E+03, 0.58932000E+03, 0.28859800E+04, 0.40692500E+03, 0.50591700E+04, 0.36250200E+03, 0.52463400E+04, -.51803700E+04, 0.25897400E+04, -.13373100E+05, 0.25927200E+04, 0.47467700E+04, -.65717600E+04, -.12463800E+02, -.56665500E+04, -.43607600E+03, -.46888400E+04, -.42939500E+04, -.30570800E+04, 0.14845500E+04, 0.32330900E+03, 0.15250600E+04, -.60761500E+02, -.37063300E+03, 0.11289300E+04, 0.31252900E+03, 0.13733200E+04, -.36866400E+03, 0.65183700E+04, 0.30245100E+04, -.14512200E+04, -.71681200E+03, -.15128400E+04, -.48807100E+03, -.45142600E+03, -.33296000E+03, 0.14571700E+04, -.50702200E+03, -.50288000E+03, 0.51413700E+03, 0.87178100E+03, -.41031600E+03, -.10486700E+04, -.43604400E+03, -.17635000E+04, -.26552700E+04, 0.37684500E+04, 0.66465100E+04, 0.11878000E+04, -.21767000E+04, -.85805000E+03, 0.20655300E+05, -.10321200E+05, 0.23672800E+05, -.10332800E+05, -.37261900E+04, 0.15898200E+05, -.61853100E+04, 0.46875100E+04, -.70342100E+04, 0.14392300E+05, -.49443400E+04, 0.27531400E+05, -.13750000E+05, 0.73412100E+03, -.13758500E+05, 0.25425500E+04, 0.45873800E+04, -.56803200E+04, 0.40020200E+04, -.10757100E+05, 0.33537300E+04, -.15070800E+05, 0.10426900E+05, -.52181900E+04, -.18875700E+03, -.51977600E+04, -.35665900E+03, 0.18919900E+04, -.29845600E+04, -.23718200E+01, -.24389400E+04, 0.11270100E+04, -.52017000E+03, -.35426300E+04, 0.17141700E+04, 0.13340600E+04, 0.17529400E+04, 0.13856600E+04, 0.19168300E+04, -.21711900E+04, -.53176900E+04, -.27856000E+03, 0.18599400E+04, 0.33087600E+04, -.10421500E+04, 0.51006200E+03, -.65776500E+03, 0.52007800E+03, 0.10147200E+03, -.44122800E+03, 0.24162700E+03, -.51918000E+03, 0.37503800E+03, -.29030800E+03, 0.41024600E+03, 0.25331600E+03, -.13276500E+03, 0.11345600E+05, -.11899200E+03, 0.84010500E+03, 0.12083600E+04, 0.10457400E+04, 0.28050700E+04, -.95868700E+03, 0.11330600E+04, -.41905100E+04, -.30012900E+05, 0.14998800E+05, -.87598500E+04, 0.15005300E+05, -.39144600E+03, -.79285500E+04, 0.70189600E+04, -.38920200E+04, 0.11412300E+05, -.78193300E+04, 0.16228900E+05, -.27742200E+05, 0.13874500E+05, 0.10320500E+05, 0.13866000E+05, -.73109800E+04, -.13208800E+04, 0.88107400E+04, 0.32089000E+04, 0.12142600E+05, -.11042100E+04, 0.18865300E+05, -.11075000E+05, 0.54679800E+04, -.54060400E+04, 0.55472600E+04, 0.83085900E+03, -.35536400E+04, 0.13111600E+04, -.61491400E+04, 0.22958900E+04, -.30135900E+04, 0.19489000E+04, -.44695100E+04, 0.22231500E+04, -.78302800E+04, 0.22313600E+04, 0.18354200E+04, -.42548800E+04, -.38553500E+03, -.53693000E+04, -.75661800E+03, -.31387600E+04, 0.37900300E+02, -.68522800E+04, 0.34204000E+04, -.10568700E+03, 0.34246300E+04, -.31122900E+01, -.12742500E+04, 0.82717200E+03, -.16980400E+04, 0.24498800E+04, -.14476000E+04, 0.38407300E+04, -.18602400E+03, 0.98250400E+02, -.77783900E+03, -.23003800E+02, -.64050200E+03, 0.12821700E+04, 0.14922900E+04, 0.89759500E+03, 0.26869000E+02, 0.17868300E+04, 0.30828500E+04, -.11655600E+03, 0.33094700E+03, 0.96666400E+03, -.79824600E+03, 0.19095400E+02, -.10697600E+04, -.39205800E+04, -.53984400E+03, -.41698900E+03, 0.10651500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.49106100E-01, -.20262800E+00, -.80536800E+00, -.13540300E+00, 0.47961200E+00, 0.70991200E-01, -.75566700E+00, 0.22476100E-01, -.13679900E+00, -.80014400E+00, 0.14685500E+00, 0.53672200E-01, -.13676600E+00, 0.17376800E+00, 0.13088500E+00, -.44410500E+00, 0.47130800E+00, 0.18698000E+00, -.44500100E+00, 0.25044700E+00, -.94195900E-02, -.59260300E-01, -.43063400E+00, 0.29495600E-01, -.18474300E+00, -.66522600E-03, -.10425200E+00, -.32946800E+00, 0.22503800E+00, 0.12297200E+00, 0.35390000E-01, 0.42983200E-01, -.38373600E-02, -.15639700E+00, -.16757800E+00, -.19080800E-01, -.18845800E-01, -.62750100E-01, -.13711700E-01, -.46892900E+00, 0.25319600E+00, -.85409400E-01, -.10431000E+00, -.11961000E+00, 0.28219000E+04, -.14285100E+04, -.29658600E+04, -.14122700E+04, -.45666700E+03, -.56820500E+03, -.27500900E+03, -.12719800E+03, -.95343800E+03, -.45037700E+03, -.14505700E+04, 0.40087900E+04, -.20180100E+04, 0.55126100E+04, -.20039400E+04, 0.16870100E+04, 0.28907600E+04, -.15137800E+03, 0.28199700E+04, -.10507600E+04, 0.23755200E+04, -.43471400E+04, -.45415300E+02, -.31122700E+02, 0.11497500E+03, 0.22741100E+02, -.24163600E+03, -.51774700E+03, 0.19560100E+03, -.17857400E+03, -.43426600E+02, -.45982800E+03, -.18716300E+02, -.34294600E+04, 0.16458200E+04, 0.13472900E+04, 0.17147300E+04, -.56443000E+03, -.25537800E+03, 0.42867000E+03, -.16628700E+03, 0.13280600E+04, -.29914100E+03, 0.22457600E+04, 0.29443200E+04, -.15224800E+04, -.77203600E+02, -.14722700E+04, 0.18857100E+03, 0.71253600E+03, -.13578900E+04, -.36392300E+03, -.15104100E+04, 0.33648500E+03, -.12242500E+04, -.46488400E+04, 0.23242400E+04, -.10407300E+05, 0.23234900E+04, -.12957000E+04, -.41991800E+04, 0.70596000E+03, -.37400000E+04, 0.46723100E+03, -.36139600E+04, 0.42668900E+04, -.10316700E+05, 0.51181300E+04, -.27195900E+03, 0.51596900E+04, 0.10467200E+03, -.16288700E+04, 0.19433100E+04, -.83845600E+03, 0.45930200E+04, -.16719400E+04, 0.53891300E+04, -.33614900E+04, 0.16876400E+04, 0.17519300E+03, 0.16835300E+04, -.32704100E+03, -.60619700E+03, 0.81360700E+03, -.52094700E+03, 0.23920700E+03, -.41127800E+03, 0.15586100E+04, -.85970800E+03, 0.47970500E+03, -.87660700E+02, 0.42702800E+03, 0.18305100E+03, 0.22461600E+02, 0.47713700E+03, 0.12551900E+03, 0.61478400E+03, 0.29179700E+03, 0.23030700E+03, -.67459400E+02, 0.11376000E+02, 0.47533300E+03, 0.33595600E+02, -.56515200E+02, -.13455900E+03, 0.60815600E+02, -.88341200E+02, 0.10618700E+03, -.82302200E+02, 0.26861900E+01, -.13139800E+04, 0.67170400E+03, -.31291400E+04, 0.65836900E+03, 0.99952900E+02, -.80695800E+03, -.54342000E+02, -.12130000E+03, 0.76716100E+03, -.55889200E+03, 0.81353400E+03, 0.56711800E+04, -.28523000E+04, 0.24790400E+04, -.28357400E+04, 0.11870800E+02, 0.21198200E+04, -.12367400E+04, 0.16351700E+04, -.21926600E+04, 0.20814000E+04, -.24372800E+04, 0.11952000E+05, -.59639200E+04, -.51997500E+04, -.59769000E+04, -.13179500E+04, 0.14902700E+04, -.37134400E+04, -.15835000E+04, -.54033600E+04, 0.82733800E+03, -.25322600E+04, 0.73614200E+04, -.36346700E+04, 0.76017500E+01, -.36791900E+04, 0.86509500E+03, 0.15399500E+04, -.75156600E+03, 0.17191700E+04, -.26732200E+04, 0.15003800E+04, -.52852400E+04, 0.84046000E+04, -.41774800E+04, 0.16933200E+04, -.42029500E+04, 0.58527400E+03, 0.23671000E+04, -.70600000E+03, 0.34211700E+04, -.19711100E+04, 0.17222200E+04, -.42638200E+04, 0.19952700E+04, -.99215500E+03, -.43912600E+03, -.99791300E+03, -.19030100E+03, 0.81945200E+02, -.40823300E+02, 0.96681400E+03, -.39635300E+03, 0.19572300E+03, -.75942300E+03, 0.25871200E+01, -.17161500E+03, 0.23851100E+02, -.18064400E+00, 0.92447800E+02, -.30678600E+03, -.86969600E+03, -.67369900E+02, 0.28476200E+02, -.38847000E+03, -.80913900E+03, -.17984000E+02, -.18973600E+03, -.16592100E+03, 0.78812900E+02, -.18753500E+03, 0.37162400E+03, 0.12200700E+04, 0.15975800E+03, 0.20453500E+03, 0.28839200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18241600E+00, -.11449100E+01, -.84772700E+00, -.35934200E-01, 0.29702300E+00, -.65174100E+00, 0.15964900E+01, -.44020200E-01, -.55148900E+00, 0.12858700E+01, 0.42797600E+00, -.16504300E+00, 0.10781900E+01, -.17878900E-01, -.15191800E+00, 0.22288400E+00, -.41134400E+00, -.40413000E-01, -.26689000E+00, -.19331100E+00, 0.61712600E-01, -.15581400E+00, -.44206200E+00, 0.75464100E-01, 0.70602300E+00, 0.14543300E-02, 0.11750400E+00, 0.92125700E-01, -.73201500E+00, 0.58332700E+00, -.18699500E+00, 0.80060100E+00, 0.10930900E+00, 0.14179200E+01, -.12001000E+01, -.17812100E-01, -.94025300E-01, 0.22727900E+00, 0.38343000E+00, -.60527400E+00, 0.64797700E+00, 0.11836200E+01, -.32661300E+00, -.11837400E+00, -.30196600E+01, -.12494200E+03, -.31869500E+04, 0.65433800E+00, -.16183100E+04, -.12700900E+04, 0.50773900E+03, -.13540200E+04, -.82684800E+01, -.11384800E+04, 0.40279200E+01, 0.10774300E+05, -.54401200E+04, 0.10614100E+05, -.53864500E+04, 0.65464300E+04, 0.43333100E+04, 0.27007800E+04, 0.11878300E+05, -.14363200E+04, 0.30069200E+04, -.16109000E+05, 0.12441300E+03, -.28676800E+03, -.37274900E+03, -.63804400E+02, -.11374300E+04, -.27130600E+04, 0.71354500E+03, -.95255500E+03, 0.10294000E+03, -.26095300E+04, 0.72889700E+03, -.10038800E+05, 0.47944900E+04, 0.22458100E+04, 0.50191600E+04, -.13549900E+04, 0.47542500E+03, -.89084100E+03, -.40531100E+04, 0.17898000E+04, 0.48451800E+03, 0.75035100E+04, 0.14452700E+05, -.73944500E+04, -.29942900E+04, -.72263000E+04, 0.64152600E+02, 0.20296500E+04, -.63288100E+04, -.21822400E+04, -.67490900E+04, 0.64797500E+03, -.24047700E+04, -.81695200E+04, 0.40305300E+04, -.20394300E+05, 0.40832700E+04, -.62371400E+04, -.75642500E+04, 0.11082500E+03, -.10213500E+05, -.20945700E+03, -.60313800E+04, 0.13141300E+05, -.18713400E+05, 0.92039000E+04, -.12907700E+04, 0.93587300E+04, 0.11421500E+04, -.22426200E+04, 0.21821400E+04, -.36004500E+04, 0.57832200E+04, -.24072100E+04, 0.93932900E+04, -.50701500E+04, 0.25316900E+04, -.83385200E+03, 0.25395700E+04, -.11296300E+04, -.99110900E+03, 0.18690700E+04, -.28806100E+03, 0.12464100E+04, -.27004000E+03, 0.34530600E+04, -.84992500E+04, 0.43915000E+04, 0.25300800E+04, 0.42440100E+04, 0.72927800E+03, 0.68876600E+03, 0.39868400E+04, 0.25284600E+04, 0.43697700E+04, 0.17714800E+04, 0.12701500E+03, 0.17521600E+03, -.17625600E+03, 0.81777900E+03, -.87915500E+02, -.41486900E+03, -.95549600E+03, 0.44692100E+03, -.12900700E+03, 0.19508100E+03, -.76555400E+03, -.26401000E+03, -.26279800E+04, 0.13716700E+04, -.64466600E+04, 0.13161700E+04, -.26192300E+03, -.21316200E+04, -.19087400E+04, -.24169500E+04, 0.37609400E+03, -.20987800E+04, 0.39257300E+04, 0.70345000E+04, -.35782600E+04, 0.57572500E+04, -.35176000E+04, -.23406200E+03, 0.30423900E+04, -.66729600E+03, 0.42267100E+04, -.16342700E+04, 0.28294800E+04, -.30993100E+04, 0.21632300E+05, -.10821300E+05, -.91250400E+04, -.10817600E+05, -.72108300E+04, 0.28415500E+04, -.83101100E+04, -.77382100E+04, -.10737500E+05, 0.18128700E+04, 0.21180700E+04, 0.18034200E+05, -.89240900E+04, 0.14681200E+04, -.90141100E+04, 0.25146200E+04, 0.99349400E+03, 0.22771900E+04, 0.98962300E+04, -.29814300E+04, 0.76636500E+03, -.15873900E+05, 0.16076400E+05, -.79050000E+04, 0.45225100E+04, -.80391400E+04, 0.25002600E+04, 0.25221100E+04, 0.26868400E+04, 0.11918800E+05, -.25790500E+04, 0.11323400E+04, -.13143200E+05, 0.20148900E+04, -.99534900E+03, -.22218600E+03, -.10078700E+04, -.32339000E+03, 0.21166800E+03, 0.27109500E+03, 0.17588400E+04, -.51008700E+03, 0.38385300E+03, -.63188500E+02, -.38892300E+02, -.32664400E+03, 0.47241100E+02, -.47996500E+01, 0.29680500E+03, -.25598600E+03, -.13838700E+04, -.21001700E+03, -.14090600E+04, -.29984000E+04, -.13992500E+04, 0.45236200E+02, -.24791800E+03, -.13613900E+04, 0.27381100E+03, 0.98674000E+02, 0.68396700E+03, 0.23379200E+04, -.13048400E+03, -.13386200E+03, 0.70980900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.80477200E-01, 0.71383700E+00, 0.10428000E+01, 0.58751000E+00, -.32151000E+00, 0.65272300E+00, -.50826800E+00, -.15467900E-01, -.83395200E+00, -.59332600E+00, 0.23466600E-02, 0.20072900E+00, -.91327200E+00, -.34965800E+00, -.13219300E+00, -.31323100E+00, 0.26059400E+00, -.27723500E+00, 0.25545700E+00, -.37165600E+00, 0.19060400E-02, -.21123700E-02, 0.85956000E+00, 0.32613100E-01, 0.20204800E+00, 0.44663100E-03, 0.13049700E+00, -.44059000E-01, 0.18252500E+00, -.59674900E-01, 0.64857000E-01, -.17697100E+00, 0.75581400E-01, 0.30539300E-01, -.87618700E+00, -.38480200E-01, 0.22117800E-01, 0.10043400E+00, -.63931200E-01, -.24815200E+00, 0.11155800E+00, -.92651600E-01, -.57846500E-01, -.42724700E-01, -.46795100E+00, -.32981900E+00, -.10514500E+04, -.94090600E+00, -.55159000E+03, -.53413100E+03, 0.25005500E+03, -.40953600E+03, 0.21115100E+03, -.52924900E+03, 0.22575700E+03, 0.34053900E+04, -.17233300E+04, 0.31419100E+04, -.17022600E+04, 0.14770500E+04, 0.42880700E+03, 0.18360100E+04, 0.51968200E+04, 0.20353100E+03, -.22133500E+03, -.51282400E+04, -.33862200E+02, -.15108800E+03, 0.98296500E+02, 0.16952100E+02, -.45391300E+03, -.96027400E+03, 0.30434200E+03, -.33895600E+03, 0.18526700E+02, -.10044300E+04, 0.58977200E+03, -.15776500E+04, 0.68048300E+03, 0.96335200E+03, 0.78882000E+03, -.51530900E+03, 0.59104800E+03, -.52484100E+03, -.85555000E+03, -.63459100E+02, 0.67683800E+03, 0.12274900E+04, 0.50010400E+04, -.24201200E+04, -.16784600E+04, -.25006300E+04, -.39009300E+02, 0.53563900E+03, -.22710700E+04, -.97512200E+03, -.23155200E+04, 0.30336600E+02, 0.48039100E+03, -.26879100E+04, 0.15421800E+04, -.79240600E+04, 0.13430500E+04, -.13456100E+04, -.24162000E+04, 0.69106300E+01, -.32289200E+04, 0.22724800E+03, -.19268700E+04, 0.46446600E+04, -.69180000E+04, 0.31035400E+04, -.63750700E+03, 0.34602800E+04, 0.75842000E+03, -.68432500E+03, 0.17983500E+03, -.25833400E+04, 0.14124100E+04, -.53501000E+03, 0.35253100E+04, -.12563900E+04, 0.52464600E+03, -.54715800E+03, 0.63088900E+03, -.31967000E+03, -.31423400E+03, 0.44672000E+03, -.30021600E+03, -.27217700E+01, 0.45955400E+02, 0.68512200E+03, -.34933600E+04, 0.16348700E+04, 0.14790200E+04, 0.17439400E+04, 0.24690400E+03, 0.24605000E+02, 0.17765700E+04, 0.13017300E+04, 0.18688300E+04, 0.51153100E+03, -.10254300E+04, -.18122300E+03, -.15199700E+02, 0.43502300E+03, 0.90480200E+02, -.18607500E+03, -.41652800E+03, 0.24556500E+03, -.30378500E+02, 0.19029900E+03, -.36629300E+03, 0.30595500E+02, -.82110800E+03, 0.57414600E+03, -.23148800E+04, 0.41188900E+03, -.14072900E+03, -.75992700E+03, -.60772900E+03, -.75096700E+03, 0.20739200E+03, -.90393900E+03, 0.26252500E+04, 0.15553100E+04, -.79259400E+03, 0.32543200E+04, -.77780600E+03, -.33798400E+03, 0.13089100E+04, -.10304600E+03, 0.12834000E+04, -.49958200E+03, 0.11623000E+04, -.10369900E+04, 0.58298100E+04, -.25941000E+04, -.24407800E+04, -.29157800E+04, -.19266200E+04, 0.91493200E+03, -.32367100E+04, -.44166300E+04, -.33672700E+04, 0.85798900E+03, 0.14385700E+04, 0.35991700E+04, -.17497500E+04, 0.38996900E+02, -.17981100E+04, 0.71565400E+03, -.42721300E+03, 0.11629300E+04, 0.27260300E+04, 0.91107800E+02, -.66151400E+03, -.35999500E+04, 0.20990200E+04, -.77196300E+03, 0.26569100E+04, -.10501400E+04, 0.57721000E+03, -.43593300E+02, 0.22647400E+04, 0.43549100E+04, 0.42360500E+03, -.60154500E+03, -.39982100E+04, 0.89647600E+03, -.30465200E+03, 0.15247900E+02, -.44850800E+03, -.14513100E+03, 0.24428200E+03, -.36688000E+02, 0.52421400E+03, -.17571400E+03, 0.26486500E+03, -.11566300E+03, -.31060400E+01, -.76533700E+02, 0.18962900E+02, -.52006400E+00, 0.13630700E+03, -.85998800E+02, -.69829000E+02, -.85419400E+02, -.37097600E+03, -.13196700E+04, -.41848300E+03, 0.55213300E+02, -.15521900E+03, -.65418200E+03, 0.99307300E+02, 0.21235400E+02, 0.28035500E+03, 0.66083000E+03, -.11148500E+03, -.25140200E+03, -.65708800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.62846800E+00, -.77113000E+00, -.40994100E+01, -.33772800E+01, -.54433900E+01, 0.34282400E+01, -.50366700E+01, 0.10671500E+01, 0.51137900E-01, 0.34520400E+00, 0.61506400E-01, -.43197900E+00, 0.15195800E+00, 0.67316200E+00, 0.13449500E+00, -.21320300E+00, 0.24434200E+00, 0.59696700E+00, -.13701000E+00, -.22598300E+00, 0.19796500E-01, 0.26719000E-01, 0.10860700E+01, 0.16073500E-01, 0.32735000E-01, 0.11279500E+00, 0.18819600E+00, 0.12879800E+01, 0.20726000E+00, 0.64996200E+00, -.83937900E+00, 0.63701600E+00, -.48630600E+00, -.51409900E+00, 0.99871500E+00, -.48536200E-01, 0.24767000E+00, -.22244400E+00, -.22875600E+00, 0.14381700E+01, -.15782600E+01, -.33999600E+00, 0.27176000E+00, 0.38556900E-01, 0.26810500E+01, -.73591500E+00, -.23565700E+01, -.60189500E+02, -.11582000E+04, -.12158700E+04, 0.26288300E+03, -.74947700E+03, 0.10912000E+04, -.14914700E+04, 0.88834500E+03, 0.64408700E+04, -.32655600E+04, 0.12448100E+03, -.32702200E+04, 0.12226300E+04, -.17605600E+04, 0.64696700E+04, 0.12971100E+05, 0.18467100E+04, -.35187900E+04, -.80599100E+04, 0.85637300E+03, -.77351400E+03, -.13729700E+03, -.42594500E+03, -.97613800E+03, -.21755000E+04, 0.48275500E+03, -.88324600E+03, -.22073200E+03, -.22488700E+04, 0.99036600E+03, -.14661200E+04, 0.54741100E+03, -.27699000E+03, 0.73425000E+03, -.14622800E+03, 0.25230400E+04, -.31762400E+04, -.43622100E+04, -.24649700E+04, 0.29377500E+04, 0.17052800E+04, 0.10759400E+05, -.51302100E+04, -.40874900E+04, -.54059000E+04, 0.46689100E+03, 0.10525700E+04, -.59000200E+04, -.35047200E+04, -.56981900E+04, 0.20350200E+03, 0.10340600E+04, -.74943500E+04, 0.42047100E+04, -.56601700E+04, 0.37434600E+04, -.35719900E+04, -.51972300E+04, 0.63701200E+03, -.54835600E+04, 0.25019500E+04, -.39715300E+04, 0.83175400E+04, -.65010200E+04, 0.24412500E+04, -.14553000E+04, 0.32818700E+04, 0.17850800E+04, 0.27112800E+02, -.10741900E+04, -.52669700E+04, -.17800400E+04, 0.10063100E+04, 0.27982300E+04, -.20287800E+04, 0.75574800E+03, -.14819000E+04, 0.10430400E+04, -.29049700E+00, 0.32875700E+03, 0.94230200E+03, 0.24639400E+03, 0.45032600E+03, 0.10658500E+04, 0.11288600E+04, -.81954100E+04, 0.37677800E+04, 0.37353300E+04, 0.41041900E+04, -.37822900E+03, -.30695200E+03, 0.51937900E+04, 0.46719300E+04, 0.51658400E+04, 0.37661800E+03, -.20750000E+04, 0.67025400E+03, -.56142700E+03, 0.11905800E+03, -.33591000E+03, -.54228500E+03, -.98071200E+03, 0.51056300E+03, 0.29072300E+03, 0.22420500E+03, -.95250700E+03, -.23273000E+03, 0.56238900E+03, 0.86529400E+02, -.38337700E+04, -.30821300E+03, -.81637800E+03, -.11310700E+04, -.28123000E+04, -.25974400E+04, -.10590400E+04, -.21761500E+04, 0.54850100E+04, 0.31586100E+04, -.15919800E+04, 0.74448400E+04, -.16365900E+04, -.10178700E+03, 0.25548000E+04, -.26646300E+03, 0.22176900E+04, -.13764400E+04, 0.20115600E+04, -.37309500E+04, 0.13227900E+04, 0.80811300E+02, 0.13101800E+04, -.66850600E+03, -.30658800E+04, -.14848000E+04, -.40525600E+04, -.98462900E+04, -.24139700E+04, -.50914800E+02, 0.24910200E+04, 0.64077100E+04, -.31550900E+04, 0.18405600E+04, -.32232100E+04, 0.12388900E+03, -.30817600E+04, 0.55947400E+04, 0.97664400E+04, 0.32140300E+04, -.41101000E+04, -.58790400E+04, -.85341100E+04, 0.49082600E+04, 0.51302200E+04, 0.42353500E+04, 0.46013700E+03, -.42776900E+04, 0.99611400E+04, 0.89510200E+04, 0.56587300E+04, -.47808200E+04, -.55004800E+04, -.62799000E+03, 0.65170800E+03, 0.15607400E+04, 0.28418100E+03, 0.15360200E+03, 0.85112000E+03, 0.17050000E+02, 0.35558300E+03, 0.94796200E+02, 0.70970300E+03, 0.28466700E+03, -.22407500E+01, 0.17064000E+02, -.11494200E+03, 0.21344900E+01, 0.19987500E+03, -.20366100E+03, 0.90997900E+03, -.13033800E+03, -.22230200E+04, -.34683000E+04, -.88612800E+03, 0.20307300E+03, -.20184800E+03, -.14887000E+04, 0.71718500E+02, 0.46980900E+03, 0.49376900E+03, 0.12757100E+04, -.71737400E+03, -.11971300E+04, -.76943100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.43139500E-01, -.15881800E+00, 0.23620100E+01, -.88772600E-04, -.20446600E-01, -.84754800E+00, 0.13218000E+01, -.11101000E+00, 0.53349200E+00, 0.22825700E+00, -.23665500E+00, -.11897900E+00, 0.54817600E+00, 0.73314400E+00, -.88072700E-01, 0.27881000E+00, -.16989200E+00, -.80756500E-01, 0.29799600E+00, -.30246900E+00, -.43035500E-01, -.17538600E-01, -.55325100E+00, 0.72215700E-01, -.10916100E+00, 0.53372200E-03, -.10464200E+00, 0.67430800E+00, 0.20222200E+00, 0.11284700E+00, -.47334800E-01, 0.41616000E+00, -.49566600E-02, -.99685900E-01, -.69742600E+00, -.13403700E+00, 0.79583900E-02, -.12171800E-02, -.49651000E-01, -.57121100E-01, 0.34495700E+00, -.61054400E+00, 0.88879300E-01, -.93989100E-01, -.27837800E+00, 0.23350900E-01, -.93276300E+00, 0.33698900E-01, -.70645200E+03, -.52279100E+03, 0.35654900E+03, -.21735500E+03, 0.44985000E+03, -.44929000E+03, 0.81421900E+02, 0.15447800E+04, -.79088700E+03, 0.52892000E+02, -.76971000E+03, 0.17682500E+04, 0.25803900E+03, 0.16570800E+04, 0.35241000E+04, 0.32721100E+03, -.76635200E+03, -.42432800E+04, -.48053800E+03, 0.74367000E+02, 0.67250800E+03, 0.23999800E+03, -.38584900E+03, -.74422700E+03, 0.40946700E+03, -.35975600E+03, 0.85340700E+02, -.81216000E+03, 0.79787300E+03, -.25591100E+04, 0.12099300E+04, 0.26142400E+04, 0.12794700E+04, -.64242500E+03, 0.29604100E+03, 0.63991700E+03, 0.79137900E+03, 0.94712000E+03, 0.45839500E+03, 0.11563300E+04, 0.31429400E+04, -.15031200E+04, -.21257200E+04, -.15708000E+04, -.12329500E+03, 0.26881900E+03, -.14749400E+04, -.55226100E+03, -.16816400E+04, -.33834900E+02, 0.21403300E+04, -.28581900E+04, 0.15974800E+04, -.64810900E+04, 0.14271600E+04, -.81989900E+03, -.26934800E+04, 0.60798100E+03, -.11691700E+04, 0.10739700E+04, -.17423900E+04, 0.39837000E+04, -.69667200E+04, 0.31835100E+04, -.54394700E+03, 0.34852100E+04, 0.16254900E+04, -.36442500E+03, -.44763100E+03, -.37895200E+04, 0.11453100E+04, 0.28561300E+02, 0.38978500E+04, -.11060300E+04, 0.46258200E+03, -.44987500E+03, 0.55820100E+03, -.39911700E+03, -.32032300E+03, 0.25947500E+03, -.54356900E+03, -.82780700E+02, 0.54483000E+02, 0.10579000E+03, -.25716800E+04, 0.11822500E+04, 0.21424300E+04, 0.12792100E+04, 0.41468900E+03, 0.14535000E+02, 0.12234900E+04, 0.86551900E+03, 0.14485000E+04, 0.45852800E+03, -.23535400E+04, -.13119100E+03, -.20181900E+02, 0.55899900E+03, 0.65309400E+02, -.21967200E+03, -.45479700E+03, 0.25075900E+03, -.75255100E+02, 0.20604700E+03, -.39471800E+03, 0.30430500E+01, -.55703300E+03, 0.42048500E+03, -.12080400E+04, 0.28246700E+03, 0.50493400E+03, 0.48257000E+00, -.40650200E+03, -.14470800E+03, -.18619300E+01, -.45957100E+03, 0.34691800E+04, 0.32857500E+04, -.16632500E+04, 0.49926500E+04, -.16413100E+04, -.51139200E+03, 0.22204000E+04, -.91064700E+03, 0.77906900E+03, -.16786800E+04, 0.16902500E+04, -.17252800E+04, 0.39407100E+04, -.16978300E+04, -.34306200E+03, -.19721200E+04, -.27309100E+04, 0.56870600E+02, -.29269900E+04, -.43251100E+04, -.25150400E+04, 0.11179900E+04, 0.20856600E+04, 0.62273000E+04, -.31007300E+04, -.33112300E+04, -.31095500E+04, 0.55543800E+03, -.41806700E+02, -.99320400E+03, -.10891900E+03, -.18932400E+04, -.51512300E+03, -.40923900E+04, -.23041700E+04, 0.13866900E+04, 0.99886300E+03, 0.11517400E+04, 0.74005000E+03, -.31715200E+03, 0.26388700E+04, 0.27906000E+04, 0.11615300E+04, -.89346600E+03, -.23795500E+04, 0.13021600E+04, -.53359000E+03, 0.41725800E+03, -.65068900E+03, -.17302500E+03, 0.69836700E+03, -.40366300E+03, 0.24934500E+03, -.36673200E+03, 0.55502100E+03, -.14602500E+03, -.31450000E+01, 0.48057800E+02, -.18479700E+01, -.33988300E+01, 0.94854700E+02, -.63650400E+01, 0.22821500E+03, -.26041200E+02, 0.17796200E+03, -.10055600E+04, -.39396400E+03, 0.29409500E+02, -.17827100E+03, -.59445400E+03, 0.99931000E+02, 0.93477900E+01, 0.37729900E+03, 0.32331200E+03, -.67358000E+02, -.31872600E+03, -.96354800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12753300E+00, 0.75298800E+00, -.43798600E+00, 0.36542200E+00, 0.65736800E+00, 0.73997600E+00, -.93589200E+00, 0.16906500E+00, -.16324700E+01, -.15560200E+01, 0.28356700E+00, 0.18061600E+00, -.14363100E+01, -.67615900E+00, -.28635800E+00, -.60205300E+00, 0.63568700E+00, 0.33026400E+00, -.27269500E-01, -.97514000E+00, -.56258900E-01, -.10959900E+00, 0.12383200E+01, 0.96344000E-01, 0.43234500E+00, 0.19374100E-02, 0.30069600E+00, 0.74952900E-01, -.11064100E+00, -.10130100E+00, -.24699700E+00, -.15503200E+00, -.10301500E+00, 0.64260500E+00, -.17826100E-01, -.47301800E-01, 0.30857000E-01, -.12461900E+00, -.11209600E+00, 0.10567400E-01, -.37486600E+00, -.76673100E-01, 0.97228100E-01, -.50779500E-01, -.76034500E+00, 0.74538500E-01, 0.84221400E+00, -.20028000E-02, 0.62023500E+00, 0.49316700E+03, -.14445000E+03, 0.69357300E+03, -.22338000E+03, 0.45124100E+03, -.23075300E+03, -.15182000E+04, 0.78991000E+03, -.98189500E+03, 0.75741500E+03, 0.46392600E+03, 0.64914500E+03, -.29448200E+04, -.54995700E+04, -.15310800E+04, 0.17284400E+04, 0.49706000E+04, -.11829800E+04, 0.82538000E+03, -.70758900E+02, 0.59090300E+03, 0.49374000E+03, 0.79034900E+03, 0.10944700E+03, 0.59627600E+03, 0.51238400E+03, 0.90812800E+03, -.26243900E+03, -.10211400E+04, 0.62325800E+03, -.16370900E+04, 0.51051000E+03, 0.73290900E+03, -.15573400E+04, 0.94030100E+03, 0.20416800E+03, 0.13238600E+04, -.16699400E+04, 0.79021000E+02, -.38748100E+04, 0.18156700E+04, 0.34473800E+04, 0.19370200E+04, -.31891600E+03, -.75660100E+03, 0.34051200E+04, 0.31459800E+04, 0.24534300E+04, -.34168800E+03, -.26481900E+04, 0.42428400E+04, -.23851100E+04, 0.82005500E+04, -.21203900E+04, -.15911000E+04, 0.29376200E+04, -.37941100E+03, 0.27718000E+04, -.12027700E+04, 0.18627900E+04, -.52523200E+04, 0.84381800E+04, -.37438300E+04, 0.67213700E+03, -.42199900E+04, -.98042900E+03, 0.76358100E+03, -.10708600E+03, 0.35211500E+04, -.82781200E+03, 0.21854600E+03, -.47911900E+04, 0.23053700E+04, -.10046500E+04, 0.38994400E+03, -.11553500E+04, 0.35185200E+03, 0.57933000E+03, -.11835600E+04, -.62937800E+03, -.78415800E+03, 0.90329200E+02, -.12038900E+04, 0.36834200E+04, -.16679300E+04, -.31520100E+04, -.18385900E+04, -.53885100E+00, 0.50896000E+03, -.30057800E+04, -.31891800E+04, -.25036900E+04, -.42853400E+02, 0.27030900E+04, -.12825400E+01, 0.13104000E+03, -.52471900E+03, 0.74760000E+00, 0.33385000E+03, 0.53798800E+03, -.31556700E+03, -.83103600E+02, -.23626900E+03, 0.49183100E+03, 0.13315100E+03, -.14926800E+03, -.14431700E+03, 0.28381500E+04, 0.72355300E+02, -.29519600E+03, 0.32785900E+03, 0.16490700E+04, 0.22851500E+04, 0.76908200E+03, 0.75409200E+03, -.34163500E+04, -.58186700E+04, 0.29245800E+04, -.57200800E+04, 0.29081800E+04, 0.12466000E+04, -.25032000E+04, 0.12246700E+04, -.12452300E+04, 0.23428900E+04, -.18918500E+04, 0.32350500E+04, -.26007600E+04, 0.87137200E+03, -.17686100E+02, 0.13013100E+04, 0.19697400E+03, 0.25447100E+03, 0.33080500E+04, 0.61286900E+04, 0.23731900E+04, -.81815000E+03, -.31422900E+04, 0.13757200E+04, -.70858000E+03, 0.31736500E+03, -.68991600E+03, -.63352000E+03, 0.17511300E+04, -.23417700E+04, -.23961000E+04, -.28536000E+04, 0.22420200E+04, 0.13873100E+04, 0.33126900E+04, -.20229600E+04, -.20836800E+04, -.16562500E+04, 0.55336200E+03, 0.16277000E+04, -.42344800E+04, -.43439100E+04, -.26460400E+04, 0.21692100E+04, 0.32131100E+04, -.17394800E+04, 0.67396600E+03, -.60845400E+03, 0.86940300E+03, 0.17011900E+03, -.90603700E+03, 0.36305300E+03, -.50475600E+03, 0.64214500E+03, -.75236200E+03, 0.37501700E+03, -.21255900E+02, -.44870500E+02, -.23900800E+03, -.20181100E+01, -.41083500E+03, 0.13616300E+03, -.50994500E+03, 0.40725000E+03, 0.22848300E+03, 0.20844500E+04, 0.45734200E+03, -.69601600E+02, 0.26838100E+02, 0.11053300E+04, -.37526600E+03, -.39223900E+03, -.48861500E+03, -.49488200E+03, 0.23806600E+03, 0.56411600E+03, 0.94314000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23657100E+00, -.91419800E+00, -.15530300E+01, 0.14599100E+00, 0.47970700E+00, -.11105800E+01, 0.23172700E+00, -.97517200E-02, 0.13685200E+00, 0.88648200E+00, 0.22248200E+00, -.13322400E+00, 0.98212300E+00, 0.77216600E+00, -.12671800E+00, 0.64437500E+00, -.29345200E+01, 0.40029400E+00, -.11282600E+01, 0.14013300E+01, 0.79733100E-01, -.14621600E-01, -.20573600E+01, -.22102200E+00, -.62400200E+00, -.50150400E-02, -.38363300E+00, 0.21044300E+00, -.46963800E+00, 0.99801500E+00, 0.81433500E-01, 0.74811100E+00, 0.10828300E+00, -.55948000E+00, -.48739000E+00, 0.13018700E+00, -.10599200E+00, -.10023500E+00, 0.45897500E+00, 0.79256900E+00, 0.17880400E+00, 0.95592300E+00, -.16724100E+00, -.89809200E-02, -.59827600E-02, 0.30289800E+00, 0.29303600E+00, -.12273300E+00, -.30341200E+00, -.10026800E+00, -.99841000E+03, -.18991600E+04, -.26549400E+03, -.72201500E+02, 0.33693700E+03, 0.83166500E+03, -.44677300E+03, 0.16884800E+04, -.42296600E+03, 0.14284300E+03, -.18143100E+03, 0.29919100E+04, 0.66820500E+04, 0.24677800E+04, -.14998100E+04, -.48630400E+03, 0.83653800E+03, -.42529300E+03, -.54507500E+02, -.41737400E+03, -.54683100E+02, -.17132400E+03, -.54363600E+03, -.51241100E+03, -.41352900E+03, -.14353300E+03, 0.85432100E+02, -.30317500E+04, 0.15762800E+04, -.23473200E+03, 0.15161200E+04, 0.74368800E+03, 0.50380800E+03, -.38347300E+03, -.19443100E+04, -.26148300E+03, 0.88657500E+03, 0.10114300E+04, 0.68344300E+04, -.33451100E+04, -.19211600E+04, -.34199800E+04, 0.11525000E+04, 0.19996200E+02, -.33127300E+04, -.28828900E+04, -.34817200E+04, -.15190600E+02, -.27226600E+04, -.63471200E+04, 0.32085600E+04, -.55453800E+04, 0.31760400E+04, -.23867700E+04, -.42451100E+04, 0.17187600E+02, -.54946000E+04, 0.16819800E+04, -.30973200E+04, 0.46754600E+04, -.71458000E+04, 0.35270100E+04, -.70359000E+03, 0.35724000E+04, -.55215100E+03, -.24088700E+04, 0.31422300E+04, 0.58556400E+03, 0.19571600E+04, -.15431100E+04, 0.25977600E+04, -.27491600E+04, 0.13504000E+04, 0.31717100E+03, 0.13691400E+04, -.13657400E+03, 0.52981000E+03, 0.11864700E+04, 0.13412300E+04, 0.12532500E+04, 0.90614800E+03, 0.12473300E+04, -.28650900E+04, 0.13413000E+04, 0.92862200E+03, 0.14425500E+04, -.67121800E+03, 0.54366800E+03, 0.17769300E+04, 0.20490000E+04, 0.17382400E+04, 0.38221000E+03, 0.77064900E+03, 0.28830300E+03, -.13775500E+03, 0.27466200E+03, -.14379900E+03, 0.29256200E+02, 0.15928400E+03, -.13758900E+03, 0.11615400E+03, -.12633600E+03, 0.10153000E+03, -.13908900E+02, 0.17993200E+04, -.89675300E+03, -.37255200E+04, -.90705900E+03, -.15843200E+03, -.11080200E+04, -.20631900E+04, -.35590100E+04, -.16103800E+04, -.14378100E+04, 0.39625600E+03, 0.72844200E+04, -.36221700E+04, 0.52859500E+04, -.36482600E+04, 0.13891200E+04, 0.31311300E+04, -.23423600E+04, 0.79834100E+03, -.26949900E+04, 0.26390600E+04, -.48078600E+04, 0.34761900E+04, -.16768300E+04, 0.35190400E+03, -.17360700E+04, -.28634900E+02, -.43379200E+03, -.39720400E+04, -.67161800E+04, -.27265200E+04, 0.66830600E+03, -.17202100E+04, 0.40416600E+04, -.21136300E+04, 0.41267700E+04, -.20280400E+04, -.84875500E+03, 0.29826100E+03, 0.15787700E+04, 0.52856600E+04, 0.12429600E+04, -.56558100E+03, -.13933400E+04, -.74459700E+04, 0.37409300E+04, 0.34952900E+04, 0.37213300E+04, 0.78309300E+02, -.17914900E+04, 0.43404300E+04, 0.39782400E+04, 0.45358900E+04, -.22562700E+04, 0.15346900E+04, -.97883600E+03, 0.51537100E+03, 0.19021900E+04, 0.48685700E+03, 0.37195700E+03, 0.71712400E+03, 0.18786500E+03, 0.29224500E+03, 0.17695500E+03, 0.64061000E+03, 0.40704400E+02, -.15284100E+02, 0.88179300E+02, -.18384500E+03, -.49422500E+00, -.22883600E+03, -.10931400E+03, 0.40986100E+03, 0.16105600E+03, -.95224800E+03, -.15860200E+04, -.85365000E+03, 0.16439700E+03, 0.72309300E+02, -.11142100E+03, -.21019900E+03, 0.75719900E+03, 0.34992400E+03, 0.84560500E+03, -.12612400E+03, -.54612200E+03, -.56320800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.17932100E+00, 0.30420500E-01, -.99309100E+00, -.19952200E-01, 0.17586200E+01, -.38812400E+00, -.14734000E-01, 0.10551700E+00, -.35103800E+00, -.60096400E+00, 0.68072800E-01, -.19308200E+00, 0.23392400E+00, -.70076600E-01, -.20489400E+00, 0.20428100E+00, -.10390300E+01, 0.30132100E+00, -.30925300E+00, 0.33636300E+00, 0.11801600E-01, 0.54662300E-01, -.85574700E+00, -.13330500E+00, -.28503300E-01, -.38622900E-03, -.40960900E-01, 0.57605500E+00, -.12025300E+01, 0.67492600E+00, -.23207100E+00, 0.99837500E+00, -.30848700E+00, 0.19866300E+00, 0.13973800E+01, 0.20048600E-01, -.42437200E-01, -.19231200E+00, 0.21236100E+00, 0.10818700E+01, -.11538500E+01, 0.36279700E+00, -.14677500E-01, -.18215300E+00, 0.13985900E+01, -.29337200E+00, 0.31732100E+00, 0.38871200E-01, -.82042500E+00, 0.62056300E+00, 0.54975500E+00, -.11136900E+04, -.76871800E+03, 0.43927300E+03, -.61276600E+03, -.51659800E+04, 0.25646300E+04, 0.73519700E+04, 0.25918300E+04, 0.30127600E+04, 0.29033400E+04, 0.14970200E+04, 0.19518600E+04, 0.20300800E+04, 0.24740300E+04, -.56121300E+04, -.13247700E+03, -.14428400E+03, 0.20711700E+03, 0.67152800E+02, -.44458400E+03, -.10638600E+04, 0.21793400E+03, -.75637700E+03, 0.26846600E+02, -.10523900E+04, 0.58749400E+03, -.15986400E+04, 0.60467000E+03, 0.11004400E+04, 0.79929300E+03, -.96933700E+03, 0.85916700E+03, -.45542900E+03, 0.20505800E+02, -.19836400E+02, 0.29314500E+03, 0.27966300E+04, 0.39701800E+04, -.19449000E+04, -.45335400E+04, -.19818800E+04, -.99266300E+02, 0.13741200E+04, -.28752300E+04, -.14201900E+04, -.24204000E+04, 0.65827600E+03, 0.16656300E+04, -.29204900E+04, 0.16758600E+04, -.85446100E+04, 0.14573400E+04, 0.98507400E+03, -.29708600E+04, 0.41936100E+03, -.23733300E+04, -.40578600E+03, -.15044000E+04, 0.61533200E+04, -.78836400E+04, 0.35400900E+04, -.28130300E+03, 0.39422500E+04, 0.16680400E+04, -.51344700E+03, 0.52487800E+03, -.17588300E+04, 0.23153700E+04, -.99971200E+03, 0.49467400E+04, -.61180800E+04, 0.29594500E+04, 0.67004700E+03, 0.30651600E+04, 0.51419100E+03, 0.57649600E+03, 0.63338700E+03, -.11715500E+04, 0.87023500E+03, 0.85306200E+03, 0.35144100E+04, -.35070100E+04, 0.16824000E+04, 0.40101600E+04, 0.17428700E+04, 0.59036400E+03, -.17921800E+03, 0.21278200E+04, 0.16689500E+04, 0.20952700E+04, 0.69434500E+03, -.16491400E+04, -.17530000E+03, -.59188700E+02, 0.43331400E+03, 0.87318600E+02, -.30146300E+03, -.64698200E+03, 0.31880500E+03, -.14760100E+03, 0.33643200E+03, -.48929000E+03, -.19303700E+03, 0.36952700E+03, 0.11804900E+01, -.39333600E+04, -.17577700E+03, 0.21697800E+02, -.90542000E+03, -.74306400E+03, -.10120400E+03, 0.21729300E+02, -.11115200E+04, 0.16595700E+04, 0.85965800E+04, -.43268900E+04, 0.33479700E+04, -.42905700E+04, -.22751200E+04, 0.17069900E+04, -.14433500E+04, 0.19936500E+04, -.28233100E+04, 0.13079700E+04, -.29175800E+04, 0.12436300E+05, -.58687900E+04, -.46594400E+04, -.62204600E+04, -.27592600E+04, 0.18930200E+04, -.47889200E+04, -.35019100E+04, -.62468300E+04, 0.25852500E+04, 0.24980300E+04, 0.28995000E+04, -.13142800E+04, 0.30164900E+03, -.14417300E+04, 0.12909800E+04, -.13059500E+03, 0.72391600E+03, 0.93828700E+03, 0.93414000E+02, 0.59431200E+03, -.66616100E+04, 0.51967900E+03, 0.49786800E+02, 0.29814400E+04, -.25774600E+03, 0.89532500E+03, 0.24206400E+04, 0.10902800E+04, 0.32240900E+04, 0.13892700E+04, 0.20372600E+04, -.34876100E+04, 0.40474600E+04, -.18648500E+04, -.82725900E+03, -.20204900E+04, -.66947000E+03, 0.58728100E+03, -.62599900E+03, 0.89021300E+03, -.13543700E+04, 0.50186100E+03, -.83978100E+03, -.10592100E+02, 0.31541300E+02, 0.26540800E+03, -.61742300E+01, 0.41545000E+03, -.97548700E+02, -.71703900E+03, -.39626900E+03, 0.11089300E+03, -.14195900E+04, -.44062100E+03, -.12604100E+03, -.21300800E+03, -.99074800E+03, 0.45024000E+03, -.52448200E+02, 0.42060100E+03, 0.26547800E+03, 0.59393700E+02, 0.30732100E+03, -.37142400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.91711500E-01, 0.10122500E+00, 0.14629500E+01, 0.18942100E+00, -.85087200E+00, -.48785100E-01, -.12876200E+01, -.16357500E+00, 0.18214900E+01, 0.58469700E+00, -.44074200E+00, -.13102100E+00, 0.59968300E+00, 0.48395900E+00, 0.90354800E+00, 0.47421400E-01, -.12451600E+00, -.28410500E+00, 0.22598600E+00, 0.43438800E-01, -.26979200E-01, -.21055400E-01, -.69377400E+00, 0.22465900E-01, -.59523600E-01, -.13677800E-03, -.82883900E-01, -.13248500E+00, 0.14160800E+00, -.12342600E+00, -.10045900E+00, 0.13741300E+00, -.12946000E+00, 0.56930400E+00, -.61440900E+00, -.72220700E-01, 0.72728800E-01, 0.19982700E+00, 0.13127000E-01, 0.29597300E+00, 0.28101100E+00, -.20364200E+00, 0.11422800E+00, 0.14353500E+00, -.16210000E+01, 0.23953700E+00, -.88273100E+00, 0.40438400E-01, 0.62364400E-02, -.33623600E+00, -.15936900E+00, 0.27471300E+00, 0.43164600E+03, -.17336400E+03, 0.29105900E+03, 0.31651600E+04, -.16040600E+04, -.30506500E+04, -.15842900E+04, -.18037800E+04, -.21282100E+04, 0.37888000E+03, 0.10022900E+04, -.11932300E+03, -.22358100E+04, 0.44515800E+03, 0.45452300E+03, -.24020400E+03, 0.99108900E+02, -.22582400E+03, -.18791500E+02, 0.27328000E+03, -.19921200E+03, 0.15605000E+02, -.18055500E+03, 0.19602200E+03, -.81619000E+01, -.24994100E+03, 0.18581500E+03, 0.18847000E+04, 0.12520900E+03, 0.40826400E+03, 0.60403200E+03, 0.61416300E+03, 0.11213800E+04, -.10447700E+03, 0.84195900E+03, -.12140500E+04, -.11081200E+04, 0.58972200E+03, -.19155900E+03, 0.55331500E+03, 0.33681900E+03, -.31206300E+03, 0.24332500E+03, -.56915400E+03, 0.19533700E+03, -.13439100E+03, 0.10375500E+04, 0.51945800E+03, -.24339600E+03, -.90951500E+03, -.25890800E+03, 0.94543600E+03, 0.61355300E+03, -.98746400E+01, 0.11338500E+04, 0.69445700E+03, 0.13003600E+03, -.86419900E+03, -.30453100E+03, 0.13432200E+03, -.24308800E+03, 0.15182500E+03, 0.42379700E+03, -.16690000E+03, -.28860800E+03, -.13380600E+04, -.46485400E+03, 0.39948600E+03, 0.61327600E+02, 0.21075000E+03, -.11916300E+03, 0.30732000E+03, -.10744000E+03, -.20494400E+03, -.21185100E+03, 0.14545000E+03, 0.45142100E+03, -.99607800E+02, -.90315600E+02, -.76073600E+03, 0.74973100E+03, -.41988000E+03, -.17658200E+02, -.37099800E+03, -.27462300E+03, -.19549700E+03, -.63247100E+02, 0.42719400E+03, -.11066400E+03, -.36982500E+03, -.97157300E+03, 0.82731700E+02, -.13796800E+02, -.16641100E+02, -.41182400E+02, 0.13384600E+02, 0.11156600E+03, -.12562900E+03, 0.18779400E+01, -.11129900E+01, 0.40295300E+02, 0.86612900E+02, 0.49058800E+03, -.24370900E+03, 0.13800900E+03, -.24732000E+03, 0.55169500E+03, 0.63490500E+03, -.43054800E+03, -.68640600E+03, -.62181500E+03, 0.43768100E+03, 0.98000000E+03, -.31781100E+04, 0.15945300E+04, 0.19851000E+04, 0.15878400E+04, 0.43910100E+02, 0.32525400E+03, 0.25659800E+03, -.73357300E+03, 0.58026300E+03, 0.26846900E+03, 0.89282600E+03, -.39776500E+04, 0.20182200E+04, 0.16832400E+04, 0.19895400E+04, 0.67999700E+03, -.31172800E+03, 0.28337600E+03, -.13935100E+04, 0.16642000E+04, -.23046800E+03, 0.59916500E+03, -.50030500E+03, 0.16425800E+03, -.27807200E+04, 0.24768800E+03, -.11243600E+04, -.13528000E+04, -.45166700E+03, -.12775500E+04, 0.77458000E+03, -.17153600E+04, 0.25884300E+04, -.83904000E+03, 0.41948000E+03, -.77733600E+03, 0.41926900E+03, -.11578600E+04, -.19855400E+04, 0.11209500E+04, 0.45276600E+03, 0.80763800E+03, -.20374500E+04, 0.10370200E+03, -.97605500E+03, 0.49559800E+03, 0.64179100E+03, 0.48752900E+03, 0.11177300E+03, 0.24984000E+03, 0.92190300E+01, -.26887500E+03, 0.27750600E+03, 0.23215300E+03, 0.27907000E+03, 0.10328300E+02, 0.98237200E+02, -.99909600E+02, 0.42917000E+00, -.68277000E+02, 0.50586800E+02, 0.59324000E+03, 0.62551500E+02, 0.77153000E+02, -.28224200E+02, 0.13156300E+03, 0.79408600E+02, 0.34602400E+02, 0.10573600E+03, -.13927700E+03, 0.20425800E+03, -.16739000E+02, -.72615700E+02, -.21098200E+03, -.43259900E+03, -.33600800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10655400E+00, -.51731500E+00, -.24054600E+01, -.11367100E+01, -.60575800E-01, 0.64582800E+00, -.13421600E+01, 0.17917500E+00, -.20541800E+01, -.94685200E+00, 0.12456900E+00, 0.92411400E-01, -.12097200E+01, 0.10240000E+00, 0.10766500E+00, -.13124300E+01, 0.92039500E+00, 0.59564100E+00, -.33816000E+00, -.99652700E-02, -.22790700E-01, 0.72345600E-01, -.24619900E+00, -.84597600E-01, -.14702300E+00, -.85695700E-03, -.49541000E-01, 0.12641300E+00, 0.21691000E-01, 0.17308800E+00, 0.38314500E+00, -.36182400E+00, 0.11555500E+00, 0.29254100E+00, -.18132800E+00, -.31465800E-02, 0.63520600E-01, 0.10466600E+00, -.46369400E-01, -.44374500E+00, 0.60895200E+00, 0.79764800E-01, -.71942000E-01, -.20568800E-01, -.54670600E+00, 0.22446100E+00, 0.92772800E+00, 0.30020100E-01, -.15511500E+00, 0.21916800E+00, -.25295400E+00, -.30661200E+00, 0.10256700E+01, 0.30936700E+03, -.54742800E+03, -.65989500E+04, 0.33131200E+04, 0.43380900E+04, 0.33043800E+04, 0.25597300E+04, 0.24574800E+04, -.60095500E+03, -.23210100E+04, 0.10834100E+04, 0.24910600E+04, -.31559500E+03, -.69061000E+03, 0.37592300E+03, 0.15461300E+02, 0.34590700E+03, 0.11489700E+03, -.49996900E+02, 0.11442800E+03, -.15077100E+03, 0.11356000E+03, 0.28632500E+02, 0.22706700E+03, -.30924100E+03, 0.13608400E+03, -.96808200E+03, 0.15462800E+03, -.57019600E+03, -.11237300E+04, 0.30373800E+03, 0.46182400E+03, 0.13418000E+04, -.14614100E+04, 0.16413100E+04, 0.12419800E+04, -.65741600E+03, -.56551000E+03, -.61916400E+03, -.26877000E+03, 0.18009900E+03, -.37670500E+03, 0.43209100E+03, -.34677600E+03, 0.10929700E+03, -.40491600E+03, 0.55376200E+03, -.32296900E+03, -.99643700E+03, -.27834400E+03, -.36810600E+03, -.34036000E+02, -.56784500E+03, -.16187900E+04, -.14171300E+04, 0.84929200E+03, 0.90461200E+03, -.15660300E+04, 0.86600800E+03, 0.49438600E+03, 0.78300800E+03, -.26969500E+03, -.10721900E+03, 0.74752500E+03, 0.14608200E+04, 0.13193300E+04, -.85635500E+03, 0.12457800E+04, 0.11778500E+04, -.55420700E+03, -.59432400E+03, -.58601200E+03, -.25399800E+03, -.16232300E+02, -.16575800E+03, 0.22577500E+03, -.21340500E+03, -.19758500E+03, 0.22623200E+03, -.52024300E+03, 0.30274700E+03, 0.53035000E+03, 0.25476200E+03, 0.48882200E+03, 0.52941000E+03, -.18909300E+03, -.70485600E+03, -.63784700E+02, 0.71331300E+03, 0.13156900E+03, -.25926700E+03, 0.11850200E+03, 0.16610300E+03, 0.12949100E+03, 0.36570600E+02, -.49069800E+02, 0.12405800E+03, -.10058900E+03, -.15247800E+02, 0.51711400E+02, -.11217100E+03, -.11686300E+04, 0.54906700E+03, 0.33011200E+03, 0.58912900E+03, -.15210300E+02, -.48943800E+03, 0.34066900E+03, 0.15197300E+02, 0.50832200E+03, -.14478000E+03, -.40282000E+03, 0.41120900E+04, -.20617600E+04, -.16903300E+04, -.20516400E+04, -.17150900E+03, 0.20136900E+03, -.76451700E+03, 0.56803400E+03, -.11829400E+04, 0.64704600E+02, -.78386500E+03, 0.60129900E+04, -.30850400E+04, -.25583900E+04, -.30076400E+04, -.84775400E+03, 0.12332900E+04, -.13155700E+04, 0.81314900E+03, -.29452500E+04, 0.14424500E+04, -.11751900E+03, -.31755700E+03, 0.20529000E+03, 0.21954400E+04, 0.16297300E+03, 0.13071400E+04, 0.20790900E+04, -.50834800E+03, -.94150000E+03, -.18731600E+04, 0.25730700E+04, -.30401400E+04, -.76143800E+03, 0.32552900E+03, 0.13050700E+04, 0.38202000E+03, 0.18143100E+04, 0.30592800E+04, -.19816300E+04, -.18063800E+04, -.11721400E+04, 0.30042100E+04, 0.55140900E+03, 0.15000000E+04, -.78840900E+03, -.66853300E+03, -.74811500E+03, -.23644900E+03, -.15146900E+03, -.12777100E+03, 0.45341100E+03, -.18389600E+03, -.14910200E+03, -.28582500E+03, -.18656500E+02, -.11645000E+03, 0.16490300E+03, -.24918900E+01, 0.20036200E+02, 0.13827100E+03, -.63505100E+03, -.22001700E+02, 0.37745500E+03, -.20115200E+01, -.25060300E+02, -.14130900E+03, -.74984500E+01, -.93298800E+02, 0.21288400E+03, -.10109000E+03, 0.10460800E+03, -.42636400E+03, 0.32845700E+03, 0.68509900E+03, -.62614900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11835600E+00, -.53771100E-01, 0.89063300E+00, 0.79461400E-01, -.10535700E+01, 0.63175000E-01, 0.49879500E+00, 0.49384600E-03, 0.74620500E+00, 0.63773700E+00, -.73275900E-01, 0.28467500E-01, 0.40427100E+00, 0.27417900E+00, 0.84882700E-01, 0.37783800E+00, -.58523400E-02, -.26021900E+00, 0.13097500E+00, -.63629500E-01, 0.44057900E-01, 0.73166600E-02, 0.11583900E+01, 0.69553700E-01, 0.15053000E+00, 0.13665600E-03, 0.18238200E+00, 0.51578300E+00, -.16422800E+00, 0.67182700E-01, -.25429400E+00, -.33213300E-03, -.27048400E+00, -.12164500E+00, 0.34797400E+00, -.41705600E-03, 0.92850200E-01, -.75876900E-01, -.10770600E+00, 0.42183300E+00, -.73162300E+00, -.34969200E-01, 0.35137000E-01, 0.16782500E-01, 0.57318900E+00, -.16992100E+00, -.52160600E+00, 0.90379200E-01, -.74148000E+00, 0.19624400E+00, 0.15917600E+00, 0.53986400E+00, 0.71663200E+00, 0.27366700E+00, 0.47928100E+03, 0.26906700E+04, -.13400000E+04, -.17588600E+04, -.13419800E+04, -.10780600E+04, -.44089300E+03, 0.89263400E+03, 0.23535500E+04, 0.16885000E+03, -.10551700E+04, 0.68308800E+03, 0.12479200E+03, -.14603500E+03, 0.38256900E+03, -.61385400E+02, -.17320700E+03, -.21528400E+03, 0.11643100E+03, 0.90891600E+00, 0.99932100E+01, -.27025500E+03, 0.39676700E+03, 0.22144600E+03, -.17841100E+03, 0.13071600E+04, -.11062900E+03, 0.10258200E+03, 0.73653900E+03, -.14062400E+03, -.11351000E+03, -.78681600E+03, 0.90216800E+03, -.13797700E+04, -.44488500E+02, 0.77892600E+02, 0.74679800E+02, 0.23445100E+02, -.84591200E+02, -.36832700E+01, -.31763000E+03, -.66054400E+03, -.18423800E+03, 0.52694300E+02, 0.20949600E+04, -.32038800E+04, 0.17195600E+04, -.39928600E+04, 0.16010400E+04, 0.16918400E+03, -.24708300E+04, 0.10537200E+04, -.42342500E+02, 0.19079900E+04, -.20488600E+04, 0.13536100E+04, -.51543700E+04, 0.23669100E+04, -.43009100E+03, 0.25770400E+04, 0.53814200E+03, -.18383000E+03, -.22080800E+03, -.33244300E+04, 0.23785100E+03, 0.25447200E+03, 0.26143200E+04, 0.17649000E+03, -.15709100E+03, -.35025200E+03, -.86588500E+02, -.10708400E+03, -.51336800E+03, 0.51880500E+02, -.36777000E+03, -.21233100E+02, -.21564700E+03, -.64074400E+03, -.56961400E+03, 0.21868500E+03, 0.46081100E+03, 0.28183900E+03, 0.51940800E+02, -.24171100E+03, 0.60208400E+03, 0.89835300E+03, 0.53366300E+03, -.22388800E+03, -.18587100E+04, 0.45946000E+02, -.90895900E+02, 0.38241300E+03, -.23022200E+02, -.10862400E+03, -.16421200E+03, 0.10565000E+03, 0.60975900E+02, 0.18310900E+02, -.18069300E+03, -.87901900E+01, -.34037100E+03, 0.27885300E+03, -.55340800E+03, 0.17335900E+03, 0.43159700E+01, 0.12978900E+03, 0.89498100E+02, 0.94746800E+02, -.24882900E+02, -.15331300E+03, 0.23075700E+04, 0.35940300E+04, -.18071600E+04, 0.30989300E+04, -.17939100E+04, 0.64855900E+02, 0.17251900E+04, -.90529400E+03, 0.71287300E+03, -.13506900E+04, 0.13962500E+04, -.26378600E+04, 0.13793300E+03, 0.11867800E+03, 0.93948000E+03, -.69645100E+02, 0.35617300E+03, -.95657100E+03, -.72902800E+03, -.14234200E+04, 0.89546500E+02, -.27325900E+03, -.87020200E+03, 0.27671100E+04, -.13332900E+04, -.22122300E+04, -.13810400E+04, -.43233700E+03, -.64451000E+03, -.23516400E+03, 0.92882000E+03, 0.48582100E+03, -.10609800E+04, 0.74779800E+03, -.19612100E+04, 0.11611400E+04, -.31885200E+02, 0.98154900E+03, -.67816500E+03, -.14648600E+04, 0.20750400E+04, 0.18650800E+04, 0.15059200E+04, -.16707900E+04, -.14954800E+03, 0.41729400E+03, -.12518100E+03, 0.68945200E+03, -.20731400E+03, 0.15048200E+03, 0.58682800E+03, -.27716000E+03, -.42494200E+02, -.33465700E+03, 0.45857400E+03, -.34195800E+03, 0.29934400E+02, -.19901000E+02, 0.58639400E+02, 0.37675200E+01, 0.14606700E+03, 0.19509400E+02, 0.32029700E+03, -.12118500E+03, 0.12563100E+02, -.48553100E+03, -.40095900E+03, 0.73663300E+02, -.42605600E+02, -.35655300E+03, 0.89248200E+02, -.30723300E+02, 0.28039300E+03, 0.48349300E+03, -.26953900E+02, -.41966000E+03, -.61355900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42332600E+00, 0.84571800E+00, 0.29060600E+01, 0.18796200E+01, 0.23025400E+01, -.10484500E+01, 0.15664400E+01, -.48033300E+00, -.46850100E+00, -.73011300E+00, -.18952000E+00, -.25534300E+00, -.19897900E+01, 0.14424300E+01, 0.15153100E+00, 0.48552000E+00, -.28264000E+01, -.23863700E-02, 0.35085600E+00, -.92069300E-01, 0.13966400E+00, 0.10892500E-01, -.22988600E+01, -.43530400E+00, -.39947900E+00, 0.16991800E-01, -.47466300E+00, 0.77995700E+00, -.23888500E+01, 0.20937900E+01, 0.38240200E+00, 0.28001700E+01, 0.16985500E+00, 0.41718300E+00, 0.10882300E+01, 0.43785800E+00, -.60612000E+00, -.48007800E+00, 0.72631800E+00, -.21494900E+00, -.62312600E+00, 0.11503500E+01, -.26380800E+00, 0.12920100E+00, -.14589000E+01, 0.10171100E+01, 0.22834000E+01, -.33192600E+00, -.29178900E+01, 0.13798700E+00, 0.14787600E+01, -.80721000E-01, -.19195600E+01, -.42768100E-01, 0.23982000E+01, 0.14596600E+05, -.72992900E+04, -.26326500E+04, -.73072500E+04, -.42279900E+04, 0.20179000E+03, -.57254600E+04, -.15929200E+04, -.50264300E+04, 0.40129900E+03, -.76227600E+04, -.31671400E+03, 0.20899500E+03, 0.38496900E+03, 0.15294500E+03, 0.23091100E+03, 0.11062000E+04, -.74706000E+03, 0.14089400E+03, 0.14423300E+03, 0.85923600E+03, -.10268200E+03, -.26555500E+04, 0.13569200E+04, 0.44283100E+04, 0.13148800E+04, 0.18379300E+04, 0.20616900E+04, 0.21862300E+04, 0.26856800E+04, 0.79218400E+03, 0.19679300E+04, 0.29594000E+03, -.56928100E+04, 0.28308200E+04, -.48517800E+04, 0.28395700E+04, -.31175000E+03, -.14472100E+04, 0.33039800E+04, 0.10196800E+04, 0.31558400E+04, -.11241300E+04, 0.93864100E+03, 0.63552900E+01, -.48658800E+02, -.71938600E+04, -.11114800E+02, 0.67728600E+04, 0.37093500E+03, 0.16541600E+04, 0.40887700E+04, 0.66341400E+03, -.65020700E+03, 0.10260700E+04, -.28892200E+04, 0.15552800E+04, -.23668500E+03, 0.14588000E+04, 0.17414400E+04, -.18170500E+04, 0.22974900E+04, 0.13778200E+04, 0.21588200E+04, -.15581200E+04, 0.16974100E+04, -.59539200E+04, 0.30238700E+04, 0.16295900E+04, 0.30074600E+04, 0.16353800E+03, -.76650500E+03, 0.62231800E+03, -.91443400E+02, 0.21568700E+04, -.87038700E+03, 0.29497300E+04, 0.46618600E+04, -.22975900E+04, 0.28001900E+04, -.23855800E+04, 0.38524500E+03, 0.30510400E+03, -.28455000E+04, -.17488200E+04, -.30474400E+04, 0.26664400E+03, 0.17763800E+03, -.16995300E+04, 0.85585000E+03, 0.29756000E+03, 0.85944800E+03, 0.33452700E+03, 0.56918200E+03, -.38657500E+03, -.59678300E+03, 0.29786900E+03, 0.48539700E+03, 0.82396500E+03, -.14785400E+04, 0.68867800E+03, -.25214300E+04, 0.74352800E+03, 0.16446000E+04, 0.99169200E+03, 0.13244200E+04, 0.82137900E+02, 0.87870600E+03, 0.14610700E+04, -.14529800E+04, -.74952100E+03, 0.36149500E+03, 0.51009800E+04, 0.35577200E+03, -.31272600E+04, -.42035200E+02, -.68374300E+03, -.14243200E+04, 0.49015700E+03, 0.40516600E+03, 0.14736300E+04, -.11419500E+04, 0.49049200E+03, -.13857500E+03, 0.56225700E+03, -.34302000E+03, 0.10907100E+03, 0.88513200E+03, 0.11495500E+03, 0.79128300E+03, -.85110100E+03, 0.56596900E+04, 0.34180600E+04, -.16912800E+04, -.65032000E+04, -.16784400E+04, -.46292100E+04, -.32439600E+04, -.37069200E+04, -.40241400E+04, -.89503000E+03, -.29699900E+04, -.18757800E+03, 0.17082300E+05, -.86191100E+04, -.44584900E+04, -.85492900E+04, -.45148300E+04, 0.13994400E+04, -.58840400E+04, 0.37849200E+03, -.49262100E+04, 0.63197100E+03, -.38730100E+04, 0.56128700E+03, -.34370300E+03, 0.78934700E+03, -.28882300E+03, -.75485300E+03, 0.80654900E+03, -.39321500E+03, -.51111800E+03, -.27210200E+03, 0.93716500E+03, 0.40628500E+03, 0.94222600E+01, 0.61166200E+03, 0.19044700E+03, -.89519000E+01, 0.82844400E+02, -.65410600E+02, -.36069900E+03, -.12085500E+03, -.10577600E+03, 0.14113600E+04, 0.18436600E+03, -.42460500E+02, 0.20529300E+03, 0.61903700E+03, 0.16841300E+02, -.18187500E+03, -.20735100E+03, 0.77767400E+03, -.87494500E+03, -.17017000E+02, -.89258100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.65092100E-01, 0.10693500E+00, 0.90292700E+00, 0.21037000E+00, -.37328800E+00, -.11431800E+00, -.49964400E+00, -.10474600E+00, 0.10138200E+01, 0.40099400E+00, -.21845900E+00, -.14248600E+00, 0.37915300E+00, 0.53399400E+00, 0.57953200E+00, -.26483300E+00, 0.26872000E+00, 0.51394600E+00, 0.51010200E+00, -.60186100E+00, -.24338000E-01, -.14902700E+00, 0.82399200E+00, 0.16813400E-01, 0.18456000E+00, -.40899200E-03, 0.21173700E+00, 0.41336600E+00, -.14459300E+01, -.34889600E-01, 0.97535400E-02, -.97122100E-01, 0.16545500E-01, -.17480000E+00, 0.44865100E+00, 0.18467600E-01, 0.41092400E-02, -.98948100E-01, -.23223900E-01, -.76456000E-01, -.46132100E-01, 0.16835100E+00, -.12429100E-01, -.60582500E-01, 0.30034600E+00, -.54990700E-01, 0.67889000E+00, -.10460300E-01, 0.10749500E+00, 0.26931200E+00, 0.54016100E-01, -.53781700E-01, -.45650400E+00, 0.13976500E-01, -.32416400E+00, 0.11391000E+00, 0.21717700E+02, -.11719800E+04, 0.16398000E+01, 0.38622200E+03, -.21291600E+03, 0.55742700E+03, 0.33831500E+03, 0.21558400E+03, -.26811800E+03, 0.74976400E+03, 0.19249500E+03, -.87906100E+02, -.93183800E+02, -.94955900E+02, 0.55480800E+01, -.48756300E+02, 0.89471500E+02, 0.50784900E+02, 0.32346100E+02, -.32108400E+02, -.19319500E+03, 0.27831100E+03, -.16556400E+03, -.41848500E+03, -.13759700E+03, -.22412600E+03, -.25770800E+03, -.29106200E+03, -.40947900E+03, -.42920000E+03, -.14573900E+03, -.11472200E+03, -.13164300E+03, 0.30361800E+02, 0.14549500E+04, 0.66802800E+02, 0.17494100E+03, 0.19855400E+03, -.16202400E+03, -.33082500E+01, -.23609300E+03, 0.22173100E+03, -.26151200E+03, -.41013900E+03, 0.17998400E+03, 0.12334500E+04, 0.20593800E+03, -.13098400E+04, -.24945900E+03, -.95738600E+02, -.57102700E+03, 0.25119200E+03, -.12408600E+03, -.33395200E+03, 0.26080300E+01, 0.28818400E+02, 0.10517200E+03, -.31390700E+01, -.34114500E+03, 0.21579200E+03, -.16626100E+03, -.24340000E+02, -.42044500E+02, 0.26748600E+03, -.11553200E+03, 0.31353000E+03, -.14832700E+03, 0.24720800E+03, -.16036200E+03, 0.16941500E+02, 0.11107300E+03, 0.34944700E+01, -.12794700E+03, -.30114100E+03, 0.12819700E+03, -.27691300E+03, -.56742000E+02, 0.73235100E+02, -.84397800E+03, 0.34752800E+02, -.26531500E+03, -.29787900E+03, 0.27189000E+03, 0.74750100E+02, 0.24757500E+03, -.30092700E+03, 0.21937400E+03, 0.22321900E+02, -.15108600E+02, 0.45951300E+02, -.12226900E+02, -.57222600E+02, -.11840200E+03, 0.17559800E+03, 0.14223000E+03, 0.12169300E+03, -.10470000E+03, -.12909500E+02, 0.38311700E+03, -.19389600E+03, 0.58139900E+03, -.19160700E+03, -.17212900E+03, -.72372900E+02, -.10564400E+03, 0.24159500E+03, -.20903500E+03, -.10772400E+03, -.26656000E+03, 0.10406200E+03, -.56715800E+02, -.79392200E+03, -.49174100E+02, 0.61486600E+03, 0.11024700E+03, 0.17827600E+02, 0.20165900E+03, -.66267400E+02, -.26302900E+02, -.18493000E+03, -.12818400E+04, 0.59903100E+03, 0.85418200E+03, 0.64191800E+03, -.10558300E+03, -.61885200E+03, 0.56746500E+03, 0.61148000E+03, 0.90333700E+03, -.50896000E+03, -.64015900E+03, 0.91173200E+02, -.11117800E+01, 0.42015400E+03, -.48958800E+02, 0.58817500E+03, 0.35470400E+03, 0.53905800E+03, 0.79353900E+03, 0.49729800E+03, 0.15771900E+03, 0.10074800E+03, -.45796800E+03, 0.21626400E+03, -.79470600E+03, 0.23018100E+03, 0.15758500E+03, -.87737300E+03, 0.90104300E+03, 0.49115800E+03, 0.79446900E+03, -.79552500E+03, 0.30354800E+03, -.45662300E+03, 0.21689100E+03, 0.42207800E+02, 0.22955600E+03, 0.18284900E+03, -.80243900E+02, 0.78062800E+02, 0.44924800E+02, 0.14860300E+03, -.12595400E+03, 0.45862000E+02, -.26475600E+01, -.10815000E+03, -.14163000E+03, 0.14364500E+01, -.57197000E+02, 0.15821600E+02, 0.71416500E+02, 0.52617500E+02, 0.91424100E+01, 0.34533200E+02, -.70137700E+02, 0.53081200E+01, -.29672200E+02, 0.64537400E+02, -.11716700E+03, 0.78485400E+01, 0.48318200E+02, 0.43153200E+02, 0.12168500E+03, -.17761900E+03, 0.47143000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.93505600E-01, -.94564200E-01, -.15501500E+01, -.19426200E+00, 0.60875200E+00, 0.25242100E+00, 0.38854000E+00, 0.13150100E+00, -.11742200E+01, -.41878800E+00, 0.22484100E+00, 0.73852500E-01, -.79025300E+00, -.16933200E+00, -.31772900E+00, -.68353600E+00, 0.57184500E+00, 0.50831400E+00, -.12544500E-03, 0.13689900E-01, -.16203900E-01, -.13062000E-01, -.49122700E+00, -.35101700E-01, -.14568100E+00, -.90895600E-04, -.12339700E+00, -.52508800E+00, -.21924600E-01, -.29032500E+00, 0.37097600E+00, -.22718100E+00, 0.20543300E+00, 0.28207400E+00, -.20241800E+00, -.12300800E-01, -.41546200E-02, 0.10668600E+00, 0.76655500E-01, -.24397600E+00, 0.65082500E+00, 0.22276900E+00, -.29818800E-01, 0.54647000E-01, -.10753900E+01, 0.22076100E+00, 0.11903300E+01, -.25566400E-01, -.10550700E+00, -.14273200E+00, -.49943900E+00, -.12385400E+00, -.33233600E+00, -.43440600E-01, -.40015600E+00, 0.19114500E+00, -.14542200E+00, -.21377100E+04, -.10223000E+01, 0.40485900E+03, -.31988400E+03, 0.39022200E+03, 0.14328500E+03, 0.38604300E+03, -.61810300E+03, 0.26529800E+04, 0.20259300E+03, -.95536500E+00, 0.53459100E+02, -.99014200E+02, 0.18292300E+03, 0.30193400E+03, -.64973800E+02, 0.12768300E+03, -.11286400E+03, 0.39690300E+03, -.24515100E+03, -.20485000E+04, 0.11264400E+04, 0.86945000E+02, 0.10271500E+04, 0.86841500E+02, -.94050500E+03, 0.51553800E+03, -.29938900E+03, 0.84112700E+03, -.64209900E+03, 0.12260200E+03, 0.30508200E+03, -.21017000E+03, 0.28212600E+04, -.15230700E+03, 0.65167500E+03, 0.87783000E+02, -.19150000E+03, -.23916000E+03, -.45724800E+03, 0.36434200E+03, -.94207200E+03, -.10623400E+04, 0.39009600E+03, 0.17769900E+04, 0.53393000E+03, -.26510700E+04, -.80045100E+03, -.59363500E+02, -.93388800E+03, 0.68293800E+03, -.53241100E+03, -.90883100E+03, -.32768000E+03, 0.41222700E+03, 0.70812900E+02, 0.16054700E+03, -.93205100E+03, -.34916900E+03, 0.28098300E+03, 0.18356100E+03, 0.45331200E+03, -.68208400E+02, -.33787100E+03, 0.72116400E+03, -.28977500E+03, 0.47749300E+03, -.36948900E+03, -.13018000E+03, 0.27060400E+03, 0.88139100E+02, 0.23331000E+03, -.36836800E+03, 0.25619800E+03, -.88370500E+03, 0.40989500E+03, -.13596100E+03, -.21752200E+04, -.18869800E+03, -.52203800E+03, 0.18262300E+02, -.17896700E+03, -.21074000E+03, -.49850600E+02, -.38124500E+03, 0.31641000E+03, 0.47576200E+03, -.14448200E+03, -.51700100E+01, -.23968900E+03, 0.59024200E+02, 0.18534200E+03, -.92614100E+02, 0.16875400E+03, -.14492300E+03, 0.14739900E+03, -.13500200E+03, 0.11692300E+04, -.70701900E+03, 0.71564100E+03, -.58861500E+03, -.68594900E+02, 0.26254200E+02, -.46406300E+03, -.48868700E+03, -.67624200E+03, 0.14430000E+01, -.42857200E+03, 0.10224600E+04, -.49582000E+03, -.45205200E+03, -.50961200E+03, 0.18534800E+04, 0.77199300E+03, -.52948400E+03, -.68559800E+02, -.71940800E+03, 0.54010400E+03, -.10473500E+04, -.17842300E+04, 0.66874800E+03, 0.15730000E+04, 0.89485600E+03, 0.33651900E+03, -.91667800E+03, 0.63756200E+03, 0.76695200E+03, 0.11783100E+04, -.54887300E+03, -.24265500E+04, 0.32066200E+04, -.16892600E+04, 0.38657500E+03, -.16130100E+04, 0.30208400E+03, 0.13941100E+04, -.50309100E+03, 0.81319400E+03, -.11831200E+04, 0.86212400E+03, 0.33064600E+03, -.23742900E+04, 0.97757600E+03, -.98988600E+03, 0.11882200E+04, 0.45944200E+03, -.11354000E+04, 0.80260000E+03, -.18389900E+03, 0.12333800E+04, -.11219700E+04, 0.16928400E+04, -.78801300E+03, 0.29855100E+03, 0.36843300E+03, 0.39472000E+03, 0.38028600E+03, -.16081900E+03, 0.27494200E+03, 0.93820300E+02, 0.24048200E+03, -.19396300E+03, -.10457900E+03, -.25825400E+01, -.93818700E+02, -.27480200E+03, 0.31734700E+01, -.27976800E+03, 0.18756400E+02, 0.17632800E+03, 0.25578400E+03, 0.19879900E+02, 0.18415100E+03, -.19503600E+03, 0.75377700E+02, -.72462600E+01, 0.38059500E+03, -.30067100E+03, 0.20537600E+03, 0.51441800E+02, 0.59857000E+02, 0.22033000E+03, -.21326800E+03, 0.17202200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.77161200E+00, 0.12717400E+01, -.31784800E+01, 0.20045900E+01, 0.19600300E+01, -.16930800E+01, 0.52278400E+01, -.73725100E+00, -.13331700E+01, 0.28762800E+01, 0.36078300E+01, -.30758100E+00, 0.24877500E+01, 0.15850600E+01, -.15275100E+01, 0.63493300E+00, 0.37904500E+01, -.17763400E+01, -.29894900E+01, 0.35591300E+01, 0.88404900E+00, -.11964700E+00, 0.72290800E-01, -.28479400E-02, 0.36804900E+00, 0.24799700E-02, -.36098800E-01, -.39178500E+00, -.83280700E+00, 0.28424800E+00, -.20889000E+00, 0.15777600E+01, -.50707400E+00, -.79260600E-01, -.47589000E+00, -.11594900E+00, -.17207600E+00, 0.15173500E+00, 0.16441000E+00, -.42396500E+00, 0.54996500E-01, -.19415300E+00, -.16631900E+00, 0.77436500E-01, 0.10779500E+01, -.28850300E+00, -.37170400E+01, -.48901600E-01, 0.23728700E+00, 0.25980000E+01, 0.11228500E+01, 0.33527500E+01, 0.41524900E+01, -.42737200E+00, 0.63789900E+01, -.13006800E+01, 0.16008800E+01, -.51191400E+01, -.51390400E+02, -.11017200E+04, 0.26031900E+04, -.81894000E+04, -.11030700E+05, -.53339500E+04, 0.39525100E+04, 0.11017600E+05, 0.89636800E+03, 0.28222800E+03, -.16557400E+04, -.46256300E+03, 0.17095200E+04, 0.29663900E+04, -.18292900E+04, 0.42155000E+03, -.11309200E+04, 0.33268100E+04, -.27946300E+04, -.11019200E+05, 0.61342200E+04, -.20603600E+04, 0.55032500E+04, 0.25808700E+04, -.43304600E+04, 0.34075100E+04, -.70806700E+03, 0.77880400E+04, -.44046900E+04, 0.50047400E+04, -.63475200E+03, -.50175900E+02, 0.47415700E+04, 0.29640300E+03, 0.15072000E+04, -.17710100E+04, 0.10888400E+04, -.12729200E+04, 0.13369300E+04, -.46253900E+03, -.97695600E+04, 0.33921900E+04, -.26383800E+04, 0.15677000E+05, -.16887600E+04, -.76102500E+03, 0.50902000E+04, -.12272900E+04, -.14022800E+04, -.23997500E+04, 0.33572700E+04, -.11849300E+05, 0.13946300E+05, -.52620900E+04, 0.21166500E+04, -.69615600E+04, -.55561800E+04, -.12351800E+04, 0.34611500E+04, 0.13987000E+05, 0.42515100E+03, -.23199700E+04, -.75949000E+04, 0.67685800E+04, -.28593100E+04, -.82292900E+03, -.33883800E+04, -.16927200E+04, -.26148500E+03, 0.17473200E+04, 0.72375700E+04, 0.25853600E+04, -.16720800E+04, -.11032200E+04, 0.56511800E+04, -.23830700E+04, -.61066100E+04, -.28106600E+04, -.10311000E+04, 0.26043500E+04, -.39878800E+04, -.31277300E+04, -.44048200E+04, 0.68155100E+03, 0.71890300E+04, 0.24151100E+03, 0.40628600E+03, -.13708800E+04, -.11608300E+03, 0.10283900E+04, 0.20813700E+04, -.10316900E+04, 0.12775700E+03, -.84171400E+03, 0.19302700E+04, -.33662300E+03, 0.13627200E+03, -.93171600E+03, 0.35333400E+04, -.10895200E+03, 0.87286700E+03, 0.31196200E+03, -.19184400E+04, -.73770200E+04, -.14613200E+04, 0.22596700E+04, -.10180700E+05, -.41540600E+03, 0.30006300E+03, -.10172600E+05, 0.15416200E+03, 0.33762600E+04, -.40616100E+04, -.42708500E+03, -.32184700E+04, 0.92424500E+03, -.27675400E+04, 0.12896700E+04, -.67206100E+04, 0.18500400E+04, 0.13278700E+04, 0.33641500E+04, 0.30730100E+04, -.20073500E+03, 0.61986000E+04, 0.79857000E+04, 0.33624900E+04, -.25843800E+04, -.91055300E+04, 0.38349600E+04, -.23561000E+04, 0.80942400E+04, -.19382700E+04, -.28250500E+04, 0.52952600E+04, -.24828900E+04, -.69480900E+02, -.80554900E+04, 0.59918300E+04, 0.20583300E+04, 0.10805000E+05, -.68094700E+04, -.45515700E+04, -.54216000E+04, 0.29686600E+03, 0.49705200E+04, -.11932500E+05, -.10010100E+05, -.98537900E+04, 0.51671600E+04, 0.62149700E+04, -.40903400E+04, 0.13704400E+04, 0.61525000E+02, 0.20215300E+04, 0.21732400E+03, -.21164600E+04, 0.20898700E+04, 0.46616200E+02, 0.15698300E+04, -.15206300E+04, 0.85076300E+03, -.11712000E+02, 0.50780900E+03, 0.70504300E+02, 0.64155500E+01, -.91079500E+03, 0.45502300E+02, -.94308000E+03, 0.63191800E+03, -.12900400E+04, 0.17957400E+04, 0.42029700E+03, -.13066400E+03, 0.99877400E+03, 0.21867500E+04, -.29615200E+03, 0.13167900E+04, -.12084700E+04, -.51679200E+03, -.10083000E+02, 0.14362000E+04, 0.26783500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20737000E+00, 0.54234300E+00, -.43893100E+01, 0.63034300E+00, 0.11041900E+01, 0.23475800E+00, 0.50406700E-01, -.42198800E-01, -.10233000E+01, 0.29279900E+00, 0.13313400E+01, -.12611000E+00, 0.81975500E+00, 0.96648100E+00, 0.19061600E+00, -.48236000E+00, 0.10662300E+01, -.11419700E-02, -.87248600E+00, 0.10605000E+01, 0.15893700E+00, -.57993000E-01, 0.38905400E+00, -.11625600E+00, -.11879000E+00, -.10690000E-02, -.41072800E-01, -.81004000E+00, -.45442100E+00, -.31407400E+00, 0.18437100E+00, -.29015100E+00, -.12392700E-01, 0.27267400E+00, 0.13028600E+01, 0.86420400E-01, 0.57661600E-01, -.47948900E-01, 0.13156200E+00, -.24052800E-01, 0.68627300E+00, 0.45648000E+00, 0.11228200E+00, -.59975200E-01, -.99253700E+00, 0.26945300E-01, 0.19587600E+01, 0.84191100E-02, -.41267200E+00, 0.50341200E+00, -.35786300E+00, 0.20149000E+00, -.14209800E+00, 0.29394500E+00, 0.30545200E-02, -.25264200E-01, -.78551000E+00, 0.14884100E+01, 0.12607100E-01, 0.18453200E+04, 0.85127400E+03, -.18211200E+04, -.27138500E+04, -.15682600E+04, 0.14596100E+04, -.54117000E+04, -.32599900E+03, 0.10602200E+03, 0.29464300E+02, 0.16011800E+03, 0.23702900E+02, 0.61981200E+02, 0.17432500E+03, 0.40101100E+03, 0.26899300E+03, 0.15273000E+02, -.89796900E+03, 0.41690000E+04, -.20790100E+04, -.21646100E+04, -.20878600E+04, -.17772000E+04, -.51873400E+03, -.49439400E+03, 0.49126800E+03, -.75880500E+03, -.62490300E+03, -.78194000E+03, -.26072600E+04, 0.12743300E+04, 0.56973200E+03, 0.13025700E+04, -.29248900E+03, 0.17794700E+03, 0.17996800E+04, 0.23645700E+04, 0.15848700E+04, -.22809700E+03, -.27829100E+04, 0.62958800E+04, -.31471600E+04, 0.21983100E+04, -.31518000E+04, 0.46986200E+03, 0.32043900E+04, -.18133700E+04, 0.89631900E+03, -.31419600E+04, 0.28981500E+04, 0.97391800E+03, 0.62763100E+04, -.31516400E+04, -.33092400E+03, -.31326600E+04, -.95987900E+03, -.12228600E+04, 0.15644000E+04, 0.62249100E+04, 0.17681500E+04, -.19115900E+04, -.32265100E+04, -.35201300E+04, 0.17554500E+04, 0.19963100E+04, 0.17728700E+04, 0.55960500E+03, 0.32760400E+03, 0.17031500E+03, -.11334800E+04, 0.63051500E+02, 0.46668000E+02, 0.16554000E+04, 0.15926700E+04, -.77742900E+03, -.79087900E+03, -.81681100E+03, 0.15639200E+03, -.41156900E+03, -.13751000E+04, -.23510800E+04, -.13131500E+04, 0.13395200E+03, 0.39636600E+04, -.70056800E+03, 0.35717700E+03, 0.11431600E+02, 0.35225100E+03, 0.14659000E+02, -.93496800E+02, 0.72824000E+02, -.18555400E+03, 0.33021900E+03, -.41143400E+00, 0.49821500E+03, 0.72184400E+02, -.22292900E+02, 0.10713900E+04, -.31437700E+02, 0.67802300E+02, -.28461200E+02, 0.97123100E+03, 0.21954500E+04, 0.76088600E+03, 0.17775500E+03, -.38482400E+04, -.58636200E+04, 0.29166700E+04, -.28826000E+04, 0.29281600E+04, -.88739300E+03, -.18880300E+04, 0.14083200E+04, -.11280400E+04, 0.18652800E+04, -.16891600E+04, 0.46319500E+04, -.12846700E+04, 0.64429200E+03, -.50551300E+03, 0.63841500E+03, -.13917200E+04, 0.49325700E+03, 0.13077600E+04, 0.19858500E+04, 0.83169400E+03, -.19624700E+03, 0.11342900E+05, -.10539600E+05, 0.52448500E+04, 0.33462700E+04, 0.52814700E+04, 0.31934800E+04, 0.47341400E+03, 0.78445500E+03, -.27296400E+04, 0.15111900E+04, 0.74553300E+03, 0.21181900E+04, 0.79408200E+04, -.39655500E+04, -.28573700E+04, -.39729500E+04, 0.37171500E+03, 0.12068600E+04, -.29513000E+04, -.63313100E+03, -.25969400E+04, 0.14214100E+04, 0.82781600E+03, 0.26793100E+03, -.13165000E+03, -.12240600E+04, -.13582300E+03, -.35108000E+03, -.48136400E+03, -.21464000E+02, -.24868600E+01, 0.20809300E+03, -.41585800E+03, 0.49294700E+03, -.65923000E+02, -.42575300E+02, -.91332900E+02, -.14838200E+02, 0.67722800E+02, -.72674300E+01, -.40271100E+03, -.51758100E+02, 0.11920200E+04, 0.13091500E+04, 0.61657900E+03, -.45559200E+02, -.95322700E+02, 0.47904000E+03, -.89011600E+02, -.38491100E+03, -.20837700E+03, -.51147200E+03, 0.40763600E+03, 0.23080500E+03, 0.33695500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.27138300E+00, 0.13546800E+00, 0.11532400E+01, -.43216500E+00, 0.12509800E-01, 0.64442600E+00, -.23528700E+00, -.10284300E+00, -.30067300E+00, -.99155900E+00, -.24980200E+00, 0.14678300E+00, -.96993100E+00, -.80542500E+00, -.23155100E+00, 0.32066000E-01, 0.34826500E+00, -.22582400E+00, 0.67194800E+00, -.10490700E+01, -.49417400E-01, 0.48223600E-01, 0.16077600E+01, 0.96346700E-01, 0.37691900E+00, 0.90643200E-03, 0.25839900E+00, -.24638800E+00, 0.73474800E+00, -.22701700E+00, 0.32450900E+00, -.10710500E+01, 0.55558900E+00, 0.56129900E+00, -.99754900E+00, 0.56895400E-01, -.40469400E-01, 0.35468900E+00, 0.11620500E+00, -.50371300E+00, 0.90983600E+00, 0.29795800E+00, -.87337500E-01, 0.16470800E+00, -.16094300E+01, 0.38335100E+00, -.47422200E+00, -.45871200E-01, 0.27699200E+00, -.62652500E+00, -.61133500E+00, -.71331200E+00, 0.50302900E+00, 0.49996300E+00, 0.64527900E-01, -.16294600E+00, -.45930900E+00, -.40817900E+00, 0.10363600E+00, 0.16790900E+00, -.18796000E+04, 0.32268400E+04, 0.41275500E+04, 0.22473000E+04, -.21390700E+04, -.11712800E+04, 0.30375500E+03, -.22069200E+03, -.22446000E+02, -.15067000E+03, -.18954200E+03, -.46385100E+03, 0.15440400E+03, -.16145300E+03, 0.32493000E+02, -.47988300E+03, 0.40047200E+03, 0.90074800E+03, -.55124000E+03, -.57733200E+03, -.44949500E+03, 0.21826000E+03, 0.10169900E+04, -.15562700E+04, -.16796600E+04, -.19617100E+04, 0.11939400E+04, -.70303200E+03, 0.14925600E+04, -.72032100E+03, -.21020200E+03, -.74591000E+03, 0.74783600E+03, 0.85527800E+03, -.14632300E+04, -.10543300E+04, -.14477900E+04, 0.59364100E+03, 0.51785600E+03, -.75719400E+03, 0.47716600E+03, -.42841500E+03, 0.38005900E+03, -.20783100E+04, -.10077900E+04, -.93805800E+02, -.64452100E+03, 0.69560500E+03, -.80119700E+03, 0.25765000E+04, 0.17128300E+03, -.27338900E+03, -.68786000E+03, -.87827500E+02, 0.37496900E+03, -.15457900E+03, -.50801100E+03, -.17386300E+04, -.83899000E+03, 0.33869800E+03, -.10497500E+04, -.33486200E+04, 0.16226000E+04, 0.12947600E+04, 0.16695300E+04, 0.10380300E+04, 0.12825900E+04, -.16216500E+03, -.13420400E+04, -.82849600E+03, 0.15722300E+04, 0.89059200E+03, -.19173000E+04, 0.93045500E+03, 0.34810400E+03, 0.96542800E+03, -.76477700E+03, -.78039400E+03, 0.16315500E+04, 0.15819100E+04, 0.17174600E+04, -.60673600E+03, -.36639300E+03, 0.23487400E+03, -.18060000E+03, -.59603300E+02, -.11781900E+03, -.16159200E+03, -.27418400E+03, 0.15523800E+03, 0.18635300E+03, 0.22762700E+03, -.31301700E+03, 0.12689700E+03, 0.24781800E+04, -.11518800E+04, -.19416300E+04, -.12408300E+04, -.73268700E+03, -.24410600E+03, -.10076300E+04, 0.17324900E+03, -.50531000E+03, -.80192800E+03, 0.11555000E+04, -.14261700E+04, 0.70913300E+03, 0.15576600E+04, 0.71436900E+03, 0.54014200E+03, 0.66109400E+03, 0.25549100E+03, 0.41654400E+03, 0.65110400E+02, 0.48253400E+03, -.38477100E+03, 0.58324400E+03, -.13095500E+03, 0.38685300E+02, -.29013900E+03, -.54871600E+03, 0.13196600E+03, -.13843800E+04, -.23701000E+04, -.23493400E+03, 0.71784600E+03, -.15803700E+03, 0.77724700E+02, 0.43819200E+02, 0.83967200E+03, -.42590600E+02, -.17150900E+03, -.14865000E+04, 0.25615900E+04, 0.34202000E+04, 0.26951200E+04, -.18027500E+04, 0.54240200E+02, -.51737700E+04, 0.27370500E+04, 0.21009200E+04, 0.25879800E+04, -.58791700E+03, -.29005100E+04, 0.45995100E+04, 0.31787200E+04, 0.48796100E+04, -.27593600E+04, -.69723700E+03, 0.39060000E+03, -.11543700E+03, 0.17309400E+02, -.19455700E+03, 0.52287300E+02, 0.10201100E+02, -.19642300E+02, 0.22632100E+03, -.91445000E+02, -.23721200E+02, -.47495100E+03, -.95650300E+01, -.72984900E+02, -.34865000E+03, 0.84034700E+00, -.89181800E+02, -.26867500E+02, 0.46239400E+03, 0.10388600E+03, -.78852900E+03, -.73336200E+03, -.96836100E+02, 0.16503300E+03, -.27425000E+03, -.19650700E+03, -.32570500E+03, 0.83640800E+02, 0.11301100E+03, 0.70575900E+02, -.19588600E+03, -.59973200E+03, 0.56514000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11846500E+00, 0.51637600E+00, 0.16717500E+01, 0.82844800E+00, -.36967100E+00, -.50603700E-01, 0.46307500E+00, -.70608600E-01, 0.12204500E+01, 0.74000800E+00, -.12174700E+00, -.13613600E+00, 0.45874000E+00, -.63305500E+00, -.13274900E+00, 0.91685300E+00, -.54352200E+00, -.12768300E+00, 0.59596000E+00, -.55309900E+00, -.19042000E-01, -.10873600E+00, 0.36819600E+00, 0.41306700E-01, 0.48082500E+00, 0.72082900E-03, 0.13511100E+00, -.45714900E+00, 0.88410500E-01, 0.96882200E-01, -.15007500E+00, 0.40031000E+00, 0.44559100E+00, 0.33988400E+00, -.15279800E+01, -.47422000E-01, -.57704200E-01, 0.30387000E+00, 0.43987900E-01, -.13380600E+01, 0.13318900E+01, 0.22240200E+00, -.25271800E+00, -.13786600E+00, -.11888800E+01, 0.38680400E+00, -.60238000E+00, 0.11349400E-01, 0.94272800E+00, -.16152200E+00, -.17503100E+00, -.36710000E+00, -.33565100E+00, -.17897000E+00, 0.24898300E+00, -.33374500E+00, 0.24824000E-01, -.10988300E+01, 0.81797900E-01, -.20782800E+00, 0.40952900E+00, -.19439500E+04, -.20026700E+04, -.78692600E+03, 0.24952200E+03, -.40069200E+03, -.32559700E+03, 0.27026400E+03, 0.44925700E+02, 0.16252800E+03, 0.31231700E+03, 0.62955200E+03, -.28922900E+03, 0.32293700E+03, -.11220100E+03, 0.59752900E+03, -.29766700E+03, -.66840400E+03, 0.42150400E+03, -.58217000E+03, 0.33235200E+03, -.18341000E+03, -.11283600E+04, 0.12180900E+04, 0.98414100E+03, 0.26282200E+04, -.10582500E+04, -.38515900E+03, -.14118100E+04, 0.61238000E+03, 0.17167700E+03, 0.70536700E+03, 0.69826300E+02, -.82981800E+03, 0.14648200E+04, 0.67126300E+03, 0.14103400E+04, -.69833900E+03, -.23206500E+04, 0.48781500E+04, -.26115400E+04, 0.13359000E+04, -.24405500E+04, 0.70892400E+03, 0.28810200E+04, -.15600800E+04, 0.29800700E+03, -.26440300E+04, 0.23480700E+04, -.57643200E+03, 0.49768900E+04, -.21828600E+04, -.31111300E+03, -.24864800E+04, -.14719400E+04, -.19180800E+04, 0.18459000E+04, 0.49868600E+04, 0.17030200E+04, -.21244400E+04, -.31495200E+04, -.62865000E+03, 0.41568400E+03, 0.82088800E+03, 0.31932300E+03, -.26250900E+03, -.82240400E+02, 0.44023400E+03, 0.74681500E+03, 0.89371500E+03, -.32383400E+03, 0.77659600E+02, 0.16410100E+04, -.71367400E+03, -.85705300E+03, -.82953500E+03, 0.15392100E+03, 0.79722200E+03, -.18218600E+04, -.16600000E+04, -.17220100E+04, 0.63932200E+03, 0.24819500E+04, -.68057600E+03, 0.42551100E+03, 0.13119000E+03, 0.34170400E+03, 0.28946700E+03, 0.46629600E+03, -.25547400E+03, -.19328400E+03, -.13540200E+03, 0.44587800E+03, 0.45934800E+03, 0.34168700E+01, -.15436800E+03, 0.50610400E+03, 0.11814600E+00, 0.51110900E+03, 0.94215700E+02, 0.15930100E+03, -.83309200E+03, -.17248000E+03, 0.44534500E+03, -.24403300E+04, -.47714900E+04, 0.23931900E+04, -.97814800E+03, 0.23842100E+04, 0.43687700E+03, -.86783800E+03, 0.43215200E+03, -.19262200E+04, 0.99922500E+03, -.56913800E+03, 0.29176000E+04, -.92824600E+03, 0.18814000E+03, -.40408600E+03, 0.46261700E+03, 0.44495900E+03, 0.93712400E+03, 0.51489200E+03, 0.67882800E+03, -.28848100E+03, 0.32273000E+03, 0.42061300E+04, -.45601300E+04, 0.22249800E+04, 0.24791300E+04, 0.22854700E+04, 0.52936200E+03, 0.13145100E+04, -.10141900E+04, -.22712100E+04, -.22525700E+04, 0.13137200E+04, 0.28505400E+04, 0.23395100E+04, -.14253600E+04, -.66214900E+03, -.11705400E+04, 0.39241900E+03, 0.18610100E+04, -.36219700E+04, -.23698000E+04, -.30779400E+04, 0.16407600E+04, 0.34648900E+04, -.28896000E+02, -.10905200E+03, -.47362300E+03, 0.13793200E+02, -.23338200E+03, -.48626700E+03, 0.30363700E+03, 0.28115200E+02, 0.30588800E+03, -.35067500E+03, 0.71252600E+02, -.43853500E+02, 0.13676200E+03, 0.70832000E+00, -.90077400E+01, -.17220600E+03, -.23638500E+02, -.13543400E+02, 0.15768100E+03, 0.41312200E+03, 0.78730600E+03, 0.51882500E+03, 0.78154200E+02, 0.16250800E+03, 0.61049400E+03, -.13269900E+03, 0.16556900E+03, -.28036500E+03, -.54562400E+03, 0.83121100E+02, 0.32339100E+03, 0.38153800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39969000E-01, -.93948500E+00, -.72180900E+00, -.81454700E+00, -.17979300E+00, 0.47277600E-01, 0.51252100E+00, 0.39468000E-01, -.15141300E+00, -.93535300E-01, -.92020500E-01, 0.79361600E-01, -.19061700E+00, -.10038700E-01, 0.56069300E-01, -.23537600E+00, 0.24008100E+00, 0.39124600E-01, 0.15716100E+00, -.10048600E+00, -.16878800E-01, -.12689000E-01, 0.38458300E+00, 0.35000000E-01, -.18340400E-01, 0.39679600E-03, 0.38667700E-01, -.14995100E-01, 0.26143100E-01, -.15828200E+00, 0.30316600E-01, -.22070300E+00, 0.17868500E-01, -.26050500E+00, 0.90733800E-01, 0.28859700E-02, -.97862700E-03, -.12615600E-01, -.60303600E-01, 0.16480900E+00, -.58544800E-02, -.18988900E+00, 0.64230700E-01, 0.11462600E-01, 0.28405600E+00, -.10201700E+00, -.18234300E+00, 0.11363900E-01, 0.27142700E+00, 0.90335400E-01, -.22537800E-01, 0.73422500E-02, 0.12987700E+00, 0.43073100E-03, -.42701500E+00, -.75712800E-01, 0.31860900E+00, -.90322800E-02, -.94296900E-02, -.90737300E-01, 0.22632300E-01, 0.85683000E-01, 0.30671800E+03, -.14454400E+00, -.10429900E+03, -.53921000E+03, -.24365600E+03, 0.77256800E+02, 0.25535300E+03, 0.12053800E+03, -.50064300E+02, -.42484100E+02, 0.77506400E+02, 0.83539800E+02, 0.78815600E+02, -.83365700E+02, 0.54545900E+02, 0.16607600E+04, -.86457700E+03, -.13856300E+03, -.83208900E+03, -.31859200E+03, 0.14086500E+03, -.19375200E+03, 0.15834400E+03, -.51812800E+03, 0.14315200E+03, -.59366500E+03, -.25877800E+03, 0.15425400E+03, -.20641800E+03, 0.12897300E+03, -.23955100E+03, -.53433700E+02, 0.38186900E+03, 0.53161400E+03, 0.38679900E+03, -.11982700E+03, 0.56632500E+02, -.13455600E+03, 0.12627500E+03, -.86521300E+03, 0.65719000E+02, 0.56538500E+03, -.12500200E+03, 0.24085800E+02, -.29614000E+01, 0.38583900E+02, -.44615500E+02, 0.19809000E+03, -.82700100E+03, 0.30775600E+03, -.23825300E+02, 0.41562700E+03, 0.16120300E+03, -.40354400E+02, 0.86651600E+02, -.16151300E+03, 0.25767500E+03, -.37853600E+02, 0.53061800E+03, 0.27592900E+03, -.17137800E+03, -.17762900E+03, -.13272400E+03, -.14385200E+02, -.13170400E+03, -.18338000E+03, -.35412900E+03, -.15187700E+03, -.83193800E+02, -.11373100E+03, 0.10210100E+03, -.80542700E+02, 0.14109300E+03, -.60240300E+02, 0.24588200E+03, -.58729300E+02, -.23248700E+03, -.41670200E+03, -.22735400E+03, 0.72364300E+02, 0.61520000E+02, -.21407600E+03, 0.76281600E+02, 0.14979200E+03, 0.10814400E+03, -.12022400E+02, -.37782400E+02, 0.12884300E+02, -.73957900E+02, 0.21314000E+02, -.31453300E+02, 0.10346800E+03, -.40286800E+03, 0.25595800E+03, 0.16527000E+03, 0.20333300E+03, -.10262600E+02, -.90724100E+02, 0.49607600E+03, 0.61891600E+03, 0.36069000E+03, -.12600300E+03, 0.44486200E+00, 0.55858100E+03, -.28540900E+03, 0.35321300E+03, -.28086000E+03, -.31431100E+03, 0.17080600E+03, -.10403300E+03, 0.14400900E+02, -.18453000E+03, 0.12807100E+03, -.14974100E+03, 0.13682700E+03, 0.25412100E+02, -.45092000E+02, -.70000900E+02, -.57832100E+01, 0.52802300E+02, -.30678300E+03, -.60204700E+03, -.19777100E+03, 0.18762700E+03, 0.85555400E+03, -.16838900E+04, 0.86426400E+03, -.19358700E+03, 0.84729500E+03, 0.38020900E+03, -.12031300E+03, -.72720500E+02, -.44984600E+03, 0.41172200E+03, -.15903500E+03, 0.46710600E+03, -.50286200E+03, 0.33904600E+03, 0.28976300E+03, 0.25052900E+03, 0.56652200E+02, 0.41308300E+02, -.10491500E+01, 0.94730900E+02, -.25153400E+02, -.23299500E+02, 0.12985200E+03, 0.28552600E+03, -.10174400E+03, -.13315500E+02, -.14347700E+03, -.71378200E+02, 0.11119500E+03, -.11212800E+03, -.68531800E+02, -.89154400E+02, 0.83235300E+02, -.53009900E+02, 0.61870600E+00, -.59717600E+01, 0.76641500E+02, -.11302500E+01, 0.85719100E+02, -.76053400E+01, 0.70497200E+02, -.65627600E+02, 0.24873600E+03, 0.15412500E+03, -.21959100E+02, -.15385100E+02, -.36222700E+02, -.60048300E+02, 0.77344500E+02, -.13248900E+03, 0.47801600E+02, -.22338200E+02, 0.29632900E+02, -.12018600E+02, -.20545400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27261700E+00, -.16436000E+01, -.36930400E+01, -.30216700E+01, -.35418500E+00, 0.15255600E+00, -.76521600E+00, 0.15193700E+00, -.40391000E+01, -.11098600E+01, 0.20169700E+00, 0.17336100E+00, -.86507300E+00, 0.99584800E+00, -.11217500E+00, -.14472700E+01, 0.25636300E+00, 0.81172800E+00, -.48874300E+00, 0.66427600E+00, -.32737400E-01, -.56268400E-01, -.16549500E+01, -.96202200E-01, -.50233600E+00, -.59388800E-03, -.24525400E+00, 0.11990600E+01, -.14299700E+01, 0.57863000E+00, -.47799300E-01, 0.12637100E+01, -.74043300E+00, 0.18451500E+00, 0.15616900E+01, -.99793800E-01, 0.11781000E+00, -.38038500E+00, -.23059100E-01, 0.15189400E+01, -.12139200E+01, -.11895200E+01, 0.36073800E+00, -.21268100E+00, 0.21710800E+01, -.66147700E+00, -.10152100E+01, 0.14364400E+00, -.25449600E+00, 0.59863200E+00, 0.25286800E+00, 0.14511000E+01, 0.26846500E+01, 0.11066900E+01, 0.79547100E-02, -.15714400E+00, 0.10554500E+01, -.34809600E+00, 0.98088900E-01, -.42937900E-01, 0.11230400E+00, 0.61858600E-01, 0.44499700E+01, 0.16396200E+04, 0.19264600E+03, 0.25039900E+04, 0.10322300E+04, -.38163900E+03, -.13297700E+04, -.51232900E+03, -.56763000E+02, -.36660400E+03, -.16896300E+03, -.48932900E+03, -.30278000E+03, -.15454500E+03, 0.13924000E+03, -.89543800E+04, 0.45669700E+04, 0.13155100E+04, 0.44824100E+04, 0.14153300E+04, -.56054200E+03, 0.14202600E+04, -.41908600E+03, 0.34880200E+04, -.59785200E+03, 0.31574800E+04, 0.19662300E+04, -.10542500E+04, 0.64341700E+03, -.98206400E+03, 0.52577100E+03, -.23308900E+03, -.18169200E+04, -.26020100E+04, -.17537400E+04, 0.23110800E+03, 0.92937400E+03, 0.73063300E+02, -.20563100E+03, -.48761200E+03, -.32429400E+02, -.18259300E+04, 0.47723700E+03, -.15741400E+03, -.76173300E+03, -.76153700E+03, 0.28517900E+03, -.95669400E+03, -.12772600E+04, 0.93717700E+03, 0.12204100E+03, 0.63323300E+03, -.45825400E+03, -.21936200E+03, -.64194900E+02, -.18982800E+04, -.58247600E+03, -.11348600E+03, 0.38899600E+03, 0.57766000E+03, -.19385000E+03, 0.30778900E+02, -.30275300E+03, -.83217800E+03, -.68069500E+03, 0.96398100E+03, 0.20361500E+04, 0.12778300E+04, -.68888100E+03, -.30699200E+03, -.10985900E+04, 0.63200300E+03, 0.56208900E+03, 0.57537300E+03, -.46292800E+03, 0.11278400E+04, 0.97511500E+03, 0.22951600E+04, 0.11508200E+04, 0.39471600E+03, -.16180200E+04, 0.13193500E+04, -.57340200E+03, -.43088000E+03, -.66319400E+03, -.84585400E+01, 0.52448000E+02, -.14447600E+03, 0.18033400E+03, -.51411300E+03, 0.47595500E+02, -.75678200E+03, 0.95545300E+03, -.63639700E+03, -.40358600E+03, -.48275700E+03, 0.28394100E+03, 0.31782900E+03, -.19442500E+04, -.31013300E+04, -.20137900E+04, 0.52077100E+03, 0.15830800E+04, -.13238100E+04, 0.68502800E+03, 0.93645000E+03, 0.66622800E+03, 0.14168900E+04, 0.11556300E+03, 0.16395600E+03, 0.51155600E+03, 0.46429400E+03, 0.21982800E+03, -.25251200E+03, -.78161500E+03, 0.12633300E+03, 0.98921000E+03, 0.39499000E+03, 0.88302100E+01, -.48957300E+03, 0.12865700E+04, 0.20026300E+04, -.11475100E+03, -.94159600E+03, -.42427900E+04, 0.11154000E+05, -.56318300E+04, -.60608400E+03, -.55924200E+04, -.18320800E+04, 0.55543700E+03, -.76563800E+03, 0.22673400E+04, -.31385300E+04, 0.65747800E+03, -.34735900E+04, 0.56726300E+03, -.53257200E+03, -.56818300E+03, -.28151600E+03, 0.70490000E+03, 0.57951700E+03, -.24968000E+03, -.14913300E+03, -.40318600E+03, 0.59508200E+03, -.12015100E+04, -.63285900E+03, 0.20558600E+03, 0.39045300E+03, 0.31823400E+03, 0.56346000E+03, -.37828700E+02, 0.18609900E+03, 0.34027000E+03, 0.26174300E+02, 0.33748100E+02, 0.11782600E+02, 0.23674700E+01, 0.72547900E+02, -.14171100E+03, 0.57051000E+01, -.24064700E+03, 0.65879400E+02, -.31953000E+03, 0.17881000E+03, -.98269700E+03, -.11278300E+04, 0.69942100E+02, 0.73115900E+02, 0.32211400E+03, -.66233700E+02, -.99187900E+02, 0.66458000E+03, -.75173600E+02, 0.11592100E+03, -.99483900E+02, 0.11701600E+03, 0.68445800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.94403900E-01, 0.14327900E+00, 0.98569800E+00, 0.31653400E+00, -.16956900E+00, -.33187500E+00, 0.14646100E+00, -.10668000E+00, 0.57449400E+00, 0.55389700E+00, -.15457200E+00, -.12664300E+00, 0.61814000E+00, -.75685100E-01, 0.11439900E+00, 0.59035500E+00, -.86266700E+00, 0.12412200E+00, 0.28832000E+00, -.43802100E+00, -.30896000E-01, -.12184800E+00, 0.53808000E+00, 0.75391400E-01, 0.30159200E+00, 0.51825600E-03, 0.21873200E+00, 0.60972400E+00, -.40390400E+00, 0.56084900E+00, -.42860000E+00, 0.44651300E+00, 0.67148900E-01, -.14255900E-01, -.41446000E+00, 0.11073100E-01, -.78948300E-01, 0.23630200E-01, 0.98227600E-01, -.63947400E-01, 0.27171300E+00, -.31396100E+00, 0.30977700E-01, -.26379800E-01, -.55025300E+00, 0.13965600E+00, -.71417300E+00, -.40689700E-02, 0.18547700E+00, -.31110700E+00, -.15014600E+00, 0.24065200E-01, 0.17454300E+00, -.14215700E+00, -.81024500E-01, -.63354400E-01, 0.41688900E+00, -.68768800E+00, 0.52243700E-01, -.41540100E-01, -.18964500E+00, -.34663400E+00, -.30437700E+00, 0.15834600E+00, -.30106200E+03, 0.91243500E+02, -.47604300E+03, 0.23840400E+03, 0.56535300E+03, 0.23681800E+03, 0.88458900E+02, 0.32140400E+03, 0.23885900E+02, 0.19742300E+03, 0.72076000E+02, 0.27679600E+03, 0.38618800E+03, -.16039600E+04, 0.80465200E+03, 0.11600100E+04, 0.80064100E+03, -.13365900E+03, -.58202900E+03, 0.14481800E+04, 0.11157300E+04, 0.12986300E+04, -.35947400E+03, -.61870700E+03, -.49156000E+03, 0.23185200E+03, 0.96879300E+02, 0.24547000E+03, 0.30287600E+03, 0.40378500E+02, 0.61964800E+03, 0.27746100E+03, 0.38645100E+03, 0.41403100E+02, 0.22278700E+03, 0.18901600E+02, -.27321300E+02, -.21273200E+04, -.10691000E+02, -.15712100E+03, -.73968300E+03, 0.14238600E+03, 0.71757400E+03, 0.32110400E+03, -.67681000E+03, 0.10300100E+04, -.10681000E+04, 0.55971600E+03, -.48752300E+03, 0.53574900E+03, -.17531100E+03, -.11117500E+04, 0.65111500E+03, -.20265400E+03, 0.11935000E+04, -.79814900E+03, 0.28531500E+03, -.76339900E+03, 0.38826200E+03, 0.17230100E+03, 0.38586600E+03, -.65331900E+02, -.10620300E+03, 0.42727500E+02, -.28315800E+03, 0.11081900E+03, 0.29576800E+01, -.48620200E+03, 0.71627800E+03, -.33918600E+03, -.45117700E+03, -.36546200E+03, -.56639300E+02, -.24874100E+03, -.62569600E+03, -.55041300E+03, -.62560500E+03, -.22357200E+03, -.38510000E+03, -.31514200E+03, 0.16704300E+03, 0.30676500E+03, 0.15838200E+03, 0.90313400E+02, 0.17527800E+03, -.94325200E+02, -.60049700E+02, -.21551800E+02, 0.14462200E+03, 0.33718600E+03, 0.12959200E+03, -.72354300E+02, -.63355900E+03, -.63289700E+02, 0.42698000E+03, 0.34454700E+03, 0.20039100E+03, 0.19953400E+01, -.16025300E+02, 0.15756500E+03, 0.80421800E+03, 0.47516800E+03, -.23785200E+03, 0.17724900E+04, -.23883300E+03, 0.44064800E+03, 0.96104000E+03, -.68771200E+03, -.64375700E+03, -.71014700E+03, 0.84150300E+03, -.41126900E+03, 0.20450300E+04, -.10513900E+04, -.50179700E+03, -.10237800E+04, 0.11371900E+03, 0.41013700E+03, -.12817900E+04, -.92892400E+03, -.97639200E+03, 0.68830500E+03, 0.67928900E+03, 0.15468700E+04, -.77896000E+03, -.75871100E+03, -.76920600E+03, 0.14885100E+03, 0.94421300E+03, -.20262300E+04, -.17002500E+04, -.17063900E+04, 0.57429800E+03, 0.87567000E+03, -.15606200E+04, 0.75283500E+03, 0.37682800E+03, 0.77958800E+03, 0.15073900E+03, 0.37269000E+03, -.22197500E+03, -.41179600E+03, 0.70399100E+01, 0.17209800E+03, 0.14729900E+04, 0.22938100E+03, -.12637000E+03, 0.25366600E+03, -.11526200E+03, -.29623400E+02, 0.23279900E+03, -.15280300E+03, -.18474800E+03, -.46812800E+02, 0.19009300E+03, -.11028200E+03, -.31063000E+01, 0.78489600E+02, -.88221400E+02, -.23216600E+01, -.10473900E+03, -.30917600E+02, 0.10718700E+03, 0.12952500E+03, 0.63424400E+03, 0.33372900E+03, -.70917700E+02, 0.98963000E+02, -.50133500E+02, 0.20106200E+03, -.14767800E+03, 0.86326000E+01, 0.47819200E+02, 0.64036800E+02, 0.13738700E+03, -.63686000E+01, -.48813300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31854900E+00, 0.19634200E-01, 0.10866700E+01, -.55531200E+00, 0.26313200E+00, 0.54749100E+00, -.14656100E+00, -.11714000E+00, 0.26931500E-01, -.11000100E+01, -.33489400E+00, 0.21092600E+00, -.11017600E+01, -.11554800E+01, -.34692400E+00, 0.33458400E+00, 0.28162500E+00, -.81330800E-01, 0.49130900E+00, -.82795800E+00, -.29869200E-01, 0.14952300E+00, 0.16532100E+01, 0.11261000E+00, 0.59256500E+00, 0.14540900E-02, 0.33260600E+00, -.48774200E+00, 0.89280500E+00, 0.17047900E+00, 0.27782400E+00, -.65406700E+00, 0.49162300E+00, 0.25559200E+00, -.16863800E+01, 0.10737100E+00, -.11331100E+00, 0.33596700E+00, 0.15622700E+00, -.12694100E+01, 0.12220700E+01, 0.37447900E+00, -.31999300E+00, -.99306000E-01, -.14557200E+01, 0.50039700E+00, -.35419600E+00, -.22685300E-01, -.32359700E+00, 0.39492100E+00, -.17430600E+00, 0.64511600E+00, 0.19343300E+01, 0.22630600E+00, 0.20012700E+00, -.63240800E+00, 0.15072900E+01, -.19194900E+01, 0.29025900E+00, -.69776300E+00, 0.36972800E+00, 0.51601900E+00, -.10398200E+01, -.30880500E+00, 0.12940800E+01, -.59779600E+04, -.40231500E+03, 0.79926600E+02, 0.20331000E+03, 0.19801800E+03, -.19254800E+03, -.34025600E+03, 0.33965400E+03, 0.10901000E+03, 0.30781100E+03, -.47192100E+03, -.36684600E+03, 0.90028700E+04, -.45699100E+04, -.16399400E+04, -.45053800E+04, -.12593900E+04, 0.81985600E+03, -.19925400E+04, 0.55548800E+03, -.31739000E+04, 0.71254400E+03, -.21756700E+04, -.25195800E+04, 0.13248600E+04, -.15516800E+04, 0.12584500E+04, -.96964000E+03, -.21053500E+03, 0.13709900E+04, 0.17371000E+04, 0.15931300E+04, -.54003600E+03, 0.43313800E+03, 0.21224300E+04, -.91208700E+03, -.39041200E+04, -.10659300E+04, 0.25116300E+04, 0.91089100E+03, -.32559700E+03, 0.10453000E+04, -.12031300E+04, 0.11986400E+04, 0.19293600E+04, -.24680900E+04, 0.97312300E+03, -.63352900E+02, 0.12408100E+04, 0.99162200E+03, -.33602600E+03, 0.62227800E+03, 0.60204100E+03, 0.11697200E+04, -.51129900E+03, 0.16708500E+04, -.17922000E+04, 0.81385600E+03, 0.65534400E+03, 0.91173600E+03, 0.26519000E+02, -.10738100E+04, 0.17779500E+03, -.12571500E+04, 0.32739100E+03, -.96165500E+03, 0.13168300E+04, 0.39150200E+03, -.27874300E+03, 0.18224000E+04, -.22029200E+03, 0.62826400E+03, -.13114400E+03, -.47819800E+03, -.10052800E+04, -.49220500E+03, 0.43549300E+03, 0.11444700E+04, -.43944300E+03, 0.14620500E+03, 0.29144800E+03, 0.22205600E+03, -.14269200E+03, -.34226500E+03, 0.13557200E+03, -.25869200E+03, 0.21860000E+03, -.27504400E+03, 0.15211500E+03, -.12628700E+04, 0.76496200E+03, 0.29600000E+03, 0.63712700E+03, 0.51669400E+02, 0.29370100E+03, 0.13361300E+04, 0.25471300E+04, 0.98157200E+03, 0.18086600E+03, -.96903300E+03, -.10236700E+04, 0.49046700E+03, 0.10179400E+04, 0.50741000E+03, -.17496300E+04, -.65150800E+01, 0.50325600E+03, 0.25969200E+03, 0.70853000E+03, -.12037500E+03, 0.16389800E+04, 0.24746900E+03, 0.11414400E+03, -.25614000E+03, -.12852900E+03, -.72809900E+03, 0.38710000E+03, -.33579300E+03, -.82499200E+03, -.53616800E+03, 0.64267400E+03, 0.76873500E+04, -.10836200E+05, 0.54569900E+04, 0.31461800E+03, 0.54320500E+04, 0.15090300E+04, -.11704700E+04, 0.17240600E+04, -.19199600E+04, 0.36182200E+04, -.11080000E+04, 0.12403900E+04, 0.30607800E+04, -.13089400E+04, -.84668100E+03, -.15335600E+04, -.45425800E+03, 0.32291900E+03, -.27505600E+03, 0.55640800E+03, -.84182700E+03, 0.26556600E+03, -.17927300E+04, 0.12125900E+04, -.50781100E+03, -.22503100E+03, -.60858200E+03, -.21566800E+03, 0.46447700E+03, -.60893500E+03, -.16407000E+03, -.38022800E+03, 0.38663300E+03, 0.92357600E+02, -.18425800E+02, -.90863100E+02, 0.20636100E+03, -.69269000E+01, 0.31036800E+03, 0.22009000E+02, -.92370000E+01, -.26083300E+03, 0.60192900E+03, 0.49616600E+03, 0.26203200E+03, -.88040800E+02, -.10359500E+02, -.19555100E+03, 0.27472500E+03, -.53229200E+03, 0.17342900E+03, -.28057200E+03, 0.43514800E+02, 0.51498100E+01, -.67723800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.44958100E+00, -.68742400E+00, -.22153700E+01, -.19295000E-01, -.63360000E+00, -.92754900E+00, -.10398500E+01, 0.27911700E+00, 0.16411700E+00, 0.11206200E+01, -.21994000E-01, -.25587700E-01, 0.10152400E+01, 0.15071500E+01, 0.76421400E+00, -.54880600E+00, -.12592300E+01, 0.56018600E+00, -.65940700E+00, 0.13443000E+01, -.22849000E-01, -.12031900E+00, -.28650900E+01, -.18793700E+00, -.45675100E+00, -.22250300E-02, -.31111000E+00, 0.23870400E+00, -.14031400E+01, 0.44098500E+00, -.77185100E+00, 0.15759700E+01, -.81437300E+00, -.10197200E+01, 0.21936900E+01, 0.78782700E-01, 0.49406400E-01, -.53625200E+00, 0.57951700E-01, 0.17514800E+01, -.16639600E+01, -.64831800E+00, 0.42085200E+00, 0.13166900E+00, 0.48152600E+01, -.13247100E+01, -.23439100E+01, 0.33939300E-01, 0.14071300E+01, 0.85485300E+00, 0.78634700E+00, 0.65417100E+00, -.10779500E+00, -.11287400E+01, -.20661300E+00, -.14817000E+00, -.32717600E+00, -.18836400E+01, -.60270700E-01, 0.33808800E+00, -.28335700E+00, -.84619800E+00, -.13773000E+01, -.71873000E-01, 0.68185000E+00, -.41062300E+00, 0.16449200E+04, -.75940000E+03, -.15703900E+04, -.81834000E+03, -.72488700E+01, -.59388700E+03, -.17093800E+03, 0.35706400E+03, -.61522100E+03, -.37548800E+03, -.23384900E+04, 0.38917200E+04, -.18353500E+04, -.56419100E+04, -.19448500E+04, -.11187400E+04, -.15219400E+04, -.27794400E+04, -.41465200E+04, 0.33936300E+03, -.13884400E+04, 0.10680600E+03, 0.15036900E+04, -.74991400E+03, 0.94827800E+03, -.75193400E+03, 0.43155200E+03, 0.58794900E+03, -.20677700E+04, -.25917800E+04, -.34716400E+03, 0.66122500E+03, -.55750400E+04, 0.19091500E+04, -.10281500E+04, 0.42513700E+04, -.95333200E+03, -.14996200E+04, 0.10424100E+04, -.15600400E+04, -.32488400E+04, -.23507500E+04, 0.11492200E+04, -.18532700E+04, 0.35152300E+04, -.16210000E+04, 0.50461900E+03, -.17593800E+04, -.30872900E+04, -.15055700E+04, 0.33724300E+04, 0.94429700E+04, 0.21079600E+04, -.19707200E+04, -.23203700E+04, 0.19077600E+04, -.92550200E+03, -.55608300E+03, -.95803500E+03, -.74887200E+03, -.95668900E+03, 0.21531900E+04, 0.33395900E+04, 0.25436700E+04, -.13313600E+04, -.18224100E+03, -.13851800E+04, 0.66244300E+03, -.83855400E+03, 0.70003500E+03, -.23678300E+03, 0.96379600E+03, 0.69128100E+03, 0.83096200E+03, 0.27441700E+03, 0.53691300E+03, 0.56666400E+04, 0.50081600E+03, -.19541500E+03, -.27344700E+03, -.25031500E+03, 0.99777700E+01, 0.39995000E+02, 0.54937400E+02, 0.22806500E+03, -.63330000E+03, 0.88017700E+02, -.34574800E+03, -.86218600E+03, 0.34618000E+03, 0.36382300E+03, 0.42964600E+03, -.25229600E+03, -.44401200E+02, -.17771800E+04, -.39083300E+04, -.94589300E+03, 0.55737800E+03, -.44740300E+04, -.23621800E+03, 0.14016600E+03, -.47914900E+04, 0.11933900E+03, 0.16074600E+04, -.56108400E+03, 0.55060500E+02, -.13879500E+04, 0.63844300E+02, -.33623200E+03, 0.61078800E+03, 0.95735800E+03, -.59246200E+03, -.47688900E+03, -.47741100E+03, 0.17528000E+04, 0.70186400E+03, 0.86694500E+03, 0.20325700E+04, -.94291700E+03, 0.10251700E+03, 0.15563600E+03, -.97316600E+04, 0.47531100E+04, 0.98204900E+04, 0.48619400E+04, 0.26674800E+04, 0.22580200E+04, 0.51710100E+04, 0.58792900E+04, 0.10045300E+04, 0.19920700E+04, 0.26018200E+04, 0.25211300E+04, -.13615000E+04, -.84894500E+03, -.12597500E+04, 0.11604100E+04, 0.81629400E+03, -.15122600E+04, -.98073300E+03, -.34569800E+04, 0.74301900E+03, 0.19063200E+04, -.10740900E+04, 0.50053700E+03, 0.10508300E+03, 0.53765600E+03, 0.23367100E+03, -.83049800E+03, 0.99695300E+03, 0.48056100E+03, 0.39862800E+03, -.63331500E+03, 0.38945700E+02, -.28350000E+02, -.33199200E+03, 0.33395200E+03, -.69641700E+00, 0.24479100E+03, 0.10287800E+02, -.39181500E+02, -.32246800E+03, -.11086600E+04, -.52408500E+03, -.39529500E+02, -.67885900E+02, 0.53827000E+03, -.22726200E+02, 0.34364500E+03, 0.57060200E+03, -.69496200E+02, -.31142800E+03, 0.18360200E+03, 0.18155100E+03, 0.14360500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13751500E-01, 0.13068800E-01, 0.20986500E+00, 0.30288000E-01, -.10650700E+00, -.23818300E-01, -.14365900E+00, -.21574300E-01, 0.21599700E+00, 0.60827500E-01, -.51488000E-01, -.60109800E-02, 0.97251000E-01, 0.23079700E-01, 0.80561700E-01, 0.74531200E-01, -.65665500E-01, -.62528200E-01, 0.35913100E-01, -.45079000E-01, -.48249300E-02, -.85561500E-02, 0.10939400E+00, 0.14474900E-01, 0.30653600E-01, -.14492500E-04, 0.27929700E-01, 0.17522200E-01, 0.10108300E+00, 0.53917900E-02, -.72577400E-01, -.73606300E-02, -.25427000E-01, -.40271000E-01, -.91213200E-01, -.20289500E-01, 0.97647700E-02, -.67174000E-02, -.34637200E-01, -.77869200E-01, 0.35154300E-01, -.38578800E-01, -.43413400E-02, -.17994100E-01, 0.78932000E-01, -.22781100E-01, 0.68586400E-02, 0.59910500E-03, 0.94465600E-01, 0.58962000E-02, 0.17293000E-02, -.32323000E-01, -.75081100E-01, -.41962100E-01, -.31196900E-01, 0.47347500E-02, 0.24976300E-01, -.49644900E-02, -.57635100E-02, 0.45937400E-02, -.27004800E-01, -.45207500E-01, 0.14898700E+00, 0.24691500E-01, 0.18099800E-02, -.20919300E-01, 0.33477100E-02, 0.12698400E+02, 0.38252200E+01, 0.19419100E+00, 0.24133600E+02, 0.56840500E+02, -.39870700E+02, -.31069100E+01, -.17791200E+02, 0.57555700E+02, -.76574200E+01, 0.24907000E+02, -.33778300E+01, -.49907000E+02, -.12428900E+02, 0.18493200E+02, -.63235100E+02, 0.37313200E+02, 0.39912100E+02, 0.67720900E+02, -.47929100E+02, -.47270400E+02, -.69890000E+02, 0.25907200E+02, 0.23245400E+02, 0.34946500E+02, 0.24308000E+02, -.75933200E+02, 0.94774700E+02, 0.26168600E+02, 0.44510700E+02, -.54955800E+02, -.13964400E+03, 0.11871900E+03, -.77524100E+02, 0.62091800E+02, -.59280900E+02, -.63936800E+02, 0.52758200E+02, -.62416100E+02, -.67649200E+02, -.53871100E+02, 0.39892900E+02, 0.80033400E+02, 0.20502600E+03, -.70164100E+02, -.28304700E+02, -.10263500E+03, -.51644800E+02, -.11408600E+03, 0.86364400E+02, 0.25889100E+03, 0.97929600E+02, -.10618900E+03, -.17859900E+03, -.16697000E+03, 0.94113900E+02, 0.89225000E+02, 0.83230600E+02, 0.29219700E+02, 0.74645600E+02, -.16372100E+02, -.27955200E+02, 0.44183400E+01, 0.65173500E+02, 0.56819900E+02, 0.10926400E+03, -.43603600E+02, -.64067100E+02, -.54286000E+02, -.22379900E+02, 0.49292600E+02, -.97617600E+02, -.64597100E+02, -.75264500E+02, 0.24813200E+02, 0.12751000E+03, -.22968100E+02, 0.20767300E+02, 0.19531100E+01, 0.11508800E+02, 0.17793000E+02, 0.34982500E+02, -.25994000E+02, -.15482400E+02, -.46085100E+01, 0.30530100E+02, 0.26666200E+02, 0.45774000E+02, -.39061600E+02, -.31500200E+02, -.22977300E+02, 0.21391400E+00, -.34575200E+02, 0.28517400E+02, -.22405400E+02, 0.61169900E+01, -.23172500E+02, -.11342700E+03, -.14958900E+03, 0.75968000E+02, 0.10432800E+02, 0.74860000E+02, 0.55792900E+02, 0.10430300E+02, -.71638700E+01, -.78414800E+02, 0.11905000E+02, 0.13584500E+02, 0.65449700E+02, -.33435700E+02, -.12339400E+02, 0.13996200E+02, 0.16797500E+02, -.33148900E+01, -.18626400E+01, 0.60021400E+01, -.13162800E+01, 0.25009400E+02, -.19442700E+02, 0.13037900E+03, -.19311500E+03, 0.91106600E+02, 0.15888600E+03, 0.96387000E+02, -.13815900E+02, 0.87089200E+02, -.14966100E+02, -.58722000E+02, -.57240500E+02, 0.67520200E+02, 0.12697000E+03, -.15894100E+01, -.26324200E+02, -.12024300E+01, 0.85983200E+00, -.85221000E+01, 0.19504100E+02, -.46577000E+02, -.34953600E+02, 0.11017300E+02, 0.93545200E+01, 0.17311100E+03, -.23805000E+02, -.11717600E+01, -.49389200E+01, 0.11944800E+02, -.57778300E+01, -.22454400E+02, 0.36731800E+02, 0.84327800E+01, 0.33225700E+02, -.17602900E+02, -.13748500E+02, -.32725200E+01, 0.19214900E+01, -.19845300E+02, -.66595200E+00, -.28962500E+02, -.14482500E+01, 0.18439900E+01, 0.25664500E+02, -.32726700E+00, 0.42417400E+02, 0.93565900E+01, 0.98154800E+01, -.29126600E+01, 0.54121700E+02, -.28679800E+02, 0.98841800E+01, -.50622000E+01, -.62582200E+00, 0.15112400E+01, -.21652900E+01, 0.11902400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42529100E+00, 0.99635600E+00, -.14820600E+00, 0.44583600E+00, -.31574800E+00, 0.47474200E+00, 0.44682300E+00, 0.14743200E+00, -.10233200E+01, 0.61461600E+00, 0.42883800E+00, -.32956600E+00, -.61426100E+00, 0.37562400E+00, 0.32386100E+00, -.12331300E+01, 0.27853800E+01, 0.68101300E+00, -.49646800E+00, -.15503400E+01, -.31547600E-01, -.49899000E-01, 0.43625400E+00, -.12359800E+00, -.60616900E+00, 0.56942000E-02, -.10059300E+00, -.63563900E-01, -.59588800E-01, 0.22347800E+00, -.47138100E-01, 0.86518100E+00, 0.31555800E-01, 0.16528000E+01, 0.21219400E+00, -.13786500E+01, -.90727600E-01, 0.80681000E+00, 0.13782700E+00, 0.46294700E+00, -.47339300E+00, -.14240800E+00, 0.62831300E-01, -.15768300E-02, 0.83571800E+00, -.31887900E+00, 0.76690100E+00, -.25717000E-01, -.24472000E+00, 0.63650200E+00, 0.78464100E-01, 0.37821900E+00, -.40233900E+00, 0.55496900E-03, 0.29385400E+00, 0.15762300E+00, -.26569300E+00, 0.51984700E+00, 0.34394400E-01, -.90671100E-02, -.35710700E+00, -.71128700E+00, 0.47749300E+00, -.12744100E+00, -.98494900E+00, 0.24455000E+00, -.17319500E+00, 0.57270900E+01, 0.93106800E+03, -.15596400E+01, 0.19173200E+03, 0.15250800E+03, -.94665500E+02, 0.18001400E+03, -.12478300E+03, 0.18877500E+03, 0.30598500E+02, -.52678800E+04, 0.26578800E+04, 0.95215900E+03, 0.26349300E+04, 0.21970800E+03, -.63436900E+03, 0.12489200E+04, -.75251800E+03, 0.28323600E+04, -.52477000E+03, 0.11924600E+04, 0.76307900E+03, -.39502900E+03, 0.12300300E+04, -.38103600E+03, 0.91415000E+03, 0.10680500E+04, -.12516400E+04, -.19147500E+04, -.80467900E+03, 0.97399100E+03, -.47268000E+03, 0.71218300E+03, -.38564000E+03, 0.34316800E+02, -.35534100E+03, -.10798400E+04, -.43142200E+03, -.27664600E+03, 0.31882900E+03, -.47452900E+03, -.44170200E+03, 0.80481500E+03, 0.15820000E+04, -.74541700E+03, -.58407600E+03, -.79199600E+03, -.13588200E+04, -.11335500E+04, 0.10000700E+04, 0.11054500E+04, 0.74093700E+03, -.94351300E+03, -.10621500E+04, 0.67418700E+02, -.24146600E+02, 0.51142600E+02, -.36232000E+02, -.42044900E+03, -.53890200E+03, 0.10484700E+04, 0.16232700E+04, 0.13540400E+04, -.55964800E+03, -.70236200E+03, -.40968400E+03, 0.20877900E+03, -.23140100E+04, 0.20904000E+03, -.44822400E+03, -.37848200E+03, 0.42400000E+03, 0.87261800E+03, 0.24840300E+03, -.47946200E+03, 0.22842600E+03, 0.25117000E+03, -.11284100E+03, 0.34066900E+03, -.12667600E+03, 0.58012100E+02, 0.13089200E+03, -.42331800E+02, 0.31427100E+03, -.16107200E+03, 0.11027900E+03, 0.38939500E+02, 0.49766600E+03, -.27378000E+03, -.90372200E+03, -.24978800E+03, 0.35157500E+03, 0.79743000E+03, -.15285200E+04, -.25365100E+04, -.13499100E+04, 0.66758900E+03, 0.46912500E+03, -.24520900E+03, 0.12708300E+03, 0.37768200E+03, 0.12336000E+03, 0.10856300E+04, 0.58961400E+03, -.54619400E+03, -.78051700E+03, -.62787900E+03, 0.54912700E+03, -.14042100E+03, 0.38820700E+04, -.19870300E+04, -.15314000E+04, -.19402700E+04, 0.51717500E+03, 0.96261800E+03, -.12963900E+04, 0.54882000E+03, -.18804500E+04, 0.81262700E+03, -.68952700E+03, 0.40435600E+04, -.20542500E+04, 0.10228900E+04, -.20244800E+04, -.13657300E+02, 0.10021900E+04, -.60385400E+03, 0.18436000E+04, -.25854800E+04, 0.80929400E+03, -.59168200E+03, 0.14502900E+03, -.11277400E+03, -.57183400E+03, -.72114500E+02, 0.34663000E+03, 0.90790900E+03, -.92245300E+03, -.36775200E+03, -.16954500E+04, 0.87446600E+03, 0.93053400E+03, -.43469000E+02, 0.91955100E+01, 0.26026000E+03, 0.22059000E+02, 0.61347000E+01, -.10744100E+03, 0.11870100E+03, 0.37020600E+02, -.16110600E+03, -.69127700E+02, 0.32443300E+02, 0.72351600E+01, 0.43195100E+02, 0.89844100E+02, 0.22599100E+01, 0.26357700E+02, -.36805900E+02, -.51694900E+02, -.49490000E+02, -.30061400E+03, -.41054800E+03, -.22657800E+02, 0.11913600E+03, 0.24177400E+03, -.41411400E+02, 0.44338900E+02, 0.46145500E+03, -.30581000E+02, 0.30562100E+02, -.46954000E+02, 0.14349700E+03, 0.23905400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46803800E+00, 0.12063000E+01, 0.38332000E+01, 0.32649700E+01, 0.51120700E+01, -.33505700E+01, 0.52445200E+01, -.83280000E+00, 0.78618600E+00, 0.58786200E+00, 0.82295900E-01, -.44356400E+00, 0.34204100E+00, 0.10736100E+01, 0.83227700E+00, -.87798200E+00, 0.84654700E+00, 0.73708900E+00, -.52586000E+00, -.27503900E+00, 0.47028100E-01, -.19623000E-01, -.18751100E+01, -.24490800E+00, 0.90689800E-01, -.10508400E-01, -.13965000E+00, 0.53921700E+00, -.21600600E+01, 0.46639900E+00, 0.42401900E-02, 0.14926100E+01, -.43242400E+00, 0.22976000E+01, 0.27908900E+01, 0.37167200E+00, 0.70832500E+00, -.21357900E+00, 0.16166000E+00, 0.84014900E+00, -.51532800E+00, -.72969800E-01, 0.13933900E+00, -.56114400E-01, 0.23385700E+00, -.23004000E+00, 0.14713400E+01, -.52123500E-01, 0.20382600E-01, 0.11133400E+01, 0.11689400E+00, 0.51244300E+00, -.23722100E+00, -.41919800E-01, -.15486000E+00, 0.20432300E+00, 0.16462700E+00, 0.25915200E+00, 0.38921700E-01, 0.76407000E-01, -.33617800E+00, -.79032300E+00, 0.39559300E+00, -.10273100E-01, -.46096800E+00, 0.14674400E+00, -.19221900E+00, 0.70253500E+01, -.22555300E+00, 0.52214600E+02, 0.20227300E+03, -.21119400E+02, -.69680900E+02, 0.70125000E+02, -.11820600E+03, 0.64467500E+02, -.12519100E+03, -.44197400E+04, 0.22601400E+04, 0.45488800E+03, 0.22152100E+04, 0.52542600E+02, -.72766200E+03, 0.72205500E+03, -.12082500E+04, 0.26662400E+04, -.65757100E+03, 0.14828400E+04, 0.17517600E+04, -.87111000E+03, 0.85348500E+03, -.87904600E+03, 0.91955200E+03, 0.12108500E+04, -.19693600E+04, -.23488900E+04, -.12080600E+04, 0.11265500E+04, -.79255000E+03, 0.38075600E+03, -.21478800E+03, -.67970800E+02, -.19032100E+03, -.10343200E+04, -.33064800E+03, -.50066400E+03, -.57068100E+03, -.83616800E+03, -.19902000E+03, 0.73764800E+02, 0.46274000E+02, 0.19133000E+02, -.22735200E+03, -.21582700E+02, -.14353100E+04, -.83152500E+03, 0.11118400E+04, 0.11454700E+04, 0.90122000E+03, -.75888400E+03, 0.61640500E+02, 0.13412200E+04, -.66785000E+03, -.56923000E+03, -.67204900E+03, -.90220600E+03, -.11943500E+04, 0.15217000E+04, 0.24386300E+04, 0.17892200E+04, -.12329700E+04, -.91298800E+03, -.95795000E+03, 0.45344400E+03, -.97198300E+03, 0.49969600E+03, -.39153000E+03, -.17759000E+03, 0.82279300E+03, 0.11677100E+04, 0.48925700E+03, -.31879200E+03, 0.22757100E+03, 0.33649000E+03, -.15184800E+03, 0.42900200E+02, -.16867800E+03, 0.23590700E+02, 0.44179700E+02, 0.48823400E+02, 0.37999700E+03, -.17284300E+03, 0.50240200E+02, -.12165600E+03, 0.12312800E+02, -.31675700E+02, -.46199800E+03, -.61557400E+01, 0.55149000E+03, 0.84411500E+03, -.19436200E+04, -.33118500E+04, -.15908400E+04, 0.83508200E+03, 0.32704500E+03, 0.77542600E+03, -.38108900E+03, -.46419200E+03, -.38584500E+03, 0.12202100E+04, 0.53874300E+03, -.58129800E+03, -.47360900E+03, -.64086300E+03, 0.46745400E+03, -.50681500E+03, 0.35811900E+04, -.18284300E+04, -.14595800E+04, -.17904600E+04, 0.91111300E+03, 0.95417200E+03, -.11174900E+04, 0.77720200E+03, -.20449400E+04, 0.80131100E+03, -.15479600E+04, 0.30815100E+04, -.16043900E+04, 0.16187400E+04, -.15523700E+04, 0.27450400E+03, 0.11026200E+04, 0.31516600E+03, 0.27807900E+04, -.22536700E+04, 0.93704400E+03, -.10358900E+04, 0.55958900E+03, -.31149900E+03, -.68233800E+03, -.28188400E+03, 0.61055200E+03, 0.89205900E+03, -.10687600E+04, -.59106500E+03, -.24403500E+04, 0.89089700E+03, 0.22644000E+03, -.21974000E+03, 0.10109000E+03, 0.28755000E+03, 0.10936100E+03, 0.10065500E+03, -.13346300E+03, 0.19003800E+03, 0.16249200E+03, -.16067100E+03, -.10507200E+03, 0.11902100E+03, 0.10475200E+02, -.47194600E+02, 0.17979800E+03, 0.50886500E+01, 0.69942100E+02, -.15795000E+02, -.62577100E+02, -.10159300E+03, -.52864600E+03, -.66240800E+03, -.65407300E+02, 0.44149300E+02, 0.36659300E+03, -.18032400E+03, 0.15864600E+03, 0.57490300E+03, 0.44019800E+01, -.45425200E+02, -.66367700E+02, 0.20431000E+03, 0.37211300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.56949400E+00, -.46077500E+00, 0.90478100E+00, -.35743300E+00, -.34958600E+00, -.46029100E+00, -.15064300E+01, -.58475800E-01, 0.15179700E+01, -.21111500E-01, -.20621700E+00, 0.45869200E-01, 0.27010300E+01, 0.86214000E+00, 0.48624700E+00, 0.24471900E+00, 0.48610600E+00, 0.34806400E+00, -.14870700E+01, 0.12190400E+01, -.17192200E-01, 0.91686600E-01, -.18056000E+01, -.89317000E-01, -.51294400E-01, -.26267100E-02, -.31765500E+00, 0.20659400E+00, 0.64428100E-01, 0.88760000E+00, 0.23623000E+00, -.18567700E+00, 0.29529600E+00, -.35268100E+00, 0.42462800E+00, 0.54291100E+00, -.24114600E+00, -.16576500E+00, 0.26053100E+00, -.83058100E-01, 0.21316700E+00, -.35127300E+00, -.20466700E+00, -.17213100E+00, 0.37650100E+01, -.28725800E+00, -.14706200E+00, -.16665200E+00, 0.18804400E+00, -.15655900E+01, -.38892900E-01, -.12840400E+01, -.98018600E+00, -.46996200E-01, -.99091800E+00, -.20968200E+00, 0.59555000E-01, 0.22145500E+01, -.36067800E-02, -.59511900E+00, 0.41549900E+00, 0.10921800E+01, 0.26047300E+01, -.13912600E+00, -.20510700E+01, 0.46165100E+00, -.73922400E-03, -.12411900E+02, 0.10821800E+01, -.16622700E-01, -.33957300E+03, 0.20030700E+03, -.29749500E+03, -.26875900E+03, -.52150000E+02, 0.99693500E+02, 0.82043600E+03, 0.17523400E+04, -.99338200E+03, 0.16309500E+04, -.88211200E+03, 0.60887500E+02, 0.25523300E+03, 0.14115600E+04, 0.31014000E+04, -.10334700E+04, 0.33622800E+03, -.17420900E+04, -.30025900E+04, 0.14727300E+04, 0.48940900E+02, 0.14998500E+04, -.95158600E+03, -.19061900E+04, 0.32915800E+04, 0.25543400E+04, 0.16237800E+04, -.17242100E+04, 0.97474200E+03, 0.10706200E+04, -.51690800E+03, 0.21995600E+03, -.53910100E+03, 0.16579500E+04, 0.94314100E+03, -.14066000E+03, 0.63905800E+03, 0.15615200E+03, 0.39296000E+03, 0.10444400E+04, 0.26997700E+04, -.13961300E+04, -.32082400E+03, -.13451700E+04, 0.19046000E+04, 0.27087100E+03, -.13083800E+04, -.37365900E+03, -.20472200E+03, 0.12075900E+03, -.14350200E+04, -.27766600E+04, 0.13946700E+04, 0.10278000E+04, 0.14013500E+04, 0.13941000E+04, 0.22504900E+04, -.23990900E+04, -.33285500E+04, -.24747000E+04, 0.23003600E+04, 0.74324900E+03, 0.24675300E+04, -.11698300E+04, -.18616500E+03, -.12599200E+04, 0.47590400E+03, 0.41388500E+03, -.17812000E+04, -.11904000E+04, -.11338000E+04, 0.51729800E+03, -.70501300E+03, -.86555000E+03, 0.38793500E+03, -.12209900E+03, 0.43750500E+03, 0.93050000E+02, 0.15047500E+03, -.34004400E+03, -.80268500E+03, 0.13272900E+03, 0.12866200E+03, 0.59585500E+03, 0.10063900E+03, -.20805600E+02, 0.72129100E+03, -.45571400E+02, -.53145300E+03, -.14639900E+04, 0.26789500E+04, 0.34125900E+04, 0.19655800E+04, -.14307200E+04, 0.49492500E+03, -.31760400E+04, 0.15830300E+04, 0.17479200E+04, 0.15837700E+04, -.17420000E+04, -.50905800E+03, 0.58626100E+03, -.42672300E+03, 0.85524700E+03, -.33022200E+03, 0.16304400E+04, -.29100500E+04, 0.14835100E+04, 0.13017100E+04, 0.14511600E+04, -.11014500E+04, -.64902700E+03, 0.42675100E+03, -.12425600E+04, 0.16824000E+04, -.79826300E+03, 0.38483100E+04, -.20772100E+04, 0.11785800E+04, -.36932900E+04, 0.10545600E+04, -.56059000E+03, -.57155900E+03, -.29009600E+04, -.57475900E+04, 0.69268900E+03, -.50651700E+03, 0.18042000E+04, -.74387500E+03, 0.39351400E+03, 0.99838200E+03, 0.37032600E+03, -.54341900E+03, -.54455600E+03, 0.63612300E+03, 0.81049200E+03, 0.25332300E+04, -.67475900E+03, 0.14065800E+04, 0.30094000E+03, -.14138700E+03, -.51508600E+03, -.15202700E+03, -.39541400E+03, 0.27206400E+02, 0.17952500E+02, -.27833900E+03, 0.42086800E+03, 0.22334400E+02, -.19332400E+03, -.39931400E+02, 0.15534800E+03, -.42539400E+03, -.14280700E+02, -.25463300E+03, -.54741900E+02, 0.11915700E+03, 0.29090500E+03, 0.12798700E+04, 0.96904100E+03, 0.18890900E+03, 0.66214700E+01, -.55983100E+03, 0.53455200E+03, -.47017000E+03, -.51855900E+03, -.43924100E+02, 0.12514800E+03, 0.94073800E+02, -.26895900E+03, -.60136000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22527800E+00, 0.69400400E+00, -.85060200E+00, 0.72020200E+00, 0.21115500E+01, 0.12470700E+00, -.17504000E+00, 0.68596300E-01, -.24628100E+01, -.21012100E+01, 0.37394200E+00, 0.13571200E+00, -.22157900E+01, -.34917200E+00, -.27599700E+00, -.91799300E+00, 0.27732000E+00, 0.52427400E+00, 0.20183300E+00, -.71597300E+00, -.50274400E-01, -.13768300E+00, 0.38174500E+00, -.21044700E-01, 0.38406200E+00, 0.44032000E-03, 0.19693900E+00, 0.40727300E+00, -.11606200E+01, 0.27933100E+00, 0.66382200E-01, 0.23046300E+00, 0.32174400E-01, 0.50892300E+00, -.10617100E+01, -.16980000E+00, 0.91301100E-02, 0.15886200E+00, 0.60803800E-01, 0.21608100E+00, 0.29714700E+00, 0.56522700E-01, 0.19227200E-01, 0.28885800E-02, -.15832200E+01, 0.21397100E+00, 0.46511000E+00, 0.54245700E-02, 0.46831600E+00, 0.73693700E+00, 0.79383300E-01, 0.28990600E+00, 0.69860900E+00, -.12359000E+00, 0.50982800E+00, -.20345900E+00, 0.49666900E+00, -.10277300E+01, 0.10264100E+00, -.86441300E-01, -.29767900E+00, 0.15127100E+00, -.30487200E+00, 0.49630000E-02, 0.36366300E+00, 0.83315200E-01, 0.13811900E+00, 0.55979700E+01, -.11694800E+00, -.45970500E-02, 0.42946900E+00, -.44433900E+03, 0.38080500E+03, 0.53730200E+02, 0.10629900E+03, -.33984300E+03, -.10876300E+03, -.17378700E+04, 0.91054100E+03, -.21634600E+03, 0.87199000E+03, 0.30749400E+03, 0.41705800E+03, -.78752500E+03, -.13585400E+04, 0.21215600E+03, 0.29182700E+03, 0.12465300E+04, 0.28889800E+04, -.14127800E+04, -.43731200E+03, -.14436500E+04, 0.14912000E+03, 0.69703100E+03, -.22504400E+04, -.10310800E+04, -.13412100E+04, 0.70134900E+03, 0.33804800E+03, -.10364700E+04, 0.53373400E+03, -.55355000E+03, 0.52043800E+03, -.95907600E+03, -.60758700E+03, 0.12592700E+03, -.53043800E+03, 0.12094500E+03, -.13411700E+03, -.34377400E+03, -.22938700E+04, 0.11330900E+04, 0.15721400E+03, 0.11440900E+04, -.31881100E+03, 0.41226900E+03, -.90907600E+02, -.16771900E+04, -.57618500E+03, 0.44569500E+03, 0.13038200E+04, 0.19492300E+04, -.98699500E+03, -.68384900E+03, -.98210100E+03, -.66128000E+03, -.98732800E+03, 0.98034900E+03, 0.14253800E+04, 0.72315400E+03, -.10532700E+04, -.63307200E+03, -.24158500E+04, 0.11623800E+04, 0.66373700E+03, 0.12220000E+04, 0.17181600E+03, 0.40611300E+03, 0.12949700E+04, 0.59870500E+03, 0.10573400E+04, 0.21765700E+03, -.65489600E+03, 0.76911500E+03, -.37760000E+03, -.22073800E+02, -.38701600E+03, -.81871000E+02, -.16759100E+03, 0.21877500E+03, 0.42694800E+03, -.99505400E+02, -.15299200E+03, -.51642700E+03, 0.21381500E+03, -.10415000E+03, -.17960200E+03, -.10964900E+03, 0.23572000E+03, 0.63319400E+03, -.15748800E+04, -.13644900E+04, -.10256800E+04, 0.62681300E+03, 0.75105100E+03, 0.20167500E+04, -.10070100E+04, -.40948800E+03, -.10060200E+04, 0.83444500E+03, 0.23421200E+03, -.61399400E+02, 0.97056500E+03, -.32080700E+03, 0.10738400E+03, -.12268600E+04, 0.58200000E+03, -.26658800E+03, -.27302700E+03, -.28875700E+03, 0.36901600E+03, 0.38598700E+02, -.88556900E+02, 0.33558300E+03, -.53354500E+03, 0.34131900E+03, -.23389100E+04, 0.33566800E+04, -.17258200E+04, 0.48628100E+03, -.16868900E+04, -.29819500E+03, -.38612000E+03, 0.13081500E+04, 0.26755300E+04, -.26581500E+03, -.35238000E+03, -.20100200E+04, -.36182800E+03, 0.20465500E+03, -.23806200E+03, 0.18198600E+03, 0.50633800E+02, -.22595900E+03, 0.32505500E+03, -.28507200E+03, -.50519000E+03, -.21032500E+02, -.15708800E+04, -.22686200E+03, 0.12132300E+03, 0.44504800E+03, 0.11437300E+03, 0.33591700E+03, 0.65033300E+02, -.10785600E+03, 0.23651100E+03, -.28403100E+03, 0.53969700E+02, 0.16460100E+03, 0.29508100E+02, -.67863100E+02, 0.22275000E+03, 0.10696600E+02, 0.14639500E+03, 0.57579400E+02, -.54350400E+02, -.14348800E+03, -.78794300E+03, -.82800100E+03, -.10658400E+03, -.19052800E+02, 0.20550300E+03, -.51557900E+03, 0.27999100E+03, 0.20228700E+03, 0.44384700E+02, -.10559000E+03, -.12466100E+03, 0.11887900E+03, 0.32655400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.58758900E+00, -.17236100E+00, 0.98497400E+01, -.46936600E-01, -.15721300E+01, -.18707200E+01, 0.33563900E+01, -.36582600E+00, 0.24023300E+01, 0.68032200E+00, -.72800900E+00, -.68208000E+00, 0.18255900E+01, 0.26719000E-01, -.89732600E+00, 0.30691800E+01, -.22200600E+01, -.69051900E+00, 0.16492500E+01, -.12344000E+01, -.10803100E+00, 0.23982500E+00, -.91428000E+00, 0.22024200E+00, 0.18576100E+00, 0.31331000E-02, -.13105700E+00, 0.26694900E+01, 0.53240800E+00, 0.37735300E+00, 0.74423000E-01, 0.80111700E+00, 0.53992900E+00, 0.19553300E+00, -.15166800E+01, -.22834400E+00, -.10745400E+00, 0.12555800E+00, 0.53583800E-01, 0.47432200E+00, 0.43829800E+00, -.20636600E+01, 0.32836500E+00, -.11063400E+00, -.80107200E+00, -.26538700E+00, -.16724000E+01, 0.12004200E+00, 0.15093300E+01, -.53156500E+00, 0.68086100E-01, 0.31465700E+00, -.10471800E+00, -.26123800E+00, 0.55982800E+00, -.23036900E+00, 0.10194900E+01, -.16655300E+01, 0.11044400E+00, -.78970900E-01, -.11105900E+01, -.47471500E+00, -.14498100E+01, -.60488800E-02, -.39292000E+00, -.34245700E+00, -.28937600E+00, 0.15024500E+02, 0.36039700E+00, -.75522700E-01, 0.55132200E+00, 0.10070000E+01, 0.42896800E+03, 0.56907900E+03, 0.32368200E+03, -.58418500E+02, -.82480200E+03, 0.32092400E+04, -.15868800E+04, -.27746000E+04, -.16084500E+04, -.33459200E+03, 0.22492400E+02, -.13337500E+04, -.11209500E+04, -.56677500E+03, -.30204800E+02, -.24461400E+04, -.39122900E+04, 0.19596500E+04, 0.26545500E+04, 0.19553700E+04, 0.75045400E+03, 0.85115700E+03, 0.11309400E+04, 0.88345300E+03, 0.15265600E+04, 0.60404300E+03, -.23220400E+04, 0.11996600E+04, -.59169700E+03, -.14442300E+04, -.60251600E+03, -.11552900E+04, -.41693200E+03, 0.19055300E+03, 0.13736100E+04, -.31064800E+03, -.40217000E+03, 0.29243900E+03, 0.26601800E+03, -.15280800E+03, -.74608700E+03, -.12957700E+03, -.17614000E+04, -.27526500E+04, 0.27689800E+04, 0.31141600E+04, 0.27968800E+04, -.24412600E+04, -.14142600E+04, -.24505600E+04, 0.12101300E+04, 0.10110800E+04, 0.12344700E+04, -.12509400E+03, -.10821000E+04, 0.11757300E+04, 0.24811800E+02, 0.21436900E+04, -.10000400E+04, 0.38041800E+03, 0.22640300E+04, -.11308600E+04, -.19022000E+04, -.11500100E+04, -.66174100E+03, -.10293000E+04, -.88318400E+03, -.11783500E+04, -.12694600E+04, -.81172200E+03, 0.33332700E+04, 0.36601600E+03, -.15108800E+03, -.42437700E+02, -.18024900E+03, -.16470200E+02, 0.36722100E+02, -.53603400E+02, 0.51088100E+02, -.32477600E+03, 0.68024000E+01, 0.25596200E+03, -.69245800E+03, 0.35848100E+03, -.56490900E+03, 0.34955500E+03, 0.94258000E+02, 0.12422300E+04, 0.10472700E+03, 0.10535400E+04, -.63429600E+03, 0.88031900E+03, -.20066800E+04, 0.35829000E+03, -.17621900E+03, 0.82030800E+03, -.18207500E+03, 0.89451100E+03, 0.56246400E+03, -.53855600E+03, -.45562600E+03, -.83138900E+03, 0.54880700E+03, -.23498100E+03, 0.69290600E+03, -.32960700E+03, 0.27561200E+03, -.34789500E+03, 0.41844700E+03, -.62333400E+03, 0.46741800E+03, 0.10551300E+04, -.25519700E+03, -.19315300E+03, 0.26657000E+04, -.38120900E+04, 0.18737700E+04, 0.44005200E+04, 0.19168200E+04, 0.93901200E+03, 0.35177500E+03, 0.13773600E+04, 0.11520500E+04, 0.53536600E+02, 0.37368200E+03, 0.35162100E+04, 0.20298700E+03, -.87918000E+02, -.67146900E+03, -.10274400E+03, 0.49440000E+03, 0.28452800E+03, -.28180800E+03, -.11629100E+03, -.11261500E+04, 0.53594100E+03, 0.28824700E+04, -.46975400E+03, 0.24700200E+03, 0.62432600E+03, 0.23373600E+03, 0.23251500E+03, 0.30936700E+03, -.37333300E+03, -.46913100E+03, -.24243800E+03, 0.23947000E+03, -.91601000E+02, -.24441200E+02, 0.15723300E+03, -.15338100E+03, -.31648500E+01, -.44158800E+02, 0.37716000E+01, -.32358400E+02, 0.76221800E+02, -.63266700E+02, 0.11097200E+04, 0.28811500E+01, 0.18125800E+03, 0.21851900E+03, 0.53059300E+03, -.17832500E+03, -.25133700E+03, -.93367500E+02, 0.93674200E+02, 0.19021700E+03, 0.64354800E+02, -.29970200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.50272900E+00, 0.11097100E+01, 0.35531200E+01, 0.20061800E+01, 0.15614900E+01, -.26138100E+00, 0.46475800E+00, -.41817000E+00, -.80245300E+00, -.12791400E+01, -.25743400E+00, -.25122100E+00, -.29834100E+01, 0.15589000E+01, 0.87227900E+00, -.12946900E+01, 0.13649100E+01, 0.50092400E+00, 0.87608100E+00, -.29254300E+00, 0.85352200E-01, 0.12802300E+00, -.14530000E+01, -.37833500E+00, -.29888500E+00, -.52326100E-03, -.31285400E+00, 0.67851600E+00, -.31748800E+01, 0.69069100E+00, 0.44326000E+00, 0.20838400E+01, -.51176600E+00, -.29722900E+00, 0.12458300E+01, 0.11040400E+00, -.14044600E+00, -.35354800E+00, -.47048500E-01, 0.69317600E+00, -.48419500E+00, -.19725900E+01, 0.24234700E+00, -.40467100E+00, 0.30525300E+01, -.64290500E+00, -.84569200E-01, -.21707700E-01, 0.10843000E+01, 0.82746500E+00, 0.57615600E+00, 0.29068200E+00, 0.28787700E+00, -.33268600E+00, 0.26294400E+00, -.69878000E+00, 0.36278700E+00, -.24270000E+01, 0.17130000E+00, -.92869500E+00, -.65758800E+00, 0.11868000E+01, 0.12975800E+01, 0.21497900E-01, 0.52416900E+00, 0.67644200E+00, 0.50608900E+00, 0.75565000E+01, 0.12232300E+00, 0.68438600E-03, 0.27400700E+00, -.13906800E+00, 0.36342400E-01, -.80811100E+03, 0.64904900E+02, -.79883300E+01, 0.11726800E+04, -.36983100E+04, 0.18531700E+04, 0.35615500E+04, 0.18537400E+04, 0.16542200E+04, 0.16703700E+04, 0.84455600E+03, 0.19354500E+04, -.96764400E+03, 0.13121400E+04, 0.23717400E+04, 0.35195700E+04, -.17287000E+04, -.22020800E+04, -.17582900E+04, -.57774200E+02, 0.17171100E+03, -.18067100E+04, 0.45001500E+02, -.19761900E+04, 0.22128400E+03, 0.45131400E+04, -.35425600E+04, 0.17951100E+04, -.17555400E+04, 0.17752700E+04, 0.50095600E+03, -.98027800E+03, 0.82134400E+03, -.37068700E+03, 0.15463200E+04, -.49892100E+03, -.42798400E+03, -.53417000E+04, 0.26368300E+04, 0.83475300E+03, 0.26654400E+04, 0.27873800E+04, 0.30640500E+04, -.31508400E+04, -.77041100E+04, -.29857200E+04, 0.28901500E+04, 0.44826500E+04, 0.20717600E+04, -.10521200E+04, -.11749700E+04, -.10492700E+04, -.34741600E+03, 0.15013000E+03, -.69834000E+03, -.24280200E+03, -.14659400E+04, 0.91062800E+02, -.26988900E+03, -.19109000E+04, 0.93373600E+03, 0.22352300E+04, 0.97854200E+03, 0.16708800E+02, -.25200900E+03, 0.17764300E+04, 0.11942800E+04, 0.14938200E+04, -.19232100E+03, -.58107700E+04, 0.78236200E+03, -.39727400E+03, -.30274200E+03, -.39347800E+03, -.20590300E+03, -.33329200E+03, 0.34329800E+03, 0.31414500E+03, 0.35906700E+03, -.29925900E+03, -.76353400E+03, 0.43622300E+03, -.19454000E+03, -.34736600E+03, -.22302300E+03, 0.41348800E+02, -.23768700E+03, -.51278800E+03, 0.41644400E+03, -.15628100E+03, -.17074800E+03, 0.40155800E+04, 0.36540000E+04, -.18260500E+04, 0.11464800E+04, -.18229900E+04, -.97762800E+03, 0.36980900E+02, 0.89865700E+00, 0.25095100E+04, 0.12504300E+01, -.26511000E+03, -.20105500E+04, -.11229900E+04, 0.59763200E+03, -.49943000E+02, 0.56550200E+03, -.55106300E+03, -.35792400E+03, -.58018400E+03, -.16561300E+04, 0.39086200E+03, 0.10902400E+03, -.38473000E+04, 0.86340800E+04, -.43164800E+04, -.61787500E+04, -.43308400E+04, -.30475900E+04, -.25093800E+04, -.11625500E+04, -.13140700E+04, 0.79856300E+03, -.20383800E+04, -.54584700E+04, -.19454500E+04, 0.10018900E+04, 0.34741400E+03, 0.97499200E+03, -.85464700E+03, -.12633100E+04, 0.16155600E+04, 0.38927600E+03, 0.25507400E+04, -.11043400E+04, -.45199600E+04, -.34251800E+03, 0.18013100E+03, 0.51076500E+03, 0.17306200E+03, 0.12164500E+03, 0.54681500E+03, -.57321200E+03, -.28103200E+02, -.20294400E+03, 0.40323100E+03, 0.62076900E+03, 0.52823600E+02, 0.51779400E+02, -.10591300E+03, 0.14375100E+02, -.14113000E+03, 0.70539100E+02, -.35008400E+02, 0.11873800E+03, -.43557800E+03, -.93316100E+03, -.17752100E+03, -.22686900E+03, -.18003100E+03, -.56585300E+03, 0.44932500E+02, -.72396400E+02, 0.11633900E+03, 0.73093200E+02, -.42963900E+03, -.46127400E+02, -.67293000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11405500E+00, 0.15154300E+00, -.31012200E+01, -.96594000E-01, -.62875300E-01, 0.11221400E+01, -.19521500E+01, 0.17437100E+00, -.11753100E+01, -.85524000E+00, 0.12151200E+00, 0.40277500E+00, -.15251700E+01, -.78410300E+00, 0.11606700E+00, -.95239800E+00, 0.34351900E+00, 0.75511000E-01, -.88727300E-01, -.21453500E+00, -.10998500E-01, -.96866100E-01, 0.66710600E+00, -.26713200E-01, -.14194200E-01, -.49598300E-03, 0.78131500E-01, -.20609400E+00, -.77134300E-01, -.15558800E-01, -.17050200E+00, 0.90826500E-01, -.24937400E+00, -.12126800E+00, 0.28068900E+00, -.60673400E-01, 0.64729300E-01, -.61409900E-01, -.11952300E+00, 0.35681100E+00, -.63479300E+00, 0.89918900E-01, 0.42637400E-01, 0.16525500E+00, 0.27215900E+00, 0.24714300E-01, -.25756000E+00, -.45315200E-02, -.63842600E+00, -.25845300E+00, 0.13196500E+00, -.10495300E+00, 0.18679600E+00, 0.52815600E+00, 0.48846900E+00, 0.30068300E+00, -.54608200E+00, 0.59716100E+00, -.50944800E-01, -.30050500E-01, 0.56808300E-01, -.50931500E+00, -.13900000E+01, -.20693100E+00, -.20484700E+00, 0.17445400E-01, -.76253000E-01, -.37298000E+01, 0.46964100E-01, 0.84464400E-02, -.15605000E+00, -.28654500E+00, -.52846100E-02, -.16621900E+00, -.13597100E+03, -.11928500E+02, 0.26013000E+03, -.13567900E+04, 0.67567300E+03, 0.57669600E+03, 0.67935200E+03, 0.14290300E+03, -.36798100E+02, 0.48085000E+03, 0.22752300E+03, 0.62074500E+03, -.21101300E+02, 0.80424500E+03, 0.10071600E+04, -.50441000E+03, -.54324700E+03, -.50328300E+03, -.10007200E+03, -.44172800E+02, -.20205800E+03, -.20143600E+03, -.19617500E+03, -.38342700E+02, 0.64857200E+03, -.91623600E+03, 0.45878400E+03, 0.16897000E+03, 0.45896800E+03, -.13005100E+03, -.56278800E+03, 0.47460300E+03, 0.40371600E+03, 0.11316600E+04, -.47491900E+03, -.22074800E+03, -.71881300E+03, 0.35609600E+03, 0.24238800E+03, 0.35825100E+03, 0.31385500E+03, 0.63130800E+03, -.66271200E+03, -.12157300E+04, -.79079300E+03, 0.56392700E+03, 0.84574200E+03, -.64573700E+02, 0.31293700E+02, 0.16521600E+03, 0.29432000E+02, 0.43573500E+02, 0.12111900E+03, -.52940900E+02, -.58136500E+02, -.34207300E+03, 0.13850900E+03, 0.25409500E+03, -.50092700E+03, 0.25109100E+03, 0.38986600E+03, 0.25539900E+03, 0.11541100E+03, 0.13369400E+03, 0.82196100E+02, 0.23877700E+03, 0.24107900E+03, 0.78156800E+02, -.92442200E+03, 0.87010900E+02, -.43115800E+02, -.23478900E+02, -.44005400E+02, 0.54213300E+01, 0.21026600E+02, 0.79030300E+00, 0.38649700E+02, -.45236400E+02, 0.87485600E+01, -.99991700E+02, 0.69287200E+03, -.34610600E+03, -.31557300E+03, -.34748000E+03, 0.15304000E+02, 0.82096700E+02, -.13167400E+03, -.16523200E+03, 0.47963100E+02, -.77812300E+01, 0.27910000E+03, 0.48002500E+03, -.23878300E+03, -.18693200E+02, -.23915900E+03, 0.79282200E+02, 0.46710800E+02, 0.31294400E+02, 0.10690100E+03, -.33952200E+03, 0.17628000E+02, -.25985200E+03, 0.11834800E+04, -.58946200E+03, -.67231800E+03, -.59087900E+03, -.31351400E+02, 0.34845300E+03, -.47948500E+03, -.23153900E+03, -.58913500E+02, 0.30117800E+03, -.82119500E+03, 0.20185400E+04, -.10072100E+04, -.72416700E+03, -.10121900E+04, -.28287900E+03, -.58780800E+02, -.54743500E+03, -.91117400E+02, -.78374400E+03, -.53344400E+02, -.12220700E+04, -.55073800E+03, 0.27717200E+03, 0.25033000E+03, 0.27585700E+03, 0.16366000E+03, 0.38776900E+03, -.11147400E+03, -.23677200E+03, 0.47843500E+01, 0.28713100E+03, -.57260300E+03, 0.28190400E+03, -.13810900E+03, -.28379700E+03, -.14056600E+03, -.33317800E+02, -.11484600E+03, 0.19928600E+02, 0.32161500E+02, -.68491500E+02, -.75508300E+02, -.80225100E+01, 0.15045500E+02, 0.60772200E+01, 0.32478300E+02, 0.24265200E+01, 0.17499100E+02, -.11030100E+02, -.23447600E+02, -.39781600E+01, -.16417000E+02, -.22249400E+03, -.98467900E+02, -.43489300E+02, -.27205800E+02, -.11930000E+03, 0.29516100E+02, 0.70189800E+02, 0.89355000E+01, 0.33614500E+02, -.48659000E+02, 0.57000200E+02, 0.20575100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12984300E+00, -.72433600E+00, -.24200400E+00, 0.47021800E-01, 0.13615500E+00, -.49240600E+00, 0.92557500E+00, -.45210500E-01, 0.64278200E+00, 0.81822300E+00, 0.38234400E-01, -.70612800E-01, 0.87572500E+00, 0.44568800E+00, 0.30568000E+00, 0.33458800E+00, -.61578200E+00, -.14476000E-01, -.18767700E+00, 0.21345100E+00, 0.58990300E-01, -.27355700E-01, 0.83010900E+00, 0.75709900E-01, 0.12366200E+00, 0.84866100E-03, 0.18240200E+00, 0.44047100E+00, -.46908500E+00, 0.53530200E-01, -.27049000E+00, -.94631600E-01, -.32543600E+00, 0.20479200E+00, 0.46282300E+00, 0.56361700E-01, 0.10609400E-01, -.15143600E+00, 0.31650100E-01, 0.15122300E+00, -.53928800E-01, 0.11929100E+00, 0.63126200E-01, 0.15540800E-02, 0.35350600E+00, -.10084800E+00, -.12732600E+00, -.44419600E-02, -.27056300E+00, -.11754200E+00, -.17099700E-02, 0.24028200E+00, 0.24544300E+00, 0.98081900E-01, -.17298000E+00, -.22505400E-01, 0.25728600E+00, 0.24533300E+00, 0.30378200E-01, 0.75851700E-01, 0.37594200E-01, -.28145600E+00, 0.12368600E+01, 0.13849300E+00, 0.48620600E+00, -.75626300E-01, 0.95985800E-01, -.72479000E-01, 0.12576100E-01, -.73147500E-02, 0.20775300E+00, 0.27629100E+00, -.68981200E-01, 0.10078200E+00, 0.12144100E+00, -.31638700E+02, -.52763300E+02, 0.30981500E+03, -.14528600E+03, -.93562900E+02, -.15531200E+03, -.57002300E+02, -.69214800E+02, -.66244200E+02, 0.26674900E+02, 0.17168700E+03, -.74210300E+02, -.32501500E+03, -.86592200E+03, 0.42405200E+03, -.12424300E+03, 0.43274700E+03, -.11546900E+03, -.68975600E+02, 0.37324400E+03, 0.34031800E+02, 0.37391200E+03, -.13099200E+03, 0.16531300E+03, 0.47001600E+03, -.24448800E+03, -.20566500E+03, -.23570700E+03, 0.13546900E+03, 0.11655000E+03, 0.13389400E+03, 0.59202800E+03, -.10164800E+03, 0.13997600E+02, 0.54732100E+02, 0.22984200E+03, -.95974700E+02, -.37906600E+02, -.11387000E+03, -.10937200E+02, -.16041600E+03, 0.10206100E+03, 0.95943100E+02, 0.11266300E+03, -.11615800E+03, -.28534100E+03, -.33639500E+03, 0.17594100E+03, 0.55741400E+02, 0.17047800E+03, -.84877700E+02, -.23001400E+03, 0.10555900E+03, -.30350500E+02, 0.31071500E+03, -.16264800E+03, 0.22304800E+03, 0.29454200E+03, -.14067800E+03, 0.21207100E+03, -.15039900E+03, 0.47304500E+01, -.61957200E+02, -.14692700E+03, 0.68799400E+02, -.12168900E+03, 0.14339500E+02, 0.22854500E+03, -.34204200E+02, 0.21913400E+02, 0.73783000E+02, 0.17156700E+02, -.11428700E+02, -.21176500E+02, -.14489300E+02, -.26409400E+02, -.16607400E+02, -.19943600E+02, 0.32349600E+02, -.36910700E+03, 0.17478900E+03, -.13960400E+02, 0.18538900E+03, 0.83671500E+02, 0.21353800E+03, 0.13724700E+03, 0.16696500E+03, 0.22631400E+02, 0.13946900E+03, -.71833000E+02, -.77457500E+03, 0.38391100E+03, 0.12365900E+03, 0.38668400E+03, -.98275600E+02, -.35246600E+01, 0.74501600E+02, -.18845100E+03, 0.11787200E+03, 0.32406600E+02, 0.44038900E+03, 0.49272700E+03, -.26161200E+03, -.22867000E+03, -.24697700E+03, -.15823500E+03, 0.14356800E+03, -.37868400E+01, 0.15266700E+03, -.24367800E+03, 0.89150600E+02, 0.13282300E+03, -.46829200E+03, 0.22739600E+03, -.20565700E+02, 0.23587700E+03, 0.78847100E+02, 0.92870900E+02, -.45468000E+01, -.18833800E+03, -.24128900E+03, 0.12790800E+03, 0.51828600E+03, 0.35403600E+03, -.19051100E+03, -.79290100E+02, -.17755100E+03, 0.48811200E+02, 0.28608400E+03, -.15793900E+03, 0.11857600E+01, -.41710000E+03, 0.22064000E+03, 0.25020000E+03, 0.18325600E+03, -.10066100E+03, -.11427500E+03, -.91984800E+02, -.27909500E+02, 0.16701600E+02, -.65512900E+02, -.40392300E+02, -.44644900E+02, 0.21197300E+02, -.58690200E+02, -.45191600E+01, -.64464900E+00, 0.42696200E+02, -.16750900E+01, 0.27579700E+02, -.56705300E+01, -.30840200E+01, -.24126000E+02, 0.19975900E+02, 0.66220600E+02, 0.48161200E+02, 0.18912500E+02, 0.35780300E+02, 0.95179500E+01, 0.40809000E+02, -.40893100E+02, -.41003400E+01, -.10946000E+02, 0.22678600E+02, 0.12345300E+02, -.18756200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14803500E+00, 0.74025500E+00, 0.64044200E+00, -.20217600E+00, -.28006200E+00, 0.62402900E+00, -.91248000E+00, 0.15324300E+00, -.27688100E+00, -.72371800E+00, -.19787700E-01, -.49292800E-01, 0.62278900E-01, -.36557000E+00, -.21710000E+00, 0.13402600E+00, -.31046100E+00, 0.20655400E+00, -.16507000E+00, -.50253800E+00, -.53351300E-01, -.45684400E-01, -.10198500E+00, 0.63541800E-01, 0.16514100E+00, 0.39492700E-02, 0.27807300E-01, 0.81288900E-01, -.90261000E-01, 0.49906700E-01, 0.12648400E+00, -.11827600E+00, 0.32911100E+00, 0.78095700E+00, 0.76281100E-01, 0.19243100E+00, -.14904800E+00, -.18821000E+00, 0.35511200E+00, -.10716900E+00, -.24907100E+00, 0.49729900E+00, -.24260700E-01, 0.84109400E-01, -.73478100E+00, 0.22213000E+00, 0.37524000E-01, 0.10312700E-01, -.97185300E-01, -.47268100E+00, 0.84533900E-02, -.43590900E+00, -.10066000E+01, -.12001900E+00, -.24851700E+00, 0.13273500E-01, -.52559500E+00, 0.35445700E+00, -.11003500E+00, 0.20027600E+00, -.78116100E-02, 0.31228800E+00, -.26897600E+00, -.12724600E-01, 0.28245500E+00, -.39465900E+00, 0.28099800E-01, -.37405600E+01, 0.87778300E-01, -.27787300E-01, 0.12105600E+00, 0.71710200E-01, 0.15382500E+00, -.79162000E-02, -.26166500E+00, 0.86027400E+00, -.24455500E+03, 0.25541600E+04, -.12632600E+04, -.82771900E+03, -.12763400E+04, -.34578600E+03, 0.34389200E+03, -.75172400E+03, -.18196800E+03, -.18252800E+04, 0.35624100E+03, -.39968200E+02, -.15254100E+03, 0.84873400E+02, -.15366400E+03, 0.76160200E+02, -.30252400E+03, -.19157300E+03, 0.29151100E+03, 0.59754000E+03, 0.12656400E+03, -.14854900E+03, 0.14503600E+03, -.13979300E+04, 0.70740200E+03, 0.44274000E+03, 0.69848700E+03, 0.13448600E+03, -.32328700E+03, 0.49023000E+03, -.78570600E+02, 0.11443000E+04, -.26895000E+03, -.57977600E+03, -.10634000E+04, 0.51690200E+03, 0.35147000E+03, 0.53268900E+03, 0.54507900E+03, 0.86015800E+03, -.66559500E+03, -.81789100E+03, -.90191600E+03, 0.88059700E+03, 0.77503300E+03, -.31206200E+03, 0.14598300E+03, 0.32230200E+03, 0.15742100E+03, 0.44878700E+03, 0.45516200E+03, -.49971600E+03, -.82919700E+03, -.85674000E+03, 0.44820700E+03, 0.51383400E+03, -.14556200E+03, 0.67517200E+02, 0.37996200E+03, 0.73340100E+02, 0.82920500E+02, -.98231400E+01, -.45031100E+01, -.30078900E+03, 0.22128600E+03, -.21188800E+02, 0.24796500E+02, 0.12503100E+03, -.44945600E+02, -.80297800E+02, -.63003300E+02, -.69337400E+02, -.93181400E+02, 0.31626500E+02, 0.10146600E+02, 0.11303400E+03, -.99653500E+02, -.16162900E+03, 0.47896300E+03, -.22868100E+03, 0.20107600E+03, -.23895500E+03, -.34730100E+03, -.33118400E+03, 0.58847100E+03, 0.11804700E+04, 0.60788600E+03, -.32721000E+03, -.61289200E+03, 0.10373000E+04, -.51898300E+03, -.42289800E+03, -.51877700E+03, -.31672500E+03, -.29797200E+03, 0.24284300E+03, 0.56402900E+03, 0.62279800E+02, -.29848700E+03, -.48287300E+03, -.20290300E+04, 0.10279800E+04, 0.94575200E+03, 0.10137600E+04, -.14978300E+03, -.60265700E+03, 0.65564500E+03, -.20802700E+03, 0.14480500E+04, -.47465500E+03, -.68543800E+03, -.14367500E+04, 0.69804000E+03, -.41768200E+02, 0.71775100E+03, 0.36292700E+03, -.54863200E+03, 0.38511100E+03, -.80422100E+02, 0.17731600E+04, -.56029500E+03, -.46870500E+03, -.42333500E+02, 0.32745000E+02, 0.21077300E+03, 0.20452500E+02, -.27069300E+03, -.73467300E+03, 0.58837400E+03, 0.40551900E+03, 0.14198400E+04, -.65710700E+03, -.13421000E+04, -.82062100E+02, 0.46450900E+02, -.24940200E+02, 0.40687400E+02, 0.59893200E+02, -.67805100E+01, 0.32248100E+02, -.21511900E+02, 0.31696500E+02, 0.18865500E+01, -.32469500E+02, 0.10921200E+02, -.12536000E+02, -.42277900E+02, 0.16014300E+01, 0.33181600E+02, 0.19355100E+02, 0.29770500E+01, -.33581300E+02, 0.20882800E+03, 0.11967800E+03, -.90555700E+02, -.56968100E+02, -.12190700E+03, -.26897200E+02, -.13605000E+02, -.18167100E+03, 0.51501600E+01, 0.76948100E+02, 0.60265200E+02, -.79815200E+02, 0.86660800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.50475300E-01, -.18474200E+00, -.58188100E+00, -.12070300E+00, 0.46609600E+00, -.60666500E-01, -.47524000E+00, -.12685400E-01, -.13194900E-01, -.26869900E+00, 0.74880900E-01, -.55681200E-01, 0.33746700E+00, 0.20523800E+00, 0.19322000E+00, -.11122100E+00, 0.28423900E+00, 0.21505900E+00, -.40464700E+00, 0.30572700E+00, -.93265000E-02, -.24515400E-01, -.44068500E+00, 0.19344800E-01, -.17279700E+00, -.53102800E-03, -.92562500E-01, -.16076200E+00, 0.51459300E-01, 0.13589900E+00, 0.43497700E-01, -.34702900E-01, -.36793600E-01, -.11140900E+00, -.41216900E-02, 0.19667500E-01, -.26273000E-01, -.71000700E-01, -.64697800E-02, -.38736400E+00, 0.23424200E+00, 0.61288400E-01, -.94854400E-01, -.84194300E-01, 0.82413900E+00, 0.54715600E-01, 0.49207500E-01, -.16651500E-01, -.10673500E-01, -.14517900E+00, 0.46366600E-01, -.18080500E+00, -.28258300E+00, -.16002000E-01, -.16293000E+00, 0.36374700E-01, -.27355000E-01, 0.31494200E-01, -.24785300E-01, -.30379300E-01, 0.71268200E-01, 0.10696500E+00, 0.32786700E-01, 0.61710900E-01, 0.14603000E+00, 0.31132800E-02, -.25042400E-01, -.11971100E+01, -.33234500E-01, 0.31040900E-02, -.10842400E-01, 0.27906800E-01, -.37180900E-01, -.69820200E-01, -.22498300E+00, 0.19760700E+00, -.84695200E-01, 0.80127200E+03, -.40028200E+03, -.42389900E+03, -.39992500E+03, -.67712600E+02, 0.69232900E+02, -.16465200E+03, 0.90472800E+02, -.66333200E+03, 0.12828600E+03, 0.16248800E+03, 0.36377800E+03, -.17881800E+03, -.64586300E+02, -.18165100E+03, -.15523300E+03, -.69597400E+02, 0.62533200E+02, 0.35831200E+03, -.62086200E+02, -.57458300E+02, 0.29321800E+02, -.50680100E+03, 0.25667000E+03, 0.92690700E+03, 0.25406100E+03, -.52636700E+02, -.47764500E+02, 0.87883600E+02, -.22377000E+03, 0.40399300E+03, -.63733700E+02, -.45100800E+03, 0.20213500E+03, -.10857800E+03, 0.24340200E+03, -.10197700E+03, 0.23558600E+03, 0.58349100E+03, -.39918800E+03, -.10218900E+03, -.58767700E+03, 0.46638400E+03, 0.26181200E+03, 0.17756300E+03, -.93197000E+02, -.25132600E+02, -.90994800E+02, 0.22311600E+03, 0.35085000E+03, -.32624600E+03, -.33885600E+03, -.50459800E+03, 0.30043200E+03, 0.15357800E+03, -.13957600E+03, 0.69723600E+02, 0.12533700E+01, 0.73536300E+02, 0.62226100E+02, -.11968900E+02, 0.33673300E+02, -.15722900E+03, 0.10172900E+03, -.20498700E+02, -.19931200E+03, 0.14275800E+02, -.38072000E+01, -.53240000E+02, -.74749900E+01, -.16318000E+02, -.28784200E+02, 0.38180700E+02, 0.19251400E+02, 0.66727300E+02, -.30872600E+02, -.60972800E+02, 0.13336100E+03, -.60792900E+02, 0.17945200E+03, -.67490600E+02, -.22227300E+03, -.30347300E+03, 0.29394400E+03, 0.47692200E+03, 0.32549900E+03, -.23670100E+03, -.17780900E+03, 0.30485900E+03, -.15118900E+03, -.66344800E+03, -.15177300E+03, -.70191900E+02, -.26202000E+03, 0.11765700E+03, 0.16976000E+03, 0.53646700E+02, -.22447500E+03, -.82791900E+02, -.38703800E+03, 0.19882200E+03, 0.41898500E+02, 0.19419300E+03, 0.21855000E+02, 0.13446400E+02, 0.85827200E+02, -.10102000E+03, 0.40728500E+03, -.63303400E+02, -.34299000E+03, -.57638600E+03, 0.28618400E+03, 0.20319900E+03, 0.28598600E+03, 0.85285500E+02, -.16700300E+03, 0.98528300E+02, -.20424000E+03, 0.72627300E+03, -.22428200E+03, -.38428800E+03, -.27709200E+03, 0.14262300E+03, 0.20946300E+03, 0.13893900E+03, -.10473500E+03, -.18029200E+03, 0.17998900E+03, 0.13443100E+02, 0.60598500E+03, -.22252200E+03, -.44581800E+03, -.23095500E+03, 0.11853600E+03, -.63886100E+02, 0.11578200E+03, 0.21030000E+02, -.85892600E+02, 0.40722600E+02, -.45339400E+02, 0.10946700E+03, -.67428300E+02, 0.12553000E+03, 0.55456000E+01, -.18067300E+02, -.12819900E+02, 0.11549400E+01, 0.81879200E+01, 0.32118700E+01, 0.67824000E+01, -.79171600E+01, 0.89987200E+02, 0.40536700E+02, -.44144100E+02, -.59403800E+02, -.71239200E+02, -.22714300E+02, -.35653300E+01, -.80935900E+02, -.22037400E+02, 0.11045500E+02, 0.19854400E+02, -.36450300E+02, 0.80937500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.79247500E+00, 0.67560000E+01, 0.10026000E+02, 0.56185900E+01, -.33011000E+01, 0.63573400E+01, -.42596500E+01, -.93724000E-01, -.66912900E+01, -.48547000E+01, -.81006900E-01, 0.18187900E+01, -.80808500E+01, -.36363400E+01, -.13752200E+01, -.21581300E+01, 0.18646200E+01, -.30313500E+01, 0.21027900E+01, -.28720900E+01, 0.13235000E+00, 0.26297900E+00, 0.83347100E+01, 0.53815900E+00, 0.20591700E+01, 0.56069300E-02, 0.12151500E+01, -.24451000E+00, 0.15585800E+01, -.63111400E+00, 0.17821500E+00, -.85213100E+00, 0.33603000E+00, 0.28598200E+00, -.16456500E+01, 0.24547500E+00, 0.11131000E+00, 0.21884900E+00, 0.73673100E-01, 0.10882300E+01, -.15501200E+01, 0.11397900E+01, -.98511500E-01, 0.18572800E+00, -.21875900E+01, 0.61535800E+00, -.35317400E+01, 0.17742000E+00, -.13318800E+01, -.19559700E+01, 0.32734800E+00, 0.52824100E+00, 0.20357600E+00, -.51480800E+00, 0.59154700E+00, -.26939700E+00, 0.13025800E+01, -.78540100E+00, -.61403100E-01, -.25068600E+00, 0.11706300E+01, 0.20079400E+01, -.14871600E+01, -.20368500E+00, -.25757100E+00, -.23677400E+00, -.12071900E+01, -.52017800E+01, -.65458700E+00, 0.37347600E-01, -.72352100E+00, 0.44358400E+00, 0.20824800E+00, -.11227200E+01, -.71077100E+00, 0.56017000E+00, 0.24633300E+01, 0.36759500E+01, -.19371700E+03, -.99947100E+03, -.56962300E+01, 0.10444300E+04, -.35622500E+03, 0.11516500E+03, -.23717800E+03, 0.10847800E+04, -.57476800E+03, -.16374800E+04, -.10197600E+04, 0.48985600E+03, 0.11014500E+04, 0.50907300E+03, 0.52741700E+03, 0.25226400E+03, 0.41948800E+03, -.19226800E+03, 0.36800400E+03, 0.14453100E+03, -.14474400E+04, 0.18117800E+04, -.86099000E+03, 0.18520600E+04, -.90698400E+03, -.56607500E+03, 0.12244200E+03, -.52705500E+03, 0.65659500E+03, -.11288300E+04, 0.17250000E+03, 0.11994900E+03, 0.35306600E+04, -.18570000E+04, -.20817100E+03, -.17650000E+04, -.48342100E+03, -.14625300E+04, 0.13952900E+04, 0.41713300E+04, 0.19397100E+04, -.17789400E+04, -.24637100E+04, -.47202200E+04, 0.23795900E+04, 0.62861500E+03, 0.23645500E+04, 0.47060600E+03, 0.56253700E+03, 0.74320100E+03, -.70165700E+03, 0.16799500E+04, 0.39414700E+03, 0.98432600E+03, 0.67949700E+03, -.29804000E+03, -.17480900E+04, -.35712100E+03, -.53331200E+03, -.28327700E+03, -.42004000E+03, 0.98334000E+02, -.46357700E+03, -.20241600E+03, 0.16872600E+04, -.14899800E+03, -.30085400E+02, -.19622100E+02, 0.80130000E+02, 0.11160900E+03, 0.13904300E+03, -.16145500E+03, -.22975700E+03, -.35047400E+03, 0.15033800E+03, 0.31441900E+03, 0.37231000E+03, -.15471600E+03, -.21548000E+04, -.18456000E+03, -.58528700E+03, -.22991000E+03, -.19497000E+02, 0.98695000E+01, -.24803700E+02, -.16048100E+03, -.27094200E+03, -.15637600E+04, 0.78698100E+03, -.11121000E+03, 0.77959200E+03, 0.60977900E+02, 0.97486800E+01, -.16418500E+03, -.12374600E+04, 0.13916900E+02, 0.36201300E+02, 0.10140700E+04, 0.55223800E+03, -.20220300E+03, -.60937300E+03, -.27695500E+03, 0.43833600E+03, -.17855300E+02, -.39672000E+03, -.43642800E+02, -.65256500E+03, 0.13736900E+03, 0.31496900E+04, -.19254700E+04, 0.11740800E+04, 0.24635500E+04, 0.97426900E+03, -.12294900E+04, 0.58913800E+03, 0.26501100E+03, -.22938700E+02, -.11109900E+04, 0.89427800E+03, 0.28362600E+04, -.18485400E+04, 0.99114600E+03, 0.19802100E+03, 0.92514700E+03, 0.44088200E+03, 0.42815900E+03, -.60113600E+03, -.74028400E+03, -.42634500E+03, 0.61418200E+03, 0.37791700E+04, -.66131400E+02, 0.70994400E+02, -.41580900E+02, 0.33008400E+02, -.23988200E+03, -.70193600E+02, 0.13763600E+03, -.28615600E+03, 0.64243800E+02, -.51170200E+02, -.79228900E+01, -.39121200E+02, 0.25825800E+02, -.23700900E+03, -.70533500E+01, -.25955300E+03, -.67701200E+02, -.13409600E+02, 0.25714400E+03, -.53615900E+03, 0.35708300E+03, 0.89321600E+01, 0.13575400E+02, -.77470900E+02, 0.45324000E+03, -.27586900E+03, -.10967400E+03, -.42646100E+02, 0.85274100E+01, -.11281900E+03, 0.11508800E+03, -.17159200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.32620200E+00, -.23961200E+00, -.68887600E+00, 0.37541200E+00, 0.27252600E+00, -.62909800E+00, 0.16632600E+01, -.19439200E+00, -.13933100E+00, 0.11341400E+01, 0.28196200E+00, -.22543100E+00, 0.49450600E+00, -.51890900E+00, -.19425100E+00, 0.13994700E+01, -.23779400E+01, -.28620700E+00, -.48898700E+00, -.29478900E+00, 0.67749600E-01, -.11404700E+00, 0.15763400E+01, 0.14135500E+00, -.37072300E+00, 0.17898300E-02, 0.28117500E+00, 0.37362600E+00, 0.76832600E+00, 0.23193000E+00, -.38667300E+00, -.14894500E+00, 0.76752200E-01, -.29272900E-01, -.82751700E+00, -.27971700E+00, -.81003200E-01, -.19707300E+00, 0.89851500E-01, -.56087300E+00, 0.60935400E-01, 0.57596200E+00, -.12155900E+00, -.11025600E+00, 0.35373000E-01, 0.33260300E+00, -.85562900E-01, -.66243400E-01, -.11858000E+01, -.71316000E+00, -.43276300E+00, 0.11699000E+00, 0.59304100E+00, 0.57828100E-01, 0.66506000E+00, -.22262000E+00, -.89903000E+00, 0.52048000E+00, 0.13991500E+00, -.26060100E+00, -.11318300E+00, 0.14924600E+00, -.29449200E+01, -.49854200E+00, 0.11824900E+01, 0.55301600E+00, -.11235600E+00, -.11153300E+02, -.62497300E-01, -.82703500E-02, 0.14824900E+00, -.91722700E-01, -.27628200E+00, 0.20439500E-01, -.42406700E+00, -.25268900E+00, -.69964700E+00, -.16337000E+01, 0.67943900E-01, 0.16471100E+04, 0.10855400E+01, 0.19961400E+03, 0.63590900E+03, -.47909500E+03, -.27676100E+03, -.74456700E+03, 0.56291400E+03, 0.61530000E+03, 0.84813300E+02, -.38905500E+02, -.51426500E+03, -.42338100E+02, -.16366300E+03, -.43615200E+03, 0.36039700E+03, 0.27479300E+03, 0.13721700E+03, -.28603900E+03, 0.29879400E+03, -.16066200E+04, 0.81375000E+03, -.56732300E+03, 0.80310100E+03, 0.13490000E+03, -.56692600E+03, 0.80003200E+03, 0.15869300E+03, 0.14843300E+04, -.37731900E+03, -.16134400E+03, -.19849500E+04, 0.98356400E+03, 0.26498200E+03, 0.99310400E+03, 0.78435800E+03, 0.65756300E+03, -.10053400E+04, -.17941100E+04, -.70216100E+03, 0.70861600E+03, 0.91617100E+03, -.82805900E+03, 0.41430400E+03, 0.64987200E+03, 0.41450900E+03, 0.36300400E+03, 0.35386200E+03, -.39869500E+03, -.56569900E+03, -.49292300E+03, 0.39437100E+03, 0.78801300E+03, 0.88078200E+02, -.46496700E+02, 0.60089900E+03, -.42014600E+02, 0.42033500E+02, 0.18594600E+03, -.26168000E+03, -.15430900E+03, 0.45241200E+02, 0.82662500E+02, -.26292800E+03, 0.20805300E+03, -.10623600E+03, -.19012500E+03, -.10467000E+03, -.62624400E+02, -.90424400E+02, 0.54494700E+02, 0.71810800E+02, 0.58911000E+02, -.95124700E+02, -.14819500E+03, 0.90173000E+03, -.44767000E+03, -.20895500E+03, -.45068300E+03, -.12382300E+02, 0.10947600E+03, 0.15314700E+03, 0.53933700E+03, 0.21502900E+03, -.75627600E+02, -.42425000E+03, 0.10877500E+04, -.55075700E+03, 0.72478200E+03, -.54373200E+03, -.28581100E+03, 0.10275700E+03, 0.21829500E+03, 0.74663800E+03, -.17170900E+03, 0.57257800E+02, -.74909500E+03, -.15688300E+04, 0.80047800E+03, 0.11305100E+04, 0.78437800E+03, -.32243900E+03, -.78922500E+03, 0.81904200E+03, -.62831700E+02, 0.13072600E+04, -.48949400E+03, -.80565200E+03, 0.17757400E+04, -.88108600E+03, -.25238800E+04, -.88944200E+03, -.47002400E+03, -.97684400E+03, 0.28132400E+03, 0.46225700E+03, 0.34228700E+03, -.83050300E+03, -.12758900E+04, 0.24788400E+03, -.10934300E+03, -.56900900E+02, -.12450700E+03, -.23144200E+03, -.53845400E+03, 0.65803900E+03, 0.45861400E+03, 0.80462000E+03, -.39918900E+03, -.15547700E+04, 0.41082800E+03, -.20624600E+03, -.84484000E+02, -.20563900E+03, -.40473800E+02, 0.48608200E+02, 0.48982000E+02, 0.78955700E+02, -.22765600E+03, 0.68311000E+02, -.24121300E+03, 0.13781800E+02, 0.16167200E+02, -.81880600E+02, 0.11147700E+01, -.23662200E+02, 0.33551400E+02, 0.11362900E+02, 0.23744900E+02, -.25173400E+03, 0.32259500E+02, -.83822600E+02, -.24014700E+00, -.39563600E+02, 0.28904500E+02, -.57446500E+02, -.33558400E+01, 0.59571800E+02, 0.67430600E+02, -.11648500E+03, -.59489800E+02, 0.20409900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36289000E+00, -.70590200E-01, 0.20695200E+01, 0.11092200E+01, 0.15336200E+01, -.15464600E+01, 0.22809700E+01, -.46158300E+00, 0.78633000E+00, 0.60522900E+00, -.69983600E-02, -.29956900E+00, 0.11540100E+01, -.27661900E+00, -.29205900E+00, 0.15229500E+01, -.21986400E+01, 0.12382600E+00, -.36355900E+00, 0.21836100E+00, 0.36031600E-01, -.59793400E-01, -.56203600E+00, 0.42981700E-01, 0.11625100E+00, 0.11668600E-02, -.17106700E-01, 0.41801500E+00, -.20730200E+00, 0.12535800E+01, -.14917600E+00, 0.10496500E+01, 0.37445700E+00, 0.17358400E+00, -.96905600E+00, 0.12895700E+00, -.25998300E+00, -.17415900E+00, 0.38119300E+00, -.13197200E+01, 0.47372500E+00, 0.39763800E+00, -.41347000E+00, -.14868500E+00, 0.62613600E+00, 0.62981800E+00, -.64512200E+00, -.18435800E+00, -.10627700E+01, -.15292600E+01, 0.48762500E+00, -.68725600E+00, -.17241300E+01, -.22938900E+00, 0.12610100E+01, 0.14472600E+00, -.11422000E+01, -.65683700E+00, 0.59865700E-01, 0.26065200E+00, -.73705700E-01, -.34941500E-02, -.20690200E+01, 0.44632600E+00, 0.20539900E+01, -.37845700E+00, -.13884400E+00, -.10477300E+02, -.10350600E+00, 0.68766800E-01, 0.11579200E+00, 0.15008800E-01, -.56853400E-01, -.12604200E+00, -.11971300E+01, 0.16660200E+01, 0.42694200E+00, 0.27352800E+01, 0.10775100E+00, -.13616800E-01, 0.31835900E+02, 0.20467200E+03, 0.17261700E+03, -.49342800E+03, -.34569800E+03, 0.33686600E+03, -.84950500E+01, 0.63381100E+02, 0.35864300E+03, -.16112300E+03, -.34460900E+03, -.17913600E+03, 0.44226000E+02, -.16785700E+03, -.67729900E+02, -.39164900E+02, 0.13764400E+03, -.74659800E+02, -.25956200E+03, -.54359400E+01, 0.21221500E+02, -.82583400E+03, 0.37813800E+01, 0.16816800E+02, -.16290700E+03, 0.10796900E+03, -.11493700E+03, 0.86630500E+02, 0.67625700E+02, 0.40784300E+03, -.60662200E+03, 0.28146600E+03, -.13563300E+03, 0.30248800E+03, -.32586500E+03, -.42279700E+03, 0.13041900E+03, 0.70126200E+02, 0.33970300E+03, -.38607500E+03, -.11431500E+03, 0.29584400E+03, -.15485100E+03, 0.86891400E+02, -.15192000E+03, -.16531000E+03, -.15388700E+03, 0.10031300E+03, 0.33983400E+03, 0.27181300E+03, -.17828600E+03, -.40006400E+02, 0.14249600E+03, -.93185400E+02, 0.13287900E+03, -.58648100E+02, 0.13286200E+03, 0.37188600E+03, -.24199200E+03, -.16666000E+03, -.27039900E+03, 0.26705800E+03, 0.11756100E+03, 0.10492400E+03, -.64361600E+02, -.22007500E+02, -.54996900E+02, 0.31976700E+02, 0.63899500E+02, -.13146200E+02, 0.17503400E+01, -.10338800E+03, 0.59523000E+02, -.51622200E+02, 0.69464600E+02, -.28168900E+02, -.17998100E+03, -.36124300E+02, 0.15413600E+03, 0.28038800E+03, -.25797200E+03, -.40029800E+03, -.24711200E+03, 0.24895900E+03, -.34504100E+03, 0.53703800E+03, -.27082000E+03, 0.37478000E+03, -.26679300E+03, 0.16448500E+03, 0.25411900E+03, -.57438900E+02, 0.59080100E+02, -.35237900E+03, 0.18049500E+03, -.37396700E+03, 0.63942500E+02, -.38545200E+01, 0.27597400E+02, -.30877400E+02, 0.18672900E+03, -.12472100E+03, 0.21038400E+03, 0.25768800E+02, -.73884200E+02, 0.51244000E+02, 0.12056200E+03, 0.28774100E+02, -.10514600E+02, 0.36315400E+03, -.22268600E+02, -.24932100E+03, -.12443400E+03, 0.77948700E+03, 0.60655500E+03, -.63355000E+03, 0.70751000E+02, -.53149300E+02, -.23430500E+03, 0.14412100E+03, 0.54748300E+02, 0.11695400E+03, 0.26095100E+03, 0.24401800E+03, 0.12782600E+02, -.35820600E+03, -.50591100E+03, 0.25466500E+03, 0.47002300E+03, 0.36814200E+03, -.17658900E+03, -.25974500E+02, -.18381300E+03, -.52107800E+02, 0.16103000E+01, 0.53466000E+02, 0.17131800E+03, -.16010100E+03, 0.20990600E+01, -.23166500E+03, -.16786300E+01, -.81331400E+01, 0.49716800E+02, -.45535300E+00, 0.18267200E-01, 0.14234500E+02, -.87143400E+01, -.12638200E+01, -.41760900E+03, -.10494300E+02, -.24449100E+01, 0.60808000E+02, 0.85097100E+02, 0.19156400E+02, 0.47865700E+02, 0.78940600E+02, 0.42782600E+02, -.66235700E+02, -.85825700E+02, 0.56330100E+02, 0.14767000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18663200E+00, -.21318600E+00, -.13763700E+01, -.54847000E+00, -.39826200E+00, -.14464700E+00, 0.33765100E+00, 0.43649000E-01, 0.55910700E+00, 0.82262400E+00, 0.82553200E+00, -.15076300E+00, 0.22481100E+01, -.30990400E+00, -.57172000E+00, 0.94828800E+00, -.75851300E-01, -.49335200E+00, -.77062000E+00, 0.88869700E+00, 0.12498400E+00, 0.57294100E-01, 0.87979500E+00, 0.17327500E+00, 0.18379100E+00, 0.75787500E-03, 0.78765100E-01, -.43959500E+00, 0.11980600E+01, -.22770000E+00, -.31833100E-02, -.92198400E+00, -.14678000E+00, -.57136200E+00, -.14584000E+01, -.25403400E+00, 0.27815500E-01, 0.37912800E+00, -.13132000E+00, -.15324700E+01, 0.95155700E+00, 0.12072300E+01, -.54335400E+00, -.37649200E-01, 0.25699400E-01, -.16242600E+00, 0.92599500E+00, 0.18584800E-01, 0.37015900E+00, 0.99755800E+00, 0.54311600E-01, 0.40900900E+00, 0.39369300E+00, -.99185600E-01, -.53763600E+00, 0.14209600E+00, 0.21586100E+01, -.70337700E+00, 0.36977300E-01, -.92447200E-01, -.21602500E+00, -.31388900E+00, 0.15285500E+01, 0.52448400E-01, -.53778800E-01, 0.91035600E-01, 0.25883300E+00, 0.92351500E+01, 0.40877400E-01, 0.56340200E-02, 0.23701800E+00, 0.36187100E+00, 0.36227400E-01, 0.15172800E+00, 0.31237700E+00, -.11697400E+01, -.92277700E+00, -.82070400E+00, 0.51399500E-01, 0.25103300E+00, 0.79127700E-01, -.23969300E+03, 0.85995800E+02, -.13701100E+02, -.96601200E+02, -.45901900E+03, 0.15096100E+03, 0.14654700E+03, -.15076300E+03, 0.70865600E+02, 0.53549100E+02, 0.75816200E+02, -.52797000E+02, 0.21853000E+03, -.15904200E+03, -.74589800E+02, -.19570100E+03, 0.13295000E+03, 0.41531800E+03, -.47341000E+03, 0.24200100E+03, 0.29628400E+02, 0.23760700E+03, 0.80542100E+01, -.17578100E+03, 0.27984800E+03, 0.33753800E+03, 0.36944700E+03, -.26913700E+03, 0.53040600E+02, -.30142800E+03, 0.14019000E+03, 0.16294600E+01, 0.14980500E+03, 0.17512500E+03, 0.40294500E+03, -.27808200E+03, -.12111200E+04, -.68143400E+03, 0.56468700E+03, 0.17962600E+03, 0.11514900E+03, -.60860900E+02, 0.66973100E+02, -.60811700E+02, 0.74139200E+01, -.16792300E+03, -.15538000E+02, -.14402200E+03, -.32083900E+03, -.68569500E+02, 0.93228100E+02, -.18002500E+03, 0.97819500E+02, 0.26924700E+03, 0.98314000E+02, -.65587300E+02, -.26129400E+03, 0.32612500E+03, 0.23169100E+03, 0.36937100E+03, -.19949900E+03, -.19524200E+03, -.57436700E+02, 0.42040500E+02, 0.30088900E+02, 0.26586400E+02, -.67890600E+01, 0.29768500E+02, -.92720000E+02, -.20426800E+02, 0.84484700E+02, 0.71218500E+01, 0.85802000E+02, 0.27143900E+03, -.12894600E+03, 0.27268000E+03, -.13689400E+03, -.23607400E+02, 0.56330100E+02, -.53377900E+02, 0.27277300E+03, -.13360600E+02, -.37178200E+01, 0.12760300E+03, 0.12028000E+02, -.91642900E+01, 0.12560800E+02, -.47766000E+01, -.65890700E+02, -.79502500E+02, 0.53025300E+02, 0.25790100E+03, 0.10987300E+03, -.36931100E+02, -.83874600E+02, 0.90824600E+02, -.37096600E+02, -.54397000E+02, -.44731500E+02, -.31904700E+03, 0.49472700E+02, -.14621400E+02, 0.77245900E+02, 0.14724000E+03, 0.19587600E+02, -.92627700E+03, 0.79145100E+03, -.39822400E+03, -.64999700E+03, -.40096200E+03, 0.27022100E+03, -.12231300E+03, -.32352800E+03, 0.16492500E+02, 0.47001200E+03, -.21561300E+03, -.42063700E+03, 0.63041000E+03, -.30691900E+03, -.13943600E+03, -.31509900E+03, -.24448100E+03, -.28700700E+03, 0.16779300E+03, 0.45915600E+03, 0.43410600E+03, -.26942000E+03, -.11590600E+04, 0.43293000E+01, 0.92443600E+00, -.25935900E+02, -.18740600E+01, 0.94746800E+02, 0.31965900E+02, -.11878800E+03, -.23298900E+02, -.51640000E+02, 0.41765600E+02, -.19721500E+02, 0.76310500E+01, 0.49417100E+01, 0.41923300E+02, 0.18893900E+01, 0.70650100E+02, -.42761800E-02, -.13298600E+02, -.67142300E+02, 0.19793200E+03, -.92201900E+02, -.14361400E+02, 0.42498800E+01, -.26568500E+02, -.11442500E+03, 0.26317600E+02, -.30739900E+02, -.12056300E+02, 0.65412300E+02, 0.57929800E+02, -.39517400E+02, 0.63202500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25213000E+00, -.65520000E+00, 0.13856500E+01, -.34061600E+00, -.42651500E+00, 0.23696600E-01, -.54362800E+00, 0.71071500E-01, 0.15857200E+00, -.28407300E+00, -.11794000E+01, 0.11275100E+00, -.52916600E+00, -.95781800E+00, 0.29239700E+00, -.10088100E+00, -.16274000E+01, 0.91936000E+00, 0.66772200E+00, -.13985600E+01, -.24447400E+00, -.54317200E-01, 0.64838200E+00, 0.13854000E+00, 0.24990000E+00, 0.91602400E-03, 0.24224700E+00, 0.40160300E+00, -.29739800E+00, 0.17578600E+00, -.20513600E+00, 0.73704500E-01, 0.14588500E+00, 0.11911100E+00, -.41345500E+00, -.31937500E-03, -.11533800E+00, -.25141700E+00, 0.15223100E-01, -.34815400E+00, -.29727500E+00, -.40202400E+00, -.38400900E-01, -.21334400E+00, 0.56364400E+00, 0.17215200E+00, -.58482700E-01, -.84918300E-01, 0.15208100E+00, -.15236600E+01, -.44531300E-01, -.10653500E+01, -.18641700E+01, -.57092100E-01, -.12224200E+01, 0.28407200E+00, -.62572300E+00, 0.96184800E+00, -.14167100E+00, -.29300300E+00, -.12523300E+00, 0.36050700E+00, -.16470500E+01, 0.26869400E+00, 0.94910300E+00, 0.39957500E+00, -.10891300E+00, -.97722200E+01, 0.19348500E-01, 0.16858800E-01, 0.33500100E-01, -.25382800E+00, -.32081900E+00, -.83137500E-01, -.17734600E+00, 0.41514500E+00, 0.35354000E+00, 0.10030600E+01, 0.70755000E-01, -.40828300E+00, 0.45848800E-02, -.11621100E+01, 0.64735600E+03, -.61091600E+03, -.51798300E+03, -.10339600E+04, 0.60555300E+03, 0.21631900E+04, 0.10369500E+03, -.47634600E+02, -.14067400E+03, -.50985500E+02, 0.21613200E+02, 0.28696200E+03, 0.49839900E+02, 0.48266600E+03, -.22210200E+03, 0.19623500E+03, 0.21389700E+03, -.15835200E+04, 0.81702100E+03, 0.60717100E+03, 0.79361600E+03, -.27342300E+03, -.38483400E+03, 0.69387900E+03, 0.27532700E+03, 0.11646400E+04, -.44252500E+03, -.38482500E+03, -.93723700E+03, 0.43115200E+03, 0.26016200E+03, 0.46625100E+03, 0.50129900E+03, 0.10731200E+04, -.85513300E+03, -.18488900E+04, -.15075700E+04, 0.12230800E+04, 0.87316500E+03, -.65319500E+02, 0.20458800E+02, 0.14372700E+03, 0.26339900E+02, 0.10302400E+03, 0.47259700E+02, -.19677800E+03, -.20045700E+03, -.38409300E+03, 0.13731800E+03, 0.92074400E+03, 0.10627300E+03, -.50176800E+02, 0.24177800E+03, -.40900800E+02, -.57139400E+02, -.35744800E+03, 0.70522400E+02, -.27954900E+03, 0.38497500E+03, -.34662000E+03, -.32511100E+03, 0.13632600E+03, -.49345600E+02, -.89121200E+02, -.70587000E+02, -.25537400E+02, 0.56364300E+01, -.55913000E+02, 0.10007800E+03, 0.94619200E+02, -.18347600E+02, -.11339700E+03, 0.24571100E+03, -.10209600E+03, 0.34734600E+02, -.12517500E+03, -.21079500E+02, 0.19265700E+03, 0.11868500E+03, 0.64602300E+03, 0.87871100E+02, 0.18854400E+02, -.73952500E+03, 0.76680600E+03, -.39264200E+03, -.35451000E+03, -.38136100E+03, 0.46429800E+02, -.19915000E+03, 0.18751200E+03, 0.73035600E+03, -.12961500E+02, -.19360600E+03, -.49692800E+03, -.50844700E+03, 0.29232000E+03, 0.21755400E+03, 0.25634600E+03, -.12109300E+03, -.22453900E+03, 0.50639000E+03, 0.33705500E+03, 0.81015500E+03, -.21833400E+03, -.23519100E+04, 0.19329400E+04, -.96829900E+03, -.83541600E+03, -.97388100E+03, -.29481000E+03, -.10755200E+04, 0.63596000E+03, 0.12734200E+04, 0.10428200E+04, -.98363700E+03, -.32259700E+04, 0.24176900E+03, -.83861300E+02, -.15909000E+03, -.12001900E+03, -.67115000E+02, -.36350500E+03, 0.52136600E+03, 0.50757600E+03, 0.94366500E+03, -.37594900E+03, -.23679700E+04, -.13565500E+03, 0.78108800E+02, 0.11231500E+02, 0.68613300E+02, 0.12605300E+03, -.13780600E+02, -.54938800E+02, 0.40870700E+02, -.92025400E+02, -.86074300E+01, -.40146400E+01, 0.14594000E+02, -.53621700E+01, 0.20076500E+02, 0.37712100E+01, 0.51773000E+02, 0.15932500E+02, -.18371800E+02, -.47822100E+02, -.31490000E+03, 0.11913600E+03, -.60952700E+02, -.37675700E+02, -.61485400E+01, -.36757500E+02, 0.18774200E+02, -.68803300E+02, -.15342500E+02, 0.10215900E+03, -.15878000E+03, -.60520900E+02, 0.27428500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27009900E+00, 0.29252700E+00, 0.14787900E+00, 0.49227100E+00, -.16137800E+01, 0.50270800E+00, 0.88408700E+00, -.18318900E-01, -.43133600E-01, 0.13495300E+01, 0.23438600E+00, 0.21329300E+00, -.24747500E+00, -.86480300E+00, -.37122900E+00, 0.56707900E+00, -.34271500E+00, -.58318800E+00, 0.37905100E+00, -.29426600E+00, 0.11289500E+00, 0.59400700E-02, 0.19747400E+01, 0.12545800E+00, 0.60584800E+00, 0.13134900E-02, 0.40220900E+00, 0.75373600E-01, -.35583100E+00, -.32753700E+00, -.23035000E+00, -.45522100E+00, 0.17926300E+00, 0.54377500E+00, 0.52287200E+00, 0.17457300E+00, -.14622400E-01, 0.69256200E-01, 0.16536300E+00, 0.54154100E+00, -.86590700E+00, 0.56175600E+00, -.35086100E-01, 0.14773000E+00, -.57138100E+00, 0.14249900E+00, -.87494600E+00, 0.10135700E-01, -.10723900E+01, -.24674600E+00, 0.13082800E+00, 0.51761700E+00, 0.79625500E+00, 0.17500500E+00, 0.87596800E+00, -.24301600E+00, -.12948900E+00, -.12676700E+00, 0.10821800E+00, -.41722600E-01, -.48863800E-02, -.20005500E+00, 0.80720300E-01, -.35446900E+00, -.99852400E+00, 0.19519000E+00, -.14002700E+00, 0.15839900E+01, 0.17466900E+00, 0.46666300E-02, 0.49249700E-01, 0.11057800E+00, 0.10986400E+00, -.54052500E-01, 0.30485600E+00, -.72304100E+00, -.11326400E+01, -.65807600E+00, 0.47814000E-01, 0.48876600E-01, 0.10241400E-01, 0.15560700E+00, 0.43263300E+00, 0.37635400E+03, 0.47029400E+03, -.26044000E+03, 0.13958100E+03, -.10128300E+04, -.42634300E+03, 0.21370300E+03, -.28994900E+03, 0.21227800E+03, -.15408700E+03, -.42045000E+03, 0.43547400E+03, -.80820700E+01, 0.18140600E+03, -.30461200E+03, 0.37986800E+03, 0.15651300E+03, -.80706700E+02, -.88918600E+03, -.80585600E+02, -.61594700E+02, -.66613000E+02, 0.10686200E+03, 0.44731400E+03, 0.44303400E+03, -.12048800E+03, 0.36320500E+03, -.29551800E+03, 0.14845000E+03, -.18921800E+03, 0.15130600E+03, 0.18664100E+03, -.48508400E+03, 0.70868500E+02, -.11530700E+03, 0.27163600E+03, -.29585100E+03, -.19647600E+03, -.14775500E+04, 0.73714300E+03, 0.69166800E+03, 0.74634300E+03, 0.51194000E+03, 0.51275100E+03, -.24071500E+03, -.70981000E+03, -.52538500E+03, 0.52152900E+03, 0.53959800E+02, -.12742100E+03, 0.67349000E+02, 0.58621700E+03, 0.53956500E+02, -.37170300E+01, 0.24211600E+03, -.16507600E+03, 0.14611800E+03, 0.19062000E+02, 0.15579000E+03, -.75834400E+02, 0.11633500E+03, -.55249300E+02, 0.35091000E+02, -.56979000E+02, -.35033700E+02, -.67278000E+02, 0.42372800E+02, 0.84006200E+01, 0.32300500E+02, -.78283500E+02, -.26763900E+01, 0.79538400E+03, -.39630600E+03, -.42422800E+03, -.39489000E+03, -.24001800E+03, -.18385200E+03, 0.31188600E+03, 0.47371900E+03, 0.33488900E+03, -.24423400E+03, 0.43151900E+03, -.79890400E+03, 0.40199700E+03, 0.11018500E+04, 0.39749600E+03, -.24474200E+01, 0.59851800E+02, 0.18688900E+03, -.13772300E+03, 0.23677600E+03, 0.62024100E+02, 0.19615200E+03, -.10463300E+04, 0.51964000E+03, 0.67478100E+03, 0.52032700E+03, -.18116700E+03, -.23599500E+03, 0.32120000E+02, -.63060000E+03, 0.73873500E+03, -.12903800E+03, 0.10371800E+04, -.10722300E+03, 0.52474000E+02, 0.38242900E+02, 0.59085800E+02, 0.12908100E+03, 0.65655100E+02, -.77035500E+03, -.11186900E+04, 0.17254200E+03, -.11583700E+03, 0.13096800E+04, -.24004500E+03, 0.11547500E+03, 0.69056000E+02, 0.11819500E+03, -.45705400E+03, -.45184200E+03, 0.40447000E+03, 0.39828500E+03, 0.12519400E+04, -.40807700E+03, 0.30122400E+03, 0.84197700E+02, -.41814800E+02, 0.14591400E+02, -.43297800E+02, 0.37589600E+02, 0.48405400E+02, 0.44123900E+02, -.15399100E+02, 0.10249600E+03, 0.58555100E+02, -.74556600E+02, -.18109100E+01, 0.77964000E+02, -.13887300E+03, -.20064400E+01, -.60503100E+02, -.70838400E+00, 0.57334500E+01, 0.60788900E+02, 0.42347000E+03, -.20982600E+02, 0.13224900E+02, 0.64731300E+02, -.13607000E+03, 0.53921200E+02, -.13126100E+03, -.43952000E+02, -.18279100E+02, 0.34159200E+02, 0.14707000E+03, -.76588400E+02, -.10694900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20741400E+00, 0.65015800E+00, -.83056600E+00, 0.43889400E+00, 0.19841300E+01, 0.45619100E+00, -.15849200E+01, 0.61267700E-01, -.13327800E+01, -.25868300E+01, 0.42851600E+00, 0.19886400E+00, -.13886000E+01, -.85546700E+00, -.49777800E+00, -.60702800E+00, 0.10462100E+00, 0.26799900E+00, -.30481600E+00, -.49428800E+00, -.48303400E-01, -.13336100E+00, -.90062600E+00, -.34748400E-01, -.38420700E+00, -.42558200E-03, -.16020700E+00, -.42098600E+00, 0.74202500E+00, 0.12986900E+00, 0.41929300E+00, -.25931900E+00, 0.66692000E+00, 0.15103500E+00, -.19625400E+01, -.33742800E+00, -.93746400E-01, 0.14754500E+00, 0.10561000E+00, -.10533500E+01, 0.73015700E+00, 0.31544600E+00, -.30788800E+00, -.20327900E+00, -.14915600E+01, 0.42182200E+00, 0.21969300E+01, -.40438600E-01, -.80506700E+00, 0.52825500E+00, -.37276900E+00, 0.23024800E+00, 0.91403500E+00, 0.56187500E+00, -.18450200E+00, 0.61594300E-01, 0.90526200E+00, 0.64734600E+00, 0.99770700E-01, -.55909800E+00, -.24704500E-01, 0.32595500E+00, 0.10146600E+00, -.97193000E-01, 0.23489200E+00, 0.73832700E+00, -.15501200E+00, -.52973100E+00, -.40778400E-01, -.19475000E-01, 0.64144500E-01, 0.18313100E+00, -.26317900E+00, 0.41525700E-01, 0.41397800E+00, 0.12964100E+01, 0.43755900E+00, -.22944200E+01, -.16084700E+00, -.27644000E+00, 0.89752000E-02, -.36504200E+00, 0.33717800E+00, 0.55861100E+00, -.33590600E+03, -.69577400E+03, 0.18008200E+02, 0.94213900E+03, 0.14521200E+04, -.71973500E+03, 0.51988700E+03, -.72505900E+03, 0.24440700E+03, 0.80725300E+03, -.85726300E+03, 0.69404400E+02, -.61258700E+03, 0.65753800E+03, 0.26077100E+03, -.12419200E+04, 0.61713100E+03, 0.24911900E+04, 0.62361900E+03, 0.38210200E+03, 0.86392300E+02, 0.53694300E+02, -.58566900E+03, 0.68055900E+02, 0.10587900E+03, -.22246200E+04, 0.11493500E+03, -.58802500E+02, 0.86638800E+03, -.61666400E+02, 0.25377400E+03, 0.17897200E+04, -.87104600E+03, 0.56224500E+02, -.11868500E+04, 0.12614800E+04, 0.15249900E+04, 0.14673900E+04, -.73806500E+03, -.96781200E+03, -.74222900E+03, 0.10449800E+02, 0.29257300E+03, -.24457800E+03, 0.22946000E+02, -.37423700E+03, 0.12199300E+03, -.24677700E+03, -.77433400E+03, 0.37884700E+03, -.95059100E+03, 0.39678800E+03, -.15752600E+03, -.82209900E+03, 0.74428100E+03, -.62148100E+02, 0.37048600E+03, -.61005400E+03, -.91930000E+03, -.17238900E+03, 0.83481700E+02, -.18691000E+03, 0.86085200E+02, -.35132500E+02, -.94474100E+02, 0.13469300E+03, 0.48968800E+02, 0.12614900E+03, -.60872800E+02, -.97176200E+02, -.42242300E+03, 0.21465100E+03, 0.11566500E+03, 0.20804200E+03, -.27119900E+03, -.57200200E+03, 0.10644400E+03, -.53927100E+01, 0.37355700E+03, -.34881900E+03, 0.33365200E+03, 0.19477400E+04, -.96596700E+03, -.23417800E+04, -.97179600E+03, -.48487300E+03, -.61996600E+03, -.23098000E+03, 0.85387100E+02, 0.11176300E+03, -.61041100E+03, -.39054500E+03, -.13149000E+04, 0.65291600E+03, 0.62386100E+03, 0.66068600E+03, 0.48721700E+03, -.18910700E+03, 0.34237800E+03, 0.12046100E+03, 0.46470300E+03, -.30065300E+03, -.35222700E+03, 0.17900500E+02, -.15658400E+02, -.34743500E+02, -.14175300E+02, -.12665000E+03, -.32536800E+03, 0.32818600E+03, 0.68692100E+03, 0.12786700E+04, -.30857900E+03, -.13653100E+04, -.52374400E+03, 0.25617300E+03, 0.16995100E+03, 0.26415400E+03, 0.13145100E+03, -.39515700E+03, 0.18485100E+03, 0.83203500E+01, 0.28719800E+03, -.34844400E+03, -.85531300E+03, -.38103000E+03, 0.19520000E+03, -.32453300E+02, 0.19194000E+03, -.95166200E+02, 0.24908100E+02, -.58047600E+02, -.24399500E+03, 0.27028700E+02, -.89912000E+01, 0.54182300E+03, 0.30374300E+02, -.71693000E+02, 0.68827400E+01, 0.61632400E+01, 0.11649500E+02, -.58764600E-01, 0.29210400E+02, -.14109600E+02, -.86601500E+02, -.53210100E+02, -.11364100E+03, -.24571200E+03, -.68435700E+02, -.14275500E+03, 0.35095200E+02, -.66333600E+02, -.19902600E+02, -.15525600E+02, -.83400300E+02, -.24929200E+02, -.23450800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.85598900E-01, 0.16811300E+00, -.22782000E+01, 0.56942800E-01, 0.51121900E-01, 0.84804100E+00, -.11871200E+01, 0.12568200E+00, -.73707100E+00, -.56978000E+00, 0.10797400E+00, 0.30812600E+00, -.11088700E+01, -.64309600E+00, 0.43350900E-01, -.68198900E+00, 0.28033100E+00, 0.57408100E-01, -.43096200E-01, -.67037600E-01, -.21224700E-01, -.83032200E-01, -.10600200E+00, -.22752900E-01, -.13650200E+00, -.36489300E-03, -.84607500E-01, -.37409100E+00, 0.53722300E-01, -.99484400E-01, 0.75020400E-01, 0.96847400E-01, -.22518500E-02, 0.49243500E-01, -.84738000E-01, -.37613900E-01, 0.21213200E-01, 0.89854000E-02, -.20084700E-01, -.19427900E+00, 0.33256300E+00, -.84581200E-01, 0.11479700E-01, -.35109500E-01, -.45656000E+00, 0.97430400E-01, 0.25993000E+00, -.37703400E-02, 0.20330000E+00, -.11073200E+00, -.17243600E+00, -.13835800E+00, -.29487900E+00, 0.20022400E+00, -.27996300E+00, 0.17169300E+00, -.28661000E+00, 0.92250900E+00, -.34302700E-01, -.58358700E-01, 0.16690000E+00, 0.19560400E+00, -.57941600E+00, -.39736800E-01, -.26752800E+00, 0.14209200E+00, -.13978200E+00, -.51087400E+01, 0.25598400E-01, 0.88896900E-02, -.87221100E-02, -.20642900E+00, -.79325500E-02, -.12854000E+00, 0.23875400E+00, 0.45291100E+00, 0.92506000E-01, -.62228400E-01, -.68817300E-01, -.48537400E-01, 0.90699100E-02, -.18631000E+00, -.83107300E-01, -.11920600E+00, -.12857700E+00, -.37603400E+03, 0.11220700E+02, 0.48248500E+03, 0.11409600E+04, -.56759500E+03, -.52702900E+03, -.57017500E+03, 0.28327000E+00, 0.11497400E+03, -.43075500E+03, 0.11667300E+01, -.34056000E+03, 0.95522000E+02, 0.15482700E+03, -.62654900E+03, 0.31509900E+03, 0.74332200E+03, 0.31418700E+03, 0.92765600E+02, 0.43762700E+02, 0.14799900E+03, -.39072600E+03, 0.12206000E+03, 0.68677000E+02, -.59240200E+03, -.33708700E+03, 0.16323500E+03, 0.40266400E+03, 0.16725700E+03, 0.28757300E+03, 0.75255000E+03, -.43928600E+03, -.21030600E+03, -.60860000E+03, 0.59926000E+03, 0.64681100E+03, 0.66597300E+03, -.33579100E+03, -.42249700E+03, -.33602400E+03, -.25905800E+02, 0.15145900E+03, -.14935200E+03, 0.12106900E+02, -.33984100E+03, 0.89151800E+02, -.10994200E+03, -.69780600E+03, 0.34682000E+03, 0.27546200E+03, 0.35382900E+03, 0.27585500E+02, -.10525900E+03, 0.37292900E+03, -.32510600E+02, 0.24928300E+03, -.69559300E+02, -.43051300E+03, -.57458800E+02, 0.31600200E+02, -.13688100E+02, 0.28409200E+02, -.58367200E+01, -.25237800E+02, 0.57912700E+02, 0.48921200E+02, 0.67638100E+02, -.16602400E+02, -.72700400E+02, -.27156000E+02, 0.17320000E+02, -.48717400E+02, 0.12467500E+02, -.62330700E+02, -.31169100E+03, 0.53765800E+02, -.11082700E+03, 0.27231000E+03, -.19111200E+03, 0.22673800E+03, 0.80014300E+03, -.39822700E+03, -.83663300E+03, -.39919400E+03, -.15262700E+03, -.25190100E+03, -.33350200E+02, 0.10009800E+03, 0.19950100E+03, -.26803400E+03, -.19328000E+03, -.47331900E+03, 0.23971400E+03, 0.16413700E+03, 0.23759100E+03, 0.13203800E+03, 0.32685500E+02, 0.11475200E+03, -.32983300E+03, 0.18351600E+03, -.44384700E+02, -.50661300E+03, 0.34472300E+02, -.21245200E+02, -.16491900E+03, -.20085800E+02, -.82139000E+02, -.13364300E+03, 0.88297500E+02, 0.43196100E+02, 0.61410200E+03, -.13642600E+03, -.66070400E+03, -.30579600E+02, 0.17849800E+02, 0.25002800E+02, 0.15871900E+02, -.93796800E+02, -.18525100E+03, 0.20651300E+03, 0.24177300E+02, 0.36116300E+03, -.23354800E+03, -.50567000E+03, -.14218700E+03, 0.74151900E+02, -.21860600E+02, 0.71526600E+02, -.65617700E+01, 0.39396900E+01, 0.68103200E+01, -.21512600E+02, 0.62268400E+02, -.31304200E+01, 0.23042100E+03, 0.97390900E+01, -.37840700E+02, 0.14561500E+01, 0.21668900E+01, -.51850300E+01, 0.84886200E+01, 0.36133500E+01, 0.45102700E+01, -.49532200E+01, -.12502600E+03, -.33503900E+02, -.89776000E+02, -.46835100E+02, -.92169600E+02, 0.98148900E+01, -.22012600E+01, -.13841900E+01, -.16411200E+02, -.18774600E+02, -.32833000E+02, -.60829400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20450600E+00, -.64423200E+00, -.12160700E+01, 0.33981300E+00, 0.32523900E+00, -.86162900E+00, -.55228800E-01, -.57890300E-01, -.71176900E-02, 0.58856600E+00, 0.13597600E+00, 0.14747300E-02, 0.39338200E+00, 0.74955800E+00, 0.24611000E-01, 0.26338900E+00, -.22327900E+01, 0.55262100E+00, -.92093100E+00, 0.10739900E+01, 0.76292900E-01, -.28954400E-01, -.76133700E+00, -.69967500E-01, -.45811800E+00, -.55639500E-02, -.19229600E+00, 0.41531400E+00, -.57463000E+00, 0.87638300E+00, 0.13621400E+00, 0.25265300E+00, 0.27357100E+00, -.10837700E+01, -.45659100E+00, 0.18793000E+00, -.89739200E-01, -.19025000E+00, 0.29583600E+00, 0.31901900E+00, -.28318900E+00, 0.57938400E+00, -.25061400E+00, -.11963200E+00, 0.17157100E+01, -.20933300E-01, -.82281000E-02, -.95295300E-01, -.33900500E+00, -.34975800E+00, 0.79060000E+00, -.41706400E+00, -.52014700E+00, 0.14657900E+00, 0.49154200E+00, -.12678900E+00, -.22892900E+00, -.40690900E+00, 0.23403000E-01, -.18812500E+00, 0.19073900E+00, 0.37289700E+00, -.54650000E+00, -.44982900E-02, 0.36611900E+00, 0.88779300E-01, 0.73054100E-02, -.24269300E+01, 0.11623800E+00, 0.38776100E-01, 0.12798100E+00, -.92732600E-01, 0.13827900E+00, -.37599300E-01, 0.79064300E-01, 0.68213200E+00, -.34533700E+00, 0.22310800E+01, 0.79567500E-02, 0.39806400E+00, -.99069200E-04, 0.83025600E-01, 0.14436600E+00, -.14184000E+00, 0.15808300E+00, -.64680300E+00, -.13665500E+03, -.40669000E+03, 0.11752300E+04, -.57364000E+03, -.90568400E+03, -.58786900E+03, 0.57840600E+02, 0.49435000E+02, -.79399000E+03, -.51735800E+03, -.44027500E+03, 0.76973300E+02, 0.53231800E+03, 0.13447600E+03, -.57380900E+02, -.92776800E+03, -.67145900E+02, 0.35920200E+03, 0.13271700E+03, -.14571700E+03, -.27182900E+03, -.56857900E+03, 0.29958400E+03, 0.25599800E+03, -.89299700E+03, 0.43173000E+03, 0.35903000E+01, 0.44627400E+03, 0.13380300E+03, 0.10774700E+02, -.67981800E+02, -.46534500E+03, 0.10163400E+03, 0.55719400E+02, 0.31820400E+03, 0.86677600E+03, -.43833600E+03, -.52645400E+03, -.43364600E+03, -.21381400E+03, -.14798100E+03, 0.10504400E+03, 0.30383000E+03, -.18199000E+03, -.15187300E+03, -.77290100E+03, -.11390500E+04, 0.55231600E+03, 0.85995400E+03, 0.56954000E+03, 0.58300400E+02, 0.12732800E+03, 0.58029800E+03, 0.27027500E+03, 0.36119600E+03, 0.14801000E+03, -.52959300E+03, -.18760600E+03, 0.86028400E+02, 0.15621200E+03, 0.94307400E+02, 0.24735700E+02, 0.91848400E+01, 0.60394400E+02, 0.11664600E+02, 0.14196400E+02, 0.25371400E+02, -.38150500E+02, 0.46631800E+00, 0.45739700E+01, -.14543700E+03, -.29385100E+00, 0.66329300E+02, -.15677600E+03, -.33046400E+03, -.61839000E+03, 0.15019600E+01, -.53369500E+02, 0.97262200E+03, 0.44411600E+03, -.21945900E+03, 0.29999700E+03, -.22204300E+03, -.18260300E+03, 0.74088800E+02, -.68871800E+02, 0.40361300E+02, 0.22719900E+03, -.41463400E+02, -.15487900E+03, -.87967000E+03, 0.45478700E+03, 0.33921500E+03, 0.43934400E+03, 0.31647100E+02, -.15570200E+03, -.82775900E+00, -.56735200E+03, -.12560100E+03, 0.93697000E+00, 0.34869700E+03, -.71359600E+02, 0.34330200E+02, -.16799100E+03, 0.35978800E+02, -.81011800E+02, 0.73141000E+02, -.19867800E+01, -.12461000E+03, 0.49517900E+02, 0.18135600E+03, 0.48584100E+03, -.18090100E+03, 0.10486100E+03, 0.55988200E+02, 0.90632200E+02, -.90630600E+02, -.24394200E+03, 0.19222500E+03, 0.53248900E+01, 0.10092200E+03, -.16877400E+03, 0.12679300E+03, 0.38275700E+03, -.18411400E+03, 0.14117600E+02, -.19129100E+03, -.44297700E+02, 0.10904000E+03, -.26651700E+02, 0.19861100E+03, -.47863500E+02, 0.64832900E+02, -.48123200E+02, 0.52159000E+01, -.21605000E+02, 0.38076700E+02, 0.11479100E+01, 0.82711200E+01, 0.65049000E+01, -.12068500E+01, -.96331300E+01, -.87352100E+00, -.37432300E+03, 0.29510400E+02, 0.20888200E+01, -.35087900E+02, -.18700300E+03, 0.41453100E+02, 0.68029800E+02, 0.53143300E+02, -.68517100E+02, 0.28505600E+01, 0.12408800E+02, -.21570000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10503100E+01, -.19928800E+00, -.48978200E+01, -.49033100E+01, -.96087100E+01, 0.64831300E+01, -.83319400E+01, 0.16266400E+01, -.26942200E+01, -.16152400E+00, 0.22914100E+00, 0.46064500E+00, -.96813600E+00, -.48045500E+00, -.12306000E+01, 0.18645000E+00, -.92041500E+00, -.88320100E+00, 0.20338500E+00, -.84866500E+00, 0.82316200E-01, -.99882000E-01, 0.78707000E+00, 0.74332600E-01, 0.38318500E+00, 0.31615600E-02, 0.10832200E+00, 0.11204200E+00, 0.17143400E+00, -.55835000E-01, -.33103100E+00, 0.12982700E+01, 0.66212700E-01, 0.38573900E+00, -.66934100E+00, -.13474000E+00, -.21048200E+00, -.94018400E-01, 0.48601800E+00, 0.15231500E+01, -.89656800E+00, -.31012000E+00, 0.28310300E+00, -.41006500E-02, 0.95007800E-01, -.31029300E+00, -.46368000E+01, 0.77178300E+00, 0.65492000E+00, -.66976800E-01, 0.14092600E+00, 0.15593200E+01, 0.26036800E+01, -.60104100E-01, 0.25110400E+00, -.75787400E+00, 0.16543600E+01, -.11628900E+01, -.89908300E+00, -.65235800E+00, -.19616300E+01, 0.24791500E+01, -.39392900E+01, -.94987200E+00, -.23799100E+01, -.77375900E+00, 0.30850000E+00, 0.13782900E+02, 0.16837300E+00, -.72162400E+00, -.94514800E+00, -.59770900E+00, 0.44957200E+00, 0.29358600E+00, 0.54681400E-01, -.62481800E+01, 0.17302700E+01, -.11669000E+02, 0.23858400E+00, -.51649200E+00, -.46614400E+00, -.28472200E+01, 0.20165100E+01, 0.17482800E+01, 0.16782600E+01, 0.67294200E+01, -.52319500E+01, -.63597400E+04, -.33179100E+04, 0.16765000E+04, -.31769800E+03, 0.16444500E+04, -.12637000E+04, -.15591700E+04, 0.50885000E+03, -.17689200E+04, 0.52496400E+03, -.13560000E+04, 0.16584900E+04, 0.29185000E+04, -.14343000E+04, -.79633600E+04, -.14634200E+04, 0.31738400E+03, -.99656000E+03, 0.42907300E+03, 0.36009200E+04, -.31756600E+02, -.10989500E+04, 0.57655300E+04, -.73745200E+03, 0.34899500E+03, -.28184400E+04, 0.38459700E+03, -.28998500E+03, -.41078200E+04, 0.13837100E+04, -.53343300E+04, 0.12548900E+04, -.22576900E+04, -.45730500E+04, -.13499500E+04, 0.67848700E+03, 0.23913500E+04, 0.70144200E+03, 0.19509500E+03, -.12744900E+04, 0.26862800E+03, -.38287300E+03, -.19186300E+04, -.42409700E+03, -.14063600E+04, -.75542500E+02, 0.84745800E+01, 0.33055000E+04, -.18186200E+02, 0.35811300E+03, 0.18904000E+04, 0.58656000E+02, 0.23585200E+04, 0.63170100E+03, 0.16098500E+04, 0.12270800E+04, -.41344300E+03, 0.16398300E+03, 0.76492900E+03, 0.21802300E+03, 0.20755200E+03, 0.47570900E+03, -.56794500E+03, -.49347800E+03, -.15782300E+02, 0.33896700E+03, 0.63632800E+03, 0.34857400E+04, -.17521200E+04, 0.17524800E+04, -.17549800E+04, -.17593100E+03, 0.13569100E+04, -.13557600E+04, 0.85468900E+02, -.89922900E+03, 0.64974200E+03, 0.14602100E+04, -.45256600E+04, 0.22555800E+04, 0.84382000E+04, 0.22233400E+04, 0.29930700E+03, 0.15096600E+04, 0.44584000E+03, 0.61722800E+03, -.38541700E+02, 0.17348500E+04, 0.38846400E+03, 0.27510900E+04, -.13387900E+04, -.99003800E+03, -.13856200E+04, -.40971600E+04, 0.35331300E+03, -.15184500E+04, -.12474000E+04, -.14770300E+04, 0.12670700E+04, 0.15744600E+04, 0.31844700E+04, -.15556900E+04, -.26172600E+04, -.15640300E+04, 0.44794400E+03, 0.13128800E+04, -.29938100E+04, -.27212700E+04, -.23431900E+04, 0.11096900E+04, 0.75650600E+04, 0.30539900E+04, -.14896400E+04, -.13997300E+03, -.15400200E+04, -.22622000E+04, -.99054100E+03, 0.54386800E+03, 0.18199200E+04, 0.14453100E+04, -.51091200E+03, -.73555800E+03, 0.31144600E+04, -.15530900E+04, -.50797200E+03, -.15733600E+04, 0.29177100E+03, 0.40550900E+02, -.47086400E+03, 0.92509700E+03, -.51712200E+03, 0.19945500E+03, -.23012300E+04, -.33050900E+02, 0.43053800E+03, 0.35053700E+03, -.75367300E+01, 0.32071500E+03, -.47963600E+02, -.13259900E+03, -.30860300E+03, 0.89453100E+03, -.10678800E+04, 0.19354400E+03, 0.77018300E+03, -.15604100E+03, -.48026800E+03, 0.22211900E+03, 0.17968800E+03, -.34230300E+01, 0.16665100E+03, 0.55567600E+03, -.26586500E+02, 0.44127400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20036200E+00, -.11695500E+01, -.82411300E+00, -.48893600E+00, -.84468800E+00, -.12561300E+00, 0.93117400E-01, 0.48644500E-02, 0.58385300E+00, 0.96007700E+00, 0.10181000E+00, -.12639000E+00, 0.84548500E+00, 0.43390000E+00, 0.46426400E+00, 0.28121400E+00, -.17834400E+00, -.29265000E-01, -.56196300E+00, 0.78408900E-01, 0.81926300E-01, -.23571100E-01, 0.92425200E+00, 0.41463600E-01, 0.10982500E+00, 0.61395900E-03, 0.13038300E+00, -.51301400E-01, 0.45753100E+00, 0.20674500E+00, -.22823400E+00, 0.86783200E-01, -.14698900E+00, -.13485700E-01, -.63030500E+00, 0.43922300E-01, 0.17733500E-01, -.81787000E-01, -.85734700E-01, -.91530500E+00, 0.95400000E+00, 0.50836800E+00, -.11534600E+00, -.68428600E-01, -.49934600E+00, 0.32112700E+00, -.13393700E+00, 0.51858100E-02, 0.51806400E+00, 0.56017100E-02, 0.15309100E-02, -.29008500E+00, -.13536500E+00, -.31874300E-01, -.22907500E+00, -.54396500E-02, 0.24014300E+00, -.29904800E+00, -.34258200E-01, 0.49829400E-01, 0.14970700E+00, 0.30287200E-01, -.50796200E+00, -.10798000E+00, 0.48543000E+00, -.20007000E+00, 0.48389600E-01, -.27122800E+00, -.32536300E+00, -.36405200E-01, -.90608300E-01, 0.18845200E+00, -.15312800E+00, -.19856300E+00, -.14216600E+00, -.44966600E+00, 0.31076400E+00, -.37949800E+00, -.67176700E-01, -.67889700E-01, -.29350700E-01, -.13670200E+00, -.56752000E+00, -.50900400E+00, -.24951500E+00, 0.13020900E+01, -.66277500E+00, -.21981500E-01, -.14738500E+04, 0.73044800E+03, 0.30527800E+03, 0.73631800E+03, -.43200700E+01, -.50067400E+02, 0.39240000E+03, 0.12235800E+03, 0.47207900E+03, -.12786800E+03, 0.66694900E+03, 0.19095300E+03, -.94631500E+02, -.96395800E+03, -.96633300E+02, -.17998300E+03, -.88281900E+02, 0.18221500E+03, 0.77464900E+03, 0.63121200E+02, -.16419100E+03, 0.32304200E+02, -.99940700E+03, 0.49788500E+03, -.20709300E+02, 0.50161800E+03, 0.34545500E+03, -.45387700E+02, -.37012200E+02, -.11071600E+04, -.18261600E+02, 0.12925500E+03, 0.40863900E+03, -.26989100E+03, 0.13589900E+03, 0.12025900E+03, 0.13903100E+03, -.32222300E+03, -.47740500E+03, 0.19640000E+03, -.15618300E+02, 0.29573600E+03, -.33664600E+03, 0.24110900E+03, 0.49653700E+03, -.24123000E+03, 0.24284600E+03, -.25460800E+03, -.62379400E+00, -.10821500E+02, -.14148000E+03, 0.15775100E+02, -.76219000E+02, 0.27945800E+02, -.16712000E+03, 0.97820200E+02, -.42950400E+02, 0.11684100E+03, -.48297200E+02, -.20123700E+02, -.21113300E+02, -.42265000E+02, -.46544000E+01, -.26049800E+02, -.26818500E+02, -.35566600E+02, -.28663800E+03, 0.14295800E+03, 0.30044500E+03, 0.14433300E+03, 0.50380000E+03, 0.50820200E+03, -.62510200E+02, 0.26054900E+03, -.20465500E+03, 0.32719100E+03, 0.12318900E+03, -.48143800E+03, 0.23867200E+03, 0.63184700E+03, 0.23890400E+03, 0.16729100E+03, 0.13243300E+03, 0.64455900E+02, 0.21624600E+03, 0.98574700E+02, 0.15060700E+03, 0.14111200E+03, 0.44571000E+03, -.22115500E+03, -.10568300E+03, -.22420600E+03, -.19898400E+03, 0.35536600E+01, -.35120500E+02, 0.34841700E+03, -.19983500E+03, 0.82166800E+02, -.52365900E+03, 0.66133100E+03, -.32978800E+03, -.62230100E+03, -.32716100E+03, -.11885000E+03, -.20531200E+02, -.21543800E+03, -.16934300E+02, -.15522200E+03, 0.10337700E+02, -.24292900E+03, 0.60093200E+03, -.29811400E+03, -.99007800E+02, -.30151600E+03, -.57167200E+02, -.26040200E+02, 0.89076400E+01, 0.30312700E+03, -.17493500E+03, 0.17064300E+02, -.62842600E+03, 0.44903200E+01, -.14872000E+01, 0.80831100E+02, -.31284000E+01, 0.10952200E+03, 0.78348500E+02, -.10944700E+03, -.12457200E+02, -.40777300E+02, 0.69281900E+02, -.78611400E+02, -.81669200E+01, 0.15934200E+02, 0.83543300E+01, -.11457900E+01, -.18448200E+02, 0.20864200E+01, -.23255800E+02, 0.20034800E+02, -.20892000E+01, 0.92688800E+02, 0.14433900E+02, 0.15359300E+02, 0.44477600E+02, 0.30197200E+02, 0.12485600E+02, -.25092300E+02, 0.15886700E+00, 0.28292400E+02, -.10354900E+02, 0.19047200E+02, 0.27609500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11274700E+00, 0.26653800E+00, -.28070400E+00, 0.46718500E+00, 0.11543000E+01, -.14054200E-01, -.15223400E+00, -.44962100E-01, -.11015400E+01, -.10802200E+01, 0.11579800E+00, 0.11801300E+00, -.14336600E+01, 0.66375700E-01, 0.23161300E-01, -.19164800E-01, -.34712000E+00, 0.79826800E-02, -.10408100E-01, -.61529000E-02, 0.59385200E-03, -.37537800E-01, -.88563400E-01, 0.36263300E-01, 0.39894100E-01, -.64942000E-03, 0.99744600E-03, 0.21567700E-01, -.11043200E+00, 0.81703400E-01, -.86802800E-01, 0.18782400E+00, -.10104400E+00, 0.24161400E+00, -.46497600E+00, -.32789200E-01, 0.40666700E-01, 0.10269300E+00, -.70681200E-01, -.20547600E+00, 0.35815600E+00, -.10691700E+00, -.10878700E-01, 0.71578100E-02, -.59334600E+00, 0.75582500E-01, -.43684300E-01, 0.13248200E-02, 0.25957100E-01, 0.11785700E+00, 0.24470600E-01, 0.12279700E+00, 0.44062400E+00, 0.52929000E-02, 0.35126800E+00, -.41966300E-01, -.95181500E-01, -.26466000E+00, 0.34484600E-01, -.36000600E-01, 0.15529800E-01, 0.65829100E-01, -.14081200E+00, -.93769900E-02, 0.11162300E+00, 0.72455700E-01, 0.19542500E-01, 0.30246300E+01, -.50763200E-01, -.68146400E-02, 0.16825800E+00, 0.27690400E+00, 0.78431800E-01, 0.10927200E-01, 0.95316800E-01, 0.66674500E+00, -.41490000E+00, 0.14848300E+00, 0.12722900E-01, 0.10289100E+00, 0.46502000E-01, 0.50897700E+00, 0.90592800E-01, -.14578800E-01, 0.32949500E+00, -.12051600E+00, 0.27329800E+00, -.34815900E-01, -.21257100E+00, 0.14356700E+02, -.53308800E+02, -.80626000E+00, -.11020000E+03, -.23448800E+03, 0.56689500E+02, -.83270300E+02, 0.39904300E+02, -.16803800E+03, -.45534800E+02, -.62066500E+02, 0.45523800E+02, -.51440900E+03, 0.30123600E+02, 0.12078200E+01, -.10358600E+03, -.68266900E+02, -.21102500E+03, 0.11133900E+03, -.64997300E+02, 0.32509400E+03, -.34395200E+03, 0.14838600E+03, -.12477000E+03, 0.17375200E+03, -.37935700E+02, -.22579100E+03, 0.36792800E+02, -.25095200E+03, 0.12449400E+03, -.14423100E+03, -.39021400E+02, 0.26604800E+03, -.14344100E+03, 0.85362200E+02, -.12956500E+03, -.29988700E+02, -.26001700E+02, -.46114200E+02, 0.10479100E+03, -.17481000E+03, -.33665100E+01, -.18060600E+03, 0.12298000E+03, -.75728300E+02, 0.18354300E+03, -.66739400E+02, 0.10888400E+03, 0.29921200E+03, -.11942600E+03, 0.76002500E+02, -.58865700E+02, 0.23195900E+03, -.26669700E+02, -.17235900E+02, 0.71265700E+01, 0.47698300E+02, 0.93833200E+01, 0.16485800E+02, 0.36123400E+02, 0.39229700E+02, 0.22569000E+02, 0.48416000E+01, 0.28797500E+02, -.30838400E+02, 0.30774000E+03, -.14287300E+03, 0.18209800E+03, -.15346000E+03, 0.42208300E+02, 0.28495100E+02, -.83344500E+02, -.13653900E+03, -.70066600E+02, 0.16312200E+02, -.10924500E+03, 0.89912400E+02, -.43442000E+02, 0.45914000E+03, -.47128900E+02, 0.12160900E+03, 0.10448100E+03, 0.59687600E+02, 0.16974000E+03, -.10217600E+03, 0.10390000E+03, -.22920800E+03, 0.17700800E+03, -.65636700E+02, -.12129300E+03, -.89893200E+02, -.11903600E+03, 0.39750700E+02, -.12724100E+03, -.13757400E+03, -.42559000E+02, 0.77101400E+02, -.29807500E+03, 0.16517300E+03, -.83899000E+02, -.59554500E+02, -.79813200E+02, 0.30011900E+02, 0.65332800E+02, -.49651300E+02, 0.14215500E+02, -.13085900E+03, 0.52810900E+02, -.68178800E+02, 0.57566400E+01, 0.18062300E+02, 0.81689000E+02, -.39963000E+01, -.60374200E+02, -.18441400E+01, 0.34357800E+01, -.30384000E+02, 0.66693700E+02, 0.54700800E+01, -.20636400E+03, 0.35845500E+02, -.78028100E+01, 0.22261300E+02, -.18949900E+02, 0.31728800E+02, -.46161500E+02, 0.63217600E+02, 0.94008200E+02, 0.28184000E+02, -.32316400E+02, -.13102400E+03, -.32891300E+01, 0.15940800E+02, 0.11867800E+02, -.39199400E+00, 0.18757500E+02, 0.24777100E+01, -.10050700E+02, -.19772300E+02, 0.56212300E+01, -.71532400E+02, -.15432500E+02, 0.39084800E+02, 0.78608300E+01, -.21949200E+02, 0.11212600E+02, 0.54415100E+02, 0.73558500E+01, 0.88193300E+01, 0.54959400E+01, 0.10612600E+02, 0.99652800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54561400E-01, -.17993900E+00, -.18679500E+00, -.24861600E+00, -.44083900E+00, 0.11783000E+00, -.13616300E+00, 0.72746300E-01, 0.22980100E+00, 0.21158600E+00, -.19661200E-01, 0.10734800E-01, 0.36330100E+00, -.20903700E+00, -.12259100E+00, -.35808600E-01, 0.21433300E+00, 0.52410400E-01, -.22896100E-01, -.11769100E+00, -.24687500E-01, 0.41829200E-02, 0.18408200E+00, -.10802100E-01, -.60707800E-02, 0.38049900E-03, 0.37686600E-01, -.46688000E-01, 0.23021500E+00, -.15153500E+00, -.44715600E-02, -.26100400E+00, 0.63871500E-01, -.85134400E-01, 0.84227500E-01, 0.21931300E-01, -.55361000E-03, -.17284200E-01, -.97570000E-03, 0.14315600E+00, -.19781500E+00, -.96655800E-01, 0.63825600E-01, 0.76096300E-01, -.47208100E-01, -.84405200E-01, -.92304800E-01, -.16051400E-02, 0.26627400E-01, -.13496300E-01, -.11064400E+00, -.84230100E-02, 0.28767300E-01, 0.38250600E-01, 0.25835500E-01, -.25264300E-01, -.68899900E-01, -.71078600E-02, 0.22429600E-01, 0.53997400E-01, 0.55165700E-01, -.94367200E-01, 0.15083600E+00, 0.11485500E-01, 0.85220100E-01, -.34003600E-01, -.38864400E-01, -.29716900E+00, 0.85245800E-02, 0.12329000E-01, -.54646800E-01, -.14238600E-01, -.24307200E-01, -.52560600E-01, 0.24147800E-01, 0.17129700E+00, 0.10466400E-01, 0.11186700E+00, 0.10563500E-01, 0.17815600E-01, -.24579600E-02, 0.12417500E+00, 0.11207300E+00, 0.48936600E-01, 0.70312600E-02, -.35985100E+00, 0.18771700E+00, -.61236300E-02, -.16254900E-01, -.17491000E+00, 0.16855500E+03, -.20543500E+00, 0.46712000E+00, 0.21340600E+00, 0.30296700E-01, 0.31907900E+00, 0.20488600E+02, 0.12543600E+02, -.25307500E+02, -.39214300E+02, 0.21870300E+02, 0.12867600E+03, 0.19603600E+02, -.34309800E+02, -.28668600E+02, 0.29493100E+01, -.40336800E+02, 0.35982500E+02, -.10450700E+02, -.98721300E+02, 0.43768300E+02, -.25918700E+02, 0.26116800E+02, -.21835500E+02, -.45647800E+01, 0.17185400E+02, -.34419300E+02, 0.95242300E+02, 0.31236300E+02, -.24370900E+02, 0.24025800E+02, 0.31585200E+02, -.17171100E+02, -.17903700E+02, -.15553600E+02, 0.29565500E+02, 0.58267900E+02, -.36959100E+02, -.54829800E+00, -.16299500E+02, 0.41030100E+02, -.52544800E+02, -.78925500E+01, 0.49643400E+01, -.14783600E+03, 0.25959700E+01, 0.28382500E+02, 0.34922500E+02, -.32456400E+02, -.27756500E+02, -.26551400E+02, 0.20006200E+02, 0.49554400E+01, 0.27955300E+02, -.10361300E+02, -.24903500E+02, -.13309800E+02, 0.73883100E+01, 0.60105700E+00, 0.72212800E+01, -.31208000E+01, -.16894100E+02, 0.28672200E+01, -.27514400E+02, -.37003800E+02, 0.20577000E+02, 0.47063700E+02, 0.18294100E+02, -.70694700E+01, -.12868700E+02, 0.11717300E+02, -.18433300E+02, 0.25834300E+02, -.96986700E+01, 0.28587900E+02, 0.11251000E+03, -.56628600E+02, -.53212700E+02, -.56828700E+02, 0.19829700E+02, -.10323800E+02, 0.50198400E+01, 0.10028500E+02, -.43123800E+02, -.74009500E+01, -.49793900E+02, 0.52509300E+01, 0.10792100E+01, 0.50207100E+02, -.26073400E+01, 0.72135100E+02, -.71973500E+01, 0.16809700E+01, -.54429200E+01, 0.75143400E+01, 0.41873300E+01, 0.79649900E+02, -.68248600E+02, 0.33200700E+02, 0.73287100E+02, 0.34943700E+02, 0.39880600E+01, -.28617300E+01, 0.30087900E+02, 0.15218800E+01, -.19340900E+01, 0.22789000E+01, 0.26854700E+02, -.12786200E+03, 0.67361000E+02, 0.55729000E+02, 0.63906800E+02, 0.57925600E+02, 0.10335700E+02, 0.23165100E+02, -.30890800E+02, 0.50706700E+00, 0.14385100E+02, 0.68926200E+02, -.21263600E+02, 0.12245800E+02, -.18827800E+01, 0.10474100E+02, -.65869000E+01, -.18047700E+02, 0.27110800E+02, -.94131500E+01, -.22266000E+01, -.12565600E+02, 0.16838000E+02, 0.43718700E+00, 0.12441900E+01, 0.16550400E+02, -.66566000E-01, 0.46604400E+01, 0.78843800E+00, -.11330100E+00, -.52966500E+01, -.66089900E+00, 0.24497700E+01, -.12400300E+02, -.65666400E+01, -.41368800E+01, -.20246200E+01, 0.17107400E+02, 0.33490000E+01, -.20107700E+01, -.60525600E+01, 0.13399700E+01, 0.40133400E+01, 0.30659900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.63321100E+00, -.76512400E+00, -.45975700E+01, -.34019800E+01, -.58477200E+01, 0.33474900E+01, -.61389000E+01, 0.96794400E+00, -.26241600E+00, 0.39586800E+00, 0.14303300E+00, 0.75336900E-01, 0.15857000E+01, 0.69892900E-01, -.21696400E+00, 0.74259100E+00, -.17739100E+01, -.11521800E-02, -.12834200E+01, 0.33306300E+00, 0.23107700E-01, -.14635800E+00, 0.26252300E+00, -.12568100E-01, -.23562500E+00, 0.14342300E-02, -.22531500E-01, -.26579300E+00, 0.92709100E+00, 0.37521200E+00, -.29317500E+00, -.44596500E-01, 0.23865700E+00, -.64112100E+00, 0.16552400E+00, 0.15153300E+00, -.38832800E+00, -.39296300E+00, 0.43144600E+00, 0.13044300E+01, -.17980800E+00, -.23842400E+00, 0.10176200E+00, -.30901500E+00, 0.36667100E+01, -.51765500E+00, -.25766400E+01, 0.27256800E+00, 0.15861800E+01, -.92172800E+00, 0.19232700E+00, -.40427500E+00, 0.46327700E+00, -.14173800E+00, -.15634400E+01, -.39839900E+00, 0.11372500E+01, -.22253200E+00, -.26424900E+00, -.26523100E+00, 0.14549700E+00, 0.13024700E+01, 0.35844800E+00, -.11104800E+00, -.94789700E+00, -.37743600E+00, 0.52318100E+00, -.36894800E+01, 0.20836300E+00, -.35671200E+00, 0.23848100E+00, -.23775300E+00, 0.16854000E+00, 0.14752300E+00, 0.88743700E-01, -.29941900E+01, 0.10247100E+01, -.28676500E+01, 0.52010600E-01, -.17606000E+00, -.18391600E+00, -.30044200E+00, -.60343700E+00, -.67119700E+00, -.70260000E+00, 0.31365400E+01, -.20382000E+01, 0.15467700E+00, 0.13535500E+01, 0.37411200E+00, -.36019100E+01, 0.31527500E+02, 0.16803100E+03, 0.18752100E+03, -.21899800E+03, -.21974600E+03, -.12232400E+03, 0.26986700E+03, 0.33363200E+03, -.16909700E+02, 0.10562400E+02, 0.85003500E+03, 0.10114900E+02, 0.24356800E+03, 0.27479900E+03, -.10753500E+03, -.23743400E+03, -.22769000E+03, 0.31626600E+03, -.87083900E+03, 0.44557900E+03, -.22684100E+03, 0.27172000E+03, -.22867400E+03, -.17502300E+03, 0.33672700E+03, -.76613700E+02, 0.91759900E+03, -.49326900E+02, 0.13933900E+03, 0.16677900E+03, 0.27477900E+03, -.13930100E+03, -.21850100E+03, -.14342400E+03, 0.28714300E+03, 0.44508600E+03, -.15850500E+03, 0.29415200E+02, -.71964000E+02, 0.29729400E+03, -.32885300E+03, -.17908100E+03, 0.91400500E+02, -.29254100E+03, 0.82696100E+02, -.34604500E+02, -.11795300E+03, 0.12686900E+03, -.10093400E+02, 0.35174200E+02, -.15652100E+03, -.37073400E+03, -.43703800E+02, 0.30325600E+02, -.75618500E+02, 0.24635400E+02, 0.30156600E+02, -.16818800E+02, 0.39689100E+02, -.41535900E+02, -.33583400E+02, 0.42383800E+01, -.87968300E+02, -.40389700E+03, 0.20546400E+03, -.31449000E+03, 0.20281300E+03, -.29762900E+03, -.33121800E+03, 0.15149200E+03, -.13641300E+03, 0.19068300E+03, -.18751900E+03, 0.48602900E+03, 0.11316200E+03, -.57552900E+02, -.78332400E+03, -.51725300E+02, -.18703300E+03, -.19173000E+03, -.14127800E+02, -.22403700E+03, 0.15967400E+03, -.22424600E+03, 0.10458800E+03, -.13173800E+04, 0.66184000E+03, 0.73178200E+03, 0.66102400E+03, 0.37042000E+03, -.25059300E+03, 0.41469800E+03, 0.59838900E+02, 0.47003700E+03, -.27507100E+03, 0.73867000E+03, -.59909500E+03, 0.29592200E+03, 0.55683000E+03, 0.30583000E+03, -.19497500E+02, -.10261300E+03, 0.33159600E+03, 0.14451400E+03, 0.30011600E+03, -.10677300E+03, 0.24030900E+03, -.52528800E+03, 0.26549400E+03, 0.48749300E+01, 0.26791000E+03, 0.20021800E+03, -.22922800E+02, 0.10438800E+03, -.14390400E+02, 0.92905200E+02, -.40528800E+02, 0.28317600E+03, -.33947800E+02, 0.18025000E+02, -.51791400E+01, 0.20644700E+02, -.10584400E+03, 0.14669600E+02, 0.73677300E+02, -.32422300E+02, 0.23946100E+02, -.71199600E+00, 0.19830100E+03, 0.14472100E+02, -.38297000E+02, 0.54487600E+02, 0.15696800E+01, 0.18728300E+02, 0.12466500E+01, 0.28833200E+02, -.22417300E+02, -.44884300E+02, -.32533600E+02, 0.89184300E+01, -.65533800E+02, -.33984300E+02, -.34273700E+02, 0.58506400E+02, -.24498000E+02, 0.85576500E+01, -.72827100E+02, -.13596700E+02, -.18170600E+02, -.12316700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16151300E+00, -.84329800E+00, -.49944600E+00, 0.57435200E-01, 0.94307300E-01, -.73062200E+00, 0.95654200E+00, -.13352100E+00, 0.11007700E+01, 0.11442000E+01, -.54732100E-02, -.20116300E-01, 0.10376400E+01, 0.22262600E+00, 0.39735700E+00, 0.16251400E+00, 0.48961200E+00, -.85407700E-01, -.31374800E+00, 0.58448000E+00, 0.28051400E-01, 0.20959100E-01, 0.22670300E+00, 0.50787000E-01, -.10515100E+00, -.86110900E-04, 0.53949300E-01, -.97358300E-01, 0.42546700E+00, -.35151900E+00, -.36130300E+00, -.20621300E+00, -.36533100E+00, -.59041200E+00, 0.85885200E+00, -.55424300E-02, -.35592200E-03, -.21739600E+00, -.25878300E+00, 0.29960500E+00, -.59308500E+00, -.89460700E+00, 0.15811100E+00, -.22827300E+00, 0.17892500E+01, -.47409300E+00, -.32286300E+00, -.32044100E-01, 0.82973000E+00, 0.23926300E+00, -.17056800E+00, 0.21945300E+00, 0.64781400E+00, 0.18021800E-01, -.72528400E+00, -.16030100E+00, 0.37426100E+00, -.26626100E+00, 0.10220700E+00, -.18062400E+00, 0.60415300E-01, -.37295500E+00, 0.13612000E+01, 0.12351800E+00, 0.13767200E-01, 0.21462500E+00, 0.20242400E+00, 0.30743000E+01, 0.41277600E-01, -.19766000E-01, 0.13888700E+00, -.16377900E+00, 0.83455400E-01, 0.15604600E+00, 0.45254300E+00, -.96487800E+00, -.92589200E+00, 0.34321600E+00, -.99116500E-01, 0.19384500E+00, -.20982400E-01, 0.53181700E+00, -.30563600E+00, -.38617900E+00, -.42580300E+00, -.90831400E-01, 0.44140300E+00, -.10756000E+00, 0.56491400E+00, 0.85976800E+00, -.45151100E-01, -.22293000E-01, 0.25192000E+03, 0.33596400E+03, -.16100800E+03, -.16511500E+03, -.13619800E+03, 0.30811500E+03, 0.22706400E+03, -.89679100E+02, 0.39421700E+02, 0.89054500E+03, 0.44836300E+02, 0.26453300E+03, 0.16903900E+03, 0.23445500E+02, 0.63232800E+02, -.15325800E+03, 0.11402600E+03, -.69275200E+03, 0.56960300E+03, -.27417300E+03, 0.23771300E+03, -.28436300E+03, 0.94895400E+01, 0.43556400E+03, -.16470300E+03, 0.47832200E+03, -.27720500E+03, 0.28787300E+03, 0.10486200E+03, -.33945900E+03, 0.17497700E+03, -.18291600E+03, 0.17058300E+03, 0.11895500E+03, 0.11529100E+03, 0.79368200E+02, -.68316400E+02, 0.19294700E+03, 0.55134900E+02, 0.13690600E+03, -.20192400E+02, 0.91498400E+01, -.24228100E+03, 0.63973700E+01, -.21477700E+03, -.37891000E+03, 0.15652000E+03, 0.66001400E+02, 0.53592700E+02, -.33663400E+03, -.29014000E+03, -.20815500E+02, 0.48290800E+01, -.31656400E+02, 0.11156400E+02, -.20764600E+02, -.47502000E+02, -.20966500E+01, -.45539200E+02, -.16540100E+02, -.34874200E+02, -.21377300E+02, -.32415900E+03, 0.15790500E+03, -.42798800E+03, 0.16108800E+03, -.25053200E+03, -.22235700E+03, 0.70479800E+02, -.75107500E+02, 0.14538200E+03, -.12944200E+03, 0.31886400E+03, -.88428200E+01, 0.43146400E+01, -.73603100E+03, 0.21747600E+01, -.28220300E+03, -.24720000E+03, -.21463800E+02, -.20098000E+03, 0.20451600E+03, -.23035300E+03, 0.19131900E+03, -.58431400E+03, 0.28303100E+03, 0.17673500E+03, 0.29227300E+03, 0.22022700E+03, -.63204800E+02, 0.18365600E+03, 0.31500900E+02, 0.17742900E+03, -.12814100E+03, 0.28466500E+03, -.29993200E+03, 0.15132200E+03, 0.17301700E+03, 0.15189600E+03, -.28866100E+02, -.12235700E+03, 0.17940600E+03, 0.52464800E+02, 0.22994200E+03, -.87962800E+02, 0.89292500E+02, -.11689400E+03, 0.49628700E+02, -.98834300E+02, 0.58032600E+02, 0.42494600E+02, -.39508300E+02, -.25127000E+01, 0.75469200E+02, 0.29083000E+02, -.49057600E+02, 0.95834200E+01, -.46155200E+02, 0.17809500E+02, -.38113100E+02, 0.22299600E+02, -.10992900E+03, 0.21052000E+02, -.26554100E+02, -.89720300E+02, 0.10099600E+02, 0.15647000E+02, 0.17586100E+03, 0.11062700E+02, -.22618700E+02, -.32531500E+02, 0.16868800E+01, -.16273800E+02, -.97152300E+01, 0.14615700E+02, 0.15559600E+02, -.27570700E+02, 0.21598600E+02, 0.32595200E+01, -.67181800E+02, -.20548400E+02, 0.16681400E+02, -.21209800E+02, -.39692800E+02, -.13235100E+02, -.14456300E+02, -.15506500E+02, -.12834000E+02, -.13540900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36563300E+00, 0.41570700E+00, -.28659700E+01, 0.98800500E+00, 0.12462900E+01, -.85366800E+00, 0.20920500E+01, -.25165800E+00, 0.62689000E+00, 0.16509500E+01, 0.18689500E+01, -.44293900E+00, 0.20320900E+01, 0.99846100E+00, -.32434800E+00, 0.28080500E+00, 0.27960000E+01, -.34105600E+00, -.16780100E+01, 0.17754600E+01, 0.36823400E+00, -.82774600E-01, -.52006400E+00, -.26430300E-01, -.35717500E-01, -.68235600E-03, -.80516300E-01, -.48511400E+00, -.23609400E+00, -.21773000E+00, 0.31250100E+00, -.32722300E+00, 0.11949100E+00, 0.19433200E+00, -.31034600E+00, -.21977100E-02, 0.32889700E-01, 0.15026500E+00, -.95504400E-01, -.98035200E+00, 0.80134200E+00, -.58143200E-01, -.16313400E+00, -.88380200E-02, -.69486200E+00, 0.17772100E+00, 0.85831200E+00, 0.39549100E-01, -.41714300E+00, 0.10451300E+01, 0.49171000E-01, 0.68261100E+00, 0.14226800E+00, 0.31415400E-01, 0.28560600E+01, -.23779400E+00, -.52731800E+00, -.71094900E+00, 0.23776100E+00, 0.25641500E+00, -.32604900E+00, 0.50344200E+00, -.33136900E+01, 0.43356700E-01, 0.96144600E+00, 0.24688800E+00, -.11455600E+00, -.30231700E+01, 0.60544900E-01, 0.37081900E-01, -.12223800E+00, -.57272900E+00, -.16016600E+00, 0.23323100E+00, -.44279700E+00, 0.26752900E+00, 0.20386600E+01, -.21788200E+01, 0.28613600E-01, -.55242300E+00, 0.62828600E-02, -.11491900E+01, 0.18856400E+00, -.51515700E+00, -.44076300E+00, 0.22195500E+01, -.13758400E+01, 0.71482300E-01, -.72647000E+00, 0.13326600E+01, 0.23215300E+01, 0.76289200E-01, 0.36367700E+00, 0.54950300E+03, -.57079800E+03, -.93779300E+02, -.16855000E+03, 0.38553000E+03, 0.84886500E+03, -.60360600E+03, 0.30727400E+03, 0.20356800E+03, 0.30423400E+03, 0.20439500E+03, -.29806100E+03, 0.18646300E+03, 0.48851500E+03, 0.35183400E+02, -.28806100E+03, -.13152300E+04, -.10029000E+04, 0.49538700E+03, 0.30624200E+03, 0.49630800E+03, 0.10611300E+03, 0.84405000E+03, -.44977200E+03, -.15860400E+04, -.66917700E+03, 0.90818500E+03, 0.11587300E+04, 0.20743700E+04, -.10356400E+04, -.11012200E+04, -.10470200E+04, -.57885900E+03, -.62673000E+03, 0.13197500E+03, 0.39838200E+03, 0.12697000E+03, -.54412700E+03, -.58048400E+03, -.23055200E+03, 0.11344300E+03, 0.25827100E+03, 0.13186500E+03, 0.91811600E+02, -.47142800E+03, 0.58000700E+03, 0.22372500E+03, 0.28842300E+03, -.29661600E+03, -.93665000E+03, -.16131700E+03, 0.66350100E+02, 0.81646700E+02, 0.77679700E+02, -.27938300E+02, -.50220200E+01, -.13523300E+02, 0.51843800E+02, 0.56041700E+02, -.23256400E+02, 0.86202000E+02, -.66249000E+03, 0.33328000E+03, 0.41882400E+03, 0.33093800E+03, 0.35500200E+03, 0.28482800E+03, -.24785000E+03, 0.48366600E+02, -.17417500E+03, 0.22267400E+03, 0.77770200E+03, 0.12664200E+04, -.63433900E+03, -.68382800E+03, -.62576700E+03, -.72855300E+01, 0.62783300E+02, -.31245900E+03, 0.18091200E+03, -.30842600E+03, 0.54230600E+02, -.56450800E+03, 0.95075300E+03, -.46691500E+03, -.52482700E+03, -.47243900E+03, -.23640400E+02, 0.31869800E+03, -.43627200E+03, 0.28082900E+03, -.81874000E+03, 0.37951400E+03, -.22421000E+04, 0.15129400E+04, -.74495000E+03, -.77655100E+03, -.76488400E+03, -.17765500E+03, 0.13900200E+02, -.24421300E+03, 0.22823200E+03, -.19167700E+03, -.28968900E+02, -.73980300E+03, -.72541600E+03, 0.37093700E+03, 0.30595900E+03, 0.36609600E+03, 0.77687000E+02, 0.10139200E+03, -.29834600E+02, -.25795100E+03, -.52621100E+03, 0.14067300E+03, -.12415500E+04, -.18223500E+02, 0.10564500E+02, 0.50037400E+02, 0.12472500E+02, 0.10292400E+03, 0.13371300E+03, -.26268600E+03, -.14094400E+03, -.21042100E+03, 0.94122700E+02, 0.10121900E+03, 0.21428900E+02, -.40508700E+02, 0.17931800E+03, 0.53017800E+01, 0.10788500E+03, 0.45671900E+01, -.11706100E+02, -.10630700E+03, -.61424800E+02, -.13427300E+03, -.90150800E+02, -.81152500E+02, 0.47117400E+02, -.26754000E+03, 0.17014700E+03, -.60284000E+02, 0.16469700E+02, -.30239700E+02, -.43213200E+02, 0.89603400E+02, -.83395400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.47935100E+00, 0.33712600E+01, 0.54357500E+01, 0.22420500E+01, -.15474500E+01, 0.26916600E+01, -.25739000E+01, 0.56981500E-01, -.25351000E+01, -.22109700E+01, 0.20977400E-01, 0.24418200E+00, -.39130900E+00, 0.93797900E+00, 0.61907600E+00, -.19518600E+01, 0.13869200E+01, -.13363200E-01, 0.23385500E-01, -.19074100E+01, -.15766600E+00, -.58625300E+00, -.11208400E+01, 0.59347600E+00, 0.83251800E-01, 0.65813500E-02, -.15944200E+00, -.50383000E+00, 0.10733700E-01, -.20773700E+00, 0.65600900E-01, 0.70680500E-01, 0.17610700E+00, 0.20887000E+01, 0.17986600E+01, 0.23584200E+00, -.18730500E+00, -.23706700E-01, 0.67326000E+00, 0.65077500E+00, 0.27731800E+00, 0.51650800E+00, 0.27590300E+00, 0.31097200E+00, -.30865300E+01, 0.94183400E-01, 0.14126300E+01, 0.18060900E-01, 0.51773100E+00, 0.58594800E+00, -.59807900E+00, 0.49698900E+00, 0.99736200E-02, -.46666700E+00, -.23156100E+01, 0.36103500E+00, 0.21675400E+01, 0.56460400E+00, -.72689100E-01, 0.47662000E+00, -.45138100E+00, -.12087200E+01, 0.29554400E+01, 0.77861300E-01, 0.13627300E+00, -.36664400E+00, 0.26917500E+00, 0.16477800E+02, 0.37766000E-01, -.79551800E-01, 0.64550800E+00, 0.21216200E+01, -.18481300E+00, -.36949100E+00, 0.27158900E+00, 0.10309200E+01, 0.53072400E+00, -.41709800E+01, 0.10271300E+00, 0.13315600E+00, 0.10581500E+00, 0.24726400E+01, 0.12188200E-01, 0.99088600E+00, -.96670300E-01, 0.11567600E+00, 0.50892200E+00, -.36429200E+00, 0.58022100E+00, 0.13154100E+01, 0.92964200E+01, -.36416600E-01, 0.93265600E+00, 0.97786500E+00, 0.55565200E+03, 0.90972000E+02, -.26832500E+03, -.66585200E+02, -.16482800E+04, 0.78716200E+03, -.39918000E+03, 0.18927400E+03, -.39395100E+03, 0.33592400E+03, 0.24186900E+03, -.47375100E+03, -.68548500E+03, -.45925500E+03, -.73264600E+01, 0.23149300E+04, 0.26713700E+04, -.13367700E+04, -.71754700E+03, -.13323300E+04, -.50181500E+03, -.96949700E+03, 0.10358400E+04, 0.14319500E+04, 0.33298800E+03, -.96391800E+03, -.19844000E+04, -.35697400E+03, 0.16677800E+03, 0.75341200E+03, 0.18289000E+03, 0.26530700E+03, 0.36029800E+02, -.12199400E+03, 0.24646500E+03, -.37010100E+03, 0.82953800E+02, 0.79958500E+03, 0.18584200E+04, -.92794700E+03, -.81209700E+03, -.93910300E+03, -.48513100E+03, -.32787100E+03, -.49156000E+03, 0.37089200E+03, -.36671800E+03, -.30263400E+03, 0.11437600E+04, 0.59119500E+03, -.29285500E+03, -.30296500E+03, -.29460000E+03, -.10324100E+03, -.44089800E+02, -.10183800E+03, 0.67865400E+02, -.19050200E+02, -.33766100E+02, -.16449800E+03, 0.53713900E+03, -.26563300E+03, 0.50781500E+03, -.27274100E+03, -.64719200E+03, -.18518000E+03, 0.94397500E+02, -.13366500E+03, -.19289700E+03, -.10392200E+03, -.20033600E+04, -.99089900E+03, 0.49950600E+03, 0.44658000E+03, 0.48598100E+03, -.35175400E+03, -.37790900E+02, -.16351900E+03, -.13266800E+03, -.24064700E+03, 0.84439800E+02, 0.50423500E+03, 0.20305200E+04, -.10213300E+04, -.17230400E+04, -.10161600E+04, -.74845200E+03, 0.54685700E+03, -.48475700E+03, 0.73861300E+02, -.62213700E+03, 0.15685000E+03, 0.13709500E+04, -.10112000E+04, 0.49087500E+03, 0.30815700E+03, 0.50934900E+03, 0.37545100E+03, 0.80773400E+02, -.19637200E+02, -.17558800E+03, 0.33724300E+02, 0.12607200E+03, 0.49479000E+03, 0.19432900E+04, -.97931300E+03, -.57214900E+03, -.97487900E+03, -.50885700E+03, 0.29724900E+03, -.75046000E+03, -.22726800E+01, -.38128700E+03, 0.13479500E+03, 0.91235900E+03, 0.99310200E+02, -.45573000E+02, -.19642600E+03, -.53634000E+02, -.20285400E+03, -.23037900E+03, -.13928500E+02, 0.13918700E+03, 0.27787300E+03, -.19597400E+03, -.28182500E+03, -.25087600E+02, 0.90952000E+02, -.16889600E+03, -.41306400E+01, 0.16747600E+02, -.57581400E+02, 0.18568600E+02, -.13864500E+02, 0.82352900E+02, 0.28475300E+03, 0.10012500E+03, 0.10799200E+03, 0.56374600E+02, 0.29159600E+03, -.12393100E+03, 0.65974000E+02, -.67115000E+02, 0.16762800E+03, 0.28183200E+02, -.98326900E+02, -.52830900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21962900E+00, -.25707200E+00, -.22928700E+01, -.63054500E+00, 0.78183200E+00, 0.42258800E+00, 0.10791400E+01, 0.16963400E+00, -.14319200E+01, -.85372400E+00, 0.22810900E+00, 0.32153900E+00, -.10718000E+01, 0.94096900E-01, -.49989900E+00, -.93373600E+00, 0.20927800E+01, 0.26517300E+00, -.74759200E+00, 0.74107100E+00, 0.72272500E-01, 0.31810900E+00, -.29853100E+00, -.17963800E+00, -.44808400E+00, 0.28968400E-03, -.35863000E+00, -.84054600E+00, 0.45749900E+00, -.40575700E+00, 0.78901900E+00, 0.13597400E+00, -.37478200E+00, -.15491200E+00, 0.64603000E+00, 0.13346900E+00, 0.45135800E-01, -.12938500E+00, -.18909700E+00, 0.20445000E-01, -.44077100E+00, -.38559400E-02, -.31352600E-01, -.10832300E+00, 0.14046600E+01, 0.35497100E-01, -.98069300E+00, 0.14131300E-01, 0.19247300E+00, -.14121700E+00, 0.25390900E+00, -.43395500E+00, -.16903000E+00, 0.18057900E+00, 0.57989400E+00, -.13317700E+00, -.70638800E+00, -.56234800E+00, -.35588600E-01, 0.54655300E-01, 0.35400000E+00, 0.31105900E+00, -.11025200E+01, 0.41349700E-01, 0.36375700E+00, -.48960400E-01, 0.51512900E-01, -.53168000E+01, -.14550100E+00, 0.12325100E-01, 0.42942300E-01, -.16305800E+00, -.24039900E-01, -.46628600E-01, -.56462200E+00, -.12805600E+00, -.47795200E-01, 0.19811300E+01, 0.45167700E-01, 0.10163000E+00, -.77127400E-02, -.23139400E+00, -.17256700E+00, -.91187500E+00, -.40939400E+00, 0.14618100E+01, -.24607100E+00, 0.11601600E+00, 0.15096400E+00, 0.10353500E+01, -.17518500E+01, 0.46871500E-01, 0.82907100E+00, -.83726200E-01, 0.20285500E+00, 0.35104400E+03, 0.31413000E+03, -.28367000E+02, 0.34819500E+03, 0.53182900E+02, -.23367900E+02, 0.43343600E+03, -.26823700E+02, -.13614300E+03, 0.49529900E+01, 0.12995500E+03, 0.36736300E+03, 0.10510400E+03, 0.84477800E+02, -.90178900E+03, -.24134800E+03, 0.11840100E+03, 0.28530200E+03, 0.11860800E+03, 0.21213200E+03, 0.44849100E+03, -.49107800E+03, 0.93799200E+01, -.16717800E+03, 0.29871100E+03, 0.49678800E+03, 0.29978000E+03, -.14855300E+03, -.42771900E+03, -.15223400E+03, -.39379600E+02, 0.11235100E+03, -.90377000E+02, -.90858900E+02, 0.88759500E+02, 0.89686400E+02, -.13744500E+03, -.52725800E+03, 0.26471700E+03, 0.37108600E+02, 0.27170000E+03, 0.17525000E+03, 0.28543400E+02, 0.31712600E+02, -.37819000E+03, -.39145500E+02, 0.74623300E+02, -.22198500E+03, -.50142800E+02, 0.25252400E+02, -.26837500E+02, 0.23495000E+02, 0.23528700E+01, -.57466800E+02, 0.91448500E+02, 0.38811200E+02, 0.36997500E+02, -.48050100E+02, 0.20421200E+01, -.43458600E+03, 0.21816000E+03, -.19080100E+03, 0.22181300E+03, 0.29609100E+03, 0.12754400E+03, 0.10370400E+03, 0.23535500E+03, 0.21707200E+03, 0.49242200E+02, 0.37572600E+03, 0.58202200E+02, -.30776200E+02, -.58067200E+03, -.20601800E+02, 0.66036800E+02, -.68297300E+02, 0.13102000E+03, -.14011800E+03, 0.10593400E+03, -.91662900E+02, 0.97931000E+02, -.42304600E+03, 0.21607900E+03, 0.39467100E+03, 0.21214100E+03, 0.53212600E+03, -.71997700E+02, 0.15994600E+03, 0.32067900E+02, 0.61821100E+02, 0.72037700E+02, 0.46504800E+02, -.38324600E+03, 0.19600600E+03, 0.17721700E+03, 0.18829700E+03, -.55199000E+02, -.58552600E+02, 0.15728800E+03, -.89005400E+02, 0.87112000E+02, -.41710400E+02, 0.36752600E+01, -.13591400E+04, 0.68397800E+03, 0.47048900E+03, 0.68189400E+03, 0.22029800E+03, -.11609000E+03, 0.50942700E+03, -.13634200E+03, 0.24392400E+03, -.55302400E+02, 0.50410900E+03, -.14033700E+03, 0.69696400E+02, 0.95003600E+01, 0.73505100E+02, 0.14599000E+02, 0.44425700E+02, 0.45388700E+02, -.97082300E+02, -.16286600E+02, 0.31248300E+02, 0.13315300E+03, 0.65569300E+01, -.66358600E+02, 0.24411500E+02, 0.31818600E+00, -.45232800E+02, 0.25246300E+02, 0.81096600E+01, 0.43445100E+02, -.10894800E+02, 0.57621000E+02, -.19717900E+02, -.58875600E+02, -.24365600E+02, -.31110800E+02, 0.25136100E+02, -.63410200E+02, 0.27370100E+02, -.12275000E+03, -.28494100E+00, 0.25573300E+02, -.22180300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21261100E+00, -.41378900E+00, -.98120100E+00, -.66683500E+00, -.13390000E+01, 0.26004100E+00, -.12827900E+01, 0.31400600E+00, 0.51070900E+00, 0.63750400E+00, 0.21050300E+00, -.17561500E+00, 0.17944700E+01, 0.10643100E+00, -.17660300E+00, 0.12634600E+00, -.50105500E+00, 0.10025500E+01, -.15443700E+01, -.45193400E-01, 0.79894100E-02, -.60695500E-02, 0.31506100E-01, -.15129600E-01, -.63275100E-01, 0.18152900E-02, -.20492900E-02, 0.72025900E-01, 0.10736100E+00, 0.15625600E+00, 0.96598300E-01, -.18548700E+00, 0.31528700E+00, -.28398200E+00, -.22169900E+00, 0.94717300E-01, -.14998900E+00, -.15210000E+00, 0.25168700E+00, -.82919800E-01, -.55843400E+00, 0.43400700E+00, -.16239000E+00, -.34818600E-01, 0.82630200E+00, -.16371100E-01, -.42653200E+00, -.82098200E-02, -.42437100E+00, -.84782600E+00, 0.51417300E-01, -.44121000E+00, -.86380500E+00, -.75506400E-01, 0.39527100E+00, 0.41101900E-01, -.11264500E+01, 0.42523800E+00, -.79609700E-01, 0.23391300E+00, 0.76286300E-01, 0.11242500E+00, -.82088500E+00, 0.38586300E-01, -.21786800E-02, -.24167200E+00, -.10077900E+00, -.30912800E+01, -.92410400E-01, -.21393600E-01, -.36870000E+00, -.34101300E+00, -.11292300E+00, -.88753400E-01, -.23090200E+00, 0.10043300E+01, 0.11974400E+00, 0.13729700E+01, 0.76657900E-01, 0.81410900E-01, -.63860200E-01, -.43387900E+00, 0.18075800E+00, 0.32017300E+00, 0.39029500E+00, -.56275200E+00, 0.35974900E+00, 0.32587200E-01, 0.17762400E+00, -.29228800E+00, 0.16268300E+01, 0.74095900E-02, -.84198700E-01, -.15086200E+00, 0.48354600E-01, 0.55841500E+00, -.20022500E+03, 0.12338400E+02, -.48735200E+03, -.99155000E+02, 0.43667900E+02, -.76789200E+03, 0.48510100E+02, -.85757200E+02, -.12676000E+03, -.31651900E+02, -.23381100E+03, -.72994200E+01, -.16812300E+03, 0.10444500E+04, -.34868300E+02, 0.25681700E+02, -.39815700E+03, 0.19874700E+02, -.29620100E+03, -.55354600E+03, 0.48878800E+03, -.32585100E+03, 0.20374000E+03, -.29286400E+03, -.55198100E+03, 0.15202900E+03, -.76272400E+02, 0.31727700E+03, -.71910900E+02, -.74128200E+02, -.22088900E+03, 0.74074400E+02, 0.10822700E+03, -.41404000E+02, -.17566500E+03, -.14759200E+01, 0.46351500E+03, -.23265600E+03, 0.48038300E+01, -.23670100E+03, -.87090700E+02, -.12411200E+02, 0.11989000E+02, 0.89381200E+02, 0.38430700E+01, -.39349700E+02, 0.39000300E+03, -.50288400E+02, 0.19626300E+02, -.81180800E+01, 0.24229600E+02, 0.72098100E+01, 0.84827700E+02, -.76599100E+02, 0.89891700E+02, 0.62129900E+02, 0.51218600E+02, 0.16918700E+03, 0.47034100E+03, -.23811300E+03, 0.19794000E+03, -.23500500E+03, -.72061200E+02, 0.67118400E+02, -.12533800E+03, 0.54432000E+01, -.32368000E+03, 0.72519200E+02, -.51106600E+03, 0.22942900E+03, -.11285800E+03, 0.63679400E+03, -.11755600E+03, 0.13487100E+03, 0.24069600E+03, -.22285500E+03, 0.13984800E+03, -.23778800E+03, 0.23382000E+03, -.34323900E+03, 0.71188600E+03, -.36543200E+03, -.33522500E+03, -.35730400E+03, -.42491000E+03, 0.61154600E+02, -.19456500E+03, 0.61363300E+02, -.23154200E+03, 0.21858900E+02, -.72168100E+03, 0.58879300E+03, -.29580400E+03, -.20761200E+03, -.29234700E+03, 0.38013400E+02, 0.12233500E+03, -.23704800E+03, 0.10317300E+03, -.17574500E+03, 0.68343900E+02, -.16384400E+03, 0.84206900E+03, -.43005400E+03, -.31212100E+03, -.42277300E+03, -.17923100E+03, 0.10486200E+03, -.32489100E+03, 0.22325400E+02, -.25812400E+03, 0.72865000E+02, -.37657000E+03, 0.39778300E+00, -.28926100E+01, 0.14556800E+03, -.16909700E+01, 0.79691100E+02, 0.44959200E+02, -.10850700E+03, 0.32119800E+02, -.40445400E+02, 0.36091500E+02, -.18192200E+03, -.68274600E+01, 0.51623300E+02, -.50473300E+02, 0.47304700E+00, 0.13805500E+02, -.81342200E+01, -.11124100E+02, -.10424600E+02, 0.10876100E+02, 0.48050600E+02, 0.20870300E+02, 0.92521400E+02, 0.47497800E+02, 0.43461700E+02, -.81485000E+02, 0.31714100E+02, -.10616900E+02, 0.97505000E+02, -.14771300E+01, -.45372800E+01, -.24825900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39156000E+00, -.20197300E+00, 0.14166500E+01, -.86765000E+00, -.48086900E+00, 0.10466500E+01, 0.79211900E+00, -.13037400E+00, 0.17022400E+01, -.96261900E+00, -.76687700E+00, 0.31006900E+00, -.10882600E+01, -.18549500E+01, -.35771900E+00, 0.13223900E+01, 0.38573200E+00, -.10412100E+01, 0.13137500E+01, -.13861900E+01, -.24984900E-01, 0.40869100E+00, 0.50152700E+01, 0.18554800E+00, 0.76643900E+00, 0.24931200E-02, 0.69317300E+00, 0.32754400E-01, 0.13989400E+01, -.10192700E+01, 0.19995800E+00, -.18311500E+01, -.14033200E+00, -.36409900E+00, 0.55122400E+00, 0.77568100E-01, 0.15477300E+00, -.21940200E+00, -.32599700E+00, 0.23408500E+00, -.15623200E+01, 0.73649900E+00, -.15617900E+00, 0.10077800E+00, 0.21010200E+01, -.26259200E+00, 0.68344400E+00, 0.57932400E-01, -.19990000E+01, -.16046400E+01, 0.24197400E+00, -.91494000E+00, -.15162400E+01, 0.41421300E+00, 0.51383400E+00, 0.57115200E+00, -.14643200E+00, 0.17091300E+01, -.28358300E+00, 0.20672500E+00, 0.51225300E-01, 0.87007800E+00, 0.35434400E+00, -.69641300E-01, -.16567300E+01, -.82965500E+00, -.31525400E+00, -.37061000E+01, 0.75727100E-02, -.11692500E-01, 0.42943800E+00, 0.28159900E+00, 0.25082900E+00, -.23641000E+00, -.11016800E+01, 0.74284100E+00, -.53249900E+00, 0.19563600E+01, 0.11648900E+00, 0.17724100E+00, 0.13278000E+00, 0.10496200E+01, -.44391000E+00, 0.53151300E+00, 0.26268400E-01, 0.18489500E-01, 0.57566100E+00, -.27299200E+00, 0.78480400E+00, 0.13083900E+01, -.25844800E+01, -.47950300E-01, 0.26678000E+00, 0.29301400E+00, 0.44321900E+00, -.76281800E-01, -.60135500E+00, 0.18725000E+03, 0.64860600E+03, -.10256500E+04, 0.51437300E+03, -.20486800E+04, 0.51601700E+03, -.79939200E+03, -.11942400E+04, 0.10405800E+04, 0.15390300E+04, 0.16922300E+04, -.10196200E+04, 0.25767000E+03, -.25800700E+04, 0.12878500E+04, -.10466600E+03, 0.12869000E+04, 0.14369800E+03, -.25221300E+03, 0.14051500E+02, -.17782800E+04, -.53635900E+02, 0.14778300E+03, 0.94317500E+03, -.10254800E+04, 0.50934500E+03, 0.12751400E+04, 0.50432300E+03, 0.48729400E+02, -.30869700E+03, 0.31441800E+03, -.16114900E+03, 0.25945200E+03, -.21838300E+03, 0.48446200E+00, -.55253000E+03, 0.27742200E+03, 0.41777400E+03, 0.28526300E+03, 0.16971600E+03, 0.37545800E+03, -.17414000E+03, -.91290400E+02, 0.26042900E+03, 0.11321200E+03, -.24847000E+03, 0.70967300E+02, -.18830600E+02, -.26181200E+02, -.34952700E+02, 0.97224600E+02, 0.17156800E+03, -.21273300E+03, -.10588000E+03, -.13226300E+03, 0.11610100E+03, 0.17608200E+02, 0.13691700E+04, -.68517200E+03, -.43674500E+03, -.69121900E+03, 0.15438600E+03, 0.82514900E+03, -.35522000E+03, 0.26217500E+03, -.67688800E+03, 0.57730000E+03, 0.24642200E+03, 0.33052100E+02, -.16750900E+02, 0.17504600E+04, -.19476200E+02, 0.61036700E+03, 0.79460600E+03, -.11151000E+03, 0.65082000E+02, -.56221400E+03, 0.69651000E+03, -.51597600E+03, 0.18910800E+04, -.94282000E+03, 0.14424900E+03, -.94278400E+03, -.95482300E+02, 0.14123000E+03, -.38366100E+03, 0.58096900E+03, 0.68465100E+02, 0.35251600E+03, -.14289900E+04, 0.19957600E+04, -.10060700E+04, -.46881300E+03, -.10036500E+04, -.24678900E+03, 0.89396300E+02, -.61136200E+03, -.56871700E+02, -.68949400E+03, 0.47135900E+02, -.40685000E+03, 0.76909300E+03, -.38166300E+03, -.35591600E+03, -.38385700E+03, 0.44922600E+03, 0.35218200E+03, 0.25992600E+02, 0.77729200E+03, 0.19081400E+02, 0.30635500E+03, -.15254600E+04, 0.16741700E+02, -.66735900E+01, 0.31423300E+03, -.90549100E+01, 0.28190900E+03, 0.26255600E+03, -.14614300E+03, -.13641300E+03, -.35184300E+03, 0.29041000E+03, -.60808600E+02, 0.17696700E+02, 0.32548500E+02, 0.92596400E+02, 0.31885900E+01, 0.18719500E+02, 0.37401300E+02, -.10689400E+03, -.14103800E+02, 0.75712600E+02, -.44009100E+02, -.12997800E+03, 0.84102300E+02, 0.87732400E+02, -.55740300E+02, 0.37837900E+02, 0.56780300E+02, 0.71007100E+02, 0.93586500E+02, 0.63868000E+02, 0.79884900E+02, 0.23284800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15948300E+00, 0.21850500E+00, 0.14133000E+01, 0.26905400E+00, -.13840800E+01, 0.35104500E+00, -.33173200E-02, -.22463700E-01, 0.59876700E+00, 0.85465000E+00, -.99218600E-01, 0.83240300E-01, 0.86082000E+00, -.10185700E+00, 0.68369700E-01, 0.10704200E+01, -.46362000E+00, -.33337200E+00, 0.25576000E+00, -.26108400E+00, 0.10193100E-01, -.30537400E-01, 0.11813100E+01, 0.95013300E-01, 0.99451400E-01, 0.22255400E-03, 0.22497400E+00, 0.63202800E+00, 0.27536800E-01, 0.60455500E-01, -.41396100E+00, 0.75762200E-01, -.30972200E+00, -.20807900E+00, 0.17055800E+00, -.10952100E+00, 0.11947000E+00, -.11131700E+00, -.15654700E+00, 0.73695200E+00, -.75117800E+00, -.22934600E+00, 0.16007900E+00, 0.31814500E-01, 0.35246300E+00, -.17602100E+00, -.49821800E-01, 0.94137500E-01, -.32866100E+00, -.19449300E+00, -.19221300E+00, -.48284800E-01, 0.48443300E+00, 0.15927800E+00, 0.21230200E+00, 0.50490400E-01, 0.13855300E+00, -.24158600E+00, -.74558100E-01, -.10524400E+00, -.23207100E+00, 0.67529600E-01, -.64925100E+00, 0.58382300E-01, -.10523400E+00, -.15930400E+00, -.16866100E+00, 0.29440600E+01, -.62070000E-01, -.74970400E-02, -.41675600E-01, 0.19588100E+00, 0.21604000E+00, -.61929500E-01, 0.37529800E-01, -.58483700E+00, 0.93058300E+00, -.10235900E+01, 0.66179200E-01, -.58522400E-01, -.21945800E-01, -.22169500E+00, -.27361800E+00, -.26573800E+00, -.24925100E+00, 0.62671000E+00, -.46431600E+00, 0.12449300E-01, -.14290600E+00, 0.49699700E+00, 0.10652000E+01, 0.25056300E-01, 0.56624400E+00, 0.25122500E+00, 0.42211200E-01, 0.22659800E+00, 0.40613100E+00, -.18535000E+00, 0.32021900E+03, 0.27981000E+03, -.14108400E+03, -.11914600E+04, -.13864600E+03, -.49191300E+00, 0.11649000E+03, 0.77513900E+01, 0.40176300E+03, -.86377100E+02, 0.11441300E+03, -.11329100E+03, -.11809300E+04, 0.59304100E+03, 0.86262800E+01, 0.58871900E+03, 0.19385300E+03, -.21349300E+03, 0.16141600E+03, -.35258000E+03, 0.29544900E+03, -.16400100E+03, 0.71147700E+03, -.16228000E+03, 0.81416500E+02, 0.17541600E+03, 0.77210300E+02, -.52464700E+02, -.71877600E+02, 0.10026800E+02, -.58796000E+02, -.97630800E+02, -.38413900E+02, -.99722700E+02, -.36251800E+03, 0.17864100E+03, 0.26422100E+03, 0.18651800E+03, 0.33048000E+01, 0.12071700E+02, 0.26266000E+02, -.27053400E+02, 0.13485200E+03, 0.11449800E+02, -.11707800E+03, -.45443400E+02, 0.22921700E+02, 0.10416000E+03, 0.22771000E+02, 0.18183200E+02, 0.95123800E+01, -.28028100E+02, -.74192500E+02, -.45047400E+02, 0.21516000E+02, -.19880600E+02, -.17350000E+02, 0.58070500E+01, 0.77492200E+02, 0.69251300E+01, 0.13285900E+03, 0.15359500E+03, 0.13511900E+02, 0.31629900E+02, 0.13323400E+01, 0.83889300E+02, 0.25621900E+03, -.31836400E+03, 0.15931500E+03, 0.79090000E+03, 0.15976100E+03, 0.41533400E+02, 0.11837100E+03, 0.31428800E+02, 0.50014800E+00, 0.11423600E+03, 0.85271100E+02, 0.19295900E+03, -.35854100E+03, 0.17688900E+03, 0.56114300E+03, 0.18022000E+03, 0.20262000E+01, -.63147200E+02, 0.86490000E+02, 0.76778000E+02, 0.15239200E+03, -.93069900E+01, 0.80989400E+03, 0.17235500E+03, -.86514800E+02, -.80426600E+02, -.89098100E+02, -.78562100E+02, -.55059300E+02, -.72451000E+02, -.95137800E+02, -.51451300E+02, -.33074300E+02, 0.79179400E+02, 0.39787600E+03, -.20019100E+03, -.12223000E+03, -.19813100E+03, 0.71194900E+02, 0.84034700E-01, 0.67381100E+02, 0.33533400E+03, 0.76959100E+02, -.15549300E+02, -.97764300E+02, 0.30660400E+03, -.15389500E+03, 0.20491100E+02, -.15286400E+03, 0.27772900E+02, 0.93332900E+02, -.49232000E+02, 0.78016700E+02, -.53151200E+02, 0.72741900E+02, -.42574700E+02, -.25854400E-01, 0.45052000E+02, 0.71607700E+01, -.86215800E+00, -.17906400E+02, 0.55585200E+01, -.13604500E+02, 0.18228600E+02, 0.18360800E+02, -.28872100E+02, 0.30483400E+02, -.86360600E+00, -.16670500E+02, -.50328200E+01, 0.10822700E+02, 0.99636100E+01, 0.26847400E+01, -.36462900E+02, 0.14263000E+02, -.75143100E+01, -.10338700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16956000E+00, 0.37312200E+00, 0.24781100E+01, 0.13008500E+01, 0.86818800E+00, -.11089700E+01, 0.14002000E+01, -.20175300E+00, 0.28679000E+01, 0.98588000E+00, -.32207700E+00, -.39847000E+00, 0.14545400E+01, 0.86372300E+00, 0.33901300E+00, 0.12675200E+01, -.24697400E+01, -.32670300E+00, -.28771900E+00, 0.11460100E+00, 0.16736500E-01, -.33812000E-01, -.28282800E+01, -.11363300E+00, -.29959700E+00, -.19733300E-02, -.38111200E+00, 0.30206700E+00, -.70102400E+00, 0.78356100E+00, 0.48859500E+00, 0.19381700E+00, 0.66566500E+00, 0.20828100E+01, 0.59437000E+00, 0.72219600E+00, -.18115800E+00, -.16788400E+00, 0.10030500E+01, -.51360400E+00, 0.93240900E+00, -.10776400E+00, 0.16899000E-01, 0.14457000E+00, -.12387100E+01, 0.15013400E+00, -.68896200E+00, -.15507300E-01, 0.49485200E+00, -.51578100E+00, -.26216400E+00, -.79726800E-01, 0.60144400E+00, -.17925600E+00, -.28325600E+00, -.15015600E+00, -.65296600E-02, -.34196600E-01, 0.45718600E-01, 0.24351500E-01, 0.21939400E+00, 0.21916100E+00, 0.66610100E+00, -.55590100E-02, 0.38038500E-01, -.25646600E-01, 0.26492300E+00, -.12718500E+00, 0.18141000E+00, -.11410500E-01, 0.50735000E+00, 0.37345300E+00, 0.25468300E+00, 0.19313000E+00, 0.11208800E+01, 0.33922500E+00, 0.79934800E+00, -.77900500E+00, 0.70315400E-02, 0.17897600E-01, 0.14166600E-01, 0.23973200E+00, -.34174900E+00, -.54053400E+00, -.97117100E-01, 0.76215000E+00, -.56863600E+00, 0.76064300E-01, 0.12560200E-01, -.10454100E+01, -.32618500E+01, -.25785000E-01, -.28687700E+00, -.40968300E+00, -.47988200E+00, -.37871200E+00, 0.61830200E+00, 0.14704300E+00, -.43533000E+00, 0.13601100E+04, -.67227300E+03, 0.75995800E+03, -.67978300E+03, 0.76083300E+03, 0.10859200E+04, -.97142000E+03, -.83131700E+03, -.16434600E+04, 0.97746400E+03, -.51094800E+03, 0.14582800E+04, -.74007500E+03, 0.73280300E+02, -.73061400E+03, -.69366300E+02, 0.11102900E+03, -.14337100E+02, 0.14124900E+04, 0.14519400E+03, -.18647000E+03, -.29084200E+03, 0.15358100E+04, -.77074900E+03, -.11011600E+04, -.76928100E+03, -.50753700E+02, 0.28250500E+03, -.30924800E+03, 0.44488800E+03, -.33317400E+03, 0.20976200E+03, -.52764400E+03, 0.12524600E+03, -.62342400E+02, -.26168000E+03, -.63340500E+02, 0.40318200E+02, -.11122900E+03, -.28559400E+02, -.40600900E+02, -.15244300E+03, -.13050600E+02, -.23424800E+03, -.81789600E+02, 0.40866900E+02, 0.51532700E+02, 0.42586400E+02, -.31576900E+02, -.15915800E+03, 0.25411400E+03, 0.40732400E+02, 0.75903300E+02, -.88058300E+02, -.21949300E+03, -.13628900E+04, 0.68607100E+03, 0.54530200E+03, 0.68230000E+03, -.19317600E+02, -.46656700E+03, 0.21717400E+03, -.46037400E+03, 0.45377400E+03, -.29142500E+03, 0.26633600E+03, -.10169400E+04, 0.50515500E+03, -.68286200E+03, 0.51042100E+03, -.36467500E+03, -.41147500E+03, 0.21290700E+03, -.31363800E+03, 0.64602500E+03, -.35551900E+03, 0.75570800E+03, -.13859500E+04, 0.70406100E+03, 0.34193700E+03, 0.69316500E+03, 0.48441300E+03, 0.52395400E+02, 0.26267500E+03, -.45605000E+02, -.22110900E+03, -.68138300E+02, 0.15215100E+04, -.17645700E+04, 0.88396300E+03, 0.54014400E+03, 0.88367800E+03, 0.10472300E+03, -.94077800E+02, 0.60016400E+03, 0.24988200E+02, 0.57518300E+03, -.48692600E+02, 0.52592700E+03, -.73307800E+03, 0.37809200E+03, 0.33188500E+03, 0.36796700E+03, -.78689500E+02, -.23604700E+03, 0.24575700E+03, -.10922500E+03, 0.98347100E+02, -.23401800E+03, 0.10902500E+04, 0.25756300E+02, -.10106300E+02, -.11606100E+03, -.11695900E+02, -.21139600E+03, -.11083700E+03, 0.18468500E+03, 0.19054700E+03, 0.31929700E+03, -.14214000E+03, 0.59450600E+02, -.53667400E+01, -.54627400E+02, 0.75294900E+02, -.27653600E+01, 0.33931300E+02, -.88107800E+01, 0.68316900E+02, -.41509900E+02, -.57057100E+02, -.82532500E+01, 0.12976800E+03, -.62288900E+02, -.54209800E+02, -.28279300E+02, 0.13161800E+03, 0.49298800E+01, -.79636700E+01, -.19205900E+03, -.28901900E+02, -.61367800E+02, -.25982800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20482800E+00, -.21362400E+01, -.59825400E+01, -.17460900E+01, 0.17709600E+01, -.15105000E+01, -.22066000E+00, 0.21897900E+00, 0.20076200E+01, 0.77516700E+00, -.14521300E+00, -.33523200E+00, -.21005600E+01, -.21794200E+01, 0.80044000E-01, 0.11243900E+00, 0.34524600E+00, 0.75203300E+00, -.20160100E+00, 0.76621600E+00, 0.11165800E+00, 0.67436300E+00, -.17350900E+00, 0.12517600E+00, 0.15705300E-01, 0.61915200E-03, 0.19921600E-01, 0.43512600E+00, 0.33663400E+00, -.22698700E-01, 0.35531400E-01, 0.13681600E+00, 0.23644700E+00, -.97924100E-02, -.15119600E+01, -.15028000E+00, 0.29441000E-01, 0.68144600E-01, -.64864600E-01, -.81266700E-01, 0.41572500E+00, -.80770300E+00, 0.13325100E+00, -.33909900E-01, -.11813300E+01, 0.93427200E-01, -.82342100E+00, 0.45889000E-01, 0.67000600E+00, -.59273200E+00, -.11727700E+00, -.12898400E+00, -.29781700E+00, 0.27343500E+00, -.15322600E+00, 0.16262000E+00, 0.11146400E+00, 0.73919000E+00, -.32301400E-01, -.20470200E+00, 0.50309800E-01, 0.23895400E+00, -.12296900E+01, -.15655400E+00, -.51519300E+00, 0.17806100E+00, -.34129100E+00, -.32063900E+01, 0.15600100E+00, -.18640400E-02, 0.19798700E+00, 0.14617200E+00, 0.13215300E+00, -.19665300E+00, 0.46751000E+00, 0.12487900E+01, 0.33613100E+00, -.10141000E+01, -.90271800E-01, -.21132700E+00, 0.24441300E-01, -.30473300E+00, 0.20313200E+00, 0.40760400E+00, 0.30857000E+00, 0.13555800E+00, 0.16494500E+00, -.44610600E-01, -.58359500E+00, -.25121300E+00, -.36632600E+00, -.29704300E-01, -.11484000E+00, -.70936200E-01, -.25711600E+00, -.15683100E+00, 0.14481800E+00, -.21007700E+00, -.25794500E+00, -.47225200E-01, 0.19568100E+02, -.14199300E+04, 0.12195400E+01, -.20182100E+03, -.22153000E+03, -.67442800E+02, 0.22713500E+03, 0.67991000E+02, -.17384000E+03, 0.36109400E+03, -.15017500E+04, 0.73700000E+03, -.43832300E+02, 0.75019300E+03, 0.74020000E+02, -.43578800E+03, 0.49774700E+03, -.52164400E+03, 0.47836300E+03, -.33876600E+03, 0.73880000E+03, 0.69628900E+02, -.42004200E+02, 0.17957600E+03, -.37270700E+02, -.26327000E+03, -.41098100E+03, 0.19910200E+03, 0.30531600E+03, 0.15556800E+03, -.33937400E+03, 0.29808800E+02, 0.15814800E+03, -.78261000E+02, 0.20100500E+03, -.78168700E+02, 0.59516000E+02, 0.17556200E+03, -.16382700E+03, 0.29551100E+02, -.39067200E+02, 0.11287600E+03, 0.13006700E+02, 0.28620700E+03, -.13286100E+03, 0.11060500E+02, -.14187100E+03, 0.65561100E+01, 0.45228600E+02, -.88740600E+02, -.18237700E+02, -.12169400E+03, 0.40343600E+02, -.14041500E+03, 0.64769200E+02, -.27081600E+02, 0.20442400E+03, -.35895400E+02, 0.27283600E+03, 0.37962000E+03, -.19780000E+03, -.16744100E+03, -.30390100E+03, 0.29300600E+03, -.13159400E+03, 0.42793100E+03, -.21362500E+03, 0.92459900E+03, -.21718100E+03, 0.30302900E+03, 0.36433500E+03, -.16615300E+03, 0.25373500E+03, -.35677400E+03, 0.32163500E+03, -.33469300E+03, 0.15997700E+04, -.79822500E+03, -.66189400E+03, -.79933800E+03, -.98339200E+02, 0.37003700E+03, -.61076100E+03, 0.16560000E+03, -.65606400E+03, 0.38310800E+03, -.42215000E+02, 0.67441500E+03, -.34281700E+03, -.20056100E+03, -.33816600E+03, -.18758100E+02, 0.88548700E+02, -.23875300E+03, -.17935400E+02, -.32591900E+03, 0.94387500E+02, -.10548300E+03, 0.71096800E+03, -.34424400E+03, -.28244000E+03, -.35574200E+03, 0.86561100E+02, 0.26630700E+03, -.18996300E+03, 0.27504900E+03, -.34182800E+03, 0.19195600E+03, -.26247600E+03, 0.89960900E+02, -.37581300E+02, 0.10834200E+03, -.46031500E+02, 0.97227200E+02, 0.47019200E+02, -.36905800E+02, 0.10399600E+03, -.41130200E+02, 0.40868200E+02, -.61338900E+02, -.64858000E+01, 0.47805400E+02, 0.53265900E+02, -.78427800E+00, 0.16607000E+02, 0.26101400E+01, -.40853700E+02, -.15907900E+02, 0.37808300E+02, 0.26681700E+01, -.20696600E+02, 0.16741600E+02, 0.64867600E+02, 0.12007300E+02, 0.61487800E+02, 0.60235100E+02, 0.11339300E+02, 0.20396200E+02, 0.26575400E+02, 0.21183300E+02, 0.40113300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14299300E+00, -.38631600E+00, -.26345400E+01, -.12145500E+01, -.18911000E+00, 0.37779900E+00, -.15705400E+01, 0.67336300E-01, -.30022900E+01, -.87155600E+00, 0.25888700E+00, 0.21709600E+00, -.74917500E+00, 0.22354900E+00, 0.11778700E-01, -.10333800E+01, -.31420200E+00, 0.59415400E+00, -.30100200E+00, 0.10377500E+00, -.36548700E-01, -.21747500E+00, 0.31181800E+00, -.36719000E-01, -.10486900E+00, -.19668300E-03, 0.84097200E-01, 0.33081400E+00, -.52362800E+00, 0.41455600E+00, -.28520200E+00, 0.34399600E+00, -.21679700E+00, -.58741400E+00, -.14295200E+00, -.14255400E+00, -.35880800E-01, -.58042600E-01, -.47369200E-01, 0.13825600E+01, -.14220500E+00, -.10129300E+01, 0.29265800E+00, -.10918700E+00, 0.64114700E+00, -.30841600E+00, -.27903300E+00, -.10092800E-01, 0.80408900E+00, 0.20567200E+00, -.31404900E+00, 0.25530500E+00, 0.91939800E+00, -.16421500E+00, -.64370300E+00, -.94463000E-02, 0.52870500E+00, -.19645400E+00, 0.52916000E-01, -.16896400E+00, -.71091100E-01, -.54473000E+00, 0.27223500E+00, 0.99525700E-02, 0.31423500E+00, 0.81151300E-01, 0.44901700E+00, 0.27550700E+01, 0.10235300E+00, -.43412000E-01, 0.38572200E+00, 0.10616700E+00, 0.31307500E+00, 0.28606400E+00, 0.80352700E+00, -.88076700E+00, -.74506700E+00, 0.19240100E+00, -.18187900E+00, 0.40172200E+00, -.38335400E-01, 0.76522100E+00, -.92471000E+00, -.85945800E+00, -.63229500E+00, 0.15075700E+00, 0.26969200E+00, -.13184200E+00, 0.63860400E+00, 0.69549100E+00, -.14394300E+01, -.56740200E-01, 0.36108600E+00, -.25531400E+00, -.31627700E+00, -.20814700E+00, -.10002400E+01, -.15494600E+00, -.13617000E+01, 0.34269400E+00, -.63667700E+00, -.39285200E+04, 0.11618400E+01, -.21496800E+03, -.34206000E+03, 0.28383300E+03, 0.97703200E+03, 0.37047900E+03, -.34955700E+03, 0.12377000E+04, -.31749800E+04, 0.16004900E+04, -.51900500E+03, 0.15888100E+04, -.21232100E+02, -.12186200E+04, 0.98526600E+03, -.17931600E+04, 0.77049200E+03, -.71192900E+03, 0.10680200E+04, -.47383400E+03, 0.23648400E+03, 0.10674400E+04, 0.23641400E+03, -.30173700E+03, -.72955200E+03, 0.31224300E+03, 0.12698100E+03, -.55479600E+02, -.54665100E+03, 0.20593800E+03, -.15701600E+03, 0.70673100E+02, 0.64872200E+03, 0.76654100E+02, -.78322600E+02, 0.10947900E+03, 0.10498000E+01, 0.79504700E+02, 0.15241400E+03, 0.34113200E+02, 0.37925500E+03, 0.91422800E+02, -.51305000E+02, 0.13226800E+03, -.45497500E+02, 0.54161500E+02, 0.17701000E+03, -.30886000E+03, -.85426500E+02, -.10372400E+03, 0.13876500E+03, 0.99874200E+02, 0.10087800E+04, -.51347000E+03, 0.26156300E+03, -.51063500E+03, 0.27433400E+03, 0.72501800E+03, -.32229800E+03, 0.46708500E+02, -.60137700E+03, 0.49473800E+03, -.49921700E+03, 0.35566200E+03, -.17558000E+03, 0.28220400E+04, -.18633000E+03, 0.39681500E+03, 0.80616100E+03, -.40711100E+03, 0.33538300E+03, -.52512800E+03, 0.71890500E+03, -.48006100E+03, 0.13830000E+04, -.71097600E+03, 0.21289300E+03, -.69174500E+03, -.78632800E+03, 0.12458800E+03, -.45755100E+03, 0.23046200E+03, -.31991100E+03, 0.26700900E+03, 0.33389700E+03, 0.18684100E+04, -.94013500E+03, -.59742300E+03, -.93488000E+03, -.17529700E+03, 0.84627400E+02, -.69543200E+03, -.52806100E+02, -.63185200E+03, 0.72089300E+02, -.17104100E+03, 0.21220200E+04, -.10717300E+04, -.79937600E+03, -.10633800E+04, -.36221500E+02, 0.32925200E+03, -.32579900E+03, 0.82011200E+03, -.33899100E+03, 0.23710000E+03, -.11261500E+04, 0.81110600E+03, -.40833400E+03, 0.19536400E+03, -.40899000E+03, 0.20738800E+03, 0.26371800E+03, -.30711200E+03, 0.16958900E+03, -.33364500E+03, 0.24152000E+03, -.45620800E+03, -.39970300E+01, 0.19564300E+03, -.34175800E+01, 0.92992200E-01, -.22711500E+02, 0.40993800E+01, -.82011400E+02, 0.29485800E+02, 0.80468200E+02, 0.12363800E+02, 0.40370300E+02, 0.13863000E+03, 0.85744600E+02, 0.45494100E+02, -.43597300E+02, 0.93771400E+02, -.16400200E+01, 0.90837700E+02, 0.47845600E+02, 0.18701800E+02, -.72170100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20648400E+00, 0.35550200E-01, -.44052400E+01, -.47809100E+00, -.53238000E+00, 0.15959300E+01, -.30958500E+01, 0.37479900E+00, -.11646300E+01, -.10788000E+01, 0.10666300E-01, 0.51956600E+00, -.20228600E+01, -.12045700E+01, 0.26188300E-01, -.94457300E+00, -.15680900E+00, 0.13008000E+00, -.38630400E-01, -.38324300E+00, -.83006500E-01, -.19102600E+00, -.44836500E+00, -.18784800E-01, -.16063500E+00, -.44415800E-03, -.42737200E-01, -.60571900E+00, 0.17957400E+00, 0.65232700E-01, 0.71406800E-01, 0.48015800E-01, 0.18452600E+00, -.60754100E-01, -.70242500E+00, -.11909100E-01, -.37331500E-01, -.26430400E-01, 0.83907000E-01, -.26759000E+00, 0.26285400E+00, 0.25583700E+00, -.32224500E-01, 0.47222400E-01, -.86428700E+00, 0.28250000E+00, -.90115700E-01, 0.32147100E-01, -.16968200E+00, -.38393100E+00, -.58535300E-02, -.25624100E+00, -.59463600E+00, 0.31441800E+00, -.41367600E+00, 0.36050300E+00, -.60899700E+00, 0.17032000E+01, -.16371300E+00, -.54209100E-01, 0.35356800E+00, 0.38352100E+00, -.10512600E+01, -.22911400E+00, -.58012500E+00, 0.15092600E+00, -.19536900E+00, -.10079700E+02, 0.22490700E-01, -.36719100E-01, -.17720700E+00, -.46584600E+00, -.23815100E+00, -.20644700E+00, 0.41096800E+00, 0.61632900E+00, 0.47347200E+00, -.16925700E+01, -.94684200E-01, -.28728200E+00, 0.16116900E-01, -.48950500E+00, 0.18886000E+00, 0.45702400E+00, 0.27033300E+00, 0.52814700E+00, -.29189800E+00, -.31207600E-02, -.49054500E+00, -.33824700E+00, -.74645300E+00, 0.93954200E-03, -.42552500E+00, -.77822400E-01, -.28508600E+00, -.15859200E+00, 0.19492600E+00, -.17141000E+00, -.13846800E+00, 0.41750900E-02, 0.31154000E+00, 0.15732000E+00, 0.29744400E+02, -.95374700E+01, 0.19856600E+02, -.10245600E+03, -.69889600E+02, -.95452400E+02, 0.27821500E+02, -.50788900E+02, -.23231900E+03, 0.10578500E+03, 0.10433600E+03, 0.11404900E+03, 0.15586700E+02, 0.25037700E+02, 0.97875100E+02, 0.32637600E+02, 0.51546100E+02, -.24547500E+02, 0.19036300E+03, -.42652700E+02, 0.17704300E+02, -.75267400E+02, 0.17246100E+02, -.10676000E+03, -.17510400E+03, 0.12475700E+03, 0.15053400E+03, 0.20361200E+03, -.16965700E+03, 0.13298100E+03, 0.11902400E+03, -.56990000E+02, -.21153800E+02, -.56907500E+02, 0.37053300E+02, 0.84992800E+02, -.97835800E+02, -.11535400E+02, -.69572300E+02, 0.59606000E+02, -.36291400E+02, 0.16231400E+03, -.73470600E+02, -.60166200E+01, -.80602600E+02, -.51867300E+01, -.35668800E+01, -.11911500E+02, -.12749500E+02, -.65003500E+02, 0.17522600E+01, -.10614200E+03, -.20364200E+03, 0.10687800E+03, -.98204300E+01, 0.99747600E+02, 0.55777000E+02, 0.51401100E+02, -.42647900E+02, -.10564900E+03, -.62099100E+02, 0.70606100E+02, -.17518100E+02, 0.16312700E+03, -.81996200E+02, -.94997500E+02, -.81491800E+02, 0.48832700E+02, 0.36546100E+01, -.21338300E+02, 0.10328700E+03, -.43690700E+02, 0.13281500E+01, -.62780000E+02, 0.55033600E+03, -.26141200E+03, -.42108900E+03, -.27337100E+03, 0.49351500E+01, 0.15999600E+03, -.23246800E+03, 0.39849900E+02, -.29582600E+03, 0.12521700E+03, -.30606200E+02, 0.66620200E+02, -.36271200E+02, -.15277300E+02, -.34692100E+02, 0.15724200E+02, 0.22406200E+02, -.94754900E+01, 0.17322400E+02, -.38680800E+02, 0.30780100E+02, -.16839600E+02, 0.17254800E+03, -.78097200E+02, -.13354900E+03, -.85137300E+02, 0.33377200E+02, 0.10637500E+03, -.91216300E+02, 0.39176400E+02, -.20260800E+03, 0.73113900E+02, 0.36824100E+02, -.10307000E+03, 0.56153300E+02, 0.28766100E+02, 0.51991000E+02, 0.18486100E+02, -.12066600E+02, 0.18675600E+02, 0.16851700E+02, 0.34030600E+02, -.11472500E+02, 0.75625900E+02, -.20661600E+01, -.56388300E+01, 0.35137700E+02, -.12636900E+00, 0.12092400E+02, -.50922400E+00, -.56612700E+01, -.12698500E+02, 0.33252100E+01, 0.14433000E+01, -.25530300E+01, -.19473300E+02, 0.32060400E+02, 0.34402000E+01, 0.48104600E+02, 0.84049300E+01, 0.33070200E+00, -.38980000E+01, 0.31336900E+01, 0.48169900E+01, 0.17078400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.63507300E+00, -.54154400E+01, -.74960700E+01, -.42818800E+01, 0.29515200E+01, -.54071000E+01, 0.45550900E+01, 0.16485600E+00, 0.69715000E+01, 0.47116100E+01, -.65945200E-01, -.20169100E+01, 0.89181900E+01, 0.46767600E+01, 0.15637200E+01, 0.20784000E+01, -.24950900E+01, 0.29661900E+01, -.21922900E+01, 0.26004100E+01, -.14791900E+00, -.37439000E+00, -.71268300E+01, -.65200800E+00, -.17929100E+01, -.61684600E-02, -.95654700E+00, 0.16536900E+01, -.24828100E+01, 0.15477100E+01, -.12919000E+01, 0.23044500E+01, -.14125900E+01, -.60685500E+00, 0.52251200E+01, 0.18599700E+00, -.22232800E-01, -.84433700E+00, -.16056600E+00, 0.18464800E+01, -.17468700E+01, -.11052200E+01, 0.53072300E+00, -.93308000E-01, 0.44859100E+01, -.12311300E+01, 0.16691100E+01, -.90612900E-01, 0.81159900E+00, 0.12026200E+01, 0.67727000E+00, 0.23074300E+00, -.17923600E+01, -.84490500E+00, -.13203500E+01, 0.60506600E+00, -.26177700E+01, 0.11271200E+01, -.25916000E+00, 0.57584300E+00, -.16010500E+01, -.27509700E+01, 0.25919400E+00, 0.25836400E+00, -.22660200E+00, -.61814700E+00, 0.86925300E+00, 0.12512300E+02, -.49795700E-01, -.77778400E-01, -.23796800E-01, -.26824300E+00, 0.10597800E+00, 0.36233600E+00, 0.47223400E+00, -.29989000E+00, -.32201500E+01, 0.89661700E+00, -.32607800E+00, 0.34319100E+00, -.17844500E-01, 0.15198500E+01, -.30378200E+00, 0.67818700E-01, 0.36966200E-01, -.71431100E+00, 0.79726600E+00, -.26658900E+00, 0.83051200E+00, 0.53201100E+00, 0.34443400E+01, -.90234700E-01, -.10146200E+01, -.29916900E+00, 0.13299800E+00, -.27371900E+00, -.23297500E+00, 0.26694300E+00, -.78418800E+00, -.48820300E-01, -.60553100E-01, 0.34290400E-01, -.58685300E-01, 0.73806400E+03, 0.54668700E+03, -.29444000E+03, -.44225100E+03, -.75646200E+03, 0.44903800E+03, -.34712000E+03, -.20643300E+03, 0.13609700E+03, 0.11651800E+03, 0.10605700E+03, -.94916000E+02, 0.34721300E+03, -.30650300E+03, -.60870500E+03, -.45806300E+03, 0.36314300E+03, 0.11328100E+03, 0.39273100E+03, -.17384900E+03, -.47106700E+03, -.19000700E+03, -.30137300E+03, -.61549600E+03, 0.29149200E+03, 0.25459400E+03, 0.32962200E+03, -.55184700E+03, 0.15893700E+03, 0.13302800E+03, -.70752800E+02, 0.19568400E+03, -.78430600E+02, -.51980100E+02, -.25404000E+02, 0.29214900E+02, -.12829900E+02, -.22367400E+03, 0.16871800E+02, -.16338000E+03, -.33935600E+03, 0.11498400E+03, 0.30346100E+03, 0.17038900E+03, -.39223900E+02, -.71626500E+02, 0.12558100E+03, -.34501700E+02, 0.98164100E+02, -.53289200E+02, 0.10705300E+03, -.26631100E+03, 0.12456200E+03, -.24651000E+02, 0.13416300E+03, -.18519800E+03, -.18548400E+03, -.23309700E+02, -.22474300E+03, -.14684600E+02, -.69531600E+02, -.13363900E+03, 0.40115500E+03, -.23078300E+03, -.39515800E+03, -.20436200E+03, -.32136800E+03, -.42911300E+03, 0.70291400E+02, 0.36452900E+03, 0.50973300E+03, -.37385700E+03, -.19991500E+03, -.12601200E+04, 0.61884500E+03, 0.39023300E+02, 0.62755300E+03, -.13614600E+03, -.12937500E+03, 0.15993200E+03, -.36371000E+03, -.33749300E+02, -.88584500E+02, -.28077500E+03, 0.32217900E+02, 0.13106000E+02, -.18474900E+03, -.93586800E+01, 0.65960300E+02, -.83345700E+02, 0.86923800E+02, 0.68336100E+02, 0.22307900E+03, -.66766000E+02, -.18920300E+03, 0.52344600E+02, -.39904900E+02, -.17519600E+03, -.27721400E+02, -.30067400E+03, -.22271600E+03, -.27978500E+02, -.30035600E+02, -.15914200E+03, -.16482600E+03, -.19162400E+03, 0.80105200E+01, -.27943700E+02, 0.15658600E+03, -.55977500E+01, -.32769300E+02, 0.82980800E+02, -.11893800E+03, -.24604700E+02, 0.58808400E+02, 0.45790000E+02, 0.59508400E+01, 0.78630300E+01, 0.28286300E+02, -.43962600E+02, 0.30246300E+01, -.59274300E+01, -.97756400E+01, 0.21283400E+02, 0.53532500E+01, -.23437700E+02, -.51691900E+01, 0.77856100E+02, -.12900100E+02, 0.55211800E+02, -.93721700E+01, -.19913200E+02, -.40630800E+00, -.49567500E+02, -.44274300E+02, -.24004500E+02, 0.36721500E+01, -.37606500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17865300E+00, -.44886500E+00, 0.80810000E+00, -.28904900E+00, -.13004700E+01, -.30058600E+00, 0.62952100E+00, -.11665200E+00, 0.16709700E+01, 0.16862200E+01, -.25897200E+00, -.84591900E-01, 0.14445800E+01, 0.20008600E+00, 0.30849400E+00, 0.72271700E+00, -.14705900E+00, -.24158700E+00, -.13196300E+00, 0.48857400E+00, 0.45322500E-01, 0.13880800E+00, 0.26661400E+00, 0.70678000E-01, -.87588700E-01, -.96234200E-04, 0.17052800E-01, 0.10946500E-01, 0.56515600E+00, -.31836700E+00, -.19249800E+00, -.37839800E+00, -.20259200E+00, -.20383700E+00, 0.12184700E+01, 0.16550500E+00, 0.10010600E-01, -.22667200E+00, -.84269300E-01, -.23945200E+00, -.25013600E+00, -.12948700E+00, 0.36806500E-01, -.12846300E+00, 0.12934300E+01, -.26001200E+00, 0.22925000E-01, -.35052600E-01, 0.52462800E-01, 0.17229400E+00, -.12987300E+00, 0.23849400E+00, 0.49263000E+00, 0.22774800E+00, -.91750600E+00, -.12087300E+00, 0.26299900E+00, 0.54926700E+00, 0.54436400E-01, -.19137400E+00, 0.38146400E+00, -.88777600E-01, 0.20083200E+01, -.22177000E-01, -.25607200E+00, 0.29387500E+00, 0.17217900E-01, -.15210800E+01, 0.64269500E-01, -.13829100E-03, -.96316300E-01, -.29914600E+00, -.20245900E+00, 0.20385800E-01, 0.17688000E+00, -.42329600E-01, -.31261400E+00, -.11506200E+01, -.52794000E-01, -.13774700E+00, 0.78915900E-03, -.19495600E+00, 0.24535200E+00, 0.53627300E+00, 0.25583100E+00, -.47959100E+00, 0.10315900E+00, -.46452000E-01, 0.20378100E+00, 0.38992800E+00, 0.13737900E+01, 0.88953200E-02, 0.33460800E+00, 0.29986700E+00, 0.31476800E+00, 0.76062000E-01, -.35818200E-01, -.38647700E-01, -.62073500E-02, -.17769900E+00, -.34382400E-01, 0.47397500E-01, 0.12839000E-01, -.17246700E+00, 0.18655000E+03, -.75688600E+02, -.21229800E+03, -.25846800E+03, 0.19497300E+03, -.10337600E+03, -.37532900E+03, 0.19461900E+03, 0.13428800E+03, 0.18733800E+03, 0.25082200E+02, 0.52013700E+02, -.20583300E+02, -.43435600E+02, 0.61337300E+02, 0.66260900E+02, 0.10078100E+03, -.22062800E+03, 0.11610600E+03, -.13978400E+03, 0.10961300E+03, -.97859300E+02, -.17381300E+03, 0.13914700E+03, -.10519600E+02, 0.22820600E+03, -.15445400E+03, 0.21226000E+01, -.24273100E+03, 0.12098100E+03, 0.20446500E+03, 0.12384700E+03, 0.56005900E+02, 0.10403900E+03, -.11650700E+02, -.10551000E+03, -.10583700E+02, 0.98226400E+02, 0.12513300E+03, -.16401800E+03, 0.75400500E+02, 0.14129700E+03, 0.81592000E+02, 0.24311100E+02, 0.13606100E+02, 0.29298200E+02, -.35113300E+02, 0.63829100E+01, 0.20116400E+02, 0.70253100E+02, -.29692300E+03, 0.14618800E+03, -.92048800E+02, 0.14888800E+03, 0.35682500E+02, -.49245100E+02, 0.61718300E+02, -.55342300E+02, 0.55319100E+02, -.14982500E+02, 0.22918100E+03, -.23910900E+02, 0.64597500E+01, -.17853800E+03, 0.13207500E+02, 0.47186600E+02, -.11999400E+03, 0.11827300E+03, 0.13634200E+03, 0.26946500E+03, -.12142200E+03, 0.23443700E+02, -.64542200E+03, 0.32022200E+03, 0.19296400E+03, 0.32276900E+03, 0.11329000E+03, -.13283400E+03, 0.18525100E+03, -.87076600E+02, 0.14681800E+03, -.11560800E+03, -.57046100E+01, -.12142100E+03, 0.66485400E+02, -.35346400E+02, 0.59412600E+02, 0.80696300E+01, -.16519200E+02, 0.57605900E+02, 0.31189800E+02, 0.11041400E+03, -.22014100E+02, 0.18846800E+02, 0.50023900E+02, -.27710500E+02, -.12885600E+03, -.24758900E+02, 0.49284500E+01, -.95162200E+02, 0.48807200E+02, 0.54293600E+02, -.42249800E+01, -.70200000E+02, 0.13464000E+03, -.11557600E+03, 0.52768200E+02, 0.71884900E+02, 0.58226100E+02, 0.35047600E+02, 0.24470700E+02, 0.27792100E+02, -.28161000E+00, 0.34560700E+02, 0.15914800E+02, 0.80317800E+02, -.25048300E+01, -.21257000E+02, 0.56292000E+01, -.15782900E+00, -.12779400E+02, 0.72189300E+01, 0.21613900E+01, 0.12187300E+02, -.12664900E+01, -.45895000E+01, 0.26535100E+02, -.84415500E+01, 0.45302300E+01, 0.23259100E+01, 0.43609200E+00, -.10031300E+02, -.25442900E+01, -.18273800E+02, 0.18116000E+01, -.71955200E+01, -.41495100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.53194600E+00, -.48978500E+01, -.71216400E+01, -.37611300E+01, 0.27664200E+01, -.47270700E+01, 0.35550800E+01, 0.20055100E+00, 0.66383800E+01, 0.41763300E+01, -.15259300E+00, -.15618500E+01, 0.66991200E+01, 0.27064400E+01, 0.10929100E+01, 0.22661100E+01, -.20936000E+01, 0.20588500E+01, -.16692800E+01, 0.26757400E+01, -.42923400E-01, 0.41884900E-01, -.62649300E+01, -.50386200E+00, -.13393500E+01, -.43591800E-02, -.86052800E+00, 0.73039100E+00, -.20991600E+01, 0.74446400E+00, -.35347300E+00, 0.14058000E+01, -.68324800E+00, -.24337400E-01, 0.25894300E+01, 0.13341400E+00, -.92931200E-02, -.41845600E+00, -.78874300E-01, 0.19664000E+00, -.84800600E-01, -.93977700E+00, 0.15627500E+00, -.21224900E+00, 0.19198700E+01, -.81729300E+00, 0.34379800E+01, -.10784800E-01, -.41709300E+00, 0.14419700E+01, 0.28384800E+00, 0.82879100E+00, -.90585400E+00, -.23783900E+00, -.53519300E+00, 0.49417400E+00, -.51133300E+00, 0.10400800E+01, -.96358500E-01, 0.29879000E-01, -.15812500E+01, -.15283200E+01, -.70066000E+00, 0.73057100E-01, 0.12639700E+01, 0.79286800E-01, 0.94647300E+00, 0.91455400E+01, 0.31982600E+00, -.52786100E-01, 0.74789000E+00, 0.32542200E+00, 0.40450100E-01, 0.76551600E+00, 0.39257400E+00, 0.21232000E+01, -.14697500E+01, -.21209000E+01, -.46779500E+00, 0.48750200E-01, 0.62959200E-01, 0.11490100E+01, 0.24582900E+00, 0.42454800E+00, 0.32176400E+00, -.83769400E+00, 0.69513800E+00, -.19963200E+00, -.55653600E+00, -.21731100E+01, 0.34375100E+01, -.12347700E+00, -.16886000E+01, -.32700700E+00, -.52807600E+00, -.15900300E+01, -.12233000E+01, 0.17862600E+00, -.23873500E+01, 0.11263600E+00, -.16741600E+01, 0.14736800E+01, -.22839000E-01, 0.81581300E+00, -.18952700E+01, -.69851200E+03, -.10172000E+04, -.47731700E+03, 0.17575700E+03, -.78126900E+03, -.15230800E+04, 0.74318900E+03, 0.56545800E+03, 0.75818900E+03, 0.16868700E+03, 0.10546100E+03, 0.13407000E+03, 0.33829400E+03, 0.74570300E+03, -.16099500E+03, 0.13124200E+04, 0.92043800E+03, -.46888800E+03, -.11233300E+04, -.46537600E+03, -.58853600E+03, -.55020400E+03, 0.26727700E+03, 0.69635700E+03, 0.47393000E+03, -.47736100E+03, -.48700900E+03, 0.65474400E+03, -.32206600E+03, 0.26992100E+03, -.31750000E+03, 0.35194100E+03, 0.45201100E+03, -.45105700E+03, -.95745500E+02, -.34192300E+03, 0.40036100E+03, -.53895900E+03, 0.33372500E+03, -.14327800E+03, 0.13308300E+03, -.16638300E+03, -.19806400E+02, -.52032600E+02, 0.26538600E+03, 0.10360800E+03, -.11522300E+03, -.15481700E+02, -.37144600E+03, -.12063200E+04, 0.60831900E+03, 0.35138000E+03, 0.60554900E+03, 0.61425700E+03, 0.13306700E+03, -.80012800E+02, -.64252400E+03, 0.35648100E+02, 0.15728500E+03, 0.50980900E+03, 0.94352000E+03, -.45730300E+03, -.64066100E+03, -.46429000E+03, 0.43822400E+03, -.86532500E+02, 0.26444400E+03, 0.55785100E+03, -.11843100E+03, -.91175400E+02, -.49284700E+03, 0.13213000E+04, -.67269100E+03, -.15666600E+04, -.65990800E+03, 0.83489600E+03, 0.58143100E+03, -.75557000E+03, -.15564300E+03, -.99105200E+03, 0.56925100E+03, -.39428700E+03, -.66136400E+03, 0.32088200E+03, 0.11773800E+03, 0.32647300E+03, 0.23807200E+03, 0.11146700E+03, 0.34870600E+03, 0.87081200E+02, -.74253100E+02, 0.14432400E+03, -.14555800E+03, -.10294200E+04, 0.53188300E+03, 0.33006700E+03, 0.51753700E+03, 0.18552700E+03, 0.21752500E+02, 0.19192100E+03, -.22359400E+03, -.23550500E+03, 0.41158800E+02, 0.68786300E+03, -.70693500E+03, 0.36143500E+03, 0.74187100E+02, 0.35669900E+03, 0.45322100E+02, -.17544700E+03, 0.30949200E+03, 0.18565200E+03, 0.37518700E+03, -.17807900E+03, 0.28382200E+03, -.17419800E+02, -.10477200E+03, 0.13302400E+03, -.31092500E+01, 0.79011600E+02, 0.17672900E+02, -.52369100E+01, -.86753600E+02, -.82558400E+01, -.14928400E+02, -.10381500E+03, -.10921300E+03, 0.48130300E+02, -.46482800E+02, 0.19930400E+03, 0.75234200E+02, 0.30831400E+02, -.10291500E+03, 0.89745300E+01, 0.30180100E+02, 0.12909900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.61688100E+00, 0.46223000E+00, 0.49668400E+01, 0.30075800E+00, -.52386900E+00, 0.13820100E+01, -.25599600E+01, 0.32159500E+00, -.13946500E+01, -.27474600E+01, -.24410700E+01, 0.40777700E+00, -.48536900E+01, -.92637100E+00, 0.14882900E+01, -.25713100E+01, 0.55084100E+00, 0.34662700E+00, 0.30997500E+01, -.21304700E+01, -.48992600E+00, 0.17903800E+00, -.12335600E+01, -.20755000E+00, 0.20018600E+00, -.59751900E-03, 0.41655500E-01, 0.10281200E+01, -.20781500E+01, -.75044700E+00, -.27518200E+00, 0.11660900E+01, -.94906500E+00, 0.13592900E+01, 0.37274800E+01, 0.99164700E-01, 0.45093700E+00, -.22988700E+00, -.51308400E+00, 0.24706000E+01, -.27924600E+00, -.41504400E+01, 0.15634100E+01, 0.42418300E+00, -.36146500E+00, -.10635300E+01, -.73100600E+00, 0.20072600E+00, 0.23304100E+01, 0.18583100E+01, -.82906300E+00, 0.12286400E+01, 0.28428900E+01, -.71976600E+00, -.23361000E+01, -.75457700E+00, 0.12129200E+01, -.93995500E+00, 0.15150300E-01, -.44305400E+00, -.76688400E+00, -.80683400E-01, 0.22488300E+01, -.54907900E+00, -.10171300E+01, 0.47844800E+00, 0.41618700E+00, 0.98932500E+01, 0.38274600E+00, 0.29589600E-01, 0.64174100E+00, 0.94806300E+00, 0.68217300E+00, 0.32889300E+00, 0.20045200E+01, -.19543000E+00, 0.87368700E+00, -.57134900E+01, -.15264500E-01, 0.91357100E-01, -.56110200E-02, 0.53547900E+00, -.59665600E+00, 0.10614700E+01, -.49732900E+00, 0.19680400E+01, -.95229600E+00, -.21042500E+00, -.58398800E+00, -.10598000E+01, 0.21473900E+01, -.92447700E-01, -.26369300E+01, 0.48711500E-01, -.97574700E+00, -.15580300E+01, 0.23385700E+01, -.80030400E+00, -.90482400E+00, 0.16245800E+01, -.17683700E+01, 0.74322900E+00, 0.26079500E+00, -.25054500E+00, -.75056900E+00, -.21132100E+00, 0.71553800E+03, 0.17118000E+03, 0.13870100E+02, -.12655800E+04, -.16959900E+04, 0.89807700E+03, 0.84138400E+03, 0.83937400E+03, 0.85177000E+03, 0.71033800E+03, -.15971600E+03, -.30664100E+03, -.24099100E+03, 0.52441400E+03, 0.11804900E+04, -.21768700E+04, 0.11154100E+04, 0.38413400E+03, 0.10693500E+04, -.10140400E+03, -.65127600E+03, 0.85340500E+03, 0.24423300E+02, 0.71045300E+03, -.40653900E+03, 0.11656100E+04, -.18884400E+04, 0.92997400E+03, 0.82193900E+03, 0.95786800E+03, 0.10672200E+03, 0.39294400E+03, -.19505700E+03, -.42889300E+03, 0.47717100E+03, 0.32869200E+03, 0.10741100E+04, -.42502300E+03, 0.17892200E+03, 0.47641100E+03, 0.21743500E+03, 0.11282000E+03, 0.21293000E+02, -.86528600E+02, -.53338900E+03, -.16255000E+03, 0.78044200E+02, 0.45811200E+02, -.58443300E+03, 0.26279900E+03, -.46738400E+03, 0.27842200E+03, 0.78473900E+02, 0.37534600E+03, -.24684600E+03, -.13393100E+03, -.52033000E+01, 0.26028300E+03, 0.37438700E+03, -.17793500E+04, 0.88006600E+03, 0.86858500E+02, 0.88401600E+03, -.72893900E+02, -.17882300E+03, 0.61845500E+03, 0.15296700E+03, 0.62040100E+03, -.10183700E+03, 0.91813600E+03, 0.41721900E+03, -.26012500E+03, -.56416900E+03, -.20253100E+03, 0.93896600E+02, 0.16793000E+03, -.24903600E+03, 0.38943100E+03, -.32561000E+01, 0.23592900E+03, 0.10003600E+04, 0.12559000E+02, 0.13398900E+02, -.58160200E+03, -.13681800E+02, -.21424000E+03, -.13597300E+03, -.90589000E+02, -.33541500E+03, 0.56051500E+02, -.25832800E+02, 0.38055600E+03, 0.46460900E+03, -.26091800E+03, -.36505100E+03, -.22890700E+03, 0.32825000E+03, -.23590700E+03, 0.47536400E+03, 0.12725000E+04, 0.33191800E+03, -.12336600E+03, -.37013600E+03, -.42874200E+02, -.42872400E+01, -.17624200E+03, 0.21052600E+02, 0.66447900E+02, 0.52989900E+01, 0.59523100E+02, 0.10644300E+03, 0.63704600E+02, 0.72516900E+02, 0.10723900E+03, 0.44816600E+01, -.95962400E+02, 0.17955900E+03, 0.43512600E+00, -.51139700E+02, 0.25630100E+02, -.51449200E+02, 0.48606800E+02, 0.55649800E+02, -.10700400E+03, -.42194900E+02, -.12956200E+03, 0.14467000E+02, 0.54368400E+01, 0.19205000E+03, -.23061900E+02, 0.49516700E+02, -.63231100E+02, 0.44027100E+02, 0.22343300E+01, 0.24001800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19614200E+00, -.11212900E+01, -.79706000E+00, -.22239800E+00, -.40788400E+00, -.34698200E+00, 0.67815400E+00, -.37916900E-01, 0.63982000E+00, 0.11422700E+01, 0.13814000E+00, -.10243400E+00, 0.98740000E+00, 0.46448500E+00, 0.46180800E+00, 0.17445200E+00, 0.38098800E-01, -.59272800E-01, -.39814800E+00, 0.16096300E+00, 0.56146800E-01, -.56105400E-01, 0.21725000E+00, 0.12033500E+00, 0.17608100E+00, 0.81713100E-03, 0.74629900E-01, 0.32065900E-01, 0.34754700E-01, 0.95671700E-01, -.18697300E+00, -.66008000E-01, -.15496800E+00, 0.52649100E+00, -.44357400E+00, 0.16957700E-01, 0.31203500E-02, 0.81328900E-02, 0.12652300E+00, -.51105100E+00, 0.53028800E+00, 0.10110600E+01, -.13252700E+00, 0.42449500E-01, -.13700700E+01, 0.47172500E+00, -.34634000E-01, -.19675100E-01, 0.60539100E-01, -.10919000E+00, -.93574800E-02, -.16800100E+00, -.18057400E+00, -.67492400E-01, -.49250700E-01, 0.17852000E-02, 0.16157300E-02, 0.25270400E+00, -.96087900E-02, 0.23018200E+00, 0.17908500E+00, -.54512100E-01, 0.95961300E+00, 0.14453300E+00, 0.26373400E+00, -.14426300E+00, 0.99363000E-01, -.10752200E+01, 0.37556600E-01, 0.37884800E-03, -.29852900E-01, -.90327900E-03, -.12370000E+00, -.12456500E-01, -.47166800E+00, 0.17768600E+00, -.81283100E-01, 0.92920400E+00, 0.44212000E-01, 0.29430800E-01, -.52961400E-02, 0.30780700E+00, 0.63049400E-01, 0.12611400E+00, 0.11750100E+00, 0.27600700E+00, -.11470400E+00, 0.39827700E-01, 0.43775900E+00, -.10789600E+01, -.18547200E+01, -.24266300E-01, -.10788600E+01, -.24286900E+00, -.18263300E-01, -.17403300E+00, -.29095200E+00, 0.48469600E+00, -.62391400E+00, 0.21577300E+00, -.17320500E+00, -.15214600E+00, -.45936700E-01, 0.28075100E+00, 0.15824300E+00, 0.10541500E+00, 0.21942400E-01, 0.14713300E+03, -.47745700E+01, 0.95914400E+02, 0.38546300E+03, -.19782200E+03, -.12237000E+03, -.19102200E+03, -.38079700E+02, -.15730000E+03, 0.15166500E+03, 0.45778400E+03, 0.16014900E+03, -.19784700E+03, -.96714000E+02, -.12286200E+03, 0.55291200E+02, 0.16616000E+03, 0.65556400E+02, 0.24126600E+03, 0.48559400E+03, -.28402600E+03, -.32183800E+03, -.35117700E+03, 0.38044400E+03, -.28900000E+02, 0.13939500E+03, -.69344000E+02, -.20695300E+03, -.78225100E+02, -.58750300E+02, -.11680900E+03, 0.61699000E+02, 0.65006500E+02, 0.87764600E+01, -.11311500E+03, -.76517900E+02, 0.11746300E+03, -.50026000E+02, -.10878300E+03, -.57534100E+02, -.63520000E+01, 0.91789100E+01, -.52396000E+02, 0.14073800E+02, -.18121400E+02, 0.48225300E+01, -.32970700E+02, 0.23744700E+03, -.11684000E+03, -.17260700E+03, -.11790300E+03, -.22106800E+03, -.23075800E+03, 0.15712000E+03, 0.28737800E+03, 0.17493700E+03, -.19492300E+03, -.74955000E+02, 0.33851400E+03, -.16026200E+03, 0.98147800E+02, -.17154500E+03, -.96109200E+02, 0.23782700E+02, -.13957000E+03, -.97532100E+02, -.23826000E+03, -.24370900E+01, -.80211700E+02, -.15728800E+03, 0.77016900E+02, 0.24500300E+03, 0.77785300E+02, -.11555100E+03, -.87885100E+02, 0.57251200E+02, -.23421800E+02, 0.20792500E+03, -.11895800E+03, 0.57595400E+03, 0.30646700E+02, -.21836300E+02, 0.23666400E+03, -.10492700E+02, -.16548300E+02, -.26509700E+02, -.31769900E+02, -.66982800E+02, -.54915000E+02, -.28702300E+02, 0.51342500E+02, -.81123300E+02, 0.38562200E+02, 0.46472000E+02, 0.39726600E+02, -.25767400E+02, 0.99406400E+02, -.87693700E+02, -.80288700E+02, 0.95832400E+02, 0.50741800E+02, 0.23576900E+03, 0.15189800E+03, -.70455800E+02, -.48337600E+02, -.76851600E+02, -.30852500E+02, -.92433300E+01, -.19834300E+02, -.14627100E+02, -.47923000E+02, -.13306800E+02, -.39401300E+02, 0.11296300E+01, 0.55008400E+02, -.18294600E+02, -.26150200E+00, 0.68400200E+01, -.13145300E+02, 0.16439100E+02, -.61124900E+01, -.66570200E+01, 0.19333800E+02, 0.18768700E+01, 0.17749400E+01, -.68585400E+02, 0.76044400E+01, -.20128000E+02, -.52096200E+02, -.21844600E+02, 0.17502400E+02, -.11034600E+02, -.19454300E+02, -.57251100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19930600E+00, -.65504800E+00, -.25927700E+01, -.84587500E+00, 0.16729900E+01, -.22215400E+00, 0.23692400E+01, 0.25094200E+00, -.21116100E+01, -.46915600E+00, 0.51588000E+00, -.17421900E+00, -.12802400E+01, 0.14866100E+00, -.82315300E+00, -.12421000E+01, 0.15324500E+01, 0.15023200E+01, -.27201100E+00, 0.30785000E+00, 0.72965900E-01, 0.20224500E+00, -.81102500E-01, -.66574000E-01, -.63765200E-01, 0.40112800E-03, -.57973800E-01, 0.11075400E+00, -.25927900E+00, -.56526100E-01, 0.48982200E+00, -.51146700E+00, 0.29132200E+00, 0.61899500E+00, 0.47313300E+00, 0.14386300E+00, -.49681100E-01, 0.13149500E+00, 0.27104000E+00, 0.74827400E-01, 0.32808600E-01, 0.12177600E+01, -.21227900E+00, 0.85507900E-01, -.87130900E+00, 0.46116000E+00, 0.15142000E+01, -.37963400E-01, -.18163400E+01, -.17018200E+00, -.31142200E+00, 0.56560700E-01, 0.90231900E+00, 0.18784200E+00, -.77606800E-01, -.17291700E+00, 0.23009700E+00, 0.17103300E+00, 0.42280300E-01, -.70991900E-01, 0.22656200E+00, 0.53606300E+00, -.84081500E+00, -.28149000E+00, 0.26937800E+00, 0.23760400E+00, 0.79828100E-01, -.43171400E+01, -.54942600E-01, -.13442300E-01, 0.27392700E+00, 0.42102300E+00, -.94147800E-03, 0.89780500E-01, 0.60029000E-02, -.10619400E+01, 0.68433100E+00, -.16095900E+01, 0.56588500E-01, 0.69848500E-01, -.16388000E-01, -.17783400E+00, -.11705800E+00, -.23543200E+00, -.26322000E+00, 0.17529300E+00, -.53702900E+00, 0.34376300E-01, 0.13049200E+00, 0.73837000E-01, -.16450800E+01, 0.52346900E-02, -.62349900E-01, -.14684200E+00, -.19317500E+00, -.31032900E+00, 0.94672600E-01, 0.13412500E+00, -.56726000E-01, 0.24675800E+00, -.24831300E+00, -.55298700E-01, 0.15153600E-01, 0.32977100E+00, 0.43970100E+00, -.40026300E-01, -.15163300E+00, 0.11004100E+01, 0.62977700E+02, -.70186200E+03, -.11288400E+04, 0.57038400E+03, 0.43951200E+03, 0.55937800E+03, 0.34645900E+03, 0.31329100E+03, -.17338500E+03, -.66725800E+02, 0.79146700E+02, 0.21140000E+03, 0.87354800E+03, -.77797300E+02, 0.42342200E+02, -.25170800E+03, 0.27714600E+02, -.20645300E+03, -.39555400E+03, 0.21712000E+03, 0.25250700E+03, 0.25126500E+03, -.25231800E+03, 0.27129600E+03, -.44875900E+03, 0.22104000E+03, 0.30734600E+03, 0.24194000E+03, 0.36286800E+01, -.43095300E+01, 0.26318300E+01, -.77337100E+02, 0.22667600E+03, 0.24253100E+02, 0.22357000E+03, -.81370500E+02, 0.39599100E+02, 0.14671500E+03, 0.39834900E+02, 0.12844500E+02, -.37896400E+02, 0.22341700E+02, -.10010800E+03, -.36176500E+02, -.63120800E+01, -.40415500E+02, -.47478800E+03, 0.23182700E+03, 0.19745000E+03, 0.23394600E+03, 0.32623100E+03, 0.22970500E+03, -.28661500E+02, -.24789500E+03, 0.37167200E+02, 0.15420600E+03, 0.78924100E+02, -.10290900E+04, 0.51618100E+03, -.54706700E+02, 0.51855300E+03, -.31445000E+02, -.90616400E+02, 0.49766100E+03, 0.64053300E+02, 0.34720800E+03, -.52500900E+02, 0.54857800E+03, 0.36191300E+02, -.28649300E+02, -.11318500E+03, -.14618400E+02, 0.72123500E+02, -.14009100E+02, 0.14371900E+03, 0.26903000E+03, -.14840500E+02, 0.46001400E+02, 0.17863000E+03, -.18944200E+03, 0.95687500E+02, -.26120600E+03, 0.84971200E+02, -.47551800E+02, -.58535900E+02, 0.12657300E+03, 0.38248800E+02, 0.66550200E+02, -.87285700E+01, 0.89069800E+02, -.27369300E+02, 0.11916000E+02, 0.20996400E+02, 0.16247000E+02, 0.19769100E+03, -.84518100E+02, 0.32391900E+03, 0.37484400E+03, -.89258600E+01, -.78179400E+01, -.12923700E+03, -.14753300E+03, 0.70479900E+02, -.80772400E+02, 0.75776100E+02, 0.19461300E+02, -.47518600E+02, 0.13925300E+03, 0.74869000E+02, 0.12653100E+03, -.18830400E+02, 0.75841000E+02, -.34147700E+01, -.94185500E+02, 0.57988800E+02, -.15508300E+01, -.23393300E+02, 0.22375500E+02, -.22063100E+02, 0.20392700E+02, -.21652700E+01, -.22990300E+02, -.36894900E+02, -.70791700E+02, 0.35005100E+02, 0.55810200E+01, 0.74180600E+02, 0.47486800E+02, 0.52798300E+02, -.56538300E+02, 0.12031900E+02, 0.12117000E+02, 0.12983400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11867900E+00, -.35929900E-01, 0.13238200E+01, 0.10170000E+00, -.10799300E+01, -.55737500E-01, 0.73322100E+00, -.37194000E-01, 0.87265800E+00, 0.11555100E+01, -.12636500E+00, -.89949000E-01, 0.98720600E+00, 0.36491400E+00, 0.14866700E+00, 0.70790400E+00, -.92379100E-01, -.24445900E+00, 0.11024700E+00, 0.94201500E-02, 0.47505600E-01, 0.34247600E-01, 0.10814400E+01, 0.78142900E-01, 0.17456400E+00, 0.15452900E-03, 0.18280800E+00, 0.61731000E+00, -.21372900E+00, 0.42373600E-01, -.26677000E+00, -.12375900E+00, -.26316200E+00, -.34669100E-01, 0.45418200E+00, 0.41774200E-01, 0.88837300E-01, -.65639700E-01, -.10021800E+00, 0.42357700E+00, -.80817700E+00, 0.35140100E-01, 0.19381400E-01, 0.22065600E-01, 0.52338500E+00, -.13882000E+00, -.51897800E+00, 0.89703300E-01, -.79236100E+00, 0.21347900E+00, 0.16588100E+00, 0.50648700E+00, 0.84109000E+00, 0.11213800E+00, 0.84945700E+00, -.11731000E+00, 0.20080000E+00, -.54477500E+00, 0.10874300E-02, 0.22185500E-01, -.17651400E+00, -.16216900E+00, 0.72957200E+00, 0.12223300E+00, 0.40441300E+00, -.59623100E-01, 0.10407800E+00, 0.38631600E+01, 0.12311800E-01, 0.64344100E-02, -.21026300E-02, 0.10162600E+00, 0.46248400E-01, 0.14487300E+00, -.37922200E-01, 0.34755500E-01, -.96135000E-01, 0.54243600E+00, 0.65527100E-01, 0.10599100E+00, -.14788800E-01, 0.14350300E+00, 0.11375700E+00, -.21049400E+00, 0.13573500E-01, -.10020200E+00, -.10921500E-01, 0.89459600E-01, -.26882400E-01, 0.65810300E-01, 0.64192000E+00, 0.29110300E-01, 0.34739500E+00, -.21413600E+00, -.91715700E-01, 0.12153200E+00, 0.14236000E+00, -.12096200E+00, -.28900100E-02, -.44948900E-01, -.69420700E-01, 0.55290700E-01, 0.53381600E-02, 0.14855900E-02, -.70528600E-01, 0.54062200E-01, -.44961800E-01, 0.46439400E-01, 0.37837600E+00, 0.32763800E+03, 0.45019200E+03, -.22322000E+03, -.17877100E+03, -.22463300E+03, -.15042700E+03, -.86592300E+02, 0.31283300E+02, 0.63320500E+02, -.69789300E+02, -.47785900E+02, -.33130500E+03, 0.85233600E+02, -.42507900E+02, 0.10843500E+03, -.40910000E+02, 0.11160900E+03, 0.21353200E+03, -.97429300E+02, -.10632300E+03, -.14061700E+03, 0.15087700E+03, -.90808100E+02, 0.10256200E+03, -.51595200E+02, -.13275500E+03, -.52879100E+02, -.39976400E+01, -.29654900E+02, 0.11673500E+02, 0.19098300E+02, -.67350200E+02, -.23800100E+02, -.56946000E+02, 0.49304800E+01, -.85174600E+01, -.49280300E+02, -.30399900E+01, -.21037500E+02, -.23061200E+02, 0.20691000E+02, 0.36125000E+02, 0.42984200E+02, -.29461000E+02, 0.14653700E+02, 0.21176100E+03, -.10592000E+03, -.94375700E+02, -.10389500E+03, -.11753200E+03, -.90530300E+02, 0.90624800E+00, 0.11056000E+03, 0.98744300E+00, -.65931600E+02, -.95111600E+02, 0.40746400E+03, -.20572400E+03, -.50068200E+02, -.20222400E+03, -.66782500E+01, 0.30108100E+02, -.19903900E+03, -.54534000E+02, -.10987000E+03, 0.73391000E+01, -.19959700E+03, -.84072300E+02, 0.43434600E+02, 0.12801500E+03, 0.41352300E+02, 0.57663000E+02, -.21505300E+02, -.77041800E+01, -.28246000E+02, 0.52028800E+02, -.25034600E+02, -.89597600E+02, -.10521000E+02, 0.76008200E+01, 0.15158000E+03, 0.65086600E+01, 0.17663800E+02, 0.11140700E+02, -.70325700E+01, -.71793200E+01, 0.29749400E+02, -.11660800E+02, -.42735800E+02, -.20826200E+02, 0.82587300E+01, 0.99396200E+01, 0.10548200E+02, -.85033500E+02, -.21223800E+02, -.64463200E+02, -.79226500E+02, 0.64761200E+02, -.43751000E+02, 0.14868900E+03, 0.30885000E+02, -.16003300E+02, 0.41935500E+02, -.14927800E+02, -.20352900E+02, 0.23492600E+02, -.41021800E+02, -.30959500E+02, -.34324900E+02, 0.10015000E+02, -.23676700E+02, 0.18774800E+01, 0.25365900E+02, -.36283000E+02, 0.70084400E+00, 0.33929100E+01, -.49471300E+01, 0.10907700E+02, -.24768200E+01, -.19777700E+01, 0.11518100E+02, 0.17852300E+02, 0.26737300E+02, -.18387000E+02, 0.26097800E+00, -.35183700E+02, -.20162100E+02, -.13699700E+02, 0.11194900E+02, -.41363500E+01, -.11483400E+02, -.71288400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.58463100E-01, -.50830000E-01, 0.43485500E+00, -.90629200E-01, -.88074900E-01, 0.80414600E-01, -.27294700E+00, 0.43789400E-01, 0.43389800E-01, -.22693900E+00, -.26801700E+00, 0.31183300E-01, -.20773600E+00, -.82744200E-01, 0.67011500E-01, -.10708200E-01, -.42704900E+00, 0.68393600E-01, 0.22851400E+00, -.22498000E+00, -.49784800E-01, 0.17291900E-01, 0.67264400E-01, 0.61174500E-03, -.12828400E-02, 0.18791600E-04, 0.88417100E-02, 0.11307200E+00, 0.46760600E-02, 0.62352200E-01, -.32354300E-01, 0.47440600E-01, -.48366000E-01, -.26461300E-01, 0.22672400E-01, -.20322000E-01, 0.93398300E-02, -.30583400E-02, -.51702200E-02, 0.86960000E-01, -.68545200E-01, 0.17552300E-01, 0.10903400E-01, 0.16376400E-02, -.91865400E-01, -.47610700E-02, 0.16907300E+00, 0.73988200E-02, -.10773100E+00, -.54644600E-01, -.28957800E-01, -.52751900E-01, -.80825400E-01, 0.43635300E-01, 0.20455500E-01, 0.46465800E-01, -.13361500E+00, 0.11423800E+00, -.22204100E-01, 0.83935200E-01, -.64147500E-01, -.67565800E-01, -.24141600E+00, 0.60073200E-02, 0.97046700E-03, -.35097300E-01, -.28087900E-01, 0.73134900E+00, -.25357700E-02, -.78775700E-04, 0.93443000E-02, 0.41700000E-01, 0.29727000E-01, 0.21606400E-02, -.35816200E-02, -.23476200E+00, 0.10651300E+00, -.22151300E+00, 0.19015400E-01, 0.32560000E-01, 0.34987500E-02, -.20633800E-01, -.56552200E-01, -.47450300E-01, -.11916600E+00, 0.90758800E-01, -.60029900E-01, -.11398900E-01, 0.34573800E-01, -.21792300E-01, -.21862200E+00, -.23428400E-02, 0.28213100E-01, 0.83337200E-01, 0.23052800E-01, 0.62966800E-02, 0.39343500E-01, 0.42420500E-01, 0.46694000E-01, 0.12217800E+00, -.87675300E-02, -.15954100E-01, -.13498900E-03, -.57464100E-01, 0.37236700E-01, -.32458800E-01, -.35330700E-01, 0.58677600E-01, -.92438400E-01, 0.85883900E-01, -.24911800E+03, 0.12826700E+03, 0.11903000E+03, 0.12398200E+03, 0.12842500E+03, 0.10885200E+03, -.31381700E+02, -.65465100E+02, -.26547700E+02, 0.90393000E+02, 0.56060700E+02, -.15917000E+03, 0.82153500E+02, 0.23987700E+01, 0.78004600E+02, -.64127900E+02, -.16122100E+03, 0.11122500E+03, 0.54458400E+02, 0.11680900E+03, -.12199900E+03, 0.81598300E+02, -.10998200E+03, 0.54149100E+02, 0.85633600E+02, 0.56649500E+02, 0.57213600E+01, 0.44594900E+02, -.20388100E+02, -.26918000E+02, 0.33805800E+02, 0.37583400E+02, 0.73110900E+02, -.59619400E+02, 0.27215700E+02, 0.54716000E+02, 0.30067900E+02, 0.13011900E+02, 0.97106000E+01, -.31616700E+01, -.45124400E+02, -.10807500E+02, 0.14102400E+02, 0.13798800E+02, -.95052500E+02, 0.45559500E+02, 0.18169800E+02, 0.46211000E+02, 0.56405200E+02, 0.59831200E+02, -.30656200E+02, -.68359100E+02, -.19134100E+02, 0.54386300E+02, 0.48649600E+02, -.26337000E+03, 0.13020700E+03, -.26548400E+02, 0.13103000E+03, -.14138800E+02, -.32469600E+02, 0.10907100E+03, 0.37427000E+02, 0.10140600E+03, -.14003700E+02, 0.16274800E+03, 0.23259500E+03, -.12066500E+03, -.17925200E+03, -.11583200E+03, -.36273100E+02, 0.79480900E+02, -.69676700E+02, 0.96892700E+01, -.89298700E+02, 0.77216300E+02, -.28700100E+02, 0.25881900E+02, -.10854500E+02, -.14563000E+03, -.14003600E+02, -.19084700E+02, -.10854400E+02, -.17722600E+02, -.27915500E+02, -.76846100E+01, 0.33144100E+01, 0.14064300E+02, 0.13107600E+03, -.66874500E+02, -.44380100E+02, -.65431100E+02, 0.17286100E+02, 0.27933100E+01, 0.23802300E+02, 0.97710600E+02, -.37978200E+02, 0.13219500E+02, -.61436000E+02, -.65303600E+02, 0.30245300E+02, -.49795500E+01, 0.32484900E+02, 0.92658800E+01, -.14663100E+02, 0.24330100E+02, 0.11823000E+02, 0.32303700E+02, -.14014800E+01, 0.84940300E+02, -.12950900E+01, -.22674800E+02, 0.13569000E+02, 0.16374000E+01, -.54931800E+01, 0.72468900E+01, -.10010700E+02, 0.52099100E+01, 0.75556300E+01, -.76766100E+01, -.82501100E+00, -.47337200E+01, 0.11621300E+02, 0.40716300E+01, 0.13685300E+02, 0.86469700E+01, 0.10676300E+02, -.79126100E+01, 0.62042400E+01, 0.58698100E+01, 0.29774700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18402000E+00, 0.10142900E+01, 0.56085700E+00, 0.12461800E+00, 0.34985900E+00, 0.29913400E+00, -.48370900E+00, 0.98063600E-01, -.17858600E+00, -.83676800E+00, -.14952400E+00, 0.18752600E-01, -.54250900E+00, -.33587400E+00, -.51612600E+00, 0.19592700E+00, -.66089900E+00, 0.18221600E-01, 0.17348900E+00, 0.22455300E+00, -.36540900E-01, 0.10420500E+00, -.10507700E+01, -.18461600E+00, -.24593500E+00, -.13460900E-02, -.18608200E+00, 0.26385700E+00, -.75446000E+00, 0.32347100E+00, 0.14806700E+00, 0.55354500E+00, 0.10347600E+00, -.17861100E+00, 0.19686900E+01, 0.10896200E+00, -.64060700E-01, -.15254600E+00, 0.24568700E+00, 0.15154800E+01, -.15445700E+01, -.30423000E+00, 0.14344800E+00, 0.61249300E-01, 0.24766700E+01, -.53552800E+00, -.76141600E+00, 0.29973700E-01, -.73719600E+00, 0.88437100E-01, 0.53024200E+00, 0.59092700E+00, -.29811100E-01, -.16415800E+00, 0.18319200E+00, 0.85958300E-02, -.59419800E+00, -.17914200E+00, -.51765200E-01, 0.50253700E-01, -.81535600E-01, -.27512700E+00, -.30891300E+00, -.74754900E-02, -.10879300E+00, -.82692800E-01, 0.58190900E-01, -.41374500E+00, -.92206000E-01, 0.42667900E-02, -.36009700E+00, -.40529700E+00, 0.41955400E-01, -.38958800E-01, -.34055800E-02, -.32303900E+00, -.72168300E+00, 0.16945700E+01, 0.76942000E-01, 0.98143500E-01, -.29820200E-01, -.10213400E+00, 0.35683700E+00, 0.41166300E-01, 0.30572200E+00, -.13823900E+01, 0.33764800E+00, 0.95279800E-01, -.36362900E+00, 0.93825000E+00, 0.11519000E+01, 0.53746600E-01, 0.57585200E+00, -.30043700E+00, 0.49232900E-02, 0.61005900E+00, 0.80216400E+00, -.30612700E+00, 0.94067100E+00, -.41401400E+00, 0.35524400E+00, -.37953800E+00, 0.34402800E-01, -.49908100E-01, 0.53246200E+00, -.23230100E+00, 0.60063800E-01, -.45329000E+00, 0.59465300E+00, 0.14287800E+01, 0.35236900E+00, -.19309800E+02, -.62955500E+02, 0.16638400E+01, -.21664900E+03, -.16762500E+03, 0.58650900E+02, -.10986800E+03, 0.19689700E+03, -.18247600E+03, 0.19202000E+02, 0.39234700E+02, -.30565900E+02, 0.36902400E+02, -.16122200E+02, 0.16442700E+03, 0.63231700E+02, -.87502200E+02, 0.46832300E+02, 0.28615900E+02, 0.23603500E+02, -.25873200E+02, 0.46718000E+03, -.22854700E+03, -.15085800E+03, -.23938900E+03, -.32201900E+02, -.51137300E+02, -.89820800E+01, 0.10367200E+03, -.12546000E+03, -.64105800E+02, -.22603700E+03, 0.29929900E+03, -.12711100E+03, -.15837600E+03, -.14916200E+03, -.23498000E+02, 0.87798100E+01, -.56092100E+02, 0.68560300E+02, -.66936800E+02, -.18462900E+01, -.12580400E+03, 0.22937100E+03, -.10609800E+03, 0.35699100E+02, -.11394500E+03, -.74282000E+01, -.11732500E+01, -.31738700E+01, 0.35704000E+02, -.78410200E+02, -.37939900E+01, -.13824700E+03, 0.51210100E+03, -.24613300E+03, -.84572600E+01, -.25778200E+03, 0.50450500E+02, 0.56368800E+02, -.17735200E+03, 0.55861000E+02, -.23434700E+03, 0.31345000E+02, -.23232400E+03, 0.14956300E+03, -.66034200E+02, -.46291800E+02, -.75642600E+02, -.13075600E+03, 0.17053500E+02, -.66058000E+02, -.40604700E+02, -.11215600E+03, -.12564600E+02, -.60386100E+02, 0.22146600E+03, -.12591900E+03, 0.28042200E+02, -.10771300E+03, 0.50965000E+02, 0.36826800E+02, -.47634600E+02, 0.87766800E+02, -.11547300E+03, 0.18801900E+02, -.80361500E+02, 0.62394100E+01, 0.88640200E+01, -.23867100E+02, -.40616100E+01, 0.11475000E+02, 0.15305900E+03, -.14699700E+03, -.21336700E+03, -.20755900E+03, 0.11232600E+03, 0.28812100E+02, 0.14956000E+03, -.64661400E+02, -.87907000E+02, -.75603500E+02, 0.87803200E+00, -.11540400E+02, -.36509800E+02, -.15844100E+01, -.93993300E+02, -.21667500E+02, -.62189100E+02, -.83037700E+00, 0.33371100E+02, 0.33561600E+01, -.65271800E+00, 0.27244200E+02, -.10605300E+02, 0.48712000E+01, -.26795900E+02, -.22997400E+01, 0.19894800E+02, 0.39957600E+01, 0.11924700E+02, 0.21804400E+02, 0.48599500E+00, 0.75823500E+01, 0.11947400E+02, -.11799000E+02, 0.11999700E+02, -.37362100E+01, 0.72787200E+01, 0.38426900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.71323200E-01, 0.21504600E-01, -.15493000E+00, 0.50637800E-01, 0.11645900E+00, -.82077700E-01, 0.22611900E+00, -.47635100E-02, -.94452200E-01, 0.88259800E-01, 0.26481500E-01, -.25944400E-01, -.53806300E-01, -.45356000E-01, -.57008000E-01, -.69229700E-02, -.69794500E-01, -.14354700E-01, -.12547300E-01, -.52981300E-01, -.56164300E-02, -.58016300E-02, -.10999900E+00, -.54257200E-02, 0.20393300E-01, 0.78669400E-04, -.10927800E-01, 0.32012100E-01, -.22209800E-01, 0.91529400E-01, 0.18418400E-01, 0.10827000E+00, 0.27360900E-01, 0.41468100E-01, -.12183600E+00, -.19741600E-01, -.17308900E-01, 0.85066700E-02, 0.31859900E-01, -.40690400E-02, 0.28462100E-01, -.46259500E-01, -.13401200E-01, -.31466000E-01, -.32398900E-01, 0.48256000E-02, 0.16868700E-01, -.31385700E-02, 0.28845700E-01, -.12088000E-02, 0.11260200E-01, 0.64416000E-01, -.73351900E-02, -.52838400E-01, -.55010200E-01, -.22641800E-01, 0.12147400E+00, -.18538400E+00, 0.16323500E-01, -.13880600E-01, -.37640100E-01, -.84163200E-02, -.21281700E+00, 0.50092800E-02, 0.17101400E+00, -.16892000E-01, -.38404800E-02, 0.46322100E+00, -.89740300E-02, 0.13320700E-02, 0.43940900E-01, 0.94659700E-01, 0.36081200E-01, 0.95387100E-03, 0.61483800E-03, 0.24679000E-01, 0.15954500E+00, 0.59597100E-01, -.10699600E-03, 0.22318200E-01, -.56991300E-02, -.61234600E-01, -.49209800E-01, -.79817000E-01, -.26272400E-01, -.12735000E-01, -.55540800E-02, 0.66276300E-03, 0.23453700E-01, 0.63819000E-01, 0.86844900E+00, 0.74127700E-02, 0.63081800E-01, 0.75591600E-01, 0.40988500E-01, -.72851200E-01, -.54624300E-02, -.27280400E-01, 0.28147100E+00, -.35618600E-01, -.33842300E-01, -.35808000E-01, -.97486200E-02, 0.70833800E-02, 0.97419800E-01, -.17250300E-01, -.30870400E-01, -.65254000E-01, -.31312500E-01, -.51208300E-01, 0.28892100E+00, -.71921100E-01, -.86854000E+02, 0.24491300E+00, -.51633600E+02, -.17288900E+01, 0.91657900E+01, -.27001900E+02, 0.43867900E+01, 0.19257600E+02, 0.15806700E+02, 0.88035900E+02, -.44513600E+02, -.54252000E+02, -.43408400E+02, -.76792400E+00, -.33230100E+01, -.38942200E+00, 0.32286800E+01, -.41171800E+02, -.93525800E+00, -.20337200E+02, 0.31785400E+02, -.16261000E+02, -.10031000E+02, -.15877400E+02, -.74436500E+01, -.32789900E+02, 0.22360500E+02, 0.13471900E+02, 0.85711300E+01, -.27676900E+02, -.15873400E+02, 0.15647800E+02, -.68615600E+01, -.95506600E+01, -.82302900E+01, -.49655300E+01, -.20006800E+01, -.10510000E+02, 0.17714400E+02, 0.11658200E+02, -.53584900E+01, 0.60322100E+01, 0.20165700E+02, -.10621100E+02, 0.15336500E+02, -.93339000E+01, -.94146000E+01, -.13913200E+02, 0.57191900E+01, 0.19003800E+02, 0.95101700E+01, -.12702300E+02, -.17563000E+02, -.12650300E+02, 0.82775700E+01, -.35266300E+01, 0.69686500E+01, 0.12817100E+02, 0.31588700E+02, -.29096500E+02, -.40356600E+02, -.85801300E+01, 0.18350300E+02, -.85120100E+00, -.94945100E+02, 0.45781800E+02, 0.31644500E+02, 0.47246400E+02, 0.17263000E+01, -.34446100E+02, 0.40011300E+02, 0.17231100E+02, 0.42172000E+02, -.35988200E+02, -.50739900E+02, 0.18618700E+01, -.24123800E+01, 0.29287800E+02, -.90208400E+00, 0.33027300E+01, 0.89074800E+01, 0.59804900E+01, 0.25310800E+02, 0.12108600E+02, -.33633200E+01, -.18305500E+02, -.20217500E+01, 0.61596200E+00, -.13490000E+01, 0.97510900E+00, -.22007900E+02, -.42015700E+02, 0.25419000E+02, 0.16299900E+02, 0.34840300E+02, -.40006400E+02, -.17508300E+02, 0.16081900E+02, -.77056700E+01, 0.19073800E+02, -.78692000E+01, 0.99107900E+01, 0.75128200E+01, -.13594000E+02, 0.54498700E+01, -.76375000E+01, 0.37594400E+01, -.37239000E+02, 0.96977600E+00, -.40058200E+01, -.12893000E+01, 0.48261100E+00, 0.22412100E+01, -.50301800E+00, 0.43160000E+01, -.18352500E+01, -.33706500E+01, 0.87932700E+00, 0.17313100E+01, 0.98998700E+01, -.10850000E+02, -.43057600E+01, -.36527100E+01, -.10178600E+01, 0.47920300E+01, 0.19042600E+01, -.20205200E+01, -.57660500E+01, -.23556300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.97626700E+00, 0.13944500E+01, 0.71921300E+01, 0.49677600E+01, 0.77811900E+01, -.55901400E+01, 0.84631300E+01, -.16047300E+01, 0.15675800E+01, 0.71845000E+00, 0.65002500E+00, -.96254000E+00, 0.15989400E+01, -.64982600E+00, -.23580300E+00, 0.12515600E+01, 0.64011900E+00, -.40698600E+00, -.48531400E+00, 0.34581500E+00, 0.25044700E-01, -.22005800E+00, -.14093500E+01, -.42341700E-02, -.12622400E+00, -.17186700E-02, -.67686500E-01, -.75715700E+00, 0.33875600E+00, -.29714900E+00, 0.74991000E+00, -.11639400E+01, 0.10459700E+01, 0.53048500E+00, -.12371900E+01, 0.17877400E-01, 0.34593500E-01, 0.21331900E+00, -.98639800E-01, -.11013800E+01, 0.15873100E+01, -.11232000E+01, -.37070900E-01, -.92739600E-01, -.22396900E+01, 0.49789800E+00, 0.11046900E+01, -.48059600E+00, 0.76634600E+00, -.70097300E-02, 0.29362900E+00, -.35389100E-01, -.10960100E+01, 0.12801200E+00, -.66723400E+00, 0.13358500E+00, 0.51561000E+00, 0.40991400E+00, 0.42288100E+00, -.26560800E+00, 0.35892400E-01, -.13318100E+01, 0.14941700E+01, 0.30311500E+00, 0.10948700E+01, 0.66053900E+00, -.39476100E+00, -.49459700E+01, 0.28230600E+00, 0.31312200E+00, 0.52577100E+00, 0.18675000E+00, 0.72774600E-01, 0.14199600E-01, 0.63666700E-03, 0.45498600E+01, -.31236200E+00, 0.33405300E+01, -.17866900E+00, -.55625700E+00, 0.18366600E+00, 0.16384200E+00, 0.20316500E+00, 0.47610500E+00, -.17404000E+00, -.25168100E+01, 0.14036500E+01, -.27075200E+00, -.15209400E+01, 0.35972200E+00, -.29048900E+00, -.15784900E+00, -.76703000E+00, 0.41729700E+00, -.11736400E+00, -.50371400E-01, -.57235500E+00, -.14093700E+00, -.24674200E-01, -.41925200E+00, 0.24815300E+00, -.11363800E+00, -.72503000E-01, 0.17113100E+00, 0.77478000E+00, 0.23056700E+00, -.10077100E+00, 0.33414000E+00, 0.11318000E+01, 0.28847600E+01, 0.20230300E+01, 0.12917400E+01, -.14757100E+00, 0.39539700E+02, -.23847400E+03, -.23862300E+03, 0.57305200E+03, 0.56745900E+03, 0.31401200E+03, -.23030900E+03, 0.54336700E+02, -.67870600E+03, 0.34007400E+03, 0.43951500E+03, 0.35447600E+03, 0.44021600E+02, 0.16678000E+03, 0.50734800E+02, -.27995400E+03, -.15028200E+02, 0.12366400E+03, 0.13397600E+03, -.31755400E+03, 0.15886000E+03, -.71155700E+02, 0.13854600E+03, -.31686900E+01, 0.63609200E+02, 0.32710700E+02, -.11588300E+03, 0.24291300E+02, 0.27423000E+02, 0.28469400E+03, -.29761300E+02, 0.19704700E+02, -.19799300E+02, 0.18757000E+02, 0.75003000E+02, 0.11878100E+03, -.14489000E+03, -.22935300E+02, -.44631100E+02, 0.11005100E+03, 0.10607500E+03, -.12448300E+03, 0.63740800E+02, -.87937000E+02, 0.54366100E+02, -.20604200E+03, -.15599800E+03, 0.12445400E+03, 0.17763000E+03, -.45718000E+01, -.92066100E+02, 0.16739200E+03, -.29017200E+03, 0.14051400E+03, -.13772900E+02, 0.12219100E+03, 0.99738100E+01, 0.51223700E+02, -.11602500E+03, -.20612400E+03, 0.24533200E+02, 0.34936900E+01, 0.16845600E+03, -.94301300E+03, 0.48432000E+03, 0.36815000E+03, 0.46751300E+03, -.10781200E+03, -.25690400E+03, 0.32099300E+03, 0.21176000E+02, 0.66239200E+03, -.37593300E+03, 0.13904700E+04, -.31230200E+03, 0.15384500E+03, 0.23510200E+03, 0.16342900E+03, -.92654700E+00, 0.53408400E+02, -.13002500E+02, -.62919000E+02, 0.15328800E+03, -.14602600E+02, 0.48518800E+03, 0.77413200E+03, -.38945900E+03, -.46917400E+03, -.39700400E+03, 0.51756400E+02, -.41196600E+02, -.23204500E+03, 0.82079200E+02, 0.13243300E+03, -.11003400E+03, -.36330500E+02, 0.32300600E+03, -.16063200E+03, -.96691200E+02, -.17201000E+03, 0.31945100E+01, 0.81575000E+02, -.14561200E+03, 0.73286700E+01, -.94601800E+02, 0.52789700E+02, -.48346400E+02, 0.18771000E+01, -.24085100E+01, 0.41621900E+02, -.25815100E+01, -.69400600E+01, -.17524700E+02, 0.20127500E+02, 0.88412600E+01, 0.23069800E+02, -.32018600E+00, -.86388300E+01, -.22270300E+02, -.32740700E+02, 0.13084900E+02, 0.31949500E+01, -.51553000E+02, 0.48856100E+01, 0.77916700E+02, 0.20522300E+02, -.61810400E+02, -.11286000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.57804700E+00, -.53657100E+00, 0.34827700E+00, -.48514800E+00, -.41614100E+00, -.16191500E+00, 0.16649900E+00, 0.95077400E-01, 0.92441800E+00, 0.58620400E+00, -.82622300E-01, -.48285500E-01, 0.11818800E+01, 0.19486600E+01, 0.60934800E+00, -.61466300E+00, 0.13087000E+01, 0.68016600E+00, -.28061700E+00, 0.64643900E+00, 0.12030000E+00, 0.11061000E+00, 0.12059100E+01, 0.76547700E-01, 0.12465900E+00, -.86216100E-03, 0.30409600E+00, 0.19323800E+01, -.62338700E+00, 0.30792400E+00, -.95684500E+00, 0.97891900E-01, -.96545000E+00, -.38820600E+00, 0.22622600E+01, 0.30081500E+00, 0.24409500E+00, -.31806000E+00, -.39980400E+00, 0.17532000E+01, -.22140800E+01, -.46057000E+00, 0.40120500E+00, 0.16890000E+00, 0.13578100E+01, -.42791400E+00, -.91740500E+00, 0.12465800E+00, -.40047000E+00, -.70310000E+00, -.51745200E-01, -.46013000E+00, -.39552900E+00, 0.44274400E-01, 0.64368800E+00, 0.43446500E+00, -.11376600E+01, 0.52971300E+00, -.25388000E+00, 0.17815500E-01, -.52494100E+00, -.76657200E+00, -.22368800E+01, -.33528100E-01, -.10204500E+01, -.45977400E+00, -.29756600E+00, 0.34380900E+01, -.85811800E-01, -.13894400E-01, -.27595700E+00, -.15207300E+00, 0.34259100E+00, -.37263300E+00, 0.52643600E+00, -.19922500E+01, 0.32002100E+00, -.47244500E+00, 0.35791700E-01, 0.69720500E-01, -.55953900E-01, -.62988000E+00, -.31124400E+00, -.40707000E+00, -.51789600E+00, 0.81285800E+00, -.16627900E+00, 0.15159500E-01, 0.29012200E+00, 0.85883300E+00, -.56322300E+00, 0.27241600E-01, 0.10545900E+01, 0.54054200E+00, 0.53178100E+00, 0.97488100E+00, 0.12846200E+00, -.11717600E+00, 0.12659000E+00, -.72518000E-01, 0.47147400E-01, -.11352200E+00, 0.31291100E-02, -.29870100E+00, 0.51519500E+00, 0.23448400E-01, 0.26274100E+00, -.17159900E+01, 0.48517600E+00, 0.23162700E+01, -.19004200E+01, 0.66867500E+00, -.10090400E+01, 0.16915100E+00, 0.53574200E+03, -.21655400E+02, 0.15090500E+03, 0.36619400E+03, 0.29998600E+03, -.72045400E+02, 0.78094800E+02, -.17305900E+02, 0.62979300E+01, -.92592700E+01, 0.18298300E+02, 0.42443100E+02, 0.26585900E+03, -.30138300E+03, -.28267300E+03, -.38381500E+03, 0.23523000E+03, -.32867200E+03, 0.20352300E+02, -.10096100E+02, -.12084600E+02, -.30407800E+02, -.12371400E+03, -.97178300E+02, 0.14868200E+03, 0.11433500E+03, 0.67405000E+02, -.11377600E+03, -.48142100E+02, -.95852100E+02, 0.59648800E+02, 0.32206400E+02, 0.51194600E+02, 0.71567700E+02, 0.14912200E+03, -.13456300E+03, -.78151800E+02, -.97146500E+02, 0.13725100E+03, 0.96752600E+02, 0.57712300E+02, -.27974400E+02, 0.26869700E+03, -.29561100E+02, -.21357500E+03, -.21002700E+03, 0.19304100E+03, 0.16461200E+03, 0.20978300E+03, -.19441200E+03, 0.25139400E+03, 0.45164700E+02, -.15225800E+02, 0.56041300E+03, -.31535100E+02, -.20779700E+03, -.94381200E+02, 0.16705700E+03, 0.18435500E+03, -.80980200E+02, -.11537400E+03, 0.12141700E+03, -.33991900E+03, 0.16001200E+03, -.15397100E+03, 0.16717200E+03, -.54414100E+03, -.14865800E+03, 0.72749000E+02, -.29303800E+03, 0.11150100E+03, -.84775900E+02, 0.13679800E+04, 0.40392000E+03, -.20556700E+03, -.17071100E+03, -.19144800E+03, -.10502400E+03, -.90888600E+02, -.18047800E+03, -.20821500E+03, -.25100300E+03, -.37607600E+02, 0.11493200E+03, -.92924500E+02, 0.41861300E+02, 0.14386700E+03, 0.43290200E+02, -.77964700E+02, 0.12434500E+03, -.19224400E+03, -.19023500E+03, -.39064800E+02, 0.15589600E+03, 0.60931500E+02, 0.25490400E+03, -.12634400E+03, 0.10351400E+03, -.13112300E+03, -.99092700E+01, -.16291600E+02, -.31825800E+02, -.23172900E+01, -.51213100E+02, -.14881100E+02, 0.80919300E+02, -.14303800E+01, 0.87314200E+02, -.66345400E+00, 0.35334200E+01, -.94406200E+01, -.23148800E+02, 0.31069200E+01, 0.10417500E+02, -.37296900E+01, -.22159400E+01, -.12451400E+02, -.80093800E+01, -.90804800E+02, 0.10656700E+02, -.30395000E+02, -.23243300E+02, -.34284400E+02, 0.25333400E+02, -.18457600E+02, 0.17368200E+02, -.11464400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10118300E+00, -.28065100E-01, 0.18494500E+01, 0.89608200E-01, -.12868500E+01, 0.16312900E+00, -.14892000E+01, -.19914300E+00, 0.25232900E+01, 0.69350500E+00, -.68637200E+00, -.15888500E-01, 0.31067500E+00, 0.80345900E-02, 0.97536400E+00, 0.27170000E+00, 0.24743300E+00, -.77517400E+00, 0.85048600E+00, -.29368300E+00, -.52927400E-01, 0.51007300E-01, 0.41830200E+00, 0.93227400E-01, 0.15007500E+00, -.35831400E-04, 0.11843200E+00, -.22025000E+00, 0.78099700E+00, -.61526600E+00, -.40217300E+00, -.22278100E+00, -.47858000E+00, 0.55803000E+00, -.11677600E+00, -.17958500E+00, 0.23443500E+00, 0.84631500E-01, -.37936700E+00, -.70186900E+00, 0.54248900E+00, -.13948500E-01, 0.12204700E+00, 0.11673500E+00, -.16738500E+01, 0.24719500E+00, 0.20004100E+00, 0.14388600E-01, 0.28352000E+00, 0.88349200E-01, -.30398600E+00, 0.70761200E-01, 0.28882700E+00, -.50500400E-01, -.31571900E+00, 0.20237300E+00, 0.17862800E+00, 0.64840500E+00, -.27793200E-01, 0.16113600E+00, 0.11036300E+00, -.33719000E+00, 0.79345000E-01, 0.30976900E-01, -.36822600E+00, -.33338000E-01, 0.18764800E-01, 0.89109600E+00, 0.11302500E+00, 0.41916700E-02, -.19957900E-01, -.20306000E+00, 0.13370200E+00, 0.61310500E-01, 0.13615000E+00, 0.74203300E-01, -.19101900E+00, 0.12855400E+00, -.85104000E-02, 0.10281900E+00, 0.13687500E-02, 0.66724100E+00, -.45818300E+00, -.24105000E-01, -.18115000E+00, 0.63173600E+00, -.75913900E-01, -.84095400E-01, 0.31306300E+00, -.12867500E+00, -.12844100E+01, -.45653200E-01, -.72964800E+00, -.86787000E-01, -.90084600E-01, -.64253800E-02, 0.21374800E+00, 0.23111800E+00, -.43106200E+00, 0.48693200E+00, -.46985800E+00, 0.91597000E-01, 0.16837800E-01, 0.11852400E+00, -.22278400E+00, 0.17033700E-01, 0.10005000E+00, 0.58636700E+00, 0.11105400E+00, 0.46374500E+00, 0.22439900E+00, -.19706200E+00, 0.34932900E+00, 0.18853000E-01, -.13726900E+00, -.11511800E+03, 0.77920600E+02, 0.24678800E+02, 0.16718300E+03, -.12264000E+03, -.31533600E+02, -.27449900E+03, 0.13763000E+03, 0.91414200E+02, 0.13894800E+03, 0.69525700E+02, -.43859400E+01, -.30626900E+01, -.38245400E+02, -.17282100E+02, 0.81742500E+01, -.48287400E+02, -.65207300E+02, 0.32983500E+02, 0.10648400E+03, 0.25879200E+02, -.28317500E+02, 0.35589000E+02, 0.53906600E+02, -.16067500E+01, -.11653500E+02, 0.13726400E+02, 0.43805000E+02, -.51951700E+02, 0.30575400E+02, 0.23348600E+02, 0.28004400E+02, 0.42093500E+02, 0.78471700E+02, -.75578800E+02, -.73899400E+02, -.58247700E+02, 0.74385800E+02, 0.31480000E+02, -.28494100E+02, 0.14352700E+02, 0.44782000E+02, 0.11494400E+02, -.67350700E+02, -.25820900E+02, 0.50344300E+02, -.93022900E+01, 0.16885300E+02, -.23926800E+02, 0.12678800E+03, 0.45542800E+02, -.21040900E+02, 0.13869800E+03, -.28281400E+02, -.23230400E+02, -.49824100E+02, 0.69360100E+02, 0.13348200E+03, -.41380600E+02, -.54528600E+02, 0.51841000E+01, -.22024000E+03, 0.10626500E+03, -.71887900E+02, 0.10980400E+03, -.21498500E+03, -.67921200E+02, 0.23726600E+02, -.17239200E+03, 0.10419900E+03, -.66607400E+02, 0.51952100E+03, 0.36396000E+02, -.20182300E+02, -.32187400E+01, -.14959800E+02, 0.11646400E+02, 0.60340800E+01, -.46647200E+02, -.30637300E+02, -.74065800E+02, 0.14268700E+02, 0.10681400E+03, 0.49166600E+02, -.24571900E+02, -.50418900E+02, -.25861900E+02, -.24098300E+01, 0.62772000E+02, -.10084400E+03, -.10489900E+03, -.83412800E+01, 0.58834700E+02, 0.10258400E+02, 0.19817900E+03, -.99282200E+02, -.10095500E+03, -.10113700E+03, -.21477000E+02, -.46887500E+02, -.84257100E+01, 0.53892700E+02, -.27038000E+02, -.41523400E+02, -.26005800E+02, -.12277100E+01, 0.29426000E+02, 0.15896000E+02, -.17453700E+00, -.12508000E+01, -.11534400E+02, -.41146600E+00, 0.18586100E+01, 0.71269900E+01, -.61561400E+01, -.30951600E+01, 0.33125700E+01, -.11708000E+02, 0.38075000E+01, 0.23146700E+01, 0.43629400E+00, -.13354100E+02, 0.23343900E+02, 0.13315500E+01, 0.79181600E+00, 0.28293300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19040800E+00, 0.12249600E+00, 0.23474400E+01, 0.42684200E+00, -.98896300E+00, -.74034200E+00, -.73640000E+00, -.30098700E+00, 0.25493900E+01, 0.12959600E+01, -.33166600E+00, -.39151800E+00, 0.17394700E+01, 0.25114000E+00, 0.77466000E+00, 0.13051800E+01, -.94417100E+00, -.89726900E+00, 0.18807700E+00, 0.24079800E+00, -.10329500E-01, -.14754000E+00, -.47693200E-01, 0.89210300E-01, 0.33036400E+00, -.49212500E-03, 0.19099100E+00, 0.70222900E-01, 0.31573700E+00, -.94418500E-01, -.78592900E+00, 0.37909900E+00, -.36892300E+00, -.69503700E+00, 0.44201100E-01, -.94679300E-01, 0.10704100E+00, -.28103500E+00, -.32642400E+00, 0.23698600E+00, -.20780400E+00, -.15272900E+01, 0.32072400E+00, -.11807700E-01, 0.27726600E+01, -.85660600E+00, -.24525200E+01, 0.79137100E-01, 0.18866200E+01, 0.64523500E-01, 0.95654800E+00, -.17743100E+00, -.10269700E+01, -.35107400E+00, -.14436500E+00, -.38309600E-01, 0.98490900E-01, -.13767900E+01, -.14253600E+00, 0.34355900E+00, -.37175700E+00, -.28784700E+00, 0.10221700E+01, 0.33887000E+00, 0.15770800E+00, -.73840500E+00, 0.35030100E+00, 0.20203800E+01, 0.24775900E+00, 0.14153400E-01, 0.17406400E+00, -.19780000E+00, 0.27431400E+00, 0.32237200E+00, -.14030400E+00, 0.11281200E+01, 0.11269900E+01, -.91131800E+00, 0.28950300E-02, -.44042000E+00, 0.69422400E-01, 0.25748900E+00, -.17788400E+00, 0.16918900E+00, -.40544900E+00, 0.25473700E+00, -.75042700E+00, -.33871300E-01, -.10998600E+01, -.48816800E+00, -.17364400E+01, -.22388600E-01, -.78092600E+00, 0.30704800E+00, -.35963900E+00, -.47848600E+00, -.82434000E-01, 0.89005800E-01, -.34564500E+00, 0.35830800E+00, 0.15098000E+00, 0.27929800E+00, 0.27977600E-01, -.36703500E-01, -.14391200E+00, 0.87760300E-01, -.22013500E-01, 0.37812500E+00, 0.37447800E+00, 0.37046300E+00, 0.10476100E+01, 0.57555800E+00, -.52431000E+00, 0.94660400E-02, -.31688500E+00, 0.96439800E+00, 0.54668300E+03, 0.30033800E+03, 0.49592100E+02, 0.15551600E+02, 0.36073000E+02, 0.20484800E+03, -.10040800E+03, 0.83609300E+02, -.10029000E+03, -.12012800E+03, 0.12044600E+03, -.36816900E+02, -.79645500E+02, -.16533200E+03, 0.71783400E+02, -.14951300E+03, -.64285900E+02, 0.31815800E+02, -.16904500E+03, 0.27846100E+02, 0.66536100E+02, 0.10023300E+03, -.68078400E+02, -.80078100E+02, -.29089600E+02, 0.77366900E+02, 0.11061100E+03, -.46417300E+01, -.37011400E+01, -.54873000E+02, 0.25379900E+01, 0.56269900E+01, -.11077700E+01, 0.21235500E+02, 0.60808800E+02, 0.51930800E+02, -.65530000E+01, 0.26924300E+02, -.15160300E+03, 0.76922000E+02, 0.90503400E+02, 0.77063700E+02, -.28413000E+02, -.71734500E+02, 0.25314100E+02, 0.59699600E+02, 0.74969600E+01, -.30684700E+02, 0.12799800E+03, 0.29668700E+02, -.22378900E+02, -.15442600E+03, -.14827600E+02, 0.54843400E+02, 0.79478800E+02, -.23588600E+03, -.17895400E+03, 0.63927700E+01, 0.38114500E+02, 0.10705700E+03, -.39146700E+03, 0.20890100E+03, 0.15879500E+03, 0.19508500E+03, 0.19163000E+03, -.35071600E+02, 0.87947700E+02, -.84655500E+02, 0.22197000E+03, -.74578600E+02, 0.42329600E+03, -.18919800E+03, 0.98705100E+02, 0.82030900E+01, 0.97280000E+02, -.30827100E+02, 0.78313600E+01, -.60563300E+02, -.13181200E+03, 0.81911300E+02, -.34049900E+02, 0.13785400E+03, 0.14848800E+03, -.75006800E+02, -.47633500E+02, -.74294600E+02, -.46264400E+02, -.12919600E+03, -.38575400E+02, -.36455400E+02, 0.15032800E+03, -.15494500E+03, 0.15951000E+03, -.93289300E+01, 0.54673900E+01, 0.12977300E+03, 0.46995900E+01, 0.18419700E+02, 0.86517300E+02, -.10431900E+03, -.29269100E+02, -.16688800E+02, 0.59928400E+02, 0.78121700E+02, 0.10446400E+01, -.16861700E+02, 0.78227500E+00, 0.12226600E+00, 0.17445500E+00, -.57490900E+01, 0.24576700E+02, 0.14426600E+01, 0.94749800E+01, 0.82210500E+00, -.66238200E+01, -.20413600E+02, -.29239500E+02, -.18037500E+01, -.80857900E+01, -.24752400E+02, 0.65386500E+01, 0.96451100E+01, 0.49474000E+00, -.34419500E+02, -.15226400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19133600E-01, 0.10005500E-01, -.14739500E+00, 0.32650500E-02, 0.19629500E+00, -.13282900E-01, -.54283800E-01, 0.11652900E-01, -.88963200E-01, -.16661600E+00, 0.18039200E-01, -.65289000E-03, -.87730900E-01, -.52678200E-02, -.22082400E-01, -.79661000E-01, -.24623500E-01, 0.47095800E-01, -.27757800E-01, 0.13622000E-01, -.45651700E-02, -.41801700E-02, -.15044500E+00, -.12804400E-01, -.27150100E-01, -.64345900E-04, -.22479400E-01, 0.24870000E-01, -.48344300E-01, 0.44883000E-01, 0.17842100E-01, 0.58644600E-01, 0.10888400E-01, 0.50179600E-02, 0.15342000E-01, -.30875000E-02, -.67651000E-02, -.40740600E-02, 0.13438500E-01, 0.38696800E-01, -.47766500E-02, -.54916200E-01, 0.80930800E-02, -.70547400E-02, 0.16633900E-01, -.96464400E-02, 0.43456600E-01, 0.12757400E-03, -.12051700E-01, 0.25038000E-01, 0.38783500E-02, 0.36406800E-01, 0.49491300E-01, 0.36143200E-02, -.28828100E-01, -.52886300E-02, 0.43578500E-01, -.40038000E-01, 0.38104800E-02, -.43843400E-02, -.45181600E-01, -.29560800E-01, 0.19857500E-01, 0.69960500E-02, 0.38280200E-01, 0.66863900E-02, 0.93638000E-02, 0.37367700E+00, 0.69948300E-03, -.94705500E-03, 0.14238700E-01, 0.29462000E-01, 0.14042100E-01, 0.18205300E-01, 0.16025300E-01, 0.27576300E-01, 0.60366300E-02, -.97610000E-01, -.14677100E-02, -.37019200E-02, 0.13363400E-02, 0.70972800E-02, -.48742900E-03, -.12080200E-02, -.26713300E-02, 0.97858600E-02, -.28529100E-01, 0.71753500E-03, -.37456500E-01, 0.51159300E-01, 0.75726600E-01, 0.13350700E-02, 0.45728100E-01, -.82335200E-03, -.22434100E-01, -.12189700E-01, 0.26736500E-01, -.33985700E-01, 0.61265000E-01, -.25532500E-02, 0.56713100E-02, 0.86240200E-02, 0.20158100E-02, -.91250700E-02, -.64993800E-02, -.60569700E-02, -.30422300E-02, 0.42083800E-01, 0.19405100E-01, 0.54735100E-01, 0.13713100E+00, 0.21804600E-01, 0.48434900E-01, -.24343700E-02, -.23100600E-01, 0.39720900E-01, -.21796000E-01, -.20431500E+02, -.17045700E+02, 0.11183400E+02, -.31381600E+01, 0.22673000E+02, -.11155000E+02, 0.23153100E+00, -.11302800E+02, -.19076300E+02, -.16296400E+02, 0.59919800E+01, 0.10743200E+02, 0.79181100E+01, -.10891600E+02, -.29939100E+01, -.15052000E+01, 0.86485600E+00, -.31717500E+01, 0.87922400E+00, 0.60006800E+01, 0.72583900E+01, -.58992400E+01, -.21369200E+01, -.50516500E+00, 0.75094400E+01, 0.93436100E+00, -.15765600E+01, 0.27838500E+00, -.10542100E+00, 0.71370800E+00, -.56252100E+00, -.22982200E+01, 0.62984200E+01, 0.69595400E+01, 0.53065600E+01, -.25170100E+01, 0.52634100E+00, 0.40003600E+01, -.18586700E+01, 0.11478200E+02, -.18821300E+01, 0.88673400E+01, 0.13722300E+02, -.10302100E+02, -.97278800E+01, -.14468700E+02, 0.97517300E+01, -.31193900E+01, -.16529500E+02, 0.75263700E+01, 0.98762100E+01, 0.84179600E+01, 0.71687300E+01, 0.31272200E+01, 0.29991900E+01, -.26584200E+01, 0.69903900E+01, -.39653300E-01, -.28505700E+01, -.32367100E+02, 0.17158900E+02, -.32497300E+01, 0.16146100E+02, 0.14288200E+02, -.63512900E+01, 0.68610000E+01, -.78192300E+01, 0.96720500E+01, -.23481700E+01, -.28232200E+02, -.46278400E+01, 0.27577300E+01, -.67090900E+01, 0.22519100E+01, -.62467700E-01, 0.72658100E+00, -.10198300E+00, -.26719400E+01, 0.32795600E+01, -.14745400E+01, -.48414900E+01, -.15318400E+02, 0.77988900E+01, 0.61112000E+01, 0.76727500E+01, -.28873800E+01, -.11434900E+02, 0.73895200E+01, -.38374900E+01, 0.10895600E+02, -.81114000E+01, -.90887900E+01, -.14896200E+02, 0.73362100E+01, 0.15772000E+02, 0.74965800E+01, 0.50494300E+01, 0.86622800E+01, -.27444600E+01, -.42396500E+01, 0.74031300E+00, 0.51693200E+01, -.30342100E+01, 0.60835700E-01, -.27933400E+01, 0.84293600E-02, -.52724500E-01, -.15191500E+00, 0.62005000E+00, 0.15250800E+00, 0.12276100E+00, 0.50961500E+00, -.14092300E+01, 0.26937400E+00, 0.11965700E+01, 0.37478400E+01, -.13666300E+01, -.47162000E-01, 0.32272800E+01, 0.23864500E+01, -.86951000E+00, 0.34684000E+00, 0.44754800E+00, -.20580500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.58626400E+00, -.22032000E+00, 0.44669700E+01, -.58314200E+00, -.11344700E+01, 0.12277800E+01, -.25607300E+01, 0.46662500E+00, 0.88365500E+00, -.20185500E+01, -.26082700E+01, 0.40977300E+00, -.17512000E+01, -.95407300E+00, 0.47008200E+00, 0.18590500E+00, -.43678400E+01, 0.16897500E+00, 0.17310500E+01, -.19105700E+01, -.37202900E+00, 0.23265100E+00, 0.11795300E+01, -.13351800E+00, 0.19499800E+00, 0.75065000E-03, 0.19312000E+00, 0.10149700E+01, -.43600900E+00, 0.63841700E+00, -.50904100E+00, 0.11058700E+01, -.69126700E+00, -.17927400E+00, 0.24778500E+01, 0.31856000E+00, 0.49734000E-01, -.40375400E+00, -.24351800E-01, 0.21286200E+01, -.11302600E+01, 0.85741500E+00, 0.39446000E+00, 0.76179500E+00, 0.57854100E+00, -.32895900E-01, 0.54615700E+00, -.11260400E+00, -.29462900E+01, -.19929300E+01, 0.10983000E+01, 0.60894900E-01, -.28438600E+01, -.34299100E+00, 0.76070600E-01, 0.82453000E+00, -.12129600E+01, 0.19737700E+01, -.22466500E+00, 0.12125800E+01, 0.22689200E+00, -.71614900E+00, -.23367900E+01, 0.13993600E+00, 0.63263000E+00, -.92623700E+00, -.55958100E+00, -.26817800E+01, -.47563100E+00, -.86988200E-02, -.23354800E+00, 0.81071800E+00, -.30524300E-01, -.72075200E+00, 0.24423000E+00, 0.24452100E+01, 0.23492400E+01, -.39150800E+00, 0.45569300E+00, -.45029500E+00, 0.10943500E+00, -.14374000E+01, 0.48841400E+00, 0.24549000E+00, 0.52106100E+00, -.62082200E+00, -.73768900E+00, 0.38525100E-01, -.23200700E-02, 0.10556400E+01, 0.74343300E+00, 0.10263500E+00, 0.16094900E-01, 0.37876400E+00, 0.45325100E+00, 0.11935900E+01, 0.53616100E+00, -.13369300E+00, -.52610800E+00, 0.16282000E+00, 0.26014100E+00, 0.29065900E+00, 0.21050200E+00, -.16592800E-02, 0.17175400E+01, -.37406700E+00, -.11136700E+00, -.14747300E+01, -.73933200E+00, -.27427500E+00, 0.24684300E+01, 0.16199800E+01, -.92342000E+00, -.29369700E+00, 0.50449700E+00, -.88145900E+00, 0.65564000E+00, -.21862600E+02, -.89214300E+03, 0.30019400E+03, 0.23229500E+03, -.92820100E+03, 0.45956900E+03, 0.32099100E+02, 0.43937300E+03, -.61865200E+03, -.39191500E+03, 0.44458200E+03, -.34305100E+02, 0.52848300E+03, -.24266000E+03, 0.17592900E+04, -.63738100E+03, 0.31856700E+03, 0.60863500E+02, 0.36068000E+03, 0.10422700E+03, 0.17159000E+02, -.10498700E+02, -.11275000E+03, 0.28132400E+03, 0.58848600E+02, 0.44493300E+03, -.62162500E+01, 0.87071600E+01, 0.12003000E+03, 0.15022500E+00, 0.67154000E+01, -.56378800E+02, 0.21645000E+02, -.51311500E+02, 0.52380600E+02, -.46706400E+02, -.70081400E+02, -.32008200E+03, 0.15854700E+03, -.48190100E+03, 0.14993400E+03, 0.20718400E+03, 0.17787200E+03, -.10887600E+03, -.11277300E+03, -.74258900E+02, 0.13765500E+03, -.53926000E+03, -.15457900E+04, 0.77280300E+03, 0.47854200E+03, 0.77849300E+03, 0.99910300E+02, 0.13669700E+03, 0.28821400E+03, -.40863200E+03, 0.42966100E+03, 0.71482300E+02, 0.27629400E+03, -.30534600E+03, 0.15908100E+03, 0.12645900E+02, 0.15973000E+03, 0.65982900E+03, -.98654200E+02, 0.20006600E+03, 0.34345800E+03, 0.23812300E+03, -.11050900E+03, -.75487100E+03, -.15985000E+03, 0.82954600E+02, -.22898600E+02, 0.55565400E+02, -.14143700E+03, -.54665300E+02, 0.87728100E+02, -.60415100E+01, 0.37884700E+03, -.11091100E+03, 0.73721600E+02, 0.67392500E+02, -.35787600E+02, -.22077900E+03, -.29701500E+02, 0.27970800E+03, -.13693000E+03, 0.25945100E+03, 0.52994400E+03, 0.26577300E+03, -.12839800E+03, -.70361000E+03, -.45587900E+03, 0.22941100E+03, 0.26679800E+03, 0.23070400E+03, 0.12472800E+03, 0.21889400E+03, 0.28731200E+02, -.57862600E+02, 0.19001900E+03, 0.15535900E+03, -.27154000E+03, -.38624600E+01, -.11299400E+03, 0.99042200E+02, -.85555400E+01, -.16553200E+02, 0.15632400E+02, -.72760800E+01, 0.16465200E+02, 0.40275200E+01, -.59329600E+02, -.21625000E+01, -.15523000E+02, 0.68622200E+02, -.42196400E+02, 0.10724600E+03, 0.59399000E+01, 0.89761300E+02, 0.25058100E+01, 0.17738600E+02, -.14092200E+02, -.37377300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17859700E+00, -.49025800E-01, 0.12272300E+01, 0.13761500E+00, -.10471800E+01, -.52467400E+00, 0.21979700E+01, -.15386800E+00, -.20101900E+00, 0.24661300E+01, 0.11702600E+00, -.25936700E+00, 0.12220700E+01, -.16387900E+00, -.34931200E+00, 0.11572700E+01, -.98329700E+00, -.33411600E+00, 0.50676700E+00, -.33278800E-01, 0.55263100E-01, -.67532800E-01, -.28621400E+00, 0.94666900E-01, 0.36434800E+00, 0.13613200E-02, 0.43644800E-01, 0.13224000E+00, -.92911500E+00, -.18819300E+00, 0.14699300E+00, -.25177100E+00, 0.55819400E+00, 0.10600300E+01, 0.11160000E+00, 0.19226500E+00, -.13361000E+00, 0.31734200E+00, 0.38990900E+00, -.11448800E+00, 0.57148600E+00, 0.61262000E+00, -.66234300E-01, 0.19125100E+00, -.25166500E+01, 0.51888200E+00, -.62204900E+00, -.50202700E-01, 0.94251800E-01, -.34760000E+00, -.33170500E-03, 0.69603400E-01, -.22736300E+00, -.18363900E-01, 0.22829000E-01, -.12966200E+00, -.11568600E+00, -.21732100E+00, 0.10502700E+00, -.13213300E+00, 0.17760900E+00, 0.25931000E+00, -.87337400E+00, -.11856900E+00, -.50199100E+00, 0.22323200E+00, -.25791500E+00, -.47863800E+01, 0.25604300E+00, 0.13190100E-01, -.38984700E-01, -.20474000E+00, 0.19209700E+00, -.21394500E+00, 0.33445500E+00, 0.10054000E+00, -.67022000E+00, 0.26152300E+01, 0.15960700E-01, 0.23527600E-01, -.19616600E-01, -.64129600E-02, 0.20554500E+00, -.21048100E-01, -.33450400E+00, -.99665600E+00, 0.71562700E+00, -.47177200E-01, -.52203000E+00, -.89476400E+00, 0.45157300E+00, -.50524400E-01, -.47877700E+00, -.20791700E+00, -.36651600E+00, -.48740100E+00, -.15158100E+00, -.23089400E+00, 0.30790800E-01, -.20445500E-01, 0.22864300E+00, -.95052500E-03, -.40552000E-01, 0.63035900E-01, 0.11671200E+00, 0.10217300E-01, -.41107400E-01, 0.23152800E+00, -.32330500E+00, -.10430600E+01, 0.31311100E-01, 0.12564600E+00, -.29985200E+00, 0.98362800E-02, -.14254900E+00, -.11664500E+01, 0.84511500E-01, 0.89236200E+01, -.21043500E+00, -.53144600E+02, 0.65736000E+02, 0.62017600E+02, -.34770800E+02, -.36457300E+02, -.32883200E+02, 0.31507100E+01, -.78074700E+02, -.10400300E+02, 0.11767000E+03, -.31007000E+02, -.69387200E+02, 0.21447300E+03, -.54352500E+02, 0.26363700E+02, 0.15303700E+03, 0.24819100E+02, -.85698400E+02, -.23423500E+02, 0.11617200E+03, 0.60470100E+02, 0.41435900E+02, -.48383700E+02, 0.61980100E+02, 0.43755000E+02, -.14519200E+02, -.93075900E+00, -.19689800E+02, 0.35798200E+02, 0.88294900E+02, -.14720400E+03, -.11980500E+03, -.85896200E+02, 0.82051600E+02, -.37823800E+02, -.28649000E+01, -.65417600E-01, 0.22371700E+02, -.47727000E+01, -.10124600E+03, -.18233500E+02, 0.53532000E+02, -.61864700E+02, -.12725000E+02, 0.62994600E+01, -.14588800E+03, -.77496800E+01, 0.12062400E+02, 0.85871400E+01, -.37322900E+01, -.83765700E+02, -.85987600E+02, 0.15228500E+03, 0.21611500E+03, -.85531400E+02, -.54456600E+02, 0.74189500E+01, 0.62991000E+03, -.32563400E+03, -.38050700E+03, -.31422700E+03, -.30842200E+03, 0.19258900E+03, -.14323600E+03, 0.83435300E+02, -.23661700E+03, 0.15022100E+03, 0.43510200E+02, 0.21260500E+03, -.11060800E+03, -.24663800E+02, -.10607600E+03, -.10951200E+02, -.32941400E+02, -.49583700E+02, 0.31365000E+02, -.72206300E+02, 0.17262300E+00, 0.35630300E+02, 0.15795800E+03, -.80568600E+02, -.74751100E+02, -.80353400E+02, 0.39030000E+02, 0.34211800E+03, -.14286100E+03, 0.39030200E+02, -.26597100E+03, 0.26108600E+03, -.25208000E+03, 0.15638700E+03, -.76961900E+02, -.15645500E+03, -.80946000E+02, -.33229000E+02, -.12314500E+03, 0.52266400E+02, 0.79311600E+02, 0.16708500E+02, -.85186100E+02, -.31064100E+02, 0.96067600E+00, 0.25341700E+02, 0.26592300E+02, 0.32586800E-01, -.80129900E+01, -.89234300E+01, -.15288200E+02, 0.89241100E+01, 0.35350000E+01, -.97403000E+01, -.67482800E+00, -.61639900E+01, 0.15197200E+02, 0.80706400E+01, 0.18384800E+02, 0.15610100E+02, -.19360000E+02, -.52735900E+01, 0.16260700E+01, 0.18095100E+02, 0.18878000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13102800E+00, 0.69193300E+00, -.14107900E+00, 0.34774800E+00, 0.72353700E+00, 0.46344000E+00, -.58793300E+00, 0.10279400E+00, -.13652200E+01, -.88821800E+00, 0.18776200E+00, 0.55146700E-01, -.71159600E+00, -.65082900E+00, -.23091400E+00, -.19973500E+00, 0.33401900E+00, 0.24332900E+00, -.76632100E-01, -.80105400E+00, -.19177500E-01, -.26580900E-01, 0.14467000E+01, 0.45816400E-01, 0.50791500E+00, 0.20921000E-02, 0.32991900E+00, 0.18557400E+00, -.25540000E+00, 0.16544300E-02, -.16906200E+00, -.13656300E+00, -.59201100E-01, 0.92561900E+00, 0.21414700E+00, -.11774800E-01, 0.16820800E-01, -.74116100E-01, -.22118900E-01, -.15733800E+00, -.12013200E+00, 0.42282500E+00, -.77130300E-01, -.54856400E-01, 0.39025700E+00, 0.93667900E-01, 0.36740200E+00, -.13531800E-01, 0.50357700E-01, 0.16557900E+00, 0.12864700E+00, -.26931700E+00, -.55446600E+00, -.62799900E-02, -.19651400E+00, 0.48242900E-01, 0.74899000E-01, 0.19936400E+00, -.51900100E-01, 0.55504600E-02, 0.60481900E-01, 0.17102900E+00, -.82491700E-03, -.69021100E-02, -.11471400E+00, -.86039800E-01, 0.67582700E-01, -.37857200E+01, 0.36365600E-01, 0.98875200E-02, 0.16973900E+00, 0.11730000E+00, -.60396900E-01, -.73334000E-01, -.32928800E+00, 0.32564600E+00, -.98127700E-01, 0.88244700E+00, 0.50355700E-01, 0.86701600E-01, 0.11607900E-01, 0.10408200E+00, -.13435700E+00, 0.88591300E-01, -.15107900E+00, -.86726200E-01, 0.22733700E+00, -.61538400E-01, -.11970600E-02, -.46953100E-01, -.60869200E+00, -.19405700E-01, 0.39996700E-01, 0.17928100E-01, 0.11016200E+00, 0.29210600E+00, -.58132300E-02, 0.68165200E-01, -.29042100E+00, -.92983700E-01, 0.10187000E+00, 0.17928100E+00, 0.22996200E-01, 0.59993700E-01, 0.12294400E+00, 0.50538800E-01, -.41830800E-01, 0.32566400E+00, 0.24505200E+00, 0.34301300E-01, -.31837500E+00, 0.21318300E+00, -.12606500E+00, -.23924100E-01, -.12878500E-01, -.34955000E+00, 0.22597500E-01, 0.53691600E+01, -.51907500E-01, 0.32107600E+00, -.99579400E+02, -.27690700E+03, 0.14009100E+03, 0.81582100E+02, 0.13640900E+03, 0.52152300E+02, 0.37774700E+02, 0.40747800E+02, -.71238800E+02, -.40704800E+02, 0.37929200E+02, -.19158000E+02, -.17536500E+03, 0.87697900E+02, 0.93389900E+02, 0.87762800E+02, 0.21048600E+02, 0.40898800E+02, -.12655100E+02, -.86829300E+02, -.13577900E+02, 0.38642600E+02, 0.86415800E+02, -.16119500E+03, 0.81121700E+02, 0.94946900E+02, 0.81885900E+02, 0.35610900E+02, 0.35964500E+02, -.11407000E+02, -.10339400E+03, -.21082800E+02, 0.40394600E+02, 0.59856300E+02, -.15694700E+03, 0.78554800E+02, 0.16235400E+02, 0.75950100E+02, -.14322700E+02, -.21887400E+02, 0.98102500E+01, 0.29649100E+01, 0.68381200E+02, -.18553700E+02, 0.17269800E+03, -.53433300E+02, 0.24697500E+02, 0.34091700E+02, 0.24524900E+02, -.63890100E+01, -.14071100E+02, -.21286500E+02, -.22642700E+02, 0.51546000E+02, -.18134200E+02, 0.80067500E+02, -.42962900E+03, 0.21734800E+03, 0.18047400E+03, 0.21567900E+03, -.47637700E+02, -.13842400E+03, 0.10349900E+03, -.74253200E+02, 0.21455300E+03, -.13150800E+03, 0.36987600E+03, -.12624300E+03, 0.65844300E+02, 0.53558100E+02, 0.63034400E+02, -.61938700E+01, 0.28930200E+01, 0.46266500E+02, 0.35062300E+02, 0.54600000E+02, 0.74701700E+00, 0.99445000E+02, 0.13501000E+03, -.66670600E+02, -.52765800E+02, -.67391100E+02, -.36580900E+02, -.13714300E+03, -.25047900E+02, -.31137300E+02, 0.11300600E+03, -.98118200E+02, 0.47052000E+01, 0.13486200E+03, -.67932600E+02, -.68614300E+02, -.68018200E+02, -.25663500E+02, -.48390300E+01, -.21699000E+02, 0.32501200E+02, -.10031700E+02, -.41265100E+01, 0.94553900E+01, 0.39582700E-01, 0.83162500E+01, 0.29671300E+02, 0.70173600E+00, 0.17357200E+01, -.23776200E+01, 0.53414200E+01, -.18275900E+01, -.85216600E+01, -.65151800E+01, -.28336000E+01, 0.63907900E+01, -.28235100E+02, -.33853500E+01, 0.22865200E+02, -.16766800E+02, -.44938300E+01, 0.23062300E+02, -.36390800E+01, -.11405300E+02, 0.64813200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.51471300E+00, -.56427600E+00, 0.11688300E+01, -.15350100E+01, 0.11517100E+00, 0.53980800E+00, 0.14888100E+00, -.11720900E+00, 0.13193100E+01, -.14844100E+01, -.70914400E+00, 0.66094600E-01, -.66858800E+00, -.13874800E+01, -.23045400E+00, 0.11401400E+01, 0.78277800E+00, -.67421600E+00, 0.14786300E+01, -.10622400E+01, -.10813400E+00, 0.29438600E+00, 0.27363700E+01, 0.14034000E+00, 0.44893400E+00, 0.10469700E-02, 0.34981000E+00, -.30820900E+00, 0.10984000E+01, -.88527100E+00, 0.73894900E+00, -.20786700E+01, 0.23770800E+00, -.18448400E+00, -.60078700E+00, -.12351300E-02, 0.15066500E+00, 0.22599900E+00, -.38473800E+00, -.10514800E+01, 0.45287700E+00, 0.52260000E+00, -.24672000E+00, -.26711100E-01, -.39413900E-01, 0.36595600E-01, 0.13688900E+01, 0.84910300E-01, -.29632700E+00, 0.32466000E-01, 0.16258600E-01, -.77372600E+00, -.41713700E+00, 0.60938800E+00, -.17035600E+00, 0.13180400E+00, 0.82409000E+00, -.14649800E+00, -.16093200E+00, -.80837100E-01, 0.43855800E+00, 0.13784100E+01, 0.39838300E+01, 0.55471900E+00, -.11715200E+01, -.65380400E+00, -.51854700E+00, 0.55336200E+01, -.28044000E+00, 0.74761300E-02, -.40568000E+00, -.21201900E+00, 0.15532100E+00, -.94018100E-01, -.58857700E+00, -.34010800E-01, 0.75055100E+00, 0.22426600E+01, 0.20132200E+00, -.10587500E+00, 0.40728900E-01, 0.10608900E+01, -.11789000E+01, -.70847400E+00, -.66865000E+00, 0.94235900E+00, -.26740700E+00, -.18779000E+00, 0.67491400E+00, 0.10627600E+01, 0.14532600E+00, -.22979300E-01, 0.54019600E+00, 0.51646100E+00, 0.47209700E+00, 0.65851600E+00, 0.40135400E+00, 0.37380900E+00, 0.11856700E+01, 0.39628400E+00, -.12496700E+00, -.43943500E+00, 0.32915400E-02, -.52596500E+00, -.78495600E+00, -.29603000E+00, 0.37824500E+00, -.14449800E+01, 0.27316800E+00, 0.30075500E+01, 0.14784800E+00, 0.41787900E+00, 0.42856600E+00, 0.19691300E+00, 0.96664400E-01, 0.16403900E+01, -.22933800E+00, -.29983000E+01, 0.53388200E-01, -.24632800E+00, 0.65236900E+00, 0.10382600E+04, -.52170200E+03, -.39623600E+03, -.50909800E+03, -.23485300E+03, -.13759900E+03, -.14946300E+03, 0.25539200E+03, 0.84326100E+02, -.15967600E+03, -.35221900E+03, 0.56970500E+03, -.27925900E+03, -.23126500E+03, -.29715200E+03, 0.16247400E+02, 0.11045800E+03, -.11277000E+03, 0.16121700E+03, -.11443100E+03, 0.83260000E+02, -.28427900E+03, 0.23568100E+03, -.12373000E+03, -.14843500E+03, -.11909800E+03, -.41978800E+02, -.64843100E+01, 0.73726200E+02, 0.23519400E+03, 0.38302300E+02, -.24603200E+02, -.77478300E+02, 0.10860100E+03, -.50347100E+02, 0.25610200E+02, -.49110000E+02, -.44068000E+02, 0.11658100E+03, -.20260400E+02, -.12190000E+03, -.14682700E+03, 0.86761200E+02, -.10949400E+03, 0.15569700E+03, -.78493500E+02, -.90389300E+02, -.78156600E+02, 0.77598600E+02, 0.86770900E+01, 0.12536000E+03, 0.17231500E+03, -.76014800E+02, 0.34449000E+02, -.22356500E+03, 0.10179200E+04, -.51308500E+03, -.33408500E+03, -.51214500E+03, -.52815500E+02, 0.34633100E+03, -.28803700E+03, 0.98953600E+02, -.60128400E+03, 0.38569100E+03, -.10491300E+04, 0.43977900E+03, -.21564500E+03, -.65279200E+02, -.21316400E+03, 0.31369600E+02, 0.48499400E+02, -.13275000E+03, -.37963300E+02, -.26504200E+03, 0.66789300E+02, -.27788000E+03, -.74128700E+03, 0.36860400E+03, 0.32777500E+03, 0.36871200E+03, -.51644000E+01, 0.38640000E+03, -.77061400E+02, -.40747800E+03, -.39719600E+03, 0.33366800E+03, 0.18253100E+03, -.35422700E+03, 0.17608200E+03, 0.33689500E+03, 0.17636600E+03, 0.88874700E+02, 0.42084800E+01, 0.64808400E+02, -.12087600E+03, 0.19985100E+02, -.34163400E+00, 0.56948200E+02, 0.13342000E+01, -.94755700E+01, -.71310100E+02, 0.67414500E-02, 0.36994200E+01, 0.70657100E+01, -.17356100E+02, -.41465500E+01, 0.81908100E+01, -.19556500E+01, 0.95542700E+01, 0.37525700E+01, 0.64627300E+02, 0.28303300E+01, -.64467800E+02, 0.47248200E+02, -.78299400E+01, -.72130700E+02, 0.74946200E+00, 0.69652400E+02, -.56243000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.64042900E+00, -.52907600E+01, -.79092600E+01, -.40870700E+01, 0.27030200E+01, -.55647400E+01, 0.38007300E+01, 0.22072900E-01, 0.64986600E+01, 0.48531000E+01, 0.23211500E-01, -.14953200E+01, 0.71495800E+01, 0.21615300E+01, 0.80715900E+00, 0.28682400E+01, -.31441000E+01, 0.20154800E+01, -.27548600E+01, 0.31702400E+01, 0.67240000E-01, 0.17451700E+00, -.49516800E+01, -.82569500E+00, -.12357100E+01, -.48523600E-02, -.66803800E+00, 0.74616200E+00, -.18406400E+01, 0.10722300E+01, -.59261000E+00, 0.16796000E+01, -.69109900E+00, -.65259300E+00, 0.42220900E+01, 0.33792400E+00, -.22171800E+00, -.91164300E+00, 0.25163800E+00, 0.22666000E+01, -.74856600E+00, -.13716800E+01, 0.43086400E+00, -.49019500E+00, 0.61456500E+01, -.14249300E+01, 0.10815400E+01, -.21186900E+00, 0.19831400E+01, 0.98984300E+00, 0.81262100E+00, 0.35489900E+00, -.57364800E+00, -.49140400E+00, -.21931600E+01, 0.11363800E+00, 0.11340100E+00, 0.57469100E+00, 0.45909900E-01, 0.17822700E+00, -.70204700E+00, -.17727400E+01, 0.30270600E+01, 0.17459000E+00, -.88922800E+00, -.11292800E+00, 0.12524300E+01, 0.87981500E+01, 0.45326900E+00, -.10584000E+00, 0.86727400E+00, -.36489300E-01, 0.20725700E+00, 0.72808300E+00, 0.85261600E+00, -.14245100E+01, -.27056900E+01, -.13466500E+01, -.67516400E+00, -.10222800E-01, -.19625900E-01, 0.76415800E+00, -.73229400E+00, 0.39930400E-01, -.83284300E-01, -.77499900E+00, 0.17991400E+00, -.25137700E+00, 0.18689100E+01, 0.25952400E+01, -.26951400E+01, -.35371300E-01, 0.53461100E+00, -.72145500E-01, 0.13700100E+00, -.62676300E-01, 0.11083000E+00, 0.34336300E+00, -.12422700E+01, 0.40144900E-01, -.11801000E+01, 0.39830700E+00, 0.12729400E+00, -.37268900E+00, 0.22582400E+01, 0.26916300E-02, 0.36468600E+00, -.70599900E-01, 0.29835600E+00, 0.12997400E+01, -.22821300E+00, 0.13158500E+00, 0.32446800E+00, 0.84655500E-02, -.84374400E-01, 0.17862100E+01, 0.15326500E+00, -.14097700E+02, 0.26984100E+00, 0.62020300E+00, -.15568600E+01, -.60097100E-01, 0.10884900E+02, 0.51960200E+02, 0.30304800E+01, -.59543900E+02, 0.11619100E+03, -.76200900E+02, -.79678700E+02, 0.11029200E+03, 0.51960200E+02, -.24838800E+03, 0.71343500E+03, -.34010000E+03, -.52348300E+03, -.35741400E+03, 0.69728900E+02, -.12512900E+03, -.20965300E+03, 0.49089900E+02, -.23244200E+03, -.82358400E+02, -.48811000E+03, 0.26003400E+03, -.12924100E+03, -.77386000E+02, -.13155700E+03, -.92732700E+02, -.16784500E+03, 0.16740700E+03, 0.18305000E+03, 0.28345100E+02, -.15385600E+03, -.10842400E+03, 0.28167300E+03, -.13606100E+03, -.60999700E+02, -.13399100E+03, 0.14186900E+03, 0.59699000E+02, -.10218400E+03, 0.92994100E+02, -.92049600E+02, 0.23869500E+02, -.10031600E+03, 0.78597600E+03, -.41087800E+03, -.21103000E+02, -.38550100E+03, 0.58830400E+02, 0.11265100E+03, -.43750800E+03, -.24989800E+03, -.10962400E+03, 0.39659300E+02, -.25969300E+03, -.57732100E+03, 0.30182700E+03, 0.35986500E+03, 0.28748900E+03, 0.29966700E+03, -.18675100E+03, 0.41448500E+02, -.25725800E+03, 0.98959300E+02, -.12068200E+03, 0.10069300E+03, -.17684300E+03, 0.90289200E+02, 0.26226000E+03, 0.90115100E+02, 0.52056800E+02, 0.15184100E+02, 0.10612800E+03, 0.50854000E+02, 0.50796100E+02, -.15331900E+02, -.19057100E+03, -.30507300E+03, 0.15188600E+03, 0.11280500E+03, 0.15397500E+03, -.10824900E+03, -.30809800E+03, 0.20937100E+02, -.38238600E+03, 0.13433900E+03, -.22899700E+03, 0.41349400E+03, -.16216000E+03, 0.79321000E+02, 0.29358600E+03, 0.83863800E+02, 0.16507500E+02, 0.21585600E+03, -.12401700E+03, -.18266900E+03, -.51291700E+02, 0.12743300E+03, 0.18603700E+03, -.42541200E+00, 0.23887800E+02, -.14746600E+02, 0.25890100E+01, 0.45441600E+02, 0.62052300E+01, 0.21632900E+02, -.46854300E+02, -.15574500E+02, 0.47089800E+02, 0.30896800E+01, 0.12031600E+02, 0.27995400E+01, -.88376600E+01, 0.19764000E+02, -.43718500E+01, -.83277200E+00, 0.15681600E+01, -.95202600E+01, -.29218000E+01, -.48228500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20410900E+00, -.41416900E+00, 0.34368700E+00, -.43493700E+00, -.20356400E+01, 0.32357600E+00, 0.22339000E-01, -.30958600E-02, 0.93731100E+00, 0.96212800E+00, -.79320800E-01, 0.67362300E-03, 0.19648600E+00, 0.16994300E+00, 0.27314900E+00, 0.11377500E+00, 0.71518900E+00, -.15098500E+00, -.16587400E+00, 0.36811200E-01, 0.26302200E-01, 0.69289900E-01, 0.66831100E+00, 0.96057000E-02, -.11954900E+00, -.10826000E-03, -.19072600E-01, -.36988600E+00, 0.92664700E+00, -.28446200E+00, 0.49606200E-01, -.32911900E+00, -.58880600E-02, -.25220100E+00, -.50275900E+00, -.47695300E-01, 0.56116600E-01, 0.46109000E-01, -.21702800E+00, -.74133300E+00, 0.71728100E+00, -.11681900E+00, 0.16758700E-02, 0.84983100E-01, -.44127200E-01, 0.85748100E-01, -.38513500E+00, -.20716800E-01, 0.68044600E+00, -.16345800E+00, -.74608100E-01, -.61008200E+00, 0.90681500E-01, 0.80450400E-01, -.10171100E+00, -.58763900E-01, 0.23980900E-01, -.17658200E+00, -.21596100E-01, -.12833700E+00, 0.19551800E+00, 0.22421000E+00, -.28941900E+00, -.15019000E+00, 0.24847200E+00, 0.77708500E-01, 0.17683700E+00, -.25341000E+01, -.13868200E-01, -.11362600E-01, 0.17288700E-01, -.83036100E-01, -.91020500E-01, 0.24472500E-01, -.18695400E+00, 0.17461300E+00, -.50325800E-01, 0.40557000E+00, 0.26010400E-01, 0.50495600E-01, 0.61623700E-02, 0.24544800E+00, -.65982700E-01, -.22738200E+00, -.13227800E+00, 0.63879200E-01, 0.42296900E-01, -.22090500E-01, 0.12024900E+00, -.42266800E+00, -.45328800E+00, -.21483900E-01, -.31248900E+00, -.23345100E+00, -.11467000E+00, -.43891700E-01, 0.67296500E-01, 0.11264100E+00, -.45864600E+00, 0.60665300E-01, -.14652200E+00, 0.42873600E-01, 0.15240700E-01, 0.21965400E+00, -.39029700E+00, 0.13130800E+00, 0.34080400E-01, 0.51748400E+00, 0.16529400E+00, -.21533700E+00, -.35405500E+00, -.11582000E-01, -.36256900E+00, -.14247900E-01, -.78145900E-01, -.20940600E+00, 0.14362900E+00, 0.46083300E+01, -.14825900E+00, 0.69522900E+00, 0.30883400E+00, 0.59490900E-01, 0.15579400E-02, 0.12491900E+03, -.28653000E+01, 0.16711000E+02, 0.85863400E+02, 0.40369400E+01, 0.37242600E+02, 0.32072000E+02, 0.64555700E+02, -.10040500E+02, -.17723300E+02, 0.81349700E+01, -.94237000E+02, 0.16468200E+02, 0.25042800E+02, 0.63906600E+01, -.53526000E+02, -.17505700E+02, -.16516200E+02, 0.18604500E+02, 0.87390500E+01, 0.37290600E+02, -.18135400E+02, -.38193400E+02, -.20218900E+02, -.15839100E+02, -.35701000E+02, 0.36831800E+02, 0.20554500E+02, 0.29684000E+01, -.31742400E+02, -.14072000E+02, 0.92502300E+01, -.53918400E+01, 0.14351700E+03, -.34171600E+01, 0.94128300E+02, 0.88181700E+02, -.95924300E+02, -.41647300E+02, -.11218700E+03, 0.79279300E+02, -.24691300E+02, 0.15326700E+02, -.76848900E+01, 0.49086500E+02, -.34629700E+01, 0.25581600E+02, 0.66527300E+02, -.12433700E+03, -.92042300E+02, -.11117300E+02, 0.54506300E+02, -.26713000E+02, -.22266200E+03, 0.11358000E+03, 0.24159500E+03, 0.11207900E+03, 0.14672700E+03, -.85541600E+02, 0.75452300E+02, 0.96551800E+02, 0.11356900E+03, -.10259700E+03, 0.61539800E+02, -.12694800E+03, 0.62560700E+02, -.11036200E+01, 0.59492500E+02, 0.82026900E+01, 0.14147500E+02, 0.27852200E+02, -.39991900E+01, 0.54251600E+02, 0.17378900E+01, 0.35200600E+02, 0.24480000E+03, -.12357900E+03, -.55146500E+01, -.12126100E+03, 0.26513200E+02, -.11987300E+03, -.31816700E+02, 0.11854400E+02, -.15309300E+02, -.10233200E+03, -.18127200E+02, -.41032500E+02, 0.21750300E+02, 0.37424600E+02, 0.22113800E+02, -.17107700E+01, 0.49519900E+02, -.19929900E+02, -.28685900E+02, -.30969600E+02, 0.34861300E+02, 0.18115700E+01, -.35796100E+00, -.52153000E+01, -.36693600E+01, 0.10558700E-01, 0.11553400E+01, 0.25380200E+01, 0.50925800E+01, -.16404800E+01, 0.13205700E+01, 0.24150900E+01, 0.27361500E+00, 0.54408200E+00, 0.12625700E+02, 0.25443500E+01, 0.28994100E+01, 0.15386300E+02, 0.92732500E+01, 0.15349600E+02, 0.27783000E+01, -.77981600E+01, -.55478800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.78787400E+00, 0.84380800E+00, 0.57109300E+01, 0.39027600E+01, 0.63067800E+01, -.41812300E+01, 0.67939300E+01, -.10617500E+01, 0.20790000E+01, 0.51392100E+00, -.30262400E+00, -.25660700E+00, 0.15477600E+01, 0.36780900E+00, 0.45049000E+00, 0.29614700E+00, 0.16483200E+00, -.66935300E-01, -.11760800E+00, 0.61942500E+00, -.48931400E-02, 0.16430400E+00, -.27965300E+00, -.13425800E+00, 0.20868200E+00, -.11135000E-02, 0.58848900E-01, 0.48326200E+00, -.14959500E+01, -.12672300E+00, -.38187600E+00, 0.81150000E+00, -.94783700E+00, 0.41661500E-01, 0.34477300E+01, 0.36024100E+00, 0.21192800E+00, -.38727700E+00, -.22975000E+00, 0.20458300E+01, -.15158600E+01, -.90557000E+00, 0.42190300E+00, -.17677700E+00, 0.16130700E+01, -.71585700E+00, 0.41803900E+00, -.37198200E+00, 0.53056300E+00, 0.50359100E+00, 0.60526100E+00, 0.15547000E+01, -.62779100E+00, -.12517100E+01, -.16625000E+01, -.54452100E-01, 0.13252300E+01, -.72382600E+00, 0.39406900E+00, 0.16687800E+00, -.11625500E+00, -.16289000E+01, 0.26305800E+01, 0.39137200E+00, 0.10663900E+01, 0.14320400E+00, -.11834100E-01, 0.89005800E+01, -.29116700E+00, 0.28854100E+00, 0.34421800E+00, 0.91968400E+00, 0.13373500E+00, -.20089000E+00, 0.72130800E-01, 0.20660800E+01, -.17408400E+01, 0.51979400E+01, 0.14172100E+00, 0.22072400E+00, 0.11183000E+00, 0.11546100E+01, -.45317000E-01, 0.31972400E+00, 0.11294900E+00, -.39078500E+01, 0.23731300E+01, -.39683700E+00, 0.57172000E+00, 0.90039300E+00, 0.16282300E+01, -.18008800E+00, -.18773700E+00, -.17998100E+00, 0.21825900E+00, -.29805600E+00, -.46762200E+00, 0.15799400E+00, -.96947100E+00, -.47843100E+00, -.20348600E+00, 0.47879000E-01, -.41396000E-01, 0.31658100E+00, 0.13875200E+01, 0.42701200E-02, 0.60725700E-01, 0.62834800E-01, 0.96979500E-01, 0.36232800E+00, 0.73913000E+00, 0.99330600E+00, 0.79116500E-01, 0.91384100E-01, 0.31942700E+00, -.34214600E+00, -.57288200E-01, -.70167800E+01, 0.26059600E+00, -.38209200E+00, -.70971500E+00, -.85236300E+00, -.52525500E+00, -.12451500E+01, 0.38554400E+02, -.24845000E+03, 0.26122200E+02, 0.80315400E+01, 0.27159600E+02, 0.38040800E+03, -.46706100E+02, -.19462100E+03, 0.61108600E+03, -.29526200E+03, -.44894400E+03, -.30546400E+03, 0.74563100E+02, -.34533900E+02, -.20236200E+03, 0.10700700E+03, -.18416900E+03, -.40187400E+00, -.43938300E+03, 0.24492800E+03, -.12743300E+03, -.93631400E+02, -.12568000E+03, -.87908300E+02, -.13227100E+03, 0.15794500E+03, 0.23806700E+03, 0.54844000E+02, -.13088400E+03, -.94853000E+02, 0.38508900E+03, -.18922300E+03, -.16009700E+03, -.18533800E+03, 0.20461500E+03, 0.18604100E+03, -.19931800E+03, -.42075400E+02, -.32077500E+03, 0.15756800E+03, -.10786300E+03, 0.56813900E+03, -.29282200E+03, -.99031100E+02, -.28097300E+03, 0.11038900E+03, 0.86856600E+02, -.27878100E+03, -.12993900E+03, -.41137000E+02, 0.70759100E+02, -.30401900E+03, -.18021100E+03, 0.99926700E+02, 0.37545100E+03, 0.86424500E+02, 0.43507500E+03, -.96290200E+01, -.25420400E+02, -.10923200E+02, -.66238600E+02, 0.44939200E+02, -.65362100E+03, -.11968600E+03, 0.65661200E+02, 0.16818600E+03, 0.59507600E+02, 0.66875100E+02, 0.52230300E+02, 0.34407700E+02, -.28120700E+02, -.48995400E+01, 0.31819000E+02, -.24743400E+03, -.44809500E+03, 0.21979900E+03, 0.24013000E+03, 0.22108800E+03, -.37499100E+02, -.13829400E+03, -.11066600E+02, -.42328700E+03, -.41091800E+02, -.96387100E+02, 0.28535800E+03, -.45754000E+03, 0.22958900E+03, 0.42828800E+03, 0.22845700E+03, 0.67402900E+02, 0.19366300E+03, -.41737700E+02, -.24430300E+03, -.21614500E+02, 0.12750700E+03, 0.20577400E+03, -.17767900E+01, -.26117300E+01, -.59218700E+02, 0.96523900E+00, 0.20153400E+02, 0.14711400E+02, 0.40302800E+01, -.21203300E+02, 0.60510900E+01, 0.24701800E+02, 0.58399100E+01, 0.58325500E+01, 0.48600000E+02, -.43863100E+01, -.32598000E+02, 0.36478800E+02, -.29555600E+01, -.28547300E+02, 0.47041600E+01, 0.30445800E+02, -.36064500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19957000E+00, -.12669400E+01, -.96040500E+00, -.37933100E+00, 0.42767600E-01, -.59009700E+00, 0.10573600E+01, 0.79964400E-01, 0.83010100E+00, 0.11902300E+01, -.79813800E-01, -.79858500E-01, 0.15246800E+01, 0.17479600E+00, -.92749500E-01, 0.76797400E+00, -.26185700E+01, -.14433200E+00, 0.13427700E+00, 0.20504000E+00, 0.17365000E-01, -.65253800E-01, 0.11195100E+00, 0.91238700E-01, 0.92870400E-01, 0.29347900E-03, 0.98457000E-01, 0.30230400E+00, -.37992700E+00, 0.59574700E-01, -.32008600E+00, 0.87414700E-01, -.27394500E+00, 0.15308000E+00, 0.90203300E-01, -.58090800E-01, 0.10173200E-01, -.20938900E-01, 0.73718400E-01, 0.28398100E+00, -.22521700E+00, 0.60125300E+00, -.29026100E-01, 0.26047000E-01, -.51417500E+00, 0.24361100E+00, -.37679300E+00, 0.99779800E-03, -.31194400E+00, -.20797300E+00, 0.10676700E+00, 0.58451000E-01, 0.18898500E+00, 0.88546700E-01, 0.38580500E-01, 0.54218900E-01, -.20650100E+00, 0.34585600E+00, -.29913600E-01, 0.19790800E+00, -.50794000E-01, -.27173300E+00, 0.31923300E+00, 0.13118900E-01, -.12726700E+00, -.12938100E+00, -.97510800E-02, -.11152100E+01, -.38858400E-01, -.64138400E-02, 0.11846100E-01, 0.11869000E+00, -.43145500E-01, -.28745800E-01, -.26210400E+00, 0.18176300E+00, -.65289200E+00, 0.72632900E+00, 0.67165800E-01, 0.12919900E+00, 0.32839500E-02, -.36384300E-01, 0.48713400E-01, 0.27226000E+00, -.10064700E+00, -.18341800E-01, 0.60828800E-01, 0.21358000E-01, -.63449900E-01, 0.49195400E+00, -.49745000E+00, 0.24347000E-01, 0.25523700E+00, 0.23273200E-01, 0.23487600E+00, 0.46084400E+00, 0.71604900E-01, 0.93139000E-02, 0.31331700E-01, -.12312800E+00, 0.10722400E+00, 0.59429700E-02, 0.25804000E-01, 0.12557500E+00, 0.21758100E+00, -.82282100E-01, -.96648400E-01, 0.48243000E+00, 0.14078000E+00, -.48069300E+00, 0.36548300E+00, 0.21583400E+00, -.12122500E+00, -.68033200E-01, -.13786900E+00, -.74769400E-01, 0.69723000E-01, -.29823700E+01, -.22513800E-01, -.57030100E+00, -.35627000E+00, -.19935800E+00, -.94788500E-01, 0.13108100E+00, -.64467600E-01, -.13285100E+03, -.86560800E+02, 0.38251700E+02, 0.79605700E+02, 0.12017400E+03, -.82214100E+02, -.50781600E+02, -.11873200E+03, 0.62401400E+02, 0.67592400E+02, 0.60004000E+02, 0.16024500E+02, 0.84708100E+02, -.13876200E+02, -.44057300E+02, -.33518100E+02, 0.68699900E+02, 0.44824900E+02, -.93828400E+02, 0.50931600E+02, 0.59072600E+02, 0.47991600E+02, 0.42802600E+02, 0.68174600E+02, -.31456500E+02, -.69335100E+02, -.31425400E+02, 0.65625700E+02, 0.36069600E+02, -.11572300E+03, 0.58775300E+02, 0.79911500E+02, 0.54150300E+02, 0.13430400E+02, 0.86854600E+02, -.21284200E+02, -.10475900E+03, -.11177400E+03, 0.87578600E+02, 0.92665100E+02, 0.47205800E+02, -.24569800E+02, -.19794100E+02, -.27533100E+02, 0.10826300E+02, -.56832300E+02, 0.72955900E+02, 0.13266500E+03, 0.26659100E+02, -.60846700E+02, -.35023800E+02, -.38285600E+02, 0.17610900E+02, -.59723000E+02, 0.19608400E+02, 0.18565800E+02, 0.19282500E+02, -.12935500E+02, -.30872700E+02, 0.15495400E+02, 0.11025000E+02, 0.37905200E+02, -.30334200E+03, 0.15452700E+03, 0.12820700E+03, 0.15069500E+03, 0.85271400E+02, 0.37264300E+02, 0.45149100E+02, -.36140900E+02, 0.53917700E+02, 0.45572400E+02, 0.59785100E+02, 0.53665500E+02, -.27371700E+02, 0.47828700E+01, -.27525000E+02, -.11737000E+02, 0.83326900E+02, -.11749800E+03, -.13929100E+03, -.10451800E+03, 0.61341300E+02, -.29636200E+02, -.35172200E+02, 0.17375200E+02, 0.72286000E+02, 0.16149000E+02, 0.13429700E+02, 0.71566500E+01, 0.63574000E+01, -.18775300E+02, -.21252500E+01, 0.12167800E-01, 0.47492000E+02, 0.38785500E+00, 0.25358700E+01, 0.17041400E+02, 0.29158200E-01, -.61735700E+01, -.19986500E+01, -.67475900E+01, 0.62101200E+01, 0.22173000E+02, -.12514900E+02, -.20024200E+00, 0.66680300E+00, 0.21303400E+02, 0.28580300E+00, 0.70267000E+01, 0.20779200E+02, -.70228800E+01, 0.32599200E+01, 0.15749800E+02, 0.14885000E+02, -.51122700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37433300E-01, -.39187200E-02, -.15291100E+00, 0.55677200E-01, -.63578800E-01, -.44178200E-01, -.66964400E-01, 0.10986600E-01, -.27564000E-01, 0.99371400E-01, 0.35814700E-01, -.32912900E-02, 0.46540800E-01, 0.85882200E-01, 0.45117000E-01, -.66182100E-01, 0.91496800E-02, 0.43078000E-01, -.75252000E-01, 0.71781200E-01, 0.38856600E-02, -.14437000E-01, -.11122200E+00, -.60371700E-02, -.27490100E-01, -.11703700E-03, -.11232000E-01, 0.60679900E-02, -.29836200E-01, 0.42432900E-01, -.60079000E-01, 0.92909700E-01, -.54680500E-01, -.47829000E-01, 0.31889400E-01, -.89110000E-02, 0.25765000E-02, -.18817500E-01, -.66384800E-02, 0.43117400E-01, -.36557800E-01, -.19886000E-02, 0.11144200E-01, -.91868400E-02, 0.45422100E-01, -.16282300E-01, 0.22440500E-01, -.21842500E-02, 0.44649400E-01, 0.45035700E-01, -.24103700E-01, 0.10898700E-01, -.15186000E-01, -.18915300E-01, -.15991300E-01, 0.21595800E-01, -.81449700E-01, 0.65291200E-01, -.19460500E-02, 0.18326600E-01, 0.19576000E-01, -.76380500E-01, 0.70686800E-01, 0.50963000E-02, -.14792600E-01, -.30925700E-02, 0.15328200E-01, 0.39678100E+00, -.17853800E-01, -.48614700E-03, -.25998400E-01, -.19213800E-01, -.13014100E-01, -.36385400E-02, 0.44026900E-01, -.45190100E-01, -.73272700E-01, -.98573100E-01, -.13034600E-01, 0.95199300E-02, 0.82461600E-03, 0.53568300E-01, -.24265000E-01, -.11309200E-01, 0.34000900E-01, 0.65507000E-01, -.78578300E-02, -.86872500E-03, 0.81892200E-01, 0.24993700E-01, -.15065500E-01, -.49948700E-03, 0.27279000E-02, -.23381800E-01, 0.20845000E-01, 0.62274500E-01, 0.99745000E-01, 0.21403500E-01, 0.73352800E-01, 0.14728800E-01, -.10646600E-01, -.53465800E-01, 0.26576900E-03, 0.72396000E-02, -.54138400E-01, -.68349500E-02, 0.53733700E-01, -.44964600E-01, 0.67142200E-03, 0.20440200E+00, 0.21804200E-01, 0.11443200E+00, -.48172600E-02, 0.75249800E-02, 0.38463400E-01, 0.12400100E+00, -.35497700E-01, -.92471200E-02, 0.10242800E-01, -.38321700E-01, -.35727300E-01, 0.98459300E-02, 0.30261600E-01, -.17754700E+00, -.18338200E-01, 0.12657900E+00, 0.27331800E+02, -.53003200E+01, -.22632900E+02, -.12682800E+02, 0.22125300E+02, 0.15128400E+02, 0.12594600E+02, -.72029000E+01, -.13982600E+02, -.40897700E+01, 0.39996700E+01, -.79569000E+01, -.11062100E+02, -.12341900E+01, 0.50698700E+01, -.31652500E+01, -.19681300E+01, 0.11056100E+02, -.70704400E+01, -.73149500E+01, -.62413000E+01, -.11107400E+02, -.19388800E+02, 0.19529700E+02, 0.20208900E+02, 0.14696900E+02, -.18373200E+02, -.50123300E+01, 0.72962800E+01, -.40161100E+01, -.13619500E+01, -.26774700E+01, 0.22887700E+02, -.25507800E+01, -.59437200E+01, 0.15236000E+02, 0.86307300E+01, -.67697100E-01, -.20225400E+02, -.10630600E+02, 0.56631900E+01, -.10947300E+02, 0.70375100E+01, 0.80905900E+01, 0.13558100E+02, -.18876800E+02, -.27707200E+02, -.37579900E+00, 0.18850200E+02, 0.31277600E+01, -.63943500E+01, 0.44512400E+01, 0.60947300E+02, 0.32667100E+01, 0.46138500E+02, -.52369000E+01, 0.13199700E+02, 0.39764000E+02, 0.10290000E+02, -.10820600E+02, -.64442900E+02, 0.92318100E+00, -.13048300E+00, -.12566100E+02, -.15813200E+01, -.76247500E+01, 0.39267800E+00, 0.57971100E+01, 0.10221400E+02, 0.10429900E+02, -.21378900E+01, -.38070900E+01, 0.33935700E+02, -.17258400E+02, 0.36331300E+01, -.16686100E+02, 0.47583900E+01, -.21794500E+02, 0.11489800E+02, 0.26762700E+02, 0.11514500E+02, -.20998000E+02, 0.27983300E+01, -.13115800E+02, 0.70094000E+01, -.71047200E+01, 0.71476800E+01, -.58547200E+01, -.30166600E+01, 0.11094500E+02, 0.15906300E+02, 0.70868500E+01, -.10520500E+01, -.63359400E+01, -.47396200E+00, -.44626000E+01, -.12297000E+02, -.40272300E+00, -.45579900E+01, 0.12991400E+01, 0.16197500E+01, 0.44456200E+01, -.36269900E+01, 0.81247300E+01, -.10621200E+00, -.29218000E+00, -.59621700E+01, 0.62068900E+01, -.90140500E+01, -.53363200E+01, 0.22109700E+01, 0.96072000E+00, -.19113400E+01, -.44074000E+01, 0.33967200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13465800E+00, 0.25175200E+00, 0.21578900E+01, 0.39716600E+00, -.11383100E+01, -.64776700E-03, -.13854000E+01, -.26646000E+00, 0.23194600E+01, 0.76586400E+00, -.56853900E+00, -.61571900E-03, 0.10560400E+01, 0.16144700E+00, 0.85063900E+00, 0.73723700E+00, -.30066500E+00, -.72637900E+00, 0.19436200E+00, -.29929600E+00, -.53339900E-01, -.37438800E-01, 0.65206600E+00, 0.11312300E+00, 0.20204200E+00, 0.15321100E-03, 0.13296800E+00, -.27268900E+00, 0.13376500E+01, -.27493300E+00, -.39408400E+00, -.33393700E+00, -.67073000E-01, -.25602200E+00, -.76181000E+00, -.96242300E-02, 0.46064800E-01, -.83651800E-01, -.28645500E+00, -.10024500E+01, 0.60336600E+00, -.49332000E+00, 0.21767800E-01, 0.12244000E-03, 0.45278500E+00, -.16396700E+00, -.44414800E+00, -.60480800E-01, 0.87524500E+00, -.40348200E+00, 0.35860400E-01, -.17310000E+00, -.50963400E+00, -.74266400E+00, -.46483900E+00, -.83312600E-01, 0.64756600E+00, -.38617400E+00, 0.39671700E-01, 0.40540800E-01, -.23566100E+00, -.20281500E+00, 0.84770300E+00, 0.13094100E+00, 0.30212200E+00, -.15007300E+00, 0.18036800E+00, 0.55671900E+01, -.10142600E+00, -.20452000E-01, 0.60294700E-01, 0.13961800E+00, 0.11514300E+00, 0.56576800E-01, 0.29692900E+00, 0.54087000E+00, 0.11940300E+00, -.56523600E+00, 0.23766800E-01, -.15202700E+00, 0.11857800E-01, 0.59707400E-02, 0.15298700E+00, 0.38053400E+00, 0.42550600E+00, -.44561300E+00, -.17767800E+00, -.46026900E-02, 0.20949900E+00, 0.80855500E+00, -.81130000E+00, 0.17103100E-01, -.15467700E-01, -.37024700E-01, 0.39315800E-01, 0.30413000E+00, 0.40295800E+00, 0.76740200E-01, -.30902000E+00, 0.27577300E-01, 0.19932800E+00, -.17558800E+00, 0.57462700E-01, -.79210200E-01, 0.59872400E+00, -.16122200E+00, 0.11224800E+00, -.49244400E+00, 0.26118600E+00, 0.11625000E+01, 0.32108000E-01, 0.62802100E+00, 0.11137300E+00, -.17397400E-01, 0.22939600E+00, 0.62034700E+00, -.69372600E-01, -.72373000E+01, 0.20541500E+00, -.43423200E+00, 0.28131200E+00, -.22184100E+00, 0.12223000E+00, -.28663800E+00, 0.34899000E-01, 0.82231600E+00, 0.12367000E+01, 0.14207200E+03, 0.36314300E+02, -.58025600E+01, 0.25190200E+02, 0.23806500E+02, 0.47102300E+02, -.27291000E+02, 0.45045700E+02, -.27245100E+02, 0.12112200E+02, 0.70718300E+00, 0.10088900E+02, 0.54496000E+02, 0.47519700E+02, -.51196900E+01, -.37219400E+02, 0.13229800E+03, -.74342500E+02, -.65874100E+02, -.66933300E+02, -.35266400E+02, -.42173500E+02, 0.48384400E+01, 0.77609500E+02, 0.17956400E+02, -.44888700E+02, -.54505100E+02, 0.30685500E+03, -.15432800E+03, -.14960700E+03, -.15067800E+03, -.58183600E+02, -.11642300E+02, -.11348000E+03, -.53218200E+01, -.30517600E+02, -.34610200E+02, -.12183900E+03, -.22586700E+03, 0.11158300E+03, -.13759600E+02, 0.11462400E+03, 0.10190500E+02, -.21548900E+02, 0.78772200E+02, 0.17172100E+02, 0.71551200E+02, -.11358200E+01, 0.22756500E+02, 0.19356400E+03, -.92832400E+02, -.36175500E+02, -.97763500E+02, 0.82104400E+01, 0.83582300E+02, -.21536700E+02, 0.74002500E+02, -.72053100E+02, 0.10739000E+03, -.22904400E+03, 0.28930900E+03, -.14455400E+03, -.12066900E+03, -.14229600E+03, -.66100500E+02, -.53398900E+02, -.41726600E+02, -.22494100E+02, -.74802900E+02, -.38427400E+02, -.73071200E+02, -.22993800E+03, 0.11845700E+03, 0.22562100E+02, 0.11503800E+03, 0.32140100E+02, 0.15699900E+02, 0.14333300E+03, 0.18718700E+03, 0.65847000E+02, 0.18597100E+02, -.79611100E+01, -.11636100E+03, 0.56396000E+02, -.10844400E+02, 0.58743500E+02, 0.27829400E+02, -.21413400E+02, -.12457600E+02, -.20618600E+02, 0.20754800E+02, -.53461600E+01, -.27971100E+02, 0.92879600E+00, -.85566200E+01, 0.13947700E-02, 0.69859600E+00, 0.22642400E+02, 0.50365800E+01, -.31005900E+01, -.21655500E+02, -.11120200E+02, -.26386700E+02, 0.84752200E+00, -.34406100E+01, -.38049100E+01, -.28272900E+02, 0.80635000E+01, 0.97403500E+01, -.21472500E+01, -.23103700E+02, -.79382400E+01, 0.20626700E+01, 0.41424300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22612600E-01, 0.98351200E-01, 0.38370400E+00, 0.19256700E+00, 0.18586000E-01, -.60902800E-01, 0.10229400E+00, -.14893800E-01, 0.33621500E+00, 0.78896200E-01, -.34840800E-01, -.16476700E-01, 0.11235800E+00, -.22017400E-01, 0.13671400E-01, 0.12095000E+00, -.26811000E-01, -.76152700E-01, 0.45843800E-01, -.33125100E-01, 0.33294700E-03, 0.77606400E-02, 0.10381400E+00, 0.81007600E-02, 0.33321600E-01, 0.16826700E-04, 0.19277900E-01, -.12011900E-01, 0.62538600E-01, -.22634200E-01, 0.92704500E-02, -.91881800E-01, 0.36735100E-01, 0.27787700E-02, -.47243400E-01, 0.10474200E-01, -.19295200E-02, 0.16512800E-01, -.89688000E-02, -.81817100E-01, 0.61219600E-01, 0.31301500E-01, -.20766600E-01, -.11350200E-01, -.14352900E-01, 0.79124800E-02, 0.68380300E-02, -.17160800E-02, 0.50003900E-01, 0.15185500E-01, 0.18714000E-01, -.30979900E-01, -.56516900E-01, 0.37206600E-02, -.22585800E-01, -.23081900E-01, 0.42209500E-01, -.37485200E-01, 0.27904500E-02, -.12148600E-01, 0.28386100E-01, 0.48166300E-01, 0.15871600E+00, 0.95544700E-02, -.29582800E-01, 0.33411200E-02, -.14762400E-01, 0.15795500E+00, 0.17710000E-01, 0.17089800E-02, 0.14969800E-02, -.16655300E-01, 0.20652000E-02, 0.66453000E-02, -.40898700E-01, 0.62516100E-01, 0.24482300E-01, 0.96316000E-01, 0.73781900E-02, -.11145200E-01, 0.98890100E-03, -.95747400E-02, 0.29811700E-01, 0.23231200E-01, 0.39004500E-01, -.51414800E-01, 0.21087500E-01, 0.66040600E-02, -.16749300E-01, -.67803800E-01, -.37093300E+00, -.16261100E-02, -.76396900E-01, -.23314800E-01, -.12953000E-01, 0.47372700E-02, -.10009000E+00, 0.23405700E-01, -.25591500E+00, 0.42851500E-01, -.25547900E-01, 0.73543700E-01, 0.26600700E-02, -.21693600E-01, 0.34308400E-01, 0.14636300E-01, -.11573000E-01, 0.57344100E-01, 0.45433400E-02, -.72980400E-01, -.24531800E-01, -.55394200E-01, -.30768100E-01, -.22035200E-02, -.18804900E-01, 0.14268300E-01, 0.51166100E-01, -.12190400E+01, 0.19167200E-01, 0.13049700E-01, 0.11209700E-02, 0.27964300E-01, 0.25798500E-01, 0.12391800E+00, 0.12709300E-01, -.12126900E+00, -.98893000E+00, 0.38142500E-01, -.24923700E+02, -.22613900E+02, 0.31774300E-01, -.24473700E+02, -.28092200E+02, 0.13386700E+02, 0.15372800E+02, 0.15038900E+02, -.49078400E+00, 0.64940100E+01, -.16585500E+01, -.18206000E+02, -.48621400E+01, 0.57176400E+01, 0.14223900E+02, -.30631500E+02, 0.13763600E+02, 0.16521000E+02, 0.15120200E+02, 0.11834900E+01, 0.69311000E+00, 0.78406800E+01, -.57362400E+01, 0.66165900E+01, 0.10828900E+01, 0.14609100E+02, -.23090500E+02, 0.11574200E+02, 0.83046100E+01, 0.11659200E+02, 0.95113600E+00, -.88872400E+01, 0.92077800E+01, 0.13795400E+02, 0.24348300E+02, -.37419700E+01, 0.16385000E+02, 0.17954100E+02, -.93752300E+01, -.22807200E+02, -.85713100E+01, -.30541400E+01, -.11308200E+02, 0.11771500E+01, 0.80069700E+01, 0.11392600E+02, -.93082700E+01, -.29698800E+01, -.75551500E+01, 0.50982300E+01, -.25226500E+01, 0.38213400E+01, 0.12062700E+02, 0.26113800E+01, 0.11613700E+01, 0.59000000E+01, 0.18869000E+02, -.66055500E+01, -.22290300E+00, -.51836600E+02, 0.27161000E+02, 0.11112400E+02, 0.25369700E+02, 0.73163000E+01, 0.51730200E+01, 0.13169800E+02, 0.34997900E+01, 0.21267100E+02, 0.43576500E+01, 0.14473400E+02, 0.67946500E+02, -.33820100E+02, -.16984700E+02, -.33915700E+02, -.77336100E+01, 0.22173700E+01, -.22855500E+02, 0.10164400E+02, 0.10593600E+01, -.42701500E+01, 0.45130400E+01, 0.16734000E+02, -.83712900E+01, -.98291900E+01, -.82376000E+01, -.10698400E+02, -.10355100E+02, 0.62462100E+01, 0.23803900E+02, 0.15170600E+02, -.10322100E+02, 0.60373100E+00, -.11774800E+00, -.26319300E+01, -.11206900E+02, -.15557300E+00, -.73457600E+01, 0.19513200E+01, -.24693500E+00, 0.73579300E+01, 0.10590600E+01, 0.78083100E+01, -.37799600E+00, 0.84005000E-01, -.10334300E+02, 0.83061800E+01, -.11404100E+02, -.95412300E+01, 0.41681300E+00, 0.26696900E+01, 0.13721900E+01, -.35525500E+01, -.15279800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18828700E-01, 0.12866900E-01, -.94176600E-01, 0.58805200E-02, 0.18842000E+00, -.29156200E-01, -.23283900E-01, 0.46591300E-02, -.77387900E-01, -.84659800E-01, 0.93878600E-02, -.15274900E-01, -.65077900E-02, -.21930300E-02, -.13967700E-01, -.24310800E-01, -.59822700E-01, 0.41163700E-01, -.27775600E-01, 0.22632900E-01, -.35479200E-02, -.92977600E-03, -.15600300E+00, -.11409500E-01, -.20786000E-01, -.40891600E-04, -.21242100E-01, 0.29594100E-01, -.63325800E-01, 0.41645200E-01, 0.18494600E-01, 0.41183500E-01, 0.16602500E-01, 0.31148700E-01, 0.43555800E-01, 0.56076000E-02, -.97900400E-02, -.21624300E-02, 0.20942300E-01, 0.26537200E-01, -.90423400E-03, -.20779300E-01, 0.11292200E-02, -.63338700E-02, -.84496700E-03, -.24110700E-03, 0.60707900E-01, -.22125800E-02, -.44291000E-01, 0.24276800E-01, 0.95555700E-02, 0.44679500E-01, 0.49433000E-01, 0.18740000E-01, -.23618700E-01, -.12889000E-01, 0.36596300E-01, -.26845600E-01, 0.81897200E-02, -.12190000E-01, -.18308800E-01, 0.86511800E-03, -.39018200E-01, -.86803400E-02, 0.14899900E-01, 0.21230600E-01, 0.34911100E-02, -.45826600E-01, 0.86505300E-02, -.12003400E-02, 0.26252900E-01, 0.25199600E-01, 0.10433700E-01, 0.13602800E-01, 0.14856700E-01, -.70833600E-03, 0.26808100E-01, -.17411000E+00, -.11062000E-01, -.18316400E-01, 0.12718100E-02, -.32063500E-01, 0.10208100E-02, 0.31117500E-01, -.10506300E-01, 0.29355100E-01, -.25775200E-01, -.48164200E-02, -.16329700E-01, 0.18847700E-01, 0.87685500E-01, 0.47377400E-04, -.34109900E-01, 0.28946200E-01, 0.29276000E-02, -.29104500E-01, -.19834000E-01, 0.11776900E-01, 0.55303700E-03, 0.12477500E-01, -.17270600E-01, 0.76937400E-02, -.20544100E-03, 0.17102700E-01, 0.40505000E-01, 0.20513400E-02, -.52501600E-02, 0.27002000E-01, 0.89769500E-02, -.22956600E-01, 0.42974700E-02, -.39696600E-02, 0.16112700E-01, -.43765500E-03, -.50880300E-02, 0.21615300E-01, 0.12205500E-01, -.13705200E+00, 0.61983100E-02, 0.46075500E-01, 0.39777500E-01, -.14198200E-01, 0.18598500E-01, -.63537700E-01, 0.31663000E-02, 0.23292100E-01, -.12571500E+00, 0.22649200E-01, 0.12196200E+00, 0.17404000E+02, -.38988300E+01, 0.47709800E+01, 0.14340200E+02, -.75111900E+01, -.19016300E+02, -.64586300E+01, -.53702100E+00, -.76906100E+01, -.34510300E+01, 0.56655600E+01, 0.45196600E+01, -.53698400E+01, -.32201700E+01, 0.10235200E+02, -.52636900E+01, -.11594200E+02, -.55015900E+01, -.45171400E+01, -.62312600E+01, 0.42883000E+01, 0.13394800E+02, 0.49275200E+01, -.67771300E+01, 0.17323800E+01, 0.11597200E+01, -.73782900E+00, -.13903600E+01, -.32407000E-01, 0.12790000E+02, 0.46025000E+01, -.38837500E+01, 0.38528100E+01, -.93495000E+01, 0.70506800E+01, -.10347900E+01, -.10561100E+02, 0.57060900E+01, 0.22085700E+01, 0.60664900E+01, 0.39883100E+01, 0.16204700E+02, -.13203300E+02, -.20650300E+02, -.25544000E+01, 0.16881900E+02, 0.25150600E+01, -.98282500E+01, 0.49346300E+01, 0.23115200E+02, 0.48784800E+01, 0.14617100E+02, -.74649200E+01, 0.60228600E+01, 0.99929100E+01, 0.14790700E+01, -.61817100E+01, -.28176400E+02, 0.14620200E+02, -.75265300E+01, -.15476900E+02, -.76683300E+01, -.28358500E+01, 0.32155900E+01, -.67578900E+01, -.22323500E+01, -.25537000E+01, 0.11134500E+01, -.72868700E+01, 0.18478100E+01, -.11145400E+01, 0.32113800E+01, -.82506600E+00, 0.64242400E+01, -.14439200E+02, 0.91954700E+01, 0.52116000E+01, -.87892500E+00, -.88486800E+01, -.53134900E+01, -.26764600E+02, 0.13544600E+02, 0.10371200E+02, 0.13642100E+02, 0.55864600E+01, 0.91595100E+01, 0.93109400E+00, -.87110900E+01, -.42394800E+01, 0.10376300E+02, 0.26882200E+01, -.17849700E+00, -.30716800E+01, -.41197800E+01, -.56530500E-01, -.93350500E+00, 0.16067700E+01, -.88675500E+00, 0.90299300E+00, 0.10766800E+01, 0.21897500E+01, 0.35605900E+00, -.21210900E+00, 0.35397900E+01, 0.13748600E+01, -.40023100E+01, -.28095300E+00, 0.26750600E+01, -.40290300E+00, 0.90523500E+00, 0.13099000E+01, 0.16573800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18060400E+00, -.53622300E-01, -.15657600E+01, -.94044200E-01, 0.18610600E+01, -.24316500E+00, -.34975700E+00, 0.18930600E+00, -.43062200E+00, -.14737600E+01, 0.16347300E+00, -.50041100E-01, -.73472200E+00, -.14810600E+00, -.30682800E+00, -.40738200E+00, -.66678700E+00, 0.36037400E+00, -.36005900E+00, 0.27823400E+00, 0.12091100E-01, 0.55346100E-01, -.89587600E+00, -.14503200E+00, -.10920100E+00, -.60874400E-03, -.63795900E-01, 0.48409900E+00, -.10096100E+01, 0.65322500E+00, -.18977100E+00, 0.10843500E+01, -.30505300E+00, -.43486400E-01, 0.10154700E+01, -.72710500E-01, -.18406900E-01, -.18260000E+00, 0.17348700E+00, 0.12133400E+01, -.12231600E+01, 0.18746300E+00, 0.41056800E-01, -.15291300E+00, 0.12859800E+01, -.36029100E+00, 0.10626500E+00, 0.54404400E-01, -.46247400E+00, 0.67034400E+00, 0.52332600E+00, 0.95431200E+00, -.19527700E-01, -.18042800E+00, 0.80670300E-01, 0.42724500E-01, 0.18303700E-01, -.25849000E+00, -.18808700E-01, 0.99450600E-01, -.19041700E+00, -.19862900E+00, 0.27230900E+00, 0.70631700E-01, 0.12397000E+00, -.12219900E+00, 0.67125100E-01, 0.39096700E+01, -.22756400E-02, 0.81310600E-02, -.12985400E+00, 0.15891100E-01, 0.30458000E-01, 0.87483800E-01, -.43698900E-01, 0.37176800E-01, -.16722000E+00, 0.60585100E+00, 0.10898900E+00, 0.13417000E+00, 0.18931400E-02, 0.45504000E+00, 0.45066500E-01, -.11553500E+00, 0.51907500E-01, -.23724000E+00, 0.16163900E+00, 0.31038400E-01, 0.34798900E-01, -.15043900E+00, 0.76298700E+00, 0.59122200E-02, 0.21974200E+00, -.30731500E+00, -.14429000E+00, -.75565500E-02, 0.17858200E+00, 0.13052900E-01, 0.15680500E+00, 0.11498700E-02, -.11241200E+00, 0.14800300E-01, -.90821700E-03, 0.78927700E-01, -.44048400E+00, 0.11737300E+00, -.47148900E-01, 0.20067600E+00, 0.41830700E-01, 0.59947700E+00, 0.27617200E+00, -.15718400E+00, 0.12180000E+00, -.26082500E-01, -.11086400E+00, 0.11020900E+00, 0.42769000E-01, 0.17334200E+01, -.27788500E-01, 0.33417900E+00, -.28719400E+00, 0.61789500E-01, -.44571400E-01, 0.40339500E+00, -.29279100E-01, -.23229000E+00, 0.13793700E+01, -.20777200E+00, -.16084100E+01, 0.98655600E+00, -.17713800E+02, -.93310000E+02, -.47468000E+02, 0.25200500E+02, 0.88492000E+01, 0.22531400E+02, -.61708000E+01, 0.34298800E+01, 0.28032100E+01, -.34365500E+02, -.36947600E+02, 0.59170800E+01, 0.38382200E+01, -.10144700E+03, 0.49048500E+02, 0.51664700E+02, 0.51744500E+02, 0.18937400E+02, 0.22257700E+02, -.73157100E+01, -.56609200E+02, -.12065800E+02, 0.25457000E+02, 0.40787800E+02, -.48223300E+02, 0.25575800E+02, 0.26988700E+02, 0.22166300E+02, -.27413800E+02, -.21352500E+02, 0.19623900E+02, 0.20364800E-01, 0.17709000E+02, -.11811800E+02, 0.75478600E+02, 0.13581500E+03, -.71243400E+02, -.33213100E+02, -.70252000E+02, -.41289900E+02, -.50019800E+02, 0.13342000E+02, 0.64598900E+02, 0.26068600E+02, -.66060500E+02, -.20054800E+02, -.10094400E+03, 0.52229200E+02, -.50083900E+02, 0.50796500E+02, -.69407100E+02, -.35517000E+02, 0.18643300E+02, -.52202200E+02, 0.48254900E+02, -.30731500E+02, 0.11033000E+03, -.14079400E+03, 0.73483500E+02, 0.85139600E+02, 0.70934500E+02, 0.24397300E+02, 0.67508800E+01, 0.44497500E+02, 0.18516100E+02, 0.39964700E+02, 0.11916400E+02, 0.12262600E+02, 0.48289800E+02, -.23352800E+02, -.53368400E+02, -.24382700E+02, -.44483000E+02, 0.53818600E+01, -.55013200E+02, -.66220000E+02, -.32660400E+02, 0.10823200E+02, 0.33444000E+02, 0.18062400E+02, -.10103100E+02, 0.41379400E+02, -.97939000E+01, -.92669700E+01, 0.12024900E+02, -.21383200E+02, -.19921000E+02, 0.66731100E+00, 0.66557800E+00, 0.44654300E+02, 0.70080100E+00, 0.82487000E+01, 0.82344200E+01, 0.38693300E+00, -.13943500E+01, -.11018700E+00, 0.98779400E+00, 0.15286500E+01, -.29291800E+01, -.10246600E+01, -.45213800E+00, 0.13398500E+00, -.71797600E+01, -.50358600E+00, 0.44802600E+01, -.70889000E+01, -.53061200E+01, 0.65432600E+01, -.19979700E+01, 0.48023200E+00, -.12378800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.46853500E+00, -.15651300E+00, 0.11196600E+01, -.87608200E-01, -.40285200E+00, 0.34234700E+00, -.11554200E+01, 0.12251400E+00, 0.12173600E+01, -.27302100E+00, -.26903800E+00, 0.24140800E+00, 0.99161400E+00, 0.10582400E+01, 0.48932200E+00, -.97482400E-01, 0.35263400E+00, 0.16389500E+00, 0.11487900E+00, 0.67226600E+00, 0.71104700E-01, 0.34040500E-01, 0.58207300E+00, 0.58593600E-01, -.85774400E-02, -.98082200E-03, 0.15181800E+00, 0.32997500E+00, -.60243000E+00, -.58079400E+00, -.21242900E+00, -.71240500E+00, -.40238400E+00, 0.63433100E-02, 0.15544300E+01, 0.29203200E+00, 0.22682200E+00, -.11000200E+00, -.30894200E+00, 0.44260900E+00, -.61703700E+00, -.22080700E+00, 0.15981700E+00, 0.11488300E+00, -.13747200E+00, -.21084500E-01, -.32342900E+00, 0.17188400E+00, -.55658500E+00, 0.20579200E+00, 0.25468000E-01, 0.29568100E+00, -.56144100E-01, 0.27807400E+00, 0.89793900E+00, 0.42675700E+00, -.82329400E+00, 0.87459200E+00, -.20151100E+00, 0.14513400E+00, -.67731300E+00, -.68285200E+00, -.69129900E+00, 0.70940600E-01, -.89228500E-01, -.32447800E+00, 0.68702700E-01, 0.15552500E+01, 0.11566900E+00, 0.10798500E-01, -.25668700E+00, -.66551300E+00, 0.21635500E+00, 0.17151800E+00, 0.25820700E+00, -.11226800E+01, 0.76023600E-01, -.94323700E-01, -.30434400E-01, -.37875200E-01, -.76892800E-02, 0.30521500E+00, -.70942800E+00, -.61304700E+00, -.13083100E+01, 0.17081800E+01, -.72890700E+00, -.54360300E-01, -.20525500E+00, 0.10414000E+01, 0.15307500E+01, 0.19335300E-01, 0.56600500E+00, 0.56817800E+00, 0.11732400E+00, 0.44305600E+00, 0.30790300E+00, -.21227300E+00, 0.12479600E+01, -.71065000E-02, 0.12425400E-01, -.88549400E-01, 0.28887400E-03, -.94433900E-01, -.40940900E+00, 0.11206500E+00, 0.13042200E+00, -.57480700E+00, -.26752900E+00, 0.10119200E+01, 0.20691100E+00, 0.77036100E-02, 0.51830700E-01, 0.56430800E-01, -.24501400E+00, 0.46498200E+00, -.20782600E-01, -.69305800E+01, 0.42900400E-01, -.15456300E+01, -.57417800E+00, -.15577200E+00, -.24391100E+00, 0.24425200E+00, 0.11022000E+00, 0.40426200E+00, -.83362700E+01, -.37732200E+00, 0.14007500E+01, -.40770100E+01, 0.10764800E-01, 0.46816600E+03, 0.33507000E+03, -.17283300E+03, -.13239300E+03, -.16724900E+03, -.11142300E+03, -.14387500E+03, 0.40318000E+02, 0.15237200E+03, 0.11000100E+03, -.13628400E+03, -.56827000E+02, 0.24973900E+03, -.12843400E+03, -.15794900E+03, -.12784200E+03, -.52496000E+02, -.42806100E+02, -.51411700E+02, 0.13028200E+03, 0.31064300E+02, -.53568900E+02, -.81540600E+02, 0.18590900E+03, -.96199800E+02, -.13114600E+03, -.90069000E+02, -.62967400E+02, -.26856200E+02, 0.19104700E+01, 0.86361200E+02, -.32568300E+02, 0.23645000E+01, -.39488900E+03, -.59062300E+03, 0.30582000E+03, 0.97303500E+02, 0.29738100E+03, -.60710100E+02, 0.74318100E+02, 0.16137100E+03, -.10753800E+02, -.67146100E+02, 0.11839900E+03, 0.28183300E+03, 0.29053100E+03, -.14428700E+03, -.62662500E+02, -.14551000E+03, -.38247800E+03, -.40311200E+02, 0.85877200E+02, 0.29164200E+03, -.65526600E+02, -.43760200E+02, -.18453300E+03, 0.81276700E+03, -.41065100E+03, -.27024600E+03, -.40714300E+03, -.16648400E+03, -.59055800E+02, -.11609300E+03, 0.17459100E+03, -.16115600E+03, -.52630700E+02, -.60470600E+02, 0.22025300E+03, -.11481600E+03, -.15192200E+03, -.11091200E+03, 0.23770900E+02, 0.13621700E+03, 0.88521100E+01, 0.23663000E+03, -.16255400E+03, 0.15269800E+03, -.37524700E+03, -.45133500E+02, 0.26146900E+02, -.13317600E+03, 0.22825800E+02, -.62257900E+01, -.10025900E+03, 0.12366100E+03, 0.14260400E+03, 0.72831900E+01, -.39339100E+02, -.54314600E+02, 0.71701200E+00, -.21450100E+02, -.62443100E+02, -.10888200E+01, -.32379100E+02, 0.31037100E+01, -.11598100E+02, 0.32736600E+02, -.42108300E+02, 0.43776700E+02, 0.54872300E+01, 0.69493800E+01, 0.79591700E+01, 0.47603900E+02, -.57555600E+02, -.19320000E+02, 0.23073100E+02, 0.97688000E+01, -.24755500E+02, 0.76425100E+01, 0.52458100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.70271700E+00, 0.43544300E+00, -.13140700E+01, 0.72741400E+00, 0.66755200E+00, -.27514300E+00, 0.25057900E+01, 0.14800500E-01, -.15076400E+00, 0.14108900E+01, 0.21531300E+00, -.25209200E+00, 0.16281300E+00, -.61927100E+00, -.66215000E+00, 0.86025600E+00, -.16121200E+01, -.46978700E+00, 0.60503700E-01, -.51011600E+00, -.26465200E-01, -.10031800E+00, -.31113900E+00, -.94299600E-01, 0.35809500E+00, 0.11282900E-02, 0.23117200E-01, 0.41068100E+00, -.82670200E+00, 0.58418800E+00, -.60887200E+00, 0.21376300E+01, -.44179300E+00, 0.29754400E+00, 0.11043000E+01, -.19932000E+00, -.56094800E-01, -.49567600E+00, 0.33673800E+00, 0.18510300E+01, -.20307900E+01, 0.32252600E+00, 0.11214400E+00, -.15982900E+00, 0.20336700E+01, -.53920600E+00, 0.13413500E+00, -.12292100E-02, -.12921200E+01, -.46377700E+00, 0.10554700E+01, 0.12633000E+01, -.11811300E+01, -.79108200E+00, -.79125600E+00, 0.20481600E+00, 0.95838500E+00, 0.52009400E+00, -.70599100E-01, 0.30778900E+00, -.29597400E+00, 0.16903500E+00, 0.98760000E+00, 0.60183800E-01, -.18176600E+00, -.67304100E+00, -.80023400E-01, 0.20006000E+01, -.11611600E+00, -.10332500E-01, 0.24089200E+00, 0.79374400E+00, 0.24899200E+00, -.15596900E+00, -.41530300E+00, 0.12663200E+01, 0.35079900E+00, -.42815700E+00, 0.84017400E-01, 0.40841700E-02, 0.57610700E-01, -.25994000E-01, 0.53479100E+00, 0.12954900E+01, 0.13365100E+01, -.19477300E+01, 0.30030900E+00, -.57083000E-01, 0.39916800E+00, -.42285200E+00, 0.10216600E+01, -.76490800E-02, -.14396900E+01, -.25289700E+00, -.70798000E-01, -.15257000E+01, -.85294700E+00, 0.51074900E+00, -.21685200E+00, -.47638600E+00, -.27403300E+00, -.50940600E-01, -.20749500E-02, 0.55920100E+00, 0.49694300E+00, -.96101500E-01, -.25586400E+00, 0.12721000E+01, 0.12918300E+00, -.16195800E+01, 0.81248400E+00, -.25353000E+00, 0.39553200E+00, -.15749400E+00, -.30517200E+00, -.57831900E-01, 0.56354400E-01, 0.14529600E+02, -.14341000E+00, 0.93393400E+00, 0.57486400E+00, -.63801900E+00, -.52539200E+00, -.22836500E+00, 0.11574200E-01, 0.33761900E+00, 0.97547900E+01, -.29716400E+00, 0.13811700E+01, 0.89373200E+01, -.68530900E+00, -.80249300E+00, 0.72314000E+03, -.34675800E+03, -.29582000E+03, -.37702400E+03, -.36462000E+02, -.15747700E+03, 0.22606600E+02, 0.24962700E+03, -.92338600E+02, -.16432400E+03, -.46720700E+03, 0.44542400E+03, -.20804200E+03, -.16428300E+03, -.22131600E+03, -.38212900E+02, -.12361000E+02, -.10948600E+03, 0.12076500E+03, -.73730600E+02, -.23728300E+02, -.17008000E+03, 0.80021600E+03, -.39762800E+03, -.42953900E+03, -.39790100E+03, -.28127500E+03, -.13217200E+03, -.43887400E+02, 0.12953700E+03, -.53070100E+02, -.17600200E+03, -.32329200E+03, 0.24050200E+03, -.11917300E+03, 0.53195300E+02, -.12262400E+03, -.41609700E+02, -.56190000E+02, 0.16263800E+02, 0.93847800E+02, -.36312100E+02, -.93098800E+02, -.12179500E+03, 0.22174900E+03, -.12664700E+03, -.37719000E+03, -.11297300E+03, -.28187100E+03, 0.70176500E+02, -.11380200E+03, -.22248200E+03, -.23458700E+03, 0.17344800E+03, -.61662100E+02, 0.75006500E+03, -.38701900E+03, 0.33104500E+02, -.36604600E+03, -.73557400E+02, -.89843100E+02, -.10644300E+03, 0.20141300E+02, -.27408900E+03, -.69702300E+02, -.29477900E+03, -.94295600E+03, 0.46973600E+03, 0.11838400E+03, 0.47090700E+03, -.68989100E+02, 0.12159300E+03, 0.12536900E+03, -.22082500E+03, 0.76313100E+02, 0.14043600E+03, 0.13505100E+03, -.28867800E+02, 0.11912800E+02, 0.15997200E+03, 0.13699200E+02, 0.82088900E+02, 0.75798100E+02, -.14217700E+03, -.20645100E+03, -.56947500E+02, 0.42539700E+02, 0.42811900E+02, 0.46403800E+01, 0.48352400E+02, 0.72915000E+02, 0.40509500E+01, 0.91640000E+02, -.11708500E+02, 0.40909600E+01, -.89905100E+02, -.28634600E+02, -.45406200E+02, 0.73781300E+01, 0.67188600E+01, 0.13410500E+02, -.81423300E+02, 0.78641900E+02, 0.24307700E+02, -.27815900E+02, -.40320600E+02, -.26774300E+02, 0.32343500E+02, -.32631900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.81586300E+00, 0.63224900E+01, 0.96992000E+01, 0.55813300E+01, -.18268800E+01, 0.56527500E+01, -.35519600E+01, -.22356300E+00, -.80957000E+01, -.56333700E+01, -.26714000E-01, 0.16133400E+01, -.79669400E+01, -.14143100E+01, 0.52829800E-02, -.47035300E+01, 0.48615500E+01, -.18234900E+01, 0.31322900E+01, -.36447000E+01, -.15074200E+00, -.41990800E+00, 0.43492200E+01, 0.12632300E+01, 0.11533400E+01, 0.45539400E-02, 0.63601400E+00, -.62312400E+00, 0.13548900E+01, -.15672000E+01, 0.24802000E+00, -.17809700E+01, 0.38854200E-01, 0.18167000E+01, -.31725200E+01, -.38395300E+00, 0.36105400E+00, 0.92700700E+00, -.46810700E+00, -.17716400E+01, 0.20664400E+01, -.78294300E+00, 0.17580000E+00, 0.36107500E+00, -.65138500E+01, 0.93031100E+00, -.12006300E+01, 0.17655200E+00, 0.10860700E+01, 0.10459800E+00, -.18740800E+01, 0.47924400E+00, 0.32161900E+01, 0.24116600E+00, -.20514500E+00, -.65561600E+00, 0.27864100E+01, -.12835500E+01, 0.30566500E+00, -.81755600E+00, 0.79006600E+00, 0.15282400E+01, 0.62457800E+00, -.13370200E+00, 0.41205300E+00, 0.83258500E+00, -.80135900E+00, 0.89458800E+00, -.48552900E-01, 0.10413900E+00, 0.42403000E+00, 0.14705000E+01, 0.28200600E+00, -.49342600E+00, 0.79827900E+00, 0.71356600E+00, 0.21400500E+01, -.16968000E+00, 0.58271000E+00, 0.27522400E+00, 0.22922300E-01, 0.14209100E+01, -.73043000E+00, -.32537200E+00, -.13088100E+01, 0.26109800E+01, -.18399100E-01, -.19637200E+00, -.50096700E+00, -.14499200E+01, 0.16659900E+01, -.10943200E+00, -.63803300E+00, 0.28631200E+00, -.41451400E+00, -.85968400E+00, 0.75745700E+00, -.11660500E+00, 0.56770600E+00, 0.14674600E+01, -.26957800E+00, -.18961300E+00, -.13937100E-01, 0.28019600E+00, -.22925000E+01, 0.29567200E-01, 0.13909700E+00, 0.12455500E+01, -.32698600E+00, -.10863300E+01, 0.23322700E+00, -.84151800E+00, 0.10201800E+00, 0.37423700E-01, -.30796600E+00, -.38054000E+00, 0.11718200E+00, 0.67012900E+01, -.25534900E+00, -.66338300E+00, 0.16986300E-01, 0.69418700E-01, -.88179800E+00, 0.15913700E+01, 0.86115600E-01, -.73940900E-01, -.82431500E+01, -.28225700E+00, 0.47598800E+01, -.34268800E+01, -.88941700E-03, 0.45113200E+00, -.17677800E+00, 0.32833200E+02, -.60607300E+02, -.22111500E+01, 0.10968800E+02, -.11528200E+03, -.46961800E+01, 0.15460300E+02, 0.98553600E+02, -.81586700E+02, -.23672000E+02, 0.56293500E+02, -.17210800E+02, -.57823200E+02, -.28321100E+02, -.24943700E+02, -.49689300E+02, -.73107000E+01, 0.50088100E+02, 0.21824900E+02, -.45338600E+02, 0.73186000E+01, 0.79273300E+02, -.38610400E+02, -.16413500E+02, -.38142500E+02, 0.79996100E+02, -.34325400E+02, 0.89698800E+01, 0.16122100E+02, 0.90889600E+01, -.32004500E+02, -.53916600E+02, -.78514000E+02, 0.35666100E+02, 0.78896800E+02, 0.39913200E+02, 0.25549900E+01, 0.10374600E+03, -.76801900E+02, -.19089800E+03, -.52385500E+02, 0.12078100E+03, 0.41792400E+02, -.22259300E+03, 0.10677100E+03, 0.21094200E+03, 0.11088900E+03, -.32058400E+02, -.10629400E+03, 0.10792300E+03, 0.44577000E+02, 0.68369700E+02, -.69314900E+02, -.11460600E+02, 0.19685100E+03, -.98436300E+02, -.43571100E+02, -.96986100E+02, -.84007800E+02, -.20327900E+02, -.71364900E+01, 0.84958000E+02, -.26183500E+02, -.28116900E+02, -.79228000E+02, -.14146200E+03, 0.71397400E+02, -.59307400E+01, 0.70619200E+02, 0.17631200E+02, -.14855600E+03, 0.15086900E+03, 0.40199500E+02, 0.13252100E+03, -.96874700E+02, -.48256400E+02, -.22174100E+02, 0.94528800E+01, -.28373100E+01, 0.11260000E+02, 0.27643600E+02, 0.47991800E+02, -.21055000E+02, -.36479100E+02, -.43268600E+02, 0.55640800E+02, -.41017500E+01, -.17090000E+00, 0.79259800E+00, 0.14706000E+02, 0.12184400E+00, -.16612400E+01, -.10896400E+00, 0.50578800E+01, 0.14912700E+01, -.29380500E+02, 0.10394100E+02, 0.22609200E+01, 0.21366200E+00, 0.14027100E+02, -.43420200E+01, 0.13783400E+02, 0.14586800E+02, 0.56986300E+01, -.43529900E+01, -.18960500E+02, -.67813300E+01, 0.16737600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.72568800E+00, 0.10711800E+01, -.73067500E+00, 0.15403100E+01, 0.13969200E+01, 0.20391600E+00, 0.25336400E+01, -.11511900E+00, -.31289900E+01, -.24884400E-01, 0.35833400E+00, 0.90081400E-01, -.43991400E+01, -.50013800E+00, 0.14401900E+00, -.21167200E+01, 0.18602600E+01, -.35917800E+00, 0.17656300E+01, -.16634500E+01, 0.27160300E-01, -.66889400E-01, 0.28827200E+01, -.46374200E-02, -.45574900E+00, 0.19236800E-02, 0.38014600E+00, -.32438000E-01, -.39643000E+00, -.10540900E+01, -.34997300E+00, 0.26037200E+00, -.85588100E+00, 0.12273100E+01, 0.54547800E+00, -.11300000E+01, 0.39970000E+00, 0.57665600E+00, -.59230500E+00, 0.90104800E+00, 0.72900100E+00, -.12119600E+01, 0.66598500E+00, 0.28178700E-01, -.33547000E+01, -.28760000E+00, 0.14973100E+01, 0.68338200E-01, 0.21677200E+01, 0.32493400E+01, -.37026000E+00, 0.20271300E+01, 0.23646100E+01, -.11057900E+00, -.91606700E+00, -.70708600E-02, 0.23523800E+01, -.20336400E+01, 0.27909600E+00, 0.27993500E+00, -.29711500E+00, -.17054200E+01, 0.22152000E+01, 0.27357600E+00, 0.54867400E+00, -.43574900E-01, 0.23572400E+00, 0.24692900E+02, -.16191900E+01, -.25709400E-02, -.86858600E+00, 0.30770300E+00, -.14352400E+00, 0.16493400E+00, 0.12837400E+01, -.15385500E+01, -.25637300E+01, -.19713700E+01, -.25163700E+00, -.88503600E-01, -.49297500E-01, 0.13079400E+01, -.34366900E+00, 0.16138200E+01, -.21621500E+00, -.73137900E+00, 0.66526800E+00, -.38727200E+00, 0.11414300E+01, 0.42534000E+00, 0.67238400E+01, -.76468200E-01, -.52563200E+00, 0.62335300E+00, 0.40279400E+00, -.19000100E+00, 0.90544400E+00, -.21093400E+00, 0.56395900E+00, -.88916500E-01, -.10565000E+01, 0.57239300E-01, 0.73478100E-01, -.27698000E+00, 0.51848000E+00, 0.46742400E-01, 0.51495200E+00, -.10058400E+01, -.60701800E+00, 0.86893600E+00, 0.90647600E-01, -.39486100E+00, 0.14555100E+01, 0.89616600E-01, -.19568200E-01, 0.17795100E+01, -.37410800E+00, -.14671600E+02, 0.14634500E+00, -.91755500E+00, -.23361800E+01, -.55100100E+00, 0.83497000E-03, -.47318600E+00, 0.10942600E+00, 0.10660000E+01, 0.25801800E+00, -.10216400E+00, 0.13583600E+01, -.97376800E+00, -.42307700E+00, 0.17504300E+00, 0.72720600E-01, -.12221900E+00, 0.47261900E+03, -.15239800E+02, -.21995200E+02, -.56956900E+02, 0.48615500E+01, 0.26607000E+02, -.20685800E+02, -.22226600E+02, -.54381800E+02, -.61875500E+02, 0.25762100E+02, 0.16528000E+03, 0.33244200E+02, -.14657900E+02, -.19621700E+02, 0.15231000E+02, -.26352000E+02, -.45522900E+00, -.70310200E+01, -.23183300E+02, -.23122600E+02, 0.12946600E+02, 0.36107000E+02, 0.10880300E+02, -.91861200E+02, -.25167800E+02, 0.17963300E+02, 0.45157700E+02, 0.18146300E+02, -.43110700E+02, 0.31447800E+02, -.22342100E+03, 0.10763600E+03, 0.57095600E+02, 0.10645700E+03, -.19779800E+02, -.48058000E+02, 0.70120800E+02, 0.23133300E+02, 0.52456300E+02, -.35074400E+02, 0.16344200E+03, -.16180100E+03, 0.88065600E+02, 0.16079700E+03, 0.80438900E+02, -.24357300E+03, -.14559400E+03, 0.10247900E+03, 0.48324900E+02, 0.50712000E+02, -.85888000E+02, 0.16160100E+03, 0.36316000E+03, -.18134400E+03, 0.62221900E+01, -.17292200E+03, -.77474900E+02, -.39806400E+02, -.39675800E+02, 0.58463000E+02, -.91980800E+02, -.38552600E+02, -.11049400E+03, -.18615600E+03, 0.92281900E+02, -.41502900E+02, 0.92236100E+02, -.18502800E+02, -.20407200E+02, 0.54509500E+02, -.33062300E+02, -.48658000E+02, 0.47262000E+02, 0.71632400E+02, -.70570800E+02, 0.35969900E+02, -.22733900E+02, 0.33596800E+02, 0.55227300E+02, 0.25266300E+02, -.11744700E+02, -.73786100E+02, -.31412000E+02, 0.25388400E+02, 0.75644400E+02, 0.18142400E+01, 0.10055200E+02, 0.16048800E+02, 0.17458900E+01, 0.24332200E+01, 0.28760800E+00, 0.33715400E+01, -.29558400E+01, -.27498700E+02, -.12617100E+02, 0.24193500E+01, 0.20343400E+01, 0.82877400E+01, -.17722000E+02, 0.31059600E+02, -.32718100E+01, -.68562500E+01, 0.30714100E+01, -.19339200E+02, 0.10411000E+02, -.11555500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.81159600E+00, 0.14899700E+01, 0.61709700E+01, 0.41572200E+01, 0.60009600E+01, -.29863300E+01, 0.55620000E+01, -.10123900E+01, -.88183700E+00, -.11679300E+01, -.22757100E+00, -.11679700E+00, -.29870900E+01, 0.87583300E-01, -.31566100E+00, 0.39764900E-02, -.16374200E+01, -.50977100E+00, 0.14044100E+01, -.71446900E+00, 0.14788400E-01, 0.80556600E-01, -.25020400E+01, -.31921200E+00, -.19729200E-01, -.34678600E-02, -.34843000E+00, 0.75507800E+00, -.16907300E+01, 0.14489600E+01, 0.46187100E+00, 0.18976100E+01, 0.26073800E+00, 0.24332400E+01, 0.81488900E-01, 0.33502300E+00, 0.18918300E+00, 0.12505800E+00, 0.41088200E+00, -.18651500E+01, 0.47104400E+00, 0.14946000E+01, -.39669200E+00, 0.52084500E+00, -.51370700E+01, 0.13762900E+01, 0.33902200E+01, -.36216000E+00, -.35721600E+01, 0.31808700E+00, 0.47100600E+00, 0.21897300E+00, -.11620000E+01, 0.22881300E+00, 0.29466900E+01, 0.11468200E+01, -.18519900E+01, 0.16108200E+01, 0.12096200E+00, 0.38831600E+00, 0.36890200E+00, -.10894400E+01, -.95621900E+00, -.15195700E+00, -.46694100E+00, 0.10697500E+00, -.56945000E+00, 0.13214400E+01, -.57870000E-01, 0.30467000E+00, -.25949800E-01, 0.53442800E+00, 0.27581600E+00, -.42033100E+00, 0.59725800E+00, 0.25710200E+01, -.17460500E+00, 0.53665700E+00, -.11951500E+00, -.28292600E-01, 0.40799600E+00, 0.69816400E+00, -.39422300E+00, 0.95522300E+00, 0.73377800E+00, -.11302200E+01, 0.72290200E+00, -.26756100E+00, -.28635800E+00, -.76574200E+00, -.13052400E+01, -.11547700E+00, -.22622400E+01, -.28933900E+00, -.40954400E+00, -.90730600E+00, 0.33570500E+00, 0.23228900E-01, -.82407100E+00, 0.92575800E+00, -.10168800E+01, 0.36924000E+00, 0.19481100E+00, -.10016600E-01, -.66785700E+00, -.82542300E-01, 0.40992500E+00, -.23048500E+00, -.42611900E+00, -.16907200E+00, -.15887500E+00, -.56367100E+00, 0.45807300E+00, -.16324300E-01, 0.38163600E-02, 0.15154100E+01, -.20333900E+00, -.75287800E+01, 0.11691500E+00, -.88034000E+00, -.14120000E+00, 0.30527200E+00, -.85370600E-01, -.28212600E+00, -.38005000E+00, 0.66034000E+00, 0.39892700E+01, 0.71952700E-02, -.24740400E+01, -.21924600E+01, 0.36138600E+00, -.21962400E+00, 0.26520400E-02, 0.14059300E-01, -.23802500E+00, 0.62960100E+02, 0.50614100E+01, -.87291300E+02, -.40094400E+02, -.67368100E+01, 0.58062800E+02, -.71302400E+02, -.31941100E+02, 0.17468900E+03, -.91547800E+02, -.20683100E+02, -.95342200E+02, -.52903400E+02, -.80412800E+02, 0.52348700E+01, 0.67993400E+02, -.86263900E+01, -.75210600E+02, -.41250100E+02, 0.65899400E+02, -.34871100E+02, -.43052200E+02, -.36835100E+02, 0.35622700E+02, -.37289400E+01, -.24753200E+02, 0.47851500E+02, 0.12903500E+02, 0.39578800E+01, -.65871300E+02, 0.71043600E+02, -.34030900E+02, 0.17771800E+02, -.33630300E+02, -.22399800E+02, 0.50066200E+02, -.76949200E+02, -.92497700E+02, -.39775400E+02, 0.54851000E+02, -.62151100E+02, 0.14498600E+03, -.67766100E+02, -.60653400E+02, -.70675500E+02, -.94318600E+02, 0.33471100E+02, -.32783400E+02, 0.18203300E+02, -.67689700E+02, 0.41748600E+02, -.24576800E+03, 0.23799200E+03, -.12024900E+03, -.51391200E+02, -.14178600E+03, -.85027400E+02, -.20942500E+02, -.20706000E+02, 0.64878000E+02, -.30433200E+02, -.23030700E+02, -.95205500E+02, 0.12051100E+02, -.83332200E+01, -.59431800E+02, -.91722400E+01, -.27829100E+02, -.14911200E+02, 0.80914700E+02, 0.11593600E+03, 0.76578800E+02, -.22721200E+02, -.10663300E+03, -.54977000E+02, 0.29396200E+02, 0.87223600E+01, 0.26288700E+02, 0.10741100E+02, 0.29849500E+02, 0.94102600E+01, -.13510300E+02, -.13809600E+02, 0.32045200E+02, 0.26274200E+02, 0.12873600E+01, -.65147900E+01, 0.33020700E+01, 0.18548700E+01, -.53804800E+00, 0.13711100E+02, -.95899800E+01, 0.10542800E+00, -.17610800E+02, 0.13355000E+02, 0.55777400E+01, 0.68066700E+01, 0.99982300E-01, 0.18369900E+00, 0.16730600E+02, -.73541700E+01, 0.11324400E+02, -.16057500E+02, -.81916900E+01, -.22897200E+01, -.33778900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11838400E+00, 0.61356100E+00, -.29569700E+00, 0.25850200E+00, 0.68532900E+00, 0.57778200E+00, -.65951400E+00, 0.18125400E+00, -.14622300E+01, -.13383000E+01, 0.31148800E+00, 0.90747300E-01, -.90813400E+00, -.49289900E+00, -.33668600E+00, -.43218600E+00, 0.41056800E+00, 0.34284300E+00, -.10751700E+00, -.90600900E+00, -.59343000E-01, -.15278600E+00, 0.65229100E+00, 0.58169200E-01, 0.31779000E+00, 0.20472200E-02, 0.22107700E+00, 0.98399000E-01, -.21293500E+00, -.21623800E-01, -.32970600E+00, 0.10503900E+00, -.14732400E+00, 0.73469200E+00, -.39816800E+00, -.43286700E-01, 0.18637100E-01, -.36468500E-01, -.11031600E+00, 0.10868200E+00, -.19957100E+00, -.58327400E+00, 0.16673500E+00, -.26167400E-01, -.11839700E+01, -.32014200E-01, 0.47428600E+00, 0.19367000E-01, 0.59293600E+00, 0.70842100E+00, -.16445900E+00, 0.21388300E+00, 0.55967200E+00, 0.24602200E-01, 0.22181800E+00, -.58961300E-01, -.68355000E-01, -.24915000E+00, 0.49098000E-01, -.48959500E-01, -.52776100E-01, -.45420500E-01, -.26072500E+00, -.24812100E-02, 0.13756100E+00, 0.91771100E-01, -.13496900E+00, 0.45072900E+01, -.79144900E-01, -.14266800E-01, -.10598400E+00, 0.34909700E-01, 0.10891300E+00, 0.32020000E-01, 0.31732200E+00, 0.82227800E+00, -.28619500E-01, -.45938600E+00, -.63209000E-01, -.76110600E-01, -.21072400E-02, 0.15721700E-01, 0.19851600E+00, -.29999800E-01, 0.50888600E+00, -.17762400E+00, 0.10195200E+00, 0.34135400E-01, -.23806200E+00, 0.57037300E+00, 0.14077400E+01, 0.16432100E-01, 0.17372600E+00, -.21360800E+00, -.24184100E+00, -.24286300E+00, 0.41033900E+00, -.21788100E+00, 0.20673200E+00, -.86790200E-02, 0.12599800E-01, -.67300600E-01, 0.66941400E-02, -.16229300E+00, -.33579600E+00, 0.49531400E-01, 0.72191900E-01, -.50346200E+00, -.19916700E+00, 0.17101800E+00, 0.13555800E+00, -.23120100E+00, 0.16718300E+00, 0.99581900E-02, 0.89130500E-01, -.70774800E-01, -.73310200E-01, -.16853100E+00, -.10374500E-01, -.64856300E-01, -.75683300E+00, -.13951800E+00, 0.30733900E-01, -.11350700E+00, -.13760400E-01, -.13553200E+00, 0.44093300E+00, -.23894100E-01, -.34279400E+00, 0.14905400E+01, 0.18317500E+00, 0.36349400E-01, -.53037200E-01, 0.59895000E-01, 0.24518400E-01, -.51151100E-02, -.21336600E+02, 0.64064000E+01, 0.23201700E+02, 0.29242600E+02, -.15091900E+02, -.29966300E+01, -.11812000E+02, 0.32445500E+02, -.19011700E+02, 0.64263300E+01, -.15860200E+02, -.41307100E+01, -.14526600E+01, -.24184800E+02, -.29204400E+02, -.23686800E+02, -.13188800E+01, -.12587000E+02, 0.57612200E+02, -.27760900E+02, -.51798200E+02, -.29813500E+02, -.60041600E+02, -.12814500E+01, -.49077200E+01, -.11610900E+01, -.20640900E+02, -.78264400E+01, -.20958200E+02, -.15304200E+02, 0.57469400E+01, -.11407000E+02, 0.65716900E+01, -.16968900E+02, -.39086700E+02, 0.41298700E+02, 0.65365000E+02, 0.20007500E+02, -.38914400E+02, -.11684400E+02, 0.52357500E+02, -.24793800E+02, -.31427600E+02, -.26060600E+02, -.11178500E+02, 0.44699300E+02, -.28352900E+02, 0.45678100E+01, -.27085000E+02, 0.41792300E+02, -.38319400E+02, -.94200600E+01, 0.63377900E+01, 0.36505400E+02, 0.47012900E+01, 0.27547600E+02, 0.26406400E+01, -.10668600E+02, -.28966100E+02, -.15240900E+02, 0.66097700E+01, -.12957900E+02, -.95463300E+02, 0.48134800E+02, 0.37606100E+02, 0.47620500E+02, -.82125000E+01, 0.56225200E+02, -.50133700E+02, -.86276400E+02, -.26726000E+02, 0.40976700E+02, 0.36479500E+02, 0.16237600E+02, -.88933800E+01, 0.22816400E+02, -.84760400E+01, 0.44922500E+01, -.10013300E+02, -.13636300E+02, -.16577400E+02, 0.34353800E+01, -.14480900E+02, -.14732700E+02, 0.47604600E+00, 0.63664800E+01, -.35058600E+01, 0.20342300E-01, 0.14376300E+01, -.47941800E+01, 0.41202600E+00, -.98608000E+00, 0.70197700E+01, -.93300200E+01, -.27194200E+00, -.26286300E+01, 0.15081200E+00, -.23177200E+01, -.26256500E+00, 0.17316200E+01, -.83717600E+01, -.33601000E+01, 0.26437600E+01, 0.69492500E+01, -.53412400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.41837300E+00, -.42569000E-01, 0.88438600E+01, 0.32694600E-01, -.74971000E+00, -.19339400E+01, 0.40778200E+01, -.44493200E+00, 0.22392800E+01, 0.17081200E+01, -.10890600E+00, -.10873700E+01, 0.40463100E+01, 0.22035900E+01, -.35783500E+00, 0.24256500E+01, -.67638200E+00, -.45507200E+00, 0.98980700E-01, 0.57609900E+00, 0.15034000E+00, 0.38316400E+00, 0.40768900E+00, -.10290700E-01, 0.26290300E+00, 0.16186000E-02, -.28141700E-01, 0.11494400E+01, -.74849400E-01, 0.22505200E+00, 0.16708000E-02, 0.14312800E+00, -.19834600E-01, 0.18374200E+00, 0.87582500E+00, 0.77232300E-01, -.10988500E+00, 0.56109300E-01, 0.91708100E-01, 0.24608600E+00, -.38751500E+00, -.28185300E-01, -.77158200E-01, -.52043000E-01, 0.13260200E+01, -.32859000E+00, -.23735900E-02, 0.23376000E-01, -.15873300E+00, 0.43810500E+00, 0.20998800E+00, 0.35356700E+00, 0.76638300E+00, -.66913400E+00, 0.10833500E+01, -.63618700E+00, 0.10330900E+01, -.33292400E+01, 0.19091500E+00, 0.17158100E+00, -.74784400E+00, -.30394300E+00, 0.12513600E+01, 0.35947500E+00, 0.10726300E+01, -.53674100E+00, 0.35224700E+00, 0.18987600E+02, -.84366000E-01, -.45031800E-01, 0.21617400E+00, 0.90892400E+00, 0.50352500E+00, 0.34693200E+00, -.10621100E+01, -.13196700E+01, -.31135100E+00, 0.24493400E+01, 0.21819400E+00, 0.44403900E+00, -.37749800E-01, 0.50873500E+00, -.21568100E+00, -.79534800E+00, -.21503300E+00, -.51729300E+00, -.60121200E-02, 0.11430600E+00, 0.93138700E+00, 0.53793800E+00, 0.11160800E+01, 0.65588100E-01, 0.61212900E+00, 0.95714700E-01, 0.53253000E+00, 0.26358600E+00, -.39782900E+00, 0.34348800E+00, 0.15188500E+00, 0.14507500E-01, -.54122900E+00, -.29056400E+00, 0.63086800E-02, 0.37314800E-01, -.24198700E+00, -.32117300E+00, -.29197100E+00, 0.45110000E+00, 0.74231400E+00, -.13075700E+00, -.48203800E+00, -.15688700E+01, 0.10735700E+01, 0.46502800E-01, -.36519400E+00, 0.15860600E+01, -.31772100E+00, 0.11480000E+02, -.27638100E+00, 0.47817600E+00, 0.87951900E+00, -.10131600E+00, -.55631600E+00, -.61711900E+00, 0.50292700E-01, -.68778200E+00, 0.12088600E+02, -.49869700E+00, -.46837000E+01, 0.13593600E+02, 0.42996400E+00, -.89562900E+00, 0.81485200E+00, 0.16266900E+00, 0.22355700E+00, -.85150300E-01, -.15215100E+01, 0.24156500E+03, -.42981400E+02, -.71215000E+02, -.20061000E+03, 0.15404800E+03, -.29160400E+02, -.21829300E+02, 0.13569700E+02, 0.59494400E+02, 0.13529600E+02, 0.52084100E+02, 0.10999600E+03, -.42058400E+02, -.13764000E+03, -.10410400E+03, 0.96546100E+02, -.25693400E+02, 0.23855200E+02, -.92866100E+01, -.52019200E+02, -.18654300E+02, -.20164200E+03, 0.48781900E+02, -.19967400E+02, -.39697800E+02, -.47543900E+02, 0.30781500E+02, -.15367600E+02, 0.49175000E+03, -.24636800E+03, -.12391700E+03, -.25425100E+03, -.14637200E+01, -.20145800E+03, 0.79452600E+02, 0.38801100E+03, -.39443600E+02, -.24661800E+03, -.28661700E+03, 0.44252500E+03, -.23123300E+03, -.45467600E+03, -.22208000E+03, -.10319800E+01, 0.30912200E+03, -.27279000E+03, -.15902600E+03, -.17987900E+03, 0.23466500E+03, 0.35718900E+02, -.39380000E+03, 0.20057500E+03, 0.22121900E+03, 0.19718200E+03, 0.18117600E+03, 0.16137100E+02, 0.53139900E+02, -.10217000E+03, 0.78954800E+02, 0.26325700E+02, 0.82710800E+02, 0.81334000E+02, -.39224300E+02, 0.24932100E+02, -.42265100E+02, -.57550400E+02, 0.42919700E+03, -.44399600E+03, -.31702200E+03, -.31749300E+03, 0.29058300E+03, 0.22546700E+02, 0.17779200E+03, -.91352700E+02, 0.50059100E+02, -.91964800E+02, -.40866400E+02, -.78765900E+02, -.57277000E+01, 0.60807800E+02, 0.21127200E+02, -.11237700E+03, 0.13819600E+02, 0.28198300E+01, 0.32757300E+02, -.17107900E+02, 0.12173900E+01, -.19165100E+01, -.10094400E+02, -.62825000E+01, 0.28559400E+01, 0.46467200E+02, -.79966700E+01, -.51606100E+01, 0.51848100E+01, -.22804100E+02, 0.17407100E+02, -.20034800E+02, -.16982900E+02, -.31811700E+02, -.44401500E+01, 0.28668100E+02, 0.25552300E+02, -.34960400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10236900E+00, 0.42777500E-01, -.14028300E+01, -.11160200E+00, 0.96835200E+00, 0.18097600E+00, 0.48658200E+00, 0.26193600E+00, -.25976200E+01, -.11091300E+01, 0.59480600E+00, 0.46250500E-01, -.73762600E+00, 0.14171800E+00, -.71785400E+00, -.10258100E+01, 0.12614000E+00, 0.67909900E+00, -.90412900E-01, 0.15972200E+00, 0.49960200E-02, -.15142200E+00, -.14584700E+01, -.13355200E+00, -.18806000E+00, -.93456400E-03, -.18284100E+00, 0.16372900E+00, -.15338400E+01, 0.34576800E+00, 0.50471400E+00, 0.57834900E-01, 0.37341000E+00, 0.31914600E+00, 0.53250200E+00, 0.18155800E+00, -.94212000E-01, 0.17875900E+00, 0.43631900E+00, 0.92939900E+00, -.10951400E-02, 0.64247300E+00, -.45641400E-01, 0.47050100E-01, -.14465400E+01, 0.24737700E+00, 0.95984100E+00, 0.45492500E-01, -.62236200E+00, 0.53855300E+00, -.17632700E+00, 0.34895400E+00, 0.36950500E+00, 0.48326500E+00, -.18516700E+00, 0.17233200E+00, -.14901700E-01, 0.82531700E+00, -.35258000E-01, -.38980100E-01, 0.16720700E+00, 0.51559700E-01, -.20839700E+00, -.16591800E+00, -.76462500E+00, 0.15596400E+00, -.22135800E+00, -.27583900E+01, 0.92772700E-01, 0.20431700E-02, -.91964300E-01, -.12027400E-02, -.46327400E-01, -.14424300E+00, 0.33213700E+00, -.13019000E-01, 0.45204800E+00, -.14125800E+01, -.63663300E-01, -.23428400E+00, -.85558700E-03, -.12313100E+00, -.11036200E+00, 0.40675500E+00, -.11509300E-01, 0.57844500E+00, -.18120200E+00, -.55576800E-01, -.27224000E+00, -.52473000E+00, 0.30147300E+00, -.27488500E-01, -.45141700E+00, 0.30368200E+00, 0.41900900E-01, -.16223700E+00, 0.85349900E-01, -.37376800E-01, 0.23832000E+00, 0.33773500E+00, -.27971800E+00, 0.13023600E+00, -.14687500E-01, -.13181700E+00, 0.17910800E+00, 0.75642300E-01, 0.89849100E-01, 0.16202600E+00, -.35157700E+00, -.12749500E+00, 0.61046200E+00, -.12369300E+00, 0.33109100E+00, 0.39694200E-01, -.16999700E+00, 0.73994000E+00, 0.10548100E-01, -.43147300E+01, 0.14067100E+00, -.32527700E+00, -.46259800E+00, 0.22411900E+00, 0.59123500E-03, -.51014100E+00, 0.21916700E-01, -.40071100E-01, -.38823500E+01, -.41683800E+00, 0.10939800E+01, -.85080400E+00, 0.25579700E+00, 0.23442700E+00, 0.13914000E-01, -.12611100E+00, -.12132200E+00, 0.37749700E-01, -.79907600E+00, -.20396200E+00, -.42669700E+02, -.24121900E+02, -.10733200E+02, 0.58320600E+01, 0.97618100E+01, 0.13414400E+02, -.14220200E+02, 0.73878100E+01, -.74471000E+01, -.30405800E+02, -.54760300E+02, 0.48295000E+02, 0.10337800E+02, 0.21566400E+02, -.49363300E+02, 0.27863900E+01, -.20442800E+03, 0.10310700E+03, 0.98498500E+02, 0.10469000E+03, 0.49864600E+02, 0.24730400E+02, 0.34345000E+02, -.10319900E+02, 0.39618600E+02, 0.25848600E+02, 0.17082600E+02, 0.73412200E+02, -.40904700E+02, -.34023500E+01, -.33580900E+02, -.27971400E+01, 0.84512500E+01, -.58716300E+02, -.42199400E+02, -.25088900E+02, 0.11204800E+02, -.15210300E+02, -.96437900E+02, 0.56522100E+02, 0.10559900E+03, 0.47858900E+02, 0.41775900E+02, -.36895600E+02, 0.30048600E+02, 0.29948600E+02, 0.49701800E+02, -.44535200E+02, 0.46456700E+02, -.15421700E+03, 0.80421600E+02, 0.44379500E+02, 0.77394400E+02, 0.24417600E+02, 0.12476700E+02, 0.37835900E+02, 0.22667100E+02, 0.55415600E+02, 0.80391600E+01, 0.11167300E+02, 0.14270000E+03, -.71499300E+02, -.27463600E+02, -.70616700E+02, -.27383500E+02, -.60878900E+02, -.24537700E+02, -.14299800E+02, -.12089200E+02, -.53367400E+02, 0.73695700E+02, -.19854200E+02, 0.10503900E+02, 0.94093200E+01, 0.11132100E+02, -.83731500E+01, 0.40908800E+00, 0.10866100E+02, 0.12688700E+02, 0.95021800E+01, -.45309000E+01, 0.10836300E+02, -.93688600E+00, 0.52498200E+01, -.32948400E+02, -.49641900E+00, -.11037900E+02, -.15447200E+01, 0.70231200E+01, 0.10761500E+02, -.30788400E+01, 0.19537000E+02, -.15707400E+01, -.10650300E+01, -.70148400E+00, 0.21683600E+02, -.20577600E+02, -.58338200E+01, -.38824000E+01, 0.91374300E+01, -.28888100E+01, -.10213500E+02, -.39563700E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.41907100E+00, 0.61135800E+00, 0.19665700E+01, 0.33329200E+00, 0.81815900E+00, 0.46981500E+00, 0.40434300E+00, -.16961700E+00, -.60867300E+00, -.12635600E+01, -.16227700E+00, 0.17939000E+00, -.10223900E+01, -.85410300E+00, -.46813400E+00, 0.24547300E+00, -.60849400E+00, -.81129200E+00, 0.94790200E+00, -.82138000E+00, 0.12507200E-01, 0.27338900E-01, 0.20094900E+01, 0.13822400E+00, 0.59277100E+00, 0.16774800E-02, 0.34558300E+00, 0.14106700E+00, 0.22281300E-01, -.15302200E+00, 0.11848300E-01, -.34056100E+00, 0.21516700E+00, 0.90071400E-01, -.32991400E+00, -.15654500E-01, -.17843600E-01, 0.64623100E-01, 0.33415700E-01, 0.37674300E+00, -.30815000E+00, 0.58701800E+00, -.91844400E-01, -.95775000E-01, -.87642500E+00, 0.15824800E+00, 0.42814200E+00, -.76033500E-02, -.20771400E+00, 0.15628700E+00, 0.32249500E+00, 0.16092300E+00, -.75590200E+00, -.15315600E+00, -.12858000E+00, -.38542500E-01, 0.60433000E+00, 0.28325400E+00, -.34508800E-02, 0.11482900E+00, 0.83012600E-01, 0.29848900E+00, 0.33110500E+01, 0.25020600E+00, -.89595200E+00, -.23193000E+00, -.51950000E+00, 0.68807300E+01, 0.81960600E-01, 0.40565300E-01, -.13199400E+00, 0.25901200E+00, 0.14550400E+00, -.21256400E-01, -.66143700E+00, 0.58650100E+00, 0.30564400E+00, 0.11033200E+01, 0.23777700E+00, -.12016300E+00, 0.45013300E-01, 0.30266300E+00, 0.82090700E-01, 0.48336600E+00, 0.81911400E+00, -.92256200E+00, -.52871500E-01, 0.18359200E-01, 0.21686700E-01, -.22887300E+00, -.62424100E+01, -.46120400E-01, -.13895700E+01, -.57547800E-01, 0.18627500E+00, -.16679100E-01, -.10900900E+01, 0.59931000E+00, -.11493200E+01, 0.14205000E+00, 0.14674100E-01, -.66319500E-01, -.54498000E-01, -.27261800E-01, 0.28376100E+00, -.17203600E+00, -.20069700E+00, 0.57726800E+00, 0.87099400E+00, 0.13608500E+01, -.95613700E-02, -.84654600E-01, -.74422400E+00, 0.10127100E+00, 0.10124100E+00, 0.12877500E+01, 0.53169500E-01, -.11203700E+02, 0.12873000E+00, -.88703000E+00, 0.68029200E+00, 0.40740300E+00, -.11226300E+00, -.84253800E+00, 0.54269300E-02, -.18902500E+00, 0.12167800E+01, 0.69091400E-01, 0.15757200E+01, 0.30773200E+01, -.14463100E+01, -.36947900E+00, -.20639300E+00, 0.28720700E+00, -.17133800E+00, -.20307900E+00, -.19155300E+01, 0.41209400E+00, 0.55281300E+00, 0.60311100E+02, -.10145100E+02, -.24237600E+02, -.52772200E+02, 0.21269100E+03, -.10742600E+03, 0.16637100E+02, -.10359000E+03, 0.37740400E+01, -.14908700E+02, -.90210000E+02, -.32678900E+02, -.87752800E+02, -.40363200E+01, -.13628400E+03, 0.52763600E+03, -.26185500E+03, -.37006500E+03, -.26990900E+03, -.27738800E+03, -.80564300E+02, -.16776900E+02, 0.17436500E+03, -.54805500E+02, -.92809700E+02, -.14054000E+03, 0.17602600E+03, -.94980800E+02, -.24097300E+02, -.96978700E+02, -.61758000E+02, -.86210300E+02, 0.78141800E+02, 0.15930200E+03, 0.28337400E+02, -.12118800E+03, -.15464600E+03, 0.39875000E+03, -.19675700E+03, -.48268100E+03, -.19897400E+03, -.29127200E+02, 0.20593100E+03, -.20885400E+03, -.23300900E+03, -.23205100E+03, 0.21639000E+03, -.31819100E+03, 0.22764200E+03, -.11567900E+03, 0.74030200E+02, -.11192200E+03, -.27677700E+02, -.47401500E+02, -.65389200E+02, -.10536000E+03, -.86745300E+02, -.29152600E+02, -.90466700E+02, -.59860500E+03, 0.30162100E+03, 0.66884100E+02, 0.29736300E+03, 0.14927700E+01, 0.19529400E+03, 0.12341900E+03, -.48209600E+02, 0.90765700E+02, 0.13233300E+03, 0.17337300E+02, 0.26886600E+02, -.16691500E+02, 0.76030000E+02, -.16775900E+02, 0.15322800E+02, 0.39870600E+02, -.65174000E+02, -.10647100E+03, -.16800700E+02, 0.53277500E+01, 0.65081700E+01, 0.49077700E+01, 0.11705300E+02, 0.98129500E+02, 0.25450200E+01, 0.45003600E+02, -.69455700E+01, -.11512000E+02, -.44997400E+02, 0.15754200E+02, -.56441700E+02, 0.81142400E+01, 0.58389900E+01, 0.68440700E+01, -.57221600E+02, 0.10504200E+03, -.40061500E+01, -.56632600E+01, -.36593800E+02, 0.78211800E+01, 0.20397500E+02, -.34021800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18595400E+00, 0.51935100E+00, 0.33274300E+01, 0.13284700E+01, -.26035400E+00, -.16514900E+00, 0.84358700E+00, -.60867800E-02, 0.38205000E+01, 0.97386400E+00, -.38948000E+00, -.38751600E+00, 0.12665100E+01, 0.20887200E+00, 0.13917700E+00, 0.14701100E+01, -.10172100E+01, -.87978800E+00, 0.15637400E+00, -.66433300E+00, 0.27643700E-01, 0.11747700E+00, -.13946400E+01, -.27456000E-01, 0.18704500E-01, -.91869600E-04, -.19594800E+00, -.16153300E+00, 0.48951300E+00, 0.18654300E+00, 0.17398100E+00, -.20647600E-01, 0.35033400E+00, 0.18311000E+01, 0.75115600E+00, 0.41733900E+00, 0.73683100E-03, 0.10453800E-02, 0.47778100E+00, -.14302700E+01, 0.85490100E+00, 0.13311700E+01, -.24426000E+00, 0.29511000E+00, -.15030100E+01, 0.54027300E+00, 0.15185400E+00, 0.97556500E-02, -.74544500E+00, -.35597200E+00, 0.88177000E-01, -.27025100E+00, -.65916100E+00, 0.17871400E+00, 0.65112400E+00, 0.17939800E+00, -.64854600E+00, 0.99979100E+00, -.74846500E-01, 0.32171800E+00, 0.73005900E+00, 0.65140400E+00, -.48537800E+00, -.14088800E+00, -.11212800E+01, -.12128100E+00, -.26310400E+00, -.60177200E+01, 0.96915800E-01, 0.90272200E-02, -.15011600E+00, -.16650400E+00, -.99425500E-01, -.26849300E+00, 0.40555300E+00, -.27509600E+00, 0.15599700E+01, -.20425500E+01, 0.18499300E+00, -.42848300E+00, 0.54854800E-01, -.44851400E+00, 0.59988500E-01, 0.35799500E+00, 0.14366500E+00, 0.18756900E+01, -.14707900E+01, 0.12053400E+00, 0.15947700E+00, -.18311400E+01, -.31668000E+01, -.10885800E-02, -.16413100E+01, -.60347500E-01, -.29402700E+00, -.28949500E+00, 0.13729300E+01, 0.55365900E+00, -.18387300E+00, 0.12202800E+01, -.12877900E+00, -.55426000E+00, 0.26250400E-01, 0.18311100E+00, -.20923000E-01, -.90979800E-01, 0.16442300E+00, 0.88975200E+00, -.27171500E+00, -.10558400E+01, 0.18948400E+00, -.50988700E-01, -.20993400E+00, -.30077400E-01, -.16465400E+00, 0.33922100E+00, 0.31599700E+00, -.72246900E+01, 0.16259200E+00, 0.22002200E+00, -.10116100E+00, 0.29694600E+00, 0.11964200E+00, 0.63862700E+00, 0.13814800E-01, -.78193100E-01, -.64716300E+01, 0.24939900E+00, 0.52164100E+01, -.25246000E+01, -.69061400E+00, 0.17577700E-01, -.84254400E-01, -.71732400E-01, -.30507200E+00, 0.96369500E-01, 0.87225000E+00, -.48332600E+00, 0.16115500E+01, 0.99058800E-01, 0.10824000E+03, -.12174300E+01, -.14009400E+01, -.90044200E+02, 0.59325600E+02, 0.10381200E+02, 0.44539200E+02, 0.38819700E+02, 0.67715300E+02, -.13583700E+02, -.18481800E+01, 0.19452100E+02, 0.59988100E+02, 0.60235300E+01, 0.15278200E+03, -.78746100E+02, -.65526900E+02, -.76855500E+02, 0.10138500E+02, -.12841400E+02, -.39444100E+02, 0.13132700E+02, -.14558500E+02, -.10969600E+02, -.13588800E+02, -.30480600E+02, 0.25478200E+02, 0.16835900E+02, 0.14729800E+02, 0.27292800E+02, 0.41677300E+02, 0.17607700E+02, 0.19991000E+01, -.42488500E+02, 0.34714700E+02, 0.57657100E+02, -.40289000E+02, 0.74956800E+00, -.83443000E+02, 0.20078800E+02, -.91129000E+02, -.48025700E+02, 0.20914900E+02, -.60639800E+02, 0.19865400E+02, -.33991200E+02, 0.95469700E+02, 0.13024300E+03, -.71737400E+02, -.27284700E+02, -.66404200E+02, -.44952100E+02, -.11364900E+02, -.10530900E+02, 0.43457800E+02, -.47265700E+01, -.14720200E+02, 0.63749300E+01, -.41087800E+01, 0.78046600E+00, -.67676200E+02, 0.15539500E+01, 0.20293000E+02, 0.66245700E+01, 0.39475100E+02, 0.66278200E+02, 0.29119800E+02, 0.23278800E+02, -.13704700E+03, 0.74705600E+02, -.36326900E+02, -.56139900E+02, -.37732000E+02, 0.13009700E+02, 0.17680600E+01, 0.79595000E+01, 0.38398800E+02, -.42800900E+02, 0.12459300E+02, -.91577500E+00, 0.12013400E+01, -.86301400E+01, 0.16804300E+02, 0.99832000E+00, -.47153200E+01, 0.33592300E+01, -.65490500E+01, 0.40776700E+01, -.69462500E+01, -.16361600E+01, 0.21693400E+01, 0.81968700E+01, 0.25044500E+00, 0.30822900E+00, 0.24415100E+01, 0.12542500E+01, 0.13636100E+02, 0.24807700E+01, -.65978000E+00, 0.13574000E+01, 0.13975000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16121100E+00, 0.14187900E+00, -.35909700E+01, -.28098000E+00, -.88642300E-01, 0.14190000E+01, -.21121800E+01, 0.19616000E+00, -.15322000E+01, -.72337100E+00, 0.30657000E+00, 0.30160600E+00, -.10422100E+01, -.16442900E+00, 0.32462100E+00, -.13354300E+01, 0.88911800E+00, 0.24674700E+00, -.74201800E+00, 0.28706200E+00, 0.67916100E-01, -.27325100E-01, 0.14290900E+01, -.12362900E+00, 0.81484300E-01, -.13029800E-02, 0.23171800E+00, -.65263400E+00, -.29848000E+00, 0.11825300E-01, -.18659500E+00, -.41066100E+00, -.40308200E+00, -.17860800E+00, 0.12728300E+01, 0.95946700E-01, 0.76788000E-01, -.15751800E+00, -.43906700E-01, 0.55968700E+00, -.13091700E+01, 0.10215300E+01, -.10797500E+00, 0.18122000E+00, 0.12521400E+01, -.99192200E-01, 0.83346600E+00, -.24283400E-01, -.19045900E+01, 0.18467100E-01, 0.15640000E+00, 0.10549100E+00, 0.42191100E+00, 0.41599100E+00, 0.42507200E+00, 0.26431800E+00, -.58038300E+00, 0.74883700E+00, -.73243100E-01, 0.13033600E+00, 0.16302700E+00, -.52917400E+00, -.68570000E+00, -.24411100E+00, 0.32214400E+00, -.70734800E-01, 0.23028800E+00, -.39320100E+01, -.99489300E-01, 0.12699300E-01, -.10045600E+00, -.16172700E+00, -.24623300E+00, 0.23525500E-01, 0.37442500E+00, 0.16358300E+00, -.24148100E+00, -.29314100E+00, 0.18965600E-01, 0.54096900E-01, 0.10675900E-01, 0.75567500E-01, 0.24165900E+00, 0.29853600E+00, 0.28441900E+00, -.48856800E+00, 0.24335000E-01, 0.12283200E-01, 0.11196700E+00, 0.23952400E+00, 0.88973700E+00, 0.17809800E-01, -.13511800E+00, 0.35613100E-01, 0.13048800E+00, -.35921000E+00, -.37590000E+00, 0.14770700E+00, 0.52518800E+00, -.29982100E+00, -.19272100E+00, -.15477000E+00, -.30747800E-01, 0.22233600E+00, 0.11594100E+00, 0.47640300E-01, -.19989500E+00, 0.46887000E+00, 0.19096300E+00, 0.38396600E-02, 0.68693200E+00, -.49229200E+00, 0.48482600E+00, -.13333600E-01, -.33627500E+00, 0.60561800E+00, 0.45784800E-01, 0.32418600E+01, -.47184200E-01, -.17248100E+00, -.30674700E+00, -.20862200E+00, -.31105700E+00, 0.21217300E+00, 0.78505400E-01, -.35902700E+00, 0.15763100E+01, -.41409200E+00, 0.83310300E+00, 0.12077400E-01, -.27398200E+00, -.16903700E-01, 0.24981000E+00, 0.67966800E-01, 0.84738100E-02, -.94032500E-01, 0.10121300E+01, -.10080200E+00, 0.38462300E+00, -.30531800E+00, 0.20754100E+00, -.17888500E+02, -.88412300E+01, 0.43522600E+02, -.13496500E+02, 0.53437400E+01, -.20047800E+02, 0.32728800E+02, 0.50259400E+02, -.71301400E+02, -.24648400E+02, -.54099800E+02, 0.47819300E+02, -.23350900E+02, 0.13021200E+03, -.65650600E+02, -.75800800E+02, -.69011500E+02, -.10546000E+03, -.33362200E+02, 0.11712600E+01, 0.48564800E+02, -.11189800E+02, -.32837800E+02, 0.63464100E+01, 0.79393900E+02, -.37435300E+02, 0.84866700E+01, -.46171400E+02, -.40156600E+02, -.38121900E+02, 0.33256400E+02, 0.57922600E+02, 0.95749000E+01, -.60319300E+02, -.49608800E+02, 0.55819700E+02, -.33286600E+02, -.20325500E+03, -.27771300E+02, -.11568300E+03, 0.35399000E+02, -.16718500E+02, -.69088300E+02, 0.62366200E+01, 0.32216100E+02, 0.20227200E+02, 0.95514200E+02, -.52413400E+02, 0.15315300E+02, -.45992000E+02, -.16087900E+02, -.24759300E+02, -.16452500E+02, -.15541300E+02, -.11296100E+02, -.15469400E+02, -.47384000E+01, -.75140500E+02, 0.37618800E+02, -.38772100E+02, 0.35903900E+02, -.24571800E+01, 0.11295200E+03, 0.85486200E+01, 0.17571300E+02, 0.25560000E+01, 0.84650600E+02, -.12624500E+03, 0.71010400E+02, -.36371300E+02, -.61888000E+01, -.38016600E+02, 0.13173500E+02, 0.28592500E+02, -.41411400E+02, -.43421100E+02, -.42668100E+02, 0.19215200E+02, 0.13896200E+02, 0.28484100E+01, 0.54504700E+01, 0.66796900E+02, 0.16551600E+01, 0.27603200E+02, 0.43674100E+01, -.12734900E+02, -.27606100E+02, 0.92356700E+01, -.24870900E+02, 0.18019900E+01, 0.43614900E+01, 0.18359700E+01, -.28307800E+02, 0.55282500E+02, -.17375400E+01, -.21311000E+00, -.59653900E+01, 0.83089000E+01, 0.10419700E+02, -.12124800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36642100E+00, 0.74523400E+00, 0.36867600E+01, -.34771600E+00, -.20090600E+01, 0.19714800E+01, -.35768400E+01, 0.49449400E+00, -.66175700E+00, -.20294800E+01, -.19120000E+01, 0.23903300E+00, -.30430700E+01, -.35063300E+00, 0.13749800E+01, -.21749700E+01, 0.16167200E-02, 0.62737100E+00, 0.20031300E+01, -.20797700E+01, -.33807600E+00, 0.74427500E-01, -.17818500E+00, 0.72603200E-02, 0.27770100E+00, 0.50044400E-02, 0.11567100E+00, 0.78733100E+00, -.12678800E+01, -.26428800E+00, -.37624800E+00, 0.10307000E+01, -.95242700E+00, 0.21189700E+01, 0.19828100E+01, 0.70189600E-01, 0.25707900E+00, -.10029600E+00, -.22591300E+00, 0.12569900E+01, 0.13869400E+01, -.16093200E+01, 0.95953000E+00, 0.11217700E+01, 0.35242200E+00, -.57678900E-01, -.18312700E+01, 0.35234200E-01, 0.97166300E+00, -.81341900E+00, -.16062500E+00, -.34913400E+00, 0.43161500E+00, -.40581800E+00, -.75739400E+00, -.41246700E+00, 0.74920900E+00, -.63320400E+00, 0.16383400E-02, -.30897400E+00, 0.21448500E+00, 0.90096500E+00, 0.74028200E+00, -.11492700E-01, 0.19069200E+00, -.46542600E-01, 0.23302000E+00, -.57073600E+01, 0.31482900E+00, 0.39885500E-01, 0.66616200E+00, 0.51006000E+00, 0.34666400E+00, 0.12003400E+00, -.72569700E-03, 0.14259100E+01, 0.19383800E+01, -.20692000E+01, 0.14423200E+00, -.56572300E-01, 0.50239100E-01, -.20978300E+00, -.22451900E+00, 0.24508700E+00, -.56092100E+00, 0.26633100E+01, -.85500800E+00, -.38903000E-01, -.63751900E+00, 0.85977500E+00, -.89262600E-02, 0.22255100E-01, -.52494400E+00, 0.81616300E+00, 0.11739500E+00, -.12594800E-01, 0.47064200E+00, -.65302000E-02, 0.23762500E+01, 0.16577300E+00, -.33866800E+00, -.84194700E+00, 0.22783900E-01, 0.11248900E+00, -.11162400E+01, 0.18272900E+00, 0.15621600E+00, -.12846800E+00, -.52591800E+00, 0.22424900E+01, 0.26706500E+01, -.48984300E+00, 0.14992900E+01, 0.53742200E-01, -.42795300E+00, 0.25527400E+01, -.16623900E+00, 0.13942300E+02, -.10755200E+00, 0.12636900E+01, -.12892300E+01, -.54371100E+00, -.20972100E+00, 0.58721800E+00, 0.12043100E+00, -.86369500E+00, 0.78056800E+01, -.11925000E+01, 0.17621600E+01, -.25933900E+00, -.19728800E+01, -.46185700E+00, 0.62820700E+00, 0.49234700E-01, 0.66545600E-01, -.30726300E+00, 0.28290100E+01, -.30399100E-01, 0.26767500E+01, -.38979400E+00, 0.96005700E+00, 0.59605800E+00, 0.11061300E+03, -.18672500E+03, 0.98610100E+02, 0.98934900E+01, 0.96617000E+02, 0.13490800E+03, 0.20680200E+03, -.19449900E+03, -.38449900E+02, -.82865700E+02, 0.19868800E+03, 0.16593900E+03, 0.19630000E+03, -.96683400E+02, 0.13036600E+02, -.11083500E+03, -.20239000E+03, -.11383900E+03, -.15763900E+02, 0.66793200E+02, -.29122500E+02, -.11024700E+03, 0.17084000E+03, -.90666900E+03, 0.45186700E+03, 0.26093600E+03, 0.43437500E+03, -.39569300E+02, 0.30845000E+02, 0.33999700E+03, 0.92610100E+02, 0.23198700E+03, 0.38398900E+02, 0.30994000E+03, -.78089600E+02, 0.41338600E+02, -.74872800E+02, 0.41025100E+02, -.63770400E+03, -.26444100E+03, 0.25967800E+03, 0.31257300E+03, 0.89622400E+02, -.18815600E+03, 0.45165800E+03, 0.61226500E+03, -.30434900E+03, -.25676000E+03, -.30368500E+03, -.13898500E+03, -.26192500E+02, -.72100500E+02, 0.11575500E+03, -.20325200E+03, 0.18826400E+02, 0.42508900E+02, -.39868300E+02, 0.21972300E+02, -.14477900E+03, 0.15081000E+02, 0.48050200E+02, 0.63431800E+02, 0.81022300E+02, 0.25407700E+03, -.12408800E+03, 0.16165100E+03, -.27607900E+03, -.16693100E+03, 0.79176300E+02, 0.11069400E+03, 0.76067800E+02, 0.79812000E+02, 0.62610900E+02, -.46480500E+02, -.17214800E+03, -.62093100E+02, 0.98086600E+02, 0.20474900E+01, 0.32590800E+01, -.25786500E+02, 0.18747200E+03, -.42616100E+00, 0.65540800E+02, 0.16481200E+02, -.33539000E+02, -.65759000E+02, -.26972900E+02, -.79416100E+02, 0.91288900E+01, -.93426000E+01, 0.81159700E+01, -.82517700E+02, 0.12578500E+03, 0.83368100E+01, 0.19124200E+02, 0.56186900E+01, -.92736900E+01, 0.39368700E+02, 0.17680800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24837500E+00, -.18110200E+01, -.26841300E+01, -.20089400E+01, 0.60277500E-01, -.13018000E+01, 0.73774300E+00, 0.20668800E+00, 0.22572000E+01, 0.15072300E+01, 0.81974200E-02, -.36386700E+00, 0.24127700E+01, -.74202900E+00, -.34356100E+00, 0.14329700E+01, -.10595900E+01, 0.14669200E+00, -.63689100E+00, 0.83110000E+00, -.13481800E-01, 0.18372900E+00, -.51542300E+00, -.54495200E+00, 0.11960200E+00, -.10702400E-02, 0.62045600E-01, 0.16981500E-01, -.70138200E-02, -.99572300E-02, -.10380500E+00, 0.50016300E-01, -.13858500E+00, 0.13072500E+00, -.62911400E+00, -.58041300E-01, 0.90752700E-01, 0.10676200E+00, -.17887700E+00, -.36750100E+00, 0.58611200E+00, -.19707000E+00, -.78191900E-03, -.98850700E-01, -.10400000E+01, 0.19532100E+00, 0.30844900E+00, 0.25780400E-01, 0.33877500E+00, 0.41995900E+00, -.58699600E-01, 0.16763400E+00, 0.56624700E+00, 0.11431500E+00, 0.13424300E+00, -.57577700E-01, -.25387300E+00, 0.29794800E+00, 0.96534800E-02, -.23220100E+00, 0.17543900E+00, 0.55049300E+00, -.11524000E+01, -.20925300E+00, -.54040700E+00, 0.27255400E+00, -.32207400E+00, -.17359900E+01, -.26909000E+00, -.13672400E-01, -.14986400E+00, -.11970600E+00, 0.67241000E-01, -.22458800E+00, 0.13501100E+00, 0.82780800E+00, -.78604700E+00, 0.12220100E+01, -.99846600E-01, 0.16620500E-01, -.25268000E-01, -.91010800E-01, -.12890000E+00, 0.28930100E+00, 0.52624200E+00, -.15510000E+00, 0.63148000E+00, -.12405200E+00, 0.12192000E+00, 0.54663400E+00, 0.35241300E+00, -.42743100E-01, -.45570800E+00, -.36216600E+00, -.43407300E+00, -.66993200E+00, 0.69288900E+00, -.13323900E+00, -.65940600E+00, 0.15833500E+00, -.16219500E+00, 0.22964400E+00, 0.56411300E-01, -.81828000E-01, -.36834500E+00, 0.27906300E-01, 0.12076000E+00, 0.33723400E+00, -.20605700E+00, -.14312700E+01, -.76399300E+00, -.53841600E+00, 0.23495000E+00, -.53478900E-01, -.55282300E-01, -.96927800E+00, -.13884500E-01, 0.15743800E+01, -.82059600E-01, -.19213400E+00, 0.49795600E-01, -.23299000E+00, -.10411400E+00, 0.31984600E-01, -.58223100E-02, -.40719000E-01, -.51085800E+01, 0.22931000E+00, 0.41594900E+00, 0.53642900E+01, 0.84789000E+00, 0.31452200E+00, -.71703300E-01, 0.97788000E-01, 0.62927200E-01, 0.13178200E+00, 0.59192800E+00, -.13674600E-01, -.27438100E+00, -.47489900E+00, -.44419600E+00, -.11321300E+00, -.58164000E+00, -.27619600E+03, 0.16163700E+03, 0.78775300E+02, 0.14115400E+03, 0.90782800E+02, 0.99765200E+02, -.74714000E+02, -.82336700E+02, 0.60083600E+01, 0.10303400E+03, 0.10790900E+03, 0.42069000E+03, -.20860800E+03, -.21402900E+03, -.21921800E+03, -.21272400E+03, -.84462300E+02, -.28382200E+02, 0.10201700E+03, -.51658600E+02, -.90443600E+02, -.52854500E+02, -.12549400E+03, 0.59574000E+02, 0.59730800E+02, 0.50725900E+02, -.51645800E+02, -.43299800E+02, 0.17082400E+03, 0.14846200E+03, 0.52681500E+02, -.59637000E+02, 0.31023500E+02, 0.16240200E+03, -.85153000E+02, -.31081000E+03, -.79881700E+02, -.24064800E+03, 0.34758300E-02, -.10953100E+02, -.15894100E+02, -.74184900E+02, 0.36869600E+02, 0.55864100E+02, 0.20296900E+03, -.10221500E+03, 0.31303900E+02, -.10084600E+03, -.57843400E+02, -.38397100E+02, -.32363000E+01, 0.27388800E+02, -.67327800E+02, -.85938300E+01, -.92168100E+01, -.31519200E+03, 0.15986500E+03, -.57254100E+02, 0.15485800E+03, 0.13021000E+01, 0.12304900E+03, 0.91323400E+02, 0.65679100E+02, 0.23328300E+02, 0.12207600E+03, -.58955500E+02, -.27533600E+01, -.24347600E+01, 0.80267800E+02, -.31915500E+01, 0.11889700E+02, 0.26562200E+02, -.34204800E+02, -.69297200E+02, -.13903700E+02, 0.17881100E+02, 0.30059000E+02, 0.38993000E+01, 0.13952600E+00, 0.11364600E+03, 0.84425600E+00, 0.40837500E+02, 0.40926800E+00, -.14513200E+02, -.41658000E+02, -.11731400E+02, -.50707100E+02, 0.70912500E+01, 0.33828900E+01, 0.19060400E+01, -.52046600E+02, 0.77839300E+02, 0.17308800E+01, 0.31865200E+01, -.14991700E+02, -.45411400E+01, 0.16170800E+02, -.15145300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54028300E+00, 0.35750700E+01, 0.61517100E+01, 0.24171600E+01, -.18055900E+01, 0.30356900E+01, -.29829100E+01, 0.36252200E-01, -.27355000E+01, -.25908600E+01, -.12170300E+00, 0.37403200E+00, -.97560700E+00, 0.63529800E+00, 0.67567800E+00, -.23246900E+01, 0.20610900E+01, -.29791800E+00, 0.45777800E+00, -.17994200E+01, -.22030900E+00, -.56449700E+00, -.17570500E+01, 0.51115800E+00, 0.34043000E-01, 0.51733700E-02, -.25357500E+00, -.77695100E+00, -.41787600E-01, -.58137800E+00, 0.17097400E+00, 0.44276800E-01, -.13647500E-01, 0.27686500E+01, 0.27662900E+01, 0.25175300E+00, -.44654700E-01, 0.22026200E-01, 0.59083700E+00, 0.70069100E+00, 0.59930200E+00, 0.33921700E+00, 0.43858200E+00, 0.46260100E+00, -.31732500E+01, 0.10417300E+00, 0.10751300E+01, 0.19960900E-01, 0.90169300E+00, 0.67074100E+00, -.71225200E+00, 0.56015100E+00, 0.38003400E+00, -.62295400E+00, -.32956300E+01, 0.38232700E+00, 0.29239700E+01, 0.76023800E+00, -.10013900E+00, 0.48861600E+00, -.53497100E+00, -.13722800E+01, 0.43205200E+01, 0.28000100E-01, 0.65975700E-02, -.42091600E+00, 0.83182700E+00, 0.99439400E+01, 0.50744300E+00, -.36896000E-01, 0.10611000E+01, 0.15825200E+01, 0.22998100E+00, 0.70495300E-01, 0.11278400E+01, -.19277200E+01, 0.10937300E+01, -.48799000E+01, 0.51770000E-01, 0.24420000E+00, 0.13590900E+00, 0.24251000E+01, -.81929800E+00, -.30826900E+00, -.15761600E+01, 0.20443500E+01, -.10116100E+01, -.21700100E+00, 0.64962200E+00, -.22256100E+01, 0.22467700E+00, -.11171300E+00, -.97464300E+00, 0.43791500E+00, 0.50941500E-01, -.13941600E+01, -.77745800E+00, 0.47598400E+00, -.13194400E+00, 0.11547800E+01, -.46381500E+00, -.26219600E+00, -.61837400E-01, 0.68396600E+00, -.75655800E+00, 0.38353100E-01, 0.76494500E-01, 0.87724500E+00, -.10012900E+00, 0.28975600E+00, 0.13515700E+01, 0.30117500E+00, -.50245400E-01, 0.31836800E-01, -.26911300E+00, 0.88414400E+00, 0.13167900E+00, 0.21893600E+01, -.18288600E-01, 0.50212700E+00, -.42887400E+00, 0.31280400E+00, -.16952500E+00, 0.38089500E+00, -.11183200E-01, 0.13513600E-01, 0.33104900E+01, -.46807300E+00, 0.57898700E+00, -.54363100E+01, -.97112000E+00, -.32395300E+00, 0.51234500E+00, 0.95977500E-01, -.17340500E+00, 0.39459300E-01, -.17990600E+01, 0.42626000E+00, 0.11425000E+01, 0.60095600E+00, 0.91681800E+00, -.93081000E+00, 0.96393500E+00, -.10796600E+01, 0.54804200E+02, 0.53519300E+01, 0.52603600E-02, 0.13241400E+02, -.38410800E+01, 0.73920200E+00, 0.54537900E+01, 0.41367100E+01, -.46855000E+01, -.26187700E+02, -.10579100E+03, 0.51308400E+02, 0.42956700E+02, 0.55132300E+02, 0.11054300E+03, 0.47453900E+02, -.43060000E+01, -.42339300E+01, 0.41022600E+01, 0.48891600E+02, 0.18581300E+02, 0.10433100E+03, -.51175500E+02, -.88833700E+02, -.47843200E+02, -.17484300E+02, 0.18031000E+02, -.89627900E+02, -.10605700E+03, 0.83637500E+01, 0.23029200E+02, 0.27506100E+02, -.33227300E+03, 0.17813000E+03, 0.18581100E+03, 0.16713100E+03, 0.17841900E+03, -.61962600E+02, 0.94235500E+02, -.42021100E+02, 0.18155600E+03, -.66167800E+02, -.50285500E+02, -.23010700E+03, 0.10807000E+03, 0.35705200E+02, 0.11373100E+03, 0.12085600E+02, 0.14115700E+02, 0.35441800E+02, -.26583000E+02, 0.91163100E+02, 0.28563300E+01, 0.41531000E+02, 0.62712500E+02, -.32086700E+02, 0.93183800E+01, -.29987000E+02, -.25967300E+02, -.18001900E+03, 0.12202900E+03, -.71397300E+00, 0.19347600E+03, -.16638500E+03, 0.80751800E+01, 0.44146800E+02, -.21108500E+02, -.56231300E+02, -.20290100E+02, -.30823800E+02, 0.11589400E+02, 0.26361400E+01, 0.30740500E+02, 0.19753100E+02, 0.71548400E+01, 0.57422800E+01, -.11636300E+01, -.11935300E+02, -.17437300E+02, -.59793200E+00, -.25682100E+02, 0.54278500E+01, 0.43622600E+01, 0.25046300E+02, 0.84142000E+01, 0.23510700E+02, -.37283900E+01, -.13079800E+01, 0.15318800E+01, 0.25704400E+02, -.26770100E+02, -.45347600E+01, 0.71837700E+01, 0.71420900E+01, 0.69361100E+01, -.21463500E+02, 0.23002900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.38380200E+00, 0.65432300E+00, 0.60432900E-01, 0.13906900E+01, 0.14447100E+01, -.41054000E+00, 0.16017400E+01, -.28464400E+00, -.15537600E+01, 0.14098800E-01, 0.18667400E+00, -.22671400E-01, -.26671700E+01, 0.14265700E+01, 0.70129100E+00, -.93504500E+00, 0.11886600E+00, 0.29966100E-01, 0.46686500E+00, -.69212200E+00, 0.14652500E+00, -.38067600E-01, 0.22673000E+01, -.18012200E+00, -.14016900E+01, -.22260200E-02, -.27237700E-01, 0.12861600E+00, -.35484300E+00, 0.31976800E+00, -.18516500E+00, 0.79413300E+00, -.41871800E+00, -.77223500E-01, 0.99595100E+00, -.37648500E+00, 0.10047600E+00, 0.20500200E+00, -.26316200E+00, 0.32490900E+00, -.10999200E-01, -.64158300E+00, 0.16047200E+00, -.18973800E-01, 0.93387000E+00, -.44136500E+00, 0.13877700E+01, -.34874000E-01, 0.91030600E-01, 0.14202000E+01, 0.21319000E+00, 0.57623500E+00, 0.15769000E+00, 0.13278900E+00, 0.13224700E+00, 0.14202200E+00, 0.21187000E+01, -.85923600E+00, 0.16082200E+00, -.31352700E+00, -.23372300E+00, -.63070800E+00, 0.18442800E+01, 0.91139400E-01, 0.40280500E-01, 0.47035200E+00, 0.34237700E+00, 0.10152300E+02, 0.81718900E+00, 0.46321600E-01, 0.43221200E+00, 0.25617800E+00, -.98934400E-02, 0.38903300E+00, 0.41658400E+00, -.10919300E+00, -.52533200E+00, -.30754100E+00, 0.42034600E-01, 0.12453300E+00, 0.10112900E+00, 0.10420800E+01, 0.18298400E+00, -.45046000E-01, -.13671100E+00, -.48005100E+00, 0.27737100E+00, -.19330300E-01, -.23289600E+00, -.27257800E+00, -.55740800E+00, -.15759200E-02, -.23556100E+00, 0.15932400E+00, 0.10415300E+00, 0.12354900E+00, -.70657600E+00, 0.22590600E+00, -.46837800E+00, 0.11671700E+00, -.10546800E+00, 0.19347800E+00, 0.14338000E-01, 0.20623000E+00, 0.48897200E+00, 0.81629100E-01, -.51879200E-02, -.17517000E+00, 0.38367500E+00, 0.93037900E+00, -.19680500E+00, 0.63733400E+00, -.29439100E+00, 0.81580600E-02, 0.18314800E+00, 0.57845100E+00, 0.15689500E+00, -.86046300E+01, 0.13269700E+00, -.56454700E+00, -.43338000E+00, 0.13499500E-02, -.19109300E-01, -.22920200E-02, -.39954100E-01, 0.87157000E+00, 0.21709400E+01, -.25730500E+00, 0.19917100E+01, -.25675900E+01, -.80875100E+00, -.45300700E-01, 0.14510300E+00, -.32946700E-01, 0.52974300E-01, -.98420200E-01, 0.27189100E+00, -.18190000E+00, 0.73705800E-01, -.36828700E+00, 0.86913500E-02, 0.61864100E+00, -.32896900E+00, -.37451400E+00, 0.37386700E-01, 0.36186300E+03, 0.30571800E+01, 0.42745500E+02, 0.66139900E+02, -.10903200E+03, -.34080600E+02, -.12475900E+03, 0.79985700E+02, -.41477200E+02, 0.41199100E+03, -.20348300E+03, -.23358400E+03, -.21691700E+03, -.21114300E+03, -.90811900E+02, -.48948800E+02, 0.10628600E+03, -.39567400E+02, -.10177600E+03, -.18813600E+02, -.30463100E+03, 0.14631700E+03, 0.10467700E+03, 0.13696000E+03, -.36325900E+02, -.28119800E+02, 0.15692000E+03, 0.91037300E+02, 0.82572700E+02, -.47291900E+02, 0.10435200E+03, 0.22085000E+03, -.10467000E+03, -.26903800E+03, -.10897800E+03, -.42391200E+03, -.27173700E+02, -.15850800E+01, 0.84419600E+01, -.11602500E+03, 0.19241200E+02, 0.15424000E+03, 0.57687500E+03, -.28458000E+03, -.82736300E+02, -.28663000E+03, -.12148300E+03, -.51233200E+02, -.80934800E+02, 0.40177300E+02, -.18558000E+03, -.24189200E+02, -.48837500E+02, -.24117400E+03, 0.12318800E+03, -.44468400E+02, 0.11708900E+03, -.30433600E+01, 0.12778800E+03, 0.64351400E+02, 0.10282500E+03, -.64951200E+02, 0.15335500E+03, -.11555000E+03, -.58853300E+02, 0.25146300E+02, 0.54855200E+02, 0.23607500E+02, 0.31061100E+02, 0.38876500E+02, -.66144100E+02, -.14439000E+03, -.41945000E+02, 0.34054000E+02, 0.55887200E+02, 0.42018200E+01, 0.16492300E+01, 0.12556000E+03, 0.21460800E+01, 0.45883800E+02, 0.34158500E+01, -.16691900E+02, -.45851600E+02, -.23387800E+02, -.62551600E+02, 0.79672100E+01, 0.13648500E+01, 0.70370000E+01, -.65281100E+02, 0.11934200E+03, 0.39587900E+01, 0.39156000E+01, -.13341600E+02, -.12812000E+02, 0.26113700E+02, -.18497600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25052900E+00, -.55044400E+00, -.17714000E+01, -.11128200E+01, -.99813800E+00, 0.28228500E+00, -.48574000E+00, 0.24530300E+00, 0.38627800E+00, 0.58396300E+00, 0.11751200E+00, 0.12074600E+00, 0.14869200E+01, -.80581000E+00, -.19277200E+00, 0.17127000E+00, 0.44308200E+00, -.11685900E+00, -.33597900E+00, 0.12976400E+00, -.62431300E-01, -.43866800E-01, 0.11031200E+01, 0.22687400E+00, 0.24641800E+00, -.25976000E-02, 0.24583300E+00, -.37805600E+00, 0.14395700E+01, -.80552100E+00, -.28381100E+00, -.12906400E+01, -.27796500E-01, 0.23396100E-02, -.28984300E+00, -.16581500E+00, 0.27238400E+00, 0.23617300E+00, -.26573700E+00, -.38109200E-01, 0.48361500E+00, 0.98457300E-01, 0.74434000E-01, 0.51424500E-01, -.56864000E+00, -.18686300E+00, -.97602300E-01, 0.10970100E+00, 0.78086500E+00, 0.26081200E+00, -.58318700E+00, 0.16889400E+00, 0.65703400E+00, 0.10205400E+00, -.10166400E+01, -.44532000E-01, 0.90523700E+00, 0.45344500E+00, -.16616900E-01, 0.18450500E+00, 0.11774500E+00, -.38203700E+00, 0.44705000E-01, -.73829000E-02, -.19541400E+00, -.93421900E-01, -.86612400E-01, 0.81546000E+00, -.11490700E-01, 0.32301600E-01, 0.27218200E-01, 0.16555100E+00, -.47738300E-05, -.24087000E+00, 0.16800400E+00, -.34015200E+00, -.21851900E+00, -.41332000E+00, 0.34001300E-02, 0.56788700E-01, -.85367700E-01, 0.16105100E+00, 0.72585300E-01, -.62020400E-01, -.28272700E-01, 0.61620100E-01, 0.32825400E-01, 0.92914300E-02, -.72685300E-01, 0.26542600E-01, 0.26283600E+00, -.81728800E-02, 0.51542100E-01, 0.43288000E-01, -.13036300E-01, -.31599600E-01, -.71400800E-01, 0.41720000E-02, 0.15866100E-01, -.28767800E-02, -.11289000E-01, 0.14351600E-01, -.26207100E-01, 0.31623900E-01, 0.45861100E-02, 0.32328100E-01, -.31069300E-01, 0.67105800E-01, -.56122600E-02, -.25504200E-01, 0.16753600E+00, -.96681800E-02, 0.48132500E-01, 0.18189600E-03, -.34660600E-01, -.33859900E-01, 0.65621500E-01, 0.40117500E+00, -.19916900E-02, 0.99578400E-01, -.20621100E+00, -.91092300E-01, -.10473300E-01, 0.80087500E-01, 0.82795400E-01, -.78097800E-01, -.11774700E+01, 0.20887900E-01, 0.78407900E+00, 0.58223400E+00, 0.57946800E-01, 0.68606100E-01, -.64568500E-01, 0.28053500E-01, 0.23195800E-01, -.15168500E+00, -.45724500E-01, -.53220100E-01, 0.16271300E-01, 0.17186300E-01, -.26808500E-01, 0.11871000E+00, -.90805300E-01, 0.45070300E-01, 0.11645700E-01, -.38508400E-02, 0.30683600E+02, 0.59137800E+01, 0.12509100E+02, -.18519800E+02, -.61389500E+01, -.88341500E+01, 0.12063000E+02, -.17552000E+01, 0.12040300E+02, -.59083400E+01, -.92802400E+00, -.63179900E+01, -.16418100E+02, -.74926300E+01, -.52824600E+01, -.17284200E+01, -.35037200E+01, -.92324500E+01, 0.12131600E+02, -.77645000E+02, 0.39604900E+02, 0.29651700E+02, 0.37378200E+02, 0.17914600E+01, 0.39632500E+01, 0.23543700E+02, 0.86521500E+01, 0.83112500E+01, 0.65618200E+01, 0.27993600E+02, 0.15409800E+02, -.90480100E+01, 0.32345800E+01, -.78602600E+01, -.67129900E+02, -.17271300E+02, 0.15355600E+02, 0.43068900E+02, -.84059200E+01, -.11396300E+02, 0.22253900E+02, 0.79692800E+02, -.40380600E+02, -.22652400E+02, -.36741000E+02, -.13049600E+02, -.61891600E+00, -.11923200E+02, 0.16175900E+02, -.27604000E+02, 0.21260800E+01, -.12415400E+02, -.16101100E+00, -.36182500E+00, -.51138400E+01, 0.19778600E+00, -.33086100E+01, 0.12063000E+02, -.18325000E+02, -.21812600E+01, -.29651300E+02, 0.19320500E+02, -.12245300E+02, -.14163600E+02, 0.70863700E+01, 0.13126300E+02, 0.67764700E+01, 0.13500500E+02, 0.19052700E+01, -.62272400E+01, -.15497900E+02, -.73175600E+01, 0.50417100E+01, -.76602300E+00, 0.16711800E+00, 0.16315900E+01, 0.12585400E+02, -.55305600E-01, 0.46194500E+01, -.56923900E+00, -.27716500E+00, -.45392200E+01, -.55378700E+01, -.66556800E+01, 0.74555700E+00, -.11533300E+01, 0.90112000E+00, -.67042600E+01, 0.10360200E+02, 0.19653500E+01, -.12988100E+01, 0.81559900E+00, -.39174400E+01, 0.33243200E+01, 0.13754400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.43314000E+00, -.96923400E+00, -.22368900E+01, -.63467900E+00, -.12616500E+01, -.37259000E+00, -.80694200E+00, 0.27180500E+00, 0.13823600E+01, 0.16671800E+01, 0.20489700E+00, -.22256900E+00, 0.24188100E+01, 0.58587600E+00, -.21302000E+00, 0.13234000E+01, -.32319200E+01, 0.13328400E+00, -.18314300E+01, 0.12886000E+01, 0.63522500E-01, -.14845400E-01, -.29278200E+01, -.14175800E+00, -.74547100E+00, -.13824900E-02, -.54489700E+00, -.38533800E+00, 0.98660100E+00, 0.86821200E+00, -.20153900E+00, 0.95760500E+00, 0.13205000E+00, 0.58718900E+00, -.10484000E+00, 0.16160900E+00, -.13323800E+00, -.25126300E+00, 0.75890500E+00, 0.52491400E+00, -.87120900E+00, 0.24107000E+01, -.37223400E+00, 0.13999000E+00, -.51497400E+00, 0.90011300E+00, -.12199100E+01, -.25716400E-01, -.20920800E+01, -.21212000E+01, 0.63037700E+00, -.70776500E+00, -.14321600E+01, -.10506900E+00, 0.88158400E+00, 0.69109300E+00, -.22016800E+01, 0.15373300E+01, -.32649200E+00, 0.78984900E+00, 0.27908700E+00, -.46821200E+00, -.32678800E+01, 0.12148400E+00, 0.33175600E+00, -.73536900E+00, 0.24667200E+00, -.11926600E+02, 0.46522300E-03, -.46546000E-01, -.43976300E+00, -.78253800E+00, -.27420800E+00, -.14671500E+00, -.11344000E+01, 0.93863300E-01, 0.20873400E+00, 0.12616500E+01, 0.88792000E-01, 0.13646000E+00, -.28547100E-01, -.26998600E+00, 0.34627800E-01, -.28386300E-01, 0.16175700E+00, -.24025100E+00, -.32565900E+00, 0.13807400E+00, 0.28308000E+00, 0.13694100E+00, -.12494700E+01, 0.52539700E-01, 0.10086700E+00, 0.12808700E+00, 0.67712900E+00, 0.59804900E+00, -.11992300E+01, 0.60550500E+00, -.10422800E+01, -.19904300E+00, 0.43951600E-01, 0.33619200E+00, -.92089100E-01, 0.35436800E-01, 0.19608400E+01, -.22397100E-01, -.17613000E+00, 0.87148900E+00, 0.57487600E+00, 0.55439300E+00, -.45039200E+00, 0.60473700E+00, 0.32031200E-01, 0.56922200E-02, 0.15036500E+00, -.52776500E-01, -.12077400E+00, 0.88764300E+01, -.12561000E+00, 0.49047300E+00, 0.63989200E+00, -.23142100E-03, 0.22673500E+00, -.11886000E+01, -.11856600E+00, 0.91092600E-01, 0.91947900E+01, -.24435200E+00, -.47262600E+01, -.32548100E+01, 0.92436200E-01, -.45743700E+00, 0.25077300E+00, -.23115800E+00, 0.27896000E-01, 0.88432500E-01, -.13620800E+00, 0.19680900E+00, -.44702500E+00, 0.41278600E+00, 0.11178100E+00, -.87971300E+00, 0.81735300E+00, -.25573900E+00, 0.12773800E-01, -.11589000E+00, -.11050000E+00, -.65377900E+02, -.85484000E+02, 0.12416500E+03, 0.57013600E+02, 0.89101900E+02, -.97099400E+02, 0.38255500E+02, -.35543500E+03, 0.17539300E+03, 0.18247400E+03, 0.18869400E+03, 0.29605200E+03, 0.12487100E+03, 0.17484200E+02, -.69348200E+02, 0.45576900E+02, 0.13470200E+03, 0.14441800E+02, 0.60729700E+03, -.30135400E+03, -.23400800E+03, -.28806900E+03, 0.42298000E+02, 0.25894100E+02, -.31141300E+03, -.18924600E+03, -.12144900E+03, 0.19555200E+02, -.15933100E+03, -.32655200E+03, 0.16427600E+03, 0.27654000E+03, 0.16189000E+03, 0.44286300E+03, 0.53796200E+02, -.65234900E+02, -.28555000E+03, 0.13862500E+03, 0.41371700E+01, -.27548200E+02, -.53268200E+03, 0.26976300E+03, 0.62026100E+02, 0.26507900E+03, 0.95528600E+02, 0.47024900E+02, 0.42255500E+02, -.91566000E+02, 0.21235300E+03, -.36803100E+01, 0.83573700E+02, 0.26613300E+03, -.13251700E+03, 0.10030500E+03, -.12927700E+03, -.14301500E+02, -.17906200E+03, -.49703300E+02, -.18011000E+03, 0.10846600E+03, -.21022000E+03, 0.65598400E+02, 0.14581200E+03, -.70540900E+02, -.18502600E+03, -.66898300E+02, -.76758700E+02, -.36670700E+02, 0.44760400E+02, 0.12219200E+03, 0.40995400E+02, -.50284600E+02, 0.27935800E+02, -.46726200E+01, -.35183900E+01, -.15295800E+03, 0.21157900E+00, -.55707600E+02, 0.54444800E+01, 0.15269100E+02, 0.56510700E+02, 0.35936400E+02, 0.73169000E+02, -.10539300E+02, 0.36578600E+01, -.55777700E+01, 0.72889400E+02, -.13597400E+03, -.10804900E+02, 0.25623100E+01, 0.11211100E+02, 0.22437200E+02, -.26416400E+02, 0.16652600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.92957800E-01, 0.32989300E+00, 0.15024700E+01, 0.55744200E+00, -.45302900E+00, 0.60238000E-01, -.92663500E-01, 0.31084000E-01, 0.20067000E+01, 0.57128900E+00, -.13918000E+00, -.38045900E+00, 0.95112800E+00, 0.97500900E+00, 0.53127500E+00, 0.18848900E+00, 0.16318900E+00, 0.36526800E+00, -.55265700E+00, -.14180900E+01, 0.36306400E-01, -.16721900E-01, -.91021800E-02, -.44884300E-01, 0.41126300E-01, 0.10393500E-02, 0.30736200E-01, 0.23207300E+00, -.28566700E+00, 0.31359800E+00, -.20730500E-01, 0.20308400E+00, 0.84581200E-01, 0.11557500E+00, 0.91459000E+00, 0.20705500E+00, -.99511800E-01, -.26054000E+00, 0.27520600E+00, 0.15832400E+00, -.11246100E+00, 0.37761900E+00, 0.20607600E-01, 0.12092500E-02, 0.69309000E-01, -.28747100E-01, 0.86960400E+00, -.28490500E-01, -.90557600E-01, 0.25340000E+00, 0.17857700E+00, 0.89907100E-01, -.59218000E+00, -.12727000E+00, -.49859100E-01, 0.26354900E+00, 0.91809900E+00, 0.39652400E+00, -.16135100E-01, 0.19591000E+00, 0.62792200E-01, 0.25510800E-01, -.45379800E+00, 0.94563800E-02, -.38903700E+00, -.59874700E-01, -.16195600E+00, -.85601300E-01, -.11455500E+00, -.36565700E-01, -.23323000E+00, -.13267100E+00, -.11542600E+00, -.16044600E+00, 0.89596400E-01, -.69146100E+00, 0.16622100E+00, -.54839900E+00, 0.65428700E-01, -.53819300E-01, -.62944900E-02, -.18481600E+00, 0.32620100E-01, -.34263800E-02, 0.15078700E+00, 0.28519700E+00, -.39175300E+00, 0.52562100E-01, 0.15757600E+00, -.49136200E+00, -.18364300E-02, 0.68392700E-04, -.15986300E+00, -.29703500E-01, -.31767300E-01, 0.12257700E+00, 0.33430100E+00, 0.11851900E+00, -.32458300E+00, 0.22470300E+00, -.43775800E-01, 0.68551500E-01, -.42761700E-01, -.21821800E-01, 0.34015000E-02, -.42627600E-02, -.26159200E-01, -.13045000E+00, -.15259800E+00, -.53610600E+00, -.16288800E+00, -.17532400E+00, -.51197500E-01, 0.36464600E-01, 0.42968200E-01, -.10081600E+00, 0.82111000E-01, -.73933100E+00, 0.10363900E-01, 0.85253500E-01, -.77200900E-01, 0.35108900E-01, -.23625500E-01, -.70147000E-01, 0.54616200E-01, -.37624700E+00, -.46860900E+00, 0.22232400E-01, 0.17032400E+00, 0.10114700E+01, 0.32373300E+00, 0.65262800E-01, -.14650400E+00, 0.80725100E-01, 0.30243700E-01, -.27621100E-01, -.14859400E+00, 0.30600000E-01, -.30530800E+00, 0.38876900E+00, -.12510900E+00, -.23757200E+00, -.10795600E-01, 0.39569900E+00, -.85341900E-01, -.23180900E+00, -.51545400E-01, 0.29649000E+00, 0.11745700E+02, -.20324000E+02, -.14721600E+02, 0.67690000E+02, 0.70469500E+01, -.34945700E+02, -.11113100E+03, 0.54676400E+02, 0.58840400E+02, 0.56785800E+02, 0.16758300E+02, 0.56667600E+01, 0.91369600E+01, -.35883200E+02, 0.14258900E+02, 0.51829500E+01, 0.54262200E+02, -.80272000E+02, 0.43448500E+02, 0.25446900E+02, 0.40709200E+02, 0.16294000E+02, 0.18667300E+02, -.17367200E+01, -.27453100E+01, -.17479200E+02, 0.27623300E+02, 0.68107900E+02, 0.25182500E+02, -.14968400E+02, 0.73823400E+02, -.13089500E+02, -.50379300E+02, -.41061600E+02, 0.36023300E+02, 0.11653600E+03, 0.36556800E+01, -.39621500E+02, -.27500200E+02, 0.35686100E+02, -.20906700E+02, -.21122200E+02, -.17120000E+02, 0.58074700E+01, 0.17432800E+02, -.14639800E+02, 0.21089400E+02, -.13808500E+02, 0.17489700E+02, -.30441100E+02, 0.11561900E+03, -.59312200E+02, -.27898500E+01, -.58042900E+02, -.19166600E+02, -.21713800E+01, -.51787200E+02, 0.17662200E+02, -.56943100E+02, 0.80326200E+01, -.15758600E+02, -.33421900E+02, 0.18034700E+02, 0.43763200E+01, 0.16793100E+02, 0.27740900E+02, -.41169100E+01, -.90124600E+00, -.20292400E+02, -.68233500E+01, 0.65459700E+01, -.31455000E+01, -.62756900E+00, 0.19949200E+01, -.37139000E+01, 0.90038400E-02, 0.22924300E+01, -.11779100E+01, 0.10131000E+01, -.18444100E+01, -.20100600E+01, -.22380400E+01, -.32725000E+00, -.16691800E+01, 0.27572200E+01, -.23946600E+01, -.11040700E+01, 0.57635300E+01, -.21406500E+01, 0.76994500E+01, -.24807800E+01, 0.42907800E+00, 0.65405200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12881300E+00, -.93876600E-01, -.17030200E+01, -.27421000E+00, 0.10268100E+01, 0.21748400E+00, 0.14302400E+01, 0.20182300E+00, -.20984800E+01, -.60012700E+00, 0.47871400E+00, 0.64413000E-01, -.76180300E+00, -.16901100E+00, -.80743700E+00, -.64642500E+00, 0.62296000E+00, 0.62788300E+00, -.33415600E+00, 0.51205000E+00, 0.42924500E-01, 0.75145300E-01, -.12160300E+01, -.14456100E+00, -.28028900E+00, 0.13657600E-03, -.27620400E+00, -.24438700E+00, -.99003900E+00, -.17243400E+00, 0.65552500E+00, 0.99888300E-01, 0.15315800E+00, 0.23144400E+00, 0.90330900E+00, 0.17117700E+00, -.81931300E-01, 0.20543500E-01, 0.28924800E+00, 0.66105100E+00, -.29561600E+00, 0.26100400E+00, 0.20899700E-01, 0.12881800E+00, -.81814500E-01, 0.98371300E-01, 0.16715100E+00, -.15960600E-02, -.67193800E+00, -.33998500E-01, -.37637400E-01, 0.23823800E+00, 0.59777100E+00, 0.40277300E-01, -.66697400E-01, -.60218100E-01, 0.17738000E+00, -.18100500E+00, 0.20468400E-01, -.12588700E+00, -.13196400E+00, 0.26458500E+00, -.69976000E+00, -.21787400E+00, 0.69395300E-01, 0.11491300E+00, 0.11541500E+00, -.35750800E+01, -.61617300E-01, -.52311300E-02, 0.42236400E-01, 0.15945900E+00, -.51658500E-01, -.10963300E-01, 0.27204200E+00, -.91540200E+00, -.62428000E-01, 0.17370800E+00, 0.60365800E-01, 0.11357900E+00, -.20431100E-01, -.14238300E+00, -.23054500E-02, -.11452900E+00, -.40436500E+00, 0.79696500E-02, 0.75924900E-01, 0.11675400E-01, 0.17150700E+00, -.16619700E+00, 0.20659200E+01, 0.21243000E-01, 0.43713200E+00, -.13858300E-01, -.99239400E-01, -.27747300E+00, 0.25531700E+00, -.20724400E+00, 0.38254900E+00, 0.28840900E-01, -.13317000E+00, 0.44459900E-01, 0.17067100E-01, -.55470600E-01, 0.42609500E+00, 0.12294900E-01, -.31285700E-02, 0.18264800E+00, -.87901800E-01, -.18312100E+00, 0.69106600E-01, -.11186600E+00, 0.17613600E+00, -.37569400E-01, -.93176200E-01, -.75420600E+00, -.88330700E-01, 0.26711200E+01, -.67915200E-01, 0.38617700E+00, -.76559700E+00, -.17482000E+00, -.10879800E-01, -.15363300E+00, -.39838800E-01, 0.33723600E+00, -.20958800E+01, -.15254500E+00, -.28909300E+01, 0.23325800E+01, 0.61203900E+00, 0.87014000E-01, 0.11001800E+00, -.17978100E+00, -.19910100E-01, 0.14480100E+00, 0.30719800E-01, -.11102500E+00, 0.81153300E+00, -.25786200E+00, -.13361600E+00, -.56661200E+00, -.41426900E-01, 0.28381200E+00, -.11871900E-01, 0.20402100E-01, 0.27877100E-02, -.25473900E+00, 0.76738700E+00, 0.38145600E+02, 0.29262700E+02, -.47598700E+02, -.13457500E+01, 0.17935000E+02, 0.76797800E+02, -.39455200E+02, -.57893800E+02, -.37412800E+02, 0.67933500E+02, 0.39015900E+02, -.33190000E+02, 0.36004800E+02, -.23122500E+02, 0.51157000E+02, -.39711200E+02, 0.17163400E+03, -.85610800E+02, -.10208400E+03, -.83157100E+02, 0.16182800E+01, -.29954200E+01, -.72053100E+02, -.59381900E+02, -.25886600E+01, -.76316000E+01, -.68183300E+02, -.18862500E+03, 0.92799100E+02, 0.11371400E+02, 0.94835400E+02, 0.17022400E+03, 0.29347200E+02, -.23647500E+02, -.20247500E+03, 0.86728800E+02, 0.10199800E+02, 0.14796400E+02, -.64552400E+02, 0.34529700E+02, -.58290600E+01, 0.30844200E+02, -.91249900E+01, -.80993400E+01, 0.10373500E+01, -.38519700E+02, 0.63354800E+02, -.29103400E+02, 0.54472400E+02, 0.37370600E+01, 0.96578000E-01, 0.33416300E+02, -.94591300E+00, 0.47470300E+02, -.28230100E+02, 0.22246400E+02, -.72998400E+02, 0.64240900E+02, -.34665700E+02, -.51430800E+02, 0.38574200E+02, -.19851300E+02, -.92166800E+02, -.18171500E+02, -.68463700E+02, -.40876200E+02, 0.84592300E+02, 0.10786300E+03, 0.65311800E+02, -.46806400E+02, 0.52232000E+02, -.52352600E+00, -.16525700E+02, -.36354000E+02, -.57359900E-01, -.27449600E+02, 0.11736600E+02, -.53784600E+01, 0.27003600E+02, 0.15019800E+02, 0.29659600E+02, -.16780700E+01, 0.80614800E+01, -.14858500E+02, 0.28654100E+02, -.38161200E+02, -.22686300E+02, 0.14077300E+02, 0.45555800E+00, 0.14478500E+02, -.94894400E+00, -.45557000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.99821700E+00, -.95484800E+01, -.12262200E+02, -.84451300E+01, 0.54301200E+01, -.93145000E+01, 0.67105500E+01, 0.45712200E+00, 0.12317900E+02, 0.70233200E+01, -.63656300E+00, -.28338100E+01, 0.14224900E+02, 0.68159200E+01, 0.17480700E+01, 0.45601500E+01, -.60194400E+01, 0.37438100E+01, -.30889100E+01, 0.46936400E+01, -.21183200E+00, -.13524500E+00, -.13318300E+02, -.54638400E+00, -.34764000E+01, -.85735900E-02, -.21734400E+01, 0.10550400E+01, -.24094000E+01, 0.69607700E+00, -.85178200E+00, 0.20323800E+01, -.11601400E+01, -.81165400E+00, 0.41080400E+01, 0.14578400E+00, -.91517500E-01, -.83557900E+00, 0.14518500E-01, 0.99400300E+00, -.12328200E+01, -.80254700E+00, 0.32150800E+00, -.12674500E+00, 0.50170200E+01, -.14311200E+01, 0.20401600E+01, -.11632300E+00, -.31820100E+00, 0.49103400E+00, 0.63385900E+00, 0.53817100E+00, -.93620800E+00, -.70012900E+00, -.79362100E+00, 0.33186200E+00, 0.54474000E+00, -.61902200E+00, -.78111300E-02, 0.96077600E+00, -.17346300E+01, -.23562400E+01, 0.24670300E+01, 0.50119200E+00, 0.15645000E+01, -.88280900E+00, 0.13181400E+01, 0.19829200E+02, 0.17862700E-01, -.79659300E-01, 0.92601400E+00, 0.13420200E+01, 0.99415000E-01, 0.84198100E+00, 0.18897400E+00, 0.17569200E+01, -.29194200E+01, -.10898900E+01, -.43415700E+00, 0.37949000E+00, 0.82247600E-01, 0.80879600E+00, 0.64092200E+00, 0.37515900E+00, 0.14683200E+01, -.20814600E+01, 0.78262200E+00, 0.30679500E-01, 0.11049100E+01, 0.15715000E+01, 0.12490300E+01, 0.55820300E-01, 0.66948600E+00, -.86436100E+00, 0.42266900E+00, 0.87093800E-01, -.64431200E+00, 0.39176600E+00, -.23295300E+01, -.40962200E+00, 0.24600700E+00, 0.46916300E+00, 0.84140700E-01, 0.33973600E+00, 0.86670500E+00, -.29472300E+00, -.28530900E+00, 0.27954300E+00, 0.12949500E+01, -.95056400E-01, -.11626000E+01, 0.75042400E+00, 0.39253100E-01, -.21675700E+00, 0.37870300E+00, -.34065000E+00, -.31399700E+00, -.28252700E+01, 0.10898300E+00, -.12777400E+01, 0.14756600E+01, -.13777600E+00, 0.86201400E+00, -.27509900E+01, -.50810200E+00, 0.14520400E+01, 0.12243700E+02, 0.74018900E+00, -.12672400E+02, -.89411200E+00, 0.15864500E+01, -.47858300E+00, -.12743600E+01, 0.95519600E-01, -.42955200E-01, 0.21402600E+00, 0.41410400E+01, -.66400500E-01, -.21976000E+01, 0.70903600E+00, 0.67808900E+00, 0.48457200E+00, -.11434000E+00, -.26735700E+00, -.26327500E+00, -.44990000E+00, -.18624400E+00, 0.26670300E+00, 0.42890900E+01, 0.13686300E+01, 0.17232600E+03, -.18919300E+03, -.15057300E+01, 0.23347300E+03, 0.37450300E+03, -.18663100E+03, -.12040400E+03, -.18572700E+03, -.16609500E+03, -.12196300E+03, 0.76636600E+02, 0.13768200E+03, 0.61890300E+01, -.99603200E+02, -.17130100E+03, 0.24986200E+03, -.12699800E+03, 0.10897200E+02, -.11979300E+03, -.37668000E+02, -.65714700E+02, 0.10552300E+03, 0.13516900E+03, 0.93364400E+02, -.63115600E+02, -.39634100E+03, 0.52968100E+03, -.24783300E+03, -.49766000E+03, -.26528900E+03, 0.42685100E+02, 0.25245400E+03, -.14616600E+03, 0.19729500E+02, -.25068700E+03, 0.26195500E+03, -.34737400E+03, -.18718400E+03, 0.13715300E+03, 0.29452200E+02, 0.90830700E+02, -.59760400E+02, -.74703900E+02, 0.75217900E+02, -.58494700E+02, 0.12978900E+02, -.34736400E+02, 0.10143500E+03, -.37250700E+03, 0.18464900E+03, -.85253300E+02, 0.18837600E+03, 0.80566700E+02, 0.15301300E+03, 0.24596200E+03, 0.30697900E+03, 0.85587800E+02, 0.77269600E+02, -.26529600E+02, -.17709000E+03, 0.86683100E+02, 0.22003000E+03, 0.90850100E+02, -.18719400E+02, 0.52758600E+02, -.45805200E+02, -.94751800E+02, 0.21669700E+02, 0.39481200E+02, -.10075200E+02, 0.40491900E+01, -.20324900E+01, 0.75645100E+01, 0.79759300E+00, 0.13194400E+02, 0.15325600E+02, -.14054200E+02, -.13235300E+02, -.65877800E+01, -.24418800E+02, 0.80206400E+01, -.45534500E+00, -.62654900E+00, -.23281500E+02, -.25244300E+02, -.41423500E+00, -.66643800E+01, -.61902100E+02, -.29784500E+01, 0.38512800E+01, -.34375200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14054000E+00, 0.68941800E+00, 0.68770900E+00, -.18538300E+00, -.25492900E+00, 0.56961300E+00, -.79695200E+00, 0.16483800E+00, -.38358200E+00, -.65889400E+00, 0.49229800E-01, -.81991800E-01, 0.24541300E+00, -.33743400E+00, -.31585400E+00, 0.29584400E+00, -.71256600E+00, 0.97618500E-01, -.20554000E+00, -.55320300E+00, -.48010000E-01, -.92217000E-01, -.38013000E+00, -.33676100E-02, 0.15547200E+00, 0.43875900E-02, 0.14623700E-01, 0.10411600E+00, -.11756900E+00, 0.22134800E+00, 0.18547600E-01, 0.15211600E+00, 0.30781300E+00, 0.85057300E+00, -.13267500E+00, 0.17328600E+00, -.18162500E+00, -.15376800E+00, 0.42531200E+00, -.13369000E-01, -.19282200E+00, 0.47668900E+00, -.18729600E-01, 0.96095200E-01, -.12597800E+01, 0.29006900E+00, -.35310800E-01, 0.18098200E-01, -.20378800E+00, -.46187500E+00, -.38154600E-01, -.21644100E+00, -.71334300E+00, -.16230500E+00, -.71338600E-01, 0.81487400E-01, -.61375300E+00, 0.44543700E+00, -.10204400E+00, 0.20910400E+00, -.46231200E-01, 0.16001900E+00, -.37607500E+00, -.12321400E-01, 0.63988800E-01, -.32300100E+00, -.14010600E+00, -.89757000E+00, -.58555000E-01, -.45246600E-01, -.27010900E+00, -.69123000E-01, 0.43814500E-01, -.12130400E+00, -.27239700E+00, 0.80132600E+00, 0.62258300E+00, 0.26092200E+00, 0.52215100E-01, 0.33156200E-01, -.26840000E-01, 0.19291500E+00, 0.38668600E-01, 0.33349600E+00, 0.18755100E+00, -.32127600E+00, 0.22711400E+00, -.45264100E-01, 0.24002700E+00, 0.16220200E+00, 0.24179900E+01, -.62616500E-03, -.39758800E-01, -.28355000E-01, 0.96181300E-01, 0.12582300E+00, 0.43165000E+00, -.31581100E-01, 0.10147600E+00, -.23996100E-01, -.27732300E+00, 0.25491100E-01, 0.96530700E-02, -.51849900E-02, -.65054000E-01, 0.14753000E-01, 0.92685900E-01, -.30215900E-01, -.20999800E+00, -.18427500E+00, -.12561200E+00, -.21719400E+00, 0.18604600E+00, -.47378400E-02, -.37253800E-01, 0.16763400E+00, -.59243600E-02, -.22172100E+01, 0.15090700E-01, -.15104200E+00, -.40112400E+00, 0.79401200E-01, -.75317100E-01, 0.25208400E+00, -.20144500E-01, -.12652100E+00, -.19429200E+00, -.67113800E-01, -.59403000E+00, -.20112600E+01, 0.43257300E+00, 0.52496800E-01, 0.51025000E-01, -.32532200E-01, -.42720500E-01, 0.50774500E-01, 0.34789100E+00, -.16998000E+00, 0.32375200E+00, -.35332300E+00, -.17714200E+00, 0.51615600E+00, -.17822600E+00, 0.23959000E+00, -.79519900E-01, 0.11038200E-01, -.72832800E-02, -.85515700E-01, 0.57947300E+00, 0.94516800E-01, -.81653700E-01, -.56553100E+02, -.18246800E+00, 0.36180000E+02, 0.11219400E+03, -.56430200E+02, -.40616700E+02, -.56448800E+02, 0.66498400E+01, 0.27483900E+01, -.17555100E+02, 0.40452700E+02, -.17111500E+02, 0.38311100E+01, -.45850500E+02, 0.60442300E+02, -.30090800E+02, -.21440800E+02, -.29269700E+02, -.85467800E+00, 0.58336700E+01, -.11286800E+02, 0.46536600E+00, 0.13013200E+02, -.18354600E+01, -.52647100E+02, 0.23983400E+02, -.10678200E+02, -.59382700E+02, -.11736200E+02, 0.67975200E+02, 0.43820800E+02, -.53774600E+02, -.10720700E+03, -.42885700E+02, 0.47452200E+02, -.31321600E+02, -.39071600E+02, 0.25994600E+02, -.45317500E+01, 0.17999900E+02, -.53024400E+01, -.87153200E+01, 0.57750000E+01, -.30918500E+02, 0.92706700E+01, -.92984000E+01, 0.17992100E+02, -.11406800E+03, 0.57361300E+02, 0.17955200E+02, 0.57556800E+02, 0.27464600E+02, -.98546600E+01, 0.53729100E+02, 0.59773600E+01, 0.54809900E+02, -.15289400E+02, 0.28686800E+01, -.68631600E+01, 0.31697600E+01, 0.10053400E+01, 0.38891200E+01, -.19757100E+02, 0.79469300E+01, 0.26564500E+01, 0.12358100E+02, 0.90990600E+01, 0.31852200E+01, 0.74861300E+01, 0.69874000E-01, -.84034400E+01, -.41435600E+01, 0.36078200E+00, -.57168000E+01, 0.35575000E+01, -.37701800E+01, 0.56915000E+01, 0.57841900E+01, 0.45290400E+01, 0.10291600E+01, 0.17324600E+01, -.17863100E+01, 0.37944100E+01, -.76093700E+01, -.65549000E+01, 0.77886300E+01, -.10172600E+02, 0.49624900E+01, 0.30852000E+01, -.39465600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.60931100E-01, -.14494400E+00, 0.76140300E-01, -.27652700E+00, -.57685300E+00, 0.26818200E-01, 0.86819200E-01, 0.50374000E-01, 0.49897800E+00, 0.36648100E+00, -.68879800E-02, -.38505300E-01, 0.68389400E+00, -.18576400E-01, -.36345100E-01, -.14985100E+00, 0.23382300E+00, 0.45822400E-01, -.86177600E-01, -.10064200E+00, -.27880400E-01, -.32465300E-01, -.44338300E+00, 0.12236400E-01, -.92669800E-01, -.22923500E-03, -.59547200E-01, -.79016800E-01, 0.18439500E+00, -.48844000E-01, -.16657500E-01, -.10045100E+00, 0.63977400E-01, -.15860500E+00, -.48481000E-01, 0.17612500E-01, -.26917200E-01, -.21280000E-01, 0.13954600E-01, 0.21441500E+00, -.46359500E+00, -.89063500E-01, 0.11477200E-01, 0.17996300E-01, -.32682800E+00, 0.27889600E-01, -.36872300E-02, -.22919400E-02, -.29937100E-02, 0.12234200E+00, 0.15246900E-01, 0.10972000E+00, 0.26402100E+00, 0.21198100E-01, 0.21227600E+00, -.25817600E-01, -.87370700E-02, -.16108800E+00, 0.31499800E-01, -.15389500E-01, 0.67034400E-02, 0.37067900E-02, -.87611800E-01, -.18005800E-01, 0.80109000E-01, 0.61673300E-01, 0.25935300E-01, 0.12119000E+01, -.85202800E-02, 0.25266500E-03, 0.83164000E-01, 0.91733000E-01, 0.27614000E-01, 0.35614300E-01, 0.69015000E-01, 0.14553500E+00, -.19609300E+00, -.11544400E+00, 0.17499300E-02, 0.33998600E-01, 0.26370200E-01, 0.20887400E+00, 0.74636000E-01, -.25071600E-01, 0.11424400E+00, -.76776800E-01, 0.77800000E-01, -.84227200E-02, -.13831000E+00, 0.35552200E+00, -.25265600E+00, 0.77867300E-04, -.95694800E-01, 0.31729100E-01, -.40506800E-02, -.41324400E-01, -.12134900E+00, -.90279500E-03, 0.79093600E-01, -.83571400E-02, 0.20764100E-01, -.40869000E-01, -.68997000E-02, 0.20136700E-01, 0.39299400E-01, -.24079500E-01, -.13466000E-01, 0.35107500E-01, -.56829800E-02, -.25963900E-01, 0.15432400E+00, 0.43075300E-01, -.37755900E-01, 0.44562900E-02, -.25795000E-01, 0.68644400E-01, 0.94725600E-02, -.33594100E+00, 0.29215700E-02, 0.79204500E-02, -.40092000E-01, 0.12048800E-01, 0.39392800E-02, 0.29709000E-01, 0.86849500E-02, 0.73579100E-01, -.10549100E+00, 0.21325900E-01, 0.33145000E+00, 0.53289700E-01, -.98884000E-01, -.12130900E-01, -.25162000E-02, -.22707000E-02, 0.43317200E-02, -.13234300E-01, -.30095800E+00, 0.17531400E-01, -.83499100E-01, 0.51008700E-01, 0.14159800E-01, -.13855800E+00, 0.63308200E-02, -.67935000E-01, 0.31130700E-01, 0.20178500E-01, 0.73998200E-02, -.81965900E-01, -.78789500E-02, -.16030200E-03, 0.64877900E-02, -.12250900E-01, 0.19601300E+01, 0.25097600E+00, -.13644600E+02, 0.68031100E+01, 0.32223000E+01, 0.71955000E+01, -.33587000E+00, -.80496500E+00, 0.48938000E+01, -.23657500E+01, 0.40422300E+01, 0.64184200E+00, 0.38719100E+01, 0.25223300E+02, -.12536900E+02, -.48974700E+01, -.12333900E+02, -.26740600E+01, -.43861300E+01, -.78978800E+01, -.38028300E+01, -.25875900E+01, -.62124300E+01, -.74602700E+01, -.10858300E+02, 0.48967500E+01, -.54457000E+01, 0.53198700E+01, 0.32208700E+01, 0.36450400E+01, -.12949500E+01, -.11487500E+02, 0.90088700E+01, 0.87407500E+00, 0.78364800E+01, -.13145400E+02, 0.61454900E+01, 0.65104100E+01, 0.68492200E+01, 0.45750100E+01, 0.33300200E+00, -.12285100E+00, -.39578200E+01, 0.54959500E+01, -.15526500E+00, -.79334700E+00, 0.68909400E+01, -.33319500E+01, 0.39468400E+00, -.34149600E+01, -.31829000E+01, 0.20552500E+01, -.49289600E+01, -.95709800E+01, 0.13368400E+01, -.66167800E+00, -.22098600E+01, 0.87509700E+01, -.44484800E+01, -.25506000E+01, -.42781100E+01, -.93621200E-01, 0.93175800E+00, -.25942600E+01, -.18943800E+01, -.26513100E+01, -.17069700E+00, 0.23760800E+01, 0.79972800E-01, 0.20832400E+01, -.61401700E+00, 0.50305300E-01, 0.24696700E+00, -.30707300E+00, 0.16140500E+00, -.20222800E+00, 0.15343300E+01, 0.33787700E+00, -.50361800E+00, -.11147500E-01, 0.26870300E+00, 0.36167600E+00, 0.18780800E+00, 0.31252600E+00, -.15274500E+01, 0.80195400E+00, 0.71071600E+00, -.34878100E+00, -.61486900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.85223300E+00, -.17209000E+01, -.58465900E+01, -.29908800E+01, -.30850300E+01, 0.10380200E+01, -.13613600E+01, 0.70701900E+00, 0.10361300E+01, 0.18467100E+01, 0.45618300E+00, 0.54597400E+00, 0.40075400E+01, -.27019000E+01, -.18304500E+01, 0.20246000E+01, -.14573400E+01, -.83385600E+00, -.13522100E+01, 0.29991400E+00, -.15254400E+00, -.15127700E+00, 0.22332900E+01, 0.63501600E+00, 0.18539800E+00, 0.56196900E-02, 0.38802600E+00, -.13077900E+01, 0.57033900E+01, -.12755200E+01, -.37842400E+00, -.40339800E+01, 0.14470800E+01, 0.10297900E+00, -.42735700E+01, -.17513500E+00, -.23621800E-01, 0.58816700E+00, 0.35549000E+00, -.15392200E+01, -.30754600E+00, 0.33602200E+01, -.72834200E+00, 0.68807400E+00, -.30169900E+01, 0.11637500E+01, -.36726700E+01, 0.42365700E-01, -.25935100E+01, -.45510700E+01, -.10759000E+01, -.18377900E+01, -.12408700E+01, 0.52150500E+00, 0.85108700E+00, 0.49560200E+00, -.69144000E+01, 0.48108900E+01, -.46056600E+00, 0.17877900E+01, 0.13226500E+01, -.13162800E+01, -.44471600E+01, -.16138900E-01, -.42620400E+00, -.15940100E+01, -.10606700E+01, -.28687300E+02, -.33963200E+00, -.27791400E-02, -.95443100E+00, -.57410500E+00, -.54038900E-01, -.16115800E+01, -.11069100E+01, 0.23208500E+01, 0.15795500E+01, 0.26845100E+01, -.12625500E-02, -.35063500E+00, -.21978300E+00, -.18182300E+01, -.15052600E+00, -.30023200E+00, 0.80937500E-02, -.10056900E-01, -.34190700E+00, 0.12991300E+00, 0.45249500E-01, 0.32262900E+00, -.24788300E+01, 0.16757000E-01, 0.43643500E+00, -.48394000E+00, 0.53692900E-01, 0.77951600E+00, 0.21075600E+00, 0.49146100E-01, -.19656200E+00, -.15627500E+00, 0.23780300E+00, 0.24395500E-01, -.11801200E-01, 0.80327800E-01, 0.20176100E+00, -.32521300E-01, -.65491900E-01, 0.52003200E+00, 0.61792200E+00, 0.73712700E+00, -.41783800E+00, 0.47432500E+00, -.52286000E+00, -.16604900E-01, 0.10101000E+00, -.41539400E+00, -.16614500E+00, 0.17907900E+01, -.15441500E-01, -.49195600E+00, 0.16823200E+01, 0.42692500E+00, -.81965200E-02, -.53368600E-01, -.54554800E-01, -.63947400E-02, 0.18715200E+01, -.88353900E-01, -.16018800E+01, -.72967400E+01, -.51705000E+00, -.31356100E-01, -.14965700E+00, -.46626500E-01, -.74381300E-01, -.84960300E-02, -.21749100E+00, -.20701100E+00, -.53557200E+00, 0.12126800E+00, -.19206900E+00, 0.93299000E+00, 0.44633100E+00, -.83269400E+00, 0.19849500E+00, -.21230100E-01, 0.44275900E-01, 0.75784700E+00, -.65507100E+00, -.25247900E+00, -.17549700E+00, 0.56660200E+00, 0.20925400E+01, 0.76597600E+02, 0.34738200E+03, -.17186700E+03, -.16508900E+03, -.17870800E+03, -.20964500E+03, -.98316600E+02, -.23734300E+01, 0.41844500E+02, -.36147700E+02, -.97906900E+02, -.14823900E+03, -.17006000E+03, 0.82708600E+02, 0.97897900E+02, 0.79150700E+02, -.55606500E+01, -.36420300E+02, 0.19189500E+03, 0.19987500E+03, 0.10795800E+02, -.25880300E+02, -.83928200E+02, 0.53849200E+03, -.27405800E+03, -.34236600E+03, -.26942800E+03, -.12928600E+03, 0.12726400E+03, -.11583700E+03, 0.15948600E+03, -.28096000E+03, 0.14529800E+03, -.13183200E+03, 0.14622500E+03, -.68868600E+02, 0.60228800E+02, -.74066000E+02, -.17007600E+02, -.36078100E+02, 0.25366900E+02, 0.49335300E+02, -.10240400E+03, -.15200800E+01, -.38392200E+02, -.28087700E+03, 0.14050500E+03, -.47385100E+02, 0.13922000E+03, 0.51965100E+02, 0.22243100E+03, -.97375400E+01, 0.12787500E+03, -.12766600E+03, 0.19760800E+03, 0.51202800E+02, -.13717300E+03, 0.67141600E+02, 0.16936300E+03, 0.66382400E+02, 0.14954100E+02, -.19603500E+02, 0.22747000E+02, -.21409600E+02, 0.20438600E+02, -.11754500E+02, -.46788100E+02, 0.26654500E+01, 0.56422400E+01, 0.36764400E+02, -.43643200E+00, 0.26467400E+02, -.76979300E+01, -.73276000E+01, -.27010000E+02, -.20727800E+02, -.29998400E+02, 0.84412000E+01, 0.31301900E+00, -.48040000E+01, -.29949800E+02, 0.33640700E+02, 0.50974800E+01, -.75086000E+01, -.27364400E+02, -.13648400E+02, 0.19343900E+02, -.53762100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18484900E+00, 0.47600400E+00, -.73072600E+00, -.22938900E+00, -.10831100E+01, 0.35076600E+00, -.97684200E+00, 0.12977700E+00, 0.41518000E+00, 0.34612700E+00, -.16487200E+00, 0.14182400E+00, 0.32425300E+00, 0.15591400E+00, -.10799800E+00, 0.30274800E+00, -.11920500E+01, 0.83243900E-01, -.21879500E+00, 0.19408100E+00, -.27011800E-01, -.59938000E-01, -.23131800E+00, 0.44339700E-01, -.28779500E+00, -.63802900E-03, -.88735700E-01, 0.19320500E-02, 0.41093900E+00, 0.17145000E+00, -.34266200E-01, -.22101600E+00, 0.24585100E+00, -.66325200E+00, 0.12915100E+00, 0.15798200E+00, -.70660900E-01, -.20071800E+00, 0.18609500E+00, 0.38208400E+00, -.75324700E+00, 0.39020300E+00, -.40875000E-01, 0.14603200E+00, 0.11572800E+01, -.11313000E+00, -.59549800E+00, -.17937900E-01, -.68134000E+00, -.83761600E+00, 0.24652400E+00, -.45982000E+00, -.77414900E+00, 0.52971200E-01, 0.48199700E+00, 0.10547500E+00, -.10776800E+01, 0.41313600E+00, -.95852900E-01, 0.28498000E+00, 0.20040400E+00, -.96044300E-01, -.54024900E+00, 0.82878200E-01, 0.22390300E+00, -.36067900E+00, 0.28445300E-02, -.39341700E+01, 0.38214500E-01, -.77872400E-03, -.14478800E+00, -.29610100E+00, -.20397100E-01, -.56248000E-01, -.16611200E+00, 0.60832600E+00, 0.46481600E+00, 0.17887200E+00, 0.38628600E-01, -.82590100E-02, -.32108100E-02, -.20027200E+00, 0.30221000E+00, -.10891700E+00, 0.25818800E+00, -.49486100E+00, -.38887000E-01, 0.11000900E+00, -.33495600E+00, 0.26504100E+00, -.17583400E+00, 0.37817200E-01, 0.32713900E+00, 0.54407500E-02, 0.11189900E+00, 0.47363300E+00, -.72509100E-01, -.84552100E-02, 0.34933600E+00, -.20411600E+00, 0.35862500E+00, -.13860900E+00, -.37288700E-01, -.52119600E-01, 0.23519900E+00, -.56581600E-01, -.94066700E-01, -.44434800E+00, 0.25385600E+00, 0.79897000E+00, 0.99775100E-01, 0.43372700E+00, -.28711400E+00, 0.36877800E-01, 0.16534300E+00, 0.56600600E-01, -.71764300E-01, 0.44648700E-01, 0.16306800E-01, 0.49527800E-01, 0.30554100E+00, 0.78567800E-02, 0.10562500E+00, -.48024500E+00, 0.13209600E-01, 0.12783400E+00, 0.28718400E+01, 0.11151900E+00, -.40218900E+00, -.75768500E+00, -.56518100E+00, -.21130600E+00, -.61429400E-01, 0.22774100E-02, 0.67862000E-02, -.81631900E-01, -.21057900E+00, 0.87500900E-01, -.66520200E-01, 0.20566000E+00, 0.11639100E+00, -.21671400E-01, 0.27673200E+00, -.35590300E+00, 0.84667500E-01, -.10040200E-01, -.67394700E-02, 0.32654000E+00, -.44296000E+00, -.56287900E+00, -.32733500E-01, 0.15261100E+00, 0.13131900E+01, -.14581100E+00, 0.16240000E+03, -.80995600E+02, -.11039200E+03, -.83584800E+02, -.11102800E+03, -.39790500E+02, -.65736700E+01, 0.32403500E+02, -.16156700E+02, -.37209600E+02, -.49597900E+02, -.13593900E+03, 0.68185000E+02, 0.40802800E+02, 0.64612700E+02, -.84444300E+01, -.22872400E+02, 0.10108700E+03, 0.89207200E+02, 0.30454800E+02, -.17345700E+02, 0.54247400E+01, 0.21891600E+03, -.11197700E+03, -.16257200E+03, -.10916500E+03, -.71327900E+02, 0.36858700E+02, -.40434700E+02, 0.57752700E+02, -.96735100E+02, 0.39707400E+02, -.67477800E+02, 0.17479100E+03, -.87392800E+02, -.90838800E+01, -.87350500E+02, -.30419400E+02, -.19511400E+02, -.21645500E+02, 0.12047000E+02, -.66034600E+02, -.65393100E+01, -.31464600E+02, -.99064600E+02, 0.49195200E+02, -.17561000E+02, 0.48664400E+02, 0.34189400E+02, 0.10805400E+03, -.61171600E+01, 0.49280900E+02, -.69199200E+02, 0.10304500E+03, 0.21956100E+02, -.65385400E+02, 0.32479300E+02, 0.45441100E+02, 0.31374500E+02, -.46283400E+00, -.27272100E+02, 0.40499000E+02, 0.13863200E+02, 0.30743500E+02, -.22123700E+02, -.12437800E+01, 0.11994200E+01, -.36627200E+01, 0.17776200E+02, -.16786900E+00, 0.15877900E+02, 0.46661500E+00, -.66483300E+01, -.16108000E+02, -.73354400E+01, -.15565100E+02, 0.43691100E+01, 0.26568200E+01, -.72643200E+01, -.16180300E+02, 0.18219500E+02, -.54094700E+01, 0.23532300E+01, -.65012000E+01, -.42751400E+01, 0.10747000E+02, -.39129800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.78302400E+00, -.65965900E+01, -.90494800E+01, -.57969500E+01, 0.20919900E+01, -.56594000E+01, 0.24168200E+01, 0.31301100E+00, 0.69630000E+01, 0.45756500E+01, 0.23311600E-01, -.19512100E+01, 0.83735500E+01, 0.35977800E+01, 0.14392200E+01, 0.22801100E+01, -.22726800E+01, 0.28549900E+01, -.29683300E+01, 0.35777000E+01, -.43662900E-01, 0.50937700E-01, -.93543800E+01, -.62766700E+00, -.20673700E+01, -.62004500E-02, -.14030000E+01, 0.46142700E+00, -.17768400E+01, 0.14072900E+01, -.92941300E-01, 0.15915000E+01, -.32962400E+00, -.10899600E+00, 0.23546100E+01, 0.28512700E+00, -.21141900E+00, -.25416500E+00, 0.17631000E+00, -.72564400E+00, 0.17055100E+01, -.55952100E+00, -.10241400E-01, -.33540200E+00, 0.21289200E+01, -.33767100E+00, 0.24183200E+01, -.12036500E+00, 0.15487400E+01, 0.18066700E+01, 0.17772300E+00, -.14008400E-01, -.22275600E+00, 0.12364500E+00, -.15426200E+01, 0.26768200E-01, 0.51053000E-01, -.34142800E+00, 0.42401700E-01, -.14913500E+00, -.73502700E+00, -.11484300E+01, 0.14452600E+00, -.13814900E+00, 0.43980600E+00, 0.33647100E+00, 0.99404500E+00, 0.47437700E+01, 0.21541400E+00, -.86542600E-01, 0.60751800E+00, 0.15995100E+00, -.18985400E+00, 0.51075800E+00, 0.75923700E+00, -.23244200E+00, -.14249000E+01, -.35144900E+01, -.71257000E+00, -.26096200E+00, 0.19738800E-02, -.63190300E-01, -.28747500E+00, 0.38507300E-01, -.48503300E+00, 0.16051100E+01, -.41245300E+00, -.96760100E-01, 0.63064000E+00, 0.24199500E+00, 0.37537700E+01, 0.14991700E-01, 0.56197000E+00, 0.95759200E-01, 0.11580200E+00, 0.71224800E+00, 0.15769300E+01, -.40803300E+00, 0.54018000E+00, 0.21068500E+00, -.20509200E+00, -.58989100E-01, 0.13023200E+00, -.31276600E-01, 0.80988400E-01, 0.23101100E+00, 0.48328200E+00, -.34290300E+00, -.67621000E+00, 0.92377300E+00, 0.14495200E+01, 0.10730800E+01, 0.43026500E+00, -.79368000E-01, -.79209400E-02, 0.58177800E+00, 0.18477900E+00, -.96001100E+01, 0.41654200E+00, -.49986800E+00, -.43193700E+00, -.17914800E+00, 0.75238600E+00, 0.49784300E-01, -.10965500E-01, 0.14114900E+01, -.11347900E+02, 0.30657400E+00, 0.41717500E+01, -.15185200E+01, 0.44088400E+00, 0.11022300E+01, -.49852700E+00, -.30439600E+00, 0.12989800E+00, 0.24183900E+00, 0.11394300E+01, -.54577200E+00, -.55205900E+00, 0.18285300E+00, 0.47165300E+00, -.12545300E+01, 0.41562700E+00, -.44869800E+00, 0.12320100E+00, -.66498100E-01, -.50885100E-01, 0.36693400E+00, 0.22082700E-01, -.40017300E+00, 0.67860100E-01, 0.21817800E+00, 0.78455700E+00, -.13290000E+00, -.75025400E+00, 0.13241100E+02, -.26459700E+02, -.14214700E+01, -.16005600E+03, -.80944000E+02, 0.38499500E+02, -.39111400E+02, 0.30037600E+02, -.74825100E+02, -.41411900E+02, -.65518900E+02, 0.36922200E+02, 0.47477400E+02, 0.30190800E+02, -.56993100E+02, -.95682100E+02, 0.16124000E+03, 0.13915400E+03, -.12503100E+02, -.64850100E+02, -.10867200E+03, 0.47000600E+03, -.24764000E+03, -.26871500E+03, -.23562200E+03, -.16369800E+03, 0.14224000E+03, -.21536900E+02, 0.28466500E+03, -.13103800E+03, 0.11313100E+03, -.28125800E+03, 0.19466200E+03, -.10148600E+03, 0.34455700E+02, -.96891800E+02, -.48142600E+02, -.52494600E+02, 0.30195600E+02, 0.87942800E+02, -.75927500E+02, -.23478000E+02, -.41734600E+02, 0.82320800E+02, -.44062500E+02, -.10266700E+03, -.41980700E+02, -.21897800E+01, 0.25503300E+03, -.69485600E+02, 0.13567800E+03, -.18087800E+03, 0.19390000E+03, -.64101300E+02, -.35719800E+02, 0.18988000E+02, 0.90646600E+02, 0.16798100E+02, -.55344400E+01, -.58116900E+02, 0.51876500E+02, 0.11637200E+02, 0.55328400E+01, -.52539600E+02, -.37984700E+02, 0.19181900E+01, 0.22554200E+02, 0.35165000E+02, -.19193600E+01, 0.34464700E+02, -.92918100E+01, 0.26110900E+01, -.35244200E+02, -.37725700E+02, -.28235800E+02, 0.16495100E+01, -.27554200E+01, -.23191600E+01, -.25313700E+02, 0.35349500E+02, 0.14653300E+02, -.24739700E+02, -.14114000E+02, -.25776000E+02, -.23268400E+01, -.32713300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25754200E+00, -.14042800E+01, -.15223700E+01, 0.16697800E+00, 0.78034600E+00, -.12651500E+01, 0.24512400E+01, -.12978600E+00, 0.42740400E+00, 0.18955000E+01, 0.33640800E+00, -.18278900E+00, 0.19111100E+01, 0.42635000E+00, 0.21620100E+00, 0.41194400E+00, -.79088400E+00, 0.33055300E-01, -.36001900E+00, 0.12383600E+00, 0.64186300E-01, -.19624800E+00, -.10742500E+00, 0.19447800E+00, 0.43284500E+00, 0.20943500E-02, 0.20916200E+00, 0.34076800E+00, -.76627200E+00, 0.17019000E+00, -.60103300E+00, 0.41345000E+00, -.32765900E+00, 0.85414100E+00, -.63343700E-01, -.10438300E-01, -.10735400E+00, -.86918300E-01, 0.19914900E+00, 0.14133600E+00, -.30924400E+00, 0.44664300E+00, -.53138900E-01, -.19959500E+00, -.15811700E+01, 0.51381800E+00, -.16122400E+00, -.43283900E-01, 0.32172300E+00, 0.28087100E+00, -.58981800E-01, 0.39732200E+00, 0.48618100E+00, 0.80937000E-01, -.33004600E+00, -.15387100E+00, 0.65788100E-01, 0.35385600E+00, 0.11610000E+00, -.45580200E-01, -.61067200E-01, -.29974600E+00, 0.13834500E+01, -.66598200E-01, -.28355300E+00, 0.25067900E+00, 0.27179900E-01, 0.21378200E+00, 0.12023300E+00, -.57770700E-02, 0.22239600E+00, 0.16594100E+00, -.17626700E+00, 0.14413900E+00, 0.92553900E-01, 0.21627700E+00, -.86597400E+00, -.88994400E+00, 0.21876500E-01, 0.10569700E+00, 0.20134900E-01, 0.38268700E-01, 0.17962700E+00, 0.92913600E+00, -.29221300E+00, 0.42686200E+00, 0.21108500E+00, -.11039900E+00, 0.25756800E+00, 0.53281400E+00, 0.11274600E+01, 0.42862700E-02, 0.38184000E+00, 0.46235500E+00, 0.26388600E+00, 0.90834000E-01, -.12571800E+00, 0.63359800E-01, -.16609700E+00, -.43327300E-01, -.90608900E-01, 0.15461600E+00, 0.38801500E-01, 0.60627800E-01, -.13338200E-01, 0.67049400E-01, -.12309800E+00, 0.25793300E+00, -.27777500E+00, -.49209000E+00, 0.64765400E+00, -.21980400E+00, -.13118100E+00, -.80394300E-01, -.34852800E-01, -.23240600E+00, 0.16275700E+00, -.53315100E+01, 0.67504500E-01, -.54871000E+00, -.83449800E+00, -.50444300E+00, -.16688600E+00, 0.33414700E+00, 0.57045500E-02, 0.70724400E+00, -.46049500E+01, 0.12308300E+00, 0.18728300E+01, 0.53334500E+01, 0.69410100E-01, 0.15915400E+00, -.19940200E-02, 0.10384800E+00, 0.57779200E-01, -.77009300E-02, -.10888800E+01, 0.22950100E+00, -.52429400E-01, 0.19471200E+00, -.11927900E+00, -.71273700E+00, -.44683800E-01, 0.19875300E+00, -.51488600E-02, 0.66826500E-01, 0.14304100E-01, -.14778400E+00, -.24390500E+00, -.62500800E-01, -.98987700E-01, 0.14204500E+00, -.70745500E+00, -.30907600E-02, -.11648700E+01, 0.29304000E-02, -.61923900E+02, -.16061200E+01, -.11619600E+03, -.31609400E+02, 0.18503400E+02, -.24062500E+02, 0.58584200E+01, -.29224000E+02, -.82589000E+01, -.16977200E+03, 0.87635300E+02, 0.27638500E+02, 0.82420400E+02, -.13459100E+02, -.50030000E+02, 0.11943800E+03, 0.87978500E+02, 0.54038700E+02, -.28313100E+02, 0.16179800E+02, 0.90890900E+02, -.49540200E+02, -.74490400E+02, -.44729900E+02, -.22279900E+02, -.16005600E+02, 0.62639600E+02, 0.20241900E+03, 0.25872900E+02, -.30624500E+02, -.34944000E+02, 0.66231600E+02, -.31680300E+02, 0.37931600E+02, -.32666400E+02, -.36091200E+02, -.23867000E+02, 0.18520600E+02, 0.40302200E+02, -.23483500E+02, -.69141900E+01, 0.28981700E+00, 0.18926100E+02, -.12724200E+02, -.42932200E+02, -.10075500E+02, -.55226800E+01, 0.90894300E+02, -.34643700E+02, 0.15803500E+02, -.73521200E+02, 0.79991500E+02, 0.85775900E+02, -.15932100E+02, 0.93536000E+01, 0.44250500E+02, 0.70157300E+01, -.15444200E+02, -.45304600E+02, 0.46336100E+02, 0.43051500E+02, 0.42823800E+02, -.40777600E+02, -.30483900E+02, 0.14583700E+01, 0.36536600E+00, 0.16818900E+02, -.13335500E+01, 0.20686400E+02, -.24398100E+01, 0.23823000E+01, -.21045400E+02, -.20074400E+02, -.17343400E+02, 0.32834900E+01, -.29311600E+00, -.80363900E+01, -.15506300E+02, 0.17483100E+02, -.60809100E+00, -.69314600E+01, 0.58324700E+01, -.13387600E+02, -.37766800E+01, -.22186100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.78047100E+00, -.96626200E+00, -.49444100E+01, -.37912200E+01, -.63405700E+01, 0.39071900E+01, -.73504600E+01, 0.11151200E+01, -.13613100E+01, -.42109000E+00, 0.26894300E+00, 0.65405300E-01, 0.13206900E+00, 0.47095000E+00, 0.30132900E+00, -.93567900E+00, 0.95111900E+00, 0.40909400E+00, -.87478500E+00, 0.35469000E+00, -.25064000E-02, -.68780400E-01, -.14485200E+01, -.19894000E+00, -.34906100E+00, -.22064800E-02, -.25932000E+00, -.46362200E+00, 0.11639900E+00, 0.30966900E+00, 0.28607200E+00, -.56172600E-01, 0.13641200E+00, -.14406100E+00, -.31416200E+00, 0.10084600E+00, -.39314200E-01, 0.23765300E+00, 0.36002600E-01, -.76908600E+00, 0.17525700E+01, 0.13162500E+00, -.10076600E+00, -.17161000E+00, 0.33966200E+00, -.58485500E-01, 0.46889100E-01, 0.40010900E+00, 0.16150200E+01, 0.12997900E+01, -.40042500E+00, -.23075900E+00, 0.15331700E+01, 0.63788200E+00, -.12816000E+01, -.48562700E+00, 0.99126800E+00, -.55290900E+00, -.28113900E+00, -.75720100E+00, 0.41508400E-02, 0.16275000E+01, -.15377100E+01, -.72252500E+00, -.11010200E+01, 0.41140300E+00, 0.41400400E+00, 0.55720100E+00, -.12378600E-01, -.25984700E+00, -.14530300E+00, -.31267100E+00, -.18382500E+00, 0.17044500E+00, 0.74598600E+00, -.22106100E+01, 0.11175000E+01, -.59014500E+01, -.85376700E-01, -.31511400E+00, -.18809000E+00, -.97571000E-01, -.39819400E+00, -.33016700E-01, -.66902900E+00, 0.46053500E+01, -.21176500E+01, 0.96407600E-01, 0.32143200E+00, -.82344000E+00, 0.32880000E+01, 0.69879100E-01, 0.12323900E+00, 0.23094400E+00, -.21015500E+00, 0.48009300E+00, 0.19196100E+01, -.44754900E+00, 0.10620800E+01, 0.80849800E+00, -.57981200E+00, 0.85275500E-01, 0.75177700E-01, -.13391800E+00, -.13002300E+01, 0.37522900E+00, 0.54685200E+00, -.42033000E+00, -.10562800E+01, 0.39659100E+00, 0.97481900E+00, 0.57251400E-01, 0.52620200E+00, -.57339200E-01, -.35214000E+00, 0.94595900E+00, 0.22623700E+00, -.47101000E+01, 0.19282100E+00, 0.17329300E+00, -.51784100E+00, 0.54088000E+00, 0.18627700E+00, 0.16927500E+01, 0.96642500E-01, -.97888000E-02, -.14085100E+02, -.77355500E-01, 0.64308600E+01, -.64533000E+01, 0.77563000E+00, 0.10540700E+01, -.79173000E-01, -.28195200E+00, -.31112900E-01, 0.68024200E-01, -.48803000E+00, -.65963500E+00, 0.11586000E+01, -.36379100E+00, 0.47849900E-01, -.73011700E-01, 0.97898200E-01, -.17644500E+00, 0.15283000E+00, 0.43808700E-01, 0.35832500E-01, -.88547000E-02, -.72130200E+00, -.51308600E+00, -.25317400E+00, 0.63659700E+00, 0.49154100E+00, -.28491000E-01, -.11042200E+01, -.10397000E+00, 0.47113700E+00, 0.30221500E+02, -.11786700E+03, -.50914500E+02, 0.15183100E+01, -.45550300E+01, 0.71315700E+01, -.48452500E+02, -.52365800E+01, -.12578500E+03, 0.66804600E+02, 0.70143200E+02, 0.66774700E+02, -.18979300E+02, -.30014300E+02, 0.11659000E+03, 0.11815300E+03, -.66150800E+01, -.22532200E+02, -.35558700E+02, 0.32013700E+03, -.16612000E+03, -.19871600E+03, -.16006300E+03, -.11419300E+03, 0.81439600E+02, -.39232000E+02, 0.12776400E+03, -.13874900E+03, 0.77690600E+02, -.13856000E+03, 0.74173800E+02, -.34753300E+02, 0.52169100E+02, -.34220700E+02, -.10836300E+02, -.25835500E+02, 0.31042000E+02, 0.39994700E+02, -.51843900E+02, -.76717700E+01, -.66425700E+01, 0.67084800E+01, -.51930100E+01, -.80012100E+02, -.69920000E+00, 0.26766700E+02, 0.15574600E+03, -.37373900E+02, 0.10684000E+03, -.12507800E+03, 0.12878600E+03, -.49382100E+02, -.78817800E+02, 0.40314500E+02, 0.90848900E+02, 0.41671600E+02, 0.15179100E+02, -.22264200E+02, 0.36097500E+02, 0.70709700E+01, -.12130200E+02, -.13294400E+02, -.17890800E+02, 0.13580600E+01, 0.79712000E+01, 0.25434900E+02, -.83213600E+00, 0.22571600E+02, -.58674400E+01, -.11339500E+01, -.23055100E+02, -.17397600E+02, -.19828800E+02, 0.27787000E+01, -.78204500E+00, -.47253700E+00, -.19067800E+02, 0.26031800E+02, 0.27062200E+01, -.67383100E+01, -.11994500E+02, -.10968500E+02, 0.61149300E+01, 0.37364200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25971600E+00, 0.12849300E+01, 0.40895600E+01, 0.22360300E+01, 0.32510900E+00, -.31226500E+00, 0.12768900E+01, -.20368100E+00, 0.28225700E+01, 0.69528100E+00, -.32330200E+00, -.57693900E-01, 0.84538000E+00, -.20033800E+00, 0.93774400E-01, 0.93900600E+00, 0.17122800E+00, -.85512600E+00, 0.15826100E+00, -.16546900E-01, 0.12577500E-01, 0.15448800E+00, 0.29623500E+00, 0.28944700E-01, 0.22552000E+00, 0.66405400E-03, 0.35668600E-01, -.45127200E-01, 0.61540600E+00, -.16660100E+00, 0.56621500E+00, -.10358800E+01, 0.57792800E+00, 0.24375100E+00, -.27560200E+00, 0.40364000E+00, -.93416300E-01, 0.13581000E+00, -.17972300E-01, -.82358700E+00, 0.60594800E+00, -.73011800E+00, -.65691000E-01, -.13156500E+00, -.12167900E+01, 0.99269900E-01, -.34003700E+00, 0.86069200E-02, 0.73766100E+00, 0.27857400E+00, 0.81238400E-01, 0.58479900E+00, 0.31453300E+00, -.79847300E+00, -.15216200E+00, -.41216200E+00, 0.17494700E+01, -.21020600E+01, 0.16390500E+00, -.43641600E+00, -.81057000E+00, 0.27459100E+00, 0.53517200E+00, 0.16620300E+00, 0.96868400E+00, 0.15158600E+00, 0.21036800E-01, 0.99482600E+01, 0.20997900E-01, -.22135900E-02, 0.13473600E+00, 0.42398500E+00, 0.39717500E+00, 0.22262700E+00, -.72871200E+00, 0.93875700E+00, 0.30461300E-01, 0.24336700E+01, 0.21916600E+00, -.12575100E+00, 0.28084800E-01, 0.61874000E+00, -.11289900E+00, -.15501800E+00, -.33922900E+00, -.82998800E+00, 0.35526300E+00, -.12470400E+00, -.31875100E+00, 0.75095800E+00, -.16362500E+00, -.38205700E-01, -.76062200E-01, 0.12759300E+00, -.33784000E-01, -.59261500E-01, -.74176200E+00, 0.11922600E+00, -.10191000E+01, -.10217500E+00, -.16123800E+00, 0.30148100E+00, 0.21205500E-02, 0.93105100E-01, 0.31268200E+00, 0.19485700E+00, -.69304000E-01, 0.18225300E+00, 0.10605400E+01, 0.29333300E+01, 0.46813300E+00, 0.52342600E+00, 0.20008900E+00, 0.91933200E-01, 0.84851900E-01, 0.96198700E+00, -.62653700E-01, -.67255000E+01, 0.85509500E-01, -.10639600E+01, -.18907500E+00, -.44002500E+00, -.45729300E+00, -.49562300E+00, 0.14956000E+00, 0.15719300E+01, -.13816500E+01, 0.67835100E-01, -.21332900E+01, 0.17360600E+02, -.36349900E+00, -.71549000E-01, 0.37360800E+00, 0.94657900E-01, 0.20336700E+00, -.17155700E+00, -.55016200E+00, 0.50321000E+00, 0.42709300E+00, -.65657100E+00, -.33602900E+00, 0.51692900E+00, -.48553000E+00, 0.24708800E+00, -.32717200E+00, 0.22929400E+00, 0.94837400E-01, -.53475300E+00, -.23081400E+01, -.67981800E+00, 0.60686400E-02, -.24284500E+01, -.29491200E+01, -.13515400E+00, 0.15046700E+01, -.18347800E+00, -.36302700E+00, 0.12943400E+00, 0.19596700E+03, 0.64199400E+02, -.32717200E+02, 0.24348800E+01, 0.77960700E+01, 0.82759200E+02, -.52065800E+02, 0.40907600E+03, -.20851900E+03, -.23751400E+03, -.19902500E+03, -.40942600E+02, -.24146200E+02, -.14329300E+03, -.13124100E+03, -.29970800E+02, -.22689900E+02, -.10538100E+03, -.20889300E+03, 0.12652600E+03, 0.54776800E+02, 0.10430900E+03, 0.18419700E+03, 0.89042700E+02, -.35421500E+02, -.27089600E+03, 0.12163400E+03, 0.60556200E+02, -.11971300E+03, -.18049900E+03, 0.10707300E+03, -.31791900E+02, 0.87980700E+02, -.58117100E+02, -.19334600E+02, 0.40684800E+02, 0.56214100E+00, 0.14599800E+03, -.43811700E+02, 0.84869200E+02, 0.11541000E+03, -.56418000E+02, 0.24412600E+02, -.56820500E+02, -.52031500E+02, -.10132700E+03, 0.82234000E+02, -.44656500E+02, 0.20185700E+03, -.13994100E+03, -.12710400E+03, 0.16348100E+03, -.80958000E+02, -.18600900E+03, -.79842000E+02, -.14174600E+03, -.69549600E+02, 0.81032200E+02, 0.14798000E+03, 0.86292400E+02, -.78038900E+02, 0.54200500E+02, -.19448100E+01, -.16967500E+02, -.70271200E+02, -.70797000E+00, -.58372700E+02, 0.13103200E+02, 0.48363900E+01, 0.58557300E+02, -.60636100E+01, 0.57206200E+02, -.66731800E+01, 0.58351500E+01, -.18613500E+02, 0.55986900E+02, -.71528900E+02, -.21713600E+02, 0.11275800E+02, -.61371400E+01, -.29671100E+00, -.30111600E+02, -.60427000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.52610500E-01, -.27534300E+00, 0.31639400E+01, -.18853500E+00, -.14619000E+00, -.82181800E+00, 0.14180600E+01, -.10741000E+00, 0.63132100E+00, 0.48465700E+00, -.25788800E+00, -.29657200E+00, 0.12078600E+01, 0.12185300E+01, 0.48939300E-01, 0.21982900E+00, 0.59168200E-02, -.15552400E-01, -.81465900E-01, 0.29914300E+00, 0.60522000E-01, 0.15678100E+00, 0.38134800E+00, -.21826200E-01, 0.95829800E-01, 0.23926700E-03, 0.30985600E-01, 0.25465200E+00, -.15297900E+00, -.65213900E-01, -.78540800E-02, -.23765700E+00, -.57865400E-01, 0.12013200E+00, 0.86485100E+00, 0.13800900E+00, -.15650500E-01, -.20974300E-01, 0.31474000E-01, 0.12587300E+00, -.46866700E+00, 0.44972500E+00, -.86894800E-01, 0.97997300E-01, 0.92920300E+00, -.10289700E+00, 0.26822300E+00, -.32379600E-01, -.84706900E+00, -.56654700E-01, 0.69365700E-01, 0.45525900E-01, 0.26758400E+00, -.15280100E+00, 0.29421400E+00, -.14503500E+00, 0.17026500E+00, -.75956600E+00, 0.48006100E-01, -.56201600E-02, 0.47137700E-01, -.59842400E-01, 0.44377400E+00, 0.88666800E-01, 0.37045000E+00, -.99263600E-01, 0.15879300E+00, 0.23761300E+01, -.65795400E-01, 0.60919200E-03, 0.60437500E-01, 0.19123900E+00, -.22857300E-01, 0.34269500E-01, -.23958500E+00, -.88847700E-01, -.95062200E-01, 0.49473600E+00, 0.25895500E-01, 0.72238600E-01, -.34273200E-02, -.66165300E-01, 0.70554300E-01, -.86107400E-01, 0.14242100E+00, -.18958200E+00, -.43837200E-01, 0.39528600E-01, 0.21917100E+00, 0.34577400E+00, 0.99459500E+00, 0.28995900E-01, 0.25886000E+00, 0.17783300E-01, 0.12882600E+00, 0.12941100E+00, 0.58601400E-01, -.46133500E-01, 0.14372700E+00, -.12276900E+00, -.59145600E-01, -.58570600E-02, 0.59465900E-02, -.99077600E-02, 0.34472600E+00, -.91690100E-01, -.39228800E-01, 0.11720300E-01, -.40879100E+00, -.12020100E+01, -.13076100E+00, -.33800200E+00, 0.29693200E+00, -.63006800E-01, -.82181100E-01, -.42626900E+00, -.57819600E-01, -.10201100E+01, -.16146100E-01, -.77378400E-01, -.45691100E+00, -.25531400E-01, -.34914600E-01, 0.15310300E+00, -.62284600E-01, -.24446600E+00, 0.12436400E+01, -.21584300E-01, -.21423300E+01, -.42242100E+01, 0.44803000E+00, -.16451400E+00, 0.80280300E-01, -.81426100E-01, -.12648500E-01, 0.10128700E+00, 0.63694700E+00, -.46022400E-01, 0.24738700E+00, -.23235400E+00, 0.81379000E-01, 0.20850000E+00, 0.15913000E-01, 0.14929700E-01, 0.27324000E-01, -.22556700E-01, -.13462100E-01, -.51721100E-01, 0.22248200E+00, 0.29599900E+00, -.33922900E-03, 0.56902300E-01, 0.16938500E+00, -.40006500E-01, 0.20932000E+00, -.58935000E-01, -.39013500E+00, -.93837300E-02, -.12955000E+00, 0.10899000E+02, -.99566200E+01, -.17857500E+02, -.15847800E+02, 0.13829500E+02, -.20322500E+01, -.94089600E+02, 0.50196600E+02, 0.19697900E+02, 0.47938200E+02, 0.13792900E+02, 0.10264600E+02, 0.40060200E+02, 0.22022800E+02, 0.19086100E+02, 0.25141500E+02, -.10036200E+01, 0.12471000E+02, -.70511800E+01, 0.19202800E+01, -.60922900E+01, 0.59647300E+02, 0.32526600E+01, 0.27583700E+02, 0.84382500E+02, 0.95839300E+01, 0.56113900E+01, -.66263200E+01, -.22138300E+02, 0.13824400E+02, 0.42811200E+00, 0.99768500E+01, -.21383100E+02, -.12932000E+02, 0.25124600E+02, 0.21586800E+02, 0.91641700E+01, -.68330800E+01, 0.26182100E+02, -.19702800E+02, 0.80455400E+01, 0.13540600E+02, 0.10057700E+02, 0.10575900E+02, -.48691400E+00, 0.18126900E+02, 0.28482200E+02, 0.13218200E+02, 0.33534600E+01, 0.29256800E+02, -.40301800E+02, 0.21239300E+02, 0.15704900E+02, 0.20472800E+02, -.20365700E+02, -.16065000E+02, 0.34570500E+02, 0.40620100E+02, 0.32143000E+02, -.76128500E+01, -.50933700E+01, -.32110200E-01, -.11477300E+02, -.43053100E+01, -.69521300E+00, -.43063600E+01, 0.21859300E+01, -.12723500E+01, 0.40552400E+01, -.71619900E+01, 0.31839300E+01, 0.74466200E+00, 0.94851100E+00, -.37350400E+01, 0.42426900E+01, -.40375900E+01, -.19644100E+01, 0.57877200E+01, -.40327200E+01, -.24684600E+01, -.13245300E+01, 0.62535500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57995600E+00, -.24649500E+00, 0.15805200E+01, -.14067600E+01, 0.49772100E+00, 0.80923900E+00, 0.95361900E-01, -.14337900E+00, 0.54392600E+00, -.15827600E+01, -.59986900E+00, 0.11842200E+00, -.10628200E+01, -.19746700E+01, -.62545400E+00, 0.95446100E+00, 0.44519100E+00, 0.41788100E-02, 0.87739400E+00, -.14053600E+01, -.14406200E+00, 0.17832800E+00, 0.14806900E+01, 0.10960800E+00, 0.67022600E+00, 0.11447800E-02, 0.35359600E+00, -.78705600E+00, 0.13073000E+01, -.20698800E-01, 0.68236300E+00, -.11937500E+01, 0.82533000E+00, 0.61513500E+00, -.27825300E+01, 0.60086400E-01, -.79264900E-01, 0.51586000E+00, 0.10252600E-01, -.20073200E+01, 0.22191800E+01, -.21237500E+00, -.38289100E+00, -.35867400E+00, -.28157100E+01, 0.74408800E+00, 0.79583600E+00, 0.19701700E-01, 0.11716400E+00, 0.10889900E+01, -.16787800E+00, 0.98806900E+00, 0.25961700E+01, 0.30791700E+00, -.34032900E+00, -.10248000E+01, 0.30283100E+01, -.27688200E+01, 0.38013400E+00, -.10269100E+01, -.19325700E+00, 0.10452100E+01, 0.13968700E+00, -.22578700E+00, 0.18201400E+01, 0.13124100E+01, -.57941500E-01, 0.75912200E+01, 0.22367000E+00, 0.10433600E-01, 0.27346300E+00, 0.23009100E+00, 0.25910100E+00, 0.53960100E+00, -.71488500E-01, 0.67003400E+00, 0.52179700E+00, -.54931500E+00, 0.11841200E+00, 0.33006500E-01, -.18291000E-01, 0.46748100E+00, 0.99144500E-01, -.17120100E+00, -.32526600E+00, 0.32987000E+00, -.23344600E+00, 0.24935000E-01, -.49405800E+00, 0.50526400E+00, 0.29736100E+01, 0.20713500E-01, -.14850900E-01, -.76644400E-01, -.37577200E+00, -.28764300E+00, 0.25527000E+00, -.40068600E+00, 0.38257600E-01, -.58429600E-01, -.63177000E+00, 0.42671600E+00, 0.44375200E-01, 0.12146600E+00, 0.11521000E+00, 0.27401500E+00, 0.15767100E+00, 0.58810700E+00, 0.71051800E+00, 0.23687600E+01, 0.30775800E+00, 0.45575800E+00, 0.38940800E+00, 0.85494900E-03, -.12560400E+00, 0.16050600E+00, 0.81440900E-01, -.52472000E+00, -.84779200E-01, 0.19732900E+00, -.14671100E+01, -.26117700E+00, 0.98538100E-01, 0.45531500E-01, -.56845200E-01, 0.13036700E+01, -.17341900E+01, 0.42993500E+00, -.15983400E+01, -.46917500E+01, 0.12232700E+01, 0.11878500E+00, 0.12383500E+00, -.28395800E+00, -.16637100E+00, 0.13667100E+00, -.11238200E+01, -.10263400E+00, 0.10219600E+01, 0.52783500E+00, 0.29093300E+00, -.80536800E+00, 0.21469200E-01, 0.28017300E+00, -.11247900E+00, -.13189000E+00, -.59104500E-01, 0.23071400E+00, 0.76704500E+00, 0.40757000E+00, 0.22795600E+00, -.33921600E-01, 0.90784600E+00, -.33123200E+00, -.69407800E+00, -.33330900E-01, 0.10012400E+00, -.12530800E+00, -.31283000E+00, 0.23258000E+01, -.44893500E+02, 0.16025700E+02, 0.12818000E+02, -.17921200E+02, 0.47554600E+02, -.19338600E+03, 0.90362400E+02, 0.90967200E+01, 0.91652400E+02, -.18478100E+02, -.11014000E+02, 0.82594200E+02, 0.13040600E+03, 0.73940800E+02, -.15852400E+02, 0.16450100E+03, -.26848900E+03, 0.14623300E+03, 0.24328000E+03, 0.13513700E+03, -.24033200E+03, -.18602600E+03, 0.11623000E+03, 0.16703200E+02, 0.10037200E+03, -.15225800E+03, 0.15658100E+03, 0.32320800E+03, -.16899500E+03, -.89063600E+02, -.15942800E+03, -.26981500E+02, 0.75325700E+01, -.56138900E+02, 0.38075900E+02, -.11251000E+03, 0.16825200E+02, -.11093500E+03, 0.25371400E+01, -.57653100E+00, -.60239900E+02, -.24171500E+01, 0.44668000E+02, -.73718000E+02, -.11798100E+02, -.24324800E+02, -.41376800E+01, -.22377300E+02, -.71968600E+02, 0.69298100E+02, -.34763900E+02, -.45071300E+02, -.36528500E+02, 0.44710600E+02, -.22024700E+02, -.15262600E+02, 0.21921900E+02, -.23086900E+02, -.91994500E+01, -.73193800E+02, -.92046200E+00, 0.13846800E+01, 0.14082100E+02, -.46574900E+00, -.22711400E+00, 0.58439500E+00, 0.26794400E+00, 0.60041900E+00, -.17778600E+02, -.62460400E+01, -.45669400E+00, -.77354000E+01, -.71733100E-01, -.73005500E+01, 0.14001900E+02, -.66279300E+01, 0.14813600E+01, 0.22175400E+02, -.14550000E+02, 0.47461500E+01, 0.11003000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35816600E+00, 0.63684700E+00, 0.17214500E+01, -.17546200E-01, 0.75944600E-01, 0.86874400E+00, -.77665100E+00, -.26366500E-01, -.11555700E+01, -.16124600E+01, -.11377900E+00, 0.10323700E+00, -.15258200E+01, -.50733100E+00, -.19431700E+00, -.45407200E+00, 0.80650300E+00, -.37823600E+00, 0.11330600E+01, -.90861200E+00, -.46624300E-01, -.14648000E-01, 0.11250200E+01, 0.39280800E-01, 0.37471100E+00, 0.11888900E-02, 0.18573700E+00, 0.12557300E+00, -.15641300E+00, -.68735500E-01, 0.28946000E+00, -.34847000E+00, 0.32191700E+00, -.19957400E+00, -.10735300E+01, -.16531300E+00, 0.30272600E-01, 0.37368400E+00, -.24852300E+00, -.64134900E+00, 0.10168700E+01, 0.44373200E-01, -.78614900E-01, 0.40789000E-01, -.18824200E+01, 0.22071200E+00, 0.14833700E+01, 0.31190400E-01, 0.16001100E+00, 0.10402800E+01, 0.10240900E+00, 0.12946400E+00, -.22140300E+00, 0.64217000E-01, -.22865600E+00, -.13017100E+00, 0.95727400E+00, -.28619800E+00, 0.35055400E-02, -.47279200E-01, -.16634600E+00, 0.47013700E+00, 0.28502500E+01, 0.73330600E-01, -.30771900E+00, -.11093600E+00, -.47786800E+00, 0.90216500E+01, -.20874900E+00, 0.23103700E-01, -.19348700E+00, 0.38313700E+00, 0.12608300E+00, 0.19443500E-01, -.28990000E+00, 0.80048900E+00, 0.50795300E+00, -.40037000E+00, 0.12604300E+00, -.22167700E+00, 0.61988800E-01, 0.55174300E-01, 0.11866100E+00, 0.84678700E-01, 0.61820300E+00, 0.30659600E+00, -.52407700E+00, 0.75914000E-01, -.49139300E+00, -.56998800E-01, -.19207600E+01, 0.22096300E-02, -.78574700E+00, -.34339100E+00, -.18764700E+00, 0.69207400E+00, 0.82694900E+00, -.15258600E+00, 0.97726800E+00, 0.14544300E-01, 0.23077100E+00, -.48570600E+00, 0.31601000E-01, 0.16083200E+00, -.14590000E+01, -.54429400E-01, 0.40206700E-01, -.52419900E+00, -.35266100E+00, 0.51642600E+00, 0.11843400E+01, 0.10915700E+00, -.17705600E+00, -.96480000E-02, -.33087100E-01, 0.90277600E+00, 0.99115600E-01, -.71855100E+01, 0.22156600E+00, -.41957500E+00, 0.50817300E+00, 0.42207300E+00, -.89902500E-01, 0.44513700E+00, -.10329000E-01, -.65714500E-01, -.27216800E+01, 0.28786800E+00, 0.20681200E+01, -.89816200E+00, -.43418700E+00, 0.94176000E-01, -.32750800E+00, 0.20299900E+00, -.16484100E+00, -.48554500E-01, 0.10858600E+01, -.22752100E+00, 0.96921300E+00, 0.45234300E+00, 0.45503300E+00, 0.32159000E+00, 0.52174700E-01, -.27032200E+00, 0.23346100E+00, 0.66702900E-02, 0.16299900E-01, -.20234800E+00, 0.29984500E-01, -.16872300E-01, -.46004600E-01, 0.12875700E+00, 0.11269300E+01, -.29424700E+00, 0.83536700E+00, -.72116400E-01, -.49915200E+00, -.24710800E-01, -.42096900E+00, -.10047200E+01, 0.36168200E+00, -.77554200E+02, -.22874600E+02, 0.25673100E+02, -.57060400E+02, 0.13909200E+02, 0.37094400E+01, -.20601300E+02, -.19990100E+01, -.71081200E+01, -.19427100E+02, 0.54874700E+02, 0.56618300E+01, -.25002200E+02, 0.17889700E+02, -.13753400E+03, 0.40082000E+03, -.20656400E+03, -.22682700E+03, -.20090700E+03, 0.17667300E+03, 0.19468800E+03, -.48020600E+02, 0.23397500E+03, -.91951100E+02, 0.14448700E+03, -.33381700E+03, -.20260400E+03, 0.11368000E+03, 0.44404000E+02, 0.97630000E+02, -.52424600E+02, -.40117900E+02, 0.98688100E+02, 0.62163000E+02, 0.88415100E+02, -.27053700E+02, 0.12021400E+03, 0.20350800E+03, -.10765000E+03, -.49579200E+02, -.10055900E+03, -.32279000E+02, 0.14498800E+03, -.26270700E+02, 0.17653700E+03, -.33597100E+02, 0.67727700E+02, -.54573300E+02, -.49260800E+02, 0.28321300E+02, 0.32683600E+02, 0.26477400E+02, -.95207100E+02, -.65002400E+02, 0.10536700E+03, 0.11734800E+03, 0.83971300E+02, -.53631500E+02, 0.29961800E+01, 0.45134600E+00, -.16014900E+02, -.15157000E+02, -.22252700E+01, -.91308300E+01, 0.46573900E+01, -.46953700E+00, 0.80809100E+01, -.20637600E+02, 0.12309900E+02, 0.10503100E+01, 0.46815800E+01, -.15734800E+02, 0.15383000E+02, -.15188600E+02, 0.14480200E+01, 0.28064300E+01, -.21456800E+02, -.75562700E+01, -.18951300E+02, 0.32712100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20288200E+00, -.73653300E+00, -.28473800E+01, -.15838900E+01, -.24738700E+00, 0.55106900E+00, -.21572800E+01, 0.14766700E+00, -.35156800E+01, -.13633300E+01, 0.35652000E+00, 0.16174500E+00, -.97790300E+00, 0.49797100E+00, 0.78948200E-01, -.15316200E+01, 0.23118000E-01, 0.69309800E+00, -.47816000E+00, 0.78925700E-01, -.25256300E-01, -.19289100E+00, -.12503800E+01, -.86743700E-01, -.24399800E+00, -.10585300E-02, -.13934000E+00, 0.11390300E+00, -.73177000E+00, 0.71148100E+00, -.99940000E-01, 0.61175000E+00, -.76927300E-01, 0.34085900E-01, 0.76737000E-01, 0.31041900E-01, -.62095000E-01, 0.86372100E-01, 0.26047500E+00, 0.48696700E+00, 0.50460100E-01, 0.37285200E+00, 0.14739800E-01, 0.99749800E-01, -.76077700E+00, 0.21033800E+00, 0.30243400E+00, -.23809100E-01, -.28963500E+00, 0.15500600E+00, -.55256300E+00, -.13595400E+00, 0.72157600E-01, 0.24873800E+00, 0.23767600E+00, 0.25799300E+00, -.16086100E+01, 0.99392100E+00, -.17968800E-01, 0.58091500E-01, 0.66436200E+00, -.49215600E+00, -.39167600E+01, -.44252000E+00, 0.62022000E-01, 0.42641300E+00, 0.59776400E-01, -.88297200E+01, -.12148400E+00, -.84973600E-02, -.21967800E+00, -.43975100E+00, -.32158600E+00, -.28255800E+00, 0.12556700E+01, -.89266100E+00, 0.56764700E+00, -.24857900E+01, -.20854400E+00, -.69150600E-01, -.59611300E-01, -.79690600E+00, -.19214800E+00, -.23547000E+00, -.31303200E+00, 0.13037900E+01, -.38880300E+00, 0.26685700E-01, 0.13029300E-01, -.41950900E+00, 0.29116800E+01, 0.20203800E-01, 0.55477400E+00, 0.29059800E+00, -.82628000E-02, 0.26702000E+00, 0.67327500E+00, -.51023900E+00, 0.37764900E+00, 0.42201600E+00, -.22780800E+00, 0.32550900E+00, 0.15843200E-01, -.28909300E+00, 0.39437500E+00, -.79851800E-01, 0.27661500E+00, -.94152900E+00, -.10614900E+01, -.15013000E+01, 0.12299200E+00, 0.28009900E+00, 0.31113500E+00, -.15330100E-01, 0.19310300E+00, -.53515000E+00, -.16730900E+00, -.69620700E+00, 0.16859100E+00, 0.37607100E+00, -.51290500E+00, 0.67799600E-01, 0.26577300E+00, -.56009400E+00, -.60132500E-02, -.97115700E-01, -.26500200E+00, 0.11323300E+00, 0.34926000E+01, -.62821900E+01, 0.54584500E+00, 0.12110400E+00, 0.17931400E+00, -.26284400E+00, -.10550800E-01, 0.13098000E+00, -.90179700E+00, -.29226500E+00, 0.15407200E+00, -.30417500E+00, 0.11795700E+00, -.23959800E+00, 0.27149400E+00, -.19024600E+00, 0.36955500E-01, 0.42052100E-01, -.19283300E-01, 0.56564000E+00, -.11895900E+01, -.99833200E+00, -.19069800E+00, 0.36296800E+00, 0.11223300E+01, -.15651400E+00, -.93355400E-01, -.43831600E-01, -.16973200E+00, -.72845800E-01, -.46226800E+00, 0.12793800E+00, 0.29028000E+00, -.16273700E+00, 0.43648000E+02, 0.12742200E+02, -.60489300E+02, 0.13110800E+03, -.60803900E+02, -.57868300E+02, -.63022900E+02, -.17928100E+02, -.45161700E+02, 0.84843800E+01, 0.38052600E+01, 0.47446900E-01, -.21756400E+02, -.10697400E+03, 0.21475500E+03, -.10823700E+03, -.16984500E+03, -.10714500E+03, 0.12569200E+03, 0.12100600E+03, -.47161500E+02, 0.59453000E+02, -.53934900E+02, 0.90914900E+02, -.25999100E+03, -.16041400E+03, 0.95008100E+02, 0.51918000E+02, 0.77958600E+02, -.35349000E+02, -.32645300E+02, 0.69767700E+02, 0.23355600E+02, 0.74141500E+02, -.23035200E+02, 0.51876700E+02, 0.67152600E+02, -.36872700E+02, 0.66828000E+01, -.32866800E+02, -.42838100E+02, 0.49861300E+02, 0.15345200E+02, 0.50840100E+02, 0.19644500E+02, 0.54048500E+01, 0.26687500E+02, -.45450300E+02, 0.25154300E+02, 0.21459500E+02, 0.23702500E+02, -.65350700E+02, -.53564400E+02, 0.78732200E+02, 0.55443000E+02, 0.64319000E+02, -.49508300E+02, 0.24340800E+02, 0.22603400E-01, -.21678600E+01, -.12667700E+02, -.94761900E+00, -.22556100E+01, 0.20252200E+01, 0.14678300E+01, 0.16700100E+01, -.14138500E+02, 0.51930600E+01, 0.14504600E+00, 0.26079200E+01, -.75094200E+01, 0.80403200E+01, -.12570900E+02, -.24535200E+01, -.48160800E+01, -.11534900E+02, -.67028800E+01, -.13925800E+02, -.54754900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.71658300E+00, -.66814900E+00, 0.27975100E+00, -.11714800E+01, -.16852600E+01, 0.68547700E+00, -.34024600E+01, 0.22529800E+00, 0.23511400E+00, -.95407300E+00, -.63711000E-01, 0.80154100E-01, 0.10826500E+01, 0.11577000E+01, 0.73647600E+00, -.24826700E+00, 0.10342500E+00, 0.53150300E+00, -.36983000E+00, 0.44764500E+00, -.61374100E-02, -.15372100E+00, -.30132600E+00, -.12113600E+00, -.74669600E+00, -.28431400E-02, -.11824600E+00, -.24591300E+00, 0.42768100E+00, -.39621600E+00, 0.76651100E-01, -.12401100E+01, 0.10744100E+00, -.32047600E+00, 0.37556000E+00, -.92939700E-01, 0.18285800E+00, 0.79647300E-01, -.34116800E+00, -.92113600E+00, 0.10572100E+01, 0.78354100E+00, -.12240900E+00, 0.12599200E+00, 0.52151100E+00, 0.10006600E-01, 0.17027700E+01, 0.43318600E-01, 0.39162400E+00, 0.82847300E+00, 0.74258300E-02, -.12282400E+01, -.12048300E+00, 0.11610400E+01, -.12875500E+00, 0.31076500E+00, -.87714700E+00, 0.26330600E+01, -.27601700E+00, -.50757900E-02, 0.10247300E+00, 0.47297600E+00, 0.36532600E+01, -.36473100E+00, -.33621600E+01, -.90053900E-01, 0.15186100E+00, -.38253900E+01, 0.41241600E+00, -.42052400E-01, 0.95761500E-01, -.48291900E+00, -.34721300E+00, 0.18460800E+00, 0.15102700E+00, -.15087400E+01, -.11586500E+01, -.31989200E+01, -.22619900E+00, -.74734200E-01, 0.34247000E-01, 0.12971500E+01, -.74639900E+00, 0.10789400E+01, -.96499500E+00, 0.19535000E+01, -.83182400E+00, -.25472100E+00, 0.37353300E+00, -.11005300E+01, 0.11764000E+01, -.79830700E-01, -.12808500E+01, 0.51306900E+00, 0.17226700E+00, 0.52947500E-01, 0.12143700E+01, 0.17495900E+00, 0.12389200E+01, 0.59655800E+00, -.64642800E+00, -.22947500E+00, 0.43046600E-01, 0.61822900E-01, -.19868400E+01, -.16915000E-03, 0.35121300E+00, -.82673200E-01, -.91496000E-01, 0.52572200E+00, 0.86355700E+00, -.15129800E+00, 0.18547100E+00, 0.10170700E+00, -.44692300E+00, 0.22688400E+01, 0.98160000E-01, -.54337600E+01, -.14763700E-02, 0.31419700E-01, 0.13120800E+00, 0.86202100E+00, 0.48058600E+00, 0.20564200E+01, 0.57710600E-01, -.54121000E+00, -.62649300E+01, -.38836400E-01, 0.32363900E+01, -.90112600E+01, -.18514600E+00, 0.53585200E+00, -.62603600E+00, -.51567900E-01, 0.33389900E+00, -.25780300E-01, -.30368900E+01, 0.19219100E+00, -.91302700E+00, 0.50062500E+00, 0.11132200E+00, 0.28503000E+00, 0.47834100E+00, -.49920000E+00, 0.74309600E-01, -.19757200E+00, -.55284000E-01, 0.73288000E+00, -.18534600E+01, -.24861200E+01, -.23298900E+00, 0.10291000E+01, 0.68501700E+00, -.46992500E-01, -.93251300E+00, -.18438900E+00, -.50736700E+00, -.11764900E-01, -.12784300E+01, -.41728500E+01, 0.21529800E+00, 0.18512300E+00, 0.30120400E+00, 0.58755200E+02, -.93896500E+02, -.16570000E+03, 0.98842500E+02, -.13323300E+03, 0.93658200E+02, -.35798500E+01, -.51810800E+02, 0.19480300E+03, 0.10931500E+03, 0.11641100E+03, 0.48314800E+02, -.14451800E+03, 0.24552200E+02, -.32278700E+01, -.17126000E+03, -.10685300E+02, 0.47116400E+03, 0.14231200E+03, 0.12320700E+03, 0.23440800E+03, 0.13455300E+03, 0.11340800E+03, -.36126900E+03, -.12361500E+03, 0.91854600E+02, -.27378000E+02, 0.54415800E+02, -.19922400E+03, -.12828800E+03, 0.15832500E+03, 0.10779600E+03, 0.13194100E+03, -.10545500E+03, 0.15781500E+03, -.13046500E+03, 0.56628000E+02, 0.67616700E+02, 0.67566700E+02, 0.55766900E+02, 0.56036300E+02, 0.21754100E+03, 0.13063500E+03, 0.16161700E+03, 0.34760200E+02, 0.11527400E+03, -.19184400E+03, 0.10293800E+03, -.61834700E+02, 0.99852400E+02, -.25114100E+03, -.25001000E+03, 0.40539500E+03, 0.43440200E+03, 0.34497900E+03, -.20024300E+03, 0.49672100E+02, -.17183600E+01, -.67263400E+02, -.84939600E+02, -.76302900E+01, -.61435300E+02, 0.21829200E+02, -.29045000E+01, 0.60281500E+02, -.57373600E+02, 0.61606900E+02, -.97435100E+00, 0.86100500E+01, -.53646300E+02, 0.65112500E+02, -.84167300E+02, -.59924000E+02, 0.28414200E+02, -.29319200E+02, -.25608300E+02, -.29063800E+02, 0.26620400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.48433500E+00, 0.20668000E-01, -.36764900E+01, 0.63195800E+00, 0.12626600E+01, -.14635000E+01, 0.27011500E+01, -.42353700E+00, 0.20616600E+00, 0.21137100E+01, 0.19691300E+01, -.26913500E+00, 0.29701600E+01, 0.10684800E+01, -.58171100E+00, 0.78755200E+00, 0.84505000E+00, -.30226700E-01, -.23503400E+01, 0.15053200E+01, 0.38109400E+00, -.16588500E+00, 0.11728400E+01, 0.81782200E-01, -.22848300E-01, -.13998000E-03, 0.10882500E+00, -.43098600E+00, 0.66891500E+00, 0.38275800E+00, -.10847400E+00, -.48728600E+00, 0.18719200E-01, 0.12901200E-01, -.10949300E+01, -.39922200E-01, -.21950900E+00, 0.45096100E-01, 0.23899400E+00, -.78304600E+00, 0.10838700E+01, 0.14746500E+01, -.54190100E+00, -.38631000E+00, -.31982900E+00, 0.61250600E+00, 0.81300600E+00, -.23600100E+00, 0.31688100E+00, -.59148100E+00, -.12317600E+00, -.40589100E+00, -.33536400E+00, 0.71384100E+00, 0.89942200E+00, 0.33320400E+00, 0.22591500E+00, 0.10364600E+01, 0.30593800E+00, 0.10493700E+00, 0.10094800E+01, -.62415300E-01, -.49283100E-01, 0.39557800E+00, -.31857800E+00, 0.19173300E+00, -.27445500E+00, -.61938500E+01, -.88542900E-01, -.20164700E-01, 0.93367900E-01, -.29359000E+00, -.28322300E+00, -.25999000E+00, -.14444400E+00, -.11204500E+01, -.65865900E+00, 0.33140000E+01, -.18304700E-01, 0.21988600E-01, -.18947000E-02, 0.79829500E+00, -.10998100E+01, -.12383100E+01, -.11824900E+01, 0.70839200E+00, 0.59030600E+00, -.25093700E+00, 0.19536600E+01, 0.66409500E+00, -.35617300E+01, -.73760200E-01, 0.14946600E+01, 0.25382800E+00, 0.42237500E+00, 0.41205600E+00, -.50724400E+00, 0.10721200E+01, 0.95598500E+00, 0.24075800E+00, 0.40441300E+00, -.99069500E+00, -.12222300E+00, 0.22016500E+00, 0.18659600E+00, 0.19149900E+00, -.35502700E+00, 0.11013500E+01, -.57309100E+00, 0.11650500E+00, 0.16886200E+01, -.48038000E+00, 0.11041500E+00, 0.46392600E-01, -.45661400E+00, 0.15235700E+01, 0.42152800E+00, 0.23843500E+01, -.18617100E-01, 0.11118300E+01, -.10386700E+01, 0.17739600E+00, -.14912700E+00, 0.19290300E+01, 0.10865300E+00, -.72856000E+00, -.60499200E+01, -.56950400E+00, 0.76174600E+01, -.31276300E-01, -.76650000E+00, 0.28760400E+00, 0.23899800E+00, 0.11091900E-01, -.16998900E+00, -.75595200E-01, 0.65849900E+00, -.50374600E+00, 0.18870300E+01, -.15838100E+00, 0.86244100E-01, -.17287200E+00, 0.64349400E+00, 0.44369000E-01, 0.18263400E+00, 0.14835600E+00, 0.25424100E-01, 0.18631100E+00, 0.22123500E+00, 0.34272700E+00, -.45106300E+00, 0.16576800E+01, 0.10592400E+01, 0.12712900E+00, 0.94121700E+00, 0.13019800E+00, -.17577700E+00, 0.14122800E-01, -.17498100E+00, -.18440200E+01, -.64176100E+00, 0.76028500E+00, 0.42502700E+00, -.66572600E+00, -.60855700E+02, 0.53525000E+02, -.23126600E+02, -.10920900E+03, -.25020300E+02, 0.12760600E+02, -.39215000E+02, 0.92150800E+02, 0.17806700E+03, 0.75168200E+02, 0.36701800E+01, -.45127800E+02, -.47981600E+03, 0.24765600E+03, 0.20403300E+03, 0.24084400E+03, 0.16294600E+03, -.10021100E+03, 0.19245200E+03, 0.23955900E+02, 0.23084600E+03, -.47120500E+02, 0.82690800E+02, -.10649900E+03, 0.63792700E+02, 0.99533000E+02, 0.52075800E+02, -.62377000E+02, -.54387500E+02, 0.10766700E+03, 0.81191600E+02, 0.56541300E+02, -.39961600E+02, -.10898000E+02, -.40584200E+03, 0.19923100E+03, 0.46235200E+02, 0.20310500E+03, 0.94286900E+01, -.15345300E+03, 0.20424700E+03, -.11456500E+03, 0.24277600E+03, -.98158500E+02, 0.17304500E+03, 0.38203700E+02, -.16453600E+02, -.16631700E+02, -.18545900E+02, -.62943500E+02, -.86685100E+02, 0.98985600E+02, 0.19069700E+03, 0.10108500E+03, -.64521400E+02, -.80737100E+02, -.18556700E-01, -.13117500E+02, -.52300500E+02, -.38082400E+01, -.50561300E+02, -.20325000E+01, 0.14025400E+02, 0.50816500E+02, -.43018700E+02, 0.41690500E+02, -.46832800E+01, -.38611400E+01, -.12056500E+02, 0.43623800E+02, -.51967400E+02, -.21877600E+02, -.17646600E+01, -.52634600E+01, -.28023300E+02, -.19319200E+02, 0.27179100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22452400E+00, -.42327400E+00, -.23440800E+01, -.79326200E+00, 0.83160800E+00, 0.46697600E+00, 0.86820400E+00, 0.21863300E+00, -.14506900E+01, -.97888300E+00, 0.34630600E+00, 0.20787100E+00, -.14151600E+01, 0.12801700E+00, -.49967700E+00, -.12165700E+01, 0.21378200E+01, 0.30154900E+00, -.69318300E+00, 0.89572700E+00, 0.89889600E-01, 0.35344100E+00, -.63804800E+00, -.17856800E+00, -.55698600E+00, -.19070700E-03, -.41170100E+00, -.11463900E+01, 0.71651400E+00, -.10927200E+01, 0.96966100E+00, -.64261800E+00, -.12956100E+00, -.26449700E+00, 0.98689100E+00, 0.28366700E-01, 0.95474300E-01, -.17636400E+00, -.19844400E+00, -.20995300E+00, -.47921200E+00, 0.22583200E+00, -.49543200E-01, -.11130400E-01, 0.20117500E+01, -.41910700E+00, 0.14127800E+01, -.13117100E-01, -.66862200E+00, 0.66066500E-01, 0.82030100E-01, -.16448600E+00, -.38334600E+00, 0.20439300E+00, 0.32210600E+00, 0.40022500E-01, -.51526800E+00, 0.67021800E+00, -.29135400E-01, 0.23158300E+00, 0.10787500E+00, 0.59066300E+00, 0.36363000E+00, -.10906900E+00, -.91873900E+00, -.11614900E+00, 0.83938000E-01, 0.15841500E+01, -.17800800E+00, -.82976400E-02, -.15387300E+00, -.11493000E+00, -.45610400E-01, 0.20405300E+00, 0.57429300E-01, 0.19349600E+00, -.75160000E-02, 0.90007700E-01, 0.15251200E+00, -.55634600E-01, 0.39189500E-03, 0.12924700E+00, 0.10511900E+00, -.13138300E+00, -.15994400E-01, -.30098500E-01, -.16451800E+00, -.21310900E-01, 0.43473300E+00, 0.12268900E+01, 0.19281400E+01, 0.32797200E-01, 0.62187800E+00, -.15541900E+00, -.75387300E-01, 0.12991200E+00, 0.35315500E+00, 0.28140200E-01, -.15300400E+00, 0.54469300E-01, -.26786300E+00, 0.16050300E+00, 0.53048500E-01, -.85256100E-02, 0.24405400E+00, -.15139700E+00, -.48693200E-01, 0.23429600E+00, 0.28391300E+00, -.16548500E+00, -.72752300E+00, -.21183200E+00, 0.34356500E+00, -.74654900E-01, -.16067200E+00, -.41508900E+00, -.15840200E+00, 0.12691900E+01, 0.49700700E-02, 0.46358700E+00, 0.41004000E+00, 0.26323600E+00, 0.28204200E-01, 0.38883600E+00, -.52033400E-01, -.26334600E+00, 0.15672500E+00, 0.20060600E+00, -.11104100E+01, -.36085500E+01, 0.10723900E+01, -.17645500E+00, 0.11565300E+00, -.15478900E+00, -.16047500E+00, 0.12168500E+00, 0.19809500E-01, -.19973100E+00, 0.67991600E+00, -.43374900E+00, 0.16807800E-02, 0.78833000E+00, -.21826700E+00, 0.60718100E-01, -.38688100E-01, -.36379900E-01, -.14239200E-01, -.19389200E+00, 0.48092100E+00, 0.13191700E+00, 0.85887700E-01, 0.33685800E+00, -.79943400E+00, 0.17721600E+00, -.51164100E+00, -.77426400E-01, 0.18078700E-01, -.13242900E-01, -.26424600E-01, 0.15644500E+01, 0.21291500E+00, -.76273200E+00, -.13022100E+00, 0.35100900E+00, 0.51280000E-01, 0.25126300E+03, -.12398000E+03, 0.26757500E+01, -.12575800E+03, -.10370600E+02, 0.69173200E+01, -.10956700E+03, -.67094100E+02, -.10216200E+03, -.31714600E+02, -.72671600E+02, 0.19352900E+03, -.11190800E+03, -.16132300E+03, -.97713300E+02, -.19041200E+02, 0.85729100E+02, -.11999800E+03, -.12934700E+03, -.11717300E+03, 0.58280500E+02, -.35497400E+02, -.26359200E+03, 0.12465200E+03, 0.13349700E+03, 0.13186000E+03, 0.70288000E+02, 0.12612600E+02, 0.71680300E+02, 0.32459900E+01, 0.87570900E+02, 0.45667500E+01, 0.62999100E+02, 0.18408400E+03, -.90970300E+02, -.58821700E+02, -.92004600E+02, -.50143800E+02, 0.56174400E+02, -.89907100E+02, 0.85277000E+01, -.61886300E+02, 0.90209500E+01, -.11009600E+03, 0.53662100E+02, -.27610400E+02, 0.23291000E+02, -.26853500E+02, 0.24669100E+02, 0.59076700E+02, -.82070500E+02, -.79084900E+02, -.89549000E+02, 0.38999700E+02, 0.34911900E+02, 0.12999700E+01, 0.19332000E+02, 0.10915700E+02, 0.26543400E+01, 0.11994300E+02, -.53920800E+01, 0.16434000E+01, -.12248400E+02, 0.13807100E+02, -.84240100E+01, 0.35894700E+00, 0.56356400E+01, 0.10223900E+02, -.84435200E+01, 0.10884800E+02, 0.13537400E+02, -.52147500E+01, -.52976100E+00, 0.11877900E+02, -.21420200E+01, -.11214800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11832900E+01, -.10361500E+02, -.13389900E+02, -.81058700E+01, 0.55701900E+01, -.10158200E+02, 0.85798200E+01, 0.26111500E+00, 0.12483300E+02, 0.86114200E+01, -.90394500E-01, -.34436300E+01, 0.16497300E+02, 0.86091800E+01, 0.26130300E+01, 0.42700200E+01, -.49827600E+01, 0.50027900E+01, -.44753400E+01, 0.55373200E+01, -.10456100E+00, -.40047600E+00, -.13319400E+02, -.13307000E+01, -.32106400E+01, -.96073800E-02, -.18674400E+01, 0.26484300E+01, -.47008100E+01, 0.26609100E+01, -.20416200E+01, 0.43613700E+01, -.25446200E+01, -.50362900E+00, 0.10488400E+02, 0.50044600E+00, -.15809100E+00, -.15342000E+01, 0.25462900E+00, 0.33509200E+01, -.30999700E+01, 0.63176700E+00, 0.57737300E+00, 0.12154600E+00, 0.79589100E+01, -.17777600E+01, 0.57419000E+01, -.32505900E+00, -.17905000E+01, 0.17901000E+01, 0.99646600E+00, 0.29246000E+00, -.22544400E+01, -.11941600E+01, -.25176600E+01, 0.12244200E+01, -.30932500E+01, 0.18958500E+01, -.37886900E+00, 0.13139400E+01, -.21729000E+01, -.48066800E+01, 0.14966300E+01, 0.29448600E+00, 0.51776100E+00, -.10527300E+01, 0.21606700E+01, 0.19758200E+02, -.21697000E+00, -.15910500E+00, 0.52349400E+00, 0.58456500E+00, -.21564200E+00, 0.70475900E+00, 0.58694400E+00, -.22825500E+01, -.52195900E+01, -.26079400E+01, -.10011400E+01, 0.59074400E+00, 0.42130700E-01, 0.12785500E+01, -.23829700E+00, 0.47720700E+00, 0.11561300E+01, -.29307900E+01, 0.70975500E+00, -.27000400E+00, 0.24242000E+01, 0.17476900E+00, -.11189700E+01, -.89318500E-01, -.14499600E+01, -.83231600E+00, 0.55720700E+00, -.56915500E+00, -.46257700E+00, 0.10408500E+01, -.15770200E+01, -.41504000E-01, -.72917200E+00, -.19173100E+00, 0.24952700E-01, 0.13481600E+01, 0.10903300E+01, -.24995200E+00, -.26720800E-01, -.38663300E+00, 0.51619400E+00, -.10260900E+01, 0.38114100E+00, 0.13145000E+01, -.10635500E+01, -.10787800E+00, 0.83217800E+00, 0.23267600E+00, 0.36592200E-01, -.54138900E+01, 0.38706300E+00, -.74592900E-02, 0.10217700E+01, 0.61066600E-01, 0.72995800E+00, -.16811400E+01, -.26366300E+00, -.10437000E+00, 0.13002300E+02, 0.16742200E+00, -.59617800E+01, 0.12752400E+01, -.10514100E+01, -.77048700E+00, -.47768000E+00, 0.38506800E-01, 0.36625000E-01, 0.37599500E-01, 0.31571600E+01, 0.24654400E-01, -.11119300E+01, 0.34073000E+00, 0.52111200E+00, -.18458500E-01, 0.52740000E+00, -.94101800E+00, 0.64828200E+00, -.16256800E-01, -.45449700E-01, 0.32926300E-02, 0.22683400E+01, 0.48061700E+00, 0.14079000E+00, 0.15428800E+01, 0.15053700E+01, 0.88829900E-01, 0.14170600E+01, -.36969100E+00, 0.32657500E+00, 0.94548200E-01, -.16250000E+00, -.33284500E+01, -.52319000E+00, 0.77692300E+00, 0.65621600E-02, -.34872300E-01, 0.73425300E+00, -.84365000E+00, 0.32349300E+02, 0.89863100E+02, -.84753900E+00, 0.44097500E+01, 0.40113900E+02, -.12963200E+03, -.15607800E+03, -.88255600E+02, -.40724200E+01, -.18086300E+02, 0.75555800E+03, -.40361900E+03, -.34895800E+03, -.37971400E+03, -.18203500E+03, 0.26417200E+03, -.32477400E+03, -.93486900E+02, -.36921500E+03, 0.20301900E+03, -.25790500E+03, 0.45629100E+02, -.53269300E+02, -.50463300E+02, -.21427600E+02, 0.79880400E+02, 0.33801600E+02, -.30308900E+02, -.76747300E+01, -.23055600E+02, 0.20544800E+02, 0.18095600E+02, 0.36943500E+03, -.19022500E+03, -.47788700E+02, -.18497600E+03, -.76011600E+02, 0.20547100E+03, -.19239000E+03, 0.12583800E+03, -.19659300E+03, 0.10492600E+03, -.18902200E+03, -.21108000E+02, 0.13517000E+02, 0.35301900E+02, 0.10229400E+02, 0.67968800E+02, 0.98794700E+02, -.13626500E+03, -.20674100E+03, -.14725900E+03, 0.75413000E+02, 0.91209100E+02, 0.68071400E+00, 0.20439600E+02, 0.43448000E+02, 0.41268200E+01, 0.39963800E+02, -.32812100E+01, -.85260600E+01, -.40280500E+02, 0.30632000E+02, -.28983000E+02, 0.40169700E+01, 0.43135500E+01, 0.18983800E+02, -.29995500E+02, 0.42755800E+02, 0.29589700E+02, -.44440200E+01, -.17297400E+02, 0.22989300E+02, 0.10927600E+02, -.22153300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19705200E-01, 0.11254300E+00, 0.62790400E-01, 0.20482500E-01, 0.42373400E-01, 0.32114700E-01, -.60953900E-01, 0.51615500E-02, -.60872200E-01, -.10917100E+00, -.14486800E-01, 0.83173800E-02, -.96206300E-01, -.46259100E-01, -.50045500E-01, -.16554900E-01, -.46880400E-02, 0.10880200E-01, 0.27647800E-01, -.15015800E-01, -.63876000E-02, 0.86527800E-02, -.43353700E-01, -.14267000E-01, -.18158400E-01, -.10552200E-03, -.10641800E-01, 0.83780900E-02, -.34600600E-02, 0.57225800E-02, 0.31037700E-01, -.24439700E-02, 0.24870900E-01, -.48803000E-01, 0.56053500E-01, 0.65214900E-02, -.32745100E-02, -.32784500E-02, -.58021400E-02, 0.49842800E-01, -.52783100E-01, -.98050200E-01, 0.10853100E-01, -.17558400E-02, 0.15256100E+00, -.45874800E-01, -.15690600E-02, 0.47142700E-03, -.14778700E-01, 0.89860900E-02, 0.14737300E-01, 0.15288700E-01, 0.29943500E-01, 0.57784700E-02, 0.54340100E-02, -.68268100E-02, 0.24380400E-01, -.57690700E-01, 0.22786100E-02, -.11993600E-01, -.29061300E-01, -.77102000E-02, -.17474200E-01, -.44677300E-03, 0.35846000E-02, 0.32130700E-02, 0.18126400E-02, 0.23919300E+00, -.25799200E-02, 0.14752200E-03, 0.11858600E-01, 0.13497700E-01, 0.16083800E-01, 0.13028900E-01, 0.29234600E-01, -.25850500E-01, 0.11183100E-01, -.78339700E-01, 0.25059000E-02, -.84138000E-02, 0.21929200E-02, -.22283900E-01, 0.20235300E-02, -.15689800E-01, -.14799500E-01, -.10011700E-01, -.23725300E-01, 0.84176100E-03, -.47937800E-01, 0.91419000E-01, 0.47599200E-01, 0.25652800E-02, 0.58863900E-01, 0.16096700E-01, -.83544700E-02, 0.66981300E-02, 0.22977600E-01, -.24836000E-01, 0.68608000E-01, -.82868500E-02, 0.12499000E-01, -.37436500E-02, 0.17801900E-02, -.42103700E-03, -.13078700E-01, -.13805300E-01, -.74495500E-02, -.50703300E-01, 0.19211400E-01, 0.19283500E-01, 0.53337600E-01, 0.26351000E-01, -.56425300E-02, -.11758700E-04, -.61823600E-02, 0.13920800E-01, 0.16863200E-01, -.26254300E+00, 0.71217100E-02, -.22982600E-01, -.46631700E-01, 0.59210100E-02, -.50201300E-02, 0.16405600E-01, 0.76619800E-03, 0.28605800E-01, -.25236400E-01, -.58373000E-02, 0.11767900E+00, -.25021600E+00, 0.16353800E-01, 0.34591100E-02, 0.21532000E-02, -.40385600E-02, -.10157600E-02, -.20465100E-02, 0.11845100E-01, -.14625400E-01, 0.72827000E-02, 0.24134900E-01, 0.37157600E-01, 0.14165000E-01, 0.24442400E-01, -.30775000E-01, 0.10214100E-01, -.46283300E-02, -.14750800E-02, 0.32472800E-01, -.90707400E-01, -.75103100E-01, -.84502900E-02, 0.76877000E-02, 0.55468200E-01, -.18026700E-01, 0.40730900E-01, -.76704800E-02, -.15433400E-01, -.33964600E-03, 0.41971100E-02, -.36676600E-01, 0.16772100E-01, 0.15879700E-01, -.28161300E-01, 0.15311900E-01, 0.61298700E-02, -.12650900E-01, 0.94134600E-02, 0.10216300E+02, -.88008800E-01, 0.35015000E+01, 0.38108300E+01, -.41101900E+01, -.44197300E+01, -.67807500E+01, 0.43265200E+01, -.18915300E+01, 0.18664100E+02, -.10195500E+02, -.37052300E+01, -.93789000E+01, -.58140000E+00, 0.37137100E+01, -.39575900E+01, 0.96017700E+01, -.97402600E+01, 0.29166000E+01, -.92972500E+00, 0.51016000E+01, -.23764000E+01, 0.13793600E+01, -.25492200E+01, -.39976600E+00, -.59395500E+00, -.14173500E+01, -.50259600E+00, -.31036200E+01, -.62468400E+00, -.23270800E+01, 0.63871600E+01, -.31621800E+01, 0.12495400E+01, -.32106000E+01, 0.30954000E+01, 0.36960500E+01, -.53256900E+01, 0.35864000E+01, -.96775000E+01, 0.41373000E+01, 0.31147700E+01, -.12291100E+02, 0.60983300E+01, 0.64479700E+01, 0.61134200E+01, 0.52736900E+01, 0.20364100E+01, 0.37629300E-01, -.50538200E+01, -.86553100E+00, 0.24187800E+01, 0.28881400E+01, -.34088900E-01, 0.13780500E+01, 0.50852000E+00, -.22352000E-01, 0.22399200E+00, -.22075400E+00, -.17302400E+00, -.27181900E+00, 0.69197700E-01, -.12406700E+00, 0.27651300E-01, 0.22762100E+00, 0.23825100E+00, 0.44226500E-01, 0.52051700E+00, 0.55056900E+00, -.70088300E+00, -.15173900E+00, 0.21058900E-01, 0.70496000E+00, 0.25592700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11706500E+01, -.11663500E+01, -.66659900E+01, -.62291900E+01, -.10891200E+02, 0.72241700E+01, -.10215200E+02, 0.20206200E+01, -.12153900E+01, 0.10666200E-01, 0.17120300E+00, -.30155400E+00, -.88410700E+00, 0.67786300E+00, -.32340500E+00, -.70317100E-01, -.39580300E-01, 0.25333200E+00, -.45738100E+00, -.59767000E-01, 0.24100600E+00, 0.39297400E+00, 0.28638300E+01, 0.57133400E-01, 0.35835400E+00, 0.23357900E-02, 0.36398300E+00, 0.19574100E+01, 0.85155600E+00, 0.10541000E+01, -.11296500E+01, 0.10527700E+01, -.54205500E+00, -.24138000E+00, 0.12992400E+01, 0.49815300E-01, -.82863600E-01, -.30308400E+00, 0.35579900E+00, 0.22292700E+01, -.27059600E+01, 0.24052500E+01, 0.46832700E-01, 0.54575900E+00, 0.20065500E+01, 0.82168500E-01, -.28394700E+01, 0.84011100E+00, -.27783000E+01, -.19925300E+01, -.52807800E-01, -.10826200E+01, 0.65799700E+00, 0.63184100E-01, 0.54478400E+00, 0.11688500E+00, -.11056700E+01, 0.71894600E-02, -.10494800E+01, -.26640500E-01, -.34415900E+00, 0.22349200E+01, -.55958500E+01, -.77569900E+00, -.17579400E+01, -.13689400E+01, -.13057500E-01, -.24641900E+00, -.73988400E+00, -.55225800E+00, -.12446800E+01, -.29958000E+00, 0.17397000E+00, -.66414200E+00, -.61309200E+00, -.67939300E+01, 0.26497600E+01, -.58475100E+01, 0.37114400E+00, -.20630300E-01, -.34291100E+00, -.25512700E+01, 0.17031300E-01, -.57718800E+00, 0.72428700E+00, 0.48587800E+01, -.41790300E+01, 0.69130400E+00, 0.14023700E+01, 0.63709400E+00, -.49950100E+01, 0.34600200E+00, 0.70587700E+00, -.89106900E-01, 0.55688700E+00, 0.11740800E+01, 0.11333400E+01, 0.29697500E+00, 0.17306400E+01, 0.38474200E+00, 0.50868700E+00, -.10686900E+01, 0.74834600E-01, 0.93995600E-02, 0.31174500E+00, -.78634500E+00, 0.27836300E-01, -.12181200E+01, 0.17377100E-02, -.16706600E+01, -.42495400E+00, 0.46628800E+00, -.12155100E+01, -.24412200E+00, 0.59232900E+00, 0.27772100E+00, 0.22845700E+00, 0.20098300E+01, 0.10319000E+00, 0.26027400E+00, 0.13099200E+01, 0.89236700E+00, -.22489100E+00, 0.88425700E+00, -.28575100E+00, -.91166200E+00, 0.90850100E+01, -.32690900E+00, 0.43339600E-01, -.14883700E+01, -.49724200E+00, -.62614500E+00, 0.28835600E+00, 0.17010800E+00, 0.66355500E-01, -.65904400E-01, 0.18261400E+01, -.15429800E+00, -.51840300E+00, -.45148600E+00, -.16677100E-01, 0.12820200E+01, 0.32923900E+00, -.70280600E+00, 0.30605700E+00, 0.15938600E+00, 0.80343300E-02, 0.22611700E+00, -.13532300E+01, -.10074400E+01, -.31671400E+00, 0.17020900E+00, -.78188900E+00, 0.10841200E+00, 0.18656100E+01, -.17581600E+00, -.24816000E+00, 0.39779900E+00, 0.56593900E+00, -.31377500E+00, -.81150700E+00, -.56099200E+00, -.46641200E+00, 0.36586100E+00, 0.75606400E+00, -.19850700E+00, 0.10741400E+00, 0.12259400E+02, 0.42320600E+02, 0.91863700E+01, 0.28488500E+02, -.14302700E+03, -.14685300E+03, -.27432500E+02, -.25112100E+02, 0.56999400E+02, 0.63664600E+03, -.33779200E+03, -.21543300E+03, -.31817300E+03, -.71087100E+02, 0.21544900E+03, -.32908900E+03, -.15346300E+03, -.33020400E+03, 0.14883100E+03, -.35996200E+03, -.25583600E+03, 0.11488300E+03, -.14525500E+02, 0.13211800E+03, 0.15568900E+03, 0.96321400E+02, -.45330600E+02, -.11012400E+03, 0.45124100E+02, 0.77248400E+02, 0.65307700E+02, 0.45217300E+03, -.22381000E+03, -.81386400E+02, -.21849100E+03, -.12961700E+03, 0.11499200E+03, -.19550300E+03, 0.15301700E+03, -.11337300E+03, 0.43234500E+01, -.16967400E+03, -.97815800E+01, 0.29219500E+01, 0.56047500E+02, 0.12092700E+02, 0.71659200E+02, 0.11856700E+03, -.17103500E+03, -.23523800E+03, -.15134000E+03, 0.93087600E+02, 0.52926600E+02, 0.57532400E+00, 0.12374600E+02, 0.51253700E+02, 0.47959400E+01, 0.51596400E+02, -.43603800E+01, -.50862500E+01, -.51586600E+02, 0.61432400E+02, -.40277800E+02, 0.51666100E+01, -.23476700E+01, 0.24313400E+02, -.42782200E+02, 0.50502100E+02, 0.30848400E+02, -.36724600E+01, -.67435900E+01, 0.39095800E+02, 0.12855200E+01, -.27425700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30307700E+00, -.15828000E+01, -.12382100E+01, 0.11656100E+00, 0.20217400E+00, -.93659300E+00, 0.18592600E+01, -.11120100E+00, 0.83853100E+00, 0.17356100E+01, 0.23274400E+00, -.16263400E+00, 0.16686800E+01, 0.88674700E+00, 0.71905500E+00, 0.68771400E+00, -.18533900E+01, -.12004300E+00, -.34556100E+00, 0.37005600E+00, 0.10623400E+00, -.19270000E+00, 0.89722100E+00, 0.27344400E+00, 0.12368300E+00, 0.25120000E-02, 0.36916800E+00, 0.68691300E+00, -.45885100E+00, -.83259500E-01, -.91484600E+00, -.49848900E-01, -.81203400E+00, 0.45385000E+00, -.36147100E-01, -.77494100E-01, 0.54863800E-01, -.23625900E+00, 0.93815100E-01, 0.79231300E-01, -.10595600E+00, 0.16594600E+01, -.11105900E-01, 0.12732900E+00, -.13692800E+01, 0.46526800E+00, -.98587100E+00, -.26274900E-01, 0.24727500E+00, -.58751900E+00, -.93622800E-01, -.31305000E+00, -.82132300E-01, -.11739100E+00, 0.17423900E+00, -.28944800E-01, -.86008200E-01, -.18684500E+00, 0.23597800E-01, 0.28414500E-01, 0.31769400E+00, 0.18476900E+00, 0.31700900E+00, 0.12284000E+00, 0.36383700E+00, -.32363900E-01, -.79432300E-01, -.23760100E+01, -.11843800E+00, 0.10968600E-01, -.70822400E-01, 0.16980800E+00, -.10918800E+00, -.32175500E+00, -.31557400E+00, -.26625900E+00, -.19282500E+00, 0.19959800E+01, 0.23073800E-01, 0.14222700E+00, -.73857700E-03, 0.10461200E+00, -.64561900E-01, -.19138900E+00, -.72352600E-01, 0.19759400E+00, 0.16994200E+00, 0.14360100E-01, 0.63400700E+00, -.27567900E+00, -.11378400E+01, 0.11367100E-02, 0.39042500E-01, -.10199300E+00, 0.13708800E+00, -.22239900E-01, -.20877200E+00, 0.21775500E+00, -.50058200E+00, 0.11165000E+00, -.50645100E-01, 0.12021000E-01, 0.40234700E-02, -.50653500E-01, 0.45464900E+00, 0.19918700E-01, 0.87167300E-01, 0.25533600E+00, -.22900800E+00, -.60397200E+00, -.73511300E+00, -.14333300E+00, -.17321800E+00, -.30637200E-01, 0.10201700E+00, 0.74341600E-02, -.11120600E+00, -.34094100E+01, 0.21883400E-01, -.48417200E+00, -.37730400E+00, 0.92179300E-01, 0.29277200E-01, 0.14657100E+00, -.99614600E-01, -.34998800E+00, 0.23326500E+01, -.42698300E+00, -.23062300E+01, -.45193800E+01, -.34518400E+00, -.17390700E+00, -.24061000E-02, -.30954000E-01, 0.36296700E-01, 0.58533700E-01, 0.14571200E+01, -.97516700E-01, -.70978000E-01, -.44652700E+00, 0.11945700E-01, 0.64867000E+00, -.13418900E+00, 0.15763500E+00, -.23104400E+00, 0.42347400E-01, -.16339200E-01, -.63764900E-01, 0.62785700E+00, 0.63038700E+00, 0.16655100E+00, -.67961800E+00, -.11331300E+01, 0.97131200E-01, 0.42225700E+00, 0.59964500E-01, -.46100100E+00, 0.23079900E-02, 0.21334300E+00, 0.12758600E+01, -.43853000E+00, -.64812100E+00, 0.77286200E-01, -.68417100E-01, 0.18927800E+00, -.46593900E+00, -.74079300E-01, -.43596800E+01, -.11036000E-01, 0.79019400E+02, 0.31509900E+02, -.47572700E+02, -.58722700E+02, -.59388400E+02, 0.21333900E+02, -.38506700E+01, 0.28510600E+03, -.14831300E+03, -.95713200E+02, -.14292400E+03, -.64431400E+02, 0.81542300E+02, -.11150900E+03, -.33562700E+02, -.14781100E+03, 0.52522400E+02, -.17337500E+03, -.10493300E+03, 0.49479600E+02, 0.12956400E+02, 0.51748000E+02, 0.37995700E+02, 0.30439700E+02, 0.23366000E+02, 0.70004600E+01, 0.32027800E+02, 0.14812000E+02, 0.61601800E+02, 0.24880500E+03, -.12368400E+03, -.59082700E+02, -.12406800E+03, -.58207500E+02, 0.91944700E+02, -.10214900E+03, 0.82126700E+02, -.10231200E+03, 0.40567700E+02, -.15465900E+03, 0.17312700E+02, -.95000000E+01, 0.20975700E+02, -.86262500E+01, 0.27626300E+02, 0.28587000E+02, -.56590800E+02, -.73694300E+02, -.63773000E+02, 0.24434400E+02, 0.25190600E+02, 0.87496500E+00, 0.63039900E+01, 0.18248300E+02, 0.19666000E+01, 0.15608400E+02, -.17369300E+01, -.18495000E+01, -.16174500E+02, 0.11574500E+02, -.10977000E+02, 0.44255500E+01, 0.46229500E+01, 0.74480300E+01, -.11499400E+02, 0.18117200E+02, 0.12834400E+02, -.59705000E+01, -.41182300E+01, 0.11212600E+02, 0.13893500E+01, -.66788400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29716200E+00, 0.26398100E+00, 0.86241600E+00, 0.46983500E+00, -.25801400E+01, 0.86535600E+00, 0.97054300E-01, 0.20738200E-01, 0.35242100E+00, 0.75234100E+00, 0.47543700E-01, 0.36482400E+00, -.45315400E+00, -.26878000E+00, 0.35480200E-02, 0.61007500E+00, -.91260900E-02, -.58315900E+00, 0.64452000E+00, -.56138800E+00, 0.52047400E-01, -.95341100E-01, 0.28627200E+01, 0.21283300E+00, 0.33957600E+00, 0.10759200E-02, 0.44701000E+00, 0.78316700E+00, 0.21789700E+00, -.11738900E-01, -.87521300E+00, 0.53067000E+00, -.73726400E+00, -.60352000E+00, 0.95835800E-01, -.20657400E+00, 0.22526600E+00, -.18409500E+00, -.33897500E+00, 0.15197000E+01, -.16401700E+01, -.41620500E+00, 0.37307300E+00, 0.27208500E+00, 0.68744900E+00, -.23067300E+00, -.23710800E+01, 0.15137800E+00, 0.17717300E-01, -.10906400E+01, -.72817800E-01, -.52417400E+00, 0.20851800E+00, 0.21613100E+00, 0.12326000E+01, 0.31304000E+00, -.94244600E+00, -.38204800E-01, -.19154000E+00, 0.36161400E-01, -.37456600E-01, -.16928300E+00, -.12531600E+01, 0.13502500E+00, -.72144200E+00, -.48096600E+00, -.36914800E+00, 0.13326100E+01, -.24603100E+00, -.53728700E-02, -.47541900E+00, -.68201400E-01, 0.22076700E+00, -.52526600E+00, -.32022500E+00, -.20899300E+01, 0.17980800E+00, 0.15577200E+01, 0.19106600E+00, 0.19105800E+00, -.24859900E-01, -.27825900E+00, -.36198000E+00, -.62742000E+00, -.22247100E+00, 0.23564000E+00, -.34990400E+00, 0.75315700E-01, 0.45407600E+00, 0.23647800E+00, -.29711000E+01, 0.21611600E-01, 0.71189200E+00, 0.14593500E+00, 0.43439200E+00, 0.85255400E+00, 0.14128800E+00, 0.14269800E+00, 0.11088000E+01, 0.71802900E-01, 0.45511200E+00, -.54812800E+00, -.51174700E-01, -.24165200E+00, 0.15479300E+00, -.30062500E+00, 0.18225700E-01, -.76999700E+00, -.63814100E+00, -.10216600E+01, -.41885900E+00, -.46815700E-01, -.79906400E+00, 0.39929700E-01, 0.28227500E+00, -.19236600E+00, 0.49492500E-01, 0.11778900E+00, -.28248800E-01, 0.62899600E+00, 0.28223800E+00, 0.42180300E+00, 0.70426300E-01, 0.82085000E+00, -.74987500E-02, -.11862700E+01, 0.22260900E+01, -.33983200E+00, 0.46438800E+00, -.31089200E+01, -.14188200E+01, -.58756000E+00, -.14118700E+00, 0.88851400E-01, -.69599800E-01, -.10275500E+00, 0.94412300E+00, -.85795200E-02, 0.38805100E+00, -.24052700E-01, 0.36030900E+00, 0.26416400E+00, 0.27197200E+00, -.19399600E+00, 0.20934300E-01, -.83453500E-02, 0.68248200E-02, 0.69915500E-01, -.79123700E-01, -.15732100E+00, 0.48497400E-01, -.30141900E+00, -.27880700E-02, -.13474900E+00, 0.14556600E+01, 0.24873300E-01, -.36772300E+00, 0.48888100E-01, 0.19522300E+00, -.43909700E+00, -.39668100E+00, 0.32158100E-01, -.28477900E+00, 0.30183100E-01, 0.38769600E+00, -.27826000E+00, -.57939900E-02, 0.34451700E+01, -.17829800E-01, 0.38096600E-01, 0.32615800E+02, -.17488400E+02, -.34122300E+02, -.23221300E+02, 0.16701400E+02, -.24154400E+01, 0.17877800E+03, -.98056700E+02, -.10684200E+03, -.89832700E+02, -.87471700E+02, 0.67279200E+02, -.94424400E+02, -.75536600E+02, -.10173200E+03, 0.44776600E+02, -.18652400E+03, -.60154200E+02, 0.22268900E+02, -.46944400E+01, 0.30904500E+02, 0.53541700E+02, 0.40070100E+02, -.49157000E+01, 0.38133900E+01, 0.15896600E+02, 0.30958400E+02, 0.17495200E+02, 0.15159200E+03, -.73538200E+02, -.68138900E+02, -.75576300E+02, -.81646500E+02, 0.47070500E+02, -.73866200E+02, 0.74432800E+01, -.18830800E+02, 0.78076100E+01, -.14167900E+03, 0.87300400E+02, -.45348500E+02, 0.60538900E+01, -.43688700E+02, 0.16127900E+02, 0.43062800E+02, -.62269200E+02, -.65168300E+02, -.83032300E+02, 0.36877200E+02, -.97365100E+01, 0.99161300E+00, -.46066000E+01, 0.17891700E+02, 0.23684500E+01, 0.13757300E+02, -.66161900E+00, -.68394400E+01, -.13870700E+02, 0.19504000E+02, -.11287800E+02, 0.35566100E+01, 0.19241700E+01, 0.12950200E+02, -.12079400E+02, 0.17530200E+02, 0.13964700E+02, 0.73671900E+01, -.46383000E+01, 0.14917300E+02, 0.48898400E+01, -.63028900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.57216100E+00, 0.13323500E+00, -.36580100E+01, 0.21855400E+00, 0.34493200E+00, -.81018400E+00, 0.12791000E+01, -.28952000E+00, -.30644700E+00, 0.17747000E+01, 0.24893000E+01, -.54924800E+00, 0.29938700E+01, 0.14048400E+01, -.40884900E+00, 0.14137700E+00, 0.35800500E+01, -.16217100E-01, -.26885600E+01, 0.22733900E+01, 0.38327300E+00, -.14060400E+00, -.27068400E+01, -.22189700E+00, -.31651500E+00, -.18162600E-02, -.43821900E+00, -.10673400E+01, -.11704600E-01, 0.46205700E+00, 0.54392200E+00, 0.52180300E-01, 0.41385700E+00, 0.89924300E+00, -.98126200E+00, 0.19021400E+00, -.18031300E+00, 0.43400500E+00, 0.30276300E+00, -.19675400E+01, 0.18075600E+01, 0.72784800E+00, -.61356100E+00, -.69170600E+00, -.23848600E+01, 0.86088900E+00, 0.83049700E+00, 0.13917800E-01, 0.18432400E+01, 0.17104200E+01, -.77410600E+00, 0.10263000E+00, 0.18623600E+01, 0.46711200E+00, -.12229100E+00, -.43347200E+00, 0.68902300E+00, -.15709700E+01, 0.23871100E+00, -.83763500E+00, 0.42654700E+00, 0.25849900E+00, 0.50054900E+00, -.12916100E+00, -.37471600E-01, 0.88953100E+00, 0.35104800E+00, 0.73584900E+01, -.11111100E+00, -.40066900E-01, -.11252900E+00, -.37606300E+00, -.21502000E+00, 0.16954000E+00, -.40454200E+00, -.17558400E+01, -.27755300E+01, 0.23685100E+01, -.26318400E+00, 0.50191900E+00, -.66080100E-01, 0.21156300E+01, -.82983100E+00, -.31872700E+00, -.65922500E+00, 0.12099400E+01, 0.11621200E+01, -.23767500E+00, 0.14231000E+01, -.83390300E+00, 0.27031200E+01, -.11807900E+00, 0.29262400E+00, -.29451100E+00, 0.45117200E-01, -.43013600E+00, 0.77311200E-01, 0.45870100E+00, 0.18619900E+00, 0.14545500E+00, -.89476700E+00, -.25536900E+00, -.13122600E+00, 0.31173700E+00, -.13142300E+01, 0.78240800E+00, 0.36161400E+00, 0.12878400E+01, -.80866200E+00, 0.10817900E+00, 0.89617500E-01, -.11141500E+01, 0.15806600E+01, 0.14699100E+00, -.55373300E+00, 0.16808100E+01, -.19494500E+00, 0.11796700E+02, -.43940800E+00, 0.14949200E+00, -.15367200E+01, -.37490400E-02, -.43839500E+00, 0.81007600E+00, 0.20263400E-01, 0.21067900E+00, -.23590700E+01, -.87931600E+00, 0.26969100E+01, 0.22047200E+01, 0.10356600E+01, 0.28920100E+00, 0.63971500E+00, -.15986700E+00, -.51754400E-01, 0.11935500E+00, 0.16114600E+01, -.52252500E+00, 0.20872200E+01, -.89630500E+00, -.27585800E+00, 0.12145500E+00, 0.87159000E-01, 0.19309500E+00, 0.12658700E+00, 0.16128600E+00, 0.24105900E-01, -.45888300E+00, 0.79224100E+00, 0.12599100E+01, -.24490800E+00, 0.62828200E+00, -.38257100E+00, -.21578000E-01, -.24831900E+00, -.57660700E-01, -.41772700E+00, -.32403400E-01, -.57507400E+00, -.17042700E-02, 0.42459500E+00, 0.76369400E+00, 0.31890900E+00, -.31060700E+00, -.74241600E+00, 0.17804600E+01, -.18708300E-03, -.22400200E+02, 0.43269500E-01, 0.60281500E+00, -.11264800E+01, 0.15667100E+03, 0.17958600E+03, 0.26311300E+02, 0.90083300E+02, -.14024000E+03, -.28162500E+03, 0.15985300E+03, 0.11004000E+03, 0.14135000E+03, 0.50514800E+02, -.31964300E+02, 0.19262400E+03, 0.20925700E+03, 0.15548400E+03, 0.37729000E+02, -.20722500E+01, 0.41292100E+03, -.17503200E+03, -.66497000E+02, -.20677300E+03, -.21264200E+03, -.10698600E+03, -.19271700E+02, 0.94652200E+02, -.10396900E+03, -.85488000E+02, -.10239400E+03, -.62946300E+03, 0.31026200E+03, 0.98776400E+02, 0.31413200E+03, 0.25093000E+02, -.98980600E+02, 0.24651800E+03, -.13120500E+03, 0.21470300E+03, -.12790200E+02, 0.24095200E+03, -.56943400E+02, 0.31180500E+02, 0.16167800E+02, 0.28473100E+02, -.70381600E+02, -.12390900E+03, 0.19843700E+03, 0.21212800E+03, 0.15902200E+03, -.85542200E+02, -.87308200E+02, -.80273500E+00, -.13459100E+02, -.56075500E+02, -.65758200E+01, -.60456700E+02, -.66390500E+00, 0.75443700E+01, 0.60261400E+02, -.70696700E+02, 0.48902900E+02, -.49090300E+01, -.33791800E+01, -.13673100E+02, 0.53236000E+02, -.55936800E+02, -.22372000E+02, -.13172000E+01, -.26088400E+02, -.49584900E+02, -.59810100E+01, 0.34393800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16373900E+00, -.14542300E+00, -.11585600E+01, -.14754200E+00, -.19665700E+00, 0.13377700E+00, 0.59351700E-01, 0.30236600E-01, -.19923800E+00, 0.31338900E+00, 0.10642700E+00, 0.91470900E-01, -.16319500E+00, 0.46699100E-01, 0.51561000E-01, -.20586700E+00, 0.30778100E+00, 0.28445900E-01, -.72466900E-01, 0.11057700E+00, 0.30433500E-01, -.10821400E-01, 0.31240200E+00, 0.20569400E-01, 0.14052000E-01, 0.45957400E-01, 0.46492400E-01, -.54821700E-01, -.50108300E-01, -.12587600E+00, -.80289500E-01, -.50788400E-01, -.11218800E+00, -.18477900E-01, 0.13346800E+00, 0.11647100E-01, 0.36357600E-01, -.27406000E-01, -.37035700E-01, 0.63882300E-01, -.13382600E+00, 0.14957400E+00, 0.18283300E-01, 0.35304700E-01, -.10303700E-01, -.16400700E-01, -.53351900E-01, 0.19459400E-02, -.90486500E-01, -.34259900E-01, -.41121700E-01, -.26797400E-01, 0.78254300E-01, 0.69615600E-01, 0.10392900E+00, 0.40576500E-01, -.26510900E+00, 0.30382700E+00, -.14838000E-01, 0.68527000E-01, 0.17962200E+00, 0.23792000E-01, 0.12722100E+00, -.20214800E-01, -.17257700E+00, -.13694700E-01, -.34365800E-02, -.19153600E+01, -.45386000E-01, 0.37278500E-02, -.93195900E-01, -.12450400E+00, -.11961000E+00, -.64094700E-01, 0.13237800E-01, -.66283500E-01, -.15512900E+00, -.16921500E-01, 0.12074700E-02, 0.17227100E-01, -.88070000E-03, -.31155600E-01, 0.15391500E-01, 0.76715700E-01, 0.34111400E-01, 0.43212100E-02, 0.39163000E-01, -.10723500E-01, 0.69972900E-01, 0.42417300E-01, 0.14699300E+00, -.10724100E-02, 0.68389300E-02, -.65692400E-01, -.21170700E-01, 0.36778000E-01, 0.87279500E-01, -.47054400E-01, 0.39440000E-01, -.51000900E-01, 0.57052700E-01, 0.12022300E-01, 0.96763200E-02, -.18537700E-01, -.19139400E-01, 0.53889600E-02, 0.20535100E-01, -.87022400E-01, -.85423200E-01, -.18236300E+00, 0.15786100E+00, 0.11596700E+00, 0.68504200E-01, -.12729500E-01, 0.94532100E-02, -.23843200E+00, 0.20312100E-01, 0.50575800E+00, 0.19444300E-02, 0.15509500E+00, 0.13010300E+00, 0.89592800E-01, 0.35544300E-01, 0.15329100E+00, -.10349000E-01, -.18795600E+00, 0.48372900E+00, -.69696200E-01, 0.22756600E+00, -.19420000E+00, -.64845000E-01, -.48865200E-01, -.52669300E-01, 0.21732700E-01, 0.11027400E-01, -.26310400E-01, 0.93687500E+00, -.11653500E+00, -.16289400E+00, -.28098500E+00, -.13547900E+00, 0.50664500E+00, -.15852100E+00, 0.79843000E-01, -.40620400E-01, 0.38533600E-02, 0.70057400E-02, -.20360000E+00, 0.37647500E+00, 0.31224100E+00, 0.44480300E-01, -.77995700E-01, -.48902500E+00, 0.85906000E-01, -.52401900E-01, 0.29758500E-01, 0.92101300E-01, 0.20806800E-01, 0.31731300E-01, -.50725800E+00, -.22890900E+00, -.39866500E+00, 0.41202100E-02, 0.12322400E+00, 0.38198500E-01, 0.38654300E+00, 0.58343200E-03, 0.76919800E+00, 0.10728800E-01, -.20134600E-01, 0.30168900E+00, 0.20019000E+00, 0.27541700E+02, 0.67644300E+01, -.60414600E+01, 0.23281800E+02, 0.25621800E+02, -.68339500E+01, 0.93753500E+01, -.12614100E+02, -.60301200E+01, -.51706000E+02, 0.53867100E+01, 0.27304000E+02, -.49925300E+01, -.45150500E+02, 0.71027700E+02, 0.43739400E+02, -.23421700E+02, -.35742900E+02, -.22593600E+02, -.28828200E+01, 0.77494100E+01, -.18999000E+02, -.73348300E+01, -.22655800E+02, 0.14169700E+02, 0.61747600E+00, 0.92645400E+02, -.47698100E+02, -.27291000E+02, -.46277600E+02, 0.19690600E+02, -.95099600E+01, -.12918700E+02, 0.84587500E+02, -.26562600E+02, -.46822800E+01, -.12339300E+02, 0.16503600E+02, -.72236300E+01, -.17490400E+02, -.81687900E+01, -.80920300E+01, 0.23576800E+00, -.18197500E+02, 0.23513000E+01, 0.12373700E+01, 0.15580400E+01, -.14645900E+02, -.69462400E+01, -.92607600E+00, 0.38755900E+01, -.55259000E+00, 0.33626200E+01, 0.65808900E+00, -.19027400E+01, -.32872400E+01, 0.13013300E+01, -.42735400E+01, -.47465100E+01, -.25296900E+01, -.33843600E+01, -.51114000E+01, 0.39956700E+01, -.12793300E+01, 0.15734500E+01, 0.13130400E+02, 0.13466800E+00, -.13352000E+01, -.12240800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27676900E+00, -.19868200E+01, -.45358300E+01, -.34032500E+01, 0.42550800E-01, 0.26906500E+00, -.13157700E+01, 0.27931200E+00, -.38682500E+01, -.12176100E+01, 0.30060200E+00, -.33642400E+00, -.15091600E+01, 0.12087200E+01, 0.25834800E+00, -.22423700E+01, 0.17929900E+01, 0.19117500E+01, -.11572800E+01, 0.15598700E+00, 0.24149100E-01, 0.25165400E+00, -.33229300E+00, -.13765700E+00, -.33365000E+00, -.12976200E-02, 0.22769600E-02, 0.19659300E+01, 0.20474100E-01, 0.14142800E+01, -.11432700E+00, 0.35085400E+00, -.27638700E+00, 0.22985400E+00, 0.23412800E+00, -.82035800E-01, 0.10667600E+00, -.59528900E-01, 0.62185900E-01, 0.73361100E+00, -.97036400E+00, 0.51137700E+00, -.30470000E-01, 0.92060200E-01, -.53359600E+00, 0.15624800E+00, 0.22126200E+01, 0.80761500E-01, -.26575700E+01, 0.11641800E+00, -.54733500E+00, 0.30876700E+00, 0.14798200E+01, 0.11000900E+00, 0.65434500E+00, 0.94676000E-01, -.31636300E+00, -.77280500E-01, -.90783100E-01, 0.95741400E-01, -.60420700E+00, -.44026200E+00, -.27610000E+01, -.11932700E+00, 0.15785800E+01, 0.16317900E+00, 0.35828000E+00, 0.44561200E+01, -.27200900E+00, -.16535600E-01, 0.88261000E-01, 0.46485200E+00, -.99073000E-02, 0.32397600E+00, -.62693700E-01, -.56545600E+00, 0.87284100E+00, -.36454700E+01, 0.59013100E-02, 0.17801200E+00, -.19820400E-01, 0.97745700E-01, 0.25074100E-01, -.27506300E+00, 0.71093400E-01, 0.84561100E+00, -.84607700E+00, 0.96605100E-01, 0.27991400E-01, 0.36443200E+00, 0.29455400E+01, 0.51627800E-01, 0.73970400E+00, -.30316500E+00, -.42943400E+00, -.37642700E+00, 0.10568600E+01, -.16165300E+00, 0.11233000E+01, 0.11865500E+00, -.38672300E+00, -.77890900E-01, 0.27211100E-01, 0.54874300E+00, -.61427600E+00, 0.91824900E-03, -.10336100E+00, 0.69189200E+00, 0.11202300E+01, 0.10137100E+01, 0.96843200E+00, 0.30629700E+00, 0.30564700E+00, -.43614300E-01, 0.18938500E-01, 0.45316200E-01, -.14432400E+00, 0.97563600E+01, -.26344900E-01, 0.10076100E+01, 0.34647000E+00, 0.96465200E-02, 0.16686300E+00, -.69042700E-01, -.28756300E-01, -.27668300E+00, 0.79460700E+01, 0.11018600E+00, -.25153300E+01, -.31531700E+01, 0.36558200E+00, -.64866400E+00, 0.23231100E+00, -.20864600E+00, 0.41569600E-01, 0.41342800E-01, -.58954400E+00, 0.29477200E-01, -.13642200E+00, 0.68372100E-01, 0.37673800E+00, -.24344300E+00, 0.67930500E+00, -.69165200E+00, 0.20282000E+00, -.23250800E-01, -.42595800E-01, 0.79072800E+00, -.14765100E+01, -.17245000E+01, -.51229200E-01, 0.18648400E+00, 0.22942800E+01, -.45653500E+00, 0.20943800E+01, -.19350700E+00, -.27073400E+00, 0.18702900E-01, 0.55056100E-01, 0.69578500E+00, 0.99142900E-01, -.33425100E-01, -.31614800E-01, 0.23367400E+00, 0.36520400E+00, -.49693000E+00, 0.69082200E-01, 0.63439200E+01, -.25542300E-01, -.24577400E+00, 0.48725300E+00, -.70780900E+00, 0.67039700E+00, 0.40276900E+02, 0.28617600E+02, -.39424100E+02, -.11821600E+03, 0.56181000E+02, 0.22197000E+02, 0.58810800E+02, -.37340500E+02, 0.40983000E+02, 0.33961500E+02, 0.26214900E+02, 0.57113400E+02, 0.48576300E+02, -.99496600E+02, 0.10697700E+03, -.41868100E+02, 0.67909400E+00, -.52835400E+02, -.41523900E+02, -.31362500E+02, -.11137900E+02, 0.32467300E+02, -.92268300E+01, -.37924000E+02, -.34900600E+02, -.25447500E+03, 0.12611500E+03, 0.28696600E+02, 0.12688800E+03, -.50444400E+02, -.21662000E+02, 0.46096000E+02, -.15776800E+03, 0.83279400E+02, 0.25773600E+01, 0.64738300E+02, -.11512500E+02, 0.62311500E+01, 0.23066300E+02, 0.55875700E+01, 0.92922000E+01, -.19354400E+02, 0.54359300E+02, 0.38426400E+02, 0.47406900E+01, -.10073600E+02, -.21449500E+02, 0.48847800E+01, 0.50366600E+01, -.25718400E+02, -.21358000E+01, -.30461300E+02, -.29826700E+01, 0.61737800E+01, 0.30270800E+02, -.15923800E+02, 0.28468200E+02, 0.19847900E+00, -.15072000E+01, 0.33044100E+01, 0.31155500E+02, -.26371300E+02, -.14346100E+01, -.86342600E+01, -.13244800E+02, -.12431900E+02, -.16304600E+01, 0.14933000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.60870800E+00, -.54559300E+00, 0.49236500E+01, -.10884800E+01, -.16843500E+01, 0.13503800E+01, -.31548200E+01, 0.48713200E+00, 0.16231200E+00, -.21662000E+01, -.32832200E+01, 0.17260300E+00, -.33272100E+01, -.24509900E+01, 0.68573400E+00, -.66920200E-01, -.49525500E+01, 0.64506400E+00, 0.31121000E+01, -.36203100E+01, -.67566900E+00, 0.27502700E-01, 0.16650700E+01, 0.11777200E+00, 0.69233000E-01, 0.25949100E-03, 0.33141800E+00, 0.63594500E+00, 0.10501000E+01, 0.18011300E+00, -.33282900E+00, -.45777700E+00, 0.16728100E+00, 0.17746500E+00, -.27750900E+00, -.12004800E+00, 0.10919300E+00, -.91256100E-01, -.77954800E-01, 0.77566700E+00, -.64802300E+00, 0.48494000E+00, 0.24318800E+00, 0.29014200E+00, -.31661400E+01, 0.63995600E+00, 0.12085400E+01, 0.36946800E-01, -.15669900E+01, -.13535200E+01, -.37086700E+00, -.10142400E+01, -.12658800E+01, 0.10548000E+01, -.96019300E+00, 0.10214800E+01, -.18280000E+01, 0.39442600E+01, -.41967800E+00, 0.59547100E-01, 0.29184100E-01, -.61972900E+00, -.33784900E+01, -.45513200E+00, -.10469200E+01, 0.31167900E+00, -.70931400E+00, -.95373800E+01, -.10301000E+00, -.40375500E-01, -.42834000E+00, -.28328500E+00, -.18617500E+00, -.63382600E+00, 0.36960700E+00, -.40571300E+00, -.14188200E+00, -.47152900E-02, -.16028300E+00, -.45173100E+00, -.40366500E-01, -.88334900E+00, 0.11566000E+00, 0.69701800E+00, 0.29555000E+00, -.14756700E+01, 0.25166400E+00, -.15090700E+00, 0.17137600E+00, -.94837300E+00, -.47307600E+01, -.88169800E-01, -.77726600E+00, 0.24751000E+00, 0.42320900E+00, -.20255600E+00, -.12066700E+01, 0.26604800E+00, -.22810000E+00, 0.87477500E-01, 0.61975000E+00, -.15328400E+00, -.73616400E-01, -.15587900E+00, 0.14553200E+01, -.27466900E+00, -.16671900E+00, -.87360900E+00, 0.51279000E+00, 0.97830700E+00, 0.13721800E+01, 0.12913600E+01, -.95124600E+00, 0.14484000E+00, 0.46570400E+00, 0.59516700E+00, 0.61387700E+00, -.25087600E+02, 0.34353900E+00, -.17576800E+01, -.33095500E+01, 0.37321000E-02, 0.46012600E+00, -.35549500E+00, 0.41593700E-02, 0.46722100E+00, -.52551600E+01, 0.60936900E+00, -.46404700E+00, -.84908000E+01, 0.13159500E+01, 0.38147700E+00, -.10629700E+01, 0.94255700E-01, 0.12308700E+00, -.20517800E+00, -.33976700E+01, 0.36640500E+00, -.13991600E+01, 0.15401900E+01, 0.51743300E+00, -.83639600E+00, 0.83396000E+00, -.33686200E+00, -.78369500E-01, -.11918700E+00, -.10546800E+00, 0.16686700E+01, -.15139700E+01, -.27347300E+01, -.95181400E-01, 0.13761800E+01, 0.13122600E+01, -.65644100E+00, 0.63955500E+00, -.68328100E-01, 0.26075100E+01, 0.10394900E+00, 0.11581700E+01, 0.14306200E+01, 0.65000300E+00, -.36498900E-01, -.14782600E+01, 0.28885100E+00, 0.68907800E+00, -.51979500E+00, 0.49277600E-01, 0.25548700E+02, 0.40135900E-01, -.28882800E+00, 0.20145600E+01, -.11442600E+01, -.24160300E+01, -.78150500E+00, 0.10215700E+03, -.97309600E+02, -.17031100E+03, 0.11874900E+03, 0.28401800E+03, 0.84554700E+02, -.26714400E+02, 0.51110400E+02, 0.73287800E+02, 0.18593700E+03, 0.39766200E+02, 0.14734500E+03, -.23959600E+03, 0.68192000E+03, -.30723700E+03, -.14125000E+03, -.34255100E+03, -.17605400E+03, -.57513500E+02, -.15133700E+03, 0.38613000E+02, -.20881300E+03, -.50167000E+02, -.24332400E+03, -.78116800E+03, 0.38390900E+03, 0.25935800E+03, 0.39044900E+03, 0.85725100E+01, -.14704500E+03, 0.21773500E+03, -.18242800E+03, 0.21113000E+03, -.33623000E+02, 0.22774400E+03, -.22297200E+03, 0.11586600E+03, 0.52211900E+02, 0.11244600E+03, -.15497000E+02, -.10877400E+03, 0.18301500E+03, 0.96074100E+02, 0.12459500E+03, -.57704900E+02, -.41331200E+02, -.14411000E+02, 0.24950100E+02, -.59768700E+02, -.85627700E+01, -.66560600E+02, -.10977600E+02, 0.11536100E+02, 0.66671500E+02, -.59512800E+02, 0.51994500E+02, -.20660300E+02, -.17414300E+02, -.63798700E+01, 0.58171800E+02, -.60560300E+02, -.14296500E+02, -.36407800E+02, -.28367000E+02, -.49996800E+02, 0.76354600E+01, 0.44618100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.45192800E+00, 0.16067700E+00, -.30107000E+01, 0.72576800E+00, 0.15215400E+01, -.14373900E+01, 0.29159800E+01, -.33369200E+00, 0.84304200E+00, 0.19960700E+01, 0.20781000E+01, -.81990600E+00, 0.21036800E+01, 0.14400500E+01, -.25004300E+00, -.12366100E+00, 0.40087900E+01, 0.15265300E+00, -.22972600E+01, 0.20166600E+01, 0.42959400E+00, -.19827800E+00, -.40890700E+00, -.19042600E-01, -.19112200E+00, -.12796200E-02, -.26752600E-01, 0.14911000E+00, -.22008900E+00, 0.14267900E+00, -.15480700E+00, 0.96516600E-01, -.17423700E+00, -.30509500E+00, 0.72323200E-01, -.95389900E-01, 0.62065300E-01, -.10389400E-01, -.25813400E+00, 0.27413900E+00, 0.10510900E+00, -.12937300E+01, 0.26837400E+00, -.92016100E-01, -.97743900E-01, -.30804400E+00, -.74403900E+00, 0.61376800E-01, 0.17506600E+01, 0.47964100E+00, 0.11016500E+00, 0.11667000E+00, -.65578000E+00, -.26821600E+00, 0.38550600E+00, 0.94109500E-03, -.16158500E+00, -.60308400E+00, 0.23742300E-01, 0.41097600E+00, -.50295700E+00, -.59321700E+00, 0.69441400E+00, 0.43608800E+00, 0.38339500E-01, -.32843300E+00, -.57223100E-01, 0.10351100E+02, 0.14476600E+00, 0.20078500E-01, -.61744600E-01, -.14200400E+00, 0.24888200E+00, 0.24591400E+00, 0.65110400E-01, -.23827600E+00, -.13077100E+00, 0.10490000E+01, 0.67781500E-01, -.11111100E-01, -.88638400E-02, 0.14197000E+00, -.83478700E-01, -.74403500E+00, -.46057300E+00, 0.11480200E+01, -.36008800E+00, 0.79774800E-01, -.18631700E+00, 0.11147400E+01, 0.15538800E+01, 0.48105500E-01, 0.72045200E+00, 0.24469900E+00, 0.44217400E-01, 0.29754600E+00, -.21988600E-01, -.18281800E+00, 0.51110900E-01, -.72854300E-02, -.46801200E-01, 0.15351600E+00, -.21761800E-01, -.27483100E+00, 0.18266300E+00, 0.10156200E+00, 0.99019800E-01, -.71028000E+00, -.76472700E+00, 0.16183400E+01, 0.85712800E+00, 0.15978900E+00, 0.27812800E+00, -.27611300E-01, 0.14968400E+00, -.57364100E+00, -.28116000E+00, -.13602000E+02, 0.23477000E+00, -.10627300E+01, -.18238400E+01, -.66342300E-01, 0.25074300E+00, -.21821100E+00, -.56248200E-01, 0.65152600E+00, -.75158500E+01, 0.18487400E+00, 0.83659900E-01, -.96744800E+01, -.15217300E+00, 0.14154100E+00, -.48224800E+00, -.17614100E+00, -.21296800E+00, 0.67952800E-01, 0.47266900E+00, -.36478800E+00, 0.10556000E+01, 0.54003400E+00, 0.75983900E+00, -.36071200E+00, 0.40624000E+00, -.36204600E+00, 0.88062300E-01, -.15806900E+00, -.37698800E-01, 0.28010800E+00, 0.20416600E+00, -.28797800E+00, 0.20526900E+00, 0.15125300E+00, 0.11445600E+01, -.41896800E+00, 0.89261600E+00, -.42710300E-01, -.25782100E+00, -.49045200E-01, 0.87796300E-01, 0.24023500E+01, 0.46567800E+00, 0.39729300E+00, -.10842100E+00, -.15950600E+00, -.23023300E+00, -.15736100E+00, -.29233300E-01, -.25955400E+01, -.44173100E-01, -.10498600E-01, -.68318100E+00, 0.18322800E+00, -.23306800E+01, -.45143600E+00, -.11201700E+00, -.57666300E+02, -.86789900E+02, 0.40325100E+02, 0.10889500E+03, 0.43132200E+02, -.16714600E+03, -.55035300E+02, -.12361000E+02, -.94139100E+02, 0.41177800E-01, -.45077800E+02, -.14141900E+02, 0.27847200E+03, -.15337900E+03, -.10119200E+03, -.13854200E+03, 0.12796300E+02, 0.26520100E+02, -.74142000E+02, 0.35038800E+02, -.71674000E+02, 0.19364200E+02, -.60652000E+02, 0.75760900E+02, -.38415600E+02, -.26123900E+02, -.37815400E+02, -.19265900E+02, 0.84285900E+01, -.96827800E+02, -.50018800E+02, -.37367500E+02, 0.13604500E+02, -.20319800E+03, 0.12537200E+03, -.62381100E+02, -.55615200E+02, -.62870600E+02, 0.19897900E+02, 0.59769500E+00, -.38145400E+02, -.75061100E+01, -.70481800E+02, 0.65848900E+01, -.71714000E+02, -.15013800E+02, 0.11993400E+02, 0.75532400E+01, -.17361100E+01, -.69975300E+01, -.72229500E+01, -.21139300E+01, 0.67469100E+01, 0.22554000E+01, 0.36708800E+01, -.14079000E+02, -.79671100E+01, 0.44328500E+01, 0.36082100E+01, 0.69686000E+01, 0.53040200E+01, -.95692300E+01, 0.23123100E+02, -.63742600E+00, 0.84179000E+01, 0.99314000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28847800E+00, -.14674200E+01, -.41328300E+01, -.24786000E+01, 0.71529000E+00, 0.48596400E-01, -.61608400E+00, 0.14656600E+00, -.32168700E+01, -.14334400E+01, 0.22516400E+00, 0.22265400E+00, -.11026300E+01, 0.13251700E+01, 0.21899600E+00, -.21057700E+01, 0.15558500E+01, 0.94784500E+00, -.10571000E+01, 0.11489000E+01, 0.37970600E-01, 0.26220500E+00, -.11803600E+00, -.11225800E+00, -.79228300E+00, -.90755900E-03, -.13847700E+00, 0.12947700E+01, -.70340100E+00, -.21172600E+00, 0.29163000E+00, -.56045200E+00, -.10281100E+01, -.88501300E+00, 0.32712700E+01, 0.75538700E-02, 0.15782400E+00, -.69463100E+00, -.27930300E+00, 0.20999800E+01, -.21316300E+01, -.12252800E+01, 0.55607400E+00, 0.45555500E-01, 0.37477200E+01, -.12174900E+01, 0.18225800E+01, 0.37866400E-02, -.17624300E+01, 0.38702600E+00, 0.48389100E-01, 0.10944000E+01, 0.16874400E+01, 0.64189600E+00, -.36358400E+00, 0.32525000E+00, 0.10769100E+01, 0.11580800E+01, 0.22000300E-01, 0.59495700E+00, -.95573500E+00, -.14284000E+01, 0.26743300E+01, 0.58458900E+00, 0.70495300E+00, -.16526500E+00, 0.24264200E+00, 0.59304300E+01, -.88772300E-01, -.15475200E-01, 0.20550000E+00, 0.37892300E+00, 0.19553300E-01, 0.43203500E+00, 0.49593400E+00, 0.57160500E-01, 0.52768800E+00, -.13739000E+01, 0.23859600E+00, -.10513300E+00, 0.26192400E-01, 0.54512500E+00, -.15399700E+00, -.36044400E+00, -.19635500E+00, 0.44405900E+00, -.80276700E+00, -.30328300E-01, 0.49494500E+00, 0.10037900E+01, -.73665700E-01, 0.84256800E-02, 0.25611900E+00, -.71300400E-01, -.23333600E+00, -.25422100E+00, 0.58237300E+00, 0.29747500E+00, -.93304800E-02, 0.60344200E+00, -.39458500E+00, -.42866100E-01, 0.23181400E-01, 0.11152400E+00, 0.44699000E+00, -.30876200E+00, -.81226900E-01, 0.36706000E+00, 0.42340800E+00, 0.39243300E-01, -.43246400E-01, 0.78832100E-01, 0.36218900E-01, -.45879900E-01, -.10499400E+00, -.47469900E+00, 0.11997100E+00, -.51809300E+01, 0.15593600E+00, 0.39484200E+00, -.39971900E+00, 0.40249400E+00, 0.32429600E-01, 0.51836900E+00, 0.50958300E-02, -.68805400E+00, -.98528500E+00, 0.13484400E+00, -.20432200E+01, -.98065200E+01, 0.11692100E+01, -.34208200E+00, -.15205000E+00, -.17949200E+00, -.31700100E+00, 0.33655400E-01, 0.84038600E-01, -.36133100E+00, 0.17166700E+01, 0.38422600E-01, 0.67929500E+00, 0.79238400E+00, -.43455300E-01, -.12371100E+00, 0.76962600E-01, -.18827100E+00, -.26020900E-01, -.50865900E-01, 0.84560500E+00, 0.14029300E+00, 0.29331500E+00, 0.21403900E-01, -.11090500E+00, -.20494900E+00, 0.36613000E+00, -.81431900E-01, -.34410700E+00, -.81794300E-01, 0.21153000E-01, 0.28873700E+01, 0.45209500E+00, -.52652800E+00, -.38782500E+00, 0.31973400E+00, -.47082400E-01, 0.69921900E+00, 0.74947400E-01, -.56271800E+00, -.90312300E-01, 0.17356900E+00, 0.55692200E+00, -.22986000E+00, -.10311900E+00, 0.36816900E+00, 0.91742300E-01, -.76501700E+00, -.23959600E+03, 0.11191500E+03, 0.20474600E+03, 0.11985700E+03, -.66408200E+02, -.13391500E+03, 0.56102000E+02, -.61180500E+02, 0.78875400E+02, -.11582200E+03, 0.19433200E+03, 0.17984300E+03, -.10180800E+03, -.60901300E+02, -.87599000E+02, 0.96694100E+00, 0.11611800E+02, -.75241600E+02, -.24304400E+01, -.17013800E+02, 0.39570200E+01, -.37002500E+02, 0.25023400E+01, -.19202700E+01, 0.76067300E+01, -.17389200E+01, 0.38850800E+02, -.37704200E+02, -.58063700E+02, -.83722400E+02, -.46067800E+02, -.24855100E+01, -.33584500E+02, 0.74823300E+02, -.36846900E+02, -.68213100E+02, -.38398200E+02, 0.14673600E+02, -.15944600E+02, -.17465300E+01, 0.28083100E+02, -.13647500E+02, -.92411700E+01, -.49905000E+02, -.13389000E+02, 0.92284300E+01, -.30031100E+01, -.24750800E+01, -.10698000E+02, -.50181100E+01, 0.15893300E+01, 0.10765100E+02, 0.61909200E+01, 0.86314100E+01, -.12723300E+02, -.73572400E+01, -.48027000E+01, 0.76725100E+01, -.31096200E+01, -.65113300E+01, -.59834600E+01, 0.30936600E+02, -.83943200E+00, 0.59986700E+01, 0.10983600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.27737200E+00, 0.80590600E+00, 0.42841000E+01, 0.19589500E+01, 0.32084200E+00, -.13498800E+01, 0.18878900E+01, -.25710300E+00, 0.44795900E+01, 0.17229000E+01, -.21101500E+00, -.76862300E+00, 0.24743000E+01, -.47359900E+00, 0.12728400E+00, 0.24691000E+01, -.13615200E+01, -.11116300E+01, 0.22873900E+00, 0.50970400E+00, -.18314600E-01, -.47379800E-01, -.13778000E+01, -.58596900E-01, -.52954500E-01, -.79609100E-03, -.16800700E+00, -.95724900E+00, 0.19878600E+00, -.35624600E+00, 0.33704900E+00, -.42648000E+00, 0.79259400E+00, 0.83622300E-01, 0.29325800E+00, 0.26697300E+00, -.95330700E-01, 0.45542200E-01, 0.15021200E+00, -.46759000E+00, 0.93884600E+00, -.40183900E+00, 0.35401600E-01, -.20027200E+00, 0.96218600E+00, -.28160900E+00, -.18549700E+01, 0.47319900E-01, 0.24315900E+01, 0.54055700E+00, 0.58756000E+00, -.10269200E+00, -.13546500E+01, -.81010100E+00, -.21372700E+01, -.50360200E+00, 0.56007600E+00, -.28990900E+00, -.12970500E+00, -.62927600E+00, 0.15133800E+00, 0.11181200E+01, 0.14775500E+01, -.57953600E+00, -.12331300E+01, 0.18849200E+00, 0.26567500E+00, -.69539800E+01, 0.34912400E+00, -.19430400E-01, 0.94446500E-01, -.54654100E+00, -.59025900E-02, 0.18841600E+00, -.15046800E+01, 0.12730400E+01, -.13715300E+01, 0.68383500E+00, -.15199900E+00, -.29991300E+00, 0.19446400E-02, 0.32276700E+00, 0.40463100E+00, 0.16631400E+01, 0.43802400E+00, -.15120300E+01, 0.69266300E+00, -.17842400E+00, -.11450900E+01, -.10417300E+01, -.40119300E+01, -.13069800E+00, -.29177800E+01, -.11455400E+00, -.12516400E+00, -.72149800E+00, -.17265400E+01, 0.39888600E-01, -.14997000E+01, -.77197900E+00, 0.14954600E+00, 0.18124700E+00, -.38124400E-01, 0.28700800E+00, -.35984100E+00, 0.27572300E+00, 0.91678600E-01, 0.93920800E+00, 0.12319800E+01, 0.16332700E+01, 0.53198900E+00, 0.98489400E+00, -.39408200E+00, 0.17493100E+00, -.41519100E+00, 0.23545400E+01, 0.36573100E+00, -.98784900E+01, -.24354200E+00, -.17475600E+01, -.23709600E+00, -.28180400E-01, -.31755100E+00, 0.10803200E+00, 0.64406900E-01, 0.18668100E+01, -.40382700E-01, 0.85834900E-02, 0.33417000E+01, 0.51087800E+01, -.13048300E+01, 0.61677400E+00, -.91842800E-01, 0.37706000E+00, 0.10972900E+00, -.34525200E+00, -.23874800E+01, 0.31660000E+00, -.12346500E+01, 0.55700000E+00, -.10658500E+01, 0.69889000E+00, -.58694500E+00, 0.67360100E+00, -.42802400E+00, 0.16323200E+00, -.32242600E-04, -.24931900E+00, 0.79586300E+00, 0.58535100E+00, -.20257000E-01, 0.65842300E+00, -.14628200E+01, 0.47877900E+00, -.25957300E+01, 0.28230900E+00, 0.86677700E+00, 0.31123400E-01, -.15797100E+00, -.10473700E+01, 0.26716600E+00, 0.24642900E+00, 0.42743200E+00, -.41605300E+00, -.18691000E+00, -.12962800E+00, -.24622800E+00, -.13141900E+00, 0.12512300E+00, -.86436900E-01, 0.25346700E+00, -.12887700E+00, -.18461100E+01, 0.55677500E+00, 0.59882300E-01, 0.85887500E-01, 0.43126300E+00, 0.49739600E+02, -.31991000E+02, 0.59018500E+00, 0.12845800E+03, -.90718800E+02, 0.76178100E+02, 0.11014900E+03, 0.53343500E+02, -.43539300E+02, 0.39461000E+03, 0.52971100E+02, -.16957900E+02, -.53734900E+02, -.30856800E+02, -.10987200E+03, -.50488200E+02, 0.39645800E+02, 0.64017000E+01, -.15023800E+02, -.27870400E+02, 0.82198000E+02, 0.72351900E+02, -.40458700E+02, -.77502100E+01, -.35758400E+02, 0.76498700E+02, -.88576700E+02, 0.14325300E+03, 0.32286000E+03, 0.41825800E+02, -.49956800E+02, 0.12177000E+03, -.12892200E+03, 0.67745600E+02, -.33784200E+01, 0.66113100E+02, -.10420400E+03, -.21908600E+02, 0.40232300E+02, 0.46765500E+02, 0.14422200E+03, -.23139500E+02, 0.51041600E+02, -.74975700E+01, -.19201300E+02, -.13878000E+02, -.73125600E+00, 0.27953900E+01, 0.14590800E+02, -.31903400E+01, -.24120800E+01, -.27277200E+02, -.77111200E+01, -.56591400E+01, 0.25790900E+01, -.25423300E+02, -.10514400E+02, -.12972300E+02, -.23098400E+02, 0.14485700E+02, 0.17078500E+01, -.12209800E+02, -.13687800E+02, -.18489700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.73394400E+00, 0.98090600E-01, -.41894500E+01, -.93195900E+00, -.53338100E+00, 0.13332200E+01, -.16095300E+01, 0.49862700E+00, -.14329300E+01, -.57691200E+00, 0.13839800E+00, 0.66345300E+00, -.22926100E+01, 0.84685700E+00, 0.85677500E-01, -.20095000E+01, 0.16697100E+01, -.49345100E+00, 0.36865500E+00, -.18989500E+00, 0.87704500E-02, 0.51809700E-01, 0.36547600E+00, -.16261000E+00, -.49542500E+00, -.25162100E-02, -.14829500E+00, -.64536500E+00, 0.61681000E+00, -.13419000E+01, 0.35885800E+00, -.15147000E+01, -.16179400E+00, 0.67724400E-01, 0.13676100E+01, 0.54468800E-01, 0.40903400E+00, 0.18150800E+00, -.21923200E+00, 0.18478800E+01, -.19183000E+01, 0.16542200E+01, 0.21254000E+00, 0.61553000E+00, -.23033500E+01, -.25523000E+00, 0.18491800E+01, 0.10203100E+00, -.15580500E+01, 0.13090400E+01, -.10173200E+00, 0.46062800E+00, 0.11037600E+01, 0.78741200E+00, 0.19101700E+00, 0.73823800E+00, -.83932900E+00, 0.32615500E+01, -.27769000E+00, 0.30681300E+00, 0.78295900E+00, -.80131400E+00, 0.20376200E+01, -.79555800E+00, -.41127900E+01, 0.89843200E-01, -.14527000E+00, 0.99697800E+01, 0.75547500E-01, -.54384900E-02, -.67011300E+00, -.43861700E+00, -.59025000E-03, -.31835100E+00, 0.17479900E+01, -.17127600E+01, -.54096300E+00, -.37339000E+01, -.21187000E+00, -.66906700E-01, 0.44716100E-01, 0.11498800E+01, -.57880100E+00, 0.14786900E+01, 0.10944200E+01, -.14854900E+01, 0.14557200E+00, -.29092800E+00, 0.62222600E+00, -.78874600E+00, -.22824400E+01, -.14469700E+00, -.16452600E+01, 0.17364800E+00, -.34655800E-01, -.11026400E+01, -.14237400E+00, 0.40629800E-01, -.73091900E+00, 0.53010300E+00, 0.96669900E-01, -.34052900E-01, -.17740900E-01, -.77653900E+00, -.22794300E-01, -.52606700E+00, 0.47042100E+00, -.21415300E+01, -.51207600E+00, 0.68198100E-01, -.17756400E+01, 0.70843600E-01, -.35723400E+00, 0.18145200E+00, 0.62288000E+00, 0.79127900E+00, -.80165900E+00, -.56280700E+01, 0.39078200E-01, -.94088200E-01, 0.12433200E+01, 0.79478200E+00, 0.58110300E+00, -.25376000E+01, -.15237500E+00, -.66103400E+00, 0.83483400E+01, 0.84240700E+00, -.91518700E+01, -.85655600E+01, 0.36537500E-01, -.60649000E+00, -.45524100E+00, -.89959600E-01, -.31836000E+00, 0.90282200E-01, -.25943000E+01, 0.62711400E+00, 0.10255400E+01, 0.96281700E+00, 0.33818700E+00, -.74117700E+00, 0.43239600E+00, -.25261100E+00, -.31883300E-01, -.42268400E-01, -.99798100E-01, 0.49742300E+00, -.67010200E+00, -.67888000E+00, 0.23315700E+00, -.14733000E+01, -.18111700E+01, 0.12455900E-01, 0.32592700E+00, -.31603400E+00, 0.14108700E+01, 0.24024900E+00, 0.10983000E+01, 0.38289000E+01, 0.29742900E+00, -.14486400E+01, -.46490600E+00, 0.52124000E+00, 0.27553200E+00, 0.12115000E+01, 0.15567400E+00, 0.52414100E+01, 0.15028400E+00, 0.29131000E-01, 0.78191600E+00, -.28014600E+00, 0.78600700E+00, 0.13789900E+01, -.14615900E+00, -.47676900E+00, -.69357200E+00, 0.28420300E-01, 0.21104700E+03, 0.11172200E+00, 0.20191000E+02, -.99508200E+02, -.41431300E+02, -.33648500E+02, -.47524100E+02, -.58705700E+02, -.93323200E+02, 0.36410000E+03, -.19925400E+03, -.16262400E+03, -.18219400E+03, 0.96550200E+02, 0.11614400E+03, -.26892700E+03, -.20687500E+03, -.18902500E+03, 0.11449400E+03, -.24168200E+03, -.75471000E+02, 0.38524700E+02, 0.10341100E+03, 0.38527200E+02, 0.12575200E+03, -.93743300E+02, 0.44851000E+02, 0.12498400E+03, 0.41739000E+02, -.52780500E+02, 0.20447800E+02, -.98682100E+02, 0.49054400E+02, 0.52155800E+01, 0.50498500E+02, 0.10384100E+03, 0.45259200E+02, -.54282800E+02, -.94075700E+02, -.10165000E+02, 0.59703000E+02, -.85414500E+02, -.20123900E+02, 0.63269500E+01, 0.18834800E+02, -.13849900E+01, 0.13222000E+02, 0.48067500E+01, -.22982600E+02, -.12066900E+02, 0.65816700E+02, -.16554800E+02, -.16073400E+02, -.15429400E+02, -.39163900E+01, -.21037200E+02, 0.18752600E+02, -.54934500E+01, -.73608300E+01, 0.22760200E+02, 0.31585800E+02, 0.28070200E+02, -.73019000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28918500E+00, 0.11051100E+00, -.48964100E+01, -.75615800E+00, -.74604800E+00, 0.19976700E+01, -.34630900E+01, 0.44009700E+00, -.12779600E+01, -.72006500E+00, 0.28979900E+00, 0.30056200E+00, -.91334600E+00, -.18752600E+00, 0.24285600E+00, -.11824100E+01, 0.50641200E+00, 0.21015400E+00, -.78837900E+00, 0.45650500E+00, 0.37421200E-01, -.11500300E+00, 0.12665300E+00, -.14247900E+00, -.12265300E+00, -.11441900E-02, -.11084800E-01, -.13926100E+01, -.58797900E-01, 0.18394200E-01, 0.69877600E-01, -.25035100E+00, -.35832300E-01, -.73536400E-01, 0.38505800E+00, 0.13750000E+00, -.63734200E-01, -.49372000E-01, 0.13446500E+00, -.41748200E+00, -.61849100E-01, 0.12677300E+01, -.24356000E+00, 0.64618300E-01, 0.22952200E+00, 0.23742000E+00, 0.66053900E+00, 0.29825600E-01, -.92705900E+00, 0.11680200E+00, 0.72496700E-01, -.22949700E+00, -.14782900E+00, 0.86945200E-01, -.23271700E+00, 0.11489300E+00, -.46970400E+00, 0.76486700E+00, -.15797600E+00, 0.38218200E-01, 0.47831700E+00, 0.65973500E+00, 0.14187700E+00, -.79342200E-01, 0.13359500E+00, 0.20552200E-01, 0.14274400E+00, -.76601100E+01, -.20373400E+00, -.53810300E-01, -.36410500E+00, -.51155100E+00, -.47210700E+00, -.70832800E-02, -.16198600E+00, -.15033900E+00, 0.49857200E+00, -.86716400E+00, 0.24868700E-01, -.98733300E-01, -.20703900E-01, -.35787300E+00, 0.14170000E+00, 0.81121200E-01, 0.25103000E+00, 0.48207400E+00, -.49242600E+00, 0.91547400E-01, -.52981400E-01, -.10742800E+00, -.22018100E+00, 0.51394900E-01, -.17681900E+00, -.40595700E-01, -.35443000E-01, -.43048900E-01, -.41368900E-02, -.36043800E-02, -.88129800E-01, 0.20910300E-01, 0.64142200E-02, 0.39366600E-01, 0.34340300E-01, 0.64468100E-02, 0.29122100E-01, -.19117600E-01, -.18597600E-01, 0.69668500E-01, 0.31020000E-01, -.39572200E-01, 0.14700200E+00, 0.22532600E-01, 0.47755000E-01, -.67888700E-01, -.50157500E-01, 0.12855600E+00, 0.64426100E-01, -.11840200E+00, 0.24776200E-01, -.70244000E-02, 0.83683200E-01, 0.48926700E-01, -.61445600E-03, 0.34591300E-01, -.70069100E-01, 0.16532900E+00, 0.30432900E+00, 0.25440000E-01, 0.37462800E+00, 0.10426400E+01, 0.72913100E-01, -.19701600E-01, 0.74674800E-01, -.71753100E-02, -.28042000E-02, 0.32116200E-01, -.73197200E-01, -.11617600E-01, -.63606800E-01, 0.50614100E-02, -.59447900E-02, 0.27275200E-01, 0.20878000E-01, -.33660400E-01, -.56755500E-02, 0.16213200E-01, -.68211500E-02, 0.63289900E-01, -.32435500E+00, -.15373400E+00, -.27844600E-01, -.13184400E+00, -.25599800E+00, 0.48157200E-02, 0.19276500E-01, -.18496900E-01, -.29319800E-01, 0.22677000E-01, 0.29836600E-01, -.27810800E-01, 0.39653800E-01, 0.18890800E-01, -.51595400E-01, 0.41091800E-01, 0.33625500E-01, 0.11474900E+00, -.10929300E-01, 0.92270500E+00, 0.45537700E-01, 0.32248500E-02, -.74085700E-01, -.72443100E-02, -.14804100E+00, -.37446100E-01, 0.35934000E-01, 0.35463200E-01, -.21191500E-01, 0.39631700E-01, -.15816000E-01, 0.29433700E+02, -.16514800E+01, -.50526000E+01, 0.20517300E+01, 0.92839200E+01, 0.25743300E+01, -.82367400E+01, -.39728300E+01, -.12715400E+01, 0.10590200E-01, -.79145500E+01, 0.59092400E+00, 0.60722700E+01, 0.55884900E+01, -.97423700E+01, -.80813700E+01, -.25422200E+01, 0.47651900E+01, -.19506600E+01, 0.20618800E+02, -.10210400E+02, -.53262200E+01, -.95293900E+01, -.24466800E+01, -.93030100E-01, -.87530500E+01, 0.96863500E-02, -.72368400E+01, -.21786400E+01, -.86133000E+00, 0.67397100E+01, -.34560300E+01, 0.16168400E+00, -.27756200E+01, 0.38511800E+01, 0.29006200E+01, -.56444900E+01, -.62803400E+01, -.40350800E+01, 0.20746300E+01, -.58902700E+01, -.16916400E+00, 0.36884600E+00, 0.30312100E+01, 0.36290700E-01, 0.28233800E+01, -.54185900E+00, 0.34186600E+00, -.28023000E+01, 0.29585200E+01, -.24936400E+01, 0.88105100E-01, -.71727900E+00, 0.12972000E+01, -.24738100E+01, 0.29837500E+01, 0.14833900E+01, -.50939500E+00, 0.18949700E+01, 0.11594800E+01, -.41086100E+00, -.75788300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20453000E+00, 0.98553600E+00, 0.64453500E+00, 0.36271700E+00, 0.88849300E+00, 0.21082400E+00, -.26260100E-01, 0.17894500E-01, -.13160700E+01, -.11751600E+01, 0.59862800E-01, -.34517300E-04, -.10972900E+01, -.58722900E-01, 0.19916400E-01, -.85693900E+00, 0.79803000E+00, 0.53258600E+00, 0.39915700E+00, -.56786700E+00, -.35439400E-01, -.39518000E-01, 0.47837500E+00, 0.40879900E-01, 0.31343400E+00, 0.16433100E-02, 0.13379700E+00, 0.34188400E+00, -.12216700E+01, -.62731900E-01, 0.23493300E+00, 0.21453800E-01, -.53756900E-01, 0.65065100E+00, -.91015700E-01, -.26255200E-01, 0.93324300E-02, 0.12510300E+00, 0.27772300E-01, -.67875700E-02, 0.84228300E+00, -.24470400E+00, 0.14658300E+00, 0.65393700E-01, -.12966500E+01, 0.12330100E+00, 0.44718200E+00, -.67181400E-02, 0.70721200E+00, 0.65181400E+00, -.19003200E+00, 0.25720400E+00, 0.57275700E+00, -.46212800E-01, -.46359100E+00, -.29476600E+00, 0.95846500E+00, -.56840800E+00, 0.12043200E+00, -.26186500E+00, -.13229800E+00, 0.37358100E+00, 0.48180100E+00, -.13610900E+00, 0.19913300E+00, 0.24005400E+00, -.25684600E-01, 0.18575000E+00, 0.72425200E-02, 0.15362900E-01, 0.40244000E+00, 0.68343300E+00, 0.26703700E-02, -.25879000E-01, 0.11732300E+00, 0.18010100E+00, 0.52652700E+00, -.10368300E+01, -.54582500E-01, -.22663000E+00, 0.82620500E-02, -.45041500E+00, 0.29255200E-02, 0.10493800E+00, -.16329000E+00, 0.63024200E+00, -.29021200E+00, -.13100200E-01, -.11898900E+00, -.68801200E+00, 0.10439600E+00, -.15839400E-01, -.33711700E+00, 0.72422100E-01, -.23564100E+00, -.57941700E+00, 0.63428400E-01, -.19347500E+00, 0.30902700E+00, -.28196000E-01, 0.71973100E-01, -.13538000E+00, 0.10610200E-01, -.63111000E-01, -.31693800E+00, 0.10865700E+00, -.11889200E-02, 0.86120600E-01, -.20410200E+00, -.22907800E+00, 0.23925900E+00, -.34612200E+00, 0.67365300E-01, 0.17715400E-02, -.82758100E-01, -.49920400E+00, -.42093600E-01, 0.30918800E+01, -.38655300E-01, 0.31039400E+00, -.15138300E+00, -.20725400E+00, -.56051700E-01, 0.47117400E+00, 0.10395100E+00, -.27607300E+00, -.44638500E+01, -.52883300E-01, 0.26249900E+01, 0.47687300E+01, -.45921500E+00, 0.13393100E+00, 0.24169300E-01, 0.77177100E-01, 0.67683000E-01, -.54635900E-01, -.42878700E+00, 0.77163200E-01, -.32033900E+00, 0.14775700E+00, -.99690900E-01, -.58778700E+00, -.92588100E-01, 0.19613500E+00, -.54405200E-01, 0.34057400E-01, 0.29251500E-01, -.19627500E+00, -.16778700E-01, 0.29659000E+00, -.36104500E-02, -.25109000E+00, -.26294800E-01, 0.12816900E+00, -.10422400E+01, 0.75943200E-01, 0.55136600E+00, -.32183300E-01, -.16589900E+00, -.46332300E+00, -.17265500E+00, -.32510100E-02, -.23941000E-01, 0.90407200E-02, 0.83310400E-01, -.20030200E+00, -.83773300E-01, 0.14152100E+01, -.39104100E-01, -.35005100E+00, 0.18918800E+00, -.74207000E-01, -.35570900E-01, -.40757000E+00, 0.13012200E-01, 0.87041000E-02, -.11740200E+00, 0.49101900E-01, -.20773100E-01, -.17370700E-01, -.14912000E+03, 0.22665400E+02, -.20024800E+02, -.43948100E+02, -.92609900E+01, 0.22635400E+02, -.41593000E+02, 0.32703400E+02, -.14407000E+02, 0.13439100E+02, -.15418200E+02, 0.84743900E+01, 0.11420900E+01, 0.55363800E+01, 0.43631600E+02, 0.13241000E+02, -.64572100E+01, 0.56951300E+01, 0.23850000E+02, -.12295100E+02, -.61578500E+02, -.12400400E+02, -.48477600E+02, 0.28970400E+02, -.38786100E+02, -.29735200E+02, -.55202700E+01, 0.22018900E+02, -.11197300E+03, 0.57668200E+02, -.28578500E+02, -.14840200E+01, -.29495200E+02, 0.12486300E+02, 0.32159000E+01, -.10779500E+02, -.47739100E+01, -.47849600E+02, 0.65884900E+01, -.12689500E+02, 0.12053500E+01, 0.84525000E+01, -.11253500E+02, -.10026200E+00, -.16308600E+02, -.21025200E+01, 0.51728600E+00, 0.16209800E+02, -.31035800E+01, 0.16847000E+02, -.56925900E+00, 0.91295500E+00, 0.31876300E+01, 0.17827400E+02, -.11821500E+02, 0.25864300E+01, -.61884400E+01, -.13250900E+01, -.15821000E+01, 0.54244700E-01, 0.65404100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22055500E+00, 0.65566800E+00, -.39251700E+00, 0.68120000E+00, 0.20681100E+01, -.10835300E+00, 0.14626100E+00, 0.52821300E-03, -.22239700E+01, -.12964700E+01, 0.23653800E+00, 0.33014400E-02, -.13676800E+01, -.31449700E+00, -.20303900E+00, -.41691100E+00, -.12415600E+00, 0.43688900E+00, 0.33593900E+00, -.59337400E+00, -.12225400E-01, -.61584500E-01, 0.10293100E+01, -.25330700E-01, 0.52059400E+00, 0.86778500E-03, 0.29600900E+00, 0.60315700E+00, -.12989100E+01, 0.30312800E+00, 0.20837400E-01, 0.24166800E+00, -.60706900E-01, 0.71461000E+00, -.52791500E+00, -.14778600E+00, 0.32322800E-01, 0.16542000E+00, 0.12598100E-01, -.21547300E-01, 0.83731900E+00, 0.50714800E-01, 0.48381700E-01, -.60195000E-01, -.12936700E+01, 0.13225000E+00, 0.10019000E+01, -.75988500E-02, 0.29919700E+00, 0.84767000E+00, -.31565800E-02, 0.36677000E+00, 0.50899500E+00, 0.58826800E-01, 0.16914800E+00, -.20272700E+00, 0.55969800E+00, -.53420600E+00, 0.11900000E+00, -.53048900E-01, -.18132500E+00, 0.16708700E+00, -.47068500E+00, -.10602300E+00, -.12441000E-01, 0.14866100E+00, -.50058800E-01, 0.26257500E+01, -.12185700E+00, -.10195400E-01, 0.33305400E+00, 0.79150200E+00, -.49980700E-01, -.30103100E-01, 0.11996700E-01, 0.39700800E+00, 0.35001700E+00, -.15396000E+01, -.54166500E-01, -.30228600E+00, -.24991100E-02, -.50027800E+00, 0.39785200E-01, 0.33933400E+00, 0.92168900E-01, 0.30184500E+00, -.36673400E+00, -.22567500E-01, -.20411400E+00, -.89591000E-01, 0.36849100E+00, -.52910500E-02, -.18850400E+00, 0.54649600E-01, -.16014600E+00, -.29757000E-01, 0.25433400E+00, -.35246900E+00, 0.24141600E+00, -.25801500E+00, 0.15259400E+00, 0.50500300E-01, 0.40490900E-01, -.14540400E+00, -.25090000E+00, 0.85563800E-01, -.14522300E-01, -.25868900E+00, -.21777800E-02, 0.30676500E+00, 0.27752800E+00, -.75682900E-01, -.17900900E+00, 0.39757100E-03, -.43051900E-02, -.41069500E+00, -.25809500E-01, 0.25197800E+01, -.62226000E-02, 0.26278500E+00, 0.51143600E+00, -.16201800E+00, -.33107900E-01, 0.31475600E+00, 0.10625900E+00, -.17620900E+00, -.40294700E+01, 0.98207100E-01, 0.25404600E+01, 0.57907900E+01, -.67509400E+00, 0.11850800E+00, -.11119400E+00, 0.15741000E+00, 0.10503400E+00, -.10756200E+00, -.32575200E-01, 0.13732500E+00, -.21954600E+00, 0.26226700E+00, -.12722200E+00, -.80497400E+00, -.11137000E+00, -.72492300E-02, 0.12096600E+00, 0.60369800E-01, 0.65657800E-01, -.50553300E+00, 0.15467400E+00, 0.41616700E+00, -.43586200E-01, -.81736300E-01, 0.44159000E+00, 0.15824700E+00, -.72852000E+00, 0.28784900E-01, 0.51359900E+00, -.35886200E-02, -.24874000E+00, -.89706800E+00, -.33738600E+00, 0.50305100E-01, 0.19860600E-01, 0.21533500E-01, -.16218600E+00, 0.19773700E+00, -.38110700E-01, -.39509900E+01, -.35181800E-01, -.16256600E+00, -.17841600E+00, 0.18488900E+00, 0.89479200E+00, -.95546800E-01, -.98855400E-01, 0.20792000E-01, 0.10362000E+00, -.35699800E-02, -.37461100E-01, -.21412400E-01, 0.59029700E+00, 0.47360100E+02, -.10806900E+02, -.28151900E+02, 0.29184700E+01, 0.45442900E+02, -.65656000E+02, -.16089800E+02, 0.91019800E+01, 0.17342600E+02, 0.88508800E+01, 0.86797400E+01, -.20564300E+01, 0.45041100E+01, -.11426800E+02, 0.74891800E+00, -.39548500E+01, -.23456600E+02, -.52253700E+02, 0.27261900E+02, 0.11872400E+02, 0.26174000E+02, 0.69929100E+01, 0.78183700E+01, 0.31417100E+02, -.38832300E+01, 0.38466100E+02, 0.46191300E+00, -.20650100E+02, -.16453500E+02, 0.75363500E+01, 0.78030100E+01, 0.83351600E+01, 0.14673000E+02, 0.77663200E+01, 0.15188700E+01, -.87555800E+01, -.69320900E+01, 0.87576900E+01, 0.12359500E+02, 0.60688400E+01, -.14848300E+01, -.38481500E+00, 0.10361300E+01, -.62059200E-01, 0.30574500E+01, -.29237100E+01, 0.17543700E+00, 0.43865100E+01, 0.50839100E+00, 0.38033400E+01, 0.24658000E+01, 0.26181300E+01, 0.57266700E-01, -.53369200E+00, 0.31929200E+00, 0.13005800E+01, -.13233800E+02, 0.38025900E+01, 0.23754200E+01, 0.94551700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16719400E+00, 0.19552600E-01, 0.81764400E+00, 0.20609500E+00, -.98085400E+00, -.18407300E+00, 0.16116000E+01, -.76221800E-01, -.31039300E+00, 0.12891000E+01, 0.21470200E+00, -.17950800E-01, 0.13042000E+00, -.25907600E+00, -.45019200E+00, 0.42938100E+00, -.47377400E+00, -.37357100E+00, 0.38515000E+00, -.18019200E+00, 0.48279200E-01, -.92768800E-01, -.19043200E+00, 0.71216700E-01, 0.28346700E+00, 0.10811700E-02, 0.21728500E-01, -.17425300E+00, -.45447900E+00, -.17523100E+00, 0.22648900E+00, -.17532700E+00, 0.60643500E+00, 0.79479100E+00, -.52689600E+00, 0.11079500E+00, -.11643600E+00, 0.32906500E+00, 0.32925600E+00, -.29881500E+00, 0.71656200E+00, 0.26395000E+00, -.65919900E-01, 0.93293500E-01, -.24549400E+01, 0.47241300E+00, -.81182400E+00, -.21312800E-01, 0.35420200E+00, 0.12970000E-01, -.78784600E-01, 0.27338900E+00, 0.54961300E+00, -.89507500E-01, 0.27868500E-01, -.30140600E+00, 0.28752900E+00, -.82715200E+00, 0.13817700E+00, -.17478400E+00, -.26845100E-01, -.44434200E-02, -.36096500E+00, -.21922700E+00, -.50586400E+00, 0.30013800E+00, -.18852700E+00, 0.12752100E+01, 0.25286200E+00, 0.68502900E-02, -.71796900E-01, -.73158100E-01, 0.25850800E+00, -.94004200E-01, 0.71125300E+00, -.87584500E+00, -.50565900E+00, 0.12359800E+00, -.14310200E-01, 0.36319100E-01, -.22390500E-01, 0.16752800E+00, 0.80907200E-01, 0.25491700E+00, -.32481400E+00, -.24119100E+00, 0.18466400E+00, -.26465300E-01, -.19846000E+00, -.70296000E+00, 0.12065300E+01, -.30294400E-01, -.30407600E+00, -.66856700E-01, -.32440200E+00, -.70530100E+00, -.31707800E-01, -.23808500E+00, -.11214800E+00, 0.10660600E+00, -.83798700E-01, 0.10010600E+00, -.20020500E-01, -.69910800E-01, -.16087200E+00, 0.20924100E-01, 0.19595200E-01, -.56752500E-02, 0.17937700E-01, -.20675400E+00, -.68036500E+00, -.39388000E+00, 0.13550200E+00, 0.41074000E-01, -.43224200E-01, -.26792200E+00, -.21132900E+00, 0.25725100E+01, -.11773700E+00, 0.11434900E+00, 0.10766000E+00, 0.17625700E-01, 0.11913900E-01, -.62130600E+00, -.14512000E-01, -.20213800E+00, 0.46095600E+00, 0.13341100E-01, -.36010900E+01, 0.26415100E+01, 0.25116400E+00, -.44437500E-02, -.40984200E-01, 0.44992500E-02, 0.43122400E-01, 0.61360200E-01, -.14210900E-01, 0.27339000E+00, 0.23882400E+00, -.71513000E-01, -.76684400E-01, -.25589300E+00, -.12670000E+00, 0.13608900E+00, -.26041300E-01, -.26858100E-01, 0.90988800E-02, -.29879700E+00, 0.35220200E+00, 0.62993900E+00, 0.73580400E-01, -.59266500E+00, -.50912000E+00, 0.10017800E+00, -.30063700E-01, -.59550500E-01, -.67660600E-01, 0.33528700E-01, 0.10259400E+00, 0.25364700E+00, -.34897000E+00, -.30555900E+00, 0.38298300E-01, -.53905800E-01, -.16627500E+00, -.52832000E-01, 0.48457300E-01, -.51916100E+01, 0.19540400E-01, 0.77189100E-01, -.29129900E-01, 0.21392400E+00, 0.88954800E+00, -.52169400E-02, -.49094600E-01, 0.24897600E-01, 0.14980400E+00, -.68997700E-01, -.40116800E-01, 0.99806300E-04, -.38417900E+00, 0.75320500E+00, 0.21844200E+02, 0.27342600E+02, 0.47931400E+01, -.62245100E+00, -.54552100E+02, -.51894400E+02, 0.29791100E+02, 0.31202600E+02, 0.24585600E+02, -.35198600E+01, -.14703600E+02, 0.35782500E+02, 0.21440000E+02, 0.25496100E+02, -.16084100E+02, 0.11403900E+02, -.16010000E+02, 0.72664700E+01, -.18676800E+02, 0.79837300E+01, 0.12899200E+02, 0.30642000E+02, 0.11745100E+02, 0.15808300E+02, -.37678800E+02, 0.40180700E+02, -.28918000E+02, -.44479800E+02, 0.22904900E+02, 0.21243400E+02, 0.22326800E+02, 0.40055100E+01, -.30765700E+01, 0.20551900E+02, 0.11708200E+02, 0.36158100E+01, -.13443600E+01, 0.14219300E+02, 0.25108300E+01, -.53465500E+00, -.98803200E+01, -.30599000E+00, -.10163000E+02, 0.17159600E+01, 0.68393500E+00, 0.10052900E+02, -.69141500E+01, 0.10616300E+02, 0.17336100E+01, 0.28692100E+01, -.30070300E+01, 0.11153200E+02, -.99505400E+01, -.35723100E+01, 0.73356700E+00, -.15765400E+01, -.35207800E+01, 0.13774600E+01, 0.20092400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12081200E+00, 0.19364300E+00, -.26159300E+01, 0.59473400E-02, 0.84106200E-01, 0.10873500E+01, -.10854400E+01, 0.13848000E+00, -.89260700E+00, -.35801200E+00, 0.27225200E+00, 0.21158400E+00, -.67473200E+00, -.25443700E+00, 0.14980200E+00, -.86676100E+00, 0.70147700E+00, 0.23416400E+00, -.55811100E+00, 0.41882800E+00, 0.26612100E-01, -.56155300E-01, 0.63168100E-01, -.10190500E+00, -.10089200E+00, -.98667100E-03, -.21095700E-01, -.11072100E+01, -.25441900E-01, -.13941800E+00, 0.15561800E+00, -.29102000E+00, -.37589600E-01, -.16306300E-01, 0.27103700E+00, 0.72431300E-01, 0.58209600E-02, -.52614000E-02, 0.10100500E-01, -.42485200E+00, 0.19067300E+00, 0.56997600E+00, -.15253700E+00, -.37180200E-01, 0.36903000E+00, 0.60506900E-01, 0.91591400E+00, -.39085000E-01, -.31903700E+00, 0.13182400E+00, -.17457400E+00, -.17585300E+00, -.19480900E+00, -.83666400E-02, -.22013300E+00, 0.11863600E-01, -.30188700E+00, 0.34923900E+00, -.59716200E-02, 0.11816800E-01, 0.26822300E+00, 0.36686600E+00, 0.30420800E+00, 0.12283700E+00, 0.27603500E+00, 0.74813000E-01, 0.77133700E-01, -.40548400E+01, -.88547300E-01, 0.22087000E-01, -.44023500E-01, -.20226400E+00, -.96603000E-01, 0.10645700E-02, -.16326400E+00, 0.19298300E+00, -.46164800E-02, 0.99264900E+00, -.66750000E-02, 0.11453500E+00, 0.29393000E-02, -.10163900E+00, -.71596500E-01, -.51128000E+00, -.17100100E+00, 0.10552100E+01, -.37943300E-01, 0.89984100E-01, 0.25920800E+00, 0.35772800E+00, 0.42179700E+00, 0.43396900E-01, 0.43747100E+00, -.51653700E-01, 0.15163200E+00, 0.13109600E+00, -.20635900E+00, 0.65557500E-01, -.20639200E+00, -.53219800E-01, -.23055900E+00, 0.82091000E-01, 0.33885100E-03, -.20735000E-01, 0.14573500E+00, 0.11210700E-01, -.11333800E+00, 0.20671100E+00, 0.41225100E+00, 0.32666800E+00, -.58964700E+00, -.59761600E+00, 0.36948800E+00, -.33264600E-03, -.73983800E-01, 0.35607000E+00, -.91649000E-01, 0.16009100E+01, -.58010300E-01, -.35112600E+00, 0.12256400E+00, -.54078600E-02, -.15565100E+00, -.28593600E+00, -.40342600E-01, -.38899400E+00, 0.23576600E+01, -.20748200E+00, -.27690000E+01, 0.15841100E+01, 0.48723200E+00, -.79424000E-01, 0.10147500E+00, 0.52041100E-01, 0.50494300E-01, 0.44286100E-01, 0.58115800E+00, 0.14726200E+00, -.70649900E-01, -.32113300E+00, -.10933600E+00, 0.57177800E+00, -.19253400E+00, 0.12401100E+00, -.32987400E-01, -.24094400E-01, -.26792100E-03, -.18626700E+00, 0.40573400E+00, 0.41288000E+00, 0.59507900E-01, -.19956600E+00, -.55468300E+00, 0.48731300E-01, -.31272000E+00, -.23954100E-02, -.12734300E+00, -.25055000E-01, -.37619600E-01, -.10397600E+00, 0.32331000E-01, -.58512400E-01, -.93978000E-01, 0.11617900E+00, -.50627200E-01, 0.11505900E+00, -.38504300E-01, -.44785100E+00, -.98803100E-02, 0.40559900E-01, -.15271800E+00, 0.31167300E-01, -.31908100E+00, -.45735200E-01, -.81153800E-01, 0.29855600E-01, -.60625700E-01, 0.53930700E-01, 0.99384500E-01, 0.68260000E-02, 0.81492800E-01, 0.73995200E-01, 0.64735100E+00, -.33319400E+02, -.17452800E+02, 0.77379300E+00, 0.28564100E+02, 0.25449900E+02, -.13780500E+02, -.27245900E+02, -.12429200E+02, -.60982400E+01, 0.48910800E+01, -.13780300E+02, -.71312600E+01, -.14192200E+02, 0.56096800E+01, 0.12602300E+02, 0.20871800E+02, -.10268300E+02, 0.15730900E+02, -.10373300E+02, -.13506000E+02, -.13433300E+01, -.19957500E+02, -.38838900E+02, -.20869800E+02, -.86457000E+01, -.14099800E+01, 0.42916700E+02, -.21864700E+02, -.19331900E+02, -.21684000E+02, -.14921400E+02, -.24866000E+01, -.18287300E+02, -.11770800E+02, -.87684500E+01, -.58600800E+01, 0.40939900E+01, -.30376400E+01, 0.63705100E+00, 0.11203000E+02, 0.29534900E+00, 0.92864500E+01, -.46708700E+01, 0.19286800E+01, -.92960500E+01, 0.14351100E+00, -.10355300E+02, -.17187200E+01, -.14486600E+01, 0.48224600E+01, -.10429300E+02, 0.11242700E+02, 0.61268900E+01, -.18084400E+00, 0.14415300E+01, -.47737200E+00, 0.76650300E+00, -.20674300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16106300E+01, -.18717200E+01, -.11637200E+02, -.19108300E+01, -.10295300E+01, 0.33059100E+00, -.92701100E-01, 0.17901900E+00, -.35773400E+01, 0.18446500E+01, 0.11666700E+01, 0.81904500E+00, -.30910200E+01, 0.58180700E+00, 0.65607300E+00, -.32563600E+01, 0.42365800E+01, 0.11551500E+01, -.36974500E-01, -.21267400E-01, 0.13529300E+00, -.36628300E+00, 0.30564400E+01, 0.51340100E+00, -.19214800E+00, -.40190300E-03, 0.46168000E+00, -.53006900E+00, 0.14202400E+01, -.13152800E+01, -.45849100E-01, -.27597700E+01, 0.12479300E+00, -.26680800E+00, -.40708300E+01, -.89735800E+00, 0.41110100E+00, 0.66871900E+00, -.73968200E+00, -.27164700E+01, 0.18523400E+01, 0.14582000E-01, -.22601000E+00, 0.29931900E+00, -.21699300E+01, 0.69886300E+00, 0.50486000E+00, 0.41713300E-01, 0.23933700E+00, 0.10563000E+00, -.20295100E+01, -.25566700E+01, 0.27968800E+01, 0.28169100E+01, 0.29534300E+01, 0.13287900E+00, -.29700100E+01, 0.20137400E+01, 0.91106500E-02, -.31669600E+00, 0.84213900E+00, -.81244500E-03, -.70632100E+00, -.15678100E+00, -.16702300E+01, 0.87773100E+00, 0.27425300E-01, -.17071900E+02, 0.76267600E+00, 0.95614500E-01, 0.69666100E-03, -.17400900E+01, -.47933200E+00, 0.42211000E+00, 0.11261200E+01, -.30249900E+01, -.37102200E+00, -.36899200E+01, -.48137600E+00, 0.31627400E+00, -.55880200E-01, 0.45306300E+00, -.10537000E+01, -.12516200E+01, -.22146900E+01, 0.41561400E+01, -.94124000E+00, 0.69580500E-01, -.66194200E+00, -.10256000E+01, -.15591000E+01, -.30827200E-01, 0.16948000E+01, 0.67200500E+00, -.17707100E+00, 0.83840200E+00, 0.10132100E+01, -.28903100E+00, 0.26222400E+01, 0.82699100E+00, 0.32073900E+00, -.41536600E+00, -.15444900E+00, -.68021200E+00, -.30357600E+01, 0.13279400E+00, 0.39038100E-01, -.61151100E+00, -.46161500E+00, -.51117600E+00, -.26064300E+01, -.22236000E+01, -.48736300E+00, 0.31385300E+00, -.28469600E+00, -.24915800E+00, -.36536400E+00, 0.14541700E+02, -.70700200E+00, 0.78784100E+00, 0.70855000E+00, 0.13422900E+01, 0.11609500E+01, 0.22723400E+01, -.99410100E-02, -.40777000E+01, -.13151300E+02, 0.10947800E+00, -.40048900E+00, -.25722200E+02, -.90036700E-01, 0.12591900E+01, -.22270000E+01, 0.31460500E+00, 0.72919200E-01, -.12026000E-01, -.24521300E+00, 0.14094100E+00, -.24799300E+01, 0.71980200E+00, 0.13789800E+00, 0.87014100E-01, 0.58061800E+00, -.37561400E+00, 0.35351100E+00, -.26786100E+00, -.71554100E-01, 0.67381400E+00, 0.18212800E+01, -.40381400E+00, -.24570000E+00, 0.36569800E+01, 0.53132600E+01, 0.51219100E+00, -.23119400E+01, 0.30054300E+00, 0.19993500E+01, -.75915000E-01, -.73299500E+00, -.39794400E+01, -.10290300E+01, -.49771800E+00, -.39875200E+00, 0.34624000E+00, -.65627600E+00, -.12516500E+01, 0.22941700E+00, -.13101100E+01, 0.19079500E-01, 0.47213600E+00, -.36118800E+00, 0.88918400E+00, 0.44028300E+01, 0.73378800E+00, -.65325700E+00, 0.94438900E-01, 0.15913300E+01, -.28412900E+00, -.58389300E+00, -.31400800E-01, -.19392100E+01, 0.55810300E+01, -.27435100E+01, -.15533500E+01, -.15977700E+03, 0.59432500E+02, -.25348100E+03, -.61719300E+03, 0.32370500E+03, 0.32492000E+03, 0.29580100E+03, 0.14441200E+03, 0.50704400E+02, 0.23685100E+03, 0.12915000E+03, 0.14889800E+03, 0.58708800E+02, 0.11231800E+03, -.28851800E+03, 0.14056100E+03, 0.41944500E+02, 0.14529500E+03, -.96084500E+02, -.68505700E+02, 0.25143000E+02, -.10946100E+03, -.13775100E+02, -.15274700E+02, -.97234500E+01, -.24739600E+03, 0.12574600E+03, 0.24222600E+03, 0.12504200E+03, 0.11263700E+02, 0.15370600E+02, 0.91681400E+01, -.56452800E+02, -.18439000E+02, 0.27917800E+02, 0.34678900E+02, -.19746600E+01, 0.17725600E+02, -.37395200E+02, -.72509200E+00, -.41164800E+02, -.18843200E+02, 0.13637000E+02, 0.41297700E+02, -.18332800E+02, 0.29358600E+02, 0.63081500E-01, -.60947100E-01, 0.21994500E+01, 0.38233900E+02, -.36949500E+02, 0.47124400E+01, -.17998700E+02, -.93993400E+01, -.74598300E+01, 0.82646000E+01, 0.11813100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.98167800E+00, 0.82430600E+01, 0.12190800E+02, 0.70370200E+01, -.31724400E+01, 0.65496100E+01, -.43224400E+01, -.50728700E+00, -.85670800E+01, -.55935900E+01, 0.91885700E+00, 0.14868500E+01, -.69838700E+01, -.36187700E+01, -.16557200E+01, -.21942400E+01, 0.30748000E+01, -.33710100E+01, 0.17768100E+01, -.36439600E+01, -.24721600E-01, -.72176200E+00, 0.63960000E+01, 0.36251100E+00, 0.15456600E+01, 0.31532300E-02, 0.10218400E+01, -.22145600E+01, 0.24649000E+01, -.11700900E+01, 0.12616200E+01, -.27959500E+01, 0.17604300E+01, 0.52127600E+00, -.48220100E+01, -.10974300E+00, 0.16500400E-01, 0.74055200E+00, -.42874500E-01, -.17171300E+01, 0.18266300E+01, 0.25298600E+00, -.34429600E+00, 0.95929200E-01, -.46916800E+01, 0.11308600E+01, -.13870600E+01, 0.97515600E-01, 0.19221000E+00, -.95271200E+00, -.16176400E+00, -.54641300E+00, 0.47820100E+00, 0.67132300E+00, -.66355600E-01, -.36234400E+00, 0.15618800E+01, 0.46841700E-01, 0.82825200E-02, -.95207300E+00, 0.10601700E+01, 0.23338400E+01, -.63631200E+00, -.31600400E+00, -.10488700E+00, 0.66928200E+00, -.10237000E+01, -.12019800E+02, -.77914900E-01, 0.28806700E-01, -.25765400E+00, -.91837100E-01, -.74709500E-01, -.41722200E+00, -.32264200E+00, 0.34142300E+01, 0.30299800E+01, 0.45216200E+00, 0.42940400E+00, -.75825600E+00, 0.28914300E-04, -.66053400E+00, 0.40930000E+00, 0.54229900E+00, 0.31389900E+00, 0.69980200E+00, -.56081700E+00, 0.51181500E-01, -.19884500E+01, -.36487500E+00, -.88193300E+00, -.10304600E-01, -.86838300E+00, 0.51090000E+00, -.37527000E+00, -.24818500E+00, -.19460200E+00, -.31302600E+00, 0.23630800E+00, 0.40722300E-01, 0.48133100E-01, 0.13521000E+00, -.35004100E-01, -.22585100E+00, -.44195900E+00, 0.34406900E+00, -.66785300E-01, -.16646700E-01, 0.88228200E+00, 0.24133000E+01, 0.13266700E+01, -.63481200E+00, 0.67255800E+00, 0.22787800E+00, -.83423200E+00, 0.32436000E+01, 0.60096400E+00, -.86498400E+01, -.68345500E-02, -.70831400E+00, -.13154600E+01, 0.99011600E+00, -.12345700E+01, 0.36047800E+01, 0.40399900E+00, -.19926100E+01, -.24152300E+01, -.14117400E+01, 0.77979600E+01, -.85377200E+01, 0.63238000E+00, 0.29087600E+00, 0.97024600E+00, 0.18342400E+00, 0.35798600E-01, -.43218900E+00, -.66740500E+00, -.46795800E+00, 0.73549800E+00, -.12249100E+01, -.65742800E+00, 0.43459700E+01, -.50377300E+00, 0.17562000E+00, -.24973800E+00, 0.16219200E+00, 0.59224200E-01, 0.19872100E-01, -.24215300E+01, -.12371600E+01, -.47891100E+00, 0.67354900E-01, -.20402700E+01, 0.44056000E+00, -.38247300E+00, 0.56469800E+00, -.94885300E+00, 0.38559000E-01, 0.41310500E+00, 0.35604400E+01, 0.42049100E-01, -.16219100E+01, -.87335700E+00, 0.70616100E+00, 0.87537400E-01, 0.14204900E+01, -.53410400E+00, 0.91971300E+01, -.23690200E-02, 0.44449900E+00, 0.47669800E+00, -.75119700E+00, -.34853300E+00, 0.35899500E+00, 0.41821200E+00, 0.85596000E-01, -.16803000E+00, 0.11687600E+01, 0.37609200E+00, -.15294900E-01, 0.29893500E+00, 0.21923900E+01, -.23053500E+01, -.15744300E+01, 0.49399100E+00, -.98497000E+02, 0.20857700E+02, -.10090700E+03, 0.63923700E+02, -.71986700E+02, 0.59362200E+02, -.25246900E+02, -.18252700E+02, -.54131400E+02, -.37965900E+02, 0.80640600E+02, -.43060800E+02, 0.13218400E+03, 0.29174000E+03, -.13549700E+03, -.11002400E+03, -.14726400E+03, -.12057900E+03, 0.14820500E+03, -.26626900E+03, -.30063500E+03, -.25518500E+03, 0.84139800E+02, 0.52704200E+02, 0.23449700E+03, -.11289300E+03, -.82625200E+02, -.12074900E+03, -.28693300E+00, -.21818200E+02, -.18484300E+02, 0.14310100E+02, -.66572400E+02, -.45741800E+02, -.38139500E+02, 0.42981500E+01, 0.98027800E+01, 0.36758500E+02, -.12121700E+01, 0.27588700E+02, -.24446300E+02, 0.27262900E+02, -.28448200E+02, 0.30856200E+01, -.15039200E+02, 0.71006100E+01, -.38529100E+01, 0.21928200E+02, -.14115600E+02, 0.36414100E+02, 0.21959500E+02, -.40021300E+01, 0.28308500E+02, -.95943400E+01, -.16499100E+02, 0.44239300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15584600E+00, 0.91919700E-01, 0.88178200E+00, 0.16512700E+00, -.13075600E+01, 0.36115000E+00, -.22171900E-01, 0.22567700E-01, 0.53670800E+00, 0.38194900E+00, -.21491900E-01, 0.15545300E+00, 0.20813000E+00, -.14202100E+00, -.17267300E-01, 0.65147200E+00, -.24706000E+00, -.32202600E+00, 0.28841000E+00, -.21610500E+00, 0.43763900E-01, -.45310100E-02, 0.16955400E+01, 0.82368300E-01, 0.17140200E+00, 0.33655200E-03, 0.28025500E+00, 0.66918000E+00, -.62340700E-02, -.17757700E-01, -.50282000E+00, 0.12392200E+00, -.39790200E+00, -.24309100E+00, 0.62088300E+00, -.10048600E+00, 0.14018000E+00, -.15605700E+00, -.20760300E+00, 0.10626100E+01, -.12777300E+01, -.28981600E+00, 0.21656000E+00, 0.12306000E+00, 0.85701700E+00, -.28072300E+00, -.35205300E+00, 0.93586000E-01, -.75562800E+00, -.35856500E+00, -.99919800E-01, -.41820100E-01, 0.61285500E+00, 0.29950200E+00, 0.62670000E+00, 0.10097800E+00, -.21553800E+00, -.14898700E+00, -.81836600E-01, -.10245700E+00, -.18916000E+00, -.11308900E+00, -.86505900E+00, 0.23760600E-01, -.15875200E+00, -.17529400E+00, -.13226200E+00, 0.21377600E+01, -.10852700E+00, -.12643600E-01, -.88993300E-01, 0.14989900E+00, 0.16059500E+00, -.11692800E+00, -.80470800E-01, -.74799800E+00, 0.44215700E+00, -.51390900E+00, 0.64894800E-01, -.46638400E-02, -.18421000E-01, -.36278200E+00, -.38955100E-01, -.16545700E+00, -.30100300E-01, -.56754200E-01, -.26940300E+00, 0.34609800E-01, -.72816700E-01, 0.43586000E+00, 0.28902800E+00, 0.27218100E-01, 0.49541800E+00, 0.15531100E+00, 0.12783000E+00, 0.38277800E+00, 0.27784900E+00, -.10261300E+00, 0.92908900E+00, -.14945900E+00, 0.12116300E+00, -.16812700E+00, -.82004200E-02, 0.55163500E-01, 0.17163900E+00, -.43118000E-01, -.45998000E-01, -.25966800E+00, 0.22030300E+00, 0.18320300E+00, -.73262900E-01, 0.26022500E+00, -.40620400E+00, 0.25998900E-01, 0.13194100E+00, -.19325200E+00, 0.19188300E+00, 0.10174000E+01, -.28362900E-01, 0.47713600E+00, 0.18859900E-01, 0.47837800E-01, 0.19805500E-01, 0.41839400E+00, 0.28301100E-01, -.28810200E+00, 0.13920100E+01, -.11809300E+00, 0.13930000E+01, -.56647100E-01, -.29087400E+00, -.13263500E+00, 0.33481200E-02, 0.46951800E-01, 0.47544800E-01, -.84390100E-01, 0.14638900E+00, 0.24623200E-01, -.29539300E+00, 0.12637600E+00, 0.11311600E+00, 0.27008000E-01, 0.15166800E+00, -.16724000E+00, 0.54894700E-01, -.46963100E-02, 0.71472800E-03, 0.13147700E+00, -.20745800E+00, -.34842700E+00, -.34119400E-01, 0.22457700E+00, 0.32673500E+00, -.36159100E-01, 0.20891400E+00, 0.15951500E-01, 0.62587300E-01, 0.27480200E-02, -.43984600E-01, -.78156300E+00, -.31875800E-01, 0.17890800E+00, -.16024200E+00, 0.60572700E-01, 0.10743100E+00, 0.18108100E+00, -.33154700E-02, 0.25325300E+01, -.14975800E-01, -.10967700E+00, 0.32052300E+00, -.33323200E-01, 0.34329200E+00, -.56216200E-01, 0.11654800E+00, 0.14110300E+00, -.33270700E-01, -.46231600E-02, -.81344500E-01, 0.55066600E-02, -.14511100E+00, 0.21662200E+00, 0.38068200E+00, -.43578700E+00, 0.12380400E-01, 0.45291900E-01, 0.73845900E+02, 0.41547500E+02, -.23053200E+02, -.29284500E+02, -.19804900E+02, -.31210500E+01, 0.69198900E+01, -.26169800E+02, -.14794400E+02, -.16522600E+02, 0.69045200E+01, -.39124000E+01, 0.89069600E+01, -.43713800E+01, 0.17664700E+02, -.45939900E+01, -.43005100E+01, -.24382200E+02, 0.54340700E+01, -.14691100E+02, 0.13341400E+02, -.25597300E+02, 0.44756700E+02, 0.16995600E+02, -.92710400E+01, -.18428600E+02, -.88065500E+01, -.54650000E+01, 0.28203300E+01, -.86753500E+01, -.10884400E+02, 0.49433500E+01, -.16491000E-01, 0.33362900E+01, 0.50703800E+00, -.27745600E+01, 0.71447400E+01, 0.81210500E+00, 0.85350100E+01, -.34514500E-02, -.96204800E+00, -.83575100E+01, 0.50926700E+01, -.89738300E+01, 0.74835500E+00, -.27177400E+00, 0.24720900E+01, -.92125900E+01, 0.71554300E+01, 0.26421000E+01, 0.27091700E+01, -.17012200E+01, 0.30139500E+01, -.13391700E+00, -.35816800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21105500E+00, 0.57654800E+00, -.43721500E+00, 0.41081300E+00, 0.19904000E+01, 0.88612100E-01, -.92215600E+00, -.28558900E-01, -.10076800E+01, -.12799100E+01, 0.29946600E+00, -.52802200E-01, -.19862500E+00, -.76373100E+00, -.35978600E+00, 0.69391800E-01, -.20108800E+00, 0.27974000E+00, -.38192900E+00, -.33357500E+00, -.39878700E-01, -.63714200E-01, -.10466400E+01, -.40191800E-01, -.28801300E+00, -.22795600E-03, -.15013700E+00, -.24895700E+00, 0.50834900E+00, 0.82859300E-01, 0.35221300E+00, -.45963900E+00, 0.65786000E+00, 0.39790200E+00, -.11636600E+01, -.14921800E+00, -.14318300E+00, 0.84530600E-01, 0.21368900E+00, -.84423800E+00, 0.27077600E+00, 0.62589300E+00, -.35789400E+00, -.20304700E+00, -.12525100E+01, 0.45089200E+00, 0.19464300E+01, -.66391800E-01, -.10048600E+01, 0.31788900E+00, -.21573200E+00, 0.21209100E+00, 0.79549800E+00, 0.43753800E+00, -.69627300E+00, 0.24303700E-02, 0.99232700E+00, 0.57101600E+00, 0.76384200E-01, -.60216000E+00, -.39664500E-01, 0.19625500E+00, 0.81206400E+00, -.11661800E+00, 0.13471400E+00, 0.72785900E+00, -.11307400E-01, -.59704700E+00, 0.89312100E-01, -.19226400E-01, 0.22877300E+00, 0.20064400E+00, -.21187400E+00, 0.10926900E+00, 0.45169400E+00, 0.54818900E+00, 0.86688700E-01, -.23874100E+01, -.16987400E+00, -.22853800E+00, 0.20813000E-01, -.25153600E+00, 0.42081300E+00, 0.78077900E+00, 0.70488600E+00, 0.13808300E+00, -.13406300E+00, 0.85088800E-02, 0.90495300E-01, -.35830900E+00, -.82427800E+00, -.46386400E-02, -.35281000E+00, 0.97977300E-01, -.46100200E-01, -.30214100E+00, -.27678800E+00, 0.26452100E+00, -.70000500E+00, 0.23650100E+00, -.25348700E+00, 0.14580400E+00, -.99797100E-02, 0.11009800E+00, 0.52755000E+00, 0.11729200E+00, -.42694900E-01, 0.48470500E+00, 0.81082900E-02, -.16769500E+00, -.10620900E+00, -.15603600E+00, 0.99034500E-01, -.11988800E-01, 0.52927600E-01, -.30751100E+00, 0.12807900E+00, -.40372600E+01, 0.10941600E+00, -.60760000E+00, -.66363700E+00, -.20521600E+00, -.52278700E-01, 0.21461200E+00, 0.48979200E-01, -.26921400E+00, -.51468800E+01, -.17846300E+00, 0.61563700E+00, -.32042900E+01, 0.44166900E+00, 0.38508100E+00, -.23075100E-01, -.75143000E-01, 0.29690300E-01, 0.68833000E-01, 0.27919600E+00, -.38840600E-01, 0.22703800E+00, -.39344800E-01, 0.15620600E+00, -.11508300E+00, 0.11152600E+00, -.13035700E+00, 0.84554100E-01, -.12056300E-01, -.43148500E-02, 0.77103500E-01, -.20818900E+00, 0.41210000E-01, -.80529800E-01, 0.99230800E-01, 0.84106400E+00, 0.45922900E-01, 0.19661900E-01, -.64130000E-01, -.51296600E+00, -.32817700E-01, -.19552300E+00, -.82479900E-01, 0.11863400E+00, 0.48337500E+00, 0.31851000E-01, -.46100500E-01, -.13492700E+00, -.51413500E-01, 0.53609200E-02, -.13564200E+01, -.34617700E-01, 0.18876600E+00, -.47508700E+00, 0.72351900E-01, 0.46995000E+00, -.14226200E+00, 0.12912400E+00, 0.81853200E-01, 0.15851300E+00, -.22324500E+00, -.14865600E+00, 0.10292900E-01, -.38955100E+00, 0.30750500E+00, 0.55490500E+00, 0.16399600E+00, -.68220000E-01, 0.87428900E-02, 0.12652100E+01, -.15877000E+03, 0.79044600E+02, 0.77847600E+02, 0.78424300E+02, 0.40645600E+02, 0.37471000E+01, 0.63151300E+02, 0.21607000E+02, 0.47090700E+02, 0.67312500E+01, 0.38246200E+02, -.15978300E+02, 0.90602300E+01, -.13534200E+02, 0.80610000E+01, -.10696000E+02, 0.62973800E+01, 0.15088000E+02, 0.64682500E+01, 0.12755400E+02, 0.25459400E+01, -.13150400E+02, -.12654300E+02, 0.63262500E+01, 0.24976500E+02, 0.66413700E+01, -.22337800E+01, 0.29738400E+01, -.86224400E+01, -.57981400E+01, -.43325000E+01, 0.47482300E+01, 0.72034600E+01, 0.12655700E+01, 0.38387000E+01, -.52489800E+01, 0.17927800E+00, -.21771800E+01, -.79567700E-01, -.45665900E+00, 0.22309100E+01, 0.10507600E+01, 0.44746700E+01, 0.96414100E+00, 0.65527200E+00, -.47040000E+00, 0.48319900E+01, -.50615500E+01, -.91140000E+00, -.43208900E+01, -.68682200E+00, 0.33128200E+01, -.86045500E+00, 0.97410100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10581400E+01, -.98276200E+01, -.11925900E+02, -.77476100E+01, 0.59475900E+01, -.10591400E+02, 0.94723400E+01, 0.68014400E-01, 0.11593300E+02, 0.84981400E+01, -.12899800E+00, -.29019600E+01, 0.16295900E+02, 0.70189800E+01, 0.14186300E+01, 0.52558500E+01, -.67467400E+01, 0.37994600E+01, -.38738000E+01, 0.48059400E+01, -.21616600E+00, -.68074400E+00, -.15560400E+02, -.10699900E+01, -.32280400E+01, -.78565800E-02, -.22099200E+01, 0.10039200E+01, -.45292700E+01, 0.17952000E+01, -.11547800E+01, 0.45125500E+01, -.14340800E+01, 0.23680500E+00, 0.58856700E+01, 0.24841900E+00, -.38815100E+00, -.11409700E+01, 0.49735400E+00, 0.16860900E+01, -.82377400E+00, -.19545200E+01, 0.54110000E+00, -.49808200E+00, 0.51502900E+01, -.16115500E+01, 0.19733500E+01, -.26750300E+00, 0.13354300E+01, 0.22680400E+01, 0.11823300E+01, 0.23507300E+01, -.38243500E+00, -.12120400E+01, -.16212500E+01, 0.69113000E-01, 0.10050900E+01, -.11058600E+01, 0.34163200E+00, 0.67900900E+00, -.25822000E+01, -.40996000E+01, 0.47450400E+01, 0.61509900E+00, 0.17177600E+01, -.10569800E+00, 0.20011700E+01, 0.26623600E+02, 0.68493900E+00, -.92525900E-01, 0.15608800E+01, 0.14360500E+01, -.40448000E-01, 0.13799900E+01, 0.54262300E+00, 0.14667600E+01, -.55619800E+01, -.47654000E+01, -.13200900E+01, -.41680200E-01, 0.99236100E-01, -.60825900E+00, 0.22047700E+01, 0.26266400E+01, 0.27257600E+01, -.34894500E+01, 0.10726900E+01, 0.12854500E+00, 0.78829800E+00, 0.54558700E+00, 0.12943600E+01, 0.83136200E-01, -.49573400E+00, -.80527800E+00, 0.44063000E+00, -.10148200E+01, -.15507500E+01, 0.32851000E+00, -.28624400E+01, -.13416200E+01, 0.30058800E+00, 0.32119500E+00, 0.96379200E-01, 0.49391800E+00, 0.19040500E+01, 0.15377500E+00, -.30549900E+00, 0.47919000E+00, 0.94092900E+00, 0.65371400E+00, 0.60686400E+00, 0.73632100E+00, 0.68262500E+00, -.28273800E+00, 0.46089600E+00, 0.70089200E+00, -.22607300E+00, -.12304300E+02, 0.45455000E+00, -.21658800E+01, -.35785800E+00, -.15392800E+01, 0.17262900E+01, -.41664900E+01, -.41932900E+00, 0.18333200E+01, 0.11041900E+02, 0.52438700E+00, -.10880100E+02, 0.64729800E+01, -.17327600E+00, 0.18794300E+00, -.16616100E+01, 0.32395300E-01, 0.40639100E+00, 0.76882000E-01, 0.59655900E+01, 0.20728700E+00, -.42963900E+01, 0.13563900E+01, 0.12740100E+01, -.93664000E+00, 0.47376500E+00, -.48429800E+00, -.62059900E-01, -.47093100E+00, -.21979000E+00, 0.60520200E+00, 0.55262400E+01, 0.14453800E+01, 0.10923100E+01, 0.12680100E+01, 0.22278100E+01, -.18563300E-01, -.59201700E+00, -.18673900E+00, 0.52709200E+00, -.29366000E-01, -.57758300E+00, -.61601400E+01, -.16823300E+00, 0.23343500E+01, 0.56817700E+00, -.67338500E+00, -.20335600E+00, -.20013500E+01, -.12056500E+00, 0.27260200E+00, -.39720600E-01, -.49435000E+00, -.99576800E+00, 0.21420000E+00, -.98438800E+00, -.15023900E+01, 0.25666800E+00, 0.16393900E+01, -.96473400E+00, -.21573400E+00, -.72811000E+00, -.14750800E-01, 0.38560000E+00, -.49921900E+00, 0.77381900E+00, 0.25435500E+00, -.14739800E+00, -.14178000E+00, 0.88263800E+00, -.18712700E+00, -.55308000E+02, 0.17301200E+02, 0.16881000E+01, 0.75421900E+02, 0.12137600E+02, 0.12912700E+02, 0.16999300E+02, 0.29760600E+02, 0.99046900E+01, -.51633200E+02, -.72638000E+02, 0.31423100E+02, 0.43740800E+02, 0.35926900E+02, -.92870700E+00, -.11055000E+02, 0.46836200E+02, -.15809300E+02, 0.35743000E+02, -.38487900E+01, 0.29654300E+02, -.44709700E+02, 0.21325200E+02, 0.17927900E+02, 0.22149400E+02, 0.47825700E+02, 0.30115400E+02, -.26868600E+02, -.44703100E+02, -.15222800E+02, 0.30129700E+02, 0.84054000E+01, 0.27102200E+01, 0.19329600E+01, 0.67332800E+01, 0.11079100E+01, 0.88285500E+01, 0.37198100E+01, -.83710400E+01, -.83390800E+01, 0.21106200E+02, -.43485500E+01, 0.20772400E+01, 0.31846700E+00, 0.37177200E+01, -.55951700E+01, 0.69176300E+01, 0.27716700E+01, -.23667200E+01, -.37309300E+01, 0.16463100E+02, 0.89227800E+01, -.51225800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.92079500E+00, 0.22979100E+00, 0.10112500E+01, -.75961900E+00, -.65672900E+00, 0.11259500E+01, -.26604800E+01, 0.33999900E+00, 0.90044300E+00, -.15637800E+01, -.65239800E+00, 0.39660600E+00, -.65570900E+00, 0.11195800E+01, 0.43135800E+00, -.21411000E+01, 0.36566100E+01, 0.59325200E+00, 0.70673700E+00, 0.97229100E+00, -.17350600E-01, 0.46629000E+00, -.11678700E+01, -.20473000E+00, 0.94549300E+00, -.22703300E-02, -.26856900E+00, 0.16845200E+00, -.19475300E+01, -.51798500E-01, 0.27983000E+00, 0.77404200E+00, -.65055300E+00, -.44755500E+00, 0.28313800E+01, 0.74880900E+00, 0.11317100E+00, 0.37935000E-01, -.16238600E+00, 0.12211300E+01, -.12393700E+01, -.10553200E+01, 0.30111200E+00, 0.36884600E+00, 0.20242300E+01, -.72717300E+00, -.16497700E+01, 0.10767200E+00, 0.11777000E+01, -.22446300E-01, 0.96482600E+00, -.46887900E+00, -.15238700E+01, -.44997400E+00, 0.27242100E-01, 0.33647100E+00, 0.26693800E+00, -.10171800E+01, -.27644500E+00, 0.63180400E+00, -.42026600E+00, -.69361000E+00, 0.25332200E+01, 0.60809600E+00, -.15236900E+01, -.10872700E+01, 0.23230000E+00, 0.14195700E+02, -.21660200E-01, 0.60192400E-02, -.76939400E+00, -.72135700E+00, 0.58121200E+00, -.12303300E-01, 0.64066600E+00, -.91838400E+00, -.54265600E+00, 0.54891500E+01, 0.26904200E+00, -.74253900E+00, -.29965700E-01, 0.89023100E+00, -.74937900E-01, -.77340900E+00, -.64208200E+00, 0.35505500E+00, 0.49113700E-02, 0.10465200E+00, 0.52011800E+00, 0.86529100E+00, -.40815000E+00, 0.37867800E-01, 0.84412400E+00, -.62969200E+00, 0.25284200E-01, 0.12929300E+01, 0.68549200E+00, 0.14989400E+00, -.11697000E+00, 0.15544100E+00, -.18807000E+00, -.15586400E+00, 0.23242800E-01, -.32308700E-01, -.20303000E+00, 0.65699700E-01, 0.25999700E+00, -.68332700E+00, -.19777800E+00, 0.13309500E+01, -.21682800E+01, 0.23682000E+00, -.18086000E+00, -.91807500E-02, 0.20712700E+00, -.81141200E+00, -.16805500E+00, -.59033900E+01, 0.86368700E-01, -.27616000E+00, -.20115700E+00, 0.60876700E+00, -.17255800E+00, 0.17102900E+01, -.36694300E-01, 0.99197400E-01, -.77147900E+01, -.23954200E+00, 0.10039800E+01, -.13200000E+02, 0.12312900E+01, 0.48851400E+00, -.52356400E-01, -.23181900E+00, -.35047400E+00, 0.13439700E+00, 0.26360200E+01, -.10103800E+01, 0.18607100E+01, -.72696300E+00, 0.12088200E+00, 0.14215000E+01, -.67068700E+00, 0.31730000E+00, 0.43375900E-01, -.38164800E-01, 0.22729900E-01, -.80734100E+00, 0.23885200E+01, 0.20855300E+01, 0.26676600E+00, -.27890800E-01, -.67776100E+00, 0.32382600E+00, -.82199400E+00, 0.53403600E-01, 0.90351000E-01, -.88408400E-01, -.42325500E-01, 0.24133100E+01, 0.46124900E+00, -.49460300E+00, 0.13731800E+00, -.25005500E+00, 0.29241600E-02, 0.55415800E+00, 0.15208500E+00, 0.11623900E+01, 0.32960200E-01, -.25940300E+00, 0.28972800E+00, 0.46563500E+00, -.19486600E+01, 0.23464000E+00, -.59985300E+00, -.13221600E+01, 0.54908400E+00, 0.50362900E+00, 0.70021600E+00, -.42668600E-01, 0.13959000E+01, 0.30200200E+00, -.14605400E+01, 0.17394500E+01, 0.97221900E-01, -.80552100E-01, -.22699800E+01, -.55586900E+00, -.10901000E-01, 0.15222000E+03, -.23418300E+01, -.60916800E+02, -.36849500E+02, 0.77231000E+02, 0.95296900E+02, 0.12976500E+02, -.31274600E+02, 0.12736800E+02, -.45633200E+02, 0.20265400E+02, -.55563400E+02, 0.22718500E+02, -.13582200E+02, 0.28310800E+02, 0.52467000E+01, 0.14318700E+02, 0.85350100E+01, 0.37317100E+02, -.35823300E+02, 0.92054400E+02, -.43662200E+02, -.56693400E+02, -.45888800E+02, -.71097700E+02, -.42795100E+02, 0.60186900E+02, 0.11142800E+03, -.21436200E+02, -.29583400E+02, -.71271900E+01, -.79467700E+01, 0.18579500E+01, -.26548800E+02, -.12780000E+01, -.21720500E+02, -.43552700E+01, 0.31154100E+01, 0.21012400E+02, -.35572000E+02, 0.20950500E+02, -.91585700E+01, 0.26080800E+01, -.29860500E+01, 0.21476800E+02, -.26075200E+02, -.68945400E+01, 0.22618700E+01, 0.97219100E+01, -.20706100E+02, -.57370100E+01, 0.21539400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10006000E+01, -.12750400E+00, -.54088700E+01, -.38148600E+01, -.62641900E+01, 0.50083000E+01, -.66975700E+01, 0.13873200E+01, -.15411200E+01, -.67691200E+00, -.11499800E+00, 0.58983200E+00, -.19608100E+01, 0.40133800E+00, 0.30733700E+00, -.23292600E+01, 0.34030900E+01, -.13028400E+00, 0.97131000E+00, -.39196500E+00, 0.89882400E-02, 0.24434100E+00, 0.32369600E+01, 0.46041900E-01, 0.24059400E+00, 0.77335700E-03, 0.39049400E+00, 0.42760400E-01, -.18245900E+00, -.23608600E+01, -.37774000E+00, -.11548800E+01, -.13478300E+01, -.11188300E+01, 0.28559400E+01, -.32027900E+00, 0.42880100E+00, -.81796600E-01, -.78517400E+00, 0.30908700E+01, -.17158500E+01, -.15389500E+01, 0.10286000E+01, 0.20605100E+00, 0.21081700E+01, -.17644900E+01, -.93406300E+00, 0.62410200E+00, 0.20314900E+01, 0.19657500E+01, -.92151900E+00, 0.13906900E+01, 0.38380100E+01, 0.12126100E+00, -.23059000E+01, -.62885700E+00, 0.27578800E+01, -.12318100E+00, -.27998400E+00, -.21595200E+00, -.94091700E+00, 0.38775200E+00, 0.30692900E+01, -.71720200E+00, -.30165500E+01, -.32588500E-01, 0.57095600E+00, 0.21494300E+02, -.79363400E-01, -.30441700E+00, -.37216400E+00, -.24530300E-01, 0.31711300E+00, 0.51519500E+00, 0.18948500E+01, -.51865400E+01, -.10350300E+01, -.54943100E+01, 0.16162200E+00, 0.30852100E+00, -.32202300E+00, 0.11892100E+01, -.57002100E+00, 0.39608700E+00, -.15536300E-01, 0.22537700E+01, -.15331200E+01, 0.11669600E-01, 0.17666800E+01, 0.65275200E+00, -.80639000E+00, 0.27213600E-01, -.15677600E+00, -.29482400E+00, -.75632500E-01, -.52385000E+00, 0.92135900E+00, 0.15439700E+00, -.15218300E+00, 0.79638100E+00, -.56043300E+00, -.15028000E+00, 0.23722200E-01, -.30588100E+00, -.24904700E+00, -.60237400E+00, 0.43634900E+00, -.62767200E+00, -.47570700E+00, -.17813800E+01, -.17372500E+01, -.34185600E+00, 0.21095700E+00, -.80968100E-01, 0.16586500E-01, 0.88842700E-01, -.33239500E+00, -.83170900E+01, -.18516300E-01, -.43303200E+00, -.49812600E+00, 0.72953400E+00, -.22359400E-01, -.11925100E+00, -.11613900E+00, -.18554600E+00, 0.30080400E+01, 0.21411500E+00, -.71550000E+01, -.10239500E+02, 0.19430100E+01, -.30613600E+00, -.24655200E+00, -.13073500E+00, -.38181800E+00, -.14749300E+00, 0.10331500E+01, -.40178800E+00, 0.21015600E+01, -.49350300E+00, 0.10493400E+00, 0.17625400E+01, -.83005800E+00, 0.62512400E+00, -.18736800E+00, -.17847300E+00, 0.27750400E-01, -.81449100E+00, 0.26902500E+01, 0.16752600E+01, 0.61237200E+00, -.10678100E+01, -.35182900E+01, 0.71996300E-01, -.39213800E+00, -.11013900E+00, -.35528100E+00, 0.13793100E+00, 0.49309100E+00, 0.46389000E+01, 0.52432100E+00, -.14556400E+01, -.12898500E+00, 0.33237500E+00, 0.21053200E+00, 0.12773500E+01, 0.79161500E-01, -.15338200E+01, 0.12183600E+00, 0.25476000E+00, 0.93686700E+00, -.16000600E+00, -.25391100E+00, 0.10243300E+01, -.15141100E+00, -.12722300E+01, 0.37297500E+00, 0.17869800E+00, 0.66447200E+00, -.30849200E-02, 0.40861500E+00, -.12946400E+01, 0.10697100E-01, 0.74159900E+00, -.78319400E-01, -.95640500E-01, -.85857200E+00, 0.35937500E-02, 0.74251700E-01, -.23284600E-01, 0.35469400E+02, -.41646100E+02, -.47788700E+01, -.68124200E+01, -.10971600E+02, -.21797500E+02, -.26816800E+01, 0.12194800E+02, -.63504700E+01, 0.41051200E+01, -.94805500E+01, 0.55839600E+01, -.18149200E+02, 0.44880200E+01, -.89872400E+01, -.14355300E+02, 0.14100600E+01, 0.46617000E+01, 0.23686700E+02, 0.20285500E+02, -.96772700E+01, -.12940400E+02, -.83603200E+01, -.16238800E+02, -.10762900E+02, 0.13160100E+02, 0.24462500E+02, 0.39072100E+01, -.99088600E+01, -.98696900E+00, 0.87204100E+00, -.22473600E+01, -.28447300E+01, -.11092700E+00, -.79687700E+00, -.12585600E+01, 0.26980500E+01, 0.60731400E+00, -.10823000E+02, 0.70335700E+00, 0.79196800E+00, 0.11494700E+01, -.39599500E+00, 0.35092400E+00, -.27869100E+01, -.19678400E+01, 0.25428300E+01, -.11467900E+00, -.88756300E+01, -.26173500E+01, 0.24704200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.43979500E+00, -.61513700E+00, 0.10104400E+01, -.83660200E+00, 0.80259400E+00, 0.58626900E-01, 0.18762600E+01, -.36947400E+00, 0.13875300E+01, -.50502600E+00, -.25628900E+00, 0.10298400E-01, 0.64706800E-01, -.14650100E+01, -.26540300E+00, 0.11068500E+01, 0.13642900E+01, -.61085600E+00, 0.54709700E+00, -.58438200E+00, 0.10374200E-02, 0.21875300E+00, 0.24878200E+01, 0.23701300E+00, 0.52502100E+00, 0.20982100E-02, 0.45663900E+00, -.41628200E+00, 0.90722000E+00, -.96792700E+00, 0.80170200E+00, -.23493000E+01, 0.35674500E+00, -.27373800E-01, -.69202600E+00, 0.31329800E-01, -.63249700E-02, 0.12419200E+00, -.16561500E+00, -.10483900E+01, 0.77437400E+00, -.48177000E+00, -.10103500E+00, -.10598000E+00, 0.25295600E+00, -.12311000E+00, 0.46127100E+00, -.33369100E-02, 0.42162900E-01, -.27118800E+00, -.31030900E+00, -.17877700E+00, 0.13153800E+00, 0.35863800E+00, -.55092300E-01, -.15990700E+00, 0.81922300E+00, -.71182100E+00, 0.11636300E+00, -.15768700E+00, 0.26942700E+00, 0.54157000E+00, 0.79592800E+00, 0.22591000E+00, 0.33306800E+00, 0.17763200E+00, -.11011600E+00, 0.36717900E+01, -.16306700E-01, 0.23047700E-02, -.19432500E-01, 0.49371300E-02, -.13470400E-01, 0.23459400E+00, 0.25006700E+00, 0.89573700E+00, 0.77729200E+00, -.87426300E+00, 0.97909600E-01, -.40324900E+00, 0.24737700E-01, 0.37357100E+00, 0.32145900E-01, 0.15352300E+00, -.14841700E+00, -.22240800E+00, -.26303600E+00, -.17301400E+00, -.16941900E+00, 0.95166500E+00, 0.32525100E+01, -.20617700E-01, 0.26131300E+00, 0.36138800E+00, -.18820500E+00, -.47615000E+00, 0.11257500E+00, -.56098100E-02, -.30690900E+00, 0.34845100E+00, -.41199500E+00, 0.42276300E+00, 0.36246600E-01, -.24390600E+00, 0.11786600E+00, -.99609500E-01, 0.75736800E-01, -.22173500E+00, 0.19606000E+00, 0.43661500E+00, -.54615400E+00, -.15117300E+00, 0.59036600E+00, 0.16452600E-01, -.22069000E+00, 0.12511200E+00, -.13171100E+00, 0.17901100E+01, 0.64011600E-01, 0.99987400E+00, 0.78534500E+00, 0.49775400E+00, 0.24497400E+00, 0.46896500E-01, 0.62347700E-01, -.83360400E+00, -.92831400E+00, 0.21140700E+00, -.32621200E+00, -.53761300E+01, 0.65852500E+00, -.23998300E+00, 0.25289100E+00, -.33018100E+00, -.17182700E+00, 0.11166900E+00, -.14425100E+01, -.85644800E-01, 0.10285200E+01, -.24204000E+00, 0.32164100E+00, 0.11011800E+00, 0.25229000E+00, -.19038000E+00, -.86504000E-01, 0.65770000E-02, -.27455300E-01, 0.40278300E+00, -.91451100E+00, -.10886000E+01, -.40189600E-02, 0.22738000E+00, -.24781300E+00, -.18395900E-01, 0.67946600E+00, -.14802200E+00, 0.10256100E+00, 0.46926300E-01, 0.48327600E+00, 0.19987400E+01, 0.21816300E+00, -.70170600E+00, -.47040800E+00, 0.38176300E+00, 0.32310800E+00, 0.94930700E+00, 0.14452900E-01, 0.50374900E+01, -.10820300E-01, -.10513900E+00, 0.69704900E-01, -.25990900E+00, -.35992500E+00, -.16730200E+00, 0.19689400E+00, 0.43877700E+00, -.16158400E+00, -.79933300E-01, -.22331500E+00, 0.13834700E-01, -.25473500E+00, -.47204600E+00, -.24502600E-01, -.10824600E+01, 0.72488500E-02, 0.57611000E-01, -.43057200E+00, -.82207400E+00, 0.54496600E-01, -.10680800E+00, 0.13963900E-01, 0.71615600E+02, 0.46078400E+02, -.38407300E+02, -.69619500E+01, -.26248200E+02, 0.45318600E+02, -.47119900E+02, 0.17114700E+02, -.72443500E+01, 0.23962700E+02, -.83647100E+01, -.45397700E+01, -.23871200E+02, 0.21676100E+02, -.35522200E+01, 0.25365300E+02, -.31527700E+02, 0.22508100E+01, 0.23899800E+02, -.13334800E+02, -.17449900E+01, -.11837800E+02, 0.20072900E+02, 0.25539100E+02, -.43311400E+02, -.52001900E+02, -.18465100E+02, 0.22579700E+02, 0.51254000E+00, 0.28609000E+00, -.39062800E+00, 0.19086600E+02, 0.19633400E+01, 0.18718600E+02, 0.12699800E+01, -.82529600E+01, -.18334000E+02, 0.25326400E+02, -.17760200E+02, 0.86575500E+00, -.88936600E+00, 0.72341100E+01, -.18212100E+02, 0.18986300E+02, 0.77397800E+01, -.61736600E+00, -.25987800E+01, 0.16682200E+02, 0.71215800E+01, -.67579300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19276900E+00, 0.48267600E+00, 0.15418400E+01, 0.43296100E+00, -.16653600E+01, 0.13874900E+00, 0.13939200E+01, -.48513000E-01, 0.34872100E+00, 0.20668600E+01, -.29449300E+00, 0.15120300E-01, 0.47606400E+00, -.54262200E+00, -.26113800E+00, 0.13519400E+01, -.15311400E+01, -.60870200E+00, 0.11413200E+01, -.62607200E+00, 0.17897400E-01, 0.20999600E-01, 0.17271600E+01, 0.10872700E+00, 0.51915500E+00, 0.15743900E-02, 0.38239100E+00, 0.86512800E+00, -.58571900E+00, -.26293600E+00, -.42498700E+00, -.10394500E+00, -.19128600E+00, 0.16910200E+00, 0.38367800E+00, 0.30907600E-02, 0.78109500E-01, 0.51929900E-01, 0.11829600E-01, 0.12124800E+01, -.10093000E+01, 0.35340700E+00, 0.20677400E+00, 0.29725200E+00, -.13416900E+01, -.75712200E-02, -.11516300E+01, 0.44472300E-01, -.13067300E+00, -.46700600E+00, 0.16956900E+00, -.62012700E-01, -.62110500E-01, -.34688200E-01, 0.36132200E+00, 0.77908500E-01, -.22438500E+00, 0.61496700E-01, -.71217800E-01, 0.15565500E+00, -.13541400E+00, -.25741200E+00, 0.28335100E+00, -.13322800E-01, -.52815000E+00, -.29835400E+00, -.65819300E-01, 0.11142300E+01, 0.51987100E-01, 0.41776900E-02, 0.42807200E-01, 0.15929500E+00, 0.19285500E+00, -.82198200E-01, -.10384000E+00, -.44449900E+00, -.59818800E+00, 0.11481600E+01, 0.71360000E-01, 0.13903600E+00, 0.10409700E-01, 0.24497500E+00, 0.51677900E-01, -.59098200E-01, -.20304300E+00, -.32523900E+00, 0.15685900E+00, 0.66752300E-01, -.20815900E+00, -.31424100E+00, -.18427100E+01, 0.30004900E-02, 0.14282300E+00, -.32276300E+00, -.10807300E+00, 0.21571500E+00, 0.51592000E-01, -.34344500E-01, 0.86574500E-01, 0.37155000E-01, 0.23803600E+00, -.11530600E+00, 0.29410000E-02, 0.58199100E-01, -.34024500E+00, -.14940100E-01, -.31859800E-01, 0.15905500E+00, 0.20434700E+00, 0.25090900E+00, 0.40978300E+00, 0.30227300E+00, -.29450100E+00, -.50375500E-02, -.63826400E-01, 0.12663500E+00, 0.12027100E+00, -.25752800E+01, -.64981300E-02, -.34514700E+00, -.17284500E+00, 0.58564100E-01, -.44458400E-01, 0.50176600E+00, -.10051400E-01, 0.58565200E+00, -.87591400E+00, -.14756300E+00, 0.24123200E+01, -.89588100E+00, -.45547500E+00, 0.88322500E-01, -.43588400E-01, 0.34545700E-01, 0.18217500E-01, -.54646200E-01, 0.16865800E+00, -.12803800E+00, -.37019300E+00, 0.24429500E+00, 0.14780600E+00, -.20551800E+00, 0.18729300E+00, -.23336000E+00, 0.40596100E-01, 0.18609100E-01, 0.29979100E-02, 0.27357600E+00, -.40136400E+00, -.26721000E+00, -.87702700E-02, -.31256700E+00, 0.33758500E+00, -.44256600E-01, 0.53548500E+00, 0.81927400E-01, -.17987500E+00, -.17601100E-01, 0.46278900E-01, -.80407600E+00, -.24644700E-01, 0.36392800E+00, -.84775400E-01, -.12569200E+00, 0.15443700E+00, -.21147500E+00, -.49471600E-01, 0.60701200E+00, -.21743800E-01, 0.21867200E+00, -.35382100E-01, -.36316100E-01, -.65310000E+00, -.84337300E-01, 0.47999800E-01, -.11287200E+00, 0.33100400E-01, 0.35891600E-01, -.39546800E-01, 0.69253500E-03, 0.24664800E+00, -.73707800E+00, -.18842200E+00, 0.16844000E+00, -.18825000E-01, -.58602300E-01, -.31975000E+00, -.16324200E+00, 0.52270200E-01, -.21660500E-01, 0.14404200E-01, 0.21305000E+00, 0.16960700E+02, -.13655200E+02, -.26706100E+02, -.17721900E+02, 0.15214800E+02, -.39300800E+00, 0.10185800E+02, -.35004300E+01, -.10147300E+02, -.51168800E+01, 0.99949700E+00, -.34534900E+01, -.16155000E+01, 0.10922100E+02, 0.15311000E+01, 0.74031400E+00, -.67165700E+00, -.22113100E+01, 0.10583800E+01, 0.32534600E+01, 0.96137400E+00, 0.85438100E+01, 0.95854200E+01, -.46008700E+01, -.94646200E+01, -.11019900E+02, 0.97894200E+01, -.85807300E+01, 0.29679000E+00, -.15648700E+01, 0.25747100E+01, 0.35935100E+00, 0.32450800E+01, -.25169300E+00, -.27669200E+01, -.33348700E+01, 0.37025500E+01, -.33926100E+01, 0.26259800E-01, 0.13424300E+00, 0.28787000E+01, -.35051500E+01, 0.25439400E+01, 0.17171600E+01, 0.15455300E+01, 0.53840000E+00, 0.28389400E+01, 0.25555600E+01, 0.54776100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12898700E+01, 0.17156100E+01, 0.84018600E+01, 0.12592300E+01, 0.84705400E-01, 0.63481800E+00, -.25110700E+01, -.32163100E+00, -.65220600E+00, -.33726000E+01, -.64805900E+00, 0.58060800E+00, -.31717900E+00, -.25785000E+01, -.11664500E+01, 0.18412200E+01, -.22862300E+01, -.18357200E+01, 0.72427700E+00, -.67376300E+00, -.19210100E+00, 0.21120100E-01, -.36371400E+01, -.17457700E+00, -.69170900E-01, 0.68542000E-02, -.71190900E+00, -.30567600E+01, 0.70320800E+00, -.83615600E+00, 0.22758300E+01, -.76287600E+00, 0.19834100E+01, 0.89847000E+00, -.38605800E+01, 0.31281000E-01, -.49824600E+00, 0.68815200E+00, 0.81366700E+00, -.35565900E+01, 0.46594800E+01, 0.56630100E+00, -.80676500E+00, -.44475000E+00, -.28475400E+01, 0.71907300E+00, 0.31042900E+01, -.18806400E+00, 0.23270000E+00, 0.10671900E+01, -.14325800E+00, 0.78377600E+00, 0.73226000E+00, 0.12919100E+00, -.11575000E+01, -.85908600E+00, 0.26168700E+01, -.92986000E+00, 0.52415600E+00, -.26878300E+00, 0.63819700E+00, 0.19461900E+01, 0.18833900E+01, -.23000900E+00, 0.17741100E+01, 0.97770800E+00, 0.35148300E+00, -.68814500E+01, 0.30262900E+00, -.12751100E-01, 0.10420000E+01, 0.83030000E+00, -.29650100E+00, 0.79747700E+00, -.79256000E+00, 0.43055900E+01, 0.95774200E+00, -.28916800E+01, -.13199800E+00, -.33671700E+00, 0.13620600E+00, 0.89753300E+00, 0.68415100E+00, 0.14285400E+01, 0.10372700E+01, -.22341500E+01, 0.59467100E+00, -.18194900E+00, -.10453000E+01, -.28119700E+01, -.16464900E+01, -.13244300E+00, -.29107700E+01, -.78971400E+00, -.12864200E+01, -.24309200E+01, -.79048600E+00, 0.53388700E+00, -.27922600E+01, 0.53337800E+00, -.37414800E+00, 0.95708500E+00, 0.63334400E-01, 0.81393100E+00, -.92930900E+00, 0.40992800E+00, -.51536500E+00, 0.43765400E+01, 0.12167300E+01, -.16715500E+01, 0.18606700E+01, -.88268300E+00, 0.12885400E+01, -.20169900E+00, -.12287100E+01, 0.26874900E+00, 0.30828800E+00, 0.11124400E+02, -.93666100E-01, 0.12506600E+01, 0.14917800E+01, -.51351500E+00, 0.40103400E+00, -.86039100E+00, 0.42269300E-01, 0.30579400E+00, -.44840600E+01, 0.67091900E+00, 0.10984900E+01, 0.15368300E+02, -.48040800E+00, -.91754400E-01, -.40473800E-01, -.20073600E-01, -.44931700E-01, 0.60801700E-01, -.28032300E+01, 0.61646400E+00, 0.51556000E+00, 0.71699200E+00, -.55616800E-01, -.22426100E+01, 0.21116100E-01, 0.37552400E+00, -.11303300E+00, 0.54959800E-02, 0.18845100E-01, -.70591000E-01, 0.10898200E+00, 0.47758100E+00, -.15719800E-01, -.10475700E+00, 0.13571000E+01, 0.84883800E-01, -.14954500E+01, 0.62442900E-01, 0.34681400E+00, -.13137200E+00, -.66614100E+00, -.22112300E+01, 0.65115800E+00, 0.76815800E+00, -.17136900E+00, 0.42499100E-01, -.12456800E+00, 0.44631000E+00, -.13850800E+00, -.35943500E+01, -.12581400E-01, -.29329000E+00, 0.34816800E+00, -.27474700E-01, -.61488500E+00, -.17906700E+00, 0.20155000E+00, 0.63470100E+00, 0.74683700E+00, 0.55972300E+00, -.15678900E+01, 0.50855800E-01, -.10551500E+01, -.16918500E+01, -.77669800E-01, -.20177700E+01, 0.63738000E-01, -.15727500E+00, -.47705300E+01, -.33303500E+01, 0.21436900E+00, -.46664600E+00, 0.84731300E-01, 0.28633300E+01, 0.19701500E+01, -.81833500E+02, -.18647400E+03, -.53495800E+02, 0.75423100E+01, -.48259000E+02, -.25132700E+03, 0.12934500E+03, 0.56014500E+02, 0.12491800E+03, 0.55185700E+02, -.12709200E+02, 0.10020300E+03, -.68009900E+02, 0.82035900E+02, -.28630600E+02, 0.16587300E+03, 0.94278200E+02, -.48369900E+02, -.62785200E+02, -.47954200E+02, -.17924500E+02, -.22147200E+02, -.15335400E+02, 0.27151100E+02, -.56632800E+01, -.15698700E+02, -.52260900E+02, -.97903800E+00, 0.68019900E+01, -.18385500E+02, -.91275800E+00, -.61134800E+01, -.17885600E+01, 0.24844500E+01, 0.73924700E+01, 0.14133000E+02, 0.93697400E+01, 0.26570500E-01, -.63514700E+01, -.27822600E+01, 0.65278500E+01, -.18087000E+02, -.63471800E+01, -.79339000E+01, -.31016800E+01, -.10678800E+01, -.32789900E+01, 0.77434400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.69629800E+00, 0.14786300E+01, -.35315200E+01, 0.12912600E+01, 0.15729900E+01, -.77158100E+00, 0.29544900E+01, -.41132000E+00, -.64963300E-01, 0.17586400E+01, 0.31894500E+01, -.35017800E+00, 0.20537800E+01, 0.20611500E+01, -.10966300E+01, 0.66635600E+00, 0.41244000E+01, -.18760800E+01, -.23976100E+01, 0.38193200E+01, 0.77786900E+00, 0.76192400E-01, -.46669300E-01, -.18498200E+00, -.17974100E+00, -.56365600E-03, -.23708200E+00, -.65027600E+00, -.11509200E+00, -.49851700E+00, 0.26883000E+00, 0.15597800E+00, -.40444100E+00, -.91928900E+00, 0.10137500E+01, -.19924400E-02, 0.13149100E+00, 0.15351900E+00, -.12056200E+00, 0.12467800E+00, 0.49113300E+00, 0.50730800E-01, 0.80725200E-01, 0.41172300E+00, 0.20037600E+01, -.70862600E+00, -.13015400E+01, 0.95137000E-01, -.45120200E+00, 0.19462400E+01, 0.66496300E+00, 0.19528800E+01, 0.27385400E+01, -.26464600E+00, 0.34687200E+01, -.64113900E+00, 0.12904800E+01, -.27154100E+01, 0.37182300E+00, 0.90193200E+00, -.16007400E+00, -.36716200E+00, 0.22617900E+01, -.88056300E-01, -.71645800E+00, -.11790600E+01, 0.25370400E+00, 0.93513400E+01, -.10740200E+00, -.26783600E-01, -.89400300E-01, 0.13972700E+00, 0.59263000E+00, 0.30470900E+00, 0.18400400E+00, 0.51667700E-01, 0.81282800E+00, -.24297300E+01, 0.22457100E+00, 0.47143000E+00, 0.57535900E-01, 0.16161100E+01, -.16036200E+01, -.65410900E+00, -.82444000E+00, 0.26181500E+01, -.14379000E+01, 0.86730300E-01, -.38907600E+00, 0.17145100E+01, 0.95962200E+00, 0.85497900E-01, 0.32016000E+00, 0.22269100E+00, -.10671900E+00, 0.85228600E+00, 0.11946900E+01, 0.91779200E-02, 0.13618300E+01, 0.40417000E+00, -.46599700E+00, -.20700200E+00, 0.73879200E-01, 0.23125600E-01, -.79382000E+00, 0.65735800E-02, 0.26088000E+00, -.36525100E+00, 0.21279300E+00, 0.27025600E+01, 0.13679300E+01, 0.60346300E+00, 0.17134300E+00, 0.11195400E-01, -.20982700E+00, 0.17900700E+01, 0.23456900E-01, -.21110400E+01, 0.22474700E+00, -.33139700E-01, 0.10685800E+01, 0.72784100E+00, -.28259400E+00, 0.16228300E+01, 0.84885000E-01, -.39347700E+00, -.24306900E+00, -.86377600E+00, 0.52631800E+01, -.43056900E+01, -.13279700E+01, 0.21438400E+00, 0.22669900E+00, 0.27517500E-01, -.75529700E-01, -.11889700E+00, 0.42092000E+01, -.98088900E+00, 0.84016000E+00, -.90328900E+00, 0.30345000E-01, 0.19552900E+01, -.83081500E-01, -.23017800E+00, 0.14417500E+00, -.23322900E-01, 0.35414700E-01, -.58354500E+00, 0.66703200E+00, 0.11303900E+01, 0.15009700E+00, -.12907700E+01, -.25008600E+01, 0.32668000E+00, 0.86989100E+00, 0.10577100E+00, -.23832400E+01, -.45479000E-01, -.80320700E+00, -.15018000E+01, -.44441300E+00, -.92914400E-01, 0.27483200E+00, 0.19852500E+00, -.43734200E+00, 0.15621600E+01, -.83822600E-01, -.26860500E+02, -.67675800E-01, 0.11822700E+01, -.14982300E+01, 0.72701000E+00, 0.16065800E+01, 0.44020700E+00, -.11437600E+00, -.32276000E+00, 0.57486400E+00, -.30212500E+00, -.15623900E+00, -.11078100E-01, -.34504800E+00, -.10780700E+01, 0.11216000E+01, -.58926300E-01, -.10510600E+00, -.63421000E-01, 0.21423300E+01, 0.20086200E+01, -.32065900E-01, -.67818900E+00, 0.26333200E-01, -.99693100E+00, 0.19137900E+01, 0.24301800E+00, 0.80056700E+02, 0.15596600E+02, 0.53804800E+00, 0.10659700E+03, 0.20289700E+03, -.10607500E+03, -.57071800E+02, -.10084900E+03, -.65539300E+02, 0.45188000E+00, -.55629100E+02, 0.88437000E+02, -.19058500E+02, -.17372000E+02, -.92227700E+02, -.15162500E+02, 0.86409500E+01, 0.22831100E+02, 0.82157900E+01, -.78361900E+01, 0.13765800E+02, -.96985300E+01, -.28293800E+02, -.58892400E+01, 0.94873900E+01, 0.40649300E+02, -.38420600E+00, -.43449700E+01, 0.23855800E+02, 0.11870300E+01, 0.15550900E+02, 0.81334500E+00, 0.17669700E+01, -.16013500E+02, 0.46105100E+01, -.19957500E+02, 0.26912900E+00, 0.30478200E+01, 0.63582300E+01, -.19701200E+02, 0.23670300E+02, 0.89825500E+01, 0.46105300E+01, -.12790800E+01, 0.53306700E+01, -.59486400E+01, -.71893000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24054100E+01, 0.26711500E+01, 0.13727900E+02, 0.17456900E+01, 0.72509000E+00, 0.15430500E+00, -.41004600E+01, -.50773500E+00, 0.13618600E+01, -.52489200E+01, -.13668700E+01, 0.51184800E-01, 0.17431200E+01, -.37599000E+01, -.13285000E+01, 0.33294500E+01, -.44114900E+01, -.18802500E+01, 0.17046700E+01, -.20904000E+01, -.76518800E+00, -.65288200E+00, -.89169000E+01, -.42720000E+00, -.80619300E+00, -.22429100E-02, -.14643300E+01, -.47995300E+01, 0.61563500E+00, -.78559300E+00, 0.34866700E+01, -.88808200E+00, 0.33071300E+01, 0.35214200E+00, -.65277600E+01, -.13542800E+00, -.78394500E+00, 0.96817300E+00, 0.54302400E+00, -.59002000E+01, 0.82314500E+01, -.43809100E+01, -.53830300E+00, -.14079700E+01, -.34375300E+01, -.31909000E+00, 0.29039700E+01, -.17014400E+00, 0.72507000E+01, 0.40664500E+01, 0.58098900E+00, 0.21844500E+01, -.15174200E+01, -.87188100E+00, -.31980000E+01, -.14297100E+01, 0.59819700E+01, -.31596600E+01, 0.87524600E+00, -.86473000E+00, -.10899700E+01, 0.18967500E+01, 0.52899600E+01, 0.43272600E+00, 0.28413400E+01, 0.14282200E+01, 0.50723700E+00, 0.12504200E+02, 0.13136800E+01, -.15713400E-02, 0.17194400E+01, 0.63980100E+00, 0.11771300E+00, 0.20506600E+01, -.36181500E+00, 0.10274300E+02, 0.99723000E+00, -.16033400E+01, -.38442900E+00, -.11367200E+01, 0.13081700E+00, 0.78620400E+00, 0.20424600E+01, 0.19532200E+01, 0.16680500E+01, -.26244200E+01, 0.16157000E+01, -.96244900E-01, -.37699800E+01, -.25668900E+01, 0.85702000E+01, -.76045800E-01, -.34165400E+01, -.21883600E+00, -.16557600E+01, -.28406400E+01, -.23053900E+01, -.71470000E+00, -.43912700E+01, -.44727400E+00, -.10229300E+01, 0.26809800E+01, 0.56408200E-01, 0.13221200E+00, -.30278400E+00, 0.14598800E+01, -.30578600E+00, 0.33767500E+01, 0.17316800E+00, 0.27007800E+01, 0.33321100E+01, -.52923300E+00, 0.31658400E+01, -.21253400E+00, -.18517700E+01, 0.52596200E+00, 0.47515200E+00, -.22185500E+01, 0.56764200E-01, -.98490900E-01, -.23782600E+01, -.14778200E+01, 0.43811100E+00, -.11418200E+01, 0.18459600E+00, 0.32724700E+01, -.20140000E+02, 0.11548100E+01, 0.75793000E+01, 0.13975600E+02, 0.24317600E+01, 0.14268700E+01, -.29577700E-01, -.37453700E+00, -.11358300E+00, 0.28526400E-01, -.48432500E+01, -.96161500E-01, 0.32637600E+00, 0.12603000E+01, 0.35211400E-01, -.22111100E+01, -.52420600E+00, 0.10558800E+01, -.60313900E+00, -.19887600E+00, -.23688300E-01, 0.26979600E+00, 0.27636300E+00, 0.29632400E-01, 0.26658000E+00, 0.28480800E+00, 0.91492400E+00, -.40401200E+00, -.38632600E+01, 0.24820600E+00, 0.26765000E+00, -.38600800E+00, -.10349100E+01, 0.96846000E-01, 0.25439200E+01, 0.19426800E+01, 0.13749800E+00, -.34791400E+00, -.12519200E+01, 0.14879100E+01, -.35962900E+00, -.10992500E+02, -.45969300E-01, -.12212300E+00, -.23136700E+01, 0.89382800E+00, -.42302700E+01, -.76708500E+00, 0.63793600E-01, -.59635300E+00, 0.21637600E+01, 0.10189300E+01, -.10149200E+01, 0.40219800E-01, 0.14788200E+01, -.27249200E+01, -.40798900E+00, -.22227600E+01, 0.18578200E+00, 0.30487600E+00, -.60059500E+01, -.43723900E+01, 0.91772000E+00, -.69758500E+00, -.16584800E-01, 0.31916800E+01, 0.38566300E+01, -.44888600E+00, -.16961100E+01, -.10542400E+03, 0.33569400E+02, 0.13873700E+03, 0.21539900E+03, -.11015100E+03, 0.25912200E+02, -.10506600E+03, -.79091800E+02, -.73234400E+02, -.17666500E+02, 0.90814300E+02, 0.11169600E+03, -.14921200E+03, -.10508400E+03, 0.19770100E+03, -.10305000E+03, -.83189600E+02, -.96043500E+02, -.13317100E+03, -.39140300E+02, -.64373700E+02, -.61302100E+01, -.15061500E+02, -.35673200E+02, 0.42103000E+02, -.11587500E+02, -.16570200E+01, 0.48363300E+02, 0.31011500E+01, 0.51954000E+02, -.35769500E+01, 0.84537000E+01, -.51408700E+02, -.25896200E+01, -.63200500E+02, -.64852200E+01, -.50369400E+01, 0.15745000E+02, -.65328200E+02, 0.49072200E+02, 0.22525100E+02, -.15303800E+01, -.24869300E+01, -.15889500E+01, -.21228500E+02, -.67258400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.96849300E+00, -.25837100E+01, -.78665300E+01, -.11537100E+01, 0.34960700E+00, -.63457600E+00, 0.18306600E+01, -.10850200E+00, -.10252600E+01, 0.14528200E+01, 0.34801400E+00, 0.11635500E+01, -.66197200E+00, -.93684900E+00, -.13097800E+01, 0.13813200E+01, -.22534800E+01, -.11340800E+01, 0.42015300E+00, 0.16344400E+01, 0.87670400E-01, -.69230300E-01, 0.43694600E+01, 0.54773000E+00, -.37472500E+00, -.11194600E-01, 0.41332700E+00, -.55486000E+00, 0.35822500E+01, -.44174800E+00, -.44776700E+00, -.29566700E+01, 0.48310700E+00, -.42048700E+01, -.45146100E+01, -.45715900E+00, 0.32860500E+00, 0.26698900E+00, -.94831600E+00, -.20429100E+01, -.10898900E+01, 0.21459700E+01, -.10701900E+01, -.10606000E-01, 0.50742200E+01, -.31814300E+00, -.16965500E+01, -.13728400E+00, -.32655000E+01, -.32161600E+01, 0.70431300E+00, -.19636700E+01, -.19880300E+01, 0.99293900E+00, 0.36993600E+01, 0.23708700E+00, -.35348200E+01, 0.59059400E+00, -.45269400E-01, 0.77796100E+00, 0.14539300E+01, -.18560400E+00, -.31210300E+01, 0.56206800E+00, 0.16577600E+01, -.77212600E+00, 0.16836200E+00, -.16546900E+02, 0.37173700E+00, 0.15756100E+00, 0.38373300E+00, -.67278200E+00, 0.61388300E-01, 0.28471500E+00, -.11525800E+01, 0.50535700E+01, -.17595400E+00, 0.54910100E+01, 0.17606600E+00, 0.47307700E+00, 0.49908600E-01, 0.28965800E+00, 0.89420700E+00, -.10189500E+01, 0.16059900E+01, -.39945000E+01, 0.12709700E+01, 0.33140900E+00, -.22756100E+01, 0.15908000E+01, -.10064400E+02, 0.49722300E-01, 0.34661000E+00, -.43049000E+00, 0.38039500E+00, 0.21621800E+01, -.29827800E+01, 0.69212300E+00, -.14950400E+01, -.60927900E+00, 0.15456600E+01, 0.67691800E+00, -.18163200E+00, 0.20633600E+00, 0.14783700E+01, -.11515200E+00, -.96329900E+00, -.41729200E+00, 0.22563000E+01, 0.31962500E+01, -.10198800E+01, 0.17872300E+01, -.16220200E+01, 0.10381400E+00, 0.74116600E+00, 0.23217700E+00, -.22529900E+00, 0.66020300E+01, -.84315900E-02, -.46477600E+00, 0.47024900E+01, 0.31205100E+00, 0.26040700E+00, -.31354400E+01, -.73758800E-01, 0.58951200E+00, 0.15427200E+02, 0.76768900E+00, -.72828600E+01, -.56518500E+01, -.16799400E+01, -.10081300E+01, -.95442100E+00, 0.30384300E+00, -.11750200E+00, -.46687300E+00, -.38306400E+01, 0.44579700E+00, -.18331400E+01, 0.16816300E+01, -.35422500E+00, 0.96440800E+00, 0.60235100E+00, -.19145900E+01, 0.39376400E+00, -.16265500E+00, -.25291200E-01, 0.12704700E+01, 0.52204800E+00, -.31085300E+01, 0.27221900E+00, 0.30817000E+01, 0.81836900E+01, -.61611700E+00, 0.46837700E+01, 0.18465200E+00, 0.44408400E+00, -.12773000E+00, 0.64988700E+00, 0.35395000E+01, 0.11437800E+01, 0.33202100E+00, -.83631900E+00, -.80639200E-01, 0.16648000E+00, 0.10084900E+01, -.25201400E+00, 0.43092600E+01, -.87118600E-01, 0.31505800E-01, -.53413600E-01, -.97897200E+00, -.29951500E+01, -.15114500E+00, 0.46362000E+00, -.14542700E+00, 0.43001200E+00, 0.88048500E-01, -.64928700E+00, 0.67802000E-01, 0.53100000E+00, -.30998700E+01, -.25849700E+01, 0.76752300E+00, -.28583000E+00, -.29836600E+00, -.21101600E+01, -.19771200E+01, 0.14637400E+00, 0.33336500E-01, -.42763700E-01, 0.21092000E+01, -.86629300E+00, 0.58268500E+00, -.54897500E+00, -.52056700E-01, -.21392000E+02, 0.11285000E+03, 0.71969600E+02, -.32789500E+02, -.53090300E+02, -.34359500E+02, 0.33264000E+01, 0.13625500E+03, -.13377600E+03, 0.18203100E+01, -.22455800E+03, 0.18893800E+03, -.61963600E+02, -.26629900E+03, 0.13489600E+03, 0.10905700E+03, 0.13465600E+03, 0.33983900E+02, -.99279100E+01, 0.12058300E+03, -.16498000E+00, 0.59581800E+02, -.10896200E+02, 0.11175400E+03, 0.73098000E+01, -.92716100E+01, -.16275300E+02, -.13057600E+01, -.29026700E+02, 0.10454400E+02, -.65118300E+01, 0.28337600E+02, 0.86079400E+01, 0.23933800E+02, 0.58458000E+01, 0.11463100E+02, -.15807800E+02, 0.22764000E+02, -.16557500E+02, -.18639200E+02, 0.10612200E+02, -.16264900E-01, 0.97910000E+01, 0.23673600E+02, -.10444900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.55652400E+00, 0.59156600E+00, -.36007300E+01, 0.96202600E+00, 0.74399400E+00, -.66831700E+00, 0.26196800E+01, -.38266700E+00, -.32306100E+00, 0.20611300E+01, 0.26336000E+01, -.29474200E+00, 0.22137400E+01, 0.10131800E+01, -.72994700E+00, 0.30173400E-01, 0.46617900E+01, -.66046400E+00, -.25871400E+01, 0.24518700E+01, 0.52170300E+00, -.75206500E-01, -.98781000E+00, -.63249600E-01, -.46789800E-01, -.51628300E-03, -.15947500E+00, -.98343400E+00, 0.17651700E+00, -.55174400E+00, 0.58931700E+00, -.60464500E+00, 0.46955400E+00, 0.63955400E-01, -.62958900E+00, 0.19021400E+00, -.51146100E-01, 0.29747900E-01, -.27991900E-01, -.13710200E+01, 0.79313300E+00, -.55813300E-03, -.28675600E+00, -.22423300E+00, 0.53160500E+00, 0.17828500E+00, -.66280200E+00, -.50353700E-02, 0.94944700E+00, 0.59538200E+00, 0.43891700E+00, 0.12250900E+00, 0.19350100E+00, -.32793500E+00, 0.43954100E-01, -.42050600E+00, 0.15703100E+01, -.16586300E+01, 0.10733400E+00, -.63671000E+00, -.31320700E+00, 0.91255300E+00, 0.86503000E+00, 0.15904300E-01, 0.45137800E+00, 0.23799500E+00, 0.10680700E+00, -.28945800E+01, 0.51230100E-01, 0.29562600E-01, -.39231900E-01, -.27456000E+00, -.13682000E+00, 0.10849000E+00, -.79639300E+00, 0.14527900E+01, 0.17260000E+00, 0.76362800E+00, -.25442300E-01, -.30800400E+00, 0.13934700E-01, -.19335800E+00, 0.43304200E+00, 0.63450000E+00, 0.35758900E+00, 0.83362600E+00, 0.74887900E-01, -.87130300E-03, -.40002100E+00, 0.66911700E+00, 0.31440100E+01, 0.29078900E-01, -.17001200E+00, 0.20826200E+00, -.71456900E-01, -.45607300E+00, -.43276100E+00, -.29053500E-01, 0.29794900E+00, -.85999000E+00, -.16164900E+00, -.92994700E-01, -.14968800E-01, 0.24851600E+00, -.33675500E+00, 0.54846600E+00, 0.83496000E-01, 0.37903000E+00, 0.34241700E+00, 0.13800500E+01, -.13929400E+01, -.42948600E+00, 0.40165200E+00, 0.40762800E-01, -.28283600E+00, 0.64942100E+00, 0.14865400E+00, 0.66631000E+01, -.22753600E+00, 0.90261900E-01, -.66918300E+00, -.14453500E+00, -.34571500E+00, 0.85395500E+00, 0.13873400E-01, -.41934300E+00, 0.12532800E+01, -.66236500E+00, -.25759100E+01, -.23221000E+01, 0.20621600E+01, 0.57222700E+00, 0.39049100E+00, -.81687400E-01, 0.14265900E-01, 0.71558100E-01, 0.23910900E+01, -.49230300E+00, 0.54329500E+00, -.10936500E+01, -.50588000E+00, 0.14545600E+01, -.69347500E+00, 0.75821400E+00, -.15324200E+00, 0.19391600E-01, 0.82581400E-02, -.10875600E+01, 0.22700600E+01, 0.20128900E+01, 0.21888900E+00, -.10365900E+00, -.29055500E+01, 0.62498800E+00, -.22477600E+01, 0.25880800E-01, -.45560200E+00, 0.41125200E-02, -.69807300E-01, 0.65494400E+00, -.12758500E+00, -.51852900E+00, -.17399200E+00, 0.32402300E+00, -.26396600E+00, 0.79580900E+00, -.17022200E+00, 0.18273400E+01, -.39104500E-01, 0.17629100E+00, -.66673200E+00, -.31530700E+00, 0.71750600E+00, 0.51069000E+00, 0.71906200E-01, -.72322200E+00, -.15459600E+00, 0.96658000E-01, 0.51575400E+00, -.12884900E-01, 0.97349500E+00, -.68969600E-01, -.35496200E+00, 0.18075600E+01, -.20512400E+00, 0.11880500E+00, 0.38067200E+00, 0.11875300E+01, 0.12469700E+00, -.91271300E-01, -.39050000E-01, -.63683800E+00, -.57227000E+00, -.34327600E+00, 0.18318800E-01, 0.20165200E+00, 0.51367000E+00, -.84820700E+02, -.14552800E+03, 0.72742100E+02, 0.83044800E+02, 0.71098800E+02, 0.10094000E+02, -.54838000E+02, 0.84548100E+02, -.74982600E+02, 0.74145500E+02, -.53239300E+02, 0.85450800E+02, 0.21273000E+02, -.11857300E+02, -.31946200E+02, -.12272000E+02, -.10819800E+02, 0.10125400E+02, -.39249800E+02, -.22093800E+02, -.18658400E+02, 0.78666300E+01, 0.65902400E+02, 0.18320500E+01, 0.17035300E+00, 0.15344600E+00, 0.20535500E+01, 0.14727300E+02, -.30151500E+01, 0.26658300E+01, -.14303400E+02, -.53125400E+01, -.64516900E+01, 0.22692500E+01, 0.47069800E+00, 0.80967400E+01, -.59037400E+01, 0.32854200E+00, 0.94287000E+01, 0.57257300E+00, -.28937000E+01, -.62032700E+01, -.30895600E+01, 0.40126200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11000700E+01, -.85599400E+00, -.80565800E-01, -.65796200E+00, -.55966400E+00, 0.13528800E+00, -.81967300E+00, 0.16357300E+00, 0.12633600E+01, 0.86458200E-01, -.77073300E-01, -.27457400E-01, 0.46618900E-01, 0.24228400E+01, 0.11078700E+01, -.15610700E+01, 0.19274900E+01, 0.64263700E+00, -.24974500E+00, 0.13564300E+01, 0.34811100E+00, 0.42912000E+00, 0.39506400E+01, 0.18473000E+00, 0.21250900E+00, -.23922300E-03, 0.67154300E+00, 0.19472300E+01, -.53597700E+00, -.79631800E+00, -.11689000E+01, -.15402500E+01, -.11446000E+01, 0.10071200E+00, 0.49179800E+01, 0.91602800E+00, 0.40603600E+00, -.34004000E+00, -.38294700E+00, 0.24834900E+01, -.30097000E+01, 0.17583100E+01, 0.44318800E+00, 0.79073100E+00, 0.63583100E+00, 0.12715300E+00, -.46557600E+01, 0.14014500E+00, -.11399000E+00, -.26051800E+01, 0.57921900E+00, -.17800600E+01, -.26466400E+01, -.14611500E+00, 0.15949500E+01, 0.95866800E+00, -.38199700E+01, 0.24142100E+01, -.59630000E+00, 0.95326000E+00, 0.24661200E+00, -.83466100E+00, -.15866300E+01, -.10899900E+00, -.42095600E+01, -.14286000E+01, -.61120900E+00, -.68993500E+01, 0.24118100E+00, 0.14079100E-01, -.89273800E+00, -.13212100E+01, 0.52616400E+00, -.10158400E+01, -.71902600E-02, -.60966500E+01, -.14108000E+01, 0.35686000E+01, 0.28966700E+00, 0.44896600E+00, -.73128300E-02, 0.35032800E+00, -.11300400E+01, -.75326400E+00, -.20182900E+01, 0.22388300E+01, -.91410900E+00, -.39556600E-01, 0.10486600E+01, 0.14965600E-01, -.93844900E+01, -.53258900E-01, -.22720800E-01, 0.26914700E+00, 0.57500500E+00, 0.13561400E+01, 0.40891400E+00, 0.73490100E+00, 0.35970000E+00, 0.56371400E+00, 0.82237000E+00, -.11663400E+01, -.44667700E-01, -.31300400E+00, -.32487500E+00, -.12187500E+00, 0.44038600E+00, -.25442100E+01, -.73726200E+00, 0.16678700E+01, -.27650300E+01, 0.69561400E+00, -.20597800E+01, 0.20146900E+00, 0.15821700E+01, -.74106800E+00, -.34951000E+00, -.39572300E+01, 0.26333600E+00, -.18663300E+00, 0.10900400E+01, 0.48285500E+00, 0.23047500E+00, 0.70258800E+00, 0.61759800E-01, -.18628500E+01, -.10084200E+02, -.39488700E+00, -.13242300E+01, -.77359200E+01, -.15567500E+01, 0.28343900E+00, -.78756300E+00, 0.84763400E-01, -.28404400E+00, -.28407700E-01, 0.14462400E+01, 0.53749000E-01, 0.18192700E+01, 0.48898500E+00, 0.72964200E+00, -.22722000E+00, 0.30403500E+00, -.42590700E+00, 0.25192700E+00, -.10581100E+00, 0.20338300E-02, -.42585600E+00, 0.59451000E+00, 0.11765900E+00, 0.22349000E+00, -.45933400E+00, 0.73432100E+00, -.14252900E+00, 0.10642400E+01, -.14512000E+00, -.19975900E+00, 0.86905500E-01, 0.11475600E+00, -.38363000E+00, -.18984500E+00, 0.33774300E-02, -.19794800E+00, 0.36876700E+00, 0.88021400E-01, -.10175300E+01, 0.98220900E-01, 0.19771200E+02, 0.14609800E-01, -.12479600E+01, 0.69736300E+00, -.19407200E+00, 0.86848100E-01, 0.10405100E+01, -.84053500E+00, -.66250500E+00, -.32669000E+00, 0.20271400E+00, 0.10665900E+01, -.25569700E-01, 0.16402000E+01, 0.20462100E+01, -.79728000E+00, 0.23285900E+01, -.45692600E-01, 0.39615300E-01, -.18907900E+01, 0.86083000E+00, 0.34434700E-01, 0.30521500E+00, -.70212100E-01, -.13792800E+01, 0.13146600E+00, -.76831300E+00, 0.23828900E+00, 0.12837200E+00, -.28761100E+00, 0.37030200E+00, -.20277700E+03, 0.10367200E+03, 0.37566000E+02, 0.10170300E+03, -.33757200E+02, 0.22044100E+02, 0.38001100E+02, -.16058200E+03, 0.94068500E+01, 0.24523100E+02, 0.11959900E+03, 0.14861100E+03, -.74854000E+02, -.78455700E+02, -.74101300E+02, -.77718800E+02, -.50657200E+02, 0.32849000E+02, 0.94696700E+02, 0.29188600E+02, -.49051800E+02, -.34235500E+02, -.59586900E+01, 0.26360600E+01, -.27508200E+02, -.17761500E+01, -.24239300E+02, -.45428500E+01, 0.62937300E+01, 0.24893100E+02, -.93379700E+01, 0.22425600E+02, -.42078300E+01, -.19938600E+01, -.10617000E+02, 0.21225700E+02, -.27126500E+02, -.13697400E+02, -.16836600E+01, 0.24403100E+01, -.98457500E+01, -.24932100E+01, 0.48386800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.96432500E+00, -.86036100E+01, -.12048800E+02, -.72929300E+01, 0.57713600E+01, -.91180500E+01, 0.76563200E+01, 0.80539600E-01, 0.89328000E+01, 0.71139100E+01, 0.78113100E-01, -.25241200E+01, 0.11593300E+02, 0.49218800E+01, 0.10353200E+01, 0.38486300E+01, -.32345500E+01, 0.35919900E+01, -.29560200E+01, 0.46077400E+01, -.20440800E-01, -.49643700E-01, -.12009800E+02, -.54188500E+00, -.22342100E+01, -.52054900E-02, -.17392400E+01, 0.10656000E+01, -.34977100E+01, 0.16414400E+01, -.74076200E+00, 0.37398800E+01, -.96084200E+00, 0.48049500E+00, 0.30428000E+01, 0.17754700E+00, -.27193700E+00, -.47451200E+00, 0.29198900E+00, 0.69410000E+00, 0.45157300E+00, -.19918300E+01, 0.40281600E+00, -.49183700E+00, 0.19995300E+01, -.44607500E+00, -.18358400E+01, -.73072200E-01, 0.31420600E+01, 0.18893700E+01, 0.74657700E+00, 0.14392600E+01, 0.29939900E+00, -.70831000E+00, -.20966400E-01, -.34853800E+00, 0.88629800E-01, -.27822800E+01, 0.32062700E+00, 0.37306000E+00, -.10401900E+01, -.21712300E+01, 0.35405200E+01, 0.10288000E+01, 0.15067900E+01, -.19422100E+00, 0.89889300E+00, 0.15797500E+02, 0.13121200E+00, -.26029900E-01, 0.29788200E-01, -.16465800E+00, -.10106600E-01, 0.63499900E+00, 0.23009300E+00, -.10672300E+01, -.28261100E+01, 0.79844800E+00, -.70024200E+00, -.18621500E+00, -.57123400E-01, -.11232600E+01, 0.74002300E+00, -.16747800E+00, 0.69051000E+00, -.11708100E+01, 0.11219300E+00, 0.25054600E+00, 0.53415600E+00, 0.17878600E+01, -.41177700E+00, 0.12229300E+00, 0.10457200E+01, -.31929000E+00, 0.59007800E+00, 0.14863100E+01, 0.33761600E+00, -.39490100E+00, 0.15892500E+00, -.75628700E+00, 0.88868200E+00, -.77573700E+00, 0.59630100E-01, -.38909800E+00, 0.16519300E+01, -.44525600E+00, 0.23078700E+00, -.10850800E+01, 0.33904800E-03, 0.16015000E+01, 0.74022500E+00, 0.16008700E+01, 0.19397600E+00, -.51433300E-01, 0.65382300E+00, 0.16120700E+00, -.34101900E+00, -.37396000E+01, 0.26403400E+00, -.77823800E+00, 0.83688000E-01, -.71106500E+00, 0.98054200E+00, -.29670400E+01, -.21812200E+00, 0.19935600E+01, 0.72693500E+01, 0.52232700E+00, -.46258400E+01, 0.70918400E+01, -.11491800E+01, -.22941200E-01, -.70683700E+00, 0.41101200E-03, 0.24105500E+00, 0.14362000E-01, 0.36915600E+01, 0.13777400E+00, -.19931400E+01, 0.55320100E+00, 0.57231300E+00, -.11737100E+01, 0.23362500E+00, -.63455700E-01, -.24567000E+00, -.12586300E+00, -.91518100E-01, 0.20431400E+00, 0.21913600E+01, 0.81955900E+00, 0.57828600E+00, -.35679900E+00, 0.10287200E+01, -.15483100E+00, 0.81282000E+00, 0.21259300E+00, -.39976800E+00, 0.54525800E-01, 0.10340400E+00, -.25036400E+01, -.36308300E+00, 0.10943500E+01, 0.93090100E+00, -.83995900E+00, -.43074700E+00, -.17638100E+01, 0.73609500E-01, -.68066800E+01, 0.44016700E-01, -.20180800E-01, -.32310000E+00, 0.51912600E+00, 0.90785200E+00, -.33702500E+00, -.30314600E-02, 0.26660900E+00, 0.47834100E+00, -.51100500E+00, -.73094400E+00, 0.82899300E-02, -.84558100E+00, -.48119000E+00, 0.36637800E+00, -.55449100E+00, -.63741400E-01, -.40723600E+00, -.51644700E-01, 0.47688400E-01, 0.32905100E+00, 0.35037500E-01, 0.31645900E-01, 0.16071100E+00, -.10028300E+00, -.61514500E-01, -.33510500E+00, 0.12283000E-01, -.19342100E+00, -.52303700E+00, 0.18250700E+00, 0.21608500E+02, 0.11068600E+02, -.39202800E+00, -.37999700E+02, -.45883000E+02, -.21595100E+01, 0.46664900E+02, 0.60893100E+02, -.38808900E+02, 0.28962400E+02, -.93876200E+02, 0.47566200E+02, 0.51703800E+02, 0.46689600E+02, 0.27425300E+02, 0.36898600E+02, -.28703100E+02, -.55012900E+02, -.16863400E+02, 0.37000500E+02, 0.52323600E+02, 0.62381400E+01, -.24762300E+01, 0.55956300E+01, 0.21898800E+01, 0.94843600E+01, 0.17811200E+01, -.19271800E+01, -.96493100E+01, 0.35004800E+01, -.74633800E+01, 0.45899200E+01, 0.26154300E+01, 0.98391400E+01, -.74366000E+01, 0.55292500E+01, 0.70402600E+01, 0.27753300E+01, -.42634800E+01, 0.31852400E+01, 0.13162400E+00, 0.56508000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.86961000E+00, -.13561400E-01, 0.14943100E+01, -.59537100E+00, 0.61267000E+00, -.97774300E-02, -.15718100E+01, -.25727400E-01, -.12776200E+00, -.12459100E+01, -.15944100E+00, -.57618200E-01, 0.15084700E+01, 0.10476600E+01, 0.32873100E+00, 0.20094500E+00, 0.47959200E+00, 0.55435500E+00, 0.86727300E-01, 0.47350700E+00, -.93089900E-01, -.19211800E+00, -.17955700E+01, -.84718000E-01, -.49641400E+00, -.18547000E-02, -.31799200E+00, -.34384500E+00, -.29605700E+00, 0.14887400E+00, 0.17435900E+00, -.30339200E-01, -.82735900E-01, -.19060200E+00, -.30244500E+00, 0.32582300E-01, 0.46362300E-01, 0.21228300E+00, -.26297700E+00, -.93107200E+00, 0.12544700E+01, -.29713900E+00, -.67740900E-01, -.18448200E+00, -.54987900E+00, 0.18070700E+00, 0.46594000E+00, 0.52933400E-01, 0.14419400E+01, 0.11551200E+01, -.23219400E+00, -.54003100E+00, 0.38014500E+00, 0.38269400E+00, 0.27401500E+00, -.18287200E+00, -.17517300E+00, -.12205300E+01, 0.77512800E-03, -.12287700E+00, 0.68820200E+00, 0.94518900E+00, 0.23890200E+01, 0.65477600E+00, 0.42382200E+00, -.52769400E-01, -.86253300E-01, 0.28316500E+01, -.33371100E+00, 0.12345000E-01, -.53032600E+00, -.46436200E+00, -.23809700E+00, 0.86841000E-01, -.22276800E+00, -.59467900E-01, 0.10562900E+01, 0.21626500E+01, 0.33722200E-02, -.11416300E+00, -.53301400E-01, 0.43845800E-01, -.92500500E+00, -.17131800E+01, -.32031600E+00, 0.28193000E+00, -.11531200E+00, 0.11302200E-01, 0.24316300E-01, 0.39181700E+00, -.15010700E+01, -.94266300E-02, 0.49099800E+00, -.69248100E-02, 0.16243000E+00, 0.10613700E+01, 0.62121300E+00, -.25867400E+00, 0.32062900E+00, 0.38428100E+00, 0.22856600E+00, -.25282900E+00, 0.92387000E-02, -.44325000E+00, -.79079600E+00, -.38647200E+00, 0.29249900E+00, -.85352700E+00, 0.20543700E+00, 0.10019500E+01, -.30114800E+00, 0.45627800E+00, -.80753100E+00, 0.13831400E+00, 0.33089900E+00, 0.38353700E+00, -.36456800E+00, 0.13597700E+02, -.28449300E+00, 0.97101200E+00, 0.18906700E+01, 0.61987700E+00, 0.19765300E+00, -.13337300E+01, -.17975500E+00, 0.62202700E+00, 0.91973400E+01, 0.19628000E+00, -.42573700E+00, 0.11895300E+02, -.12974400E+01, -.53448400E+00, -.27330700E-01, 0.27769900E+00, 0.14921200E+00, -.68293000E-01, -.14687000E+01, 0.71103700E+00, -.15316900E+01, 0.30268200E+00, -.45873800E+00, -.60690400E+00, 0.14381400E+00, -.31408000E+00, 0.94851700E-02, 0.21369400E+00, 0.21080700E-01, 0.25037700E+00, -.20176100E+01, -.15363600E+01, -.30253500E+00, -.40914100E-02, 0.43704300E+00, -.97914300E-01, 0.90353100E+00, -.49829600E-01, -.25122300E+00, 0.10906500E+00, 0.28719900E+00, -.25837400E+01, -.48517600E+00, 0.30391700E+00, 0.67638700E+00, -.10537500E-01, -.49519900E+00, -.89565600E+00, 0.10861600E+00, -.40811400E+00, 0.49887200E-01, 0.52174300E+00, -.15278500E+01, 0.38817500E+00, 0.23587500E+01, 0.65017900E+00, -.37730200E+00, -.20948700E+00, 0.95578200E-01, -.43113000E+00, 0.34610500E-01, 0.23120600E-01, -.18919100E+00, 0.96701200E+00, -.22286900E+01, 0.79593000E+00, 0.17980400E+00, -.19749700E+00, -.10672100E+01, 0.48200700E+00, 0.89725200E-01, -.62475900E-01, 0.19704700E-01, -.23405800E+00, -.13831100E+01, -.24386000E+00, -.41394800E+00, 0.45957100E-01, 0.11638400E+00, 0.94058100E-01, 0.23881500E+00, 0.15617400E+00, 0.11775000E+03, 0.37201900E+00, -.10436300E+01, -.37179500E+02, -.14114200E+02, -.16003500E+01, -.70161700E+01, -.10012000E+02, 0.12323000E+02, -.12980500E+03, 0.64633800E+02, 0.45600000E+02, 0.64944500E+02, 0.49199500E+02, 0.32281500E+02, -.18553900E+02, -.84714800E+02, -.14085300E+02, 0.33814400E+02, 0.30782700E+02, 0.58437500E+01, -.70723900E+01, 0.20560400E+02, 0.25778700E+01, 0.19181500E+02, 0.12523200E+01, -.58542100E+01, -.19401800E+02, 0.73697000E+01, -.19610100E+02, 0.43339000E+01, 0.22221000E+01, 0.13938600E+02, -.18369500E+02, 0.20490900E+02, 0.12829700E+02, 0.67746100E+01, -.39344100E+01, 0.71513800E+01, 0.13564900E+02, -.32331500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.96219400E+00, -.44477100E+00, -.61038800E+01, -.41833300E+01, -.60585400E+01, 0.44847700E+01, -.60687600E+01, 0.11770900E+01, -.31137400E+01, -.48923700E-01, 0.45413800E+00, 0.41516100E+00, -.28818900E-01, 0.64738600E+00, -.65023900E+00, -.63584300E+00, 0.85988600E+00, 0.35759300E-01, -.34752200E-01, -.22865500E-01, 0.28623100E-01, -.31473100E+00, -.10117800E+01, 0.13635300E-01, 0.13830100E+00, 0.13833300E-02, -.15823900E+00, -.30868700E+00, -.85840900E+00, 0.28634400E+00, -.18790800E+00, 0.15239600E+01, -.23385300E+00, 0.47906500E+00, -.69492200E+00, -.21095600E-01, -.15826600E+00, 0.17339200E+00, 0.22926100E+00, 0.54675200E+00, 0.37942600E+00, -.58198200E+00, 0.20733200E+00, -.17745800E+00, -.11047500E+01, 0.15524200E+00, -.47682400E+01, 0.57551300E+00, 0.26207100E+01, 0.98231600E+00, 0.67850300E-01, 0.10401600E+01, 0.24272600E+01, 0.70280500E-02, 0.60922000E+00, -.84261100E+00, 0.10407700E+01, -.26425700E+01, -.13178900E+00, -.32481600E+00, 0.13847000E+00, 0.14706700E+01, 0.14125500E+01, 0.23720200E+00, -.66856200E+00, -.15603600E+00, 0.67144800E-01, 0.87787300E+01, -.19546600E+00, -.30048800E+00, -.10108700E+01, -.72196800E+00, -.45056900E-01, 0.43839400E-01, 0.22086500E+00, -.34173700E+01, 0.59498600E+00, -.22292700E+01, 0.17482800E+00, -.22177300E+00, -.25911500E+00, -.82625800E+00, 0.48653200E+00, -.14911900E+00, 0.45683300E+00, 0.27086500E+01, -.20072700E+01, 0.44057200E+00, 0.20764700E+00, -.29140300E+00, -.10851000E+01, 0.17377500E+00, 0.44966200E-01, -.22951800E+00, 0.57821700E-01, 0.79189500E+00, 0.65147700E+00, -.35171700E+00, 0.49502300E+00, 0.17894100E+00, 0.13326300E+00, -.41810600E+00, 0.17758500E-01, -.43057700E+00, -.66463400E+00, -.12642500E+00, 0.31585200E+00, -.11328200E+01, -.48945600E+00, 0.86977800E+00, -.14019200E+00, -.13626000E-01, 0.29076300E+00, -.42058400E-01, 0.15891200E+00, 0.79598000E+00, -.31795000E+00, 0.33552100E+01, -.71500500E-01, 0.15355400E+00, 0.17367200E+00, 0.45990900E+00, 0.24326500E-01, -.56396100E+00, -.15932000E+00, -.11917700E+00, 0.51715400E+01, -.18819900E+00, -.23093500E+01, 0.65628000E+00, -.81334300E+00, -.29377600E+00, 0.81865800E-01, 0.69341200E-01, -.41273400E-01, -.14764200E+00, 0.14748300E+01, 0.47358600E-01, 0.83246600E+00, -.39881700E+00, -.89137600E-01, 0.69660300E+00, -.26812400E+00, 0.37464500E+00, -.19022500E+00, 0.66546800E-01, 0.28891800E-01, -.49091300E+00, 0.94949000E+00, 0.94281600E+00, 0.11885200E+00, -.31112100E+00, -.33436200E+00, 0.81606200E-01, 0.29965200E+00, 0.41365300E-01, -.35361400E+00, 0.14859900E+00, 0.20859000E+00, 0.57857000E+00, -.17253400E+00, -.21076100E+00, 0.64540400E+00, -.39913700E+00, -.37788800E+00, -.54847900E+00, 0.68712400E-01, -.80156400E+01, 0.22530500E+00, 0.17767100E+00, 0.19103800E+00, 0.52601100E+00, 0.10660200E+01, 0.42009600E+00, -.20682000E+00, -.26514000E+00, 0.77295700E+00, 0.13147500E+00, -.29988700E+00, 0.35590700E-01, -.67607000E+00, 0.59721600E+00, -.82373400E+00, -.11146000E+01, 0.24329000E+00, -.39956500E-01, -.12376400E+01, -.10153100E+01, 0.13598900E+00, 0.19153100E+00, 0.85232400E-01, 0.55068900E+00, -.42117300E+00, -.11197200E+00, -.70753600E+00, 0.10113000E+00, -.13223000E+00, -.72781400E+00, 0.51161800E+00, -.31375100E-01, 0.19391600E+00, 0.29975200E+02, 0.16933400E+01, -.38219200E+02, 0.12390700E+02, 0.76044100E+02, 0.65724200E+02, -.38783000E+02, 0.32421500E+01, -.11021600E+03, 0.55632500E+02, 0.56047000E+02, 0.56622800E+02, 0.47042000E+02, 0.48655600E+02, -.46758400E+02, -.70776700E+02, -.30007800E+02, 0.47114200E+02, 0.72252700E+02, 0.86800900E+01, -.16006900E+01, 0.96225600E+01, 0.26266500E+01, 0.15624400E+02, 0.34259500E+01, -.35445700E+01, -.15903100E+02, 0.55155100E+01, -.10290600E+02, 0.70659200E+01, 0.40208600E+01, 0.10563500E+02, -.10031800E+02, 0.95183500E+01, 0.98679600E+01, 0.15039600E+01, -.65286900E+01, 0.52496500E+01, 0.28858100E+00, 0.91526600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.72718600E+00, 0.79563900E+00, -.46529500E+01, 0.95023100E+00, 0.20088400E+01, -.15672500E+01, 0.38857700E+01, -.56171100E+00, -.18295300E+01, 0.24450900E+01, 0.33487500E+01, -.41395100E+00, 0.35693800E+01, 0.28432900E+01, -.83626300E+00, 0.24009600E+00, 0.37501500E+01, -.91582800E+00, -.25661200E+01, 0.39110300E+01, 0.63024200E+00, -.32188000E+00, -.32989500E+01, -.98584000E-01, -.17533300E+00, -.29935900E-03, -.57836400E+00, -.54401800E+00, -.20490800E+01, 0.54527400E+00, 0.10217100E+00, 0.20807500E+01, -.44417800E+00, -.42062300E+00, -.10416500E+00, 0.52977200E-01, -.14604300E+00, 0.17958500E+00, 0.21414200E+00, -.60215100E+00, 0.10574800E+01, -.15727800E+01, 0.11393900E+00, -.66392900E+00, -.52710000E+00, -.53917400E+00, -.32537900E+01, 0.15905700E+00, 0.38815800E+01, 0.45743400E+01, 0.71807500E+00, 0.34171100E+01, 0.39789800E+01, -.34832700E+00, 0.30275900E+01, -.14047400E+01, 0.19618900E+01, -.42440800E+01, 0.71446200E+00, -.42175700E+00, -.40582400E-01, 0.12304100E+01, 0.35539100E+00, -.30608400E+00, -.12425900E+01, 0.55725700E+00, -.16145600E+00, -.41147700E+01, 0.49998300E-02, -.26506000E-01, -.48162400E+00, -.10281300E+01, 0.99454300E-01, -.12118800E-01, 0.12959200E+01, -.13918300E+01, -.29800900E-01, 0.55514000E+00, -.23212400E+00, -.18500000E+00, -.14402900E+00, -.34340300E-01, -.99599000E+00, -.73641400E+00, -.63873600E+00, -.25585900E+00, 0.47496200E+00, -.86641000E-01, -.57302600E+00, -.16607200E+01, -.19710200E+01, -.12050400E+00, -.81510200E+00, -.45311000E+00, -.50109700E+00, 0.36737100E+00, 0.11577600E+01, -.95419000E+00, 0.49002000E+00, 0.30105800E+00, 0.77934300E+00, -.16308700E+00, -.24452500E-01, -.66033600E+00, 0.11481500E+01, -.27480800E+00, 0.60403400E+00, -.82487700E+00, -.84948100E+00, -.37111800E+00, 0.31301900E+00, 0.19221400E+01, -.77095000E+00, 0.14582700E+00, 0.40750800E+00, -.23004400E+01, -.20655100E+00, 0.61689300E+01, -.26676500E+00, -.20649600E+00, -.71990600E+00, -.73427500E-01, 0.17559400E+00, -.10828300E+01, -.39113200E-01, 0.24974000E+01, -.71112700E+01, 0.13874400E+01, -.70012400E+00, -.49283100E+00, 0.13390900E+01, 0.63794700E+00, -.33273200E+00, -.18614300E+00, -.12440600E+00, 0.76862300E-01, -.22235100E+01, -.28608700E+00, -.76596600E+00, -.19987700E+00, -.10048100E+01, -.69801900E+00, -.70516300E+00, 0.45029500E+00, -.14085400E+00, 0.23783700E+00, 0.50538400E-01, -.23293000E+00, -.14643000E+01, -.81038100E+00, -.19952400E+00, 0.11716800E-01, -.10518300E+01, -.39449200E+00, -.30389100E+00, -.78748800E-01, 0.14596600E+01, 0.58421500E-01, 0.57065000E+00, 0.14733600E+01, 0.45840400E+00, -.45064500E+00, 0.44722900E+00, -.92054600E-01, 0.64046500E+00, -.14364600E+01, 0.17236300E+00, 0.20882600E+02, 0.66680800E-01, -.64968900E+00, 0.11697900E+01, -.90321600E+00, -.23079800E+01, 0.72605900E+00, -.22780000E+00, -.59268200E+00, -.69898300E+00, 0.36237300E+00, 0.73026400E+00, -.42021600E-01, 0.53441000E+00, -.12388500E+01, -.22808600E+01, 0.56528800E+00, -.63543600E-02, -.75197400E-01, -.47644900E+00, -.19344800E+00, -.25528200E+00, 0.54362000E+00, 0.38220200E-02, -.44316700E+00, -.14151500E+01, -.99633200E-01, -.27639100E+00, -.14267700E+00, 0.31196500E-01, -.82536900E+00, 0.71975000E+00, -.15485500E+00, 0.28699800E+00, -.67969300E-01, 0.64702900E+02, -.40138800E+02, 0.17315200E+02, 0.10663500E+03, 0.32131500E+02, -.43420300E+02, 0.10246900E+03, -.52398800E+02, 0.26831200E+02, 0.27611400E+02, 0.24526800E+02, 0.28286400E+02, 0.40264400E+02, -.71286600E+02, -.61510600E+02, -.53805800E+02, 0.40802900E+02, 0.73692100E+02, 0.41832500E+00, 0.38353100E+01, 0.11407400E+02, 0.15572200E+01, 0.22963500E+02, 0.75515400E-01, 0.14886900E+01, -.23209800E+02, 0.73737300E+00, -.12341600E+02, -.10061600E+01, -.19534500E+01, 0.99841100E+01, -.12305900E+02, 0.11154200E+02, 0.13148000E+02, -.38189100E+01, 0.80913300E-01, -.43850900E-01, -.45288200E+01, 0.64978100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18915100E+00, 0.38834500E+00, 0.10577600E+01, 0.35058600E+00, -.15917400E+01, 0.36600400E+00, 0.85499000E+00, 0.36540300E-01, 0.17284500E+00, 0.83648200E+00, -.15097800E+00, 0.23556500E+00, -.64114200E+00, -.55517600E+00, -.38913200E+00, 0.55584900E+00, -.10146500E+01, -.63357700E+00, 0.10377500E+01, -.68113900E+00, 0.34792700E-01, -.12189700E-02, 0.18914000E+01, 0.93067200E-01, 0.49736300E+00, 0.13431900E-02, 0.35991000E+00, 0.60303200E+00, -.28181100E+00, -.23823500E+00, -.42946000E+00, 0.12286200E+00, -.18284700E+00, 0.23805700E-01, 0.22715900E+00, -.55936200E-01, 0.94336600E-01, 0.50735100E-01, -.33952000E-01, 0.11210600E+01, -.10993600E+01, 0.55804000E-01, 0.19909000E+00, 0.25393200E+00, -.82236400E+00, -.12738400E+00, -.11698500E+01, 0.70684400E-01, -.32040100E+00, -.13151100E+00, 0.11329400E+00, 0.29063300E+00, 0.56610800E+00, 0.71498700E-01, 0.93611800E+00, 0.14354800E-01, -.28275900E+00, -.11540600E+00, -.11311000E-01, 0.16982000E+00, -.18662300E+00, -.40612000E+00, -.17308700E+00, -.14511000E+00, -.74089300E+00, -.28098800E+00, -.72888000E-01, 0.24771500E+01, 0.19491300E-01, -.37632200E-02, -.42498400E-01, 0.52490300E-01, 0.20093700E+00, -.47750700E-01, 0.22179000E+00, -.73731000E+00, -.46430200E+00, -.32327000E+00, 0.55676800E-01, 0.15561200E+00, 0.21085000E-02, 0.15519400E+00, -.57664500E-01, -.58809300E-01, -.16258300E+00, -.28330900E+00, 0.12371600E+00, 0.33214100E-01, -.48750400E-01, 0.16532100E+00, -.10152700E+01, 0.10355800E-01, 0.44022500E+00, -.20976600E+00, 0.43259400E-02, 0.38792400E+00, 0.20613600E+00, -.13398800E+00, 0.40603600E+00, -.54652400E-01, 0.26509800E+00, -.11764500E+00, 0.17731800E-01, -.48238400E-01, -.27906600E+00, -.10921400E+00, 0.24454700E-02, -.21115700E+00, 0.28312200E-01, 0.20579800E-02, 0.29052500E+00, 0.29781400E+00, -.25343600E+00, -.15408600E-01, 0.70436300E-02, 0.60639400E-01, 0.38493500E-02, -.13957200E+01, -.19483000E-01, -.19596000E+00, 0.19494100E-01, 0.10814700E+00, -.78657200E-02, 0.24729100E+00, -.57870700E-01, 0.65599100E+00, 0.66525500E+00, 0.46416200E-01, 0.11144500E+01, -.34888800E+00, -.31355000E+00, -.53460500E-01, -.34965000E-01, 0.24443500E-01, -.29714700E-01, -.16767500E-01, -.46225400E-01, -.82180400E-01, -.20186400E+00, 0.13995800E+00, 0.44382300E-01, -.83840900E-01, 0.98189300E-01, -.17436200E+00, 0.35359800E-01, 0.34003900E-01, 0.51535800E-02, 0.17354200E+00, -.47289400E+00, -.34238200E+00, -.24820800E-01, -.26942200E+00, 0.33225700E+00, -.66036400E-01, 0.55425700E+00, 0.33369400E-01, 0.44426400E-01, 0.95508800E-02, 0.14853000E+00, -.27399900E+00, -.91228900E-02, 0.80183400E-01, -.39305000E-01, -.59512600E-01, 0.13772300E+00, -.13671600E+00, 0.74422500E-02, 0.16965100E+01, 0.13600600E-01, 0.38657800E-01, 0.12139900E+00, -.84085500E-02, -.22545900E+00, 0.77277400E-01, -.50332900E-01, -.10138900E+00, 0.16411200E-02, 0.31880000E-01, 0.52884500E-01, -.74536800E-03, 0.68710600E-01, -.26161300E+00, -.22932400E+00, -.62852100E-01, 0.53258700E-01, -.49241000E-01, -.32544400E+00, -.23782000E+00, 0.12767800E-01, -.12250800E-01, 0.78819800E-02, 0.10105600E-01, 0.93111300E+00, 0.62268200E-02, 0.10903900E+00, 0.74249900E-02, -.15278400E+00, -.75022700E-01, 0.87638200E-01, 0.17098000E-01, 0.13105600E-01, 0.45634500E-02, 0.60731700E-01, 0.18497800E+02, -.16425000E+02, -.18511600E+02, -.27611000E+02, 0.22996900E+02, -.75860900E+01, -.29538500E+02, 0.14803400E+02, 0.14820200E+02, 0.14974700E+02, 0.41973200E+01, -.34698600E+01, 0.14269400E+02, -.14244000E+01, 0.12602300E+02, -.46793100E+01, 0.10366200E+02, 0.11930000E+01, -.18171500E+00, -.25999200E+01, -.27392500E+00, -.39090200E+01, 0.66533500E+00, -.98449600E+00, 0.38613300E+01, 0.27969700E+00, 0.35026500E+01, 0.11464400E+01, 0.92045700E+00, -.21438700E+01, 0.35517100E+01, -.26227200E+01, -.22277800E+01, 0.17122400E+00, -.12317300E+00, 0.40110800E+00, 0.34531200E+01, -.23743300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36863100E+00, -.60099200E-01, -.14603300E+01, 0.48406000E+00, -.25808000E+00, -.48873600E+00, -.60611600E+00, 0.53623500E-01, -.10300900E+01, 0.60097800E+00, 0.45588700E+00, -.45074400E-01, -.16737000E-01, 0.92173100E+00, 0.45084400E+00, -.12918000E+01, 0.11843100E+01, 0.80686200E+00, -.97136800E+00, 0.94487900E+00, 0.11321900E-01, -.12123800E+00, -.22919300E+01, -.51736700E-01, -.63903200E+00, -.13878500E-02, -.39455400E+00, -.28249600E+00, 0.19492400E+00, -.52201800E-01, 0.14017000E+00, 0.19051500E+00, -.52028900E-01, -.22102600E+00, -.75916800E+00, -.22150500E+00, 0.26478800E-01, 0.28418800E-01, -.13643800E+00, -.82587500E+00, 0.13557700E+01, -.99482800E+00, 0.13534700E+00, 0.40583800E-01, 0.47141800E+00, -.81201500E-01, -.21043200E+00, -.64718200E-01, 0.14867500E+01, 0.99698600E-01, -.20508400E+00, -.47078500E+00, 0.71540400E+00, 0.28303800E-01, -.53054000E+00, -.15514700E+00, 0.55569800E+00, -.71447200E+00, 0.77693200E-01, -.14243500E+00, -.51206000E+00, -.30806500E+00, -.51410400E-01, 0.61252100E-01, 0.36760600E+00, 0.13742700E+00, 0.33344800E+00, -.52003400E+00, 0.94484500E-01, -.27105000E-02, 0.17829600E+00, -.39835500E-01, 0.52758000E-01, 0.22164000E+00, 0.67678800E+00, -.11821900E+00, 0.21992500E+00, -.14373800E+01, -.11464300E+00, -.46550000E-01, -.26866900E-01, 0.85844000E-01, -.21522700E+00, -.27536000E+00, -.75756700E+00, 0.11599800E+01, -.38281300E+00, -.24102300E-02, -.20060500E+00, 0.67900300E+00, 0.28706100E+01, 0.31701400E-01, 0.11563900E+01, 0.14903000E+00, -.13486300E+00, 0.61077700E+00, 0.16958000E+01, -.47944600E+00, 0.14258500E+01, 0.22212600E+00, 0.10442900E+00, -.29404600E+00, 0.69763300E-01, -.27560100E+00, -.36851300E+00, -.24914800E-01, 0.27445000E+00, -.26704700E+00, -.10161300E+00, 0.75506800E+00, -.31739300E+00, 0.53980600E-01, 0.60063700E+00, 0.78063100E-02, -.16124700E+00, 0.21622800E+00, -.15930300E+00, 0.71746900E+01, -.92194100E-01, 0.69286700E+00, 0.14276400E+00, 0.66023400E-01, 0.41874400E+00, 0.80870900E+00, 0.44588700E-02, -.36310100E+00, -.33479200E+01, 0.42241100E+00, -.59091600E+01, -.88210300E+01, 0.17281700E+01, 0.46754200E+00, -.43677700E+00, -.24999900E+00, -.92533600E-01, 0.18548700E+00, 0.80382500E+00, -.29072900E+00, 0.38346600E+00, -.16816700E+00, 0.27977600E+00, 0.19254400E-01, 0.29631100E-01, 0.95950200E-01, -.33450100E-01, -.17802500E+00, -.63370600E-01, 0.10500700E+00, 0.16876300E+01, 0.70393900E+00, 0.29417800E+00, 0.32767400E+00, 0.79244600E+00, 0.51338000E-01, -.53688800E-01, 0.12678900E+00, -.47022100E-02, -.28127900E-01, -.26049800E-01, 0.15084700E+00, 0.18579300E+00, -.48132700E+00, -.52585400E+00, 0.32611300E+00, 0.11087200E+00, -.79474300E+00, 0.35488700E-01, 0.60981100E+01, -.19303700E-02, 0.65246900E-01, 0.54241400E+00, -.40383400E+00, -.10336200E+01, 0.37064500E+00, -.70246900E-01, -.50331000E-01, 0.33209700E+00, 0.17859900E+00, -.20404600E-01, -.14649700E-01, -.92439200E+00, 0.19386700E+00, -.16767200E+00, -.13629700E+01, 0.13539600E+00, 0.80474400E-01, 0.57958000E-01, 0.18078300E+00, -.11299000E-01, -.12747000E+00, -.12927000E-01, -.10373400E+00, 0.72812400E+00, -.10787100E+00, 0.18159600E+00, 0.55638300E-01, -.23436100E+00, -.18931300E+00, 0.88349500E-01, -.88416900E-01, -.16820800E+00, -.25007000E-01, -.37363100E+00, -.50329800E+00, -.40241800E+02, 0.29268200E+02, 0.58995900E+01, -.49378900E+01, 0.19561300E+02, 0.34841800E+02, -.16556600E+02, 0.51917700E+01, -.18716300E+02, 0.55354700E+01, 0.23444300E+02, -.64866700E+02, -.25051300E+02, -.52683200E+02, 0.23510500E+02, 0.19915400E+02, -.48360100E+01, 0.53302500E+01, -.46113500E+01, -.23617100E+00, -.22992400E+01, -.56288800E+01, 0.30103900E+01, 0.20796700E+01, -.22462400E+01, 0.61700600E+01, -.53170000E+01, -.27781600E+01, 0.51054700E+01, 0.68416300E+01, -.48352900E+01, 0.66100400E+01, -.53488300E+01, 0.62055700E+01, -.30728500E+01, -.23201600E+01, 0.85811300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10820600E+01, 0.10201400E+01, 0.78966500E+01, 0.48789500E+00, 0.22348100E+00, -.41029800E+00, -.54779200E+00, -.40061500E+00, -.48597300E+00, -.23671900E+01, -.46385400E+00, -.24948900E+00, -.13638300E-01, -.10890000E+01, -.75418200E+00, 0.11735600E+01, -.14118600E+01, -.54381700E+00, 0.40799800E+00, -.99618200E+00, -.13704600E+00, 0.69933100E-01, -.12270600E+01, -.11990300E+00, 0.11510200E-01, 0.15568300E-02, -.28180400E+00, -.41673200E+00, 0.95750100E+00, 0.34651900E+00, 0.51610400E+00, 0.41197500E+00, 0.84392800E+00, -.13473500E+00, -.15800700E+01, -.74819000E-01, -.41423100E+00, 0.18493100E+00, 0.44686400E+00, -.46418800E+00, 0.13999100E+01, -.28344100E+00, -.66022500E-01, -.18723300E+00, 0.32513600E+00, -.23668500E+00, -.12631100E+01, -.27563100E+00, 0.30006900E+01, -.33695500E+00, 0.44468500E+00, -.61047300E+00, -.37521100E+00, -.90674400E+00, -.16989500E+01, -.83710000E+00, 0.20958200E+01, -.33359200E+01, 0.36821700E+00, 0.43102700E+00, 0.85973600E+00, 0.38403500E+00, 0.47668600E+01, 0.41814000E+00, -.42388100E+00, -.45186300E+00, -.18152700E-01, 0.14888200E+02, -.21486100E+00, -.45375400E-01, 0.41438100E+00, 0.16374000E+01, 0.15207900E+00, -.98782000E-01, -.59948700E+00, 0.15567700E+01, -.93292400E+00, 0.25286500E+01, 0.19166200E+00, 0.28412700E+00, 0.43435500E-01, 0.89535000E+00, 0.36186000E+00, 0.65865100E+00, 0.17664900E+01, -.29438400E+01, 0.12504800E+01, -.62580700E-01, 0.10871300E+01, -.68955800E+00, -.25764900E+01, -.59684600E-01, -.96828600E+00, -.92956900E+00, 0.19671600E-01, -.73133500E+00, -.30523300E+00, 0.61175900E+00, -.13375400E+01, 0.33289700E-01, -.12872800E+00, -.93137200E-02, -.35065400E-02, 0.66246900E-01, 0.11241100E+01, -.64065600E-01, -.29854900E+00, 0.96021500E+00, 0.62916200E+00, 0.61046100E+00, 0.31054200E+00, -.25587400E+00, -.89847900E-01, -.66871800E-01, 0.39533000E-01, -.39243000E+00, 0.23278100E-01, 0.47103100E+01, 0.17986600E-01, 0.41707800E+00, 0.49715200E+00, 0.41918100E+00, -.73850500E-01, -.73395200E+00, -.19203400E+00, -.13090900E+01, 0.50396000E+01, -.34518600E-01, -.56806900E+01, -.30123300E+01, 0.68109000E+00, -.61472300E+00, -.37711700E+00, 0.16327900E+00, -.39545100E+00, 0.22346300E-01, 0.25044300E+01, -.41638300E+00, 0.13646300E+01, -.21104900E+00, -.15500400E+00, 0.17823400E+01, -.42955700E+00, 0.26820500E+00, 0.14108800E+00, -.63703000E-01, -.16110500E-01, -.76176300E+00, 0.30973100E+01, 0.22300400E+01, 0.11170500E+00, 0.12929200E+01, 0.17106400E+00, 0.41516800E+00, -.15992900E+01, 0.74448200E-01, 0.61384400E+00, -.45754300E-01, -.21249000E+00, 0.14375300E+01, 0.88694600E-01, -.71730200E+00, -.30665500E+00, 0.28544400E+00, 0.13035800E+00, 0.53346000E+00, -.66070600E-01, 0.34150100E+01, -.20966800E-02, -.13339500E+00, 0.58202500E+00, -.28336100E+00, -.38738800E+00, 0.54585400E+00, -.23301600E+00, 0.58529300E+00, -.80040200E+00, 0.30528700E+00, 0.31381800E+00, -.39227800E-01, -.54853500E+00, 0.88959300E+00, -.18406600E+01, -.51452400E+00, 0.31934000E+00, 0.19224300E+00, 0.16458700E+01, -.99739500E+00, -.24597600E+00, 0.37950900E+00, -.10118200E-01, -.31426500E+00, -.19294400E+01, 0.71082000E-01, -.24503500E+00, -.12454700E+00, 0.32248900E+00, -.30103700E+00, 0.53833600E+00, -.23304000E+00, -.15573700E+00, -.55330600E-01, 0.11057900E+01, 0.15619300E+01, -.16357000E+01, 0.10658200E+03, 0.63079400E+02, -.24460800E+02, -.12542100E+03, 0.13017500E+03, -.64119100E+02, -.24776500E+02, -.67029900E+02, 0.16896800E+02, 0.47125000E+02, -.13741700E+03, -.36255200E+02, -.93941800E+02, 0.46799900E+02, -.54762800E+02, -.70560100E+01, 0.10403600E+02, -.16461300E+01, -.58191500E+00, -.21993500E+01, -.10371900E+02, 0.59615200E+01, 0.19955000E+01, -.44048900E+01, 0.63684800E+01, -.74563400E+01, -.45143200E+01, 0.84208900E+01, 0.76638400E+01, -.17135400E+01, 0.90826400E+01, -.11169300E+02, 0.78369800E+01, -.54654400E+01, -.96306500E+01, 0.13698400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.35777300E+00, -.12701000E+01, -.45323800E+01, -.25785300E+01, -.36413000E+00, 0.62379000E+00, -.99335000E+00, 0.14242400E+00, -.38379500E+01, -.89319900E+00, 0.29867200E+00, 0.40607400E+00, -.67961700E+00, 0.90668200E+00, -.17805400E-01, -.14595900E+01, 0.85412400E+00, 0.71641800E+00, -.76294200E+00, 0.67172600E+00, 0.57744200E-01, -.30633900E-01, 0.21859700E+00, -.80363800E-01, -.49390800E-01, -.21918300E-03, 0.83243000E-01, 0.12156200E+01, -.18169800E+01, 0.74000100E+00, -.78539200E+00, 0.18832900E+01, -.14995900E+01, -.72609400E-01, 0.30292400E+01, 0.72597000E-01, 0.15060100E+00, -.68966400E+00, -.53332400E-01, 0.27965500E+01, -.29933200E+01, -.39989900E+00, 0.38794900E+00, -.67894800E-01, 0.40420700E+01, -.68443200E+00, -.25215000E+01, 0.10982200E+00, -.10913700E+01, -.43927300E+00, 0.83595200E+00, 0.10803400E+01, 0.76290300E+00, 0.69328300E+00, 0.10456300E+01, 0.20433900E+00, -.56002300E+00, 0.55325600E+00, -.39122400E-01, 0.32668900E+00, 0.67440300E+00, -.10618400E+00, 0.29289700E+00, 0.54555100E+00, 0.13325500E+00, -.29590100E+00, -.54594000E-02, -.11568100E+02, -.22366000E+00, 0.22445100E-01, -.29174500E-01, -.25433300E+00, -.22912300E+00, -.27985500E+00, -.73516900E+00, -.42406700E+00, 0.28679500E+00, 0.44206600E+00, 0.10514500E-01, -.19256200E+00, 0.17425900E-01, -.82318900E+00, 0.23452600E+00, 0.65461100E-01, -.59166700E-01, 0.11574100E+01, -.48616200E+00, 0.41498000E-01, 0.21272700E+00, 0.82008500E+00, -.21544000E+01, 0.33041800E-01, 0.99857400E-01, 0.39802200E+00, 0.55350500E+00, 0.45603900E+00, -.55437500E+00, 0.36850000E+00, 0.10693900E+01, -.31752600E+00, 0.19814000E+00, -.56920200E+00, -.58577000E-01, 0.15835100E+00, 0.26746600E+00, 0.13067800E-02, -.21743000E-01, 0.39431100E+00, -.11427500E+01, -.22113100E+01, 0.12005000E+01, -.26966300E+00, 0.47913200E+00, -.48430000E-01, -.27149500E+00, 0.63279600E-01, 0.32594200E-01, 0.10362600E+02, -.71835700E-01, 0.38675200E+00, -.26064300E+00, -.35344800E+00, -.34966100E+00, 0.50578700E+00, 0.10390800E+00, -.48258000E+00, 0.26401700E+01, -.90310800E+00, 0.43499700E+01, -.58748200E+01, -.18641300E+01, -.24990700E+00, 0.56977000E+00, -.64520900E-01, -.15857800E+00, -.12421800E+00, 0.27382500E+01, -.64095500E+00, 0.96098200E+00, -.87543400E+00, 0.39350200E+00, 0.16799800E+01, -.63174300E-01, 0.20203400E+00, -.19466200E+00, 0.38591800E-01, -.10941400E-01, -.74582500E-01, 0.74747100E+00, 0.12414700E+00, 0.19660700E+00, 0.92716800E-01, -.29631500E+00, 0.35291000E-01, 0.24930400E+00, 0.16778800E+00, -.26152400E+00, 0.16539500E-02, 0.28891000E+00, 0.15120500E+01, 0.29703300E+00, -.18086100E+00, 0.35096800E+00, -.19140000E+00, -.12455800E+00, -.45748000E+00, -.80214900E-01, 0.77686800E+00, 0.48380800E-02, -.12098400E+00, 0.55944500E+00, -.14048800E+00, -.40696000E+00, 0.24831300E+00, -.83081100E-01, -.61051100E-01, 0.18950900E+00, 0.53323200E-01, -.14579300E+00, -.10283100E-01, -.21527400E+00, -.19669500E+00, -.22054500E+01, -.11375600E+01, 0.16908500E+00, 0.66743200E-02, -.98509900E+00, -.87492800E+00, 0.74929900E-01, 0.27107800E+00, 0.48095400E-02, 0.31211600E+00, -.45344500E+00, -.10686700E+00, -.55728100E+00, 0.51446500E-01, -.14817300E+00, -.87226100E+00, 0.52887800E+00, -.45385200E-01, 0.16486100E+00, -.54310300E-01, -.86134600E-01, -.24339600E+01, 0.42012700E+00, 0.10350800E+00, 0.37307000E+02, 0.11374400E+02, -.10648600E+02, -.21031200E+03, 0.10466300E+03, 0.99813200E+02, 0.10505100E+03, 0.50681500E+02, 0.28402400E+02, 0.18016900E+02, -.68077000E+02, 0.29804600E+02, 0.20657700E+02, 0.11644200E+03, 0.12910800E+02, -.39647000E+01, 0.53688200E+01, 0.17890300E+01, 0.10394900E+02, 0.63184200E+01, -.82495600E+01, -.10681400E+02, 0.77459900E+01, -.44554000E+01, 0.12238400E+02, 0.77638600E+01, 0.30988200E+01, -.36462300E+01, 0.53006100E+01, 0.45732700E+01, 0.39261000E+01, -.82263700E+01, 0.84079200E+01, 0.72936400E+01, -.11260200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19924700E+01, -.29996700E+01, -.14630800E+02, -.32667800E+01, -.24530000E+01, 0.20887600E+01, -.16539700E+01, 0.10096500E+01, -.24681000E+01, 0.18180600E+01, -.66280800E+00, 0.22687800E+01, -.31810100E+01, 0.27959400E+01, 0.15881600E+01, -.42711200E+01, 0.10167000E+01, 0.16073800E+01, 0.43547800E+00, 0.67631900E+00, 0.13319400E+00, 0.35050200E+00, 0.46344900E+01, 0.18556500E+00, 0.26654600E+00, 0.73081700E-03, 0.55256900E+00, 0.20798200E+01, -.20416200E+01, -.22883400E-01, -.22326100E+01, 0.16825800E+01, -.33454400E+01, -.91882700E+00, 0.47584300E+01, 0.34071300E-01, 0.59533600E+00, -.66160200E+00, -.51952900E+00, 0.29307700E+01, -.50449900E+01, 0.23820700E+01, 0.21453500E+00, 0.39196100E+00, 0.44516500E+01, -.86985800E+00, -.47354000E+00, 0.54373100E-01, -.31050400E+01, -.27145300E+00, -.71523300E+00, -.93091200E-01, 0.19043200E+01, 0.27739900E+00, 0.30478700E+01, 0.56648400E+00, -.37460300E+01, 0.12673800E+01, -.17004300E+00, 0.11964500E+01, 0.10446600E+01, -.11763500E+01, -.29869900E-01, 0.78546700E-01, -.17564000E+01, -.67957900E+00, 0.45709000E+00, 0.17611700E+01, -.48878900E+00, 0.10165900E+00, -.69219900E+00, -.53515400E+00, -.44280300E+00, -.48428600E+00, 0.76829600E+00, -.67895900E+01, -.29710000E+01, 0.13233700E+01, 0.16235900E+00, 0.17887400E+01, -.20204300E-01, 0.21121900E+01, -.14973900E+01, -.14125700E+01, -.12778900E+01, 0.60595400E+00, 0.11385500E+01, -.16694400E+00, 0.34307200E+01, 0.17299800E+00, 0.11664800E+01, -.48767900E-01, 0.27807600E+01, -.62329400E+00, 0.60464700E+00, 0.64548500E+00, 0.10286800E+01, 0.36607300E+00, 0.54337800E+00, 0.54905800E+00, -.36829000E+00, -.45894600E-01, -.18136800E-01, -.44983600E+00, -.16187000E+01, -.40027500E+00, 0.29810500E+00, -.13775900E+01, -.22450200E+01, -.51019700E+01, -.56113600E+01, -.27148900E+01, -.23274900E+00, -.71948300E-01, 0.11211200E+01, -.37801100E+01, -.18798900E+01, 0.29727000E+02, -.66604200E+00, 0.29636900E+01, 0.19785100E+01, -.57980100E+00, 0.39399100E+00, -.42855600E+01, -.54922500E+00, -.26305200E+00, 0.20046300E+02, 0.63120700E+00, -.21296000E+02, 0.16712000E+02, -.12745300E-01, -.21686600E+01, 0.33787600E+00, -.14739100E+00, -.25895700E+00, 0.61673200E+00, -.13501300E+01, 0.15856600E+01, 0.35025400E+01, -.12523200E+00, -.71989000E-01, -.41942700E+01, -.18819200E+00, 0.62644300E+00, 0.32732000E+00, 0.53617000E-02, 0.84627900E-01, -.15976800E+01, 0.28897000E+01, 0.32527900E+01, 0.33046700E+00, -.12479900E+01, 0.52431200E+00, -.53646200E+00, 0.11378600E+01, -.23258800E+00, 0.53263800E+00, -.29122400E-01, 0.36141600E+00, 0.31766000E+01, -.44187900E+00, -.64699400E+00, 0.15345000E+01, -.89282100E+00, -.37223700E+00, -.12509500E+01, 0.62169800E+00, -.20675300E+02, 0.63282600E-01, -.25893400E+00, 0.97274800E+00, 0.98946900E+00, 0.32651400E+01, 0.10634100E+01, -.11637700E+01, -.13344700E+01, 0.37484800E+00, -.43859400E+00, 0.55327500E+00, 0.67307200E-01, 0.19572100E+00, 0.66956600E+00, 0.33933600E+00, 0.25431900E+01, -.15269900E+00, -.50050400E+00, -.49058000E+01, -.23244500E+01, -.12932900E+00, 0.88920300E+00, -.34318800E-01, 0.60501600E+00, -.13435000E+01, -.54931700E+00, -.12365200E+01, 0.11735200E+00, -.41981100E-01, -.87516200E+00, 0.15268300E+01, 0.94144200E-01, 0.95058300E+00, -.74672600E-01, 0.18429300E+01, 0.31453600E+01, -.12760300E+01, -.99025800E+00, 0.36849500E+01, -.10059200E+03, -.21615000E+03, 0.99963100E+03, -.49513800E+03, -.44212800E+03, -.50230300E+03, -.12389100E+03, -.48945400E+02, -.24098000E+03, 0.23007800E+03, -.22558400E+03, -.28908200E+02, -.50712900E+03, -.47744600E+02, 0.21127200E+02, -.26606800E+02, -.65660600E+01, -.53415300E+02, -.31002600E+02, 0.33496800E+02, 0.54242900E+02, -.26367800E+02, 0.31448800E+02, -.43123100E+02, -.26542900E+02, -.91520800E+01, 0.32341200E+02, -.26337500E+02, -.87690600E+01, -.23325100E+02, 0.29892700E+02, -.28984100E+02, -.39288000E+02, 0.54254500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28444400E+00, 0.44968000E+00, 0.47239600E+00, 0.63555200E+00, -.17750600E+01, 0.38404500E+00, 0.13581000E+01, -.10546000E+00, -.20713000E+00, 0.24824800E+01, 0.15650100E+00, 0.61565700E-01, 0.73438800E+00, -.93316100E+00, -.31107100E+00, 0.13614000E+01, -.10113300E+01, -.60476700E+00, 0.55807900E+00, -.41454900E+00, 0.98466600E-01, -.18393300E-01, 0.22310800E+01, 0.16476000E+00, 0.72967600E+00, 0.18124400E-02, 0.48347000E+00, 0.35433600E+00, -.61167400E+00, -.24169700E+00, -.40181700E+00, -.37412200E+00, 0.89194900E-01, 0.74741600E+00, 0.72022400E+00, 0.18653500E+00, -.25477600E-01, 0.46671000E-01, 0.18724800E+00, 0.70428100E+00, -.90407900E+00, 0.63296500E+00, 0.87176800E-02, 0.18211700E+00, -.72217800E+00, 0.19197000E+00, -.11199100E+01, -.63741800E-02, -.88980500E+00, -.57689800E+00, 0.18856500E+00, 0.28172200E+00, 0.30720700E+00, 0.15834700E+00, 0.90225700E+00, -.18759400E+00, -.34865900E+00, -.35314000E-01, 0.94712900E-01, 0.85356900E-02, 0.58365700E-01, -.89774900E-01, -.19967100E+00, -.22526100E+00, -.67838300E+00, 0.94798900E-01, -.14098200E+00, -.10745600E+01, 0.13029600E+00, 0.60816200E-02, 0.10761700E+00, 0.20438900E+00, 0.65506000E-01, -.11087900E+00, -.13078800E+00, -.74201200E-01, -.11995200E+01, 0.14351400E+01, 0.10553300E+00, 0.53947300E-01, 0.19868100E-02, -.17995800E+00, 0.73074800E+00, 0.74294200E+00, 0.15309200E+00, -.85848800E+00, 0.39577900E+00, 0.58588700E-01, -.12669000E+00, -.32524700E+00, -.65838400E+00, 0.60361700E-02, -.11586100E-01, -.20690000E+00, 0.13090300E-01, 0.18037800E+00, -.90065500E-01, -.17968700E-01, 0.16726200E+00, -.16325000E+00, 0.23534500E+00, -.23717000E+00, -.18334300E-01, 0.10249500E+00, 0.34528100E+00, -.72695500E-01, -.97362700E-01, 0.37582000E+00, -.13265600E+00, -.91180600E+00, 0.47478500E+00, 0.16166600E+00, -.31659300E+00, -.26531200E-01, -.12022900E+00, -.74376800E+00, 0.21534800E+00, 0.97526900E+01, -.17654200E+00, 0.11619200E+01, -.32158800E-01, -.14555800E+00, -.82329100E-01, 0.60023300E+00, 0.31716800E-01, 0.61551500E-02, 0.27654600E+01, -.85559900E-01, 0.23925600E+01, 0.10442500E+01, -.51786100E-02, -.21507400E+00, 0.27018400E+00, -.25184500E-02, 0.72665800E-01, -.58499600E-01, -.51826500E+00, 0.36423200E-01, -.51655000E+00, 0.12856800E+00, 0.12534900E+00, -.23505600E+00, 0.30969400E+00, -.24842800E+00, 0.49262900E-01, 0.40854300E-01, -.79841700E-02, 0.45088300E+00, -.10494700E+01, -.96677700E+00, -.13443000E+00, 0.30277400E+00, 0.89624200E+00, -.18741700E+00, 0.46206400E+00, 0.25392300E-01, -.84572000E-01, -.13611600E-01, -.90501300E-01, -.89177400E+00, 0.13047100E+00, 0.47498900E+00, -.76698700E-01, 0.59312700E-01, 0.17810400E+00, -.20967200E+00, -.58817300E-01, 0.76262100E+01, -.27074200E-01, -.17665700E+00, 0.59348900E-02, -.25278000E+00, -.51948200E+00, 0.26546000E-01, 0.64016900E-01, -.10927000E+00, -.94129700E-01, 0.32131200E-01, -.23367700E-01, 0.10772800E-02, 0.42596300E+00, -.56444700E+00, -.75082600E+00, 0.96056600E-01, -.11890900E-01, 0.43112700E-01, -.57355400E+00, -.15440900E+00, 0.92436300E-01, -.12607300E-01, -.58856200E-02, 0.22424300E+00, 0.15628200E+00, -.10877100E+00, -.24105200E+00, 0.43511600E-01, -.86657600E-01, -.29527400E+00, 0.38852800E-01, -.28481500E-03, 0.13559900E+00, -.12413400E-01, -.32394700E-01, -.12686300E+01, 0.19323200E+00, -.19965400E+00, -.20228800E+00, -.12893000E+00, -.67581200E+02, 0.51156400E+02, -.25443600E+02, -.19532300E+02, -.26124000E+02, -.55838000E+01, 0.53584900E+01, -.29165600E+02, 0.49933000E+00, -.24035500E+02, 0.56828500E+01, -.10425900E+02, -.23550900E+01, 0.97619500E+00, -.59232500E+01, 0.73636300E-01, -.69976700E+01, -.23195800E+01, -.31133400E+00, 0.70341600E+01, -.23901100E+00, 0.63194200E+01, -.22230500E+01, 0.28202800E+00, -.29186200E+00, 0.69639500E+01, -.58990500E+01, 0.36421200E+00, -.96585600E+00, 0.26642400E+01, -.36655500E+00, 0.65622000E+00, 0.33261100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20363600E+01, 0.44060700E+00, 0.11034800E+02, 0.19391500E+01, 0.13312600E+01, -.22460200E+01, 0.34984100E+00, -.89729500E+00, 0.24883500E+01, -.14363900E+01, -.31790300E+00, -.14679600E+01, 0.38793900E+01, -.20922500E+01, 0.99779700E-02, 0.31216400E+01, -.17548300E+01, 0.46673400E+00, -.92605500E+00, -.35294800E+00, -.27509600E+00, -.29899800E+00, -.55636600E+01, 0.14508600E-02, 0.94754000E-01, 0.15094000E-02, -.55494500E+00, -.74607600E+00, 0.50864200E+00, 0.24136000E+01, 0.93388700E+00, 0.12930300E+01, 0.19325000E+01, 0.12615700E+01, -.54291100E+01, -.79448300E-01, -.88078300E+00, 0.63371800E+00, 0.67238500E+00, -.47504300E+01, 0.63635000E+01, -.23674400E+01, -.76662000E+00, -.12003200E+01, -.18301900E+01, 0.12445300E+01, -.11370400E+00, -.26067800E+00, 0.47050800E+01, 0.48103500E-01, -.32932000E-01, -.69578500E+00, -.23963100E+01, -.11789300E+01, -.20999600E+01, -.13661900E+01, 0.25053800E+01, -.49303700E+01, 0.59055300E+00, -.16929300E+01, -.38658900E-01, 0.27027700E+01, -.29129500E+01, 0.91610600E+00, 0.58498900E+01, 0.12341100E+01, -.64839300E-01, -.15201700E+02, 0.41348000E+00, 0.16640700E-01, 0.15195800E+01, 0.95982800E+00, -.24308300E+00, 0.44013200E+00, -.26962100E+01, 0.57451800E+01, 0.30511600E+01, 0.35392400E+01, -.25395600E+00, -.72196900E+00, -.70150900E-02, -.26381500E+01, 0.13821200E+01, -.96251700E+00, -.34295200E+00, -.72750700E-01, 0.79563000E+00, 0.22609100E+00, -.32707700E+01, -.22031600E+01, 0.44475600E+01, 0.60139200E-01, -.19807800E+00, 0.76857800E+00, -.37319300E+00, -.30000700E+00, -.11252600E+01, -.51101900E+00, 0.60544700E+00, -.92377100E+00, 0.36224500E+00, 0.26025200E+00, -.10321600E+00, 0.84134200E+00, -.99481600E-01, 0.13855900E+01, -.69676400E+00, 0.23630500E+01, 0.67717300E-01, 0.17276600E+01, 0.54374000E+01, 0.55495800E-01, 0.61198600E+00, -.25388900E-01, -.73511600E+00, -.31885700E+00, 0.13693900E+01, 0.18239600E+02, 0.52419200E-01, 0.16379500E+01, -.18257600E+01, -.19288000E+01, -.18970900E+00, 0.21862900E+01, 0.66179100E+00, -.57248300E-01, -.19338800E+02, -.58172300E+00, 0.23331200E+02, 0.25738900E+02, -.24244700E+01, 0.15115700E+01, 0.65047500E+00, 0.26558700E+00, 0.91484400E+00, -.44580800E+00, -.14629900E+01, 0.15999100E+00, -.35832700E+01, 0.52148900E+00, -.18610000E+00, -.28347000E+01, 0.10538600E+01, -.37167700E+00, 0.16287800E+00, 0.39033900E+00, 0.12283600E+00, 0.10976200E+01, -.43691300E+01, -.30442100E+01, -.12801600E+01, 0.33630200E+01, 0.49372500E+01, -.35811800E+00, -.10878700E+01, 0.29415200E+00, 0.57746300E+00, -.12965500E+00, -.11100200E+01, -.10120700E+02, -.42972900E+00, 0.36399200E+01, 0.15748800E-01, -.68386200E+00, -.98665400E-01, -.28553300E+01, -.21588800E+00, 0.13330100E+02, -.13485200E+00, -.56827800E+00, -.20593700E+01, -.24713400E-01, -.16403100E+01, -.25327000E+01, 0.58343700E+00, 0.25434900E+01, -.74058900E+00, -.24322400E+00, -.16456700E+01, -.49206100E-02, -.30559400E+00, 0.40194100E+00, -.93126300E+00, -.14312000E+01, 0.93545000E-01, 0.13527600E+00, 0.11068100E+01, -.23245300E+00, -.85584800E-01, -.11786600E+00, 0.92516300E-01, 0.16024100E+01, -.23956300E+01, -.22793900E+00, -.12273300E+01, -.30056700E+00, -.83225500E-01, -.22700600E+01, 0.40226000E+00, -.22064500E+00, 0.85373000E+00, -.11849900E+00, -.32890300E+00, -.71474000E+01, -.36907000E+00, 0.54638600E-01, -.60336100E+00, -.19527700E-01, 0.81463100E-01, -.31755000E+03, 0.15781400E+03, 0.14251200E+03, 0.15635500E+03, 0.28162300E+02, 0.55801500E+02, -.37467300E+02, -.15259300E+03, 0.12893200E+01, 0.37033700E+02, 0.37219000E+03, 0.13085100E+02, 0.41128100E+00, 0.12941300E+02, 0.41661100E+01, 0.39703100E+02, 0.12357800E+01, 0.26966400E+01, -.39921900E+02, 0.14058900E+01, -.19734200E+02, 0.13699500E+02, 0.10362300E+02, 0.15879700E+02, -.19351000E+02, 0.12977900E+02, 0.24281200E+02, 0.10124500E+01, -.71540800E+01, 0.95816100E+00, -.77148500E+00, -.11358600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.77409200E+00, -.70434100E+01, -.96660600E+01, -.58028000E+01, 0.30866500E+01, -.64374200E+01, 0.50499800E+01, 0.20164400E+00, 0.84495300E+01, 0.58299500E+01, -.43972400E-01, -.20262100E+01, 0.94644700E+01, 0.37232200E+01, 0.12627100E+01, 0.31516200E+01, -.22432400E+01, 0.28041300E+01, -.28824700E+01, 0.39655900E+01, 0.16125000E-02, 0.12624400E+00, -.89626700E+01, -.71910100E+00, -.19897100E+01, -.53951400E-02, -.13301500E+01, 0.64863800E+00, -.22951300E+01, 0.80032600E+00, -.35613600E+00, 0.19166900E+01, -.88941100E+00, -.39211300E+00, 0.43233800E+01, 0.31923400E+00, -.12928500E+00, -.72800000E+00, 0.56525100E-01, 0.59406300E+00, -.40857400E+00, -.59575100E+00, 0.21160300E+00, -.21229800E+00, 0.39451100E+01, -.89420100E+00, 0.25064800E+01, -.12796600E+00, 0.53176900E+00, 0.15906600E+01, 0.80498300E+00, 0.39908500E+00, -.90422500E+00, -.70402500E+00, -.12846800E+01, 0.26686500E+00, -.59266300E-01, -.67318600E+00, -.75960100E-01, 0.56152100E+00, -.18549800E+01, -.21413600E+01, 0.23479700E+01, 0.38980500E+00, 0.11829700E+01, -.50154600E+00, 0.13961100E+01, 0.15012000E+02, 0.17227100E+00, -.58425400E-01, 0.54829800E+00, 0.35049000E+00, -.68654900E-02, 0.89555800E+00, -.29191800E+00, 0.51612600E-02, -.29975300E+01, -.51501000E-01, -.50186200E+00, 0.28094000E+00, 0.54208200E-01, 0.10461800E+01, 0.20899600E+00, 0.31068600E+00, 0.55120700E+00, -.12412000E+01, 0.66752200E+00, -.96882300E-01, 0.10359300E+01, -.13499400E+00, 0.16488000E+01, -.27133500E-01, -.91899800E+00, -.77614300E+00, -.13732000E+00, -.94324700E+00, -.63151400E+00, 0.50713300E+00, -.15664400E+01, -.30773200E+00, -.58210000E+00, 0.33266700E+00, 0.32331100E-01, 0.79483200E+00, 0.47638400E+00, 0.36654200E+00, -.65418700E-01, 0.12758400E+01, 0.26160400E+00, 0.62987000E+00, 0.72206200E+00, 0.36465900E+00, 0.74164100E-01, -.17133400E+00, 0.12592400E-01, -.51653900E+00, -.27990800E-01, 0.21673900E+01, 0.71977500E-01, 0.13977700E+00, -.56128100E+00, -.54965700E+00, 0.50413900E+00, -.14498400E+01, -.25979400E+00, 0.99827100E+00, 0.35022000E+01, 0.32566100E+00, -.71920500E+01, 0.73878300E+01, 0.15711900E+01, 0.80416200E-01, -.28104900E+00, -.13791000E+00, 0.39599300E-02, 0.24158300E+00, 0.15831800E+01, 0.50886900E-01, -.33818900E+00, 0.61433600E-01, -.18008300E-01, -.10231600E+01, 0.15586000E+00, -.32668500E-01, 0.23047900E+00, 0.57094300E-02, -.37169500E-01, -.36227800E+00, 0.18147300E+01, 0.12026100E+01, 0.12367200E+00, 0.59112300E+00, 0.30270500E+00, 0.11330800E+00, -.13801300E+00, -.21295800E+00, 0.30965000E-01, 0.60000600E-01, -.69901900E-01, -.14180500E+01, -.25857700E+00, 0.67536300E+00, 0.20093000E+00, -.10548900E+00, 0.53109700E-01, -.14995600E+00, 0.20823800E+00, 0.12169200E+01, 0.24277700E-02, -.12781200E+00, -.86056700E+00, 0.49747000E-01, 0.91184600E+00, 0.12768100E+00, -.17074400E-01, 0.14791300E+00, -.15848700E+00, -.26185000E+00, 0.48395800E-01, 0.46459000E-02, 0.17897800E+00, 0.86671800E-01, -.12979400E+00, 0.90630800E+00, -.91864700E-01, -.10171700E+00, 0.82650600E-02, 0.71464100E+00, 0.17358200E+00, -.17572600E+00, -.78316100E-02, -.43197300E+00, -.13948000E+00, -.80533900E-01, 0.93077400E-01, 0.68131100E-01, 0.11615300E+00, 0.39358600E+00, 0.78375000E-01, 0.40032800E-01, 0.22356100E+00, 0.82613200E-02, 0.15376600E+00, 0.91758400E+00, -.89707100E-01, -.17265600E-01, -.14314300E+00, -.19866900E-01, 0.27673500E+00, 0.15669600E+00, 0.14805900E+02, 0.75506800E+01, 0.62811500E+00, -.92507700E+01, -.12561200E+02, 0.16745400E+02, 0.15352200E+02, 0.22238100E+02, -.98684800E+01, -.56293800E+02, 0.28069100E+00, 0.68006000E-01, -.15967500E+00, -.46979400E+00, -.30019000E+01, 0.30287800E+00, 0.24292800E+00, 0.30802100E+01, -.81564800E+00, 0.25248300E+00, -.75270500E-01, -.14039200E+01, -.33649200E+01, -.47931200E-01, -.12957400E+00, -.41619400E+01, -.25560200E+00, -.11595200E+00, -.61318300E+00, -.35024100E+00, -.21880600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20901600E+00, -.43275400E+00, 0.68656300E+00, -.45067300E+00, -.20755100E+01, 0.10174600E+00, 0.41669600E+00, -.75384700E-01, 0.11251400E+01, 0.18415700E+01, -.16370800E+00, -.17997100E+00, 0.10442500E+01, 0.21603400E+00, 0.37278500E+00, 0.69188300E+00, 0.38145800E+00, -.16846500E+00, -.18723000E+00, 0.13913800E+00, 0.43262500E-01, 0.11280200E+00, 0.85065500E+00, 0.12954300E-01, -.30879900E-01, 0.16207900E-03, 0.12747800E-01, -.26547100E+00, 0.79147200E+00, -.21254000E+00, -.55031100E-01, -.27727900E+00, -.53364000E-01, -.15658700E-01, -.12077300E+00, 0.19893600E-01, 0.35079900E-01, 0.36815300E-01, -.21154200E+00, -.82920900E+00, 0.68786000E+00, -.90777500E-01, -.15347100E-01, 0.38559200E-01, 0.15746100E-01, 0.12429800E+00, -.51113300E+00, -.31224900E-01, 0.56824600E+00, 0.39250800E-01, 0.49429300E-02, -.38468500E+00, 0.42532700E+00, 0.92126100E-01, -.11458800E+00, -.25052100E+00, 0.13737100E+00, -.56912300E+00, 0.38066100E-01, -.26037600E+00, 0.25946900E+00, 0.13691200E+00, -.20669800E-01, -.22147800E+00, 0.32946900E+00, 0.25994700E+00, 0.18428900E+00, -.89416600E+00, -.23755500E-01, -.18326500E-01, 0.19595800E-01, -.56297100E-01, -.11309400E+00, 0.30056000E-01, -.86521900E-01, -.28508300E-01, -.34466400E+00, -.21081400E+00, -.32892800E-01, -.14006200E-01, -.29014700E-02, 0.21889900E-01, 0.10030200E+00, -.81633100E-03, 0.12870200E-01, 0.15322800E+00, -.18980200E+00, 0.64338000E-02, 0.20073000E+00, -.14851300E+00, -.16139500E+00, -.60193300E-02, -.34027400E+00, -.10851500E+00, 0.24925800E-03, 0.60151900E-01, 0.35466400E-01, -.88039000E-01, -.41499400E+00, -.16084400E+00, -.11010300E+00, 0.27614000E-02, 0.22027300E-01, 0.97401100E-01, -.25788800E+00, 0.78060600E-01, 0.68449800E-01, -.37160200E-01, 0.43892200E+00, 0.35738200E+00, -.76667900E+00, 0.51384800E-01, -.51046600E+00, 0.35977500E-01, 0.32657900E-01, -.42679700E-01, 0.46985200E-01, -.67951400E+00, -.10212400E+00, 0.86913800E-01, 0.53183800E+00, 0.19824400E+00, -.86491900E-03, 0.10024800E+01, 0.40047600E-01, -.18233600E+00, -.92597100E+00, 0.69167100E-01, 0.50896500E+00, -.20115400E+01, -.77487800E+00, 0.61127200E-01, -.13162900E+00, 0.80199000E-01, 0.38385300E-01, -.65841300E-01, 0.19464600E+00, 0.80152100E-01, -.36030900E+00, 0.43063600E-01, -.47482300E-01, 0.51094700E+00, -.18056000E+00, 0.10855400E+00, -.86170700E-01, -.29384200E-01, -.48076100E-02, -.87841900E-01, 0.13721900E+00, 0.10040100E+00, 0.46357800E-01, -.10921700E+00, -.46239100E+00, 0.39282400E-01, -.46362500E+00, 0.15182600E-01, 0.20020300E+00, 0.35077700E-02, -.79010600E-01, 0.58048100E+00, -.19221200E+00, -.28942000E+00, 0.13965500E+00, -.10309600E+00, 0.55623800E-01, -.32533400E+00, -.13356100E-01, 0.90337600E-01, 0.26039400E-01, -.18168200E+00, 0.44273600E+00, -.18074600E-01, -.19319800E+00, -.37527000E+00, 0.79787200E-01, 0.56555800E-01, -.16720500E+00, 0.63474800E-01, 0.18838600E-01, -.10672000E-01, 0.11191400E+00, 0.56404000E-01, 0.51571600E+00, 0.32989700E-02, -.52080800E-01, 0.58710400E-01, 0.26302800E+00, 0.91911300E-01, -.38123800E-01, 0.18736300E+00, -.19518900E-01, -.57759500E-01, -.33340500E+00, -.14244900E-01, -.73727500E-01, -.70197000E-01, -.31125700E-01, -.31880600E+00, -.54146100E-01, -.49582900E-01, -.38472600E-01, -.85814000E-02, 0.15945000E+00, -.83620500E+00, -.17314900E+00, -.41020900E-01, 0.17092900E+00, 0.21824500E-01, 0.25427900E+00, 0.57817200E-01, -.81191600E-02, -.95809500E+01, 0.38943700E+00, -.12455700E+02, -.15981000E+02, 0.23794900E+02, 0.27501100E+02, 0.19121600E+02, -.13555400E+02, -.59329900E+01, -.65008900E+00, -.53951300E+00, -.92464200E+01, -.56881700E+00, -.96529900E+01, 0.14032200E+01, 0.58571100E+00, 0.97578700E+01, -.98414800E+00, 0.76686400E+01, -.62624200E+00, 0.15253900E+00, -.57696300E+01, 0.71166000E+01, -.92354700E+01, -.61761200E+01, 0.63561100E+00, 0.49893100E+00, -.97675100E+00, -.14748700E+01, 0.98950800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.77000900E+00, -.53524700E+00, -.49183100E+01, -.36207800E+01, -.69310200E+01, 0.47969900E+01, -.65112800E+01, 0.11748600E+01, -.11879500E+01, 0.17833200E-01, 0.22989700E+00, 0.28661100E+00, -.50533300E+00, -.21093800E+00, -.27527400E+00, -.27375600E+00, 0.98898500E+00, -.16805400E+00, -.44863300E+00, 0.18736000E+00, 0.91547800E-01, 0.95613200E-01, 0.45513300E+00, -.27787500E-01, 0.21436900E-01, 0.72524700E-03, -.10349300E-01, -.32314400E+00, 0.52673700E+00, -.31875200E+00, 0.12498700E+00, -.13388800E+00, -.97120100E-02, -.33124200E+00, -.78378800E-01, 0.99299700E-01, -.47857200E-01, -.78605200E-01, 0.37964900E-01, 0.79526700E-01, -.28892100E+00, 0.60872300E+00, -.60195700E-01, 0.38905800E-01, 0.89906600E+00, 0.16183300E-01, -.15463700E+01, 0.48778100E+00, -.15962000E-01, -.32963500E-01, 0.14680000E+00, -.26699800E+00, 0.94207300E+00, 0.18194900E-01, -.70723400E-01, -.32001200E+00, 0.92706700E+00, -.12529800E+01, -.45408100E+00, -.17306700E+00, -.69224400E+00, 0.16521200E+01, -.75427600E+00, -.23551100E+00, -.20388100E+00, -.53167800E+00, 0.35212300E+00, 0.33646400E+01, -.16481100E+00, -.27311300E+00, -.46903500E+00, -.25440800E+00, 0.10727700E-01, 0.20410200E+00, -.75852500E+00, -.24357300E+01, 0.96364500E+00, -.20422500E+01, 0.24609000E+00, 0.19615500E-01, -.16126800E+00, -.50779200E+00, 0.24577900E+00, -.12950900E+00, 0.28718400E+00, 0.28435700E+01, -.17916300E+01, 0.33577000E+00, 0.55621500E+00, 0.21212700E-01, 0.59801700E-01, 0.17308800E+00, -.29288600E-01, -.37737500E+00, -.18527100E+00, -.23457300E+00, 0.21381800E+00, 0.15674900E+00, 0.69162100E-01, 0.27173700E-01, -.15689300E+00, -.35873300E-01, 0.52669100E-01, 0.15082900E+00, -.15984200E+00, 0.14718000E+00, 0.23655100E-02, 0.85873800E+00, -.10149700E+00, 0.16726700E+00, 0.22153500E+00, -.35343600E+00, 0.11288300E+00, -.22708900E+00, -.20574700E+00, -.27911100E+00, 0.60156900E-01, 0.61147900E+01, -.10487800E+00, 0.43954700E+00, -.60667200E+00, -.40623300E-02, -.17022500E-01, 0.12877300E+00, -.24935400E+00, 0.22979100E+00, 0.12045500E+01, -.97678200E-02, -.41679300E+01, 0.48572700E+01, 0.19756400E+01, 0.14615700E+00, 0.16320200E+00, -.65220600E-01, -.17262900E-01, 0.14589300E+00, 0.62623700E+00, -.46363800E-01, 0.36360500E+00, -.48626700E+00, -.38264600E+00, -.49408400E-01, -.32967300E-01, 0.17418400E+00, 0.68116600E-01, 0.11668900E+00, 0.10991800E-01, -.36550900E+00, -.54408200E-01, 0.47337700E+00, -.15863900E+00, 0.70456300E-02, -.97333200E+00, 0.14145700E+00, -.10954500E-01, -.15966200E+00, -.22851600E+00, 0.20703200E+00, 0.29668000E+00, 0.41460500E+00, -.29733100E+00, -.11763100E+00, -.10320900E+00, 0.16856700E+00, 0.10205700E+00, 0.33600800E+00, -.11478800E-01, 0.58750800E+01, 0.17692600E+00, 0.11451700E-01, -.60782800E+00, -.10621000E+00, 0.11576100E+01, 0.40282700E+00, 0.81820400E-02, -.41017600E-02, -.19038300E+00, -.11406800E+00, 0.24088500E+00, 0.33193400E-01, 0.58986500E-01, 0.51515300E+00, -.56039300E+00, 0.63381300E+00, 0.58308700E-02, 0.61715400E-01, -.11162900E+00, 0.81309600E+00, 0.76293700E-01, -.17973500E+00, 0.39361700E-01, -.49829700E+00, -.17918100E+00, -.88941900E-01, 0.12674400E+00, 0.50566900E-01, 0.90667600E-01, 0.37550200E+00, 0.91602900E-01, 0.23814900E-01, 0.28142600E+00, 0.90365000E-01, 0.17485300E+00, 0.12151500E+01, -.86592300E-01, -.11891400E+00, -.11548700E-01, 0.40524400E-01, 0.25468500E+00, 0.14926900E+00, -.52184300E-01, -.91813400E+00, 0.31406800E+02, -.27845200E+02, -.29604700E+02, 0.40473700E+02, 0.41120500E+02, 0.42464400E+02, -.24876400E+02, -.58174900E+02, -.99546100E+00, -.34968400E-01, -.82226800E+01, -.10286200E+01, -.10603900E+02, 0.12214600E+01, 0.12451000E+01, 0.10764600E+02, -.23388400E+01, 0.66229200E+01, -.12004700E+01, -.15654600E+01, -.84723300E+01, 0.57417200E+01, -.81737200E+01, -.93326200E+01, -.15757200E+00, 0.10195900E+01, -.21481500E+01, -.21141200E+01, -.18581800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.87305700E+00, 0.89629100E+00, -.12202500E+01, 0.13541900E+01, 0.10749600E+01, -.11227100E+01, 0.46393800E+01, -.37964600E+00, -.18983700E+01, 0.25229800E+01, 0.13959900E+01, -.49297800E+00, 0.27901300E+00, -.11433000E+01, -.14633700E+01, 0.83034200E+00, 0.79541900E+00, -.96013300E+00, -.10633400E+01, -.20914900E+00, 0.14024300E+00, -.28966700E+00, -.13945200E+01, 0.30751700E-01, 0.33942600E+00, 0.18231300E-02, -.69924900E-01, -.67127900E+00, 0.34641600E+00, 0.50278300E+00, 0.70846800E+00, 0.49717200E+00, 0.11863700E+01, 0.10843700E+01, -.28568600E+01, -.25551900E+00, -.30200800E+00, 0.24708500E+00, 0.56389000E+00, -.87118300E+00, 0.16391100E+01, -.59510400E+00, -.21599900E+00, -.42963400E+00, -.20642700E+01, 0.51090300E+00, -.13601900E+00, -.66530100E-01, 0.78627000E+00, -.22798000E+00, 0.10780100E+00, 0.84335100E+00, -.20219900E+00, -.41777500E+00, -.12327000E+01, -.44670100E+00, 0.20492400E+01, -.13781700E+01, 0.27723700E+00, -.59271400E+00, -.55340900E-01, 0.68292100E+00, -.28161800E+01, -.11721800E+00, 0.19006300E+01, 0.34803800E+00, -.33856100E+00, -.63986800E+01, -.44495200E-01, -.47024300E-03, 0.54740000E+00, 0.73813600E+00, 0.26222600E+00, -.16697100E+00, 0.69171700E-02, 0.28654700E+01, 0.22576400E+01, -.65580100E+00, -.83910800E-01, -.48773500E+00, -.39330200E-01, -.14665600E+01, 0.47939700E+00, 0.17253200E+00, 0.29159300E+00, 0.51574100E+00, -.18835300E+00, 0.97339600E-01, -.99340400E+00, -.44060000E+00, 0.56904800E+01, 0.50855200E-01, -.19087000E+00, 0.51471200E+00, -.24396900E+00, -.11571700E+01, -.42830000E+00, -.47384600E+00, 0.10695700E+01, -.49161100E+00, -.11638300E+00, -.76903500E-02, -.69029900E-01, 0.20113800E+00, 0.61999900E+00, 0.22138400E+00, -.19431200E+00, 0.84845700E+00, -.28463000E+00, -.17310100E+01, 0.14221900E+01, -.60645600E+00, 0.11730900E+01, -.54539000E-02, -.85658400E+00, 0.31858800E+00, 0.29441100E+00, 0.15933300E+02, -.27360800E+00, 0.32202400E-01, -.11080200E+01, -.38484400E+00, -.84965000E+00, 0.11723700E+01, 0.20009200E+00, -.52974500E+00, 0.37896600E+01, -.84269800E+00, 0.54531100E+01, -.97263100E+01, 0.16097700E+01, 0.37945600E+00, 0.11133700E+01, -.16434700E+00, 0.61024400E-01, -.18426200E-01, 0.21318700E+01, -.10063200E+01, -.10011400E+01, -.11266400E+01, -.27789900E+00, 0.22340800E+01, 0.11537100E-01, -.23979500E-01, -.10064700E-01, -.10570900E-01, -.47780100E-01, 0.45991700E+00, 0.57862800E+00, 0.83525800E-01, -.18970300E+00, 0.17193200E+01, 0.39787200E+00, 0.39955700E+00, -.11637200E+01, 0.25055200E+00, -.11504500E+01, -.14086900E+00, -.95566000E+00, 0.30983300E+01, -.65871400E-01, -.30207400E+00, 0.18682400E+00, 0.28390900E-01, 0.11369000E+00, 0.11914000E+01, -.62416200E+00, 0.22049000E+01, -.11694300E+00, -.81108600E-01, -.63566100E+00, -.95843700E+00, -.19062900E+01, -.46043400E+00, 0.66677500E+00, 0.52320300E+00, -.32081600E+00, 0.45914600E+00, -.83629300E-01, -.32961500E-01, 0.12368300E+01, -.97656300E+00, 0.81642400E-01, -.87328200E+00, -.26662100E+00, 0.54518300E+00, 0.63006100E+00, 0.13179600E+00, 0.15340500E+00, -.16760500E+00, -.61501100E-01, 0.50085200E-01, 0.16553900E+01, -.14669400E+00, 0.10777500E-01, 0.14539000E+00, -.17028700E-01, 0.64885600E-01, -.28184300E+00, -.23083900E+00, 0.67671500E-01, -.80540000E-02, -.34387900E+00, -.24400200E+01, -.23647500E+00, 0.15593300E+00, -.51287700E+00, -.76298500E-01, -.87721200E+00, 0.24676200E+00, -.11024700E+00, -.31442600E+01, 0.45486200E-01, -.60106600E+02, -.84128600E+02, 0.85313900E+02, 0.11513400E+03, 0.12404100E+03, -.80382700E+02, -.49764100E+02, -.10812900E+01, 0.46643500E+01, -.56995900E+02, -.34286000E+01, -.57907700E+02, 0.65296300E+01, 0.44335700E+01, 0.58888500E+02, -.80961300E+01, 0.50371600E+02, -.74174900E-01, 0.20055100E+01, -.44342900E+02, 0.48750900E+02, -.57017200E+02, -.35852600E+02, -.43053100E+01, 0.21760700E+01, -.78714700E+01, -.83080700E+01, -.10629100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13008200E+01, 0.17118200E+01, 0.94075100E+01, 0.10687100E+01, 0.42069400E+00, 0.11244000E+01, -.85714600E+00, -.44025700E-01, -.49927700E-01, -.35916300E+01, -.83439800E+00, -.44592500E+00, -.31872300E+01, -.14278400E+01, -.47030700E+00, -.73336500E-01, 0.18223700E+01, -.64844100E+00, 0.30457800E+01, -.18439800E+01, -.20743800E+00, 0.37425300E+00, -.19957400E+01, -.11854900E+00, 0.48056500E+00, 0.30275300E-02, -.29256600E+00, 0.39334100E-01, -.71456400E+00, -.31964200E+00, 0.12006300E+01, 0.58764300E+00, 0.53565200E+00, 0.11322000E+01, -.22170200E+01, -.38667100E+00, 0.96505000E-01, 0.98627500E+00, -.24681400E+00, -.31420600E+01, 0.20246700E+01, 0.17768000E+00, -.23713700E+00, 0.46839300E+00, -.78183800E+01, 0.10022500E+01, 0.36717200E+01, 0.19285900E+00, -.16346200E+01, 0.21665600E+01, -.37946800E+00, 0.10297500E+01, -.46383900E+00, -.21468200E+00, 0.14550300E+01, 0.79624100E-01, 0.15238600E+00, -.12934800E+01, -.15241200E-01, -.87840900E-01, -.12593100E+01, 0.59297400E+00, -.28617300E+01, -.37069800E+00, 0.14823600E+01, 0.28899000E+00, -.76337100E+00, 0.14052200E+02, -.46894700E+00, 0.47676900E-01, -.74620500E+00, 0.66625200E+00, -.64116400E-01, 0.61647200E-01, -.66153500E+00, 0.37463100E+01, 0.92328400E+00, -.10206300E+01, 0.44649100E-01, -.20493400E+00, 0.78715800E-01, -.13312700E+01, 0.19438900E+01, 0.16892200E+01, 0.24876200E+01, -.22838500E+01, 0.78747300E+00, 0.23160900E+00, -.28538900E+01, -.14934000E+01, 0.71920500E+01, 0.12779100E+00, -.22110500E+01, -.17936300E-01, 0.15814300E+00, -.96095900E-01, 0.31356400E-01, -.73344300E+00, 0.11954700E+01, -.75458300E+00, -.32474100E+00, 0.12345200E+00, 0.24632400E-01, 0.12348900E+00, -.10930400E+01, 0.14996800E+00, 0.82961500E-01, -.19054800E+01, -.19508800E+01, -.22666000E+01, 0.15972900E+01, -.74586900E+00, 0.13944000E+01, -.11859000E+00, 0.36020300E-01, 0.35695100E+00, -.11072100E+00, -.24579100E+01, 0.21575500E+00, -.84416800E+00, -.21272800E+01, -.28381300E+00, -.31578300E+00, -.75846900E+00, -.15833500E+00, 0.12676000E+00, 0.76167400E+01, -.14373500E+00, -.43449500E+01, 0.25841000E+01, 0.26700900E+01, 0.17507700E+00, 0.59209100E-01, 0.20249200E+00, 0.13296500E+00, 0.29272400E-02, 0.24188700E+01, -.30724800E+00, -.16388300E+00, -.12107100E+01, -.27014200E+00, 0.26293300E+01, -.42455500E+00, 0.17076300E+00, -.45117900E-01, 0.10882400E+00, 0.45599800E-02, -.20396700E+00, -.60536600E+00, -.99291100E+00, -.19954000E+00, 0.61246800E+00, -.21217200E+01, -.50283500E+00, 0.10488400E+01, -.23175100E+00, -.75972300E+00, 0.56571700E-01, 0.29694100E+00, -.22325700E+00, 0.11092400E+01, 0.38567900E+00, -.65883100E-01, 0.41987000E+00, 0.61611300E-01, 0.99435400E+00, 0.12456900E+00, 0.55846100E+01, 0.89418100E-01, 0.48037000E+00, -.72734200E+00, 0.12225700E-01, -.37248700E+00, -.40909700E+00, 0.37323700E+00, 0.77691200E+00, -.18349400E+01, -.59709000E+00, 0.21631400E+00, 0.25690600E-01, -.48119800E+00, -.31076500E+01, 0.43045200E+00, -.12848100E+01, 0.18975300E-01, 0.15719200E-01, 0.25995200E+01, 0.70048500E+00, 0.88160700E-02, -.54250400E+00, 0.84544900E-01, -.77289700E+00, 0.10480100E+01, 0.24785300E+00, 0.99357600E+00, -.28077700E+00, -.28018800E+00, 0.39412800E+00, -.14804900E+00, 0.87006300E-01, 0.28799300E+00, 0.67954700E-01, 0.26528800E-01, 0.60471600E+01, -.28819700E+00, 0.25101500E+00, 0.32320100E+00, 0.40169100E+00, -.22975700E+01, -.75398400E-01, -.15719200E+00, 0.89544800E+00, -.59578800E-03, 0.10912400E+01, 0.84557600E+02, -.10462200E+03, -.14493600E+03, -.12351900E+03, 0.77701400E+02, 0.17526400E+03, -.15208200E+01, -.68319200E+01, 0.80723700E+02, 0.61882900E+01, 0.96269600E+02, -.43148500E+01, -.74551500E+01, -.96997900E+02, 0.88456500E+01, -.80397800E+02, -.82493900E+00, -.64262700E+00, 0.49688600E+02, -.82106400E+02, 0.81259600E+02, 0.41788700E+02, 0.63152500E+01, -.28867400E+01, 0.83538500E+01, 0.11926900E+02, 0.34975300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.70033400E+00, -.21125000E+00, 0.96146000E+00, -.47307500E+00, -.11964200E+01, 0.89760500E+00, -.20882800E+01, 0.11705000E+00, 0.90129300E+00, -.73713400E+00, -.16134600E+00, 0.18616700E+00, 0.45850700E+00, 0.48920100E+00, 0.52362700E+00, -.33140800E-01, 0.87961000E+00, 0.22575500E+00, -.10238500E+00, 0.61825600E+00, 0.73396000E-01, 0.88155100E-01, 0.11793200E+01, 0.16601000E-01, -.22578200E+00, -.11763300E-02, 0.13152100E+00, -.26841300E+00, 0.38314900E+00, -.10432400E+01, -.10441000E+00, -.13362400E+01, -.29258000E+00, -.49253200E+00, 0.12996500E+01, 0.23608000E+00, 0.24183000E+00, -.17181100E+00, -.44148800E+00, 0.35946100E-01, -.75826500E+00, 0.42901000E+00, 0.75096500E-01, 0.27565100E+00, 0.86631600E+00, -.34943200E-01, -.10313500E+01, 0.10906700E+00, -.78460000E-02, -.53737300E-01, 0.35663000E+00, -.85492800E+00, -.64291700E-02, 0.37228600E+00, 0.97552300E+00, 0.16477200E+00, -.76002900E+00, -.64103900E-01, -.25099900E+00, 0.22827200E+00, -.39484200E+00, -.84638200E-01, 0.17813700E+01, 0.21413800E+00, -.51951700E+00, -.34902300E+00, 0.33738600E+00, 0.16008000E+01, 0.33654300E+00, 0.23567100E-01, -.25805700E+00, -.66325700E+00, 0.64184600E-02, 0.29186300E+00, -.86597200E+00, -.12556500E+01, -.69014700E+00, 0.21060100E+01, 0.20466700E+00, 0.12814800E+00, 0.53335800E-01, 0.80487300E+00, -.11139400E+00, -.46492900E+00, -.53391000E+00, 0.75291900E+00, -.49574100E+00, 0.76998800E-01, 0.12584400E+00, -.35431000E+00, -.54229700E+01, -.12638200E-01, -.43084100E+00, -.52643500E+00, -.32477500E+00, 0.27089000E+00, -.16976000E+00, 0.52237400E+00, -.85273900E+00, 0.35708900E+00, 0.66883000E-01, -.11041900E+00, 0.90688000E-02, 0.19453300E+00, -.49300100E+00, 0.23999200E+00, -.19494100E-01, 0.64394000E+00, 0.43153300E+00, 0.24873300E+01, 0.52130800E+00, 0.56597600E+00, -.12088000E+01, -.12681600E-01, 0.24038900E+00, -.35343700E+00, 0.28782000E+00, -.51375400E+01, 0.15427200E+00, 0.43811800E+00, 0.13048000E+00, 0.49496800E+00, 0.36635500E+00, 0.13042000E+01, -.53670800E-01, -.57002600E+00, -.93085500E+01, 0.11079900E+00, 0.60894300E+00, 0.37601100E+01, 0.12691000E-01, 0.16339300E+00, -.62831600E+00, 0.61907900E-01, -.19902200E+00, -.47612100E-02, -.28939700E+00, 0.12863000E+00, 0.41035000E+00, 0.35149100E+00, 0.11070900E+00, -.79646400E+00, 0.11139300E+00, -.21558500E+00, 0.15580600E+00, 0.12021500E+00, 0.41679100E-01, -.43446900E+00, -.82798700E+00, -.22966600E+00, -.83489100E-01, -.58364800E+00, 0.54305700E+00, 0.63478300E-01, 0.31859300E+00, -.19814200E+00, 0.61777800E+00, 0.13760100E+00, 0.36724500E+00, -.12963100E+01, -.24658500E+00, 0.20306400E+00, -.38158100E+00, 0.20908400E+00, 0.23456700E+00, 0.59661400E-01, 0.15560900E+00, 0.74006400E+01, 0.52281700E-01, -.40853700E+00, -.96889300E-01, 0.34424300E+00, 0.76806300E+00, 0.50222000E+00, -.52743800E+00, -.33821800E+00, -.18876900E+00, 0.38253700E-01, 0.63228700E+00, -.13289100E-01, 0.97064700E+00, 0.13900800E+01, -.11343300E+01, 0.84440600E+00, 0.22565800E+00, -.36623700E-01, -.38357200E+00, 0.66757100E+00, 0.35995100E-01, -.52800300E-01, -.50007200E-02, -.96590500E+00, -.44849200E+00, -.12573900E+00, 0.32151800E+00, 0.69771100E-01, -.69470700E-01, 0.41411500E+00, 0.28316200E+00, 0.88950400E-01, -.39985100E-02, 0.21875400E-01, 0.19609300E+00, 0.25509000E+01, 0.83125300E-01, 0.14386200E+00, -.53662100E+00, -.18232900E+00, 0.10102700E+01, 0.30884200E-01, 0.43007300E-01, -.23144900E+01, 0.49552700E-01, 0.55035300E+00, 0.11610100E+00, 0.43080700E+02, 0.19498200E+02, -.19947500E+02, 0.10700400E+02, -.50845900E+02, -.27345500E+01, -.34361400E+01, 0.21305300E+02, -.31539300E+00, 0.14351300E+02, -.24190400E+01, -.12100800E+01, -.14921700E+02, 0.20003000E+01, -.18907700E+02, -.38992400E+01, -.42748400E+01, 0.15955900E+02, -.19169500E+02, 0.21345100E+02, 0.77076900E+01, 0.34621800E+01, 0.15779000E+01, 0.22553000E+01, 0.11717500E+01, 0.12957000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.37009500E+00, 0.26639500E-01, 0.13926000E+01, -.53092900E+00, 0.75173300E+00, 0.34303100E+00, 0.74033100E+00, -.13731800E+00, 0.17293100E+00, -.96693700E+00, -.34688900E+00, 0.34403300E-01, -.52204900E+00, -.88316000E+00, -.41898300E+00, 0.62726300E+00, -.13131500E+00, -.38500200E+00, 0.80309500E+00, -.70459200E+00, -.51684000E-01, 0.10539300E+00, 0.97431400E+00, 0.71361900E-01, 0.26517700E+00, 0.13005700E-02, 0.10775600E+00, -.28890500E+00, 0.18009100E+00, -.52996500E+00, 0.51602300E+00, -.82953200E+00, 0.45476500E+00, 0.39913300E+00, -.26476800E+00, 0.76661000E-01, -.47237300E-01, 0.16433900E+00, 0.92312500E-01, -.40035000E+00, 0.42647200E+00, 0.29725900E-01, -.62212900E-01, 0.13229400E+00, -.18124900E+00, 0.65464700E-01, -.40600600E+00, -.20326200E-01, -.23059600E+00, -.59973500E+00, 0.72270800E-01, -.19297900E+00, -.12632400E+00, 0.27557200E+00, 0.23719100E-01, -.17238000E+00, 0.13333100E+00, 0.70603500E-01, 0.53220900E-01, -.12744000E+00, 0.37104700E+00, 0.85970300E+00, -.95297600E+00, -.22672000E+00, -.36598000E+00, 0.79039500E-01, -.15853900E+00, -.91739200E+01, 0.11806900E+00, -.15399400E-02, 0.29445800E+00, 0.41366800E-01, 0.32933700E-01, -.40877600E-01, 0.20576900E+00, 0.25234700E+00, 0.77189500E+00, -.51510100E+00, 0.98384200E-02, -.20718500E+00, -.88814300E-03, -.61802700E+00, 0.14482000E+00, 0.13719600E+00, -.57854300E+00, 0.13481200E+00, -.12728800E+00, -.13981500E-01, -.59019400E+00, -.23775400E+00, 0.87932900E+00, 0.12442700E-01, 0.16080500E+00, 0.32752200E+00, -.16364500E+00, -.13951600E+00, 0.30899200E+00, -.26461400E+00, 0.62155900E+00, 0.33084300E-01, 0.24426600E+00, -.60735000E-01, 0.32332600E-01, -.86094400E-01, -.59550800E-01, -.46070500E-01, -.62518400E-01, -.37781700E-02, -.22708800E+00, -.10242100E+01, 0.41560600E+00, -.36578500E-01, 0.27327000E+00, -.35522200E-01, -.27941200E+00, -.42771000E+00, 0.18314600E+00, 0.89252500E+00, -.16893700E-01, 0.37036000E+00, -.36030000E+00, -.25313300E+00, 0.39915400E-01, 0.65194500E+00, 0.10983800E+00, 0.21923900E+00, -.69372200E+01, 0.14391100E+00, 0.30682300E+01, -.18032300E+01, -.63272700E+00, 0.22807200E+00, 0.67403800E-01, -.14615700E+00, -.25850700E-01, 0.33216300E-01, -.61329500E+00, -.15816100E+00, 0.43972900E+00, 0.16523700E-01, 0.14438800E+00, -.50511800E+00, -.44197600E-01, 0.20171400E+00, -.70487800E-01, -.51610400E-01, 0.71674700E-02, -.30862900E-01, 0.55647300E+00, 0.26978000E+00, 0.38926700E-01, 0.53879500E+00, 0.68167600E+00, -.36521800E-01, -.64823500E+00, 0.11618200E+00, 0.27358500E+00, -.77906900E-01, -.27491800E+00, -.55173800E-01, 0.36706300E+00, 0.51784100E-01, -.19825200E+00, 0.45821500E-01, -.52050100E-01, 0.25461300E-01, -.74838100E-01, -.77736700E+00, -.18104600E-01, -.28862300E-01, -.40727200E-02, -.93581500E-02, -.96751500E+00, -.19968300E+00, 0.25431800E-01, 0.17695100E+00, 0.22687800E+00, 0.16454700E+00, -.35479800E+00, 0.11084900E-02, -.95619700E-01, -.55943400E+00, -.47285200E-01, -.69427400E+00, 0.82262600E-02, -.25406000E-01, -.87542800E+00, -.78367100E+00, 0.33531500E-01, -.10258600E+00, 0.17907600E-01, 0.66802800E+00, 0.74935700E+00, 0.93861900E-01, -.31977400E-01, 0.19146700E-01, -.98975100E-01, -.15728600E+00, 0.36424600E-01, -.54738700E-02, -.14384900E+00, -.40358000E-02, -.14438700E+00, -.47623200E+00, 0.21697600E+00, 0.30514300E-02, 0.11273500E+00, -.34940500E-04, -.17389000E+00, -.10830400E+00, -.13398100E-02, 0.49006900E+00, -.15819600E-01, -.17224900E+00, -.86438900E-02, -.16161300E+00, 0.98852900E+01, -.53014300E+00, -.79944800E+00, 0.13537800E+02, -.21124700E+00, -.11137900E+00, -.39208600E+00, 0.97004200E-03, 0.67090000E+00, -.27366200E+00, 0.46724700E+00, -.73191700E+00, -.36032100E+00, -.54715400E-01, 0.15719200E-02, 0.53150300E+00, -.58474900E-01, 0.78083100E-01, -.32398600E+00, 0.52752500E+00, 0.22015100E+00, 0.14171400E+00, -.43704800E+00, -.52437400E+00, 0.11657300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19012500E+00, -.14265400E+00, 0.57585700E+00, -.68374900E-01, -.18783500E+01, 0.33739000E+00, 0.22420900E+00, -.15806900E-01, 0.73377300E+00, 0.86034000E+00, -.42727300E-01, 0.12739700E+00, -.64074700E-01, -.55838100E-04, 0.13114000E+00, 0.13614200E+00, 0.78417000E+00, -.37737700E+00, 0.11701100E+00, -.25659900E+00, 0.38773500E-01, 0.43826900E-01, 0.15009800E+01, 0.95788700E-01, 0.14360700E+00, 0.23417000E-03, 0.17919000E+00, -.11738900E+00, 0.74388100E+00, -.27417900E+00, -.64046900E-01, -.47844000E+00, -.51936400E-01, -.23843700E+00, -.50770900E+00, -.18745600E-01, 0.93469300E-01, 0.18828200E-01, -.19573300E+00, -.29034400E+00, 0.77713800E-02, 0.15297300E+00, -.22195100E-01, 0.35526100E-01, -.25082900E+00, 0.66374800E-01, -.66086500E+00, 0.36392100E-01, 0.43189300E+00, -.26911100E+00, 0.41111600E-01, -.45355100E+00, -.44730600E+00, -.64036500E-01, 0.38550400E+00, 0.10213700E+00, -.16394900E+00, 0.15184800E-01, -.82950500E-01, 0.19472000E+00, 0.99496000E-01, 0.89408900E-01, 0.69663900E+00, 0.18768900E+00, -.92378500E-01, -.31511100E+00, -.74789800E-01, 0.14456000E+01, -.29889300E-01, 0.14587000E-01, -.17914300E+00, -.10908900E+00, -.17007000E-01, -.74772600E-01, -.54708000E+00, 0.37215200E+00, -.11301100E-01, 0.15321100E+01, 0.14706800E+00, 0.84095600E-01, 0.20369700E-01, 0.39906800E+00, 0.22035500E-01, -.15903200E+00, 0.18967200E+00, 0.18082600E-01, 0.86410700E-01, 0.39551300E-01, 0.69851600E-01, -.25420800E+00, -.17483600E+01, -.90167800E-02, -.15803700E+00, -.27762300E+00, -.24100700E-01, 0.15477200E+00, -.53119500E-01, 0.26253700E+00, -.29242900E+00, 0.24114600E-02, 0.93641900E-01, -.13623100E+00, -.19008500E-01, 0.67651600E-01, -.49100000E+00, 0.92762600E-01, -.35577500E-01, 0.13817600E+00, 0.13605200E+00, 0.53241000E+00, -.12829700E+00, -.84995700E-01, -.23496300E+00, 0.13808000E-01, 0.62172800E-01, 0.13979700E-01, 0.67069900E-01, 0.16411300E+01, -.21426800E-01, 0.19599000E+00, 0.35652800E+00, 0.21134600E+00, -.76450900E-01, 0.55671900E+00, 0.95745000E-02, -.57974000E+00, 0.15226200E+01, -.22765100E+00, 0.60361900E+00, -.15569900E+01, 0.47640900E-01, -.13380100E+00, -.22794200E-01, 0.78080600E-01, 0.13170000E-01, -.78431500E-01, 0.27497600E+00, 0.12897200E-01, -.22734100E+00, 0.37245200E-01, 0.74449500E-01, 0.41816400E+00, 0.89370500E-01, -.21332400E+00, 0.26953200E-01, -.28042400E-02, 0.19098300E-02, 0.83411700E-01, -.69377500E+00, -.56733000E+00, -.45271200E-01, -.13680500E+00, 0.59770500E-01, -.11681600E-02, 0.23147200E+00, -.26344500E-01, -.12694300E+00, 0.24249700E-01, 0.26674900E-01, 0.13099200E+00, -.84340200E-01, 0.26920700E-02, -.49150000E-01, 0.62420600E-01, 0.58867600E-01, 0.11124300E+00, -.51801200E-01, 0.38958100E+01, 0.19905300E-02, -.20748000E+00, 0.11510000E+00, -.71657300E-01, -.59680700E-01, 0.21491500E+00, -.90160000E-01, -.83948100E-01, -.16215600E+00, 0.12265800E+00, 0.17153800E+00, -.29153600E-02, 0.44389800E+00, 0.19747700E-01, -.42661400E+00, 0.26098600E+00, 0.16548100E-01, 0.45480700E-01, -.47800700E+00, -.17902200E+00, 0.31547700E-01, 0.44095000E-01, -.57509200E-02, -.97940500E-01, -.12794200E+00, -.55231200E-01, -.31788400E-01, 0.43676400E-02, 0.44778700E-01, 0.79337000E-01, 0.99133600E-01, 0.24955200E-03, -.43755500E-01, 0.34596900E-03, 0.11524100E+00, -.16447900E+00, -.13652800E+00, 0.52580000E-01, -.18663500E+00, -.70293800E-01, 0.39742900E+00, 0.33123500E-01, -.16712100E-01, -.15710600E+00, 0.10832300E-01, 0.12539700E-01, -.11482600E-01, 0.27061900E+00, 0.52422800E-01, 0.83291700E+01, -.40213300E+00, -.46734300E+01, 0.87121700E+00, -.60158300E+00, -.30426200E+01, 0.11121100E+00, -.30857500E+01, 0.15803300E+01, 0.25366500E-01, 0.32029900E+01, -.21966200E-01, 0.27406000E+01, 0.10650300E+01, 0.85734300E+00, -.36986500E+01, 0.25361600E+01, -.30717500E+01, -.27915100E+01, 0.38636800E+00, -.11103500E+01, -.13588300E-01, 0.28242300E-01, -.33044800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10897700E+01, -.33744200E+01, -.95759900E+01, -.18115900E+01, 0.11221000E+01, -.17467800E+01, 0.29015200E+01, -.67278700E-01, -.61085400E-01, 0.24484800E+01, 0.60014600E+00, 0.76224300E+00, 0.12003500E+01, -.53836900E-01, -.13374300E+01, 0.23398400E+01, -.37631900E+01, -.38282700E+00, -.56047900E+00, 0.16495200E+01, 0.18797300E+00, -.14015600E+00, 0.47983700E+01, 0.21384300E+00, -.34413400E+00, -.96036600E-02, 0.52613900E+00, 0.18599700E-01, 0.26171300E+01, 0.56725700E+00, -.62293600E+00, -.21497600E+01, 0.54372100E+00, -.56179900E+01, -.23058600E+01, -.29019000E+00, 0.23744200E-01, -.18620900E+00, -.57813900E+00, -.67290300E+00, -.24599400E+01, 0.28059900E+01, -.10817700E+01, -.13321800E+00, 0.66571200E+01, -.83365100E+00, 0.13542000E+01, -.21743200E+00, -.42277000E+01, -.14493200E+01, 0.13027800E+01, -.12824800E+01, -.33644200E+01, 0.10708300E+01, 0.42855300E+01, 0.81005900E+00, -.39531400E+01, 0.12702700E+01, -.58562400E-01, 0.12087800E+01, 0.94015900E+00, -.17697600E+01, -.33164300E+01, 0.60695500E+00, 0.88655000E+00, -.80234800E+00, -.28179000E+00, -.31848600E+01, -.14809300E+00, 0.38877500E-01, -.11452600E+01, -.13683600E+01, -.88915000E+00, -.10244100E+00, -.17854200E+01, 0.42666700E+01, -.17327100E+01, 0.29264600E+01, 0.36263900E-01, -.96853300E-01, -.94023700E-02, -.66152400E+00, 0.22905400E+01, 0.10396500E+01, 0.29688800E+01, -.62501200E+01, 0.17742400E+01, 0.35199300E+00, -.19293500E+01, 0.20072900E+01, 0.29256800E+01, 0.16492800E+00, 0.13523800E+01, 0.10077200E+00, 0.11598200E+01, 0.33503500E+01, -.18143200E+01, -.18876100E-01, -.18759600E+00, -.24227800E+01, 0.16768300E+01, 0.51557900E+00, -.14637500E+00, -.31266900E+00, 0.15704900E+01, 0.52927800E-01, -.87831000E+00, -.24206500E+01, 0.15943900E+01, 0.38869700E+01, -.91816000E+00, 0.14631900E+01, -.11685100E+01, 0.11990100E+00, 0.10158400E+01, 0.24513800E+00, -.45380400E+00, -.11071100E+01, 0.15984500E+00, -.33405700E+00, 0.30677400E+01, -.12233600E+00, 0.47137500E+00, -.31359300E+01, 0.19031700E-01, 0.56973000E+00, 0.12528300E+02, 0.10375800E+01, -.54304400E+01, 0.24265800E+01, -.16203800E+01, -.93929600E+00, -.10654800E+01, 0.35873000E+00, 0.56861900E-01, -.54365700E+00, -.10823400E+01, 0.34252800E+00, -.11257400E+01, 0.13616600E+01, -.50496700E+00, 0.22906700E+00, 0.54975800E-01, -.15466700E+01, 0.69103200E+00, -.59786400E-01, 0.73626900E-01, 0.17971900E-01, 0.33920600E+01, -.78740900E-01, 0.89647900E-01, 0.42630700E+01, 0.10798700E+02, -.39744800E+00, 0.36657200E+01, 0.40485000E+00, 0.13682800E+00, -.27141400E+00, -.95778600E+00, 0.57089000E+00, 0.71837100E+00, 0.77486100E+00, 0.19470400E+00, -.48330800E+00, -.42382200E+00, 0.61909100E+00, -.26475200E+00, -.12395000E+02, -.10661600E+00, 0.82798300E-01, -.86808800E+00, 0.15878900E-01, -.23318800E+01, 0.78329100E-01, -.21970500E+00, -.22559300E+00, 0.14467600E+00, 0.53044400E+00, -.20909200E+00, 0.10295100E-01, 0.21951800E+01, -.18372100E+01, -.18154600E+01, 0.19525100E+01, -.20912100E+00, -.36839800E+00, -.84216700E+00, -.13046400E+01, 0.17579500E-02, 0.78734800E-01, 0.21738300E-01, 0.67224500E+00, -.14751500E+01, 0.12833000E+00, -.34753000E+00, 0.19397900E-01, 0.61655100E+00, 0.54723300E+00, 0.49688500E+00, 0.81026900E-01, -.99373300E-01, 0.66565300E-02, -.10818800E+00, 0.59575900E+00, -.57537100E+00, 0.88770100E+00, -.75313800E+00, -.30616500E+00, -.10399100E+01, -.22050900E+00, 0.20158000E+00, 0.18868900E+01, -.68457900E-01, -.14233700E+01, -.69328400E+00, -.11083600E+01, 0.10131100E+01, -.29763700E+01, 0.10055900E+02, 0.22707100E+01, -.29361000E+01, -.80507800E+00, 0.14882100E+02, 0.87384800E-01, 0.84554400E+01, 0.50514000E+01, 0.30012900E+00, -.83273100E+01, -.35925500E+00, -.16682000E+02, -.22655800E+01, -.78660800E+00, -.78874000E+01, -.20205400E+02, 0.15217200E+02, -.72445900E+01, -.28040400E+00, -.99396900E-01, -.52027900E+00, -.75076000E+00, 0.11778600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15755200E+01, 0.12578800E+01, 0.10055800E+02, 0.13242200E+01, 0.22296100E+01, -.15266700E+01, -.52894100E+00, -.39787200E+00, 0.17831900E+01, -.29243500E+01, -.10258200E+01, -.87776400E+00, 0.99441900E+00, -.90692400E+00, -.39207400E+00, 0.20226400E+01, -.37997800E+01, -.33999100E+00, 0.13873000E+01, -.15908300E+01, -.34892700E+00, -.10747900E+00, -.24424800E+01, -.94199800E-01, -.37133300E-01, 0.24864000E-03, -.33143000E+00, 0.14023500E+00, 0.12938000E+00, 0.11003500E+01, 0.38616000E+00, 0.79267700E+00, 0.10751500E+01, 0.50997100E+00, -.18029700E+01, -.28059100E+00, -.40956000E+00, 0.37979300E+00, 0.48744100E+00, -.75577400E+00, 0.22667100E+01, -.14882600E+01, 0.17610800E-01, -.30061700E+00, -.13994300E+01, -.28698200E+00, 0.15206600E+01, -.13520700E+00, 0.16635200E+01, 0.45343500E+00, -.22506700E+00, 0.73132300E+00, -.15063800E+01, -.50365500E+00, -.15245200E+01, -.18718500E+00, 0.75483600E+00, 0.48067500E+00, 0.30197100E+00, -.30226300E+00, 0.32882300E+00, 0.19157900E+00, -.11216800E+01, -.13850500E+00, 0.45381700E-01, 0.51643800E+00, -.37055800E+00, 0.16305100E+01, 0.26932700E+00, -.73878700E-01, 0.62741300E+00, 0.62809300E+00, 0.24774800E+00, 0.72225500E-01, 0.83104700E+00, 0.27764700E+01, 0.13024000E+01, -.32255800E+01, -.30969600E+00, -.63858600E+00, -.10660600E-01, -.11636000E+01, 0.54744800E+00, 0.64870200E+00, 0.92860300E+00, -.17203700E+01, 0.13334000E-01, -.13720100E-01, -.15411900E+01, -.79180200E+00, -.57756100E+00, -.25653200E-01, -.10087400E+01, 0.57205300E+00, 0.46674000E-01, 0.63065500E-01, -.36501400E+00, -.39178300E+00, -.57587500E+00, 0.17976700E+00, 0.22774700E+00, 0.33344100E+00, 0.52169700E-02, -.20399000E+00, 0.41186300E+00, -.33710400E+00, -.10764400E+00, -.11241100E+01, 0.20155400E+00, -.85792400E+00, 0.97763000E+00, 0.82469500E+00, 0.25152600E+00, 0.74321900E-01, 0.17545100E-03, 0.11136800E+01, 0.41745700E+00, -.11365300E+02, 0.34524700E+00, -.61226000E+00, 0.10532400E+01, 0.12429100E+00, 0.75787600E-03, 0.27049700E+00, 0.32516500E+00, 0.25020900E+00, -.45768900E+01, 0.23775100E+00, 0.13009600E+02, -.34876900E+01, -.31020900E+01, -.12771300E+00, -.11081600E-01, 0.11065300E+00, 0.58550800E-01, -.39871000E+00, -.17543300E+01, -.16695500E+00, -.10120400E+01, 0.10753500E+01, 0.76323400E+00, 0.35676500E+00, 0.68130800E-01, -.42266400E+00, -.16222200E+00, -.16439500E+00, -.93510300E-02, 0.10298000E+01, -.10814200E+01, -.18906600E+01, 0.13075200E+00, 0.29138000E+00, 0.12084400E+01, -.38546600E+00, -.23748700E+00, 0.26873000E+00, 0.31836300E+00, -.20271700E+00, -.54142300E+00, -.11774400E+01, 0.10978000E+01, 0.69040100E+00, -.20677800E+00, -.14103500E+00, -.25262500E-01, -.14760800E+00, -.72519200E-01, -.38058000E+01, -.52966300E-01, -.17520400E-01, 0.59769200E+00, 0.67536300E-01, -.39032600E+01, -.10816600E+01, 0.25353200E+00, 0.19813300E+00, 0.38551900E+00, 0.43086500E+00, -.74842900E+00, -.80770600E-02, 0.62680300E-01, -.24219200E+01, 0.86920300E+00, -.21137900E+01, -.29800700E-01, -.24634700E-01, -.24232300E+00, -.20533500E+01, 0.14954300E-01, 0.21022400E-01, 0.36731700E-01, 0.15334600E+01, 0.12986800E+01, 0.25720900E+00, -.23848000E+00, -.60179800E-02, -.15606900E+00, -.53825000E+00, -.41373100E+00, -.63086700E-01, -.63812600E+00, 0.47466400E-02, -.55135100E+00, -.21157000E+01, 0.30099800E+00, 0.23550100E+00, -.38957400E+00, -.11106900E+00, -.68607600E+00, -.33534700E+00, 0.16489400E+00, 0.14391600E+01, -.16127400E-01, -.63828000E+00, -.58448300E-01, -.54958200E+00, 0.33783900E+00, -.12271600E+01, -.16868300E+00, 0.72775000E+02, -.17601800E+01, 0.13575900E+01, -.80225800E+01, -.24346500E+00, -.53440800E+01, 0.22232300E+01, 0.17979400E+01, 0.55803200E+01, -.16124000E+01, 0.58417300E+01, -.63741300E+00, 0.19080400E+01, -.78816600E+01, 0.49873200E+01, -.80195700E+01, -.44550100E+01, -.11254200E+01, 0.64740800E+00, -.18149500E+01, -.24035300E+01, -.51909900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.65643200E-01, 0.50261000E-01, -.17402100E+00, -.90085800E-02, -.18329200E+00, 0.49617800E-01, -.16719100E-01, -.72579700E-02, 0.11989100E-01, 0.14333300E+00, 0.70458700E-01, 0.18400200E-01, 0.38051600E-01, 0.27414800E-01, -.62416100E-02, -.53808500E-03, 0.21686500E+00, -.30501500E-01, -.46923000E-01, 0.81197600E-01, 0.18860300E-01, -.25770600E-03, 0.11376100E+00, 0.15776700E-02, -.13949600E-02, -.83354400E-04, 0.14171300E-01, -.61154400E-01, 0.35589200E-01, -.77878500E-01, -.15382300E-01, -.64535600E-01, -.15157700E-01, -.65952600E-01, 0.65138400E-01, 0.11061700E-01, 0.11585500E-01, -.10220900E-01, -.32443500E-01, -.24027400E-02, -.48574100E-01, -.18326600E-01, 0.90298600E-02, 0.12259300E-01, 0.15356100E+00, -.32470700E-01, -.10138000E+00, 0.22782900E-03, 0.39058300E-01, 0.50675600E-02, -.17037200E-02, -.27305900E-01, 0.58890500E-03, -.14511500E-02, 0.51564500E-01, 0.40901200E-02, -.63674600E-01, 0.49540300E-01, -.30299900E-02, -.54021000E-02, 0.59105200E-01, 0.24602300E-01, 0.96997600E-01, -.34123800E-02, -.79242300E-01, 0.84181300E-03, 0.35681700E-02, -.47397100E+00, -.12866300E-01, 0.99731200E-03, -.35737800E-01, -.64116700E-01, -.34384600E-01, -.15778200E-01, 0.19018400E-01, 0.45954900E-02, -.61676000E-01, 0.20518000E-01, -.31920700E-03, -.74072100E-02, 0.59612300E-03, -.11368000E-01, 0.20815800E-01, 0.17848700E-01, 0.35994300E-01, -.23432900E-02, 0.79355000E-02, 0.15775200E-02, -.85553500E-02, 0.72002100E-01, -.25102300E-01, 0.16722300E-02, 0.30393800E-01, -.18928900E-01, -.44686900E-02, 0.56277400E-01, 0.55250200E-01, -.21364600E-01, 0.15183100E-01, -.35443000E-01, 0.26607100E-01, -.11337400E-01, 0.47057500E-02, -.88380600E-02, -.40136900E-01, 0.40615000E-02, 0.23180800E-01, -.10294800E+00, -.12243800E-01, 0.24069100E-01, -.10893200E+00, 0.58954700E-01, -.72402300E-01, 0.39730800E-03, 0.22997200E-01, -.40516400E-01, 0.10502000E-01, -.34946900E+00, 0.12797000E-02, 0.18760800E-01, 0.32037100E-02, 0.27656900E-01, 0.64592800E-02, 0.73872900E-01, -.39671900E-02, -.17251100E-01, 0.17544100E+00, -.25037500E-01, 0.13015900E+00, -.64522000E+00, -.31457900E-01, 0.79744900E-02, -.94397200E-02, 0.22346700E-02, -.20915300E-02, -.64822000E-02, 0.20332300E+00, -.37227100E-01, 0.34147500E-02, -.35545700E-01, -.54909800E-02, 0.89787400E-01, -.35268800E-01, 0.15167600E-01, -.53046000E-02, -.78947600E-03, 0.23726200E-02, -.49426900E-01, 0.85251400E-01, 0.85415900E-01, 0.12735700E-01, -.37376200E-01, -.80971300E-01, 0.24463000E-01, -.55862600E-01, 0.72303600E-02, -.33902000E-01, -.20475400E-02, -.22683500E-01, -.40928900E-01, -.27252100E-01, -.56092100E-01, 0.29649500E-01, 0.43858300E-02, -.11167700E-01, 0.36210800E-01, 0.17300900E-02, -.21107800E+00, 0.11196000E-02, 0.10140500E-01, 0.60662600E-02, 0.34473300E-01, 0.11612700E+00, 0.54216500E-02, -.72461200E-02, -.22562500E-01, -.54147000E-02, 0.22849200E-02, 0.44843600E-02, 0.20152600E-03, 0.18762200E-01, -.28926600E-01, 0.22208700E-01, 0.51470200E-01, -.66704700E-02, -.27303100E-02, -.10142000E-01, 0.74922300E-02, 0.17127700E-02, 0.88384800E-02, 0.11836800E-02, -.30769700E-02, -.55344200E-02, -.18986800E-02, -.98726000E-03, -.36422400E-02, 0.13675100E-02, 0.77298400E-02, -.45420300E-02, 0.22186200E-02, -.62008900E-02, 0.67777200E-03, -.73405700E-02, -.82418300E-01, 0.14600400E-01, 0.17742600E-03, -.22622800E-01, -.10376600E-01, 0.36751400E-01, 0.40605500E-02, 0.14174700E-02, 0.94033600E-01, 0.13820200E-03, -.35969300E-01, -.16964300E-01, 0.11987200E-02, 0.21231900E-01, 0.14619200E+00, 0.38442600E-02, -.28377500E-02, 0.52788200E+00, -.30439600E+00, 0.34444400E+00, 0.20192700E+00, 0.42069000E+00, 0.30997200E+00, -.30461400E+00, -.42011000E+00, 0.30625300E+00, -.44989000E+00, 0.47422000E+00, 0.30656700E+00, 0.85664800E-01, -.50477000E+00, 0.35193900E+00, -.81160400E-01, 0.31644100E+00, -.48029700E+00, 0.31452500E+00, 0.35581400E+00, -.96347800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30730600E+00, 0.50476600E+00, 0.14343400E+01, 0.68937000E+00, -.27473800E+01, 0.90589300E+00, 0.20409200E+00, -.60370800E-01, 0.28968200E+00, 0.17315800E+01, -.48745300E-01, 0.23503100E+00, 0.55661800E+00, -.26896700E+00, 0.15318800E+00, 0.12985900E+01, -.45593200E+00, -.63829500E+00, 0.61748800E+00, -.70870700E+00, 0.71004300E-02, -.15921500E+00, 0.23503300E+01, 0.24639500E+00, 0.30090200E+00, 0.10455900E-02, 0.41553400E+00, 0.70097400E+00, 0.20921800E+00, 0.76535600E-01, -.82234800E+00, 0.45891200E+00, -.62103100E+00, -.44049900E+00, -.42405900E+00, -.20637400E+00, 0.19733000E+00, -.13955800E+00, -.24355500E+00, 0.11414600E+01, -.10871000E+01, -.20570400E+00, 0.30546600E+00, 0.17558500E+00, -.29410300E+00, -.26604800E-01, -.21275800E+01, 0.15042200E+00, 0.46408900E+00, -.91989100E+00, -.11932600E+00, -.49983700E+00, -.17923800E-01, 0.21794300E+00, 0.72197500E+00, 0.32295200E+00, -.74244000E+00, 0.34743200E+00, -.19977100E+00, 0.73141500E-01, -.33183700E-02, -.89746000E-01, -.88188500E+00, 0.90244500E-01, -.10779600E+01, -.41066000E+00, -.48704500E+00, 0.11966400E+01, -.11022600E+00, -.21338200E-02, -.45492200E+00, -.14715500E+00, 0.25383000E+00, -.50124900E+00, 0.12602000E-02, -.16636500E+01, 0.55151300E+00, 0.39490400E+00, 0.16259700E+00, 0.58404700E-01, -.14815800E-01, -.20525200E-01, -.58969500E+00, -.36518800E+00, -.43330100E+00, 0.11024500E+01, -.53056600E+00, -.39073200E-02, 0.26820600E+00, 0.24202200E+00, -.28047900E+01, -.46231000E-02, 0.53348800E+00, 0.32513200E+00, 0.31359200E+00, 0.64945200E+00, 0.21946300E+00, 0.86286300E-01, 0.84364500E+00, 0.30708400E+00, 0.37829300E+00, -.27814500E+00, -.34354000E-01, -.40824500E+00, -.12480000E+00, -.17942500E+00, 0.12597000E+00, -.70798800E+00, -.78849000E+00, -.38176900E+00, -.41810300E+00, -.18223500E+00, -.36125700E+00, 0.45992400E-01, 0.28761000E+00, 0.26431600E+00, -.21711300E+00, -.32997200E+01, 0.82270600E-01, -.23234000E+00, 0.42561800E+00, 0.40334700E+00, 0.13585300E+00, 0.13026500E+00, -.28582000E-01, -.83581000E+00, -.21895000E+01, -.32385500E-01, -.16003900E+01, -.11952700E+01, -.85554100E+00, -.19620900E+00, -.36873200E+00, 0.85790300E-01, -.14413400E+00, -.15283000E-01, 0.21702100E+00, 0.11139800E+00, 0.70868100E+00, 0.57240500E-01, 0.15262700E+00, 0.10529900E+00, 0.26685100E-01, 0.21063500E-01, -.62159100E-01, 0.11119200E-02, 0.53010600E-02, -.11098200E+00, -.29559500E-01, 0.16870900E+00, 0.75541100E-01, -.68403200E+00, -.19485200E+00, -.24678700E-01, 0.74770500E+00, -.18039200E-01, -.96872100E-01, 0.60913100E-01, 0.30471300E+00, 0.39877000E+00, -.23624300E+00, -.20081800E+00, -.18464000E+00, 0.50765500E-02, 0.13707600E+00, -.51843600E+00, 0.28676400E-01, 0.41653200E+00, 0.30402000E-01, 0.12559500E+00, 0.76746800E+00, 0.10524000E+00, -.87028700E-01, 0.15441900E+00, -.22502000E+00, -.15262400E+00, 0.21125800E+00, 0.85675000E-01, 0.16415000E+00, -.47493700E-02, -.16507200E+00, 0.86915000E+00, -.15982500E+00, -.19595500E+00, 0.13629900E+00, -.93144200E-02, -.21890900E+00, -.95910400E-01, -.80694700E-01, 0.96518600E-01, -.39594700E-02, -.19897400E+00, -.34014000E+00, -.44300500E-01, -.66326200E-02, 0.43547400E-01, -.72925100E-01, -.68588200E-01, 0.21333300E+00, -.96249100E-02, 0.98551600E-02, -.59676100E-02, 0.50247300E-01, 0.82303300E+00, -.13077500E-02, 0.64205900E-01, 0.11882000E+00, 0.57164200E-01, -.29906200E+00, 0.60318900E-01, 0.51492100E-02, -.51999900E+00, 0.63413700E-02, -.46665700E-02, -.96255200E-01, 0.16259000E-01, -.52810900E+00, -.90117900E+00, 0.18589200E-01, 0.96774300E-01, -.27531900E+01, 0.13632600E+01, 0.47138400E+01, 0.24186700E+00, 0.52612100E+01, -.28573700E+00, -.58643000E+00, -.53594400E+01, -.22333000E-01, -.39730100E+01, 0.70293300E-01, -.48809600E+00, 0.16744400E+01, -.40895200E+01, 0.47685600E+01, 0.13805600E+01, -.15913300E+01, -.17433500E+00, 0.99577800E-01, 0.87354000E+00, 0.11801400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19645500E+01, 0.11015100E+01, 0.12455700E+02, 0.16827800E+01, -.10231300E+01, 0.14388300E+00, -.31706700E+01, -.14939300E+00, 0.55562300E+01, -.31659100E+01, -.15476300E+01, -.11741300E+01, 0.37539600E-01, -.27961800E+01, 0.35075200E+00, 0.27163400E+01, -.32679800E+01, -.77143800E+00, 0.66506700E+00, -.13236100E+01, -.25182100E+00, 0.73180900E+00, 0.46963400E+00, -.17854800E+00, -.22745500E+00, -.32666300E-03, -.39029000E-01, 0.32036200E-01, 0.29762000E+01, -.25764600E+00, 0.10620700E+01, -.25693800E+01, 0.15269700E+01, -.11925200E+01, -.66031400E+00, -.98644700E-01, -.25827600E+00, -.79495900E-01, 0.84938000E-01, -.16092700E+01, 0.12536100E+01, 0.46164100E+00, -.41423100E+00, 0.72115500E-01, 0.26372500E+01, -.70747800E+00, 0.77349300E+01, -.20506600E+00, -.28633600E+01, -.12675900E+01, -.21304300E+00, -.17107800E+01, -.40407100E+01, -.59032500E+00, -.34923400E+01, 0.63021100E+00, 0.12645500E+01, 0.27948300E+01, -.36063600E+00, -.18943300E+00, -.15169900E+01, 0.96885100E+00, -.52602600E+01, -.11555400E+01, 0.93081100E+00, -.16114800E+00, 0.29111200E+00, -.69231400E+01, 0.34790200E+00, -.11342300E+00, 0.17657400E+01, 0.16658500E+01, 0.40339700E+00, 0.50614200E+00, -.10525300E+01, 0.42516000E+01, 0.22395000E+01, -.37217600E+01, -.15864200E+00, -.19016400E+00, 0.12527700E+00, -.63102900E+00, 0.91014900E-01, 0.69842800E+00, 0.58209500E+00, -.90052600E+00, 0.12807700E+00, -.18984200E+00, -.79051600E+00, -.30370200E+00, 0.19217700E+01, -.18181200E-02, -.12695600E+01, 0.28284300E+00, -.50360700E+00, -.21741400E+01, -.11489900E+01, 0.60526000E+00, -.14179300E+01, -.39727900E-01, -.44160700E+00, 0.10940400E+01, 0.93420500E-01, 0.98281000E+00, 0.13527200E+01, 0.21884400E+00, -.71293100E+00, 0.30056700E+01, 0.88726400E+00, -.24924100E+01, 0.19175300E+01, 0.56709300E-01, 0.23663000E-01, -.34365000E+00, -.82347200E+00, -.98734200E+00, 0.12625000E+01, -.59558200E+01, 0.28851400E+00, 0.11498600E-01, -.78433400E+00, -.82846800E+00, -.11179900E+00, 0.18942200E+01, 0.14500900E+00, 0.97456300E+00, -.13652500E+02, 0.56217100E+00, 0.10238300E+02, 0.59308400E+01, 0.26279500E+01, 0.82665100E+00, 0.21865500E+00, -.16427100E+00, 0.12055100E+00, 0.14460800E+00, -.33598200E+01, -.41535900E+00, -.18875200E+01, 0.81462500E+00, 0.17176600E+00, -.10442500E+01, 0.47572200E+00, -.72230900E+00, 0.31911600E+00, -.49819900E-01, -.30560600E-01, 0.12288500E+01, -.31583400E+01, -.28083100E+01, -.43426800E+00, 0.85815900E+00, -.61112000E+00, -.26974300E+00, -.10636200E+01, -.13848300E+00, 0.53445900E+00, -.74725800E-01, -.35160200E+00, -.16025200E+01, 0.89474200E+00, 0.91994300E+00, -.17294400E+01, 0.10103300E+01, 0.99537100E+00, 0.16324200E+01, -.23752500E+00, 0.25223500E+02, -.12980100E+00, -.35540600E+00, -.10067000E+01, -.12295500E+01, -.39300300E+01, -.11868300E+01, 0.72212600E+00, 0.73204000E+00, -.15645400E+01, -.45465300E-01, 0.30742200E+00, -.48360300E-02, 0.15683200E+01, -.28121500E+01, 0.13721000E+01, 0.13174000E+01, -.50646200E+00, 0.18824500E+00, 0.19776600E+01, 0.15601400E+01, -.93667800E-01, -.75140700E+00, -.21816600E-01, -.51502600E+00, 0.18344000E+01, 0.31287600E+00, 0.14255100E+01, -.10624900E+00, 0.28870300E+00, 0.16656800E+01, -.12883700E+01, 0.10186900E+00, -.46863400E+00, 0.14317600E+00, -.24469500E+00, 0.43835100E+01, -.99100400E+00, -.36678400E+00, -.10222900E+00, 0.32608900E+00, -.14325700E+01, -.67224300E+00, -.15019600E+00, -.20925200E+01, -.55778700E-01, 0.17104200E+01, 0.13510700E+01, -.49366500E+00, 0.18306300E+01, -.57219200E+01, 0.41307600E+00, -.71316700E+00, -.14264100E+02, 0.22473300E+01, -.59935500E+02, -.14994700E+01, -.58834500E+02, -.37360900E+01, 0.12132100E+02, 0.59423100E+02, -.69800100E+01, 0.57662300E+02, -.73146700E+00, 0.26232000E+01, -.13653900E+02, 0.60947600E+02, -.60945400E+02, -.83047800E+01, 0.18667900E+01, 0.55843200E+01, -.76956500E+01, -.13202300E+02, 0.11021800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.43148200E+00, -.34489500E+00, -.29807600E+01, -.37152300E+00, -.55991200E+00, 0.37325800E+00, 0.12595200E+00, 0.75973400E-01, -.51284400E+00, 0.82515600E+00, 0.28673900E+00, 0.23985700E+00, -.44046900E+00, 0.10502100E+00, 0.12960900E+00, -.53749700E+00, 0.86559900E+00, 0.66955600E-01, -.18711700E+00, 0.28722600E+00, 0.81135000E-01, -.25870300E-01, 0.83574100E+00, 0.58727700E-01, 0.36461400E-01, 0.10695300E-03, 0.12019600E+00, -.15446700E+00, -.11058000E+00, -.33683600E+00, -.21332800E+00, -.13450200E+00, -.29327500E+00, -.60839100E-01, 0.46377400E+00, 0.28978800E-01, 0.94982600E-01, -.75235700E-01, -.90579600E-01, 0.22737600E+00, -.41495600E+00, 0.38817100E+00, 0.58964000E-01, 0.11701500E+00, 0.24734300E-01, 0.51527200E-01, -.43049200E+00, 0.46145800E-02, -.27619100E+00, -.12411500E+00, -.12920400E+00, -.84184000E-01, 0.24237000E+00, 0.20130400E+00, 0.31264100E+00, 0.11336300E+00, -.68046400E+00, 0.80794900E+00, -.36301400E-01, 0.10177000E+00, 0.45931700E+00, 0.63069200E-01, 0.15346400E+00, -.75940200E-01, -.50852300E+00, 0.33438100E-01, -.28717900E-01, -.52578900E+01, -.86819500E-01, 0.13194700E-01, -.23430000E+00, -.35987600E+00, -.25278000E+00, -.17268700E+00, 0.12313200E+00, -.27309400E+00, -.43208700E+00, 0.94076400E-02, -.38006600E-02, 0.53179300E-01, -.10690100E-02, 0.47569500E-01, -.26285900E-02, 0.15764100E+00, 0.17843800E-01, 0.12252700E+00, 0.10711600E+00, -.29599000E-01, 0.16964500E+00, 0.24114200E-01, 0.25454500E-03, -.10668300E-01, 0.50625000E-01, -.13039400E+00, -.33097500E-01, 0.14975300E+00, 0.28280200E+00, -.71856000E-01, 0.12722600E+00, -.95780200E-01, 0.13095100E+00, -.47736900E-01, 0.14395200E-01, -.33146700E-01, -.16631200E+00, 0.24560700E-01, 0.12176400E+00, -.30817400E+00, -.23826700E+00, -.24957300E+00, -.45703000E+00, 0.23860600E+00, -.38430800E+00, -.81459600E-02, 0.13570900E+00, -.54859400E+00, -.56568800E-01, 0.89293600E+00, -.27271900E-01, 0.30294900E+00, 0.20132800E+00, 0.93829600E-01, 0.75029300E-01, 0.10820300E+00, -.35734400E-01, -.92985300E-01, 0.87502500E+00, -.63550900E-01, -.25431700E+00, -.11643900E+01, -.25296300E+00, -.16240400E-01, -.83548000E-01, 0.15527900E-01, -.27243900E-01, -.91979900E-02, 0.79922300E+00, -.12010700E+00, 0.12735100E-01, -.21011200E+00, -.17222500E+00, 0.15583200E+00, -.18526200E+00, 0.15313000E+00, -.28248700E-01, 0.18805800E-01, 0.17285600E-01, -.32051600E+00, 0.59897900E+00, 0.57679400E+00, 0.49080000E-01, -.10854900E+00, -.45628500E+00, 0.11935400E+00, -.25551200E+00, 0.40597900E-01, 0.66739900E-01, 0.41443300E-02, -.62828200E-01, -.20366600E+00, -.26825000E+00, -.37236300E+00, 0.23597400E+00, -.19632000E-01, -.77483700E-01, 0.19359500E+00, 0.18061400E-01, -.38035400E+01, 0.79659700E-02, 0.22740300E-01, 0.15855900E+00, 0.23483600E+00, 0.10331800E+01, 0.96238200E-01, -.86105500E-01, -.13518500E+00, 0.69871300E-01, -.18374700E-01, 0.17567700E-01, 0.18931700E-03, 0.43628100E-01, 0.24645900E+00, 0.92097300E-01, 0.80181400E-01, 0.61708900E-02, -.22827000E-01, -.10875100E+00, -.11358700E+00, -.17576000E-02, 0.53793400E-01, 0.19261200E-02, -.43800100E-01, -.41512900E-01, -.25833800E-01, -.41464300E-01, 0.17140900E-02, -.18809000E-01, -.21072100E-01, 0.49205400E-01, 0.11817200E-01, 0.10858500E-02, -.93213100E-03, 0.48577000E-01, -.12205200E-01, 0.15183300E-01, -.18702800E-01, 0.81651300E-01, 0.40755500E-02, 0.56660300E-01, 0.31602900E-01, 0.40627600E-02, 0.19351100E+00, 0.33872900E-02, -.10809900E+00, -.83894700E-01, 0.27455800E-01, 0.47801400E-01, 0.64818400E+00, -.50030400E-02, -.15997200E-01, 0.46579900E+01, 0.29494900E+00, 0.92282800E-02, -.40316200E+00, -.38734200E+00, -.11960300E+00, 0.64689300E-01, 0.37337300E+00, -.47962700E-01, -.13900200E+00, -.12354100E+00, -.29643900E+00, -.39772500E-03, -.60542300E-01, 0.40931600E-01, -.22561100E+00, -.26335800E-01, 0.35728900E-01, -.49105600E-01, -.14653700E+00, 0.43320200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10380000E+00, 0.40225000E+00, 0.41589700E+00, 0.44154700E+00, 0.77851300E+00, -.16120900E+00, 0.23383300E+00, -.10700200E+00, -.57033100E+00, -.46953800E+00, 0.47222700E-01, -.10773800E-02, -.62034500E+00, 0.29262500E+00, 0.24431400E+00, -.13386300E+00, -.23414300E+00, -.66087600E-01, 0.70319700E-01, 0.87648400E-01, 0.34925500E-01, -.21672200E-01, -.98137300E-01, 0.33518000E-01, 0.99240800E-01, -.11273000E-02, -.10740700E-01, 0.86350800E-01, -.41478800E+00, 0.21362200E+00, -.48362600E-01, 0.46621400E+00, -.20787600E+00, 0.29735400E+00, -.22383100E+00, -.63901000E-01, 0.58037100E-01, 0.92457400E-01, -.67184600E-01, -.25037100E+00, 0.57490300E+00, 0.42297200E-01, -.50279000E-01, -.94214900E-01, -.46578200E+00, 0.14160600E+00, 0.36809900E+00, 0.10389900E-01, 0.10365000E+00, 0.36965400E+00, 0.10097800E+00, 0.21234800E+00, 0.35362300E+00, -.25373100E-01, -.25619400E-01, 0.27841600E-01, 0.55828600E+00, -.17770000E+00, 0.10421800E-01, -.14354400E+00, -.76874500E-01, 0.13534700E+00, -.14417700E+00, -.37379800E-01, -.11469600E+00, 0.16666000E+00, 0.31906400E-01, 0.24564100E+01, -.41899900E-01, -.11299900E-01, 0.13955300E+00, 0.21521100E+00, 0.28484400E-01, 0.25600300E-01, 0.26925100E-01, -.15681800E+00, -.36682800E+00, -.32975000E-01, -.83155000E-02, 0.60089500E-01, 0.19756900E-01, 0.11053300E+00, -.87791300E-01, 0.29242200E-01, 0.12643200E+00, 0.29323100E+00, 0.31458000E-01, -.29904400E-01, 0.47092000E-01, 0.23044900E+00, -.79624500E+00, -.11507900E-01, -.15123300E+00, -.84337300E-02, -.17018600E-01, -.22245400E+00, -.11813100E+00, 0.30121900E-01, -.23170100E+00, 0.37921000E-01, -.12014600E-01, 0.53827000E-01, -.13637200E-02, 0.37989400E-01, -.69210400E-01, 0.26273900E-03, -.16115300E-01, 0.21405800E+00, 0.19987700E-01, -.28284100E+00, -.86640600E-01, -.94810300E-01, 0.20447800E-01, -.11166900E-01, -.28011000E-01, -.13095000E+00, -.44990400E-02, 0.14024000E+01, -.32347500E-01, -.54237400E-02, 0.12709200E+00, -.18439700E-01, -.39921400E-01, -.93647300E-01, -.15176400E-01, 0.11388200E-01, -.21892600E+00, 0.41770900E-01, -.32627200E+00, 0.11328700E+01, 0.17790500E+00, 0.13181900E-01, -.13341500E-02, 0.54119900E-01, -.84907900E-02, 0.33937600E-01, -.15752200E+00, 0.90566900E-01, -.12832900E+00, 0.87781900E-01, -.20063400E-01, -.21834800E+00, -.21170600E-01, 0.79736200E-01, 0.35142000E-02, -.26343700E-01, -.10214800E-01, -.20160200E-01, -.21828600E+00, 0.12555500E-01, 0.28785000E-01, -.49181800E+00, -.95900000E+00, 0.55499100E-01, -.39496800E+00, -.50828500E-01, 0.17189800E+00, 0.36898700E-01, 0.10694800E+00, 0.78595300E-01, -.23638800E-01, -.13683200E+00, -.39849200E-01, 0.79433700E-01, -.58560200E-01, 0.11509000E+00, 0.40577400E-01, 0.30027800E+00, 0.20173900E-01, 0.44484000E-01, 0.47602700E-02, 0.47623200E-01, 0.40518800E+00, 0.12332800E+00, -.14223700E-01, -.36505600E-01, 0.99742400E-01, -.25396600E-01, 0.15959200E-02, -.35691100E-02, -.18887200E+00, 0.34928300E+00, -.95161200E-01, -.14586100E+00, 0.36445500E-01, 0.10643200E-01, -.72058200E-01, -.82762000E-01, 0.15662500E-01, 0.45237300E-02, -.54252800E-02, 0.45721400E-01, 0.11380000E+00, 0.13617000E-01, -.18195000E-01, 0.13892600E-01, 0.13549400E-01, 0.36738500E-01, -.52802100E-01, -.38396500E-02, -.31104700E-01, 0.24507700E-02, 0.21312700E-01, 0.11666200E+00, 0.58307900E-01, -.49631400E-01, -.48021900E-02, 0.92164700E-02, 0.86065200E-01, 0.15441400E-01, -.97166000E-03, -.78393000E-01, 0.94224400E-02, 0.55076100E-01, 0.12297500E-01, 0.73683300E-01, -.95824300E-01, 0.39861500E+00, -.67304900E-01, -.76063300E-02, 0.64661300E+00, -.40770900E-01, 0.34376700E-01, -.21451900E+00, 0.38527700E+01, 0.80492600E-01, -.27892300E+00, -.37558600E+01, 0.56626300E-01, -.34840300E+01, 0.36320400E-02, -.26030700E+00, 0.12370000E+01, -.38323400E+01, 0.48426900E-01, 0.61428900E+00, -.59819700E-01, -.29044400E+00, 0.36741600E-01, 0.45658200E+00, 0.18947800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19872900E+00, -.90641500E+00, -.32440600E+01, -.18022500E+01, -.16056700E+00, 0.61512000E+00, -.96376800E+00, 0.16069600E+00, -.30849900E+01, -.85615100E+00, 0.30501100E+00, 0.17825200E+00, -.94100100E+00, 0.35213100E+00, -.10916700E+00, -.12648900E+01, 0.73242300E+00, 0.70848300E+00, -.52476500E+00, 0.43900200E+00, 0.12049500E-01, -.14917700E-01, -.10341600E+01, -.10445000E+00, -.29287500E+00, -.42403100E-03, -.18456300E+00, 0.44504200E-01, -.50874700E+00, 0.20508500E-01, 0.13426700E+00, 0.42658100E+00, -.27240600E+00, -.95306900E-01, 0.44363200E+00, -.16530800E-01, 0.43645100E-01, -.11323500E+00, 0.36692300E-01, 0.53447000E+00, -.36425900E+00, 0.10525100E+00, 0.67703700E-01, 0.82699700E-01, 0.51295200E+00, 0.15374100E-01, -.96339600E-01, 0.24268000E-01, -.34337900E+00, -.20666400E+00, 0.32264600E-01, -.13815300E+00, 0.69600900E+00, 0.27311000E+00, -.11613400E+00, 0.64946000E-01, 0.16755900E+00, -.46176400E+00, -.61226500E-01, 0.96543200E-01, -.31140100E+00, -.15122200E+00, -.76582000E+00, -.13949500E-01, 0.32635300E+00, -.20958900E+00, 0.16455500E+00, -.13357800E+01, -.17150800E+00, -.10904800E-02, 0.11089500E-01, 0.19358200E+00, 0.28821500E-01, -.83955800E-01, 0.17076700E+00, -.10068000E+01, -.81007400E-01, 0.55456800E+00, -.13001600E-01, 0.22586000E+00, -.28770200E-01, 0.69047100E-02, -.31183100E+00, -.36221300E+00, -.40467900E+00, 0.31272300E+00, 0.56994700E-01, -.52274300E-02, 0.63148800E+00, 0.30971200E+00, 0.18424900E+01, 0.27427700E-01, 0.80334100E+00, -.56942500E-01, 0.58962300E-01, -.14930300E+00, 0.47616400E+00, -.55923600E-01, 0.94367400E+00, 0.26476000E-01, 0.11571500E-01, -.16369200E+00, 0.10419700E-01, -.29276100E-01, 0.42009300E+00, -.85582500E-01, -.11994200E-01, 0.30718500E+00, -.41078800E+00, -.10167400E+01, 0.15595700E+00, -.31320700E+00, 0.52003400E+00, -.84504700E-01, -.17593300E+00, -.55429100E+00, -.18825400E+00, 0.53263900E+01, -.43823500E-01, 0.33040000E+00, -.45832100E+00, -.79118100E-01, 0.11399900E+00, -.32473400E+00, -.10170000E+00, -.16268300E+00, 0.60499200E+00, -.17929700E-01, -.44842300E+01, -.47818900E+01, 0.10419800E+01, 0.26802700E-01, 0.22285100E-01, -.21063300E+00, -.16632500E+00, 0.21689500E+00, 0.11062000E+01, -.33433300E+00, 0.55306100E+00, -.43445100E+00, -.13365600E+00, -.87337000E-01, -.43735900E-01, 0.31084800E+00, 0.21689200E-01, -.65760300E-01, -.41118100E-01, -.19654700E+00, 0.20525300E+01, 0.13579400E+01, 0.14668700E+00, 0.62054700E+00, 0.27496400E+00, 0.13186500E+00, -.69864800E-01, 0.59219700E-01, -.22213800E+00, -.40753900E-03, 0.35608200E-01, 0.12116900E+01, -.12281800E+00, -.38148700E+00, -.12146000E+00, 0.54927000E-01, -.96649300E-01, 0.78582700E-01, 0.12949300E-01, -.17368900E+01, -.12088100E-01, 0.26231200E+00, -.20274300E+00, -.42261300E-01, 0.72484500E+00, 0.42938100E+00, -.48052500E-01, -.14363700E+00, 0.49334800E+00, -.61078000E-01, -.25166200E-01, -.37898500E-02, -.35535600E+00, 0.60326200E+00, -.37825500E+00, -.22949400E+00, 0.68336700E-01, 0.25714400E-01, -.46143200E+00, 0.91476500E-01, 0.78118000E-01, -.21234000E+00, -.61429000E-02, -.14801600E+00, 0.69746600E+00, -.15212600E+00, 0.54809100E-01, 0.14557000E+00, -.61579200E-01, 0.32852800E+00, 0.69035600E-01, -.10256000E-02, 0.44619500E-01, 0.57797400E-02, -.28852700E+00, 0.35389200E+00, 0.34432300E+00, 0.75570400E-01, -.10085900E+00, -.19768800E-02, -.74424600E+00, 0.85838400E-01, 0.21023900E-01, -.10944200E+01, 0.15806000E-01, 0.84672700E-01, -.12615500E+00, -.62021600E-01, 0.41106400E+00, 0.16860400E+01, 0.12478600E+00, -.18720000E+00, -.66019700E+00, 0.37665900E+00, -.46362600E-01, 0.45871600E+00, 0.11808900E+00, -.23737100E+01, 0.10554000E+00, -.11950600E+00, 0.16043600E+00, 0.48337600E+00, -.77349600E+00, -.10388700E+01, 0.53593200E+01, 0.10335300E+01, -.31221500E-01, 0.24924900E+01, 0.37741800E+00, 0.98354800E+00, 0.12929800E+00, -.31885500E+00, 0.46962500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21576800E+01, 0.69972300E+00, 0.10147900E+02, 0.30668300E+00, 0.54216400E+00, -.14610600E-01, -.50922000E+01, -.11979000E+00, 0.44362600E+01, -.43149500E+01, -.13675400E+01, -.14098300E+01, 0.19091400E+01, -.11734200E+01, 0.98292000E+00, 0.19269300E+01, -.92582800E+00, 0.70153100E+00, 0.39047700E+00, -.25764500E+00, -.43322500E+00, 0.33750600E+00, -.39753700E+01, -.38378300E+00, -.74375500E+00, -.40388000E-02, -.76871000E+00, -.10393400E+01, 0.15370800E+01, 0.79342700E+00, 0.16729700E+01, -.17886000E+01, 0.15211800E+01, -.10354500E+01, -.17591000E+01, 0.12327900E+00, -.32183700E+00, 0.55623000E+00, -.12303000E+00, -.39701200E+01, 0.45238000E+01, 0.79097700E-01, -.71771700E+00, -.37979200E+00, 0.75199400E+00, 0.10047400E+00, 0.67246900E+01, -.16505200E+00, 0.14788000E+01, 0.85475900E+00, -.20336500E+00, -.27649700E+01, -.45163000E+01, -.62232000E+00, -.32803600E+01, 0.12204300E+00, 0.10840500E+01, -.10890400E+01, -.31050500E+00, -.45753100E+00, 0.30748300E+00, 0.30181500E+01, -.28423300E+01, 0.26528900E+00, 0.31299500E+01, -.28320300E+00, 0.13057600E+00, -.66544900E+01, -.57945500E+00, -.61266000E-01, 0.20280500E+00, 0.75694300E-01, -.17391100E+00, 0.43241300E+00, -.13886600E+01, 0.41457000E+01, 0.49206500E+01, 0.42746900E+01, 0.16809300E-01, -.50674200E+00, -.64999200E-01, -.11637600E+01, -.14599300E+01, -.35225000E+01, -.32968200E+00, -.77895000E+00, 0.59079100E-01, -.21756500E-01, -.14204400E+01, 0.22480600E+00, 0.90701200E+00, -.12146400E-01, 0.11863400E+00, 0.33924400E+00, -.32088300E+00, 0.79222900E+00, 0.55350800E+00, -.47874800E+00, 0.11914500E+00, 0.63628200E+00, 0.34954300E+00, 0.31902100E+00, 0.44136300E-01, -.30323300E+00, 0.10038400E+01, -.38724900E+00, 0.11967900E-02, -.39606300E+00, 0.12999200E+00, 0.61147900E+00, 0.24685700E+01, 0.17265200E+01, -.18845000E+00, 0.35998300E-01, -.57766500E-01, -.76360800E+00, 0.71911100E+00, 0.15185900E+02, 0.49953000E-01, 0.25810600E+01, 0.95207400E+00, 0.33924800E+00, 0.32069400E+00, 0.90644300E-01, 0.10358500E+00, 0.11872300E+01, -.68237200E+01, 0.14887500E+01, 0.10244300E+02, 0.14414100E+02, 0.19406400E+01, 0.16079600E+00, 0.22841400E+00, -.10857500E+00, 0.90253400E-01, 0.60741800E-01, -.47146900E+01, 0.75915100E-01, -.19180300E+01, 0.13159000E+01, 0.20162200E-01, -.24945200E+01, 0.83544300E+00, -.90831600E+00, 0.41903400E+00, 0.15754700E+00, -.16973100E-01, 0.14579100E+01, -.42214300E+01, -.36523200E+01, -.82114900E+00, 0.19677200E+01, 0.13172400E+01, -.45550700E+00, -.39301100E-01, -.21816100E+00, 0.11579400E+01, 0.34083200E-01, -.15514900E+00, -.25553000E+01, 0.81460300E+00, 0.12011500E+01, -.98699300E+00, 0.52784700E+00, 0.72643100E+00, 0.69988400E+00, 0.64524800E-01, 0.24648900E+02, 0.64926400E-02, -.95278000E-01, -.12681400E+01, -.62306800E+00, -.20069700E+01, -.26334900E+00, 0.31902400E+00, 0.39101600E+00, -.13698200E+01, -.13382700E+00, 0.36138800E+00, 0.20423100E-01, 0.79907300E+00, -.14975900E+01, -.22260800E+01, -.29370300E+00, -.85434200E-01, 0.56488700E-01, 0.15563300E+01, 0.20838900E+01, -.13265800E+00, -.55663600E+00, 0.15969600E-01, -.99106000E+00, 0.35732400E+00, 0.23725800E+00, 0.12540300E+01, -.22566100E+00, 0.36614200E+00, 0.13862100E+01, -.67581400E+00, -.62456700E-01, -.13978400E+00, 0.71594100E-01, 0.59514200E-01, 0.23540700E+01, 0.62594200E+00, -.42628900E+00, -.54845800E+00, 0.85493300E-01, 0.75138300E+00, -.19193600E+00, -.10225900E+00, 0.28052000E-01, 0.39053800E-01, 0.67950100E+00, 0.28152300E+00, 0.50097000E+00, -.15280300E+01, -.16728700E+00, -.33122000E+00, 0.50793100E-01, -.12511700E+02, 0.69434200E+00, -.37007700E+00, -.10866800E+01, 0.31672100E+00, 0.15342600E+01, 0.12531900E+02, 0.21595300E+00, -.74981200E+01, -.31235300E+01, 0.11684900E+01, 0.89922100E+00, -.73437300E+01, -.28399100E+01, 0.49511700E-02, -.21460600E+01, 0.36157600E+00, -.96959800E-01, -.78478700E+01, -.99634700E+01, -.62376200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20120700E+00, -.28208500E+00, 0.11098800E+01, 0.38648000E+00, 0.73265700E+00, -.32227400E-01, 0.33710100E+00, -.13412800E+00, -.70348700E+00, -.64885200E+00, 0.11081700E+00, -.51845300E-01, -.61303800E+00, 0.37020200E-02, 0.32973300E+00, -.77250900E+00, 0.15579200E+01, -.41451300E-01, 0.30673600E+00, -.29793400E+00, -.16681200E-02, -.78522300E-02, 0.17194800E+00, 0.23741400E-01, 0.25315200E+00, 0.51090300E-03, 0.69855900E-01, -.12616100E+00, -.33422100E+00, -.30419000E+00, -.46831600E-01, 0.26915700E+00, -.38877500E+00, 0.55105200E+00, -.10672500E+00, -.22799500E+00, 0.11707400E+00, 0.23663600E+00, -.28841900E+00, -.13694000E+00, 0.75261900E+00, -.50319500E+00, 0.13132200E+00, -.96146900E-01, -.16101800E+01, 0.10951100E+00, 0.78930900E+00, 0.16921100E-01, 0.85198400E+00, 0.11003000E+01, -.27475200E+00, 0.60884500E+00, 0.10381600E+01, -.78998800E-01, -.67088900E+00, -.85230900E-01, 0.13526400E+01, -.45097500E+00, 0.10796700E+00, -.27342600E+00, -.26355300E+00, -.82941500E-01, 0.85052900E+00, -.75708800E-01, -.19205400E+00, 0.38300100E+00, 0.15988600E-01, 0.62865200E+01, -.41591300E-01, 0.43717200E-02, 0.18228400E+00, 0.44683200E+00, 0.20741900E-01, 0.41151000E-01, 0.27352700E+00, -.68269200E+00, -.50208500E+00, -.71600300E+00, -.49541400E-01, 0.96199900E-02, 0.15399700E-01, 0.37677900E+00, -.27544500E+00, 0.14175300E+00, -.26624700E+00, 0.57622200E+00, 0.38040300E-01, -.12750600E+00, 0.34685200E+00, -.19271600E+00, 0.94328900E+00, -.38976400E-01, -.29306100E+00, 0.72595800E-01, -.79774900E-01, -.59681000E+00, 0.29233300E-01, -.16931600E-01, -.24153700E+00, 0.20165900E+00, -.36381900E+00, 0.77985800E-01, 0.32356600E-01, 0.57017700E-01, -.34242100E+00, 0.58104700E-01, 0.10680900E+00, 0.37798500E+00, -.30661900E+00, -.73481600E+00, 0.59506700E-01, -.45992900E+00, 0.32050700E+00, -.30863600E-01, -.16353900E+00, 0.14469000E-01, 0.61909500E-01, -.26214200E+00, -.14215000E-01, -.44458300E-01, -.51763700E+00, -.24634600E-01, -.10293800E+00, 0.46680300E+00, -.13482600E-01, -.14190100E+00, -.26044800E+01, -.13274200E+00, 0.43931400E+00, 0.87057300E+00, 0.49010700E+00, 0.19283400E+00, 0.77431900E-01, 0.18595000E-01, -.64778600E-02, 0.80383600E-01, 0.26138100E+00, -.46154300E-01, 0.11128500E+00, -.14699900E+00, -.44056600E-01, -.93810500E-01, -.20079800E+00, 0.28846200E+00, -.36867900E-01, 0.10556300E-01, 0.73326400E-02, -.31705800E+00, 0.36322800E+00, 0.57973200E+00, 0.37652600E-01, -.29922200E+00, -.13495600E+01, 0.15295200E+00, -.10322400E+01, -.74206500E-02, 0.11076200E-01, 0.28700300E-02, -.93946700E-02, -.37832400E-01, -.17495600E-01, -.11474600E-01, 0.83664700E-02, 0.40317700E-02, -.51034900E-02, -.79502600E-02, 0.98567200E-02, -.17201900E+00, 0.24170400E-02, -.93572500E-03, -.12400200E-02, 0.19939500E-01, 0.67065600E-01, 0.10339700E-01, -.10068700E-01, 0.55612500E-03, 0.15806100E-02, 0.27244400E-03, 0.11232800E-01, -.11822700E-02, -.16355100E-01, 0.77756100E-01, 0.46215000E-01, -.41371500E-01, 0.10161200E-01, 0.71815800E-02, 0.35664000E-01, 0.13793500E-01, -.74849400E-03, -.32777800E-02, -.33257100E-03, -.26605300E-01, 0.23275800E-01, -.80993400E-02, 0.54614200E-02, 0.44310400E-02, -.16760200E-01, 0.44071100E-03, -.30958700E-02, -.19196200E-02, -.23640000E-02, 0.26324900E-04, -.30335100E-02, 0.13071200E-01, 0.43748900E-02, 0.14718500E-02, -.30177300E-02, 0.18610600E-03, -.66934000E-02, 0.11604800E-02, 0.12938700E-02, -.17167600E-01, 0.30761500E-03, 0.39707400E-02, 0.51741800E-03, 0.29618300E-02, -.14629100E-01, 0.10210200E-01, -.26415400E-02, 0.49434800E-02, -.26464200E-01, -.21270900E-01, -.55892900E-03, -.34650800E-01, 0.14616500E-01, -.36674000E-03, -.37950500E-02, 0.17911400E+00, 0.32741500E-02, -.70986000E-01, 0.62872500E-02, -.12294200E-01, 0.32092900E-01, -.75192200E-01, 0.10168900E-01, 0.10664200E-01, 0.12569900E-02, -.15275600E-01, -.38792500E-02, 0.98803200E-02, -.12185500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18949400E+00, -.28434200E+00, 0.96041400E-01, 0.29576100E-01, -.91736200E+00, -.80913500E-01, 0.14807400E+00, -.58819200E-01, -.52750300E+00, 0.75721200E+00, 0.32852800E+00, -.10254000E-02, 0.65021400E+00, 0.36604000E+00, 0.16287200E-01, 0.10244300E+00, -.42881000E+00, -.17101900E+00, -.16966600E+00, 0.18158500E+00, 0.76183100E-01, -.11601800E+00, 0.56653200E+00, 0.68302500E-01, 0.18172900E+00, 0.34429100E-03, 0.16198800E+00, 0.41374300E+00, -.39666600E+00, 0.26858700E+00, -.36430000E+00, 0.29227900E+00, -.23333000E+00, -.17101600E-02, 0.51277500E-01, -.34666300E-01, 0.49483900E-02, -.17023800E-01, 0.40592400E-01, 0.33010400E+00, -.99745400E-01, 0.95668100E-01, 0.64096700E-01, 0.43162200E-01, -.42359000E+00, 0.85843900E-01, -.56398300E+00, 0.10371200E-01, 0.31959500E-01, 0.13662100E+00, 0.40466700E-02, 0.31031500E+00, 0.55485400E+00, -.76588500E-02, 0.22150800E+00, 0.60766900E-02, 0.21676400E+00, -.40948000E-01, 0.37199300E-01, 0.11089200E+00, -.48695900E-01, -.38554700E+00, 0.38937000E+00, 0.75174400E-01, 0.17452000E+00, -.62018200E-01, -.86563800E-02, -.46788700E+00, -.28685700E-02, -.24223000E-02, -.38235400E-01, 0.77522600E-02, -.31471100E-01, -.60770000E-01, -.18967200E-01, -.54313000E-01, -.10763600E+00, 0.26888800E+00, 0.31060900E-01, 0.69707300E-01, -.47315400E-02, 0.79640500E-01, -.92456000E-01, 0.56521900E-01, 0.30778500E-02, 0.49418400E-01, -.34123700E-02, 0.98654500E-02, 0.14058200E-01, -.13539000E+00, -.83145700E+00, -.33922400E-02, -.16830300E+00, 0.13040300E-01, 0.68744600E-01, 0.83970300E-01, 0.12432600E-01, 0.48254600E-01, 0.40183500E-01, 0.26612700E-01, 0.23232300E-01, -.91480900E-01, -.70648900E-02, 0.19106500E-01, 0.66279000E-01, -.34046000E-01, 0.18765100E-01, 0.60597300E-01, -.91944100E-01, -.18635500E+00, 0.13398200E+00, 0.83862600E-01, -.18612400E+00, 0.21109900E-02, 0.82034100E-02, -.27281600E-01, 0.39264500E-01, -.68612000E+00, -.21577800E-01, -.50734500E-01, -.22639300E+00, -.26197400E-01, -.74309100E-01, 0.11949100E+00, -.12437000E-02, 0.13667100E+00, 0.76631100E+00, -.10050100E+00, 0.15483500E+00, -.88036300E+00, -.19905300E+00, -.58462300E-01, 0.25443400E-01, 0.19712800E-01, -.11292100E-01, -.42094600E-01, 0.89049300E-01, -.21622000E-01, 0.16440600E+00, 0.63677600E-02, 0.10980600E-01, 0.71542300E-01, 0.47983200E-02, 0.90093800E-02, 0.23022700E-01, 0.31448700E-02, 0.60807100E-02, -.45941400E-01, 0.33578600E-02, 0.96599900E-01, 0.17234300E-01, -.21945800E+00, -.25107800E+00, -.31766800E-01, 0.76961500E-01, 0.16827100E-01, -.11793500E+00, -.52244800E-02, -.32636600E-01, 0.13372900E+00, 0.56229400E-02, -.10121700E-01, 0.31166400E-01, 0.68299200E-02, -.33058000E-01, 0.35077800E-01, -.99796700E-02, -.11026100E+01, -.95799100E-02, 0.73990500E-01, 0.37852900E-01, -.15904600E-01, 0.46437500E-01, 0.19762600E+00, -.26099100E-01, -.19252300E+00, 0.56883000E-01, 0.18542600E-01, 0.93535600E-01, -.22514200E-02, 0.12783900E+00, -.20379200E+00, -.68960700E-01, 0.15379000E+00, -.21452100E-01, 0.95379200E-02, -.37382900E-01, 0.54791400E-01, 0.94392800E-02, -.11222700E-01, -.52040100E-03, -.79396200E-01, 0.83735300E-01, -.25217900E-01, -.89920500E-02, 0.22027800E-01, -.10534500E-02, -.89079600E-02, 0.16354500E-01, -.28556200E-02, 0.57706500E-02, -.18485300E-02, 0.18819700E-01, -.12567300E+00, -.10140000E-01, -.43458400E-02, 0.73990300E-03, -.16444500E-01, 0.11089200E+00, -.19272100E-01, 0.47640200E-05, 0.75468400E-01, -.19381900E-02, -.21686900E-01, -.36133100E-02, -.25177100E-01, 0.67481600E-01, 0.22668000E-01, 0.25193100E-01, -.12003800E-01, 0.76260200E+00, -.50693000E-01, 0.12321100E-01, 0.99477300E-01, 0.99567600E-02, -.37776900E-01, -.10814800E-01, -.38341300E-01, 0.47293100E+00, 0.77254800E-01, 0.65274100E-02, 0.36867100E-01, 0.13682000E+00, 0.12721600E+00, -.35989900E-02, 0.96443200E-01, 0.54857200E-03, -.45885000E-01, 0.23637600E+00, 0.17971400E-01, 0.32513600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16533700E+01, -.31392000E+01, -.12528200E+02, -.35483700E+01, -.26161100E+01, -.54478500E+00, -.18818900E+00, 0.45215200E+00, 0.22785600E+01, 0.46816500E+01, 0.91629300E+00, 0.47184300E+00, 0.60287500E+01, 0.91354900E+00, -.10046700E+01, 0.34271100E+01, -.58991600E+01, 0.22520200E+00, -.40571300E+01, 0.23569500E+01, 0.25662000E+00, -.39903500E+00, 0.25090000E+01, 0.38740700E+00, -.85784500E+00, -.15693100E-02, 0.96847700E-01, -.82978400E+00, 0.39839300E+01, 0.10373000E+01, -.75859400E+00, -.18366700E+01, 0.14096200E+01, -.34494200E+01, -.19752400E+01, 0.39921800E+00, -.47295200E+00, -.81051000E+00, 0.88599000E+00, 0.10364300E+01, -.43709800E+01, 0.53453500E+01, -.13635000E+01, -.44933100E-01, 0.78369300E+01, 0.38284600E+00, -.48306800E+01, -.14397900E+00, -.53294500E+01, -.65047600E+01, 0.20974900E+01, -.35839000E+01, -.57477800E+01, 0.72906300E+00, 0.34711500E+01, 0.11223500E+01, -.68635200E+01, 0.31790000E+01, -.75891700E+00, 0.20723600E+01, 0.14600500E+01, -.59993000E+00, -.53925800E+01, 0.69184700E+00, 0.10406300E+01, -.24864300E+01, -.26057800E+00, -.38482300E+02, -.32953800E+00, -.42931800E-01, -.14068800E+01, -.24905800E+01, -.98885100E+00, -.99134900E+00, -.35810900E+01, 0.86021300E+00, 0.12340000E+01, 0.50940800E+01, 0.28973900E+00, -.22160100E+00, -.68184800E-01, -.27028400E+01, 0.14405900E+01, -.13355400E+01, 0.58798400E+00, -.20733400E+01, -.57371700E+00, 0.71191400E+00, -.44169700E+00, 0.25333600E+01, -.25827700E+01, 0.30637800E+00, 0.45599800E+01, 0.14885600E+00, 0.14610100E+01, 0.38835500E+01, -.20460900E+01, 0.25509400E+00, 0.71773300E+00, -.28713700E+01, 0.33340000E+01, -.39443000E+00, -.23753800E+00, -.26192900E+00, 0.25303100E+01, -.15318200E+00, -.12884300E+01, -.93312200E+00, 0.24611400E+01, 0.31949100E+01, -.16934900E+01, 0.23935900E+01, -.23018000E+01, 0.35095300E-01, 0.85340600E+00, -.23366200E+01, -.28935300E+00, 0.13707300E+02, -.14144900E+00, 0.76460500E+00, 0.49933700E+01, 0.21209800E+00, 0.55816300E+00, -.24184000E+01, -.40437300E-01, -.24917300E-01, 0.12517500E+02, 0.51866800E+00, -.60273700E+01, 0.11866200E+01, -.25084500E+01, -.94118200E+00, -.12208000E+00, 0.29354100E-01, 0.26343700E+00, -.58553600E-01, -.14473700E+01, 0.12039000E+01, -.24891200E+01, 0.94164200E+00, -.41116900E-01, -.20646100E+01, 0.13650800E+01, -.15815600E+01, 0.39501500E+00, 0.96167900E-02, -.18906300E-01, 0.14404300E+01, -.45303300E+01, -.19834400E+01, -.29639500E+00, -.27789600E+01, 0.28402200E+01, 0.50264800E-02, 0.30972000E+01, -.22909900E+00, 0.32490800E+00, 0.20984100E+00, 0.19445700E+00, -.42650000E+00, -.17181900E+01, -.13814800E+01, 0.62537500E-01, 0.35568400E+00, -.69408800E+00, 0.65659400E+00, 0.13337900E+00, -.13370100E+02, 0.71996100E-01, 0.16967700E+00, -.53785500E+00, 0.97709100E+00, 0.53854600E+01, 0.50364300E+00, -.35196900E+00, 0.34779800E+00, 0.62429900E+00, -.31570900E+00, 0.20947100E-01, -.37102600E-01, -.19266100E+01, 0.56899700E+01, 0.18434900E+01, -.25404900E+01, 0.42585500E+00, 0.47192600E+00, 0.10798400E+01, 0.38146600E+00, 0.39132800E-01, -.10746000E+00, -.45806900E-01, -.50187900E+00, 0.15693200E+01, -.20900500E+00, 0.16013000E+00, 0.98094700E-01, -.68622100E+00, -.68661200E+00, -.24641000E+00, -.13984700E+00, 0.76066300E-02, 0.16353700E-02, 0.13694900E+00, 0.67113800E-01, 0.37840300E+00, -.56428200E+00, 0.85058200E+00, 0.30188200E+00, 0.58779100E+00, 0.23088800E+00, -.18440700E+00, -.11498600E+01, 0.63967800E-01, 0.11481600E+01, 0.54728700E+00, 0.85391500E+00, -.11997000E+01, 0.29705500E+01, -.77035800E+00, 0.13407100E+00, -.18937000E+01, -.77852000E+00, -.92466500E-01, -.76847100E+00, -.27481900E+01, -.39609100E+00, -.22408300E+00, 0.28811900E-01, 0.16145800E+01, -.12369000E+02, -.23030800E+00, -.13524000E+01, 0.62268300E+01, -.11996400E+02, 0.18386600E+00, 0.21903200E+01, 0.88883600E-01, -.10651700E+01, 0.18814900E+00, 0.40653500E+00, 0.19831300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15904700E+01, 0.20883900E+01, 0.10071100E+02, 0.26964200E+01, 0.30747600E+01, -.11515500E+01, 0.35098900E+01, -.61869200E+00, 0.22294200E+01, -.15450800E+01, -.10065900E+01, -.38110000E+00, -.28238600E+00, -.20420900E+01, -.11442800E+01, 0.26312300E+01, -.23506400E+01, -.12424100E+01, 0.22353100E+01, -.17138600E+01, -.14722900E+00, 0.22488900E+00, 0.20068900E+01, 0.31077700E+00, 0.79154500E+00, 0.45382400E-02, 0.31566900E+00, 0.48447100E+00, 0.59620600E+00, -.65995400E+00, -.11465000E+00, 0.31082800E+00, 0.32289500E+00, 0.33248800E-01, -.65663700E+00, -.36831400E+00, -.14155600E+00, -.24105000E+00, 0.12110300E+00, 0.13311100E+01, -.19288600E+01, -.12680700E+01, 0.29237700E+00, 0.31064500E-01, 0.52030300E+00, -.55072200E+00, -.14950200E+01, -.24947700E-01, -.74737200E+00, -.16833400E+01, 0.58634800E+00, 0.90398700E+00, -.20503300E+01, -.16997000E+01, 0.42340600E+00, -.49305600E-01, 0.10764400E+01, -.11979100E+01, 0.11231000E+00, 0.72803800E+00, -.10827500E+01, -.20105000E+00, 0.14694500E+01, 0.94595400E+00, 0.19599600E+01, -.10657600E+01, -.40845700E+00, 0.97908700E+01, 0.18459800E-01, 0.53960700E-01, 0.15743500E+00, 0.76320000E+00, 0.61164000E+00, 0.29065700E+00, -.18926600E+01, 0.23604100E+01, 0.28307000E+00, 0.53673800E+01, 0.32747500E+00, 0.18409800E+00, 0.23677200E-01, -.14475400E+01, 0.17076500E+01, 0.30276500E+00, 0.25114500E+01, -.58198100E+01, 0.12872600E+01, 0.36382500E+00, -.10794600E+01, 0.10853500E+01, -.65409700E+01, 0.10173100E+00, -.10124100E+01, -.56952700E+00, 0.14053800E+00, -.12562900E+01, -.38016600E+01, 0.81402200E+00, -.24184500E+01, -.14220700E+01, 0.10729800E+01, 0.52049600E-01, -.13143600E+00, 0.36675600E+00, 0.26665900E+01, -.74488800E+00, -.11851600E+01, 0.13248500E+01, 0.20578100E+01, -.12319300E+01, -.64446500E+00, 0.18463000E-01, -.64157100E+00, -.13851800E+00, 0.37206700E+00, -.16123600E+01, 0.80614800E-02, 0.11092600E+02, -.29334800E+00, 0.16617900E-01, 0.67682100E+00, -.10863400E+01, -.39896300E+00, -.29224600E+01, -.18062100E+00, 0.39113700E+00, 0.24762900E+02, 0.38326700E+00, -.83090900E+01, 0.17221100E+02, -.73834000E+00, -.18560300E+01, 0.28383000E+00, 0.56789300E+00, 0.98371600E-01, -.37967100E+00, 0.49021600E+00, 0.10389300E+01, -.25192200E+01, 0.90100200E+00, -.78445000E-01, 0.36023100E+00, -.23652700E+00, 0.31288500E+00, -.30097300E+00, -.58606900E-01, -.34830000E-01, 0.22698300E+00, 0.10199800E+01, 0.26590500E+00, 0.35832400E+00, -.33555500E+00, -.76647500E+00, -.10314600E+00, 0.19290700E+01, 0.30749400E+00, -.10788700E+01, 0.12167100E+00, 0.11613400E+01, 0.21588900E+01, -.77835600E+00, -.39962600E+00, -.15942900E+00, -.51649100E+00, -.63721100E+00, -.10996000E+01, 0.63354700E-01, 0.72030000E-01, -.27988300E-01, 0.60227900E+00, -.53164000E+00, -.52958800E-01, 0.27869200E+01, 0.49379700E+00, 0.30600400E+00, -.73126100E+00, 0.25011800E+01, -.37431400E+00, -.11596400E+01, 0.41924700E-01, -.16456700E+01, 0.13856800E+01, -.19401600E+00, -.16988500E+01, 0.19056700E+00, 0.50930600E-01, -.22206900E+01, -.51488200E+00, 0.52753700E+00, -.37400900E+00, 0.19600000E-01, 0.91021600E+00, 0.34588200E+01, -.31515600E+00, -.34470200E+00, 0.40158400E+00, -.25968200E+00, 0.44548900E+00, -.52854900E+00, 0.67341300E-01, -.27524800E+00, 0.65685400E-01, -.15321700E+01, -.56615800E+01, 0.22823800E+01, -.89278500E+00, -.81795500E+00, -.28632100E+00, -.35030300E+00, 0.27214400E+00, 0.75501900E-01, -.31006400E+01, 0.87160400E-01, -.31054000E+00, -.87543200E+00, -.30595600E+00, 0.95735300E+00, 0.44235200E+01, 0.31901700E+00, -.20344800E+00, 0.25565200E+01, 0.10364400E+01, -.17023600E+00, 0.20402000E+01, -.17456400E+00, 0.59010900E+00, 0.19676600E+00, 0.24548400E-01, 0.34992400E+00, -.53380800E-01, -.13642800E+01, -.28022700E+01, 0.82614900E+01, -.59264900E+00, 0.16207800E-01, -.57877800E+01, 0.87358800E-01, 0.34684600E+00, 0.14448400E+00, -.61811400E-01, 0.55042300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19440500E+00, -.12421200E+00, 0.94572700E+00, -.44819800E-01, -.19465100E+01, 0.20066200E+00, 0.51622400E+00, -.74351800E-01, 0.85188300E+00, 0.16540300E+01, -.11441000E+00, -.16163800E-01, 0.63346500E+00, 0.63244800E-02, 0.21516700E+00, 0.61715100E+00, 0.52065100E+00, -.43573600E+00, 0.12254000E+00, -.18464500E+00, 0.48474600E-01, 0.75015600E-01, 0.14717600E+01, 0.11318000E+00, 0.19731900E+00, 0.40030500E-03, 0.18941900E+00, -.11352400E+00, 0.64065300E+00, -.33380800E+00, -.38574000E-01, -.63675900E+00, 0.73264900E-02, -.73692400E-02, -.37390000E+00, 0.39548200E-01, 0.80349200E-01, 0.42351600E-01, -.14895300E+00, -.45211400E+00, 0.15962900E+00, 0.38902800E+00, -.73230800E-01, 0.18870600E-01, -.52393100E+00, 0.15287000E+00, -.57236500E+00, 0.27605000E-01, 0.37709000E+00, -.20431100E+00, 0.11308100E+00, -.39597900E+00, -.55771900E+00, -.20539600E-01, 0.30242700E+00, 0.41502300E-01, -.12144700E+00, 0.10962800E+00, -.66905300E-01, 0.20962000E+00, 0.17875200E+00, 0.17344200E+00, 0.10056000E+01, 0.15764100E+00, -.22339300E+00, -.27602600E+00, -.84737900E-01, 0.54558300E+00, 0.47839500E-01, 0.17665100E-01, -.11641000E+00, -.15296000E+00, -.32944900E-01, -.23995500E-01, -.61186200E+00, 0.56417700E+00, -.40461300E-01, 0.12041100E+01, 0.11691000E+00, -.58381300E-02, 0.27313900E-01, 0.37162900E+00, 0.10425500E+00, 0.56852300E-01, 0.19460200E+00, 0.15933300E+00, 0.17759700E-01, 0.31000900E-01, -.42286500E-01, -.46907300E+00, -.23474400E+01, -.21476400E-01, -.49203600E+00, -.25560800E+00, -.78423500E-01, 0.41885800E-01, -.23399700E+00, 0.30308900E+00, -.61120400E+00, 0.13855200E-01, 0.12019500E+00, -.77473700E-01, -.22703100E-01, 0.96829700E-01, -.53831900E+00, 0.15793300E+00, -.46219400E-01, 0.27290800E+00, 0.18020900E+00, 0.63640100E+00, -.13012300E+00, -.57742400E-01, -.26308300E+00, 0.19832900E-01, 0.62390900E-01, 0.25839600E-01, 0.88267900E-01, -.63560700E+00, 0.24211600E-01, -.19600500E-01, 0.51513400E+00, 0.20691100E+00, -.45369500E-01, 0.54579300E+00, 0.41111800E-01, -.52792500E+00, -.87953600E+00, -.15020000E+00, 0.16872900E+01, -.61874100E+00, -.18274300E+00, -.39889000E-02, -.11252200E+00, 0.10984000E+00, 0.98213100E-02, -.10136800E+00, 0.10838300E+00, 0.37658600E-01, -.33089800E+00, 0.16939200E+00, 0.42675900E-01, 0.24215900E+00, 0.82714500E-02, -.17211500E+00, 0.21031400E-01, -.28943000E-02, 0.10960000E-01, -.48563500E-01, -.53077400E+00, -.44475000E+00, -.26179000E-01, -.97076400E-01, -.25142300E+00, 0.64905700E-01, -.27860300E+00, -.13238500E-01, 0.89722400E-01, 0.24200800E-01, -.85249400E-02, 0.37988300E-01, -.11072400E+00, 0.11124200E-01, -.72424400E-01, 0.42519000E-01, -.44137800E-01, 0.19352900E+00, -.64561700E-01, 0.21079200E+01, -.61698500E-03, -.27319900E+00, -.22057400E-01, -.65904500E-02, -.88702000E-01, 0.12137500E+00, -.10928300E+00, -.51530700E-01, -.17817300E+00, 0.13095600E+00, 0.16651900E+00, -.70627300E-02, 0.60147000E+00, 0.95855100E-01, -.30319600E+00, 0.27887200E+00, -.55077400E-02, 0.30353000E-01, -.39564100E+00, -.21172800E+00, 0.29246000E-01, 0.57685900E-01, -.41811700E-02, -.84011500E-01, -.18450600E+00, -.59528100E-01, -.46612900E-01, -.10113900E-01, 0.36218300E-01, 0.15501100E-02, 0.12464500E+00, 0.90444800E-02, -.35455700E-01, -.27767500E-02, 0.13513800E+00, -.28054400E-01, -.21165600E+00, 0.64969500E-01, -.11379900E+00, -.40078400E-01, 0.29104000E+00, 0.44712100E-01, -.21068000E-01, 0.10931500E+00, 0.48900500E-02, 0.26849800E-01, 0.48445900E-01, 0.26809800E+00, 0.15929600E+00, 0.92407600E+00, -.15744900E+00, 0.13243800E-01, -.14224200E+01, 0.18838700E+00, -.10952100E-01, -.22051300E-01, -.20192800E+00, -.24950100E+00, -.77259200E-02, 0.89175300E-01, -.71646500E-01, 0.90607200E-01, 0.11284500E+00, 0.29044800E+00, -.16571500E+01, -.21677300E+00, 0.48984100E-01, -.81186200E-01, 0.30552100E-01, 0.81261600E-01, -.90651000E-01, -.18106900E+00, 0.72949900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20783400E+00, 0.15825300E+00, 0.56621200E+00, 0.11447100E+00, -.43681500E+00, 0.11591400E+00, 0.19408000E+00, -.10339900E+00, 0.82579000E-01, 0.39734700E+00, 0.36471500E+00, -.46308300E-01, 0.71757300E+00, 0.25954700E+00, -.37468700E-01, 0.25668500E+00, 0.92476700E+00, -.18599500E+00, -.28184200E+00, 0.47468100E+00, 0.10672600E+00, 0.32269600E-01, 0.32779100E+00, 0.16103900E-01, 0.64401500E-01, 0.12399000E-03, 0.22823400E-01, -.22741100E+00, -.17527200E-01, -.30334900E+00, 0.10170100E+00, -.38661700E+00, 0.31180400E-01, 0.27718700E-01, 0.22004700E+00, 0.11606400E+00, 0.29403000E-02, 0.40378200E-01, -.30975500E-01, -.23019200E+00, 0.14259200E+00, 0.18459100E+00, -.39494000E-01, 0.59036000E-01, 0.87253400E-01, 0.34071200E-01, -.33175500E+00, -.26812000E-02, 0.14241600E+00, 0.24777900E-01, 0.36680900E-01, -.96409500E-01, 0.10973500E-01, -.35522700E-01, 0.20969700E+00, -.10131000E+00, 0.73529100E-02, -.12344400E+00, 0.20040600E-01, -.25431900E-01, 0.19030900E+00, 0.26348300E+00, 0.69747800E+00, 0.13887100E-01, -.20442500E+00, -.11385600E-01, 0.31830100E-01, -.12525900E+01, 0.39801600E-01, 0.48307200E-03, -.54849300E-01, -.16534600E+00, -.70382300E-01, 0.18629500E-01, -.14145600E+00, 0.12386500E+00, -.12682800E+00, 0.42988300E+00, 0.36261100E-01, -.15267400E-01, 0.34613600E-02, 0.51533500E-01, 0.99052500E-01, 0.56636700E-01, 0.28859600E-01, 0.82752400E-01, -.12758000E-01, 0.21235900E-01, -.79741200E-01, 0.38013700E-01, -.31646000E+00, 0.64912800E-02, -.12213600E+00, -.71155200E-01, -.47519600E-01, 0.14028200E+00, 0.57237400E-01, 0.70408600E-02, -.28965600E+00, -.47102500E-01, -.14424700E-01, 0.30268300E-01, 0.17500700E-01, 0.53409800E-02, -.11412500E+00, 0.76562300E-01, 0.50657600E-01, 0.58291600E-02, 0.42968200E-01, 0.25862700E+00, -.40292900E+00, 0.51048300E-01, -.15200500E+00, -.66948800E-02, 0.27011600E-01, -.11702700E+00, 0.67113300E-02, -.47607300E+00, 0.29325400E-02, 0.12279700E+00, 0.27747600E+00, 0.73358900E-01, 0.23884700E-02, 0.35451800E+00, 0.10639200E-01, -.11591300E+00, -.12199000E+01, -.88642300E-01, 0.70920800E+00, 0.26122800E+00, -.24723500E+00, 0.72211900E-01, -.14643300E-01, 0.17929100E-01, -.93297900E-03, -.16990300E-01, 0.40650700E+00, -.47625400E-01, 0.73379500E-01, -.12053400E+00, -.76747900E-01, 0.17811400E+00, -.17072200E+00, 0.10007700E+00, -.42448600E-01, 0.17648800E-01, 0.16711300E-01, -.25468700E+00, 0.21806600E+00, 0.36535400E+00, 0.32791700E-01, -.25649200E+00, -.46131500E+00, 0.13049100E+00, -.32368400E+00, 0.26552800E-01, -.11629600E+00, -.13744100E-02, -.80392000E-01, -.47734300E+00, -.99908500E-01, -.94625000E-01, 0.84541000E-01, 0.27038900E-01, -.11083200E+00, 0.11237100E+00, -.66841900E-02, -.21534900E+01, 0.43556200E-02, 0.61286500E-01, -.19091600E+00, 0.20876000E+00, 0.45495500E+00, 0.53094600E-01, -.10320900E+00, -.58936800E-01, 0.29030300E-01, 0.91015300E-02, -.73265700E-02, -.50476700E-03, 0.57179600E-01, 0.78144400E-01, -.56076400E-01, 0.98359900E-01, 0.20380100E-01, -.15232800E-01, -.65788900E-02, 0.10762900E+00, 0.20682100E-01, -.21440300E-01, 0.72567700E-02, -.95672000E-02, 0.19841600E-01, 0.59907200E-02, 0.39987700E-01, -.35956600E-02, 0.13615000E-01, 0.78285000E-01, -.31397500E-01, 0.17870500E-01, -.58453900E-01, 0.68838800E-02, -.54731200E-01, -.95316300E-01, 0.10301300E+00, 0.16995200E-01, -.11516000E+00, -.46656900E-01, 0.16469400E+00, -.21569800E-01, 0.64505000E-02, 0.45409300E+00, -.17117300E-02, -.13325300E+00, -.20626200E-01, 0.14245100E-01, 0.65042500E-01, 0.32043500E+00, -.11111900E-01, -.59103600E-02, 0.19865800E+01, -.95833900E-02, -.37447300E-02, 0.23889200E+00, 0.92175700E-02, -.25475700E-01, 0.11528600E-01, -.44001100E-01, 0.13544400E+00, 0.49526400E-02, -.16779200E-01, 0.73894200E+00, 0.13921100E+01, 0.12350400E+00, -.31760500E-01, -.73248400E-02, 0.51961200E-02, -.20638800E-01, 0.93111000E-01, 0.11698700E+00, -.37187900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17291800E+00, -.41478600E+00, 0.43080500E+00, -.26150200E+00, -.12925800E+01, -.97517400E-01, 0.33783900E+00, -.59452400E-01, 0.15074400E+01, 0.10732600E+01, -.15499000E+00, 0.18945600E-01, 0.83646900E+00, 0.17632000E+00, 0.25031100E+00, 0.29776900E+00, 0.21160500E+00, -.21707300E+00, -.22847400E+00, 0.43857100E+00, 0.19874500E-01, 0.81565900E-01, -.24332500E+00, 0.51651000E-01, -.21500400E+00, -.49633100E-03, -.78175700E-01, -.21745000E+00, 0.64925600E+00, -.33413200E+00, -.78736800E-01, -.36112700E+00, -.96861900E-01, -.32518400E+00, 0.76389300E+00, 0.13678900E+00, -.54326600E-03, -.19744400E+00, -.42991100E-01, -.11498500E+00, -.48236000E+00, -.77633900E-01, -.11232800E-01, -.79030900E-01, 0.12182400E+01, -.17833700E+00, -.52467200E+00, -.16160600E-01, 0.16487000E+00, -.84895700E-01, -.37377400E-01, 0.64739500E-01, 0.39218600E+00, 0.14945500E+00, -.69438500E+00, -.50236500E-01, 0.18026900E+00, 0.38470400E+00, 0.68183500E-02, -.19852600E+00, 0.31117500E+00, -.99401900E-02, 0.18869400E+01, 0.45508200E-01, -.12618000E+00, 0.19008500E+00, 0.12213400E+00, -.18239200E+01, 0.10184900E+00, 0.87860300E-02, -.43847500E-01, -.27029200E+00, -.14985400E+00, 0.84017400E-02, 0.88407100E-01, -.17294100E+00, -.53088000E+00, 0.41898800E+00, -.67810600E-02, 0.10943500E+00, 0.38966900E-02, 0.27116600E+00, 0.83858900E-01, 0.25077700E+00, 0.15245500E-01, -.55956900E+00, 0.46367300E+00, -.60032000E-01, 0.25388200E+00, 0.26130200E+00, 0.10506100E+01, -.14519600E-02, 0.39487700E+00, 0.19010500E+00, 0.33002700E+00, 0.44663900E-01, -.11470000E+00, 0.35300300E+00, -.40484300E+00, 0.17234500E+00, -.19947800E+00, 0.82895600E-01, -.11075800E-01, -.12789700E-02, 0.93564200E+00, 0.59363700E-02, 0.36946800E-01, 0.34414400E+00, -.30118000E-01, -.36108000E+00, -.23413600E+00, 0.67373400E-01, 0.24019000E+00, -.93508200E-02, 0.11271200E-01, 0.22722500E+00, 0.41968400E-01, 0.10362300E+01, -.23170200E-01, 0.73893200E-01, -.36255700E+00, -.19832300E-01, 0.41845200E-01, -.32988900E+00, -.77522800E-01, 0.24008200E+00, 0.33037900E+01, -.11979700E+00, -.14756300E+01, -.19942000E+01, 0.67289000E+00, -.80419800E-01, 0.15093200E+00, -.12443000E+00, -.61752900E-01, 0.82439300E-01, 0.57409700E+00, -.16566500E+00, 0.38038700E+00, -.38360900E+00, 0.28340200E-02, 0.23765200E+00, 0.47811800E-01, 0.20347100E-01, -.11677700E-01, 0.27287000E-02, -.16869300E-01, 0.67920400E-01, 0.48139500E+00, 0.16616200E+00, 0.15557800E-01, 0.38286200E+00, -.64899100E+00, 0.48261200E-01, 0.21398100E+00, -.73157900E-02, -.25999800E+00, 0.17540900E-02, 0.17646300E+00, 0.40772300E+00, 0.12698900E+00, -.23057200E+00, 0.13715500E+00, -.34732700E-01, -.48702000E-01, 0.45444000E+00, 0.61019800E-01, -.31670100E+01, 0.59736000E-02, 0.30580800E+00, -.31965500E+00, 0.97926100E-01, -.15747500E+00, 0.26078500E+00, -.43225700E-02, 0.47860900E-01, -.80369100E-01, -.75579800E-01, 0.19663600E-01, 0.12601100E-01, -.51608300E+00, -.44137200E+00, -.13337500E+00, 0.82159200E-01, -.37184200E-01, -.53782400E-01, 0.28832400E+00, -.28101000E-02, -.16018000E-01, -.64780200E-01, 0.47971400E-02, -.63961900E-01, -.17242100E-01, 0.39675600E-01, 0.11474900E+00, -.30356000E-01, 0.20987800E-01, 0.11879700E+00, 0.45816800E-01, 0.21777600E-01, 0.22057200E-01, 0.21411700E-02, -.37096200E-01, 0.78303600E+00, -.42225400E-01, 0.14340100E+00, -.67660900E-01, -.12261000E-01, -.30750500E+00, -.69082400E-01, 0.16707800E-01, 0.28189100E+00, -.15262200E-01, -.67038400E-01, 0.24612200E-01, -.15101500E+00, 0.14852100E+00, -.63586200E+00, 0.13858000E+00, 0.50281000E-02, 0.46112300E+00, 0.22222400E+00, 0.23797100E-01, 0.36679700E+00, 0.17338000E+00, 0.76367700E-01, 0.54085600E-02, -.12666500E+00, -.16203300E+00, -.61553900E-01, -.77423800E-01, -.39333700E+00, -.40746300E+00, 0.79868500E+00, -.14846600E-02, -.51863400E+00, -.36118000E-01, 0.84437800E-01, 0.52458500E-01, 0.77684900E-02, 0.77345200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.51215200E-01, 0.13661200E+01, 0.43530100E+00, 0.35459400E+00, 0.67751800E-01, 0.27848900E+00, -.24433500E+00, -.60740400E-02, -.71923300E+00, -.59582900E+00, 0.47424400E-02, 0.10870400E+00, -.73065000E+00, 0.16875100E+00, 0.84984900E-01, -.46031600E+00, 0.16328800E+00, 0.70360200E-01, -.10797100E+00, -.91951500E-01, -.18465700E-01, -.52227500E-01, -.59384200E+00, 0.10867200E+00, -.93013500E-01, -.45558100E-03, -.11154500E+00, -.47664600E-01, 0.85711200E-01, 0.76866600E-01, -.74478800E-02, 0.18560600E+00, 0.23532900E-01, -.21582200E-01, 0.80404500E-01, 0.29641700E-01, -.26117100E-01, -.51883900E-01, 0.35440400E-01, 0.28403600E+00, -.39878200E+00, -.14266700E+00, 0.26779900E-01, -.27777600E-01, -.15722100E+00, 0.64130600E-01, -.82288500E-01, 0.20439400E-03, -.40992500E-01, -.10123500E-01, 0.70215000E-01, 0.52966600E-01, 0.17792800E+00, -.21040800E-01, 0.18585800E+00, -.29065600E-01, -.12926500E+00, -.14435100E+00, 0.74418500E-02, -.27848200E-01, -.37757400E-01, 0.54912900E-01, -.12384900E+00, -.10178100E-02, 0.65572200E-01, 0.40628900E-01, 0.56275000E-01, 0.12719900E+01, -.75399700E-02, -.73360900E-02, 0.10295700E+00, 0.11508100E+00, 0.28999000E-01, 0.62480600E-01, -.31505900E-02, 0.16163200E+00, -.11523000E+00, -.67419600E-01, 0.77985000E-02, 0.30856200E-01, 0.18263800E-01, 0.10401800E+00, 0.20150000E-01, -.24801700E-01, 0.10919500E+00, 0.97879500E-01, -.47862300E-02, -.15320500E-02, -.92092100E-01, 0.39894300E+00, -.52756200E+00, 0.22465200E-02, -.27349700E-01, 0.40159600E-01, 0.40740300E-01, 0.38673500E-01, -.78411800E-01, 0.13391700E-01, 0.75624400E-01, -.21833400E-01, 0.32064100E-01, -.38518300E-01, -.83071500E-02, 0.24539300E-01, 0.29263200E-01, -.13086000E-01, -.23563700E-01, 0.29119400E-01, 0.24440300E-01, 0.88907000E-01, 0.14464000E+00, 0.52545900E-01, -.30630500E-01, 0.40522700E-02, -.15205300E-01, 0.97291400E-01, 0.91331300E-03, 0.51351900E-01, 0.24729100E-02, 0.30235400E-01, 0.54283700E-02, 0.13474200E-01, 0.69516000E-02, -.10065000E-01, 0.41296900E-02, 0.47608600E-01, 0.31454000E+00, 0.60633900E-02, 0.82153600E-01, -.13922600E+00, -.11099900E+00, -.34645300E-01, 0.55869600E-02, 0.16652100E-02, -.45578600E-02, -.15035600E-01, -.24286700E+00, 0.34790300E-01, -.21524100E-01, 0.87261700E-01, 0.52909200E-01, -.11072700E+00, 0.59138300E-01, -.11509300E+00, 0.34212700E-01, -.81509500E-03, 0.37827300E-02, -.43008700E-01, -.38394600E-01, -.59684300E-02, 0.11626700E-01, -.48558100E-01, 0.39716800E+00, -.86663700E-02, -.26573800E-01, -.55747800E-03, 0.29581900E-01, 0.17234900E-02, 0.22990100E-02, 0.21901500E-01, 0.90286300E-02, -.86616200E-02, -.65054900E-02, 0.57729200E-02, -.35986800E-02, 0.11821100E-01, -.11391700E-02, 0.13496100E+00, 0.18449100E-02, -.19983500E-02, 0.21242900E-02, -.21640700E-02, -.16071400E-01, 0.68270800E-02, -.26273000E-02, -.71954300E-02, 0.82569700E-03, 0.50890700E-02, 0.39743300E-02, -.65719800E-03, 0.14390700E-01, -.21074700E-02, -.39128800E-01, 0.14268600E-01, 0.33712600E-05, -.19888800E-02, -.26594200E-01, -.22310300E-01, 0.89798100E-03, 0.52651100E-02, 0.70729700E-04, 0.90946500E-02, -.17844500E-01, -.53862600E-03, -.11126600E-01, 0.74165100E-03, 0.63577700E-02, -.45855900E-02, 0.52820900E-02, -.46009800E-03, -.21991900E-03, -.29386700E-03, 0.70935600E-02, 0.88545800E-03, -.11560600E-01, 0.74439400E-02, -.82000200E-02, -.22791500E-02, 0.93951700E-02, 0.26741700E-02, 0.18639800E-02, 0.32646200E-01, 0.15271500E-03, -.66627100E-02, -.18986400E-02, -.19488300E-02, 0.59337800E-02, 0.61047700E-02, -.29880400E-02, -.17570800E-02, 0.74453700E-01, -.28398300E-02, 0.41741400E-02, -.64424300E-02, 0.10295100E+00, -.68187700E-02, 0.12255900E-03, 0.54456100E-01, -.82855100E-02, 0.11483600E-02, -.52165800E-02, -.10582700E-01, -.18322900E-01, -.14029300E-01, 0.36444900E+00, -.36856100E-01, -.79312400E-02, -.12724200E-03, -.19919400E-02, -.25363600E-02, 0.47338300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13586000E+00, 0.19489600E+00, -.50435900E+00, -.37658900E+00, -.12641700E+01, 0.84266200E+00, -.51535500E+00, 0.13939600E-01, -.16302500E+01, -.31221200E+00, 0.31491500E+00, 0.22451700E+00, -.10289800E+01, -.56701900E-01, -.18689300E+00, -.65341600E+00, 0.11632200E+01, -.11956400E+00, -.10417700E+00, -.10371300E+00, 0.59021500E-01, 0.77730900E-02, 0.99649300E+00, 0.30200700E-01, 0.96621900E-01, 0.96455400E-04, 0.11483000E+00, 0.55872400E-02, 0.23001200E+00, -.56344700E-01, 0.88785800E-01, -.16188800E+00, -.31507800E-01, -.96995800E-01, -.29877900E+00, -.53616300E-01, 0.72051700E-01, 0.36310200E-01, -.10065900E+00, 0.20786800E-02, -.19281000E+00, -.50223400E-01, -.33735500E-02, 0.45542000E-01, 0.46184400E-01, 0.18817700E-01, -.38522500E+00, 0.49109300E-01, -.26714500E+00, 0.13787800E-01, -.56662000E-01, 0.37321900E-01, 0.68980200E+00, 0.36423900E+00, 0.84831500E+00, -.24111700E-01, -.13551000E+00, -.16991200E+00, 0.19908000E-01, 0.77265700E-03, 0.15725100E+00, 0.22418600E+00, -.55949800E+00, -.26142600E-01, -.52525700E-01, -.29596400E-02, -.77143000E-01, -.18442800E+01, -.91783100E-01, 0.63075300E-02, -.13179600E+00, -.96625600E-01, -.64923700E-01, -.10420400E+00, -.12862900E+00, -.13420100E+00, 0.14818300E+00, 0.22104900E+00, 0.57933800E-01, 0.14309500E-01, -.21050000E-02, -.92086500E-01, 0.32786000E-01, -.60055600E-01, 0.42714800E-01, 0.48546800E-01, -.18865700E-01, 0.79957800E-02, 0.12606700E-01, 0.22835600E+00, 0.44849500E+00, 0.10977400E-01, 0.18056400E+00, 0.44697200E-01, 0.40734400E-01, 0.70642100E-01, 0.94372500E-01, -.22433400E-01, 0.30729800E+00, -.11920700E+00, 0.48771700E-01, -.10112900E+00, -.40063300E-02, -.34893900E-01, -.63617100E-01, -.27075500E-01, 0.41840600E-02, -.10704000E+00, -.20559900E-01, -.11717000E+00, -.16946000E+00, -.76359800E-01, 0.94356900E-02, 0.71561100E-02, -.39091900E-02, -.13677500E+00, -.40627500E-01, 0.36755800E+01, -.77208000E-01, 0.38235700E+00, 0.61238800E-01, 0.34731900E-01, -.42192900E-01, 0.12265600E+00, -.19655900E-02, -.27150200E+00, 0.22738400E+01, -.13858500E+00, -.72634200E+00, -.41486200E+00, -.53460900E-01, -.16625500E+00, 0.70019500E-01, 0.67448600E-02, 0.57189100E-02, -.28781700E-01, 0.40703600E+00, -.20543800E-01, 0.13736600E+00, -.17894200E+00, -.16905200E-01, 0.30447600E+00, -.43672600E-01, 0.50099100E-01, -.21669000E-01, 0.89251600E-04, 0.52260700E-02, -.89274600E-01, 0.14395700E+00, 0.12609400E+00, 0.22994700E-01, -.39606500E-01, -.11526600E+00, 0.13287200E-01, 0.68390000E-02, 0.20353100E-01, -.57307700E-01, -.56715800E-02, -.14277900E-01, 0.20604000E+00, -.48614000E-01, -.18981300E+00, 0.42032800E-01, 0.34313500E-01, -.12397900E-01, 0.68267600E-01, -.17524300E-01, -.18755200E+00, -.38123000E-02, -.53380100E-02, 0.19958300E+00, -.22006100E-02, 0.27443000E+00, 0.76324300E-01, -.10061800E-01, -.45979300E-01, 0.34542700E-01, 0.27982200E-01, -.21248400E-01, -.49613100E-03, 0.62898000E-02, 0.25092100E-01, -.11267700E+00, -.35202700E-01, 0.11654400E-01, 0.12324300E-01, -.11897000E+00, -.22449300E+00, -.42386600E-02, 0.46732600E-01, -.16935900E-02, 0.78326500E-01, -.11646600E+00, -.11083200E-01, -.92042800E-01, 0.93654500E-02, 0.37736200E-01, -.28610400E-01, 0.45267600E-01, -.86958100E-02, -.65278000E-02, -.48439300E-02, 0.72195500E-01, -.23282600E+00, -.72525700E-01, 0.12376300E-01, 0.50075400E-01, 0.65439700E-03, 0.38233200E-01, 0.17458400E-01, -.56485500E-02, 0.12017900E+00, 0.13493800E-02, -.87956100E-01, -.69311900E-01, -.22489700E-01, 0.55606900E-01, 0.25071600E+00, 0.32132400E-01, -.15834900E-01, 0.14244500E+01, 0.99374800E-02, -.17383500E-02, 0.20590900E+00, 0.53473400E-01, -.21419400E+00, -.11173900E-02, -.19648700E+00, 0.20927300E+00, -.23647500E-01, 0.76880100E-01, -.17426600E+00, 0.30257500E+00, 0.87752500E-01, 0.31286800E-01, 0.91984700E+00, 0.33968700E-01, 0.61884300E-02, -.44104400E-01, -.10472500E+00, 0.80924700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.60623200E-01, -.16972000E-02, 0.12367200E+00, 0.38343900E+00, 0.15524000E+01, -.51599500E+00, -.78523600E+00, 0.37514700E-01, 0.89276500E+00, -.11967100E+01, -.71294300E-01, -.35996000E-02, 0.86657600E-01, 0.65431700E+00, 0.28418600E+00, -.77908500E+00, 0.18104000E-01, 0.11636800E+00, -.29664300E+00, 0.57629200E+00, 0.93151900E-02, -.43307100E-02, -.12888100E+01, -.97429400E-01, -.17494800E+00, -.90813800E-03, -.19318600E+00, -.86940200E-01, -.40590700E+00, -.48712100E-01, 0.50574900E-01, 0.67957400E-01, -.26561400E-01, 0.10315200E-01, 0.77859900E+00, 0.18814900E+00, -.31342700E-01, -.41187300E-01, 0.10211100E-01, -.22309200E-01, 0.94701000E-01, -.17613800E+00, 0.31237000E-01, -.23114100E-01, 0.34999700E+00, -.10794000E+00, 0.76874100E-01, -.37251500E-01, 0.43581400E+00, 0.12181300E+00, 0.17816800E+00, -.45149900E-01, -.66049500E+00, -.17186000E+00, -.25632200E+00, 0.92307700E-01, -.25795300E+00, 0.27766200E+00, -.18154800E-01, 0.12258700E+00, -.15123800E+00, -.32696500E+00, 0.27483000E+00, 0.18271500E-01, -.32230400E+00, -.89468400E-01, 0.75339100E-01, 0.76626200E+00, 0.12094400E+00, 0.37938700E-03, 0.48806400E-01, -.13316900E+00, 0.39217900E-01, 0.49800400E-01, 0.15440500E+00, -.59889700E-02, -.48108700E+00, 0.14947800E+00, -.73392100E-01, 0.15432400E-02, 0.10622700E-01, 0.14475400E+00, 0.80219100E-02, 0.12488200E+00, -.51064400E-01, -.97748200E-01, 0.18048400E+00, -.39248200E-01, 0.21432700E-01, -.13421200E+00, -.57506000E+00, -.21991400E-01, -.28919900E+00, -.91641900E-03, 0.15363900E-01, -.22909500E-01, -.18354300E+00, 0.80162100E-01, -.61172500E+00, 0.34590400E-01, -.32080000E-01, 0.80166700E-01, 0.53074700E-02, -.15452200E-01, 0.22579300E-01, 0.83754000E-01, 0.74932200E-01, -.25747500E+00, 0.20688000E-01, 0.64101200E+00, -.33769300E+00, 0.16490100E+00, -.11950500E+00, 0.24221400E-01, 0.20109800E+00, 0.80653000E-02, -.39059600E-01, -.12639900E+01, 0.58784900E-01, -.14536300E+00, 0.58363200E-01, -.70075000E-01, 0.90646500E-01, -.22404100E+00, 0.43849800E-02, 0.13920300E+00, -.23068400E+01, 0.12617700E+00, -.10678900E+00, 0.67010100E+00, 0.46912700E-01, 0.15026900E+00, -.11683800E+00, -.18482600E-01, -.46537400E-01, 0.24737300E-01, -.14033700E+00, 0.71148000E-02, 0.17469600E+00, 0.15896200E+00, 0.47617900E-01, -.26878900E+00, -.28422000E-01, 0.33133500E-01, 0.14226100E-01, -.22607200E-01, -.26974700E-02, -.73634700E-01, 0.32081300E+00, 0.19930500E+00, 0.46744200E-01, 0.61043200E-01, 0.19935100E+00, 0.26747900E-02, -.27961800E+00, -.10660500E-01, 0.82599200E-01, -.17604200E-01, -.81573400E-01, -.12983700E+00, 0.13618300E+00, 0.14179400E+00, 0.20127600E-01, -.19270200E-01, -.68349500E-01, -.56321100E-01, 0.19342300E-01, 0.41409700E+00, -.28634500E-04, -.13696200E+00, -.11886500E+00, 0.42467800E-01, -.33329300E+00, -.83447300E-02, -.77853000E-01, -.54661800E-01, 0.48485000E-01, 0.72120900E-01, 0.27091000E-01, -.95392700E-03, 0.19592000E+00, -.15700700E-01, -.94337600E-01, 0.13870000E+00, -.40748300E-02, -.33480100E-02, -.53797100E+00, -.14861500E+00, 0.36205200E-01, 0.12153000E-01, -.50409000E-02, 0.64037100E-01, 0.13247400E+00, -.49347000E-01, -.34072100E-01, 0.35763800E-01, -.16416500E-01, 0.18633900E-01, 0.88470500E-01, -.65347500E-02, -.22558400E-03, -.22772100E-02, -.24015400E-02, -.40042600E-01, 0.13190600E-02, 0.99284300E-02, -.64236400E-02, 0.22554700E-02, -.27854300E-01, 0.11700700E-01, 0.10379300E-01, -.43668800E-01, -.22482000E-03, -.46399100E-02, -.15633700E-01, -.30381700E-02, -.47003200E-01, -.10693300E+00, -.10573600E-02, 0.20516600E-01, -.11372800E+00, 0.24038600E+00, 0.70742000E-02, 0.42391200E-01, -.39182900E-01, -.33379200E-01, 0.44237500E-02, 0.76167300E-01, 0.15830500E+00, 0.15536100E-01, 0.19187400E-01, 0.44275400E+00, 0.36257400E+00, 0.20321600E-01, -.51640200E-01, 0.69977000E-01, 0.31048400E+00, -.28998600E-01, 0.33257700E-01, 0.20031100E-01, -.29966500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36340900E+00, 0.35778100E+00, 0.11896600E+01, 0.37674400E+00, 0.77610200E+00, -.67681200E-01, -.73857200E+00, -.15231900E-01, 0.27194600E+00, -.85271700E+00, -.15690100E+00, -.15269500E+00, 0.18560800E-01, -.52193100E+00, -.55485900E-01, 0.32866700E+00, -.74947300E+00, 0.11031900E-02, 0.92574300E-01, -.15878300E+00, -.69502100E-01, 0.29699700E-01, -.81098500E+00, -.68849900E-01, -.41454300E-01, -.30531100E-03, -.10721800E+00, 0.63118300E-02, 0.24435000E-01, 0.24061600E+00, 0.24239100E+00, -.44667500E-01, 0.31346200E+00, 0.12106700E+00, -.21702800E+00, 0.20836700E-01, -.86688200E-01, 0.70103400E-01, 0.11148300E+00, -.24135300E+00, 0.40752700E+00, -.15020700E+00, -.73720600E-01, -.73338500E-01, -.84695300E-01, -.17663700E-01, 0.78597500E+00, -.22376800E-01, -.58083400E-01, 0.74729800E-01, 0.91427700E-01, 0.40612200E-01, -.33345800E+00, -.16648200E+00, -.49302300E+00, -.80355100E-01, 0.56747100E+00, -.45832900E+00, 0.18804500E-01, -.86748700E-01, -.34266300E+00, 0.16445000E-01, -.16323600E+00, 0.56864000E-01, 0.45313100E+00, 0.17891100E-01, 0.51611700E-02, 0.29158000E+01, 0.91778300E-01, -.74795700E-02, 0.21442200E+00, 0.26059500E+00, 0.17636400E+00, 0.14967100E+00, -.11288600E+00, 0.46755900E+00, 0.52958100E+00, -.35780300E+00, -.17211300E-01, -.12428400E+00, 0.37594500E-02, -.17921200E+00, 0.53243600E-01, -.58018500E-01, 0.23010400E-02, -.67276400E-01, -.15279900E+00, 0.23388800E-01, -.32367700E+00, -.74584900E-01, 0.12874300E+00, 0.76264600E-02, -.12479400E+00, 0.10786600E+00, -.72921100E-01, -.19254900E+00, -.14797600E+00, -.22825500E-01, -.86917800E-01, 0.64776800E-01, -.36199300E-01, 0.74399900E-01, -.26726800E-02, 0.42392300E-01, 0.13812800E+00, 0.13447600E-01, -.87109400E-01, 0.27646500E+00, 0.15090000E+00, 0.14455400E+00, 0.49384400E+00, -.56295100E-01, 0.21515800E+00, -.61772700E-02, -.12435500E+00, 0.28308000E+00, 0.97809400E-01, -.15289900E+01, 0.48911000E-01, -.28060200E+00, -.16382400E+00, -.82424700E-01, -.28144400E-01, 0.39471000E-01, 0.36774200E-01, 0.16379500E+00, -.22767200E+01, 0.13199700E+00, 0.11310900E+01, 0.37026500E+00, 0.22047400E+00, 0.15310200E+00, 0.17061600E-01, -.19330000E-01, 0.12667500E-01, 0.18228100E-01, -.60238400E+00, 0.16511100E-01, -.16711600E+00, 0.19925200E+00, 0.10632100E+00, -.16945400E+00, 0.15106200E+00, -.13296900E+00, 0.30148600E-01, -.10295100E-01, -.15203000E-01, 0.29418600E+00, -.58732300E+00, -.52443100E+00, -.70378100E-01, 0.12904500E+00, 0.44070800E+00, -.76504800E-01, 0.12561000E+00, -.27144900E-01, -.90128100E-02, 0.90112300E-03, 0.33712800E-01, 0.30521100E-01, 0.16773500E+00, 0.31393700E+00, -.18095800E+00, 0.63211900E-02, 0.73929000E-01, -.18678700E+00, -.21832400E-01, 0.39182600E+01, -.22353800E-02, -.67048900E-01, -.18619200E+00, -.19421900E+00, -.73493600E+00, -.79453000E-01, 0.60673000E-01, 0.11203000E+00, -.73582400E-01, 0.23449600E-01, 0.57324600E-02, -.26514100E-02, 0.18725600E-01, -.59215900E-01, -.11654200E+00, -.74807400E-01, 0.66507600E-02, 0.34413900E-01, 0.96150700E-01, 0.19919500E+00, 0.75694800E-02, -.48134500E-01, -.37419800E-02, -.38122800E-01, 0.10526400E+00, 0.11271500E-01, 0.81721700E-01, -.72452100E-02, -.34282900E-04, 0.56715500E-01, -.84326000E-01, -.70233700E-02, -.14620200E-01, 0.48529100E-02, -.76839100E-01, -.56661800E-01, 0.25179700E-01, -.11784400E-01, -.11897600E+00, -.18673100E-01, 0.13518800E-01, -.30212700E-01, -.90778800E-02, -.25277400E+00, -.58343600E-03, 0.14028200E+00, 0.86112800E-01, -.12502900E-01, -.31442000E-01, -.61296800E+00, 0.20804300E-01, -.23828800E-01, -.37704700E+01, -.15692300E+00, 0.11858400E-01, -.72012000E+00, -.93219200E-02, 0.11098900E+00, 0.16107400E-01, 0.30195500E-01, -.18011300E+00, -.54942200E-02, 0.55931300E-01, 0.86200900E+00, 0.47079400E+00, 0.14721200E+00, -.96183400E-01, 0.33785500E+00, -.19187000E+00, 0.20454800E+00, 0.21806500E-01, 0.10457500E+00, -.14985400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14580900E+00, -.34460300E+00, 0.18698100E+00, -.77509500E-01, -.69487500E+00, -.23787600E+00, 0.63208500E+00, -.84168200E-01, -.35320700E+00, 0.78117700E+00, 0.35002200E+00, -.87093500E-01, 0.73628100E+00, 0.31993000E+00, -.47209900E-01, 0.22699800E+00, 0.95234900E-02, -.14949700E+00, -.30612500E+00, 0.41296500E+00, 0.84701400E-01, -.34745500E-01, 0.34000500E-01, 0.29722400E-01, 0.43485600E-01, 0.39062300E-03, 0.24886900E-01, 0.12882700E+00, -.21464200E+00, 0.51111100E-01, -.11915100E+00, 0.16205400E+00, -.17483400E+00, 0.40196400E-01, 0.35263700E-01, -.32750500E-01, -.41936300E-02, -.17309700E-01, 0.14790000E-01, 0.76985200E-01, 0.36078000E-01, 0.10430100E+00, 0.16389300E-01, 0.57809800E-02, -.11671300E+00, 0.44678600E-01, -.33128000E+00, -.56933600E-02, 0.15377500E+00, 0.10999100E+00, 0.76442100E-01, 0.16541100E+00, 0.19840700E+00, -.36836400E-01, 0.27478400E+00, -.51736700E-01, 0.94215200E-01, -.14373100E+00, 0.48438800E-01, 0.81770200E-01, 0.11751200E-01, -.19925600E-01, 0.29905300E+00, 0.82771400E-01, 0.12171900E+00, -.67465200E-01, 0.16115800E-01, -.11749500E+01, -.11851600E-01, -.90909800E-03, 0.29318400E-01, 0.41758700E-01, -.31260100E-01, -.14545700E-02, -.16851800E+00, 0.23500300E+00, -.61157600E-02, 0.63104900E+00, 0.44856600E-01, 0.43463400E-01, -.79426100E-03, -.11340800E-01, -.10920100E-01, -.88146000E-01, -.60945100E-01, 0.73120000E-01, 0.32119000E-02, 0.27698300E-01, -.55822500E-01, -.46948300E-01, -.44605300E+00, 0.72775600E-02, -.19414700E-01, -.25552400E-01, 0.23315900E-01, 0.11498100E+00, 0.36629400E-02, 0.40215600E-01, 0.17775500E-01, 0.24591500E-02, 0.19720000E-01, -.55303500E-01, -.27811300E-02, 0.74517100E-01, 0.59153600E-01, 0.46593200E-02, -.32055800E-01, 0.24265700E+00, 0.98583800E-02, -.11045200E+00, 0.24583400E+00, 0.79986800E-01, -.12626200E+00, -.14057900E-01, -.54588400E-01, -.11497800E+00, 0.95923700E-01, 0.46802700E+00, -.20868500E-01, 0.70394000E-01, -.16607700E+00, -.62028700E-01, -.75220600E-01, 0.30586600E+00, 0.14430800E-01, 0.12238500E+00, -.50089300E-01, -.11006400E+00, 0.11110600E+01, -.16086100E+00, -.15318100E+00, -.77620200E-02, 0.55792000E-01, 0.14462900E-01, 0.16145600E-01, -.37081800E-01, 0.18154800E+00, -.64540800E-01, -.19907300E-01, -.34681300E-01, 0.20458700E-01, 0.67678000E-01, 0.23749000E-01, -.17893800E-01, 0.14365700E-01, 0.77540400E-02, 0.61699000E-02, 0.17346700E-02, -.75359600E-01, -.11502700E-01, -.84828500E-02, -.47568800E-01, -.13480300E+00, -.24650700E-01, 0.27430600E-01, 0.29214600E-01, -.15061600E+00, -.16930300E-01, -.94106100E-01, -.23987000E+00, -.67234500E-02, 0.94164800E-01, 0.15982600E-01, 0.77907900E-02, -.25123300E-01, 0.27846100E-01, -.27401200E-01, -.78467100E+00, -.20343600E-01, 0.75673900E-01, -.84095500E-01, -.73777800E-02, -.47683400E-01, 0.51812300E-01, 0.10188200E-01, -.88288500E-01, 0.57642100E-01, -.20907600E-02, -.12108300E-01, -.16550100E-02, 0.11167000E+00, -.24272500E+00, -.10334100E+00, 0.11739600E+00, -.23426400E-01, 0.71450400E-02, -.38360000E-01, 0.54409200E-01, 0.17565800E-01, -.24409200E-01, 0.10515300E-02, 0.11184900E-01, 0.95510900E-01, -.37162000E-01, -.61312600E-01, 0.14079000E-01, -.20373300E-02, -.10022100E+00, 0.18261500E-01, -.81758800E-02, 0.34113200E-01, -.66307700E-02, -.35466400E-02, -.50563800E+00, -.64779100E-02, -.24916700E-01, -.17983900E-01, -.18952200E-01, 0.15555600E+00, 0.19074300E-01, 0.68474000E-03, 0.34404600E-01, -.16194400E-02, -.18477300E-01, -.69713800E-02, -.18882000E-01, 0.64909600E-01, 0.38497400E-01, 0.20277900E-01, -.13881900E-01, 0.76690800E+00, -.16073400E-01, 0.15820900E-01, 0.13592800E+00, -.17295900E-01, -.19240000E-01, -.90568100E-02, -.58245800E-01, 0.49735100E+00, -.86648500E-03, -.23479900E-02, 0.47540700E-01, 0.94582700E-01, 0.16594300E-01, -.47261700E-02, -.71999500E-02, 0.21130700E-01, -.10918800E+00, 0.16980500E+00, 0.97314800E-02, -.17546100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15734400E+00, -.62410800E-01, 0.52926800E+00, 0.40308800E-01, -.10353800E+01, 0.25887500E+00, -.26636600E+00, 0.20134400E-01, 0.10750000E+00, 0.67703600E-01, -.29238800E-01, 0.15081200E+00, -.30787800E+00, -.47730300E-02, 0.59506800E-01, -.16551200E+00, 0.14391700E+00, -.14064500E+00, 0.20213000E+00, -.25726900E+00, -.28128200E-03, -.67780100E-01, 0.59979600E+00, 0.62191200E-01, 0.11497000E+00, 0.12822100E-03, 0.10819000E+00, -.12572300E+00, 0.22592900E+00, -.12233800E+00, -.13483700E+00, -.11917200E+00, 0.96859300E-02, -.40659400E-01, -.44548900E+00, -.41031300E-01, 0.35359000E-01, 0.62056800E-01, -.51641200E-01, -.13066600E+00, 0.14099700E+00, 0.95226300E-01, 0.29959400E-02, 0.44523400E-01, -.61073000E+00, 0.12059600E+00, -.35526300E+00, 0.14623400E-01, 0.26304200E+00, -.50637500E-01, -.12623500E+00, -.14709500E+00, 0.80097000E-01, -.32821200E-01, 0.91596400E-01, 0.26332300E-01, -.14561400E+00, 0.77426200E-01, -.21130800E-01, 0.29118800E-01, 0.90964500E-01, -.89953400E-01, 0.28523500E+00, -.34940100E-01, -.26787500E+00, -.26693600E-01, -.38788300E-01, 0.16724100E+01, -.21068900E-01, 0.74405200E-03, -.17043500E+00, -.10583600E+00, -.23558400E-01, -.54131600E-01, 0.16753900E+00, -.44350300E+00, -.14971800E+00, -.22019800E+00, 0.22400600E-01, 0.37470500E-01, -.61350300E-02, 0.19109600E+00, -.49432200E-01, 0.60330700E-01, 0.36676300E-01, 0.84289200E-01, -.53397800E-01, 0.42687400E-02, 0.20027100E+00, -.88215900E-01, -.21874500E+00, -.29245000E-02, 0.45108400E-02, -.67440600E-01, 0.11424700E-01, 0.29388300E-01, 0.12824300E+00, 0.12302200E-01, 0.11404400E-01, 0.38485200E-01, -.26027300E-01, -.66784200E-01, 0.19941200E-02, -.67494000E-01, -.25485000E+00, -.15447300E-01, 0.66859700E-01, -.20307500E+00, 0.43659000E-01, 0.35307800E+00, -.38917400E+00, -.90115700E-01, -.56589100E-01, 0.22023000E-01, 0.81774900E-01, 0.21607500E+00, -.12927500E+00, -.15918400E+01, -.79589000E-03, -.15280600E+00, 0.17277800E+00, 0.13186000E+00, 0.17486600E-01, -.13068400E+00, -.26770700E-01, -.13272000E+00, 0.11868700E+01, -.55703000E-01, -.13955200E+01, -.27571800E+00, -.16755200E+00, -.61743600E-01, -.54542100E-01, 0.27036300E-01, -.52652100E-03, 0.46270700E-03, 0.16957800E+00, 0.90014600E-01, 0.14285000E+00, -.37323700E-01, -.53167600E-01, 0.10663900E-01, -.60715800E-01, 0.53784400E-01, -.12540000E-01, -.35316700E-02, 0.73359200E-02, -.16225000E+00, 0.26348700E+00, 0.34522800E+00, 0.42333400E-01, -.24283400E+00, -.71660300E-01, 0.58555300E-01, 0.40519400E-01, -.40808100E-02, -.97638300E-01, 0.99271300E-02, -.79208000E-02, -.74427500E-01, -.16015100E+00, -.13058300E+00, 0.10438600E+00, -.32593000E-01, -.87266000E-01, -.11122900E-01, 0.17565900E-01, -.33094700E+01, 0.10299300E-01, 0.52031200E-01, 0.41967600E-01, 0.15379300E+00, 0.52207500E+00, 0.30244000E-01, -.53079500E-01, -.24948100E-01, 0.88080000E-01, -.27213300E-01, -.32405000E-01, 0.15272600E-02, -.13262400E+00, 0.23623800E+00, 0.28186200E+00, 0.68107700E-01, 0.96465100E-02, -.24685100E-01, -.13594700E+00, -.11387300E+00, 0.83003100E-03, 0.33632100E-01, 0.47494800E-02, 0.76008700E-01, -.95464500E-01, 0.17048700E-01, -.64426700E-01, -.10291000E-02, -.19173700E-01, -.74625400E-01, 0.38625400E-01, 0.10762200E-01, 0.35072100E-01, -.19913400E-02, 0.10796900E-01, -.66651200E-01, -.22034200E-01, 0.26210600E-01, -.31154400E-01, -.19135100E-01, 0.58144900E-01, 0.26827000E-01, 0.80293400E-02, 0.12732500E+00, 0.11417900E-03, -.10191200E+00, -.56045300E-01, 0.29925400E-02, -.50925400E-02, 0.25924300E+00, -.12294100E-01, 0.30756300E-01, 0.17965200E+01, -.62155200E-01, -.12103500E-01, 0.16794100E+00, -.88956000E-02, -.88225900E-01, -.48712000E-01, 0.33065900E-01, 0.34954500E-01, 0.20541700E-02, -.33197700E-01, -.23540500E+00, -.15247800E+00, -.63242100E-01, 0.23823500E-01, -.22238900E+00, 0.84628500E-01, -.16714800E+00, -.71276300E-01, 0.15928700E+00, 0.17716200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39984000E+00, -.35106500E+00, -.22082700E+01, -.37269200E+00, -.62359500E+00, 0.21153500E+00, 0.48271800E+00, 0.39568300E-01, -.34552700E+00, 0.95620500E+00, 0.27523600E+00, 0.14838000E+00, -.90441700E-01, 0.36036900E+00, 0.11461100E+00, -.39514600E+00, 0.83448800E+00, 0.24549700E-01, -.19173500E+00, 0.35119000E+00, 0.96004100E-01, 0.11341400E-01, 0.89142400E+00, 0.52396400E-01, 0.55501100E-01, 0.21044000E-03, 0.11369700E+00, -.93550000E-01, -.12659700E+00, -.33820500E+00, -.20294200E+00, -.14838200E+00, -.28951600E+00, -.23457800E-01, 0.62300200E+00, 0.53900800E-01, 0.84086800E-01, -.71462300E-01, -.81921900E-01, 0.24251300E+00, -.46898900E+00, 0.41481700E+00, 0.45005600E-01, 0.13288400E+00, 0.20471600E+00, 0.26315100E-01, -.42733600E+00, 0.85071300E-03, -.38565400E+00, -.15419900E+00, -.10132200E+00, -.77985900E-01, 0.27197000E+00, 0.15331800E+00, 0.36458000E+00, 0.71596600E-01, -.58690100E+00, 0.57176300E+00, -.24205600E-01, 0.80380500E-01, 0.43639800E+00, 0.65634000E-01, 0.21260200E+00, -.56386400E-01, -.42280800E+00, 0.43645600E-02, -.35803600E-02, -.43964400E+01, -.89558000E-01, 0.10372000E-01, -.20127400E+00, -.29421000E+00, -.22206800E+00, -.15692500E+00, 0.65733300E-01, -.28417400E+00, -.41619100E+00, 0.12060900E+00, 0.15713500E-02, 0.62791500E-01, -.15042900E-02, 0.35031200E-01, 0.20363600E-02, 0.11540900E+00, 0.38276100E-01, 0.10040900E+00, 0.80189700E-01, -.19183400E-01, 0.19729100E+00, 0.10333500E+00, 0.79177500E-01, -.43829600E-02, 0.84963600E-01, -.12153200E+00, -.52593300E-02, 0.16748000E+00, 0.25756500E+00, -.75546200E-01, 0.12862200E+00, -.11568800E+00, 0.11657100E+00, -.48703000E-01, 0.15260100E-01, -.32929300E-01, -.83736200E-01, 0.65655500E-03, 0.11034300E+00, -.28357400E+00, -.30169400E+00, -.46152200E+00, -.46688400E+00, 0.17054000E+00, -.31898900E+00, -.20505800E-01, 0.11440200E+00, -.58531100E+00, -.65595700E-01, 0.34893700E+00, -.28485200E-01, 0.25869700E+00, 0.95252600E-01, 0.92954800E-01, 0.71851700E-01, 0.14239900E+00, -.50230300E-01, -.10935300E+00, 0.10293400E+01, -.55368400E-01, -.68295000E+00, -.21142400E+01, -.20242900E+00, -.60749900E-01, -.70910700E-01, -.47917800E-02, -.36539900E-01, 0.12253300E-01, 0.85553500E+00, -.13194800E+00, 0.85423700E-01, -.22596000E+00, -.13233900E+00, 0.18701800E+00, -.17259300E+00, 0.14818700E+00, -.27665300E-01, 0.11280900E-01, 0.12874300E-01, -.31265300E+00, 0.63397000E+00, 0.61700800E+00, 0.58663400E-01, -.11164000E+00, -.40255200E+00, 0.10678200E+00, -.19837100E+00, 0.28405400E-01, -.19119600E-01, 0.46811900E-03, -.77480100E-01, 0.86354400E-01, -.23432400E+00, -.34660900E+00, 0.20003800E+00, -.19042800E-01, -.54033000E-01, 0.15279800E+00, 0.11934200E-01, -.34237200E+01, 0.67515800E-02, 0.27474800E-01, 0.18515700E+00, 0.19155200E+00, 0.84371500E+00, 0.58599200E-01, -.66591700E-01, -.11612800E+00, 0.46611300E-01, -.11030600E-01, 0.54372600E-02, 0.52659900E-03, 0.54623200E-01, 0.12013800E+00, 0.65881200E-01, 0.64253700E-01, -.15192800E-02, -.26716200E-01, -.10168300E+00, -.13348800E+00, -.65067300E-02, 0.50263900E-01, 0.22768600E-02, -.14097800E-01, -.72657200E-01, -.90981800E-02, -.45474200E-01, -.32380400E-02, -.32677200E-02, -.32769200E-01, 0.48609700E-01, 0.79735900E-02, 0.64355700E-02, -.17945800E-02, 0.56206100E-01, 0.37851300E-02, -.63147600E-02, -.91504400E-02, 0.10844000E+00, 0.14118100E-01, 0.23455200E-01, 0.28230800E-01, 0.39554000E-02, 0.20359500E+00, 0.27059300E-02, -.99984300E-01, -.70961200E-01, 0.21154900E-01, 0.44951300E-01, 0.53241300E+00, -.92298900E-02, -.70475300E-02, 0.40281500E+01, 0.24325300E+00, 0.82865200E-02, 0.81213500E+00, 0.14109400E-01, -.50946500E-01, -.36982700E-02, 0.41985300E-02, 0.38655500E-01, 0.36952000E-03, -.12110600E+00, -.11394400E+01, -.54676900E+00, -.29812800E+00, 0.12711200E+00, -.93191100E+00, 0.22848500E+00, 0.27087000E+00, -.42757300E+00, -.15788500E+01, 0.28897800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
    },
    {
        { 0.22556600E+06, -.11564400E+06, 0.26677200E+05, -.11289000E+06, -.40568700E+05, -.16694600E+05, -.27406900E+05, 0.48419300E+05, -.26729700E+05, -.24241600E+05, -.42427500E+05, -.15837500E+05, 0.85003600E+04, -.80856500E+04, 0.79163900E+04, 0.34862900E+04, -.32746900E+03, 0.39559600E+04, -.26894700E+04, 0.11732500E+03, 0.11814900E+04, -.27240000E+04, -.46553700E+05, 0.24481100E+05, -.43027500E+04, 0.23302800E+05, 0.14774300E+04, -.10334000E+05, 0.11507400E+05, -.64744100E+04, 0.10582300E+05, -.57811600E+04, 0.14941000E+04, -.87803200E+05, 0.45438700E+05, -.18816400E+05, 0.43881300E+05, 0.12094700E+05, 0.18410500E+04, 0.11214400E+05, -.25969000E+05, 0.11285200E+04, 0.69400900E+04, 0.10926600E+05, 0.15483700E+06, -.79988700E+05, 0.71778400E+05, -.77500200E+05, -.18141300E+05, 0.23507700E+05, -.38751100E+05, 0.31868100E+05, -.95843700E+04, 0.56792900E+04, -.33531000E+03, 0.92325300E+05, -.47059100E+05, 0.21604900E+05, -.46213100E+05, -.10611900E+05, 0.57697800E+04, -.19492700E+05, 0.83365800E+04, -.26253500E+05, 0.15983300E+03, -.15889300E+05, 0.12456900E+06, -.64403300E+05, 0.19759100E+05, -.62244400E+05, -.19297500E+05, -.51780400E+04, -.14444300E+05, 0.37274300E+05, 0.10806700E+03, -.12107100E+05, -.16186900E+05, -.83987400E+05, 0.43319100E+05, -.19259400E+05, 0.41971900E+05, 0.13162700E+05, 0.12992300E+04, 0.14368500E+05, -.15839600E+05, 0.90617500E+04, 0.54885300E+04, 0.86256400E+04, -.14907300E+06, 0.76638400E+05, -.21322200E+05, 0.74581100E+05, 0.34070100E+05, 0.21797800E+05, 0.13581600E+05, -.29909400E+05, 0.24185000E+05, 0.23277800E+05, 0.29545700E+05, -.10613300E+06, 0.54435600E+05, 0.13227400E+05, 0.53138100E+05, 0.19428600E+05, 0.13467900E+05, 0.71647100E+04, -.34540500E+05, -.53449200E+03, 0.15829800E+05, 0.20646500E+05, 0.14653400E+06, -.76338200E+05, 0.28716900E+05, -.73370300E+05, -.28902300E+05, -.91751000E+04, -.20221000E+05, 0.34624500E+05, -.72830900E+04, -.16085000E+05, -.16533100E+05, -.19429200E+06, 0.10004900E+06, -.52420000E+05, 0.97250400E+05, 0.34563900E+05, 0.10080900E+05, 0.26978900E+05, -.40673900E+05, 0.24058900E+05, 0.17112800E+05, 0.37408200E+05, 0.54925500E+05, -.28325000E+05, 0.16201900E+05, -.27451400E+05, -.74519200E+04, 0.75645200E+03, -.10306100E+05, 0.93878000E+04, -.71305700E+04, -.22920200E+04, -.52231900E+04, -.12966100E+06, 0.66924300E+05, -.62610100E+05, 0.64845100E+05, 0.18031800E+05, -.27328700E+04, 0.23641700E+05, -.14167700E+05, 0.35584000E+05, 0.27241400E+04, 0.33988900E+05, 0.98453700E+05, -.51582700E+05, 0.39732600E+05, -.49252500E+05, 0.79597000E+03, 0.25264500E+05, -.26073100E+05, 0.80439500E+04, -.31370900E+05, 0.15882600E+05, -.24685500E+05, -.45722000E+05, 0.24040700E+05, -.27159700E+04, 0.22932300E+05, 0.64696900E+04, -.65400300E+04, 0.10903100E+05, -.13422800E+05, -.76001200E+04, -.42784200E+03, -.63325700E+04, 0.12430700E+06, -.63943900E+05, 0.13909900E+05, -.62222400E+05, -.19237400E+05, -.10060500E+05, -.10691700E+05, 0.35274900E+05, -.69868000E+04, -.13962900E+05, -.33503800E+05, 0.17331900E+06, -.89445000E+05, 0.50088100E+05, -.86725500E+05, -.42198600E+05, -.27703100E+05, -.14121000E+05, 0.49038700E+05, -.33218500E+04, -.31850200E+05, -.37199500E+05, 0.11924900E+06, -.60393500E+05, 0.52436200E+05, -.59627800E+05, -.26262100E+05, -.15085200E+05, -.14585900E+05, 0.10074500E+05, -.42140700E+05, -.14546000E+05, -.35833200E+05, 0.65288200E+05, -.33635000E+05, 0.51460800E+05, -.32667100E+05, -.72115600E+04, 0.89556400E+04, -.15918800E+05, 0.52197700E+04, -.19464400E+05, 0.40573800E+04, -.14908700E+05, 0.21330400E+06, -.11130800E+06, 0.89359600E+05, -.10680400E+06, -.36297300E+05, -.46464100E+04, -.31225900E+05, 0.51359400E+05, -.21941100E+05, -.15271400E+05, -.29381600E+05, -.13669500E+06, 0.70698300E+05, -.29625500E+05, 0.68329000E+05, 0.26921500E+05, 0.10775500E+05, 0.16437600E+05, -.34916000E+05, 0.84805800E+04, 0.16194400E+05, 0.20418100E+05, 0.12186400E+06, -.61936700E+05, -.13931500E+05, -.61036100E+05, -.26350900E+05, -.21967100E+05, -.59583600E+04, 0.36770700E+05, -.31767200E+04, -.22464200E+05, -.29883300E+05, -.19666800E+06, 0.10011500E+06, -.67072100E+05, 0.98386000E+05, 0.40681500E+05, 0.22901700E+05, 0.23336400E+05, -.23339900E+05, 0.60587500E+05, 0.23712300E+05, 0.50983900E+05, 0.32808000E+05, 0.13152800E+04, 0.12039100E+05, -.26308700E+05, -.19589200E+05, -.15309700E+05, 0.11948800E+05, -.14448100E+05, 0.12496800E+05, -.83565700E+04, 0.17392300E+05, 0.25977200E+05, 0.13681600E+04, 0.14954600E+05, -.95467700E+04, -.24425000E+05, -.14084000E+05, 0.15588200E+05, -.16402500E+05, 0.23374600E+04, 0.17876600E+05, -.22483200E+05, -.13201500E+04, 0.18635700E+05, 0.17801700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.52459500E+01, -.48189900E+05, 0.11134900E+07, -.71974400E+04, -.16975000E+06, -.14707800E+06, 0.12616100E+06, 0.16983000E+06, 0.19162100E+06, -.16556500E+06, 0.12676000E+06, 0.94988100E+05, -.42001200E+05, -.16640500E+06, -.46797400E+05, 0.53558000E+04, -.12084800E+05, -.64995300E+04, 0.15570200E+05, -.40677600E+05, -.57799300E+04, -.65387800E+05, 0.24781600E+06, -.91514700E+05, -.43828800E+06, -.12293300E+06, -.47786300E+04, 0.28041700E+05, -.72693900E+05, -.21891900E+05, -.11773600E+06, 0.43042400E+05, -.11595300E+06, 0.95618400E+05, -.18935900E+05, -.60416000E+06, -.46352200E+05, 0.40439300E+05, 0.93437800E+04, -.36426800E+05, -.43952200E+05, -.13232400E+06, 0.31304600E+05, -.11992900E+06, -.44136100E+06, 0.18417800E+06, 0.16033100E+07, 0.21478200E+06, 0.10681300E+05, 0.22880700E+06, -.67384100E+04, -.10590700E+05, 0.28517500E+06, 0.12964300E+06, 0.36063500E+06, -.28115100E+06, 0.11816600E+06, 0.72577000E+06, 0.13869800E+06, -.54194600E+05, -.66741200E+05, 0.10525100E+06, 0.21722000E+05, 0.12441800E+06, -.66914600E+05, 0.13428100E+06, -.10423100E+06, 0.13738100E+05, 0.78153500E+06, 0.49319800E+05, -.70692700E+05, -.26986500E+05, 0.58253200E+05, 0.81646700E+05, 0.19246700E+06, -.56075700E+05, 0.16017000E+06, 0.19721800E+06, -.73831500E+05, -.58668000E+06, -.98397600E+05, 0.36118400E+05, 0.40854200E+05, -.67185500E+05, -.38636900E+05, -.13610900E+06, 0.51467500E+05, -.13604100E+06, 0.16144700E+06, -.41924300E+05, -.71274100E+06, -.76556700E+05, 0.16688600E+06, 0.22117300E+06, -.16852200E+06, -.10708000E+06, -.15519700E+06, 0.19885800E+06, -.14198200E+06, -.25413400E+06, 0.14304500E+06, -.20559500E+06, 0.13233400E+06, 0.76249600E+05, 0.51045200E+05, 0.63189700E+04, -.91593700E+05, -.36826300E+05, 0.61439200E+05, 0.20608000E+05, -.50160600E+06, 0.19375300E+06, 0.10554800E+07, 0.24431900E+06, -.12022100E+06, -.16072900E+06, 0.19041300E+06, 0.10524500E+06, 0.34498300E+06, -.17002400E+06, 0.34361000E+06, -.24305200E+05, 0.62194800E+05, -.11836600E+07, 0.18807200E+05, 0.12750400E+06, 0.90724200E+05, -.79417800E+05, -.15313500E+06, -.15207000E+06, 0.11751600E+06, -.10772600E+06, -.13898400E+06, 0.53517600E+05, 0.42661600E+06, 0.69368600E+05, -.15632100E+05, -.16328700E+05, 0.41055400E+05, 0.19168900E+05, 0.85294400E+05, -.25396600E+05, 0.91145500E+05, 0.15829700E+06, -.32169000E+05, -.11127600E+07, -.77905700E+05, 0.85609100E+05, 0.99764100E+05, -.10994700E+06, -.77538100E+05, -.98246900E+05, 0.10404000E+06, -.82461400E+05, -.24427000E+06, 0.56844400E+05, 0.10667600E+07, 0.12113000E+06, 0.17000600E+05, 0.10541700E+05, 0.92701300E+05, 0.77281200E+05, 0.11403400E+06, -.28781800E+05, 0.87612600E+05, 0.95590600E+05, -.36218200E+05, -.34277600E+06, -.43222900E+05, -.19222100E+05, -.12744000E+06, 0.26590800E+05, -.15818500E+05, -.10366300E+06, -.79239800E+05, -.12384100E+06, 0.21405900E+06, -.13256500E+06, 0.55144600E+06, -.11224300E+06, -.82247900E+05, -.39965100E+05, 0.24614200E+04, 0.71685200E+05, 0.36332100E+05, -.57149100E+05, -.12947900E+05, 0.83104700E+05, -.76181600E+05, 0.92253900E+06, -.48748200E+05, -.18398300E+06, -.11881200E+06, 0.57843600E+05, 0.11970300E+06, 0.16365500E+06, -.12922400E+06, 0.12373000E+06, -.22008800E+06, 0.89016500E+05, 0.84460900E+06, 0.10992000E+06, -.17807400E+06, -.27040400E+06, 0.19119500E+06, 0.64360000E+05, 0.96586800E+05, -.22306400E+06, 0.75311400E+05, -.13591300E+06, 0.45850800E+05, 0.77775400E+06, 0.67098600E+05, -.27310200E+05, 0.71560700E+04, 0.30004200E+05, -.73493800E+03, 0.60020800E+05, -.94924100E+04, 0.63895700E+05, -.41014000E+06, 0.12493900E+06, 0.17959200E+07, 0.19699200E+06, -.15498200E+06, -.10419000E+06, 0.13245600E+06, 0.54599600E+05, 0.31062100E+06, -.13853300E+06, 0.34813900E+06, 0.11774500E+06, -.17272000E+05, -.82727700E+06, -.55202200E+05, 0.11474300E+06, 0.96721200E+05, -.88351300E+05, -.10195200E+06, -.18861300E+06, 0.10872000E+06, -.16455800E+06, 0.44886900E+06, -.23564100E+06, 0.10986300E+06, -.23066600E+06, -.11124300E+06, -.90840400E+05, -.13151700E+05, 0.13989200E+06, -.10963000E+05, -.92496100E+05, -.11387000E+06, 0.23197500E+06, -.70106400E+05, -.12216300E+07, -.11360300E+06, 0.23798300E+06, 0.35571100E+06, -.25070000E+06, -.10483300E+06, -.11839400E+06, 0.30077600E+06, -.10825500E+06, -.10063100E+05, 0.13333800E+05, 0.16053000E+06, -.47028400E+05, -.74681500E+05, -.15853300E+06, 0.18797800E+05, -.49957100E+05, 0.72996200E+05, -.97909200E+05, -.54255900E+05, 0.17600800E+06, -.19642600E+05, 0.88041800E+05, 0.41199200E+05, 0.53981800E+04, -.21124600E+06, -.44746100E+05, 0.24200000E+05, 0.11943200E+06, 0.70222200E+05, -.64075800E+05, 0.16079500E+05, -.65043000E+05, 0.95185600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16635900E+00, 0.51710200E-01, -.11376200E+06, 0.48353300E+04, -.37475300E+05, -.37583700E+05, 0.77792500E+04, -.45684600E+04, 0.10407200E+05, -.27739800E+05, 0.38248300E+05, -.24513000E+05, 0.12007300E+05, 0.20855200E+05, 0.11760700E+05, 0.34360400E+04, 0.27001600E+04, 0.25207100E+04, -.48273100E+04, 0.59107700E+04, 0.23124400E+04, 0.55295600E+04, 0.26084300E+05, -.12442000E+05, 0.36438500E+05, -.13662600E+05, 0.24805600E+05, 0.22803000E+05, -.65994500E+04, 0.13662900E+05, -.89388200E+04, 0.15929300E+05, -.32607700E+05, -.10152600E+05, 0.51894800E+04, 0.59625900E+05, 0.40166500E+04, 0.15325300E+05, 0.22745200E+05, -.79829900E+04, -.82791600E+04, -.44088500E+04, 0.17315500E+05, -.11124100E+05, 0.32180500E+05, -.15245600E+05, -.17402300E+06, -.12111600E+05, -.55781500E+05, -.72075900E+05, 0.20205600E+05, 0.96333500E+04, 0.17856100E+04, -.55600800E+05, 0.28333700E+05, -.23944400E+05, 0.11668000E+05, -.51636000E+05, 0.13178700E+05, -.22459000E+05, -.22270900E+05, 0.65268100E+04, -.93129100E+04, 0.98337600E+04, -.17398100E+05, 0.35076100E+05, 0.16403300E+05, -.88227100E+04, -.77966300E+05, -.61537600E+04, -.19481400E+05, -.28350800E+05, 0.93767300E+04, 0.10937200E+05, 0.48493800E+04, -.21584400E+05, 0.12769900E+05, -.49276300E+05, 0.23277200E+05, 0.63130400E+05, 0.24437500E+05, 0.10534500E+05, 0.68404800E+04, 0.73031000E+04, -.34784200E+04, 0.12523800E+05, 0.42338600E+04, 0.27984700E+04, -.45238800E+05, 0.22172800E+05, 0.69251900E+05, 0.19779100E+05, 0.10735000E+05, -.45711900E+04, 0.13419400E+05, 0.81617600E+03, 0.93637100E+04, -.48871300E+04, -.72507000E+04, 0.17058000E+04, -.14039600E+04, 0.37161400E+05, -.44116200E+04, 0.14428100E+05, 0.19011600E+05, -.76500900E+04, -.42062000E+04, -.87412800E+04, 0.14875500E+05, -.12438200E+05, 0.40723200E+05, -.19985400E+05, -.10036300E+06, -.16018900E+05, -.37020400E+05, -.29823000E+05, -.60135200E+03, -.46922000E+04, -.68020500E+04, -.21126300E+05, 0.14190900E+05, -.70005100E+04, 0.31555000E+04, 0.12315300E+06, -.95995000E+03, 0.36679600E+05, 0.35906700E+05, -.72721200E+04, 0.64367900E+04, -.71391600E+04, 0.25904000E+05, -.29637700E+05, 0.33357700E+05, -.15578100E+05, -.44865000E+05, -.16565800E+05, -.71327900E+04, -.47718100E+04, -.50570500E+04, 0.23684000E+04, -.83787100E+04, -.29593900E+04, -.14625500E+04, 0.35026500E+05, -.17589200E+05, 0.84443200E+05, -.18352700E+05, 0.27974100E+05, 0.25781700E+05, -.57812700E+04, 0.21394300E+05, -.12438800E+05, 0.18021300E+05, -.42013000E+05, -.99707800E+05, 0.49087400E+05, -.74301200E+05, 0.50496100E+05, -.46959900E+05, -.52501500E+05, 0.23293700E+05, -.32582300E+05, 0.33563100E+05, -.37027500E+05, 0.73950400E+05, -.36692300E+05, 0.17807400E+05, 0.54960400E+05, 0.15283500E+05, 0.16609800E+05, 0.23345700E+05, -.32738700E+04, -.97783800E+04, 0.48581300E+04, 0.17765700E+05, 0.38853400E+04, -.42984600E+05, 0.21760000E+05, -.55191000E+05, 0.25026500E+05, -.23876600E+05, -.35163000E+05, 0.17788800E+05, -.20668500E+04, 0.23453700E+05, -.27077400E+05, 0.31751400E+05, 0.42082300E+05, -.20062800E+05, -.10088700E+06, -.16093100E+05, -.17305900E+05, -.21367900E+05, 0.36446800E+04, 0.12427000E+05, -.27410200E+04, -.16702600E+05, -.39142700E+04, -.22416000E+05, 0.11031600E+05, -.44191400E+05, 0.11286800E+05, -.69343300E+04, 0.14828700E+04, -.38382200E+04, -.14153300E+05, 0.64641000E+04, 0.12218600E+04, 0.32361900E+05, -.29425200E+05, 0.14661200E+05, -.60894700E+05, 0.15262800E+05, -.21302000E+05, -.27015700E+05, 0.11143200E+05, -.75701800E+04, 0.11482500E+05, -.20492400E+05, 0.29376900E+05, -.11750100E+05, 0.59109100E+04, -.16162200E+06, 0.11205900E+05, -.57906500E+05, -.70438400E+05, 0.24224800E+05, 0.67064000E+03, 0.19861200E+05, -.53775400E+05, 0.50152600E+05, -.36520400E+05, 0.18613100E+05, 0.82494800E+05, 0.15628900E+05, 0.16858300E+05, 0.16892800E+05, -.14044400E+04, -.83224800E+04, 0.35001000E+04, 0.12762800E+05, -.50081900E+04, 0.82428200E+04, -.35547500E+04, -.32834900E+05, 0.37933600E+02, -.56034600E+04, -.59264900E+04, 0.16267500E+04, 0.45865700E+04, 0.41711900E+04, -.46186800E+04, 0.57646100E+04, -.52548500E+04, 0.29847900E+04, 0.85460700E+05, 0.10671700E+04, 0.12583700E+05, -.79331500E+04, 0.12788100E+05, 0.14138400E+05, -.32760900E+03, -.75583500E+04, -.36193800E+05, 0.11829200E+03, -.80949500E+04, 0.11071900E+05, -.77041800E+04, -.16871800E+05, -.29335100E+04, 0.15347100E+05, -.18071600E+05, 0.22740000E+05, 0.27026800E+05, -.38570900E+03, -.11945500E+05, -.46543800E+04, 0.23169400E+05, -.17146800E+05, -.14446700E+05, -.97695700E+03, 0.61145500E+04, 0.50889800E+04, -.28602800E+05, 0.36330100E+04, -.14021100E+03, -.20587500E+05, -.80362800E+03, -.27657800E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23102600E-02, -.55440900E-02, -.62756800E-01, -.68086300E+04, 0.69754500E+05, 0.26750300E+05, 0.14084400E+05, 0.65588200E+05, 0.56342700E+05, 0.22033500E+05, -.64093300E+05, -.13194200E+05, 0.58902800E+04, 0.31916000E+04, 0.72693400E+04, -.53225400E+04, 0.35733300E+04, -.36911400E+04, -.13749200E+05, -.81956200E+04, 0.21539300E+04, 0.16939700E+05, -.33515900E+05, 0.18247300E+05, -.78711600E+04, 0.17633000E+05, -.18448800E+05, -.12137300E+05, 0.79813200E+03, -.25029500E+05, 0.28092200E+04, -.85277200E+04, 0.39319500E+05, -.97356500E+05, 0.49741700E+05, 0.15221200E+05, 0.50058200E+05, -.10257100E+05, -.24693600E+04, 0.93338600E+04, -.34318600E+05, 0.27094600E+04, -.21518300E+04, 0.67997000E+05, 0.24163300E+05, -.11696900E+05, 0.39909200E+05, -.17681600E+05, 0.84410300E+05, 0.46978400E+05, -.19241100E+04, 0.58405500E+05, 0.39957500E+05, 0.40786400E+05, -.81535200E+05, -.98800500E+04, 0.38679000E+04, 0.16798900E+05, 0.32078500E+04, 0.33792700E+05, 0.20348500E+05, 0.10379900E+05, 0.31174800E+05, 0.15777500E+05, 0.16687500E+05, -.31953900E+05, 0.11926400E+06, -.60537800E+05, -.16855300E+05, -.62327200E+05, 0.13510100E+05, 0.24510100E+04, -.97447300E+04, 0.43601400E+05, -.36357100E+04, 0.23531500E+04, -.85854000E+05, -.33529600E+05, 0.18362300E+05, 0.37028000E+04, 0.17004900E+05, -.11341900E+05, 0.74120500E+04, -.12978300E+05, -.44469200E+05, -.23957000E+05, 0.66059700E+04, 0.47101000E+05, -.29075900E+04, 0.18791500E+04, 0.27291900E+05, 0.54268800E+04, -.34908700E+05, 0.53329900E+04, -.18729100E+05, -.50069300E+05, -.40881200E+05, 0.43958600E+04, 0.42015500E+05, -.59392000E+05, 0.28616500E+05, 0.23676300E+05, 0.34707500E+05, -.18491200E+05, -.69154100E+04, 0.97934400E+04, -.25965400E+05, -.11273900E+05, -.62921800E+04, 0.46675500E+05, -.67470900E+03, -.60862900E+03, 0.76940700E+04, -.57976500E+04, 0.62922200E+05, 0.21448700E+05, 0.11611700E+05, 0.61160900E+05, 0.49935600E+05, 0.17771000E+05, -.55639600E+05, 0.13363600E+05, -.63552900E+04, -.14556900E+05, -.38430200E+03, -.70947400E+05, -.29325900E+05, -.80709200E+04, -.54440200E+05, -.47031000E+05, -.24881500E+05, 0.48826600E+05, 0.34528600E+05, -.18463800E+05, -.16712600E+04, -.17398900E+05, 0.55558800E+04, -.71407000E+04, 0.85886000E+04, 0.32353200E+05, 0.11820300E+05, -.61470500E+04, -.37736400E+05, -.26102300E+04, 0.29996100E+04, -.15138700E+05, 0.24704300E+04, -.47682000E+05, -.22215200E+05, -.12068000E+05, -.47501300E+05, -.20999600E+05, -.17067300E+05, 0.41509300E+05, 0.73167100E+05, -.40018200E+05, 0.24164400E+05, -.37487200E+05, 0.37448900E+05, 0.31516900E+05, -.41211800E+04, 0.50113500E+05, -.12137400E+05, 0.22265900E+05, -.68351700E+05, -.36871700E+05, 0.17239300E+05, -.14607700E+04, 0.22751700E+05, -.15820100E+05, -.13964800E+04, -.45989300E+04, -.33031500E+05, -.18741900E+05, -.17451700E+04, 0.41981200E+05, 0.11824400E+06, -.58354700E+05, -.36757200E+05, -.64111300E+05, 0.24091800E+05, 0.12572800E+05, -.15495900E+05, 0.42829100E+05, -.14040800E+04, 0.99445400E+04, -.73553300E+05, -.92767100E+03, 0.20196600E+04, -.20877900E+05, -.64780200E+04, 0.62871600E+05, 0.20751300E+05, 0.13786700E+03, 0.41289800E+05, 0.55254400E+05, 0.19582900E+05, -.36213900E+05, -.64608500E+05, 0.31036100E+05, 0.17417800E+04, 0.32191400E+05, 0.41410000E+05, 0.18096400E+05, 0.20831100E+05, 0.27441600E+05, 0.30146100E+05, 0.14924200E+05, -.41807500E+04, -.12566100E+05, 0.52909900E+04, 0.18813700E+05, 0.54958100E+04, 0.37918400E+05, 0.26276900E+05, 0.30832400E+03, 0.16199300E+05, 0.10959000E+05, 0.21520200E+05, -.16656600E+05, 0.69131100E+05, -.34622100E+05, -.35214000E+04, -.42078300E+05, 0.94035600E+05, 0.52349000E+05, -.14357800E+05, 0.66357300E+05, 0.30223900E+05, 0.44923800E+05, -.98510200E+05, -.18557400E+05, 0.97333800E+04, 0.10517500E+04, 0.12850100E+05, -.32485800E+05, -.10583000E+05, -.12726200E+04, -.32038900E+05, -.22819300E+05, -.10202300E+05, 0.43342900E+05, 0.44914600E+04, -.16393800E+04, -.16951500E+05, -.81233600E+04, 0.20256400E+05, 0.41315400E+04, -.56792900E+03, 0.15476000E+05, 0.26325000E+05, 0.39790500E+04, -.19960700E+05, 0.65249300E+05, -.30260600E+05, 0.58952500E+04, -.30405700E+05, -.59040700E+05, -.13125200E+05, -.27971900E+05, -.46600800E+05, -.44742500E+05, -.10315500E+05, 0.23531400E+05, -.37296800E+03, 0.55042800E+04, -.19476100E+05, 0.76008500E+04, 0.45455100E+05, -.12449200E+04, -.85005900E+03, 0.50124900E+05, -.41520700E+05, -.21802100E+05, -.95988800E+04, -.11540200E+04, 0.80926500E+03, -.40550800E+05, 0.31090100E+04, 0.94408900E+04, 0.16392200E+05, -.22099600E+05, -.51091800E+03, 0.15174300E+04, 0.11048900E+05, 0.99790600E+04, 0.47104700E+05, -.19266000E+04, 0.10824200E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.17716500E+00, 0.40198600E-01, 0.53745200E+00, 0.58416900E+00, -.54498700E+05, -.57000000E+05, 0.57241400E+05, 0.41679700E+04, 0.15878100E+05, -.55184200E+05, 0.64368100E+04, 0.45544500E+05, -.22163200E+05, -.19110700E+05, -.22749500E+05, -.10472100E+04, -.43565600E+04, -.42394100E+04, 0.14702500E+05, -.40211000E+04, -.38130400E+04, -.19375500E+05, 0.39850800E+05, -.21362200E+05, -.13679200E+05, -.19932400E+05, -.21453000E+04, 0.27525900E+04, -.68167900E+04, 0.10700200E+05, -.77965500E+04, 0.18587100E+04, -.12714300E+05, 0.51059100E+05, -.26295900E+05, -.67307800E+04, -.25438200E+05, 0.20428500E+05, 0.25002800E+05, -.36451900E+05, 0.60883800E+04, -.21720100E+05, 0.24888500E+05, -.24269300E+05, -.82122800E+05, 0.40369900E+05, 0.16466000E+05, 0.41057000E+05, -.56760900E+05, -.62433800E+05, 0.79037800E+05, -.14655800E+05, 0.29087000E+05, -.57796800E+05, 0.39097500E+05, -.50610100E+05, 0.26255000E+05, 0.17833200E+05, 0.25337600E+05, -.31433200E+04, -.68054900E+04, 0.93586900E+04, -.16709400E+05, 0.94375500E+04, -.37266200E+04, 0.18985100E+05, -.47108400E+05, 0.24548500E+05, -.19294800E+04, 0.23394700E+05, -.32189300E+05, -.40110500E+05, 0.50895400E+05, 0.91186300E+03, 0.33469200E+05, -.39938500E+05, 0.24391100E+05, 0.87689100E+05, -.43970800E+05, -.30256800E+05, -.43805200E+05, 0.46230600E+04, 0.54299800E+04, -.19273900E+05, 0.25569600E+05, -.14345900E+05, 0.50596600E+04, -.37758200E+05, 0.87623700E+05, -.43839100E+05, -.52800000E+05, -.43786500E+05, 0.10984300E+05, 0.54902500E+04, -.18509200E+05, 0.29260200E+05, -.94445500E+04, 0.50592200E+04, -.34932400E+05, -.81914700E+05, 0.42078400E+05, 0.40607500E+05, 0.40960700E+05, 0.56886800E+05, 0.66331000E+05, -.63651200E+05, -.35997800E+05, -.85012500E+04, 0.65741600E+05, 0.25964300E+05, 0.63785500E+05, -.31464600E+05, -.34348400E+05, -.31876600E+05, -.74379600E+05, -.83539400E+05, 0.82032000E+05, 0.28396800E+05, 0.13238200E+05, -.81567100E+05, -.16160300E+05, -.56221000E+05, 0.28077300E+05, 0.32131500E+05, 0.28096900E+05, 0.75000300E+05, 0.82322600E+05, -.80159600E+05, -.27487900E+05, -.13926200E+05, 0.80303600E+05, 0.11918900E+05, -.79708800E+05, 0.39891400E+05, 0.26671600E+05, 0.39832300E+05, 0.16638900E+04, 0.21548800E+04, 0.10119300E+05, -.23419100E+05, 0.11986400E+05, 0.21603900E+04, 0.33997700E+05, 0.48408300E+05, -.25383200E+05, -.13366100E+05, -.24191900E+05, 0.15281200E+05, 0.17644300E+05, -.21686100E+05, 0.12323000E+05, -.13216600E+05, 0.15159600E+05, -.22735100E+05, -.64341600E+05, 0.35062200E+05, 0.80798800E+04, 0.32176200E+05, 0.15136100E+04, -.86504600E+04, 0.11934900E+05, -.16178600E+05, 0.15928600E+05, -.59889100E+04, 0.26463700E+05, 0.80152900E+05, -.38956700E+05, -.29938800E+05, -.40080400E+05, 0.36675800E+04, 0.64335600E+03, -.13526700E+05, 0.25465900E+05, -.92356900E+04, 0.12181600E+04, -.35088300E+05, -.19531300E+05, 0.90566100E+04, 0.26239700E+04, 0.97687400E+04, -.29507700E+05, -.31117600E+05, 0.37994300E+05, 0.26400100E+04, 0.17057100E+05, -.31901400E+05, 0.15215400E+05, 0.11002400E+06, -.56672600E+05, -.47334300E+05, -.55049900E+05, -.99173300E+05, -.10168100E+06, 0.97698000E+05, 0.46432400E+05, 0.11712000E+05, -.10028200E+06, -.26735800E+05, -.12203900E+05, 0.71125100E+04, 0.18125300E+05, 0.61039500E+04, -.91603400E+04, -.72153000E+04, 0.25521200E+04, -.10211000E+05, 0.66413100E+03, -.43941000E+04, 0.33471700E+04, -.21528400E+05, 0.11518300E+05, 0.53751700E+04, 0.10777400E+05, -.12354100E+05, -.13632600E+05, 0.14324500E+05, -.46314500E+04, 0.70674500E+04, -.11415400E+05, 0.89924300E+04, -.99837500E+04, 0.51263400E+04, -.46573400E+04, 0.50133100E+04, -.78877000E+05, -.82484000E+05, 0.94155400E+05, 0.87172200E+04, 0.22355900E+05, -.80976300E+05, 0.11720000E+05, -.46061600E+05, 0.22474000E+05, 0.33957800E+05, 0.23152200E+05, 0.60784900E+05, 0.72499900E+05, -.72672600E+05, -.28602600E+05, -.22187500E+05, 0.70463100E+05, 0.12013400E+05, 0.11493900E+06, -.58317700E+05, -.51026200E+05, -.57450400E+05, -.60734000E+05, -.69668200E+05, 0.59740400E+05, 0.46350500E+05, 0.59729400E+04, -.68700100E+05, -.39180800E+05, 0.74931500E+05, -.39350200E+05, -.49655400E+05, -.37488300E+05, 0.11953000E+05, 0.82771600E+04, -.13809900E+05, 0.28202900E+05, -.93657400E+04, 0.45427400E+04, -.25687300E+05, 0.97981000E+04, -.17543500E+05, 0.39319000E+05, -.14160600E+05, -.30800600E+05, -.19930500E+05, 0.17225900E+05, -.30729000E+05, 0.38748200E+05, 0.29833000E+05, -.68236600E+04, -.13370900E+04, -.11242300E+05, 0.38731800E+05, -.15989000E+05, -.13418900E+05, -.37860000E+05, 0.15099300E+05, 0.17167800E+05, -.14817800E+05, 0.13405100E+05, -.15217600E+05, -.17943500E+05, -.62326000E+04, -.20304400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25411400E+00, -.57052000E-01, 0.75178700E+00, -.17612600E+01, -.21539700E+01, -.12628600E+06, 0.20931100E+06, 0.25434900E+06, 0.37010000E+06, -.14287400E+06, -.10628200E+06, 0.12692800E+06, -.63849600E+05, -.58325100E+05, -.63547000E+05, -.14963100E+05, -.53648700E+04, -.24181100E+05, 0.63839000E+04, -.62620100E+05, -.51498700E+04, -.30652400E+05, 0.60893900E+05, -.28786900E+05, -.10566600E+06, -.30391800E+05, -.52583900E+05, -.16311200E+05, -.27106500E+05, -.37428900E+05, -.41866300E+05, -.79893300E+04, 0.47812500E+05, -.80442100E+05, 0.41224800E+05, -.22224700E+04, 0.39922400E+05, 0.47084000E+05, 0.75244500E+05, -.83329900E+05, -.10452500E+06, -.15884600E+06, 0.81682700E+05, 0.74328500E+05, -.43014500E+06, 0.21317100E+06, 0.33249100E+06, 0.21510100E+06, 0.81655500E+05, -.20557100E+04, 0.20798400E+06, 0.97636800E+05, 0.38697300E+06, -.25654800E+05, 0.54952900E+05, -.26306200E+06, 0.13010600E+06, 0.15572200E+06, 0.13139400E+06, 0.79350500E+05, 0.29201900E+05, 0.68176800E+05, 0.24738900E+05, 0.12015000E+06, 0.26583100E+05, 0.18630300E+05, 0.16971200E+06, -.84762100E+05, -.33574700E+05, -.84301100E+05, -.87465200E+05, -.13174400E+06, 0.12673700E+06, 0.17228900E+06, 0.22910400E+06, -.13930800E+06, -.11832700E+06, 0.22347200E+06, -.10758100E+06, -.10338100E+06, -.11189100E+06, -.77895000E+04, 0.42923000E+05, -.98732300E+05, -.57475600E+05, -.19219200E+06, 0.44347800E+05, -.29198200E+05, 0.29331800E+06, -.14489600E+06, -.62087800E+05, -.14676300E+06, -.37960200E+05, 0.62296800E+05, -.12792400E+06, -.83976500E+05, -.25541300E+06, 0.61746200E+05, -.38636900E+05, -.48121700E+06, 0.23957000E+06, 0.22097300E+06, 0.24057800E+06, 0.13099400E+06, 0.18778900E+06, -.13309200E+06, -.23092400E+06, -.14034000E+06, 0.19141100E+06, 0.21416500E+06, 0.47616900E+05, -.26258700E+05, -.19195100E+05, -.23860300E+05, -.47936200E+05, -.18348400E+06, 0.25723400E+06, 0.27161000E+06, 0.34919400E+06, -.19699600E+06, -.99860500E+05, -.30979500E+04, 0.29903200E+04, -.32889800E+04, 0.15918500E+04, 0.22163000E+05, 0.14320100E+06, -.23469700E+06, -.25083000E+06, -.33022100E+06, 0.16268200E+06, 0.64603000E+05, -.18689100E+06, 0.90202500E+05, 0.95186000E+05, 0.93529000E+05, 0.12977200E+05, -.16485100E+05, 0.59529000E+05, 0.23738900E+05, 0.12356100E+06, -.17220800E+05, 0.31875400E+05, 0.29827400E+06, -.14555300E+06, -.16019400E+06, -.14917000E+06, -.90530500E+05, -.18287800E+05, -.10630800E+06, -.75097800E+05, -.18553200E+06, -.48672200E+04, -.45510400E+05, -.71596800E+05, 0.31071700E+05, 0.19248100E+06, 0.35748700E+05, 0.10621500E+06, 0.57918400E+05, 0.36618900E+05, 0.81666000E+05, 0.55508700E+05, 0.36532100E+05, -.65498800E+05, 0.95357300E+05, -.48250400E+05, -.96327500E+05, -.47659100E+05, -.13100300E+05, 0.49215400E+04, -.50880800E+05, -.48362600E+05, -.14421900E+06, 0.11800200E+05, 0.52536900E+04, 0.33553500E+06, -.16687000E+06, -.11612500E+06, -.16773900E+06, -.52594700E+05, -.86856900E+05, 0.70136700E+05, 0.18449600E+06, 0.14712800E+06, -.10116600E+06, -.15943300E+06, 0.21929200E+06, -.10911100E+06, -.18742800E+06, -.10943100E+06, -.12106100E+06, -.22716100E+06, 0.25733700E+06, 0.29146600E+06, 0.39171100E+06, -.24020100E+06, -.85048100E+05, -.39159600E+06, 0.19374300E+06, 0.97157600E+05, 0.19578800E+06, 0.91764900E+05, 0.24931200E+05, 0.85370500E+05, 0.14325100E+05, 0.15178200E+06, 0.22995900E+05, 0.90403800E+05, -.24376800E+06, 0.11996900E+06, 0.14687300E+06, 0.12182400E+06, 0.81360900E+05, 0.52291100E+05, 0.46188600E+05, 0.49388900E+04, 0.10997100E+06, 0.39385600E+05, 0.55824500E+05, -.13698800E+06, 0.67302900E+05, 0.11860800E+06, 0.68336200E+05, 0.36305500E+05, -.67935100E+05, 0.22599000E+06, 0.20131400E+06, 0.38418200E+06, -.10142000E+06, -.46464100E+05, -.83868000E+05, 0.42091100E+05, 0.60906700E+05, 0.41468800E+05, 0.93412100E+05, 0.17668100E+06, -.20130500E+06, -.19357400E+06, -.26670300E+06, 0.18053300E+06, 0.71550800E+05, 0.47794900E+06, -.23837800E+06, -.27063300E+06, -.23904800E+06, -.14357400E+06, -.21479700E+06, 0.14790600E+06, 0.24985200E+06, 0.17354400E+06, -.21554300E+06, -.20104700E+06, 0.63556300E+06, -.31417700E+06, -.18101600E+06, -.31768300E+06, -.12824000E+06, -.44032800E+04, -.14817100E+06, -.14105700E+05, -.26152500E+06, -.40844600E+04, -.14013000E+06, 0.95751200E+04, -.11218800E+05, 0.78199000E+05, -.10378700E+05, 0.30975500E+05, -.74904600E+05, 0.37771200E+05, 0.61765500E+05, 0.18384200E+05, 0.18859600E+05, -.88444400E+05, 0.17534000E+05, -.50979100E+05, 0.18041000E+05, -.33577600E+05, 0.44111700E+03, -.68470200E+05, -.58739100E+05, 0.57025700E+05, -.33851400E+05, 0.79863200E+05, -.31593400E+05, 0.86490000E+05, -.66144600E+05, -.26777800E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33832300E-01, -.73647900E-01, 0.72160300E+00, 0.63296100E+00, -.70010600E+00, -.62407800E+00, 0.10964900E+06, 0.11537300E+06, 0.20324900E+06, -.29130800E+05, 0.23239200E+04, 0.17721800E+06, -.87293100E+05, -.76728300E+05, -.88631600E+05, -.13104000E+05, -.20288300E+05, -.18614500E+05, 0.33139100E+05, -.55158900E+05, -.16859000E+05, -.71675400E+05, -.69432200E+05, 0.32026400E+05, -.53399400E+05, 0.34748500E+05, -.53575400E+05, -.69939200E+05, 0.23743200E+05, -.23327600E+05, 0.24929100E+05, -.55912400E+05, 0.59308000E+05, 0.47648500E+05, -.24785800E+05, -.38153000E+05, -.23883500E+05, 0.24662800E+05, -.51979800E+04, -.52971400E+05, -.32060500E+05, -.11420400E+06, 0.11553900E+05, -.27558300E+05, -.41984200E+06, 0.20645800E+06, 0.35052700E+06, 0.20993600E+06, 0.52983700E+05, 0.10265500E+06, 0.12450000E+06, -.75942800E+04, 0.25617300E+06, 0.63431700E+05, 0.17001800E+06, -.79526500E+05, 0.41217800E+05, 0.76510400E+05, 0.39716300E+05, 0.69490700E+05, 0.86606600E+05, -.37468900E+04, 0.62918500E+03, 0.25944600E+05, 0.78396100E+05, 0.89197900E+04, -.19154500E+04, 0.30204200E+04, 0.17340400E+05, 0.10900700E+04, -.54414000E+05, -.21122400E+05, 0.81903300E+05, 0.71984600E+05, 0.16714900E+06, -.42203100E+05, 0.15685600E+05, 0.28523400E+06, -.14034300E+06, -.10889800E+06, -.14266500E+06, -.14707200E+05, -.30637700E+05, -.52277800E+05, 0.22779100E+05, -.13399200E+06, -.20069700E+05, -.11961400E+06, 0.35097800E+06, -.17470100E+06, -.55779300E+05, -.17552400E+06, -.33860500E+05, -.21398000E+05, -.69744400E+05, 0.21072500E+05, -.17262500E+06, -.13187900E+05, -.14148900E+06, -.32989600E+06, 0.16691600E+06, 0.14980600E+06, 0.16492900E+06, 0.10918400E+06, 0.12417900E+06, -.11564300E+06, -.15400600E+06, -.84837500E+05, 0.13493600E+06, 0.11919200E+06, 0.42041000E+05, -.21377800E+05, -.34750800E+05, -.21030200E+05, -.49619400E+05, -.59438800E+05, 0.16486500E+06, 0.14494300E+06, 0.20527700E+06, -.86427300E+05, -.26260100E+04, 0.17482500E+05, -.79001600E+04, 0.48932200E+04, -.87338200E+04, 0.28561800E+05, 0.28711700E+05, -.15102400E+06, -.12690700E+06, -.20751200E+06, 0.62202600E+05, -.31077400E+05, -.23749800E+06, 0.11682100E+06, 0.97649200E+05, 0.11877300E+06, 0.17616500E+05, 0.34718100E+05, 0.28604100E+05, -.31209400E+05, 0.90609600E+05, 0.27102000E+05, 0.98196300E+05, 0.18973500E+06, -.95689800E+05, -.84071000E+05, -.94869500E+05, -.82009200E+05, -.10775800E+06, -.23743900E+05, -.13282200E+05, -.97378600E+05, -.83066700E+05, -.66988300E+05, 0.17254500E+06, -.81655400E+05, 0.97252900E+05, -.86303700E+05, 0.11151800E+06, 0.15780000E+06, -.60511200E+05, 0.52979400E+05, -.61043700E+05, 0.12481000E+06, -.11184100E+06, 0.19942700E+06, -.97168400E+05, -.16108000E+06, -.99705500E+05, -.15088800E+05, -.34601200E+05, -.31796400E+05, 0.20797200E+05, -.10273100E+06, -.21001400E+05, -.77112400E+05, 0.16460400E+06, -.83399800E+05, -.43324800E+05, -.82270300E+05, -.23684300E+05, 0.45923500E+02, 0.43733100E+05, 0.93630800E+05, 0.88963100E+05, -.24666500E+05, -.57317000E+05, -.45642500E+05, 0.18892900E+05, -.10026900E+06, 0.22924500E+05, -.11739800E+06, -.13011900E+06, 0.22260600E+06, 0.14601000E+06, 0.31248900E+06, -.15581600E+06, 0.86169200E+05, -.21692000E+06, 0.10965900E+06, -.35609600E+05, 0.10845600E+06, 0.77878300E+05, 0.88566200E+05, 0.90155300E+04, -.14057600E+05, 0.76420200E+05, 0.79767600E+05, 0.87752400E+05, -.13299300E+06, 0.67029700E+05, 0.90660000E+05, 0.66474000E+05, 0.68515400E+05, 0.98885900E+05, -.10602300E+04, -.87246200E+04, 0.54964600E+05, 0.78847600E+05, 0.50669400E+05, -.16733700E+06, 0.83146100E+05, 0.91191900E+05, 0.83578900E+05, 0.32846900E+05, 0.95628500E+05, 0.12755500E+06, 0.73779300E+05, 0.23950400E+06, 0.39188300E+05, 0.88986300E+05, -.40041700E+04, 0.96272400E+03, 0.47726000E+05, 0.18647000E+04, 0.80568300E+05, 0.80029700E+05, -.14634000E+06, -.10403700E+06, -.19021600E+06, 0.95885600E+05, -.26849000E+05, 0.33229400E+06, -.16776100E+06, -.20098500E+06, -.16617000E+06, -.12580000E+06, -.16191100E+06, 0.13073600E+06, 0.17287000E+06, 0.11541600E+06, -.16698800E+06, -.11335200E+06, 0.47300000E+06, -.23903000E+06, -.41144000E+05, -.23646400E+06, -.10227200E+06, -.96368700E+05, -.47825500E+05, 0.58839400E+05, -.15695700E+06, -.87353500E+05, -.18011900E+06, 0.97170400E+04, 0.15610900E+05, 0.24493900E+05, 0.16625900E+05, 0.51907600E+03, -.12763200E+05, -.22220500E+05, 0.21657900E+05, 0.26851900E+05, -.71776200E+04, -.59113200E+05, 0.18652300E+05, -.29368800E+05, 0.19031400E+05, -.66134800E+04, 0.21626500E+05, -.22952200E+05, -.22715000E+05, 0.22863400E+05, 0.18950900E+05, 0.30029700E+05, -.36980100E+05, 0.43644900E+05, -.44399600E+05, 0.21781700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.85266000E+01, -.14830800E+00, -.83602500E+01, -.46596500E+01, 0.66519800E+01, 0.14351000E+01, -.30668100E+01, 0.50859800E+06, 0.75705400E+06, -.30584300E+05, 0.51112700E+06, -.80556300E+05, 0.39527000E+05, -.15474600E+05, 0.39966000E+05, 0.69393500E+04, -.39885100E+04, 0.56410900E+04, -.95795700E+05, -.11839200E+06, 0.65570600E+04, -.40498800E+05, -.65750800E+05, 0.32820500E+05, 0.25195700E+05, 0.33047100E+05, 0.10217800E+06, 0.47057300E+05, -.21173000E+05, -.91640300E+05, -.83592100E+05, 0.47110100E+05, -.17112000E+06, -.35941600E+06, 0.18443200E+06, -.69801000E+04, 0.17854400E+06, 0.68790800E+05, -.19630500E+04, 0.78704000E+05, -.30556500E+06, -.32011200E+06, 0.17349500E+05, -.12410200E+06, -.94646800E+06, 0.46995300E+06, 0.67300400E+06, 0.47332600E+06, 0.18255800E+06, 0.34875600E+06, -.11924200E+06, 0.26198700E+06, 0.99710900E+06, 0.24659800E+06, 0.10515600E+07, -.24839600E+06, 0.12289000E+06, 0.19601800E+06, 0.12370700E+06, -.44142700E+05, 0.16738000E+05, 0.92726300E+05, 0.15253300E+06, 0.22954300E+06, 0.70938600E+03, 0.34485800E+06, 0.47218900E+06, -.24447700E+06, 0.19819700E+05, -.23397900E+06, -.10685700E+06, -.54568900E+04, -.92393500E+05, 0.41828500E+06, 0.43135500E+06, -.31868000E+05, 0.17816100E+06, -.32714800E+06, 0.15997800E+06, 0.83928500E+04, 0.16300400E+06, 0.55089600E+05, -.64837500E+04, 0.19448100E+05, -.31841800E+06, -.29964100E+06, 0.17889100E+05, -.11670000E+06, -.39092000E+06, 0.19073700E+06, 0.24391900E+06, 0.19508300E+06, 0.80111200E+05, 0.81574600E+05, -.46267100E+05, -.42787200E+06, -.40467200E+06, 0.95697800E+05, -.19065500E+06, -.43836200E+06, 0.21516300E+06, 0.23296300E+06, 0.21908800E+06, -.22548400E+05, -.31412900E+05, 0.21949100E+06, -.24149900E+06, -.26329700E+06, -.27887400E+05, -.28922100E+05, -.62058900E+06, 0.31303500E+06, 0.34186700E+06, 0.31009200E+06, 0.13608400E+06, 0.18923900E+06, -.11167400E+06, 0.28677300E+06, 0.78263500E+06, 0.15034500E+06, 0.68921600E+06, 0.56158400E+06, -.28192600E+06, -.31742200E+06, -.28062300E+06, -.16129500E+06, -.21262500E+06, 0.13991100E+06, -.27341900E+06, -.75082900E+06, -.16656600E+06, -.68154900E+06, 0.28229900E+06, -.13836500E+06, 0.61079500E+04, -.14083700E+06, -.54022100E+05, -.68523700E+04, -.67667900E+04, 0.22487300E+06, 0.17909000E+06, -.22741200E+05, 0.51546500E+05, 0.56041200E+06, -.28247500E+06, -.38573300E+06, -.28034400E+06, -.17370100E+05, -.74568600E+05, -.68077600E+05, -.11034000E+06, -.40684100E+06, -.45985200E+05, -.47358100E+06, -.27468700E+06, 0.13960300E+06, 0.28413800E+06, 0.13719300E+06, -.14015200E+06, -.50694500E+05, 0.11095300E+06, 0.12616800E+06, 0.21060900E+06, -.53616500E+05, 0.33440700E+06, -.25377400E+06, 0.12600800E+06, 0.59737800E+05, 0.12695400E+06, 0.53624400E+05, 0.27396600E+05, -.12134700E+05, -.31052900E+06, -.36546100E+06, 0.50312300E+05, -.10626200E+06, 0.49334500E+06, -.24438700E+06, -.21308900E+06, -.24661100E+06, -.98262400E+05, -.11824800E+06, -.60724200E+05, 0.32121900E+06, 0.34826300E+06, -.11425900E+06, 0.14937900E+04, -.65649700E+06, 0.33047300E+06, 0.29255600E+06, 0.32896300E+06, 0.28394100E+06, 0.27730300E+06, -.21437600E+06, 0.26325100E+06, 0.92313700E+06, 0.21775200E+06, 0.62214700E+06, -.66022300E+06, 0.32903700E+06, 0.24766000E+06, 0.33007900E+06, 0.42435100E+05, 0.63005300E+05, 0.14479000E+06, 0.80410900E+05, 0.28985700E+06, 0.45563300E+05, 0.47906500E+06, -.68552400E+06, 0.34088900E+06, 0.38650600E+06, 0.34255100E+06, 0.78206300E+05, 0.13122600E+06, 0.27779900E+05, -.32051100E+05, 0.31603900E+06, 0.99091600E+05, 0.46874000E+06, -.86949200E+06, 0.43460400E+06, 0.50996300E+06, 0.43425000E+06, 0.15378200E+06, 0.24741100E+06, -.15853300E+06, 0.29211100E+06, 0.10393200E+07, 0.18665000E+06, 0.10576500E+07, 0.18985500E+06, -.90762300E+05, -.23579700E+06, -.96644500E+05, -.79980600E+05, -.18822000E+06, 0.16474000E+06, -.25678700E+06, -.51063900E+06, -.14509800E+06, -.46503600E+06, 0.40338400E+06, -.19874700E+06, -.25528800E+06, -.20196600E+06, 0.59212300E+05, 0.45456200E+05, -.20102000E+06, 0.23632200E+06, 0.26679800E+06, 0.36460000E+05, 0.12336700E+05, 0.36672000E+06, -.18317300E+06, -.14253800E+06, -.18300900E+06, -.16239900E+05, -.52317800E+05, -.11114000E+06, -.22651100E+06, -.36639800E+06, -.22487200E+05, -.54963900E+06, -.87667800E+05, 0.13420100E+06, -.11017400E+05, 0.81657500E+05, 0.92607600E+05, -.60272800E+05, -.24967800E+05, 0.16064200E+06, -.82518200E+04, -.15923300E+06, -.17126300E+06, 0.13170800E+06, -.29897700E+05, -.12928800E+05, -.14171400E+05, 0.51308400E+05, 0.72025500E+05, -.20867700E+06, -.17167500E+05, 0.16715400E+05, 0.97208100E+05, -.85296700E+04, 0.12405900E+06, -.14810200E+06, 0.76725800E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.83031500E+00, -.40915800E-01, -.83576700E+00, -.66356800E+00, -.32817000E+00, 0.35393200E+00, 0.59799800E+00, 0.15228100E+00, -.30570800E+06, 0.37119500E+05, -.14425300E+06, -.17423400E+06, 0.85681700E+05, 0.79839200E+05, 0.87205100E+05, 0.10051500E+05, 0.23710100E+05, 0.50199600E+04, -.42784100E+05, 0.77214700E+05, 0.17418800E+05, 0.94429700E+05, 0.30264900E+05, -.11967800E+05, 0.95946600E+05, -.15205600E+05, 0.32303500E+05, 0.43996800E+05, -.29187200E+05, -.19398300E+05, -.37478000E+03, 0.32302400E+05, -.25341000E+04, -.11977300E+06, 0.60111500E+05, 0.97922100E+05, 0.60185700E+05, -.25866900E+05, 0.58778900E+04, 0.32469800E+05, 0.21493000E+05, 0.21487700E+06, -.16403600E+05, 0.10035200E+06, 0.74891200E+06, -.36952500E+06, -.58874500E+06, -.37449200E+06, -.99729700E+05, -.18181000E+06, -.20139400E+05, 0.16537600E+06, -.45947900E+06, -.11883200E+06, -.44994300E+06, 0.95356400E+05, -.49107000E+05, -.11131200E+06, -.47524900E+05, -.50830200E+05, -.64278000E+05, 0.57154300E+05, 0.11872700E+06, -.30626400E+05, -.55939500E+05, -.82524000E+05, 0.74961800E+05, -.38401400E+05, -.87372500E+05, -.38055600E+05, 0.59643500E+05, 0.20676300E+05, -.47431200E+05, -.52830400E+05, -.29245200E+06, 0.49609600E+05, -.10768200E+06, -.25459000E+06, 0.12501800E+06, 0.10973400E+06, 0.12746500E+06, 0.11395200E+03, 0.29884900E+05, 0.22722000E+04, -.69598200E+05, 0.18241000E+06, 0.14183600E+05, 0.17831400E+06, -.31608200E+06, 0.15786000E+06, -.53105400E+04, 0.15815700E+06, 0.17788400E+05, 0.27656500E+04, 0.21373300E+05, -.77767600E+05, 0.24039800E+06, -.84490000E+04, 0.21749600E+06, 0.30130700E+06, -.15222100E+06, -.14081000E+06, -.15061200E+06, -.91866200E+05, -.10956400E+06, 0.71494400E+05, 0.16775000E+06, 0.16480000E+06, -.12123400E+06, -.72380000E+05, 0.14127300E+06, -.70584800E+05, -.50250000E+05, -.70584900E+05, 0.17621500E+05, 0.19120600E+05, -.47090400E+05, -.10880700E+04, -.33524400E+06, 0.54238100E+05, -.19178900E+06, -.17361700E+06, 0.85925800E+05, 0.71070400E+05, 0.86766500E+05, 0.10593600E+05, 0.32201800E+05, 0.29887800E+05, 0.46138600E+04, 0.33039000E+06, -.15603500E+05, 0.22744000E+06, 0.20918600E+06, -.10262400E+06, -.99968700E+05, -.10468300E+06, -.31238600E+04, -.31985600E+05, 0.32493300E+04, 0.62337100E+05, -.12078700E+06, -.20798800E+05, -.13488100E+06, -.29858300E+06, 0.15050400E+06, 0.14939900E+06, 0.14932100E+06, 0.74054400E+05, 0.11564100E+06, -.41338500E+05, -.12420200E+06, 0.14718700E+06, 0.85624200E+05, 0.20585300E+06, -.12922300E+06, 0.58874700E+05, -.19079700E+06, 0.64679300E+05, -.82101300E+05, -.12843700E+06, 0.10035700E+06, 0.63356100E+05, 0.50359600E+05, -.96318300E+05, 0.35314400E+05, -.11098900E+06, 0.52598800E+05, 0.14655500E+06, 0.55471600E+05, 0.33012700E+04, 0.39897800E+05, -.13496500E+05, -.29548500E+05, 0.14376800E+06, 0.18729200E+05, 0.10451400E+06, -.11871600E+06, 0.60211300E+05, 0.13974300E+05, 0.59307700E+05, 0.36391300E+05, 0.21850400E+05, -.37672000E+05, -.10753900E+06, -.19708600E+06, 0.46497700E+05, -.39788200E+04, 0.31408500E+06, -.15273700E+06, 0.14617000E+05, -.15730800E+06, 0.43800400E+05, 0.45713100E+05, -.12375200E+06, -.69130800E+05, -.51261100E+06, 0.88548900E+05, -.28640200E+06, 0.32641100E+06, -.16432400E+06, 0.41405800E+05, -.16319400E+06, -.72287300E+05, -.74653900E+05, 0.47833700E+05, 0.17539100E+06, -.95947500E+05, -.64118300E+05, -.21476400E+06, 0.31830700E+06, -.15933500E+06, -.19599300E+06, -.15908500E+06, -.83510000E+05, -.11820500E+06, 0.25054800E+05, 0.99310800E+05, -.12222700E+06, -.90426500E+05, -.17601400E+06, 0.66506100E+06, -.33178400E+06, -.32997600E+06, -.33232400E+06, -.81727700E+05, -.14300700E+06, -.59654900E+05, 0.72628100E+05, -.52058400E+06, -.71890500E+05, -.43299500E+06, -.15036100E+06, 0.75643700E+05, 0.36801400E+05, 0.75684000E+05, -.47089200E+05, -.34923000E+05, 0.67385600E+05, 0.28285400E+05, 0.30523600E+06, -.61919800E+05, 0.16311500E+06, -.36141400E+06, 0.18205900E+06, 0.23371700E+06, 0.18078800E+06, 0.10375700E+06, 0.13957400E+06, -.75905000E+05, -.19038600E+06, -.17485100E+06, 0.14774800E+06, 0.88046700E+05, -.60486100E+06, 0.30523400E+06, 0.39488600E+05, 0.30231700E+06, 0.97869700E+05, 0.87740800E+05, -.19023800E+05, -.23998800E+06, 0.21102600E+06, 0.75167400E+05, 0.34955100E+06, 0.15677100E+05, -.46850600E+05, -.13682300E+04, -.26161900E+05, 0.17004400E+05, -.50810000E+04, 0.71322700E+05, -.22565000E+05, -.22476900E+05, 0.19895900E+05, 0.87734200E+05, -.52898000E+05, 0.70613600E+05, -.86217800E+04, -.36655600E+05, -.40947500E+05, -.53496000E+04, 0.54880100E+05, -.99933000E+04, -.60379500E+05, -.19925700E+04, 0.65285300E+05, -.37690500E+05, 0.76854800E+05, -.30237400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.82958000E-01, -.12424100E+00, 0.84422700E+00, 0.77462500E+00, -.79509100E+00, -.81111900E+00, 0.12670400E+01, 0.26343600E-01, -.26595000E-04, -.14329000E+05, -.17077000E+05, -.27545200E+04, 0.14062100E+04, 0.39370600E+04, 0.13812400E+04, 0.40384100E+03, -.10357300E+04, 0.13372300E+04, 0.38113000E+03, 0.15341800E+04, 0.76424400E+03, 0.17251800E+04, 0.16047700E+05, -.80554400E+04, -.12843400E+05, -.80264000E+04, -.15422500E+04, 0.39529300E+04, -.55276000E+04, -.22789100E+04, -.87594100E+04, 0.89556700E+04, 0.22668500E+04, 0.76588600E+04, -.38815700E+04, -.17127400E+04, -.38150100E+04, -.46773300E+03, -.27471000E+03, -.44500200E+03, 0.36700700E+04, -.89310300E+03, 0.57469500E+04, 0.55993700E+04, 0.36187300E+05, -.18150900E+05, -.14943300E+05, -.18095000E+05, -.28626700E+04, 0.26233800E+04, -.62206900E+04, 0.46031800E+04, -.88930600E+04, -.14924600E+05, -.31976000E+05, 0.13075900E+05, -.65187200E+04, -.66616800E+04, -.65314500E+04, -.20558200E+04, -.96697900E+03, -.26992900E+04, 0.29514300E+04, 0.25134400E+04, -.12641600E+05, -.15326100E+05, -.70418300E+04, 0.36348100E+04, 0.78628200E+03, 0.34942700E+04, 0.38431900E+03, 0.87862500E+03, -.38875600E+03, -.50908700E+04, -.96281000E+02, -.75648600E+04, -.85758600E+04, 0.91288200E+03, -.36103000E+03, 0.31421500E+04, -.44901900E+03, -.87620500E+03, 0.18502000E+03, 0.23136100E+03, -.11001000E+03, -.28692600E+03, 0.75483100E+04, 0.10557600E+05, 0.40397000E+04, -.19412400E+04, 0.38438400E+04, -.20148900E+04, -.75460300E+03, -.35952900E+03, 0.51759000E+03, -.10368700E+04, -.26655900E+04, 0.10721100E+05, 0.95372200E+04, 0.40867400E+04, -.19850200E+04, -.32342100E+04, -.20419500E+04, -.61758400E+03, -.13095500E+04, -.13397900E+04, 0.31214500E+04, 0.31029400E+04, 0.15975000E+04, 0.36465800E+04, -.17140900E+04, 0.80976700E+03, -.15965700E+04, 0.85953700E+03, -.13411500E+04, -.50175100E+04, 0.47132300E+04, 0.29896300E+04, 0.23425800E+04, -.17052700E+05, -.16062800E+05, -.26808900E+04, 0.13744100E+04, 0.23970400E+04, 0.13383800E+04, 0.12716700E+04, 0.21771600E+04, -.20141200E+04, -.14551400E+04, 0.30892700E+03, 0.13997100E+05, 0.15760500E+05, -.14015700E+04, 0.62201200E+03, -.25585200E+04, 0.69676100E+03, 0.78398400E+03, 0.19559300E+03, -.33488200E+03, 0.10889600E+02, 0.67790800E+03, -.49849900E+04, -.67811100E+04, -.62825600E+04, 0.31833000E+04, 0.53128900E+04, 0.31428900E+04, 0.80706400E+03, 0.22562700E+04, -.69201300E+03, -.66806200E+04, -.46740000E+04, 0.13864500E+05, 0.12377500E+05, -.98558100E+04, 0.49462600E+04, 0.13815200E+05, 0.49302100E+04, 0.20414900E+04, -.43844100E+04, 0.50581400E+04, 0.56076200E+04, 0.10305700E+05, -.14597300E+05, -.88722600E+04, -.74421800E+04, 0.37765400E+04, 0.13145300E+02, 0.37201700E+04, -.88952000E+03, -.40460900E+04, 0.34903000E+04, 0.19473700E+04, 0.67542500E+04, -.18486300E+03, 0.75650800E+04, -.23488100E+04, 0.11450500E+04, 0.37260100E+04, 0.11731200E+04, 0.14783100E+04, 0.32841900E+04, -.13159000E+04, -.31349100E+04, -.30769200E+04, -.20381700E+04, -.45162800E+04, 0.21340300E+05, -.10748200E+05, -.16272900E+05, -.10680200E+05, -.34724000E+04, 0.13878300E+04, -.36097900E+04, -.12300900E+04, -.11343100E+05, -.71162900E+04, -.16370700E+05, -.21158600E+04, 0.10603000E+04, -.52848600E+04, 0.10583700E+04, -.31816100E+04, -.44796900E+04, 0.62114700E+03, 0.14363600E+04, 0.89911700E+04, -.15203500E+05, -.10401600E+05, 0.87551800E+04, -.43698600E+04, -.43592100E+04, -.43747600E+04, -.19062600E+04, -.14162200E+04, -.12966600E+04, 0.17222300E+04, 0.13003800E+04, -.84277500E+04, -.10994500E+05, -.17034700E+05, 0.84995700E+04, 0.62946300E+04, 0.85247000E+04, -.16431700E+04, -.59897300E+04, 0.68667200E+04, -.98256700E+03, 0.76799000E+04, -.20654300E+05, -.15844700E+05, -.29124900E+04, 0.13980900E+04, 0.56612500E+04, 0.14784100E+04, 0.21730400E+04, 0.20299400E+04, -.46316400E+03, 0.18127500E+04, 0.10331700E+04, 0.11093000E+05, 0.12870900E+05, -.32852800E+04, 0.15981100E+04, 0.17472000E+04, 0.16461900E+04, 0.35169600E+02, 0.11681900E+04, 0.99651700E+03, -.30795200E+04, -.37921300E+04, -.95479800E+03, -.27138400E+04, 0.65098600E+03, -.33074600E+03, 0.11047600E+05, -.33018200E+03, 0.16313000E+04, 0.37023200E+04, -.97995400E+03, -.68631500E+04, -.11598200E+05, 0.20927000E+05, 0.14371000E+05, 0.34375900E+03, -.12996500E+03, -.40936400E+03, -.44487000E+04, -.20514800E+04, 0.92367700E+03, -.42005000E+03, -.17150100E+04, 0.25105200E+04, 0.38345300E+04, 0.13476600E+04, 0.16605300E+04, 0.25177500E+04, 0.24298900E+04, 0.15237600E+04, -.85512800E+03, 0.15807600E+03, 0.12641900E+04, 0.20612100E+04, -.39096900E+04, 0.29743200E+04, -.30943000E+04, -.21528400E+03, 0.10294900E+04, -.44372100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13841000E+01, 0.49820700E-01, 0.98172000E+00, 0.74934100E+00, -.12990500E+01, -.82969000E-01, 0.45669800E+00, -.70980200E-01, -.83083300E-01, 0.10306200E+01, 0.84574400E+05, 0.26430700E+05, -.11938200E+05, -.25687500E+05, -.13198600E+05, -.56881400E+03, -.39100700E+04, -.13226900E+04, 0.59466800E+04, -.34805300E+04, -.29516800E+04, -.22651600E+05, -.21394200E+05, 0.74444200E+04, 0.15059900E+05, 0.10699300E+05, 0.87875900E+02, -.69158800E+04, 0.88730200E+04, 0.40033700E+04, 0.97074700E+04, -.80421900E+04, -.13640600E+05, -.61971700E+04, 0.16954900E+04, -.30902500E+05, 0.31744600E+04, 0.86343700E+04, 0.24650900E+04, 0.14223900E+04, 0.19864000E+04, 0.49835000E+04, 0.25928400E+04, -.43842100E+05, -.79087200E+05, 0.38047200E+05, 0.55090300E+05, 0.39543400E+05, -.11558000E+05, -.10770600E+04, 0.10402000E+05, -.60737000E+04, 0.32846800E+05, -.29768300E+04, 0.13412700E+06, -.99595000E+04, 0.70891800E+04, 0.11389000E+05, 0.49994900E+04, 0.12534300E+05, 0.48360400E+04, -.17836600E+04, -.31812300E+04, -.21032000E+04, 0.98267200E+04, 0.25756400E+05, 0.17370200E+05, -.70736600E+04, 0.35918100E+05, -.88094600E+04, -.13220000E+05, -.64299300E+04, -.12668700E+04, 0.18906400E+04, -.37924200E+04, -.59875600E+04, 0.56259800E+05, 0.32614100E+05, -.16993800E+05, -.49616000E+05, -.16280900E+05, 0.20682100E+04, -.47721800E+04, -.40015900E+03, 0.10119800E+05, -.15007100E+04, -.57524600E+04, -.54825200E+05, 0.28586400E+05, -.14799600E+05, -.25111100E+05, -.14277400E+05, -.10267000E+05, -.72701600E+04, 0.24833500E+04, 0.14663400E+05, 0.27995400E+04, -.90786200E+04, -.64212100E+05, -.24738500E+05, 0.14653600E+05, 0.13501800E+05, 0.12367100E+05, 0.16381800E+05, 0.13314000E+05, -.84548500E+04, -.10758300E+05, 0.17605200E+04, 0.14961500E+05, -.36659400E+05, 0.35934700E+04, -.54034000E+03, 0.12996900E+05, -.17830600E+04, -.76188700E+04, -.47412800E+03, 0.26801500E+04, -.19072900E+04, -.16410300E+02, -.11342700E+04, 0.73114700E+05, -.60918900E+04, 0.28065700E+04, -.10148800E+05, 0.30342300E+04, 0.76006000E+04, 0.58440400E+04, -.58333900E+04, -.40302800E+04, -.85097800E+04, 0.61323100E+04, -.74951800E+05, -.23692300E+05, 0.12252700E+05, 0.42474600E+05, 0.11830600E+05, -.12460100E+04, 0.35651200E+04, 0.14502500E+03, -.76423000E+04, 0.44352400E+02, 0.45259300E+04, 0.36414300E+05, 0.13756400E+05, -.98716500E+04, -.31634400E+05, -.68662000E+04, -.12441800E+05, -.95503200E+04, 0.35420200E+04, 0.84635800E+04, 0.28514100E+04, -.12648100E+05, -.35716500E+05, 0.28738300E+05, -.76031400E+04, -.11492100E+05, -.14372600E+05, 0.68237700E+04, 0.13730000E+05, -.15952100E+05, -.13575800E+05, -.19014300E+05, 0.17280200E+05, 0.11549000E+05, 0.56633300E+05, -.25947800E+05, -.25599800E+05, -.28318300E+05, 0.57757200E+04, -.42922400E+04, -.41293100E+04, 0.90067500E+04, -.14597400E+05, -.16190500E+04, -.62878700E+05, -.67523300E+04, 0.19017900E+04, 0.13546000E+05, 0.33884200E+04, -.61536300E+04, -.23190200E+04, 0.34479300E+04, -.20454000E+04, -.25818800E+04, -.35393100E+04, 0.44788300E+05, -.33873000E+05, 0.13416400E+05, 0.33247000E+05, 0.16927800E+05, -.10660400E+05, -.10703800E+05, 0.15893800E+05, 0.25663200E+04, 0.18327900E+05, -.14945300E+05, 0.91915400E+05, -.86196300E+04, 0.66263900E+04, 0.15936100E+05, 0.43108000E+04, 0.28798700E+05, 0.83430900E+04, -.22019200E+04, -.27598300E+04, -.24925400E+04, 0.14176700E+05, 0.15680000E+05, -.29035400E+05, 0.16193600E+05, 0.21098200E+05, 0.14524700E+05, 0.10715400E+05, 0.62728400E+04, 0.41726000E+03, -.48733600E+04, 0.87224600E+04, 0.79896800E+04, 0.30387900E+05, 0.95721700E+04, -.43796000E+04, 0.30268700E+05, -.47898600E+04, -.84891800E+04, 0.15703200E+04, -.43028400E+03, 0.23648200E+04, 0.34987200E+04, -.22590100E+04, 0.10355800E+06, -.24015300E+05, 0.11047900E+05, -.18959400E+05, 0.12092000E+05, 0.12523800E+05, 0.10477500E+05, -.33118500E+04, -.73677500E+04, -.32932400E+04, 0.99178200E+04, -.54713400E+05, 0.28754900E+05, -.16126400E+05, -.23789900E+05, -.14364500E+05, -.12711300E+05, -.14379400E+05, 0.86032600E+04, 0.14523000E+05, 0.27610100E+03, -.15766100E+05, 0.31792900E+05, 0.39723500E+04, -.63609300E+04, -.28364600E+05, -.19986500E+04, -.30030800E+05, -.94119700E+04, 0.69350300E+04, 0.11238700E+05, 0.95571300E+04, -.16278500E+05, -.41459800E+05, 0.11699700E+04, -.23105300E+04, 0.10140400E+05, 0.53174900E+04, -.70022800E+04, -.28931100E+04, -.12016800E+04, -.84865400E+04, 0.26242300E+04, -.45439800E+04, -.23056900E+04, 0.79576900E+04, 0.13290700E+03, 0.20916300E+04, 0.21036500E+04, 0.20639100E+04, -.10767800E+05, 0.63279900E+04, -.33970000E+04, 0.75393500E+04, 0.10165100E+04, -.29418000E+04, -.51127500E+04, -.20889800E+04, 0.66057500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11303100E+01, 0.74769200E-01, 0.21439300E+01, -.63654000E+00, -.17819600E+00, 0.25375200E+00, 0.24080700E+00, 0.33379500E-01, 0.25434000E+00, 0.21379500E+00, -.83368700E+00, 0.48135000E+05, -.22240700E+05, -.20859800E+05, -.24096600E+05, 0.16080700E+04, -.14756600E+04, -.48232300E+04, 0.97925800E+04, -.12640500E+05, -.12796800E+04, -.19811600E+05, -.45629200E+04, -.21919800E+04, -.17146500E+05, 0.23081900E+04, -.23005300E+05, -.16953000E+05, 0.52010700E+04, -.12686300E+04, 0.39654000E+04, -.15379700E+05, 0.22146400E+05, 0.65204000E+05, -.34495100E+05, -.25419500E+05, -.32697400E+05, 0.17568500E+04, -.27005800E+04, -.62514100E+04, 0.13139100E+05, -.21804600E+05, -.14364700E+04, -.32463400E+05, -.97039800E+05, 0.46138500E+05, 0.67273400E+05, 0.48532800E+05, -.14519900E+05, -.34012200E+04, 0.16165700E+05, -.11924100E+05, 0.38626900E+05, -.31280800E+04, 0.40449400E+05, -.42186800E+05, 0.23983800E+05, 0.26529900E+05, 0.21041200E+05, 0.23498800E+05, 0.94620300E+04, 0.12392700E+04, -.11629900E+05, 0.86767300E+04, 0.14877600E+05, -.73953300E+04, -.78605700E+05, 0.42062900E+05, 0.28142000E+05, 0.39490000E+05, -.45775500E+04, -.56519800E+03, 0.86379000E+04, -.12826200E+05, 0.32310700E+05, -.13011800E+04, 0.41959500E+05, 0.11534400E+06, -.57158100E+05, -.48801400E+05, -.57728700E+05, -.42387200E+02, 0.36157800E+04, -.15687200E+05, 0.19517200E+05, -.33213100E+05, 0.13113200E+04, -.47584900E+05, 0.11623000E+06, -.58108700E+05, -.38704800E+05, -.58154200E+05, -.73038700E+04, 0.38713800E+04, -.14739600E+05, 0.24832600E+05, -.29638500E+05, -.27839400E+03, -.43349900E+05, -.25463200E+05, 0.16174700E+05, 0.83548900E+04, 0.12716200E+05, 0.10678300E+05, 0.60226600E+04, -.37688400E+04, -.10425200E+05, 0.52701100E+04, 0.85160500E+04, -.12767700E+04, -.20118900E+04, 0.21291000E+04, -.16968500E+04, 0.98948900E+03, -.59253500E+04, -.39214800E+04, 0.46988900E+04, 0.41917400E+04, 0.51148500E+04, -.55225700E+04, 0.32546700E+04, -.37513100E+04, 0.18980800E+04, 0.47808300E+04, 0.18889700E+04, 0.95672600E+04, 0.66419500E+04, -.78335700E+04, -.12594100E+05, -.14235700E+05, 0.89696800E+04, -.73137000E+04, -.98282400E+05, 0.48610200E+05, 0.41036300E+05, 0.49171000E+05, 0.20678600E+04, 0.22002700E+03, 0.11839600E+05, -.17300800E+05, 0.28087700E+05, 0.15991000E+04, 0.40271300E+05, 0.53112400E+05, -.30025800E+05, -.23824300E+05, -.26564700E+05, -.22869600E+05, -.19258900E+05, -.78243700E+03, 0.59834600E+04, -.16150400E+05, -.18981100E+05, -.10666500E+05, 0.29880400E+05, -.61494200E+04, 0.13133000E+05, -.14965100E+05, 0.45890500E+05, 0.38994000E+05, -.17976700E+05, 0.12971500E+04, -.15130400E+05, 0.35247000E+05, -.39295800E+05, 0.49916000E+05, -.21535900E+05, -.29576000E+05, -.24949900E+05, 0.87234000E+04, -.33232400E+03, -.39591900E+04, 0.11044100E+05, -.12008500E+05, 0.11130000E+04, -.30533800E+05, 0.15453900E+05, -.98601600E+04, 0.28442600E+04, -.77069400E+04, 0.36972500E+04, 0.15823200E+05, -.51609400E+04, 0.46192700E+04, -.67490700E+04, 0.10620000E+05, 0.38141900E+04, -.15898500E+05, 0.27507600E+04, -.12814500E+05, 0.80436400E+04, -.37108100E+05, -.19454600E+05, 0.12035100E+05, 0.45284500E+04, 0.14844500E+05, -.22174200E+05, 0.39914700E+05, -.67851600E+05, 0.36937100E+05, 0.11412300E+05, 0.33922000E+05, 0.27829300E+05, 0.11065300E+05, 0.19502600E+04, -.18307600E+05, 0.19385500E+05, 0.16609800E+05, 0.51113400E+04, -.27592500E+05, 0.15991000E+05, 0.17331300E+05, 0.13772500E+05, 0.13457900E+05, 0.13215800E+05, 0.20878900E+03, -.22896300E+04, 0.10832800E+05, 0.13032400E+05, -.85979300E+03, 0.38837100E+04, -.14580900E+04, 0.30441300E+04, -.20170600E+04, -.20995200E+04, 0.18208300E+05, -.10636400E+04, 0.71009200E+04, 0.13891700E+05, 0.90390400E+04, -.10102000E+04, 0.50819200E+05, -.26981200E+05, -.11409200E+05, -.25578100E+05, 0.12351200E+05, 0.15672300E+05, -.14355200E+05, 0.17267600E+04, -.30429800E+05, 0.14186500E+05, -.29100400E+05, 0.25594700E+05, -.15534600E+05, -.19232900E+05, -.12824300E+05, -.16311400E+05, -.15477800E+05, 0.59109600E+04, 0.12617600E+05, -.41281900E+04, -.16104700E+05, 0.50427500E+04, 0.14496900E+06, -.78133400E+05, -.39773300E+05, -.72445400E+05, -.29019200E+05, -.27319900E+04, -.15673400E+05, 0.32968800E+05, -.42755500E+05, -.11800800E+05, -.29325100E+05, -.74353300E+03, 0.71597200E+03, 0.16134300E+05, 0.83021100E+04, -.32221100E+04, -.24785700E+04, -.62271000E+04, -.22244200E+04, 0.87578100E+04, 0.14149900E+04, -.27336400E+04, 0.10081700E+04, -.10603400E+03, 0.66442900E+04, 0.43497400E+04, 0.10803300E+05, -.12896700E+05, -.42748700E+03, 0.26291500E+04, 0.87827200E+04, -.50738500E+03, -.22926000E+04, -.33373100E+04, -.26496000E+04, 0.45460700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.85325600E+00, 0.20663900E+00, 0.16398400E+01, 0.60191700E+00, 0.51446700E+00, 0.32722600E+00, -.74358900E+00, -.19897400E-01, -.11667300E+00, 0.34022000E+00, 0.24987400E+00, 0.80065200E+00, -.15445100E+04, 0.19625500E+04, 0.23880200E+02, -.28229300E+04, -.34111400E+04, 0.20037500E+04, 0.27521500E+04, 0.18690700E+04, -.29927400E+04, -.39857200E+03, 0.22674200E+05, -.70325500E+04, 0.98883600E+04, -.11350300E+05, -.15942100E+04, 0.19688500E+05, -.13078700E+05, -.12947400E+05, -.10835100E+05, 0.17256800E+05, -.12469100E+05, 0.25754200E+05, -.11164300E+05, 0.19706900E+05, -.12788200E+05, -.60910300E+04, -.59880100E+04, 0.30358800E+03, 0.87183500E+04, -.56624500E+04, -.66342900E+04, -.12518600E+05, -.23782600E+05, 0.12980600E+05, -.28050700E+05, 0.11884200E+05, 0.16008900E+05, 0.10955700E+05, -.75668400E+04, -.19175600E+05, -.62695600E+04, 0.12769300E+05, 0.11405600E+05, 0.55555000E+05, -.30650900E+05, -.33232100E+05, -.27739800E+05, -.68609500E+04, 0.36908600E+04, -.12500800E+05, 0.42110300E+04, -.21577200E+05, 0.21361700E+04, -.10686500E+05, -.32246600E+05, 0.14354000E+05, -.26121800E+05, 0.15961400E+05, 0.77388800E+04, 0.68976600E+04, 0.42150400E+03, -.10688100E+05, 0.68964900E+04, 0.73982200E+04, 0.15116900E+05, 0.21819200E+05, -.94030700E+04, 0.15283300E+05, -.10866000E+05, -.73520900E+04, -.10238300E+04, -.18834600E+04, 0.18353200E+04, -.57825800E+04, 0.50836400E+02, -.12469600E+05, -.29106200E+05, 0.15561500E+05, 0.46619500E+04, 0.14582100E+05, 0.24175400E+04, 0.52179700E+03, 0.17547700E+04, -.12863200E+05, 0.81674500E+04, 0.29622600E+04, 0.15790800E+05, 0.24274000E+05, -.15164600E+05, -.26156900E+04, -.12129800E+05, -.23594700E+04, 0.71337400E+03, -.38055900E+04, 0.60753600E+04, -.11049800E+05, -.50273800E+03, -.61782900E+04, -.46657100E+05, 0.21220600E+05, 0.11115900E+05, 0.23344100E+05, 0.12277400E+05, -.57336500E+04, 0.11649200E+05, 0.72096000E+04, 0.18208600E+05, -.60888800E+04, 0.16837800E+05, 0.58858000E+05, -.28735200E+05, -.14750100E+05, -.29441900E+05, -.85891200E+04, 0.73130100E+04, -.11380000E+05, 0.11087900E+04, -.15190500E+05, 0.66924300E+04, -.18810300E+05, -.12904500E+05, 0.53967000E+04, -.16276800E+05, 0.64284500E+04, 0.46805100E+04, 0.41384700E+03, 0.87464600E+03, -.11231100E+04, 0.33230300E+04, -.32122700E+03, 0.79733300E+04, 0.17657100E+05, -.43381300E+04, 0.17632800E+05, -.88180500E+04, 0.12295400E+04, 0.18763500E+05, -.10356800E+05, -.11573900E+05, -.86072600E+04, 0.17829400E+05, -.85985100E+04, -.58409400E+05, 0.20017500E+05, -.20757500E+05, 0.29216400E+05, -.24252700E+03, -.43765900E+05, 0.29575600E+05, 0.24080100E+05, 0.28093800E+05, -.38432800E+05, 0.29931300E+05, 0.24225000E+05, -.14987300E+05, 0.25937300E+04, -.12117700E+05, -.80477100E+04, -.11727600E+04, -.19493900E+04, 0.91143300E+04, -.49576100E+04, -.22951900E+04, -.71052000E+04, -.28929200E+05, 0.16453500E+05, -.10726000E+05, 0.14459800E+05, 0.14754400E+04, -.36360400E+04, 0.45433800E+04, -.68595500E+04, 0.11691600E+05, -.17726000E+04, 0.93509400E+04, -.31369700E+05, 0.19906400E+05, 0.19431500E+05, 0.15630000E+05, 0.80825700E+04, 0.14422200E+05, -.14601100E+04, -.11839800E+05, 0.10060400E+05, 0.13428000E+05, 0.27974900E+04, 0.84813600E+05, -.45673500E+05, -.32024500E+05, -.42404300E+05, -.17565400E+05, 0.73396300E+04, -.17065100E+05, 0.10954200E+05, -.30311200E+05, 0.38726900E+04, -.21046700E+05, 0.84695000E+04, -.67681700E+04, -.17607200E+05, -.42186000E+04, -.38693500E+04, -.38676400E+04, -.26051600E+04, -.63277000E+03, -.56283900E+04, -.29559200E+04, 0.39824000E+04, -.63618800E+05, 0.30792000E+05, -.72585800E+04, 0.31847700E+05, 0.13821000E+05, 0.10066900E+05, -.23123800E+03, -.17577600E+05, 0.64863300E+04, 0.13034700E+05, 0.30101500E+05, 0.29852600E+05, -.13752800E+05, 0.48301100E+04, -.14794600E+05, -.79160100E+04, -.52242900E+04, -.20591200E+04, 0.47221700E+04, -.55974000E+04, -.48569800E+04, -.13002800E+05, -.91472900E+04, 0.69386900E+04, 0.12552300E+05, 0.45946000E+04, -.25879500E+04, -.25203400E+04, 0.41872500E+04, -.16439100E+04, 0.95704800E+04, -.18893800E+04, -.24548600E+04, -.89693500E+05, 0.50930600E+05, 0.28976700E+05, 0.44819800E+05, 0.15752800E+05, -.55132300E+04, 0.15666100E+05, -.18499700E+05, 0.33600000E+05, -.10082300E+04, 0.28330400E+05, -.83762300E+04, -.24475300E+04, -.69230600E+04, 0.38636300E+04, 0.78122600E+04, 0.10842000E+04, 0.38698500E+04, 0.77737300E+04, -.60337700E+04, 0.11799500E+04, -.80027500E+04, -.23473100E+04, -.15668100E+03, -.85157000E+04, -.22426400E+04, 0.48368200E+03, 0.56434200E+04, -.64440800E+04, 0.41113100E+04, -.53405700E+04, 0.44742600E+03, 0.59363100E+04, 0.26875400E+04, -.98096700E+04, -.27523600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.76233100E-01, -.11727400E+00, -.15086100E+01, -.27163200E+00, -.77651000E+00, 0.12214100E+00, 0.17662400E+00, -.38849900E-01, 0.53743000E-01, 0.48363800E-01, 0.43982900E+00, -.28720600E+00, -.74544100E-01, 0.67046400E+04, -.42165300E+01, 0.12948100E+04, 0.76274600E+03, -.37272100E+03, -.11318300E+04, -.20029800E+04, 0.45523000E+03, -.14545900E+04, 0.75005500E+04, -.38152200E+04, -.13419900E+05, -.37517600E+04, -.44480500E+04, 0.28223200E+04, -.39382200E+04, -.40057300E+04, -.51810100E+04, 0.36915700E+04, 0.77152100E+03, 0.11291700E+05, -.56214700E+04, 0.57524300E+04, -.56661300E+04, -.12388200E+04, -.98543200E+03, -.81788900E+03, 0.23231700E+04, -.58744000E+04, -.87941400E+03, -.56986600E+04, 0.14449400E+05, -.73530700E+04, -.15124000E+04, -.72249900E+04, -.43058400E+04, -.20073000E+04, 0.10458200E+04, 0.38995600E+04, 0.95910400E+03, -.14207900E+04, -.40034100E+04, -.14103000E+05, 0.70596800E+04, 0.69739700E+04, 0.70471200E+04, 0.98759800E+03, -.18329700E+03, 0.13741000E+04, -.48767700E+04, 0.54516000E+04, -.65768800E+03, 0.41361200E+04, -.18962700E+05, 0.96214000E+04, -.62054000E+04, 0.95135200E+04, 0.23066400E+04, 0.15187600E+04, 0.11092100E+04, -.44359100E+04, 0.75785100E+04, 0.15556800E+04, 0.92171500E+04, 0.23605800E+05, -.11245200E+05, 0.75666800E+04, -.11809200E+05, 0.70453800E+03, 0.57320900E+04, -.70963400E+04, -.28316300E+04, -.12827600E+05, 0.47631700E+04, -.11482900E+05, 0.24511900E+05, -.12077800E+05, 0.43691300E+04, -.12259600E+05, 0.34793400E+04, 0.65944500E+04, -.62569300E+04, -.53493100E+03, -.12531600E+05, 0.55617700E+04, -.12315200E+05, -.67967300E+04, 0.34935500E+04, 0.28258000E+04, 0.33995000E+04, 0.12427000E+03, -.76200700E+03, 0.40224400E+03, -.18398900E+04, 0.34068200E+04, -.14748500E+04, 0.16488000E+04, -.91227900E+04, 0.43883800E+04, -.38316800E+04, 0.45577600E+04, 0.48366900E+03, -.64440300E+04, 0.58558100E+04, 0.43150000E+04, 0.57480300E+04, -.59547800E+04, 0.33064000E+04, 0.18054100E+04, -.80039500E+03, 0.61600100E+04, -.89955000E+03, 0.66451100E+03, 0.37400300E+04, -.43986200E+04, -.68626400E+04, -.57977000E+04, 0.41546500E+04, -.12816000E+04, -.20043800E+05, 0.95731500E+04, -.64191400E+04, 0.10025800E+05, -.14324300E+03, -.32989700E+04, 0.50249000E+04, 0.14616900E+04, 0.10609700E+05, -.28213800E+04, 0.98706700E+04, 0.31703000E+05, -.15717600E+05, -.22809700E+04, -.15854900E+05, -.31896600E+04, 0.13858100E+04, -.69103000E+04, -.12913100E+04, -.14589500E+05, 0.28066600E+04, -.11917200E+05, -.11804600E+05, 0.58560900E+04, 0.22862600E+05, 0.59041200E+04, 0.12512900E+05, 0.56419100E+03, 0.35674400E+04, 0.43478900E+04, 0.71087500E+04, -.27824900E+04, -.31462300E+04, -.24528700E+05, 0.12304500E+05, 0.37338000E+04, 0.12264600E+05, 0.11593100E+04, -.64535000E+02, 0.36961100E+04, -.43548700E+04, 0.60255500E+04, -.44443100E+03, 0.72345800E+04, 0.11194900E+04, -.58673400E+03, -.22424000E+04, -.56407000E+03, 0.30779700E+04, 0.54069000E+04, -.17016900E+04, 0.63535300E+03, -.72645900E+03, 0.49602400E+04, 0.11008400E+04, -.31551200E+04, 0.14543400E+04, -.17749900E+05, 0.15773300E+04, -.61175700E+04, -.94273500E+03, 0.15267000E+04, -.59220600E+03, 0.51530800E+02, 0.62907200E+03, 0.51349700E+04, -.36423800E+05, 0.18166300E+05, -.14144200E+04, 0.18211700E+05, -.29124400E+04, -.13561800E+04, 0.40009500E+04, -.92099400E+04, 0.13600400E+05, -.19778300E+04, 0.14592500E+05, -.51476600E+04, 0.25397200E+04, 0.14204800E+04, 0.25724500E+04, 0.46173500E+03, 0.14546900E+04, 0.10697800E+04, -.20181100E+03, 0.35217700E+04, 0.27201200E+03, 0.83776400E+03, -.13026400E+04, 0.71017900E+03, -.15494300E+05, 0.65481400E+03, -.17427900E+04, -.86250000E+03, 0.41621100E+04, 0.55658600E+04, 0.10059900E+05, -.15901200E+04, 0.11630500E+04, 0.21110800E+05, -.10649800E+05, 0.80018800E+04, -.10575800E+05, 0.66578500E+03, 0.42769500E+04, -.54540600E+04, 0.98671300E+03, -.94367500E+04, 0.34067500E+04, -.97867900E+04, 0.18504300E+04, -.10799300E+04, -.95718200E+03, -.92838300E+03, -.13255400E+04, 0.57971900E+03, -.41452300E+03, -.78252400E+02, -.46709400E+04, 0.14718200E+04, 0.98232000E+03, 0.56698900E+05, -.28265800E+05, 0.27821000E+04, -.28346900E+05, 0.47832000E+04, 0.61077800E+04, -.10132200E+05, 0.72565300E+04, -.24487000E+05, 0.61289800E+04, -.23635700E+05, -.11622000E+04, -.54779700E+03, 0.27639200E+04, 0.23880300E+03, 0.22294700E+04, -.82609800E+03, -.31881500E+03, 0.25899100E+04, 0.16820400E+04, 0.38959700E+04, -.10156100E+04, -.85803200E+03, 0.38250800E+03, 0.87352300E+03, -.93067000E+02, 0.22793000E+04, -.78206200E+03, -.12505700E+04, 0.82569600E+03, -.23980500E+04, 0.15625500E+04, 0.51802500E+03, 0.16696600E+03, -.32400700E+03, -.33396400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.32528500E+01, 0.16830700E+00, -.21837800E+01, 0.60274100E+00, 0.57706800E+00, -.10117100E+01, 0.36535500E+00, 0.23794300E-01, -.32960300E+00, 0.24667800E+00, 0.25011400E-01, -.35954900E+00, -.87826900E-01, -.93472200E+00, 0.66027900E+02, -.27264900E+04, -.33114700E+04, 0.49822000E+03, -.41830700E+04, -.44254900E+04, -.20004600E+04, -.31795000E+04, -.47856500E+04, 0.16467100E+04, 0.46299300E+05, 0.23681600E+04, 0.81901400E+04, 0.64834100E+04, 0.16608100E+04, 0.42997900E+04, 0.29420500E+03, 0.56050100E+04, -.75241000E+04, 0.11361400E+05, -.52638100E+04, 0.98644700E+04, -.54229100E+04, -.10378800E+05, -.51943600E+04, 0.41807800E+04, 0.56703100E+04, -.64234700E+04, -.35990700E+04, -.81814100E+04, -.10041800E+06, 0.50049600E+05, -.42949000E+05, 0.50195200E+05, 0.83756900E+04, -.61671800E+04, 0.14642000E+05, -.36523000E+04, 0.43087600E+05, -.76776400E+04, 0.61257600E+05, 0.21352000E+05, -.10272500E+05, -.39465700E+05, -.10577000E+05, -.55558300E+04, -.74930300E+04, 0.13540400E+04, 0.11450400E+05, -.14495900E+04, -.10101200E+05, -.25281700E+04, -.28287300E+05, 0.13860700E+05, -.73648700E+04, 0.13681700E+05, 0.16946500E+05, 0.10008000E+05, -.49848200E+04, -.13239200E+05, 0.48015300E+04, 0.80426800E+04, 0.15805900E+05, 0.11193300E+05, -.46306400E+04, 0.38174000E+03, -.54850600E+04, -.57519000E+04, -.61718400E+04, -.17494500E+04, -.76113600E+04, -.13581300E+05, -.38408500E+04, -.97552700E+04, -.12119000E+06, 0.60301900E+05, -.26507800E+04, 0.60670800E+05, 0.65499100E+04, -.33324800E+04, 0.18693600E+05, -.18412800E+05, 0.35077200E+05, -.10521500E+04, 0.51686100E+05, 0.17321100E+05, -.82665200E+04, -.35718500E+04, -.86485000E+04, -.23564400E+04, 0.68107300E+03, -.23104700E+04, 0.60495600E+04, -.47684300E+04, -.93381300E+03, -.58912300E+04, -.55192200E+04, 0.29451300E+04, 0.80953200E+04, 0.28074600E+04, 0.97057100E+04, 0.17120100E+05, -.77049800E+04, -.96809000E+04, -.17189400E+04, 0.15183900E+05, 0.42577000E+04, 0.35101700E+05, -.17601400E+05, -.21523400E+05, -.17590400E+05, -.59664200E+03, -.42259000E+04, -.96561100E+03, 0.14725200E+05, -.15327700E+04, -.61699000E+04, -.15983800E+05, -.40304500E+04, 0.12371300E+04, -.58014300E+04, 0.19534700E+04, 0.35494800E+04, 0.23224700E+04, 0.18797100E+04, 0.76269600E+04, 0.98141000E+04, 0.83041200E+03, 0.57588500E+04, -.24647700E+05, 0.11574400E+05, 0.20005500E+05, 0.12357700E+05, 0.10981500E+05, 0.98171400E+04, -.67834100E+03, -.57955800E+04, 0.57870000E+04, 0.88604300E+04, 0.55855200E+04, -.18033400E+05, 0.10389100E+05, -.90538600E+05, 0.90367600E+04, -.13932500E+05, -.21087200E+05, 0.43189500E+04, -.12602100E+05, 0.80958100E+04, -.17159300E+05, 0.19188200E+05, 0.46965800E+05, -.23324100E+05, 0.11076000E+05, -.23495800E+05, -.73704200E+04, 0.10579000E+04, -.77148500E+04, 0.61288400E+03, -.23233200E+05, 0.57225000E+03, -.23440800E+05, -.23797100E+05, 0.11694300E+05, -.91609900E+04, 0.11903600E+05, -.95421800E+02, -.81641500E+04, 0.43174900E+04, -.54515900E+04, 0.73762800E+04, -.55167900E+04, 0.90304900E+04, -.10742600E+05, 0.48010100E+04, 0.70252700E+05, 0.52506000E+04, 0.11007800E+05, 0.14177700E+05, -.39665100E+04, -.59764700E+04, -.12594900E+04, 0.13766200E+05, -.37543300E+04, 0.12255900E+06, -.60836500E+05, 0.18542500E+05, -.61273200E+05, -.16703600E+05, -.96915800E+04, -.93914200E+04, 0.26018700E+05, -.40675900E+05, -.10741400E+05, -.57353600E+05, -.11627400E+05, 0.60900600E+04, -.10953000E+05, 0.58544500E+04, -.75315600E+04, -.10213700E+05, 0.48984200E+04, 0.85419400E+03, 0.48827000E+04, -.91158500E+04, 0.10328700E+05, -.42446200E+05, 0.21774500E+05, 0.13756300E+05, 0.21299200E+05, 0.47744500E+04, 0.16802300E+04, -.30195000E+03, -.12460200E+05, 0.54203100E+04, 0.24369300E+04, 0.25245200E+05, 0.21427000E+05, -.10770000E+05, -.17118300E+05, -.10348400E+05, -.12582700E+05, -.13735400E+05, 0.50045500E+04, 0.12490900E+05, 0.23888300E+04, -.11892500E+05, -.11945400E+05, -.28218500E+04, 0.79493700E+03, 0.23209000E+05, 0.14657400E+04, -.34594300E+03, 0.69426700E+03, 0.13437200E+04, -.45448800E+04, -.98020400E+03, 0.25247000E+04, -.35355800E+04, -.19662600E+06, 0.97503100E+05, -.21666600E+04, 0.98244000E+05, 0.20390400E+05, 0.63425300E+04, 0.23054500E+05, -.36202300E+05, 0.63229800E+05, 0.10113600E+05, 0.81467700E+05, -.29517500E+04, 0.50751500E+03, -.57814000E+04, 0.36248300E+04, 0.54741900E+04, 0.16606800E+04, 0.37171800E+04, 0.57758100E+04, -.31247200E+04, -.78524700E+04, -.19828200E+04, 0.61075900E+02, -.18074500E+04, -.49900500E+04, -.19070100E+04, -.21848400E+04, 0.12079900E+05, -.11739000E+04, -.66206100E+03, -.11488900E+04, -.69249900E+03, 0.77490500E+03, 0.63873400E+03, -.34598000E+04, 0.10335300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.94217900E+00, 0.28718000E-01, 0.57946400E+00, 0.81956900E+00, -.13468900E+01, -.98220100E+00, 0.11527700E+01, -.62934000E-01, -.23027300E+00, 0.95164800E+00, 0.12688000E+00, -.24091400E+00, -.63450600E+00, 0.11562200E+01, 0.17498300E-02, -.51852300E+04, -.70531000E+04, 0.34397300E+04, 0.15734700E+03, -.59509500E+03, -.48636200E+04, -.20693700E+04, -.27901000E+04, 0.90986500E+03, 0.46796400E+05, 0.13942300E+04, 0.91551300E+04, 0.13530900E+05, -.12384600E+04, -.56119800E+03, 0.13785400E+04, 0.10141600E+05, -.13235100E+05, 0.22676000E+05, -.11204700E+05, 0.15185200E+05, -.11338700E+05, -.61815000E+04, -.40230400E+04, 0.43392500E+03, 0.49631800E+04, -.51199300E+04, -.34755100E+04, -.13163000E+05, -.86304700E+05, 0.43435900E+05, -.62439800E+05, 0.43151900E+05, 0.31138800E+05, 0.18062200E+05, -.20330500E+04, -.11313700E+05, 0.27358100E+05, 0.13485300E+05, 0.49876800E+05, 0.64008000E+05, -.31640500E+05, -.63837900E+05, -.32003800E+05, -.10978200E+05, -.79469600E+04, -.73900700E+04, 0.16890500E+05, -.17647000E+05, -.96679600E+04, -.10008500E+05, -.30200400E+05, 0.14804800E+05, -.20549000E+05, 0.15101400E+05, 0.84697700E+04, 0.57701400E+04, 0.72988300E+03, -.76038900E+04, 0.52854000E+04, 0.46970900E+04, 0.16133300E+05, -.17712900E+05, 0.87009000E+04, 0.77792800E+04, 0.88573400E+04, -.68423800E+04, -.12291200E+05, 0.11275800E+05, 0.39341900E+04, 0.84510600E+04, -.87233100E+04, 0.26662700E+04, -.15631000E+06, 0.77685600E+05, 0.29747800E+04, 0.78155500E+05, 0.70240500E+04, -.76184600E+04, 0.25700400E+05, -.23852500E+05, 0.54447900E+05, -.41803400E+04, 0.71780200E+05, 0.30857100E+05, -.15174100E+05, -.14682100E+05, -.15428000E+05, -.26979700E+04, 0.17263000E+04, -.65868400E+04, 0.85146800E+04, -.11728500E+05, 0.90567200E+03, -.55950100E+04, -.28911800E+05, 0.14854700E+05, 0.23627100E+05, 0.14455400E+05, 0.11948100E+05, 0.14214400E+05, -.36388800E+04, -.11824100E+05, 0.62499000E+04, 0.12656200E+05, 0.12421500E+05, 0.65952900E+05, -.33188100E+05, -.38865200E+05, -.32976100E+05, -.68136000E+04, -.43329700E+04, -.37089600E+04, 0.20434500E+05, -.74011600E+04, -.63525900E+04, -.23324900E+05, 0.18624700E+05, -.91801300E+04, -.13360500E+05, -.93128100E+04, 0.39533700E+04, 0.66266500E+04, -.79205100E+04, -.69796900E+03, -.71089100E+04, 0.42924900E+04, -.39662000E+04, -.44823200E+05, 0.21574000E+05, 0.26063500E+05, 0.22411300E+05, 0.15534200E+05, 0.20807600E+05, 0.24756400E+04, -.59495800E+04, 0.14767400E+05, 0.17132700E+05, 0.11250900E+05, -.46787300E+05, 0.24538900E+05, -.93509400E+05, 0.23394500E+05, -.27096600E+05, -.46543900E+05, 0.20254100E+05, 0.27588000E+03, 0.20039100E+05, -.35256700E+05, 0.43512200E+05, 0.67509900E+05, -.33729000E+05, 0.12276400E+05, -.33755000E+05, -.13996500E+05, -.54049300E+04, -.61319900E+04, 0.11874700E+05, -.22281200E+05, -.48888100E+04, -.25526100E+05, -.33709000E+05, 0.16667100E+05, -.64359200E+03, 0.16853100E+05, -.22094200E+04, -.12918200E+05, 0.82691100E+04, -.61174800E+04, 0.11951500E+05, -.98729900E+04, 0.75889300E+04, -.29064100E+05, 0.14260600E+05, 0.91408700E+05, 0.14529900E+05, 0.20392100E+05, 0.23177700E+05, -.40139500E+04, -.11899400E+05, 0.79386000E+04, 0.19405000E+05, -.73005800E+04, 0.18881200E+06, -.93904900E+05, 0.15121100E+04, -.94406200E+05, -.27776400E+05, -.15014700E+05, -.20513100E+05, 0.34423900E+05, -.66226000E+05, -.13997700E+05, -.72408400E+05, -.65299300E+04, 0.36178100E+04, -.14347900E+05, 0.32651900E+04, -.69362600E+04, -.12570700E+05, 0.20793100E+04, 0.23253500E+03, 0.15703000E+04, -.97135900E+04, 0.14434600E+05, -.81514000E+05, 0.41129200E+05, 0.43678300E+05, 0.40758900E+05, 0.16502000E+05, 0.10629800E+05, -.38947600E+04, -.25513700E+05, 0.26248700E+04, 0.13023300E+05, 0.40487900E+05, 0.85224100E+04, -.41943100E+04, -.13201300E+05, -.42618800E+04, -.84160100E+04, -.13248800E+05, 0.44432100E+04, 0.81395600E+04, 0.60702300E+04, -.10999400E+05, -.45426700E+04, -.84517400E+04, 0.39155800E+04, 0.29861100E+05, 0.42261700E+04, -.15683100E+04, -.23810500E+04, 0.68972100E+04, -.44920000E+04, 0.84675100E+04, -.18355300E+04, -.82999200E+04, -.28783500E+06, 0.14308300E+06, 0.24626600E+05, 0.14391700E+06, 0.28568500E+05, 0.50909200E+04, 0.39171200E+05, -.52487000E+05, 0.10096400E+06, 0.80389600E+04, 0.11183400E+06, -.66362900E+04, -.99976200E+02, -.15566800E+05, 0.43795000E+04, 0.44804800E+04, 0.38874300E+04, 0.60545100E+04, 0.38472500E+04, -.54927200E+04, -.83946700E+04, -.62502100E+04, 0.38696000E+03, -.27617600E+04, -.74146100E+04, -.19861300E+04, -.34325200E+04, 0.20317500E+05, -.44455700E+04, 0.12154000E+04, -.39419400E+04, -.14372300E+04, 0.31877700E+04, 0.36977500E+03, -.88375400E+04, 0.57326900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10046500E+01, 0.24453900E-01, -.51287600E+00, 0.90264500E+00, 0.15356600E+00, -.25930800E+00, 0.13085700E+00, -.87809100E-03, -.10645700E+00, 0.25626600E+00, 0.31957800E+00, 0.25649800E+00, 0.29133200E+00, 0.21400000E+00, -.17669600E+00, 0.40614900E+00, 0.22954300E+04, -.27068300E+04, -.29325400E+04, 0.37959200E+03, 0.16412100E+04, 0.13047300E+04, -.14430900E+05, 0.73444600E+04, 0.56431000E+04, 0.72074100E+04, 0.65956500E+04, -.90988000E+04, 0.84415500E+04, 0.11633300E+05, 0.71386200E+04, -.81116100E+04, 0.32788400E+04, -.32661700E+05, 0.16165500E+05, 0.35423900E+04, 0.16321800E+05, 0.25637500E+04, 0.54671300E+04, 0.27120900E+04, -.50949900E+04, 0.94023900E+04, 0.52953900E+04, 0.13679300E+05, 0.31555300E+04, -.12356000E+04, 0.58938000E+04, -.15812500E+04, -.14249200E+04, -.96136200E+04, 0.78254200E+04, 0.89785900E+04, -.27871200E+04, -.84112300E+04, -.57635700E+04, -.28393100E+05, 0.14172500E+05, 0.13703800E+05, 0.14200900E+05, 0.36268800E+04, -.59070700E+03, 0.71395800E+04, -.12880800E+03, 0.10264400E+05, -.15851600E+04, 0.32346300E+04, 0.42514900E+05, -.21358400E+05, -.40609600E+04, -.21249300E+05, -.28079700E+04, -.57840500E+04, -.48184300E+04, 0.65562700E+04, -.13071700E+05, -.55637200E+04, -.17336300E+05, -.27076000E+05, 0.12479300E+05, 0.61340400E+04, 0.13541800E+05, 0.34178100E+04, -.31513900E+03, 0.15676000E+04, -.54532300E+04, 0.87255200E+04, -.68445000E+03, 0.12616100E+05, -.82605400E+04, 0.38754600E+04, 0.49674800E+04, 0.41333400E+04, 0.21329100E+04, -.30363700E+04, 0.33651100E+04, 0.70941700E+04, 0.31793700E+04, -.31546700E+04, -.49688900E+03, -.61859200E+04, 0.29526400E+04, 0.16717900E+04, 0.30981000E+04, 0.11985500E+04, 0.27333000E+03, 0.33516000E+04, -.16115700E+04, 0.21249500E+04, 0.23936900E+03, -.22239500E+04, 0.32292100E+05, -.15818800E+05, -.13010700E+05, -.16148400E+05, -.41154900E+04, 0.84093900E+04, -.11988800E+05, -.73909200E+04, -.16187400E+05, 0.84940500E+04, -.11192200E+05, -.41295500E+05, 0.20429900E+05, 0.16092800E+05, 0.20649900E+05, 0.48737600E+04, -.59035900E+04, 0.10780500E+05, 0.47379200E+04, 0.15829900E+05, -.64148900E+04, 0.13238900E+05, 0.19067800E+05, -.87014700E+04, -.31190100E+04, -.95352400E+04, -.22048900E+04, 0.47114900E+02, -.64118100E+03, 0.42006000E+04, -.62383400E+04, 0.31468000E+03, -.91016000E+04, -.20511800E+05, 0.10029600E+05, 0.40372800E+04, 0.10252700E+05, 0.31710200E+04, -.10925400E+05, 0.75250000E+04, 0.67336800E+04, 0.11637300E+05, -.10107600E+05, 0.99464200E+04, 0.40315600E+05, -.20111400E+05, -.88308800E+04, -.20149700E+05, -.83858300E+04, 0.21555700E+05, -.20455100E+05, -.22760400E+05, -.20334900E+05, 0.18736400E+05, -.15620000E+05, -.10822000E+05, 0.53441400E+04, -.10791200E+04, 0.54097900E+04, 0.12789100E+04, 0.31788000E+04, -.27645200E+04, -.77257800E+04, 0.29043400E+04, 0.24354900E+04, 0.46139000E+04, 0.10909800E+05, -.54198000E+04, -.76190700E+03, -.54661700E+04, -.42634700E+04, -.41209100E+04, -.45641000E+03, 0.20009900E+04, -.29334800E+04, -.40775600E+04, -.35663400E+03, 0.25131900E+05, -.12281400E+05, -.10440200E+05, -.12586800E+05, 0.75415800E+03, -.70597800E+04, -.19305300E+04, 0.80197300E+04, -.11188400E+05, -.53434700E+04, -.79393200E+04, -.24580500E+05, 0.12355300E+05, 0.11978600E+05, 0.12290800E+05, 0.52022400E+04, -.18086600E+04, 0.75038200E+04, -.13926900E+03, 0.10224200E+05, -.26984400E+04, -.46299700E+03, 0.24405800E+04, -.11152600E+04, 0.70847300E+03, -.12173600E+04, 0.69924600E+02, -.48280400E+03, 0.14014000E+04, 0.84297500E+03, -.19564100E+04, -.84604100E+03, -.58915800E+04, 0.39902500E+05, -.19985400E+05, -.11094600E+05, -.19930200E+05, -.93767500E+04, -.12826800E+05, 0.31560100E+03, 0.50210700E+04, -.11352500E+05, -.11755900E+05, -.16537000E+05, -.35664300E+05, 0.17904400E+05, 0.84406300E+04, 0.17836000E+05, 0.18006400E+04, -.22098000E+03, 0.82577100E+04, -.13788900E+04, 0.13595300E+05, -.50718300E+03, 0.14477900E+05, 0.36374700E+04, -.15660300E+04, -.24551300E+04, -.18173300E+04, 0.17952300E+04, 0.24823200E+04, -.44909800E+04, 0.21069400E+04, -.18956800E+04, 0.26755800E+04, 0.33165700E+04, 0.17546900E+05, -.88983700E+04, -.68502300E+04, -.87777100E+04, -.30396200E+04, -.22243000E+04, -.22102300E+04, 0.93651200E+04, -.62840400E+04, -.13043500E+04, -.23114300E+04, 0.57890600E+04, 0.12772300E+04, 0.15494900E+04, -.37201900E+04, -.42267800E+04, 0.55964400E+03, -.21391300E+04, -.43484300E+04, 0.20916700E+04, -.62239000E+03, 0.55581800E+04, 0.38650200E+03, 0.64443500E+02, 0.36283300E+04, 0.29062300E+03, -.26470800E+04, -.21216400E+04, 0.52451000E+04, -.32100000E+04, 0.27947100E+04, -.18494300E+04, -.31051300E+04, -.20615800E+04, 0.58585600E+04, 0.14659600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.46479900E+00, -.47625100E-01, -.21323300E+00, -.18986900E+00, -.49608500E+00, -.94021100E-01, 0.38786100E+00, 0.14202000E-01, 0.31638500E+00, 0.53586700E+00, 0.41630600E+00, -.14855100E+00, -.12845600E+00, 0.81278100E+00, 0.36934700E-01, 0.25420500E+00, 0.37360200E+00, 0.17025500E+04, 0.32717900E+04, 0.32886900E+04, -.43826600E+03, 0.69322700E+03, 0.28644600E+04, -.15158500E+04, -.21810800E+05, -.14308900E+04, -.57811800E+04, -.72949000E+03, -.22781200E+04, -.61569200E+04, 0.43723400E+03, -.58803400E+03, 0.39050400E+04, 0.63216900E+03, -.24951400E+03, -.43431600E+04, -.31473500E+03, 0.10303200E+04, -.25555700E+04, -.31430800E+04, -.36903400E+04, -.41118200E+02, -.23778400E+04, 0.62823500E+04, 0.40872900E+05, -.20438600E+05, 0.22861400E+05, -.20435800E+05, 0.19904400E+04, 0.10827000E+05, -.10736800E+05, -.13672900E+04, -.26093800E+05, 0.11174300E+05, -.26486800E+05, 0.19491400E+04, -.93725400E+03, 0.12762100E+05, -.97518300E+03, 0.34735100E+03, 0.52106800E+04, -.70201000E+04, -.90074800E+04, -.84374000E+04, 0.77364800E+04, 0.45433000E+04, 0.25284000E+04, -.12811900E+04, 0.43578200E+04, -.12656800E+04, -.26397500E+04, 0.16065800E+04, 0.48046800E+04, 0.80548300E+04, 0.10252500E+04, 0.12968600E+04, -.96321900E+04, 0.80735400E+04, -.38600400E+04, -.14836300E+04, -.40376500E+04, -.13845600E+04, -.56141300E+03, 0.13747900E+04, 0.46000600E+04, 0.31885700E+04, -.93145200E+03, -.20558600E+04, 0.58388600E+05, -.29184300E+05, 0.21657600E+04, -.29194800E+05, -.58894700E+04, 0.19475200E+04, -.95439500E+04, 0.57802100E+04, -.16899500E+05, 0.47986400E+03, -.22161000E+05, -.10374300E+05, 0.52437000E+04, 0.30859200E+04, 0.51862600E+04, 0.20783100E+04, 0.26115100E+04, -.42162100E+04, -.62307600E+04, -.25914200E+04, 0.37177300E+04, 0.10825600E+05, -.53644200E+04, 0.26910000E+04, -.12612900E+04, 0.26827400E+04, -.30159100E+04, -.12057800E+05, 0.94597700E+04, 0.10308700E+05, 0.57864300E+04, -.11264600E+05, 0.56579600E+03, 0.51862200E+03, -.26624700E+03, 0.44376100E+04, -.25974000E+03, -.22714300E+04, 0.41775700E+04, -.56800000E+04, -.70580700E+04, -.44372200E+04, 0.54638800E+04, 0.29258600E+04, -.57498000E+04, 0.27422600E+04, 0.25150700E+04, 0.28752900E+04, 0.11155500E+04, 0.14371700E+04, -.18906500E+04, -.43004300E+04, -.33468000E+04, 0.17007700E+04, 0.14572600E+04, 0.16142900E+05, -.81231500E+04, -.87876500E+04, -.80709300E+04, -.62223900E+04, -.33630000E+04, 0.71672400E+03, 0.51274100E+03, -.12029600E+04, -.33244300E+04, -.98100000E+04, 0.45460100E+04, -.21511700E+04, 0.43473500E+05, -.22743600E+04, 0.82899900E+04, 0.39464300E+04, 0.23748600E+04, 0.14928600E+05, -.27842700E+04, 0.26695400E+04, -.50341300E+04, -.18489400E+05, 0.92697900E+04, -.65323500E+04, 0.92448700E+04, -.18316800E+02, -.38513600E+04, 0.70687400E+04, 0.34390300E+04, 0.12295700E+05, -.28872500E+04, 0.11058700E+05, 0.97981300E+04, -.49207400E+04, 0.17250900E+04, -.48970600E+04, 0.12148300E+04, 0.36513300E+04, 0.93420600E+03, 0.55404500E+04, 0.93340700E+03, 0.21960200E+04, -.99522700E+04, -.38871200E+04, 0.18992600E+04, -.31526400E+05, 0.19470700E+04, -.40335200E+04, -.62889600E+04, 0.83395900E+04, 0.67446300E+04, 0.92596300E+04, -.69063900E+04, -.21826500E+03, -.40187200E+05, 0.20124300E+05, -.19877300E+05, 0.20093500E+05, 0.35194200E+04, 0.65469900E+04, -.34479600E+04, -.17994400E+05, 0.87004900E+04, 0.85657600E+04, 0.31092000E+05, 0.60143000E+04, -.29695600E+04, 0.50983800E+04, -.30076000E+04, 0.36882800E+04, 0.74573900E+04, -.44719000E+04, -.84709600E+03, -.59750100E+04, 0.72069300E+04, -.95800700E+03, 0.38582700E+04, -.18267200E+04, -.35926200E+04, -.19325400E+04, 0.41075300E+04, 0.67559700E+04, 0.21904900E+04, 0.35710100E+04, -.21930900E+04, 0.58068200E+04, -.10559900E+05, 0.78603300E+04, -.39502800E+04, 0.39366000E+04, -.39302900E+04, 0.17984400E+04, 0.36659500E+04, -.84854300E+04, -.89248500E+04, -.61978500E+04, 0.37421700E+04, 0.22825300E+04, 0.29298800E+04, -.15584800E+04, -.11331600E+05, -.14652500E+04, -.22580200E+04, -.43411800E+04, 0.52965400E+04, 0.63559800E+04, 0.68943000E+04, -.57862600E+04, -.50954500E+04, 0.81532200E+05, -.40832600E+05, 0.86031900E+04, -.40765500E+05, -.84912900E+04, -.40776800E+04, -.69281100E+04, 0.17236900E+05, -.20851000E+05, -.75019100E+04, -.40834400E+05, 0.17691500E+03, -.96005800E+03, -.80878700E+03, -.10165700E+04, 0.16151300E+04, -.63384900E+03, -.18440000E+04, 0.16969100E+04, -.12883800E+04, 0.38338800E+04, -.24600400E+04, -.37561700E+03, 0.91946300E+03, -.18042700E+04, 0.39753200E+03, 0.13815000E+04, -.39257700E+04, -.21253000E+04, 0.19298300E+04, 0.10702600E+04, -.35080800E+03, 0.93395000E+03, 0.22218600E+04, -.12050400E+04, -.59633500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16122900E+01, 0.22386200E+00, 0.38650700E+00, 0.75547800E+00, 0.48868100E+00, -.70247100E+00, 0.37185000E+00, -.40592700E-01, -.29526900E+00, 0.48362300E+00, -.40712700E-01, 0.32831500E+00, -.55157500E-01, -.75643300E+00, 0.21211200E+00, 0.25938000E+00, 0.28604800E+00, -.61205000E-01, 0.52790900E+04, 0.38496100E+04, -.24571400E+03, -.92465100E+03, 0.50739700E+04, -.27419900E+04, 0.14405600E+05, -.25434700E+04, -.45260800E+03, 0.32256700E+04, -.46960000E+04, -.65285500E+04, -.20046100E+04, 0.34894800E+04, -.28499200E+04, -.24684900E+04, 0.10660900E+04, 0.11639000E+05, 0.12268000E+04, -.13225300E+04, -.14083300E+02, 0.12297500E+04, 0.13517400E+04, 0.38332600E+04, -.10571500E+04, 0.14789400E+04, -.26009300E+05, 0.13324600E+05, -.21947500E+05, 0.13001900E+05, 0.80571100E+04, 0.95005300E+02, -.29803000E+04, -.22642200E+05, -.67145900E+04, 0.39738000E+04, 0.11941400E+05, 0.28668000E+05, -.14155800E+05, -.22916900E+05, -.14330500E+05, -.43560300E+04, 0.11478000E+04, -.25122500E+04, 0.37156700E+04, -.93412100E+04, 0.22917200E+03, -.61701900E+04, 0.10078400E+05, -.48588500E+04, -.19230700E+05, -.50325600E+04, 0.56595700E+03, -.26398400E+04, -.69044900E+03, 0.53668000E+03, -.27095500E+04, -.11512500E+04, -.55477700E+04, -.93708700E+04, 0.46787500E+04, 0.86463400E+04, 0.46884400E+04, 0.65727200E+03, 0.47353800E+04, -.27230400E+04, 0.24987900E+03, 0.53944700E+04, 0.40705700E+04, 0.31272900E+04, -.20589500E+05, 0.10252300E+05, -.12022100E+05, 0.10297200E+05, 0.53383600E+04, 0.35875700E+04, -.37956100E+04, -.86766100E+04, 0.91699700E+04, 0.46293000E+04, 0.91218900E+04, 0.26163900E+05, -.12854200E+05, -.96523900E+04, -.13077800E+05, -.76245600E+04, -.97692500E+04, 0.96555500E+04, 0.98014400E+04, -.42686600E+04, -.94197100E+04, -.96947200E+04, -.16373200E+05, 0.83087900E+04, 0.80010300E+04, 0.81847700E+04, 0.13438700E+05, 0.10499200E+05, -.73807600E+04, -.24535200E+04, -.22438300E+03, 0.91833000E+04, 0.33632700E+04, 0.25436300E+05, -.12820000E+05, -.11974500E+05, -.12716500E+05, -.85389200E+04, -.32121000E+04, 0.45079300E+04, 0.30814400E+04, 0.17149500E+04, -.38281900E+04, -.77391600E+04, 0.81956900E+04, -.41139200E+04, -.84457000E+04, -.40988800E+04, -.97380900E+03, -.42486700E+04, 0.24910200E+04, -.53567900E+03, -.49546400E+04, -.35971100E+04, -.24775000E+04, -.22324500E+05, 0.10845200E+05, 0.16846200E+05, 0.11159600E+05, 0.15501500E+04, 0.85129600E+04, -.34518200E+04, -.74352100E+04, 0.72777400E+04, 0.80217400E+04, 0.11305500E+05, -.19086900E+05, 0.99615200E+04, -.30972800E+05, 0.95500300E+04, 0.48488600E+03, -.11211100E+05, 0.13978300E+05, 0.15520400E+05, 0.93860500E+04, -.10790400E+05, 0.85711300E+04, 0.15885700E+05, -.79310000E+04, 0.66622000E+04, -.79438400E+04, 0.60357500E+03, 0.58537700E+04, -.52225400E+04, 0.99131200E+04, -.22528900E+04, 0.39039400E+04, -.88479100E+04, -.71428300E+04, 0.34256400E+04, -.66107800E+04, 0.35623600E+04, 0.62653800E+02, -.77048700E+03, -.52823700E+03, -.32982200E+04, 0.13972000E+04, -.57939400E+03, 0.29595400E+04, -.11402200E+05, 0.56052700E+04, 0.27242300E+05, 0.56842800E+04, 0.10724600E+05, 0.10909500E+05, -.13942100E+05, -.14212400E+05, -.56299700E+04, 0.11837600E+05, -.27528100E+04, 0.71461700E+05, -.35508600E+05, -.84277000E+04, -.35730400E+05, -.91915000E+04, 0.18041500E+04, -.77164600E+04, 0.15405200E+05, -.24689800E+05, 0.31253800E+03, -.26397800E+05, 0.21174800E+05, -.10354100E+05, -.17683500E+05, -.10585000E+05, -.14065800E+04, -.23797100E+04, -.16996400E+04, 0.14814800E+04, -.90128200E+04, -.15537700E+04, -.75530100E+04, -.96668100E+04, 0.50924500E+04, -.33737300E+04, 0.48504600E+04, 0.12772700E+05, 0.13432100E+05, -.11678200E+05, -.97536300E+04, -.15768500E+05, 0.14184400E+05, 0.24388600E+04, 0.31502800E+04, -.17198500E+04, -.68339100E+03, -.15718700E+04, -.68045900E+04, -.51041900E+04, 0.68246100E+04, 0.26515900E+04, 0.29735500E+04, -.58433500E+04, 0.17523800E+04, -.12023800E+05, 0.57709400E+04, 0.13792700E+05, 0.60130400E+04, 0.39654500E+04, 0.50522000E+04, -.87844500E+04, -.63358000E+04, 0.53760700E+04, 0.52472700E+04, 0.24538500E+04, -.60667000E+05, 0.30004100E+05, -.50838200E+04, 0.30330000E+05, 0.93371200E+04, 0.10193400E+04, 0.14572500E+04, -.19421900E+05, 0.23785900E+05, 0.31465700E+04, 0.25057500E+05, -.28955000E+04, -.73166900E+02, -.17457800E+02, 0.39243900E+04, 0.42290400E+04, 0.28255500E+04, 0.16501100E+04, 0.38315100E+04, -.38803900E+04, -.13921500E+04, -.22773200E+03, -.79281100E+03, 0.19956500E+04, -.28070400E+04, -.33352300E+03, 0.78909200E+03, 0.16099600E+04, -.17723500E+04, -.46961700E+03, -.10562800E+04, -.16564300E+04, 0.39793600E+04, 0.20673700E+04, -.27063400E+04, 0.10705000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14197400E+01, -.12935000E+00, -.19321200E+00, -.84972900E+00, -.16325300E+01, 0.63113900E+00, 0.70474600E+00, 0.10420800E+00, 0.10238900E+01, 0.65715500E+00, 0.64360000E+00, -.25692400E+00, 0.49255100E+00, 0.20205600E+01, -.13921700E+00, -.16516100E+00, -.14376100E+00, 0.26659500E+01, -.36820500E+00, -.59394600E+04, 0.64687400E+03, -.21155300E+04, -.19577400E+05, 0.98623200E+04, 0.37991500E+05, 0.97838800E+04, 0.65375800E+04, -.78462500E+04, 0.47532100E+04, -.33163200E+04, 0.13433700E+04, -.50986600E+04, 0.20989800E+04, 0.10775200E+05, -.53552100E+04, -.35224400E+04, -.53925600E+04, -.29458800E+04, -.43082200E+04, 0.19189300E+04, -.22195800E+03, -.45780800E+04, -.27796900E+04, -.12582900E+05, -.51464400E+05, 0.25926100E+05, -.45272900E+05, 0.25729900E+05, 0.55527700E+02, -.75576400E+04, 0.88927100E+04, -.14449500E+04, 0.45763000E+05, -.10665700E+05, 0.35588100E+05, 0.21127000E+05, -.10560200E+05, -.34440600E+05, -.10561200E+05, -.18749900E+04, -.73769100E+04, 0.49991800E+04, 0.15671300E+05, 0.85218800E+04, -.11724200E+05, -.14289000E+05, -.25110200E+05, 0.12000300E+05, 0.82738600E+04, 0.12560500E+05, 0.57576100E+04, 0.76477700E+04, -.21288700E+04, -.66023500E+04, 0.59059900E+04, 0.61153100E+04, 0.21504200E+05, -.31256900E+05, 0.14243600E+05, -.55040900E+04, 0.15631600E+05, 0.15787600E+04, -.26156300E+04, 0.51864700E+04, -.33418900E+04, 0.79422400E+03, -.12066400E+03, 0.10393900E+05, -.97392000E+05, 0.48130900E+05, -.20006500E+05, 0.48697800E+05, 0.73958100E+04, 0.92482300E+02, 0.12941300E+05, -.16656300E+05, 0.27453300E+05, 0.25089700E+04, 0.41358700E+05, 0.49390700E+04, -.27440600E+04, -.10622100E+05, -.24663700E+04, -.78484100E+04, -.13173200E+05, 0.94620600E+04, 0.89510000E+04, 0.11256800E+05, -.13006400E+05, -.74919100E+04, 0.19313400E+05, -.91512800E+04, 0.68473500E+04, -.96585400E+04, 0.44966300E+04, 0.23347900E+05, -.16513300E+05, -.13875500E+05, -.11091800E+05, 0.20185200E+05, -.63010900E+04, 0.13999600E+04, -.98027500E+03, -.17965000E+05, -.69848300E+03, 0.44565300E+04, -.74338100E+04, 0.77621500E+04, 0.83392900E+04, 0.64070000E+04, -.91187600E+04, -.45936400E+04, 0.22227900E+05, -.10004200E+05, 0.97973400E+03, -.11115300E+05, -.14146600E+04, 0.89205900E+02, -.24076700E+04, 0.39494700E+04, 0.16852300E+04, -.17260500E+04, -.69263700E+04, -.71456600E+05, 0.35254500E+05, 0.14923800E+05, 0.35726300E+05, 0.11795400E+05, 0.11503300E+04, 0.78161400E+04, -.66646700E+04, 0.12831400E+05, 0.31284500E+04, 0.32942300E+05, 0.28727600E+04, -.10999400E+04, -.79149500E+05, -.14314800E+04, -.15351400E+05, 0.33168800E+04, 0.22272800E+04, 0.53694800E+04, 0.94458000E+04, 0.19175200E+04, 0.53136300E+04, 0.37255900E+05, -.18711500E+05, 0.15980700E+05, -.18628600E+05, 0.73599400E+03, 0.53580100E+04, -.66800000E+04, 0.65457800E+04, -.21255800E+05, 0.31440700E+04, -.22481000E+05, -.27147200E+03, 0.21136000E+03, 0.31775100E+04, 0.12855500E+03, 0.33092600E+04, 0.62479900E+04, -.60628400E+04, -.39549600E+04, -.87224200E+04, 0.62100300E+04, 0.39352700E+04, 0.10433200E+05, -.49572000E+04, 0.69416700E+05, -.52292000E+04, 0.78832800E+04, 0.11413400E+05, -.15794500E+05, -.18760400E+05, -.17810700E+05, 0.12355200E+05, -.54029700E+04, 0.11160800E+06, -.55667900E+05, 0.33641300E+05, -.55803900E+05, -.90508100E+04, -.14234600E+05, -.52326900E+04, 0.29074700E+05, -.31001600E+05, -.16393500E+05, -.66869500E+05, 0.20942600E+04, -.98075900E+03, -.81266800E+04, -.10454900E+04, -.61984700E+04, -.77104600E+04, 0.45969300E+04, 0.45484500E+04, 0.93048500E+04, -.80793400E+04, -.39784300E+04, 0.12721200E+05, -.65114500E+04, 0.22290500E+05, -.63483500E+04, -.75144000E+03, 0.67379500E+04, -.92775300E+04, 0.42964100E+04, 0.89597600E+02, 0.33252000E+04, 0.95679000E+03, 0.22451500E+03, 0.24126500E+03, -.23739500E+05, -.11177400E+03, -.23985900E+04, -.78950700E+04, 0.62930900E+04, 0.84696700E+04, 0.37459700E+04, -.69254700E+04, -.56266100E+04, -.39507800E+04, 0.23787900E+04, 0.24758500E+05, 0.19765000E+04, 0.57978900E+04, 0.86501600E+04, -.80071500E+04, -.14680700E+05, -.15756400E+05, 0.10931700E+05, 0.37751500E+04, -.15801100E+06, 0.78723100E+05, -.28208700E+05, 0.79003100E+05, 0.14165300E+05, 0.14508900E+05, 0.87721000E+04, -.45056400E+05, 0.37145800E+05, 0.20133800E+05, 0.77697600E+05, 0.13909700E+04, 0.25202500E+04, -.95559700E+03, 0.35422600E+04, -.98159900E+03, 0.24330100E+04, 0.32334400E+04, -.11214600E+04, 0.48593500E+03, -.93565200E+04, 0.51508700E+04, 0.24569600E+04, -.38346800E+03, 0.12380200E+04, -.16227400E+04, -.30287600E+04, 0.10326500E+05, 0.27814700E+04, -.47747100E+04, -.16707000E+04, 0.27169500E+04, -.24647100E+04, -.16202600E+04, 0.42350800E+04, 0.20201300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11289100E+01, 0.10672800E+00, -.16423900E+00, -.13370100E+00, -.46464200E+00, -.59634600E+00, 0.80306700E+00, 0.33384800E-02, -.18687300E-01, 0.41846900E-02, -.19715900E+00, 0.21252900E-01, -.18020500E-01, -.65108300E+00, -.28594600E+00, 0.67160900E+00, 0.33675400E+00, -.43218500E+00, -.40359800E+00, -.57066900E-01, -.78858400E+03, -.19291900E+04, 0.19420800E+04, -.24690100E+04, 0.20247300E+04, -.97445300E+03, -.68446000E+03, 0.13968800E+03, -.20668600E+04, -.30794000E+04, -.27931700E+04, 0.18262700E+04, 0.37362800E+04, -.15053400E+04, 0.14008300E+04, -.29959600E+04, 0.74804400E+03, -.28475000E+04, -.61580600E+04, 0.16660100E+04, 0.62951400E+03, 0.61673200E+03, -.51076800E+04, 0.18711600E+04, -.15285800E+05, 0.77439400E+04, 0.99804800E+04, 0.76417300E+04, -.51771200E+04, -.31973000E+04, 0.43497100E+04, -.21460400E+04, 0.65842000E+04, -.80128700E+03, 0.10041700E+05, -.88906400E+04, 0.52474800E+04, 0.47780200E+04, 0.44477300E+04, -.74516600E+03, -.29360400E+02, 0.45097500E+02, -.62945300E+04, 0.20317400E+04, -.85933100E+03, 0.25664700E+04, 0.46122600E+04, -.31309500E+04, 0.35271100E+04, -.23035100E+04, 0.36977400E+04, 0.72720100E+04, -.23524300E+04, -.26141900E+02, -.12232700E+04, 0.61224600E+04, -.40328300E+04, 0.14036100E+05, -.62045400E+04, -.57816500E+04, -.70178100E+04, -.19464100E+04, -.46724300E+04, -.25846900E+04, -.18169700E+04, -.51232600E+04, -.42766900E+04, -.72969400E+04, 0.77230200E+04, -.47008500E+04, -.32552000E+04, -.38601100E+04, -.16272800E+04, 0.40348000E+04, -.46432400E+04, -.35368600E+04, -.51504700E+04, 0.33539900E+04, -.38498900E+04, -.87477400E+04, 0.50445100E+04, 0.64531300E+04, 0.43759200E+04, 0.26490000E+03, -.12995800E+04, 0.16135700E+04, -.35195500E+04, 0.34329400E+04, -.18252000E+04, 0.32886000E+04, 0.25918200E+04, -.45899200E+03, -.28476800E+04, -.12962300E+04, 0.45311800E+04, 0.28572300E+04, -.28888400E+03, 0.44382100E+04, 0.27003700E+03, 0.17344000E+04, -.29865400E+04, -.33782500E+04, 0.12503000E+04, 0.20146800E+04, 0.16896500E+04, -.49333400E+03, 0.77941900E+03, -.15471800E+04, -.59047600E+04, -.33830000E+04, 0.12114200E+04, 0.11706500E+04, -.95591100E+04, 0.40864300E+04, 0.43460300E+04, 0.47799000E+04, 0.15786400E+04, 0.37536700E+04, 0.15252300E+04, 0.86467500E+03, 0.30868200E+04, 0.34913000E+04, 0.53350800E+04, 0.88858600E+04, -.63329500E+04, -.42110300E+04, -.44443000E+04, -.37760000E+04, -.38934900E+04, -.22580300E+04, -.25353100E+04, -.37065800E+04, -.15465900E+04, -.16165900E+04, 0.80673700E+04, -.98889500E+03, -.18514700E+04, -.40302400E+04, 0.64469400E+04, 0.68452500E+04, -.19364400E+04, 0.25128700E+04, -.19213900E+04, 0.18826100E+04, -.13154800E+05, -.95081400E+04, 0.50394000E+04, 0.59882200E+03, 0.47533200E+04, 0.13836700E+04, 0.14608400E+03, 0.19713600E+04, -.98819400E+03, 0.31481900E+04, -.12092400E+04, -.13229400E+04, 0.75770500E+04, -.41788700E+04, -.84278100E+04, -.37926700E+04, -.23371300E+03, 0.24018900E+04, -.32485100E+03, 0.38710400E+04, -.16785200E+04, 0.23904900E+04, -.21600000E+04, -.39808700E+04, 0.12339300E+04, 0.76438200E+03, 0.19816400E+04, 0.98085300E+03, 0.25799200E+04, -.46075300E+03, 0.30401800E+03, -.76027400E+03, 0.43873500E+04, 0.42953100E+04, -.97338100E+04, 0.58018900E+04, 0.27095100E+04, 0.48671600E+04, 0.62310200E+03, 0.13340800E+04, -.48921900E+03, -.67181200E+04, 0.32012000E+04, -.47840000E+03, 0.21752000E+04, -.19915200E+04, 0.17315500E+04, 0.15375200E+04, 0.99721400E+03, 0.15571300E+03, 0.35376200E+04, -.64425700E+02, -.56775100E+03, 0.90074400E+03, 0.20317400E+04, -.98620500E+03, 0.70598200E+04, -.22273200E+04, -.11998300E+05, -.35202900E+04, 0.32797600E+03, 0.41452800E+04, 0.16670400E+04, 0.70173900E+04, 0.58879700E+04, 0.27939200E+04, -.53633900E+04, 0.41360300E+04, -.20275800E+04, -.33339800E+04, -.20633800E+04, -.34670900E+04, -.47886000E+04, 0.28703400E+03, -.83505400E+03, -.28835900E+04, -.42275000E+04, 0.50150500E+03, 0.15746500E+04, -.18463900E+04, 0.50730000E+03, -.78715400E+03, -.17498700E+03, 0.12682100E+04, -.16204600E+04, 0.86000600E+03, -.38188600E+04, 0.19440000E+04, 0.71275100E+03, 0.20957600E+05, -.12267100E+05, -.90997200E+04, -.10481000E+05, -.19711700E+04, 0.37214100E+04, -.66370300E+04, 0.74832200E+03, -.10858200E+05, 0.49489500E+04, -.51978400E+04, 0.29009400E+03, 0.32754100E+03, 0.40188100E+03, 0.40556000E+03, 0.21721200E+04, -.94883500E+02, -.15382700E+04, 0.26594200E+04, -.16242700E+04, -.80159100E+03, -.54514300E+02, -.21444100E+03, 0.88755300E+03, -.21165000E+04, 0.61434000E+03, 0.11866200E+04, -.10200000E+04, -.31159700E+03, -.82798400E+03, 0.17548900E+04, 0.71807700E+02, 0.87899200E+02, 0.25084400E+04, 0.93381400E+03, 0.28581400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.67601300E+01, -.78649200E+00, -.41424400E+00, -.44016400E+01, -.54855300E+01, 0.32700800E+01, -.12361700E+01, -.39345300E+00, 0.63746100E+00, -.23210500E+01, -.96552500E+00, -.19336300E+01, -.22884600E+01, 0.17504000E+00, -.28957200E+00, -.89384000E+00, -.23077100E+01, 0.13915300E+00, -.13341600E+01, 0.75746400E+00, 0.17267400E+01, 0.16185500E+05, 0.72041700E+05, -.33666000E+05, -.90861000E+05, -.35999100E+05, -.33218300E+04, 0.35438700E+05, -.23599900E+05, -.39766500E+04, -.20753100E+05, 0.26206900E+05, -.28125100E+05, -.19918700E+05, 0.89915500E+04, 0.31332400E+04, 0.99862200E+04, 0.82032900E+04, -.45790200E+03, 0.93937400E+04, 0.83103600E+04, 0.95061100E+04, -.14299700E+04, 0.12300900E+05, 0.21275700E+06, -.10662200E+06, 0.66769200E+05, -.10637000E+06, -.11571600E+05, 0.23422800E+05, -.45110100E+05, 0.19407800E+04, -.78474000E+05, 0.19354300E+05, -.13588200E+06, 0.16580400E+05, -.95786100E+04, 0.54926200E+05, -.83034900E+04, 0.66941800E+04, 0.15748100E+05, -.14126100E+05, -.11821700E+05, -.19345800E+05, 0.24209000E+05, -.88849100E+04, 0.34203600E+05, -.15925700E+05, -.26357700E+03, -.17121800E+05, -.11123800E+05, 0.19248100E+04, -.14261900E+05, -.96270600E+04, -.14400300E+05, 0.21644600E+04, -.18761200E+05, 0.43764500E+05, -.23337300E+05, 0.83646900E+04, -.21888800E+05, -.30571500E+04, 0.98203900E+04, -.71983100E+04, -.14041500E+04, -.17726200E+05, 0.88908900E+04, -.78947600E+04, 0.21083400E+06, -.10418800E+06, 0.50989900E+05, -.10542500E+06, -.19061600E+05, -.93045700E+04, -.23119900E+05, 0.25290900E+05, -.66606300E+05, -.10288700E+05, -.84127300E+05, -.21483700E+04, -.59519300E+02, 0.22527400E+05, 0.10607300E+04, 0.20411800E+05, 0.25190900E+05, -.18605000E+05, -.36505700E+04, -.73190600E+04, 0.24376600E+05, -.53531300E+04, -.68968800E+05, 0.33245200E+05, -.54856600E+04, 0.34488900E+05, -.25732500E+05, -.68039300E+05, 0.51151700E+05, 0.30994400E+05, 0.46963000E+05, -.61814600E+05, 0.40922300E+05, 0.22748300E+05, -.10712900E+05, 0.28181500E+05, -.11378700E+05, 0.21188100E+04, 0.22996400E+05, -.22917900E+05, -.28291500E+05, -.31512600E+05, 0.28257900E+05, -.12026200E+05, -.33564600E+05, 0.18002600E+05, 0.47169400E+02, 0.16783500E+05, 0.28893600E+04, -.25442900E+04, 0.23285300E+04, -.17986100E+04, 0.12214600E+05, -.24097800E+04, 0.37918600E+04, 0.15709200E+06, -.75619400E+05, -.35622300E+05, -.78537300E+05, -.15329500E+05, 0.13677000E+05, -.24167400E+05, 0.84023400E+04, -.57473800E+05, 0.10304300E+05, -.66171800E+05, -.59644100E+05, 0.25101700E+05, 0.20435500E+06, 0.29800000E+05, 0.91259100E+04, -.46152900E+05, 0.22488300E+05, 0.16824500E+05, 0.16048300E+05, -.37377300E+05, 0.29960400E+05, -.94282500E+05, 0.46703600E+05, -.39312400E+05, 0.47145200E+05, -.15228800E+04, -.15329300E+05, 0.19183400E+05, -.98696800E+04, 0.35678600E+05, -.85491700E+04, 0.75778800E+05, -.28428600E+05, 0.14871100E+05, 0.29757100E+04, 0.14243000E+05, -.76135200E+04, -.54393100E+04, -.18287400E+03, -.15736900E+05, 0.86636400E+04, -.58123600E+04, 0.14603500E+05, -.27458600E+05, 0.14959200E+05, -.15572400E+06, 0.13785500E+05, -.21634700E+05, -.12090600E+05, 0.21822200E+05, 0.12226600E+05, 0.39126900E+05, -.21965000E+05, 0.28495800E+05, -.24565300E+06, 0.12133300E+06, -.82829400E+05, 0.12282500E+06, 0.27086500E+05, 0.37346700E+05, 0.17709600E+05, -.36097600E+05, 0.80742800E+05, 0.40425500E+05, 0.13896900E+06, -.15528700E+05, 0.65766500E+04, 0.20711900E+05, 0.77558300E+04, 0.68370600E+04, 0.96426200E+04, -.89575200E+04, -.13000500E+05, 0.22428000E+04, 0.10251400E+05, 0.13507100E+05, -.54753600E+05, 0.25306100E+05, -.45423500E+05, 0.27318000E+05, -.26767600E+05, -.27946800E+05, 0.14397800E+05, -.11324200E+05, 0.34879000E+05, -.23668000E+05, 0.42368900E+05, -.89735000E+04, 0.44779900E+04, 0.37541800E+05, 0.44683000E+04, 0.12943400E+05, 0.17920000E+05, -.98426700E+04, -.11704900E+05, -.10836900E+05, 0.18653100E+05, -.33562600E+04, 0.52319700E+04, -.87505800E+03, -.53169900E+05, -.26186900E+04, -.79652600E+04, -.10803400E+05, 0.15026700E+05, 0.93330700E+04, 0.71632000E+04, -.14376500E+05, 0.51357600E+04, 0.33373800E+06, -.16406600E+06, 0.78037200E+05, -.16685700E+06, -.36123400E+05, -.41725600E+05, -.19231800E+05, 0.64169400E+05, -.10090500E+06, -.47846900E+05, -.15657300E+06, -.99110100E+04, -.52450900E+04, -.22199500E+04, -.84940900E+04, -.89746700E+04, -.69065700E+04, -.34649500E+03, -.73780100E+04, 0.46934700E+04, 0.18231600E+05, -.99473800E+04, -.25899600E+04, 0.31916000E+02, 0.23281300E+04, 0.10539200E+03, 0.28182100E+04, -.19329700E+05, -.41164200E+04, 0.11643100E+05, -.84929400E+04, 0.39289600E+04, 0.26813500E+04, -.23439700E+04, -.96405400E+04, -.62745600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34046900E+01, 0.40765500E+00, -.55132400E+01, -.41747200E+01, 0.14213400E+01, 0.19287100E+01, -.19306900E+01, 0.27954100E+00, 0.50945700E+00, -.32382300E+01, -.45046900E+00, -.49287400E+00, -.63937300E+00, -.36861600E+01, -.25140400E-01, -.45631100E+00, 0.17496400E+00, -.15677000E+01, -.19812900E+01, 0.77945400E+00, 0.13841500E+01, -.66150900E-01, 0.52162900E+05, -.25200200E+05, 0.19214000E+05, -.26110300E+05, -.13871200E+05, 0.26648800E+05, -.22210300E+05, -.18202000E+05, -.23897400E+05, 0.23839500E+05, -.13900500E+05, 0.50998500E+05, -.25862100E+05, 0.53529500E+05, -.25533200E+05, 0.21880600E+04, 0.13271500E+05, -.13002100E+05, 0.41647700E+04, -.21692700E+05, 0.82867800E+04, -.17956900E+05, -.18306600E+06, 0.90558500E+05, 0.40026300E+04, 0.91521200E+05, 0.83665100E+04, -.28811600E+05, 0.38643600E+05, -.22486400E+05, 0.64066100E+05, -.18163900E+05, 0.79547700E+05, 0.20570400E+05, -.11012600E+05, -.19079200E+05, -.10268800E+05, -.72050900E+04, 0.12606200E+05, -.10177600E+05, -.96575400E+04, -.11760600E+05, 0.11173800E+05, 0.54707100E+04, -.66752200E+05, 0.34523300E+05, -.73323800E+05, 0.33404600E+05, -.28973300E+04, -.18706300E+05, 0.17454100E+05, -.49922100E+04, 0.28950800E+05, -.12843200E+05, 0.23114100E+05, 0.41918900E+05, -.19230000E+05, 0.44174000E+05, -.20947500E+05, 0.21565100E+04, 0.26762400E+05, -.18771300E+05, -.81687500E+04, -.20556600E+05, 0.22824000E+05, -.19896900E+05, 0.68067500E+03, 0.10358900E+04, -.14160800E+05, -.32923500E+03, 0.18143000E+05, 0.89274100E+04, -.55056200E+04, -.89908200E+04, -.21911600E+04, 0.99490800E+04, 0.52845500E+04, 0.13633600E+05, -.71313500E+04, 0.21034100E+05, -.67986400E+04, -.50331000E+03, 0.80223700E+04, -.53240000E+04, 0.20722100E+02, -.42296000E+04, 0.41647800E+04, 0.29592800E+04, -.50592200E+05, 0.23933900E+05, -.55768600E+04, 0.25288600E+05, 0.21991200E+05, -.11754100E+05, 0.21119600E+05, 0.30471000E+05, 0.29053200E+05, -.14675800E+05, 0.11918800E+05, 0.65183300E+05, -.31803200E+05, 0.67170200E+04, -.32584700E+05, -.73703900E+04, 0.27683200E+05, -.26442400E+05, -.23956300E+05, -.34363300E+05, 0.27502900E+05, -.19674800E+05, -.37741300E+05, 0.17463900E+05, -.36866800E+05, 0.18867000E+05, -.18578100E+04, -.18898700E+05, 0.13668200E+05, 0.34682600E+04, 0.17110700E+05, -.15937400E+05, 0.18198200E+05, 0.71465100E+05, -.33592300E+05, 0.32156900E+05, -.35744200E+05, -.29022600E+04, 0.24571600E+05, -.24762500E+05, -.15827200E+05, -.33063300E+05, 0.24811200E+05, -.29379100E+05, -.11184600E+06, 0.53348700E+05, -.57809400E+05, 0.55952300E+05, 0.26843600E+05, -.53947500E+05, 0.44979800E+05, 0.32694200E+05, 0.51655500E+05, -.49563000E+05, 0.40050700E+05, 0.62375400E+05, -.31187600E+05, 0.64560500E+04, -.31192400E+05, -.45675300E+04, 0.15408700E+05, -.16181600E+05, 0.29098200E+04, -.25731100E+05, 0.12269500E+05, -.31309300E+05, -.17362900E+05, 0.90226200E+04, -.54554000E+05, 0.86418600E+04, 0.29686200E+04, -.74153700E+04, 0.71916200E+04, 0.23287200E+04, 0.91638100E+04, -.37644300E+04, 0.15970000E+04, -.35699800E+05, 0.18023800E+05, 0.13437100E+05, 0.17775200E+05, -.40950000E+04, 0.22936700E+04, 0.97286000E+04, 0.49411800E+04, 0.15181100E+05, 0.28952800E+04, 0.50830700E+04, 0.68708300E+05, -.35467800E+05, -.24325100E+05, -.34352200E+05, -.26091500E+05, 0.35715200E+05, -.26143700E+05, -.60852300E+04, -.26627300E+05, 0.27083700E+05, -.64998500E+04, -.13246000E+05, 0.57461600E+04, -.22416400E+05, 0.66338400E+04, -.22150200E+03, -.13525400E+03, 0.16604700E+04, -.17727200E+04, 0.58265000E+04, -.69846800E+03, 0.13299300E+05, -.67888500E+05, 0.33199000E+05, -.62181600E+05, 0.34020700E+05, 0.19016900E+05, 0.63793700E+04, 0.14962000E+05, 0.10587900E+05, 0.33807100E+05, 0.89168400E+04, 0.20535300E+05, 0.47774600E+05, -.24279900E+05, 0.32329000E+05, -.23869700E+05, 0.84579200E+03, 0.16309800E+05, -.16560900E+05, -.76199800E+04, -.22201500E+05, 0.13914900E+05, -.13670300E+05, -.39692500E+04, 0.22657400E+04, 0.10882600E+05, 0.19891800E+04, -.79878800E+04, -.88159600E+04, 0.43307600E+04, 0.41553300E+03, -.62939700E+03, -.65294500E+04, -.64397700E+04, -.50271400E+05, 0.27059600E+05, -.13190500E+04, 0.25119900E+05, 0.36564800E+05, -.15907000E+05, 0.19713300E+05, 0.11719500E+05, 0.23528500E+05, -.12147000E+05, 0.15828800E+05, -.12080100E+05, -.58295100E+04, 0.10240800E+05, 0.10534700E+05, 0.13706500E+05, -.54556400E+04, 0.31192100E+04, 0.12873300E+05, 0.59538400E+03, 0.70525800E+04, -.10715500E+05, -.63639000E+04, 0.16463900E+04, -.79698200E+03, -.58156200E+04, 0.46592600E+04, -.64124900E+04, -.10429900E+05, 0.10308000E+05, -.19697800E+04, 0.49175500E+04, 0.11008800E+05, 0.29746000E+04, -.11738200E+05, -.44641600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.83327200E+00, -.12495800E+00, -.33585500E+00, -.41032000E+00, -.37196500E-01, 0.38621100E+00, -.34393900E+00, 0.33782300E-02, 0.62149000E-01, -.23323400E+00, 0.13309000E-01, -.28495500E+00, 0.23936800E-01, 0.19215800E+00, -.17239700E+00, -.38083200E+00, -.15000000E+00, 0.11524800E+00, -.24390800E+00, 0.23638400E+00, -.56691600E+00, -.43967700E-01, 0.14039300E+00, -.98982800E+03, -.55143100E+04, 0.62377000E+01, 0.88047500E+03, 0.61968000E+02, 0.53269900E+03, 0.21048200E+04, 0.12410900E+04, -.22152400E+03, 0.17263100E+04, -.77467700E+04, 0.43405900E+04, -.72310000E+04, 0.38801800E+04, -.22550200E+04, -.51221000E+04, 0.41363900E+04, 0.17919500E+04, 0.40503000E+04, -.38521200E+04, 0.40243700E+04, 0.26891200E+05, -.13325100E+05, 0.41821200E+04, -.13442800E+05, -.36319900E+04, 0.32656600E+04, -.65203100E+04, 0.80108100E+03, -.11156500E+05, 0.21497700E+04, -.11650800E+05, -.52852700E+04, 0.32029800E+04, 0.54977600E+04, 0.26395000E+04, 0.77565300E+03, -.16116100E+04, 0.13521400E+04, -.10817600E+04, 0.71375500E+03, -.29939500E+03, 0.48137600E+03, 0.12566600E+05, -.68449500E+04, 0.97486200E+04, -.62900900E+04, 0.30315700E+04, 0.65369100E+04, -.54178100E+04, -.17266500E+04, -.58638600E+04, 0.50639600E+04, -.65535400E+04, 0.93422800E+04, -.41241800E+04, -.87512600E+04, -.46747200E+04, -.19985700E+04, -.54524000E+04, -.80887300E+02, 0.79167800E+03, -.25825700E+04, -.48364300E+04, -.34750100E+04, 0.13488700E+05, -.73036900E+04, 0.30157200E+04, -.67466700E+04, -.44216900E+04, 0.66093600E+02, -.26976400E+04, 0.40354500E+03, -.47308200E+04, -.65842400E+03, -.55125100E+04, 0.54468500E+03, 0.20850100E+03, -.57995600E+03, -.27636400E+03, 0.11369500E+04, 0.18238800E+03, 0.19137600E+03, 0.83443500E+02, -.78816000E+03, 0.56282700E+03, -.14650900E+04, -.18523500E+04, 0.14776500E+04, 0.16794400E+04, 0.92828700E+03, -.84640500E+03, -.90615700E+03, 0.99822000E+02, -.13122900E+04, 0.22987000E+02, -.37514000E+03, 0.17022000E+04, 0.62833200E+00, -.28988500E+03, -.21051500E+04, -.20745500E+01, -.88236600E+03, -.29644500E+04, 0.14681700E+04, 0.62718900E+03, 0.10571500E+04, -.24779700E+04, -.94274300E+03, -.49187500E+04, 0.20110900E+04, 0.69743900E+04, 0.24608300E+04, 0.15258200E+04, 0.41738900E+04, -.27322100E+03, -.53153700E+03, 0.96272000E+03, 0.37140700E+04, 0.16186200E+04, 0.63962400E+04, -.44700700E+04, -.67384300E+04, -.31955900E+04, -.22356500E+04, -.17465500E+04, -.68787400E+03, 0.99075000E+03, -.80586700E+03, -.20714700E+04, -.20175300E+04, 0.11703700E+05, -.38316700E+04, 0.16356600E+05, -.58581800E+04, 0.69971900E+03, 0.45949200E+04, -.47819800E+04, -.38242100E+04, -.73906200E+04, 0.39271800E+04, -.82032000E+04, -.17024900E+05, 0.86938900E+04, -.27521100E+04, 0.85132800E+04, 0.10495100E+04, -.27781500E+04, 0.37614600E+04, -.14662700E+04, 0.59781700E+04, -.16541000E+04, 0.73570100E+04, -.58973000E+03, 0.83499400E+01, 0.35626000E+04, 0.30389700E+03, -.10741600E+04, 0.54464200E+03, -.66856300E+03, -.11997800E+04, -.13765100E+03, 0.16015500E+02, 0.14625900E+04, -.16415000E+04, 0.28848300E+03, -.76708900E+04, 0.83697800E+03, 0.33362700E+03, 0.13348600E+04, -.68468900E+03, 0.13166200E+03, 0.13458600E+04, 0.59776100E+03, 0.42745200E+04, -.24848600E+05, 0.13084700E+05, -.13058800E+03, 0.12423900E+05, 0.50195200E+04, -.22269900E+04, 0.53262500E+04, -.14916000E+04, 0.76762600E+04, -.18875200E+03, 0.92121100E+04, -.38942300E+03, 0.71018100E+03, 0.39245100E+04, 0.19251500E+03, 0.49000700E+03, 0.10551800E+04, -.51130200E+03, -.94427400E+03, -.12245900E+04, 0.12007700E+04, -.73615200E+03, 0.85658300E+03, 0.42114600E+03, 0.20279700E+04, -.44437500E+03, -.19914800E+04, 0.77183700E+03, -.22711500E+04, -.33056400E+04, -.28185300E+04, 0.28221000E+03, 0.11623300E+04, -.12737100E+04, 0.66754400E+03, -.45190600E+04, 0.63517500E+03, -.28766200E+04, -.49414400E+04, 0.27229700E+04, 0.15614000E+04, 0.11714200E+04, -.42363600E+04, 0.60247300E+03, 0.31512900E+03, -.87841300E+03, -.34068500E+04, -.15885900E+03, 0.28595400E+03, 0.86192400E+03, -.41770800E+03, 0.72629900E+03, 0.12313100E+04, 0.28872100E+03, 0.14510600E+04, 0.29993300E+05, -.16223800E+05, 0.84500800E+03, -.14993500E+05, -.78642900E+04, 0.11146400E+04, -.62447200E+04, 0.12882500E+04, -.93334100E+04, -.77861000E+03, -.10435200E+05, 0.28622000E+03, 0.46844700E+03, -.92859600E+03, -.12185200E+04, -.59171900E+03, 0.36111800E+03, -.56971200E+03, -.11370600E+03, -.10535700E+04, -.38732700E+03, 0.18971300E+03, 0.41261400E+03, 0.28615200E+03, -.13941900E+04, 0.11423600E+04, 0.54040900E+03, -.75310600E+03, 0.57532700E+03, -.64515100E+03, 0.38626400E+03, -.10243100E+04, -.50761800E+03, 0.87491100E+03, 0.16156500E+03, 0.60740800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.66476400E+01, 0.10918600E+01, 0.60574000E+01, 0.42389500E+01, 0.40409200E+01, -.17097600E+01, 0.14117700E+00, 0.25777000E+00, -.45564200E+00, 0.19343700E+01, 0.13182800E+01, 0.19066000E+01, 0.26822200E+01, 0.39438600E+01, -.55335900E+00, 0.10764700E+01, 0.28693900E+01, 0.23800100E+01, 0.98336200E+00, 0.12115100E+01, -.33045900E+01, -.28311500E+00, -.25635400E+00, 0.28762600E+01, 0.74780400E+05, 0.28628800E+02, -.26640900E+05, -.14811200E+05, 0.47690100E+04, 0.86281700E+03, 0.28558900E+04, -.11381600E+05, -.40134100E+05, 0.14651500E+06, -.73023300E+05, 0.31410800E+05, -.73226400E+05, -.12798400E+05, 0.11148200E+05, -.26076600E+05, 0.17333300E+05, -.49476300E+05, 0.60703700E+04, -.50238400E+05, -.38445100E+06, 0.19002100E+06, -.16708200E+05, 0.19223800E+06, 0.13409100E+05, -.49705400E+05, 0.76506000E+05, -.39186400E+05, 0.11375200E+06, -.31701000E+05, 0.17078700E+06, -.16321800E+04, 0.45571800E+03, -.46470800E+05, 0.80165500E+03, -.74913800E+04, 0.61427200E+04, 0.46136400E+04, 0.49528700E+04, 0.32024600E+04, 0.16634400E+04, 0.86448200E+05, -.20219200E+06, 0.10359400E+06, -.45172000E+05, 0.10106600E+06, 0.15884000E+05, -.19978500E+05, 0.38219600E+05, -.21399100E+05, 0.69636900E+05, -.13182600E+05, 0.68102000E+05, 0.94384900E+05, -.39081800E+05, 0.19097500E+05, -.47208600E+05, -.37854000E+04, 0.17733700E+05, -.21578400E+05, 0.13215300E+05, -.29550000E+05, 0.11904000E+05, -.61695900E+05, -.63824400E+05, 0.35102500E+05, -.72811700E+05, 0.31901500E+05, 0.21342400E+05, 0.14352200E+05, -.14683300E+04, -.98364800E+04, 0.21318700E+05, 0.14857600E+05, 0.21656300E+05, 0.44761700E+05, -.21357600E+05, -.51860400E+04, -.22399400E+05, -.25872700E+05, -.15437000E+05, 0.12635600E+05, 0.11709000E+05, -.74529200E+04, -.16666800E+05, 0.38705600E+05, -.31242300E+05, 0.12313000E+05, 0.44738200E+04, 0.15630800E+05, 0.40353400E+05, 0.32027500E+05, -.12529600E+05, 0.70089800E+04, 0.66911100E+04, 0.27385400E+05, 0.73600100E+02, 0.87043600E+05, -.41541400E+05, -.22244600E+05, -.43529900E+05, -.14156000E+05, 0.89224500E+04, -.76901400E+04, 0.13212200E+05, -.15676200E+05, 0.42727300E+04, -.10641700E+05, -.78784900E+05, 0.32921100E+05, -.20838400E+05, 0.39398900E+05, 0.24341400E+04, -.15083500E+05, 0.18945500E+05, -.10229400E+05, 0.24934700E+05, -.10208100E+05, 0.51504700E+05, 0.10671600E+05, -.19988200E+04, 0.50030100E+05, -.53241900E+04, -.10571600E+04, 0.18871000E+05, -.17500000E+05, -.18097500E+05, -.98020700E+04, 0.16957800E+05, -.59721100E+05, -.77348700E+05, 0.35942400E+05, -.19578000E+06, 0.38645300E+05, 0.40441400E+05, -.11447000E+05, 0.25264300E+05, 0.10195500E+05, 0.38536300E+05, -.75424600E+04, 0.11785100E+06, 0.16053800E+06, -.79853700E+05, 0.23758700E+05, -.80264900E+05, -.66125800E+04, 0.30600800E+05, -.37104700E+05, 0.17476200E+05, -.54648600E+05, 0.21729700E+05, -.44531500E+05, -.14690200E+05, 0.71968700E+04, -.46192000E+05, 0.73865200E+04, 0.17769500E+05, -.82934800E+04, 0.10947600E+05, 0.14118300E+05, 0.18745200E+05, -.44780400E+04, -.42893400E+05, -.31587300E+05, 0.14199700E+05, 0.10888700E+06, 0.15868300E+05, -.61363500E+04, -.10705800E+05, -.59365400E+03, 0.54728700E+04, 0.82556000E+04, -.18888500E+04, -.77091600E+05, 0.20071100E+06, -.10158400E+06, 0.30578300E+05, -.10035800E+06, -.39323200E+05, 0.13813300E+05, -.29808700E+05, 0.23205300E+05, -.68071300E+05, 0.58850000E+04, 0.52748100E+04, -.12712000E+04, -.43339000E+03, -.42657400E+05, 0.62549000E+03, -.57036500E+04, -.10304700E+05, 0.82848000E+04, 0.75178700E+04, 0.88782600E+03, -.73470800E+04, 0.41540400E+05, -.69942300E+05, 0.34843100E+05, -.18010200E+05, 0.34897100E+05, 0.50614100E+05, 0.37494800E+05, -.10251500E+03, 0.36606600E+04, 0.65980600E+04, 0.37521100E+05, -.60248100E+04, 0.15456500E+06, -.78711200E+05, -.19015200E+05, -.77290700E+05, -.17332300E+05, 0.27574500E+04, -.15179800E+05, 0.22407500E+05, -.38212500E+05, -.19087100E+04, -.49257900E+05, -.30090500E+05, 0.13375400E+05, 0.50351600E+05, 0.15039400E+05, 0.60454800E+03, -.13496700E+04, -.92544300E+04, -.12123200E+05, 0.30710600E+04, 0.12181500E+04, -.48673300E+05, -.18818900E+06, 0.96454100E+05, -.75632900E+05, 0.94109000E+05, 0.50394600E+05, 0.90877100E+04, 0.18981700E+05, -.20162000E+05, 0.67665000E+05, 0.14342100E+05, -.14883900E+05, -.10318200E+05, -.19533500E+04, 0.13193800E+05, 0.33788100E+05, 0.25499200E+05, -.54015900E+03, 0.27446300E+04, 0.23375300E+05, -.55065400E+04, -.47834000E+04, -.60057300E+04, -.52271500E+04, -.16424800E+03, -.85524000E+04, -.36865500E+04, 0.12041600E+05, 0.24678800E+04, -.16655200E+05, 0.11289300E+05, 0.27424700E+04, 0.21597700E+03, 0.12191100E+05, 0.22727500E+04, -.94574500E+04, 0.35585400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.28328200E+01, 0.14990900E+00, -.15634000E+01, 0.26035700E+01, 0.22182000E+01, -.15510100E+01, 0.35846600E+00, 0.80798900E-01, -.42402100E+00, 0.63269600E+00, 0.24754800E+00, -.34932400E+00, 0.44585200E+00, 0.54509200E-01, -.63283500E+00, 0.17730300E+00, -.16695900E+00, -.69168000E+00, -.10798100E+00, -.17194700E+00, -.12112200E+01, -.36770900E+00, 0.56636100E-01, 0.17635300E+01, 0.24357200E+00, -.36624200E+02, 0.75122100E+04, 0.16140300E+04, -.30642100E+03, 0.18739500E+04, -.93004800E+03, 0.15461200E+04, 0.54106900E+04, -.10858100E+05, 0.53592500E+04, -.85804100E+04, 0.53875600E+04, 0.10813100E+04, 0.20307600E+04, 0.14722500E+04, -.17287700E+04, 0.37982000E+03, 0.28117300E+04, 0.27638000E+04, 0.48740800E+05, -.23650700E+05, -.11374300E+05, -.24386300E+05, -.57220700E+04, -.21839500E+04, -.87943400E+04, 0.38084900E+04, -.16791800E+05, -.37248400E+04, -.19704400E+05, -.26193100E+04, 0.14277100E+04, 0.34800300E+04, 0.13294000E+04, 0.12697200E+04, -.38395900E+04, 0.20165600E+04, 0.18413400E+04, 0.15843900E+04, -.36772300E+04, -.17252000E+05, 0.43698300E+04, -.29365100E+04, 0.16917500E+05, -.21475500E+04, 0.10145800E+04, 0.61521200E+03, -.26162700E+04, -.11796000E+04, -.19083300E+04, -.29389500E+03, 0.12263900E+04, -.85695500E+04, 0.17991000E+04, -.46513100E+04, 0.43022700E+04, 0.24926100E+04, 0.18943500E+04, -.22091500E+03, -.44409500E+04, -.19294800E+04, 0.26017600E+04, 0.74589000E+04, -.11532600E+05, 0.47715000E+04, 0.82166400E+04, 0.57802700E+04, 0.16586600E+04, -.21716800E+04, 0.24755900E+04, -.11306200E+04, 0.81525400E+03, -.20596600E+04, 0.50872900E+04, 0.12933400E+04, -.95783200E+03, -.80947800E+03, -.62325800E+03, 0.68774700E+03, -.59434400E+03, 0.28864700E+03, 0.18211400E+04, -.14456900E+04, -.23465200E+03, -.12745300E+05, 0.14144700E+05, -.60384800E+04, -.44214900E+04, -.70831900E+04, -.57598500E+04, 0.35838400E+04, -.54623900E+04, -.64278200E+04, -.86311200E+04, 0.32399100E+04, 0.36053000E+03, -.10225900E+05, 0.44901800E+04, 0.15761700E+04, 0.51225300E+04, 0.39048700E+04, -.62277400E+04, 0.53485000E+04, 0.68286800E+04, 0.99895000E+04, -.58992200E+04, -.54165400E+04, 0.71714900E+04, -.15830000E+04, 0.35913400E+04, -.35919600E+04, -.16103800E+04, -.13928800E+04, -.44916200E+02, 0.35200000E+04, 0.13597700E+04, -.20387500E+04, -.60971400E+04, -.18327400E+05, 0.81220700E+04, 0.27168200E+04, 0.91489000E+04, 0.40179700E+04, -.48270400E+04, 0.62137500E+04, 0.36641000E+04, 0.88673000E+04, -.42162500E+04, 0.16452000E+05, 0.12707100E+05, -.55095100E+04, 0.67691900E+04, -.63163800E+04, -.95177900E+04, 0.32333300E+04, -.47159100E+04, -.46486600E+04, -.61611100E+04, 0.16578400E+04, -.18980300E+05, -.22133700E+05, 0.10930500E+05, 0.14609700E+04, 0.11061300E+05, 0.15335200E+04, -.15045400E+04, 0.46538200E+04, -.24737400E+04, 0.54445100E+04, -.93847700E+03, 0.44502300E+04, -.44564200E+04, 0.22724500E+04, 0.41539900E+04, 0.21766800E+04, 0.12561100E+04, 0.31266300E+04, -.27043400E+04, -.48222000E+04, -.90672100E+03, 0.19331900E+04, 0.11972600E+05, 0.12668300E+05, -.58295800E+04, -.65861100E+04, -.64294200E+04, 0.22722500E+04, 0.37401000E+04, -.46474500E+04, -.35359200E+04, -.75363900E+04, 0.26019300E+04, 0.13193200E+05, -.11467100E+05, 0.61263000E+04, 0.27038000E+04, 0.57359900E+04, 0.32593100E+04, -.48580200E+04, 0.53061700E+04, 0.22564400E+04, 0.41455200E+04, -.39187900E+04, -.17061500E+05, 0.48403300E+04, -.20746900E+04, 0.25814500E+02, -.24067700E+04, -.14608700E+04, -.10785200E+04, -.16902800E+03, 0.27217400E+03, -.31062700E+04, -.13668500E+04, -.10282600E+05, 0.10380300E+05, -.51335500E+04, 0.35249900E+03, -.50940200E+04, -.72049700E+04, -.51215200E+04, -.18194900E+04, -.51463800E+04, -.91775000E+04, -.62377700E+04, 0.42304600E+04, -.28392100E+04, 0.18705800E+04, -.10205300E+05, 0.14369700E+04, 0.38980100E+03, -.13569700E+04, 0.16530500E+04, 0.16900100E+04, 0.46416900E+04, -.79307200E+03, -.27184000E+04, 0.26455900E+04, -.81210800E+03, -.31413500E+04, -.13163100E+04, 0.13718200E+04, 0.21759700E+04, -.98593900E+03, -.25329800E+03, 0.18419200E+04, 0.23364400E+04, 0.11913900E+05, 0.95870000E+03, -.12275000E+04, 0.38525100E+04, -.49877400E+03, -.13921800E+04, 0.77154100E+03, -.25590100E+04, -.36996700E+04, -.67501800E+03, 0.56089000E+03, 0.19396400E+05, 0.25984400E+04, 0.95394200E+03, -.19551100E+04, -.48317400E+04, -.38771600E+04, 0.88634600E+03, 0.49286200E+02, -.33901300E+04, 0.35572900E+04, -.76377800E+03, 0.21909700E+04, 0.92893900E+03, 0.30539900E+03, 0.42458700E+04, -.25254500E+02, -.27574900E+04, 0.46840800E+03, 0.35410100E+04, -.35726700E+04, 0.37417700E+03, -.15210400E+04, -.23110200E+04, -.22607200E+04, 0.19588900E+04, 0.23831200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.73548400E+00, -.52838100E-01, 0.22148500E+00, 0.17100400E+00, -.73305900E-01, -.82033100E-02, -.90990600E-01, -.31780200E-01, -.43534100E-01, 0.12314300E+00, 0.10275300E+00, -.16483600E+00, -.10483600E+00, 0.91892100E-01, -.19958700E-01, -.74923000E-01, -.65090400E+00, 0.54133200E+00, -.17070100E+00, -.77626500E-01, -.20839300E+00, -.77023800E-01, -.20897500E-01, -.10893800E+00, 0.10209600E+00, 0.18399400E+00, 0.44323800E+04, 0.10607200E+04, 0.79272500E+03, 0.36777700E+04, 0.34157200E+03, 0.56143400E+03, 0.12064700E+04, -.18121900E+05, 0.90201300E+04, 0.17426900E+04, 0.90613400E+04, 0.73383500E+03, -.91730000E+03, 0.53088900E+04, 0.10163000E+04, 0.67258100E+04, -.28269100E+03, 0.54850300E+04, 0.24501300E+05, -.12050300E+05, -.16897000E+04, -.12250800E+05, -.20841300E+04, -.19329900E+03, -.53896200E+04, -.60406800E+03, -.59008100E+04, -.10585000E+04, -.98414500E+04, 0.31560500E+02, 0.28586100E+02, 0.31641300E+04, -.16032600E+02, 0.21443700E+04, -.77993300E+03, 0.73919600E+03, 0.16423700E+04, 0.11542800E+04, -.80523800E+03, -.83950800E+04, 0.26123400E+05, -.13250500E+05, -.19330800E+04, -.13061400E+05, -.10102700E+04, 0.13206100E+04, -.72729500E+04, -.10838600E+04, -.87639600E+04, 0.62458800E+03, -.82710400E+04, -.41875400E+04, 0.14098200E+04, -.37301300E+03, 0.20943700E+04, 0.49445300E+03, -.24068600E+04, 0.10449000E+04, -.17703000E+04, 0.43315500E+03, -.18792000E+04, 0.25572000E+04, 0.26436300E+04, -.15824800E+04, 0.63643400E+04, -.13218500E+04, -.95572200E+03, -.33411300E+04, 0.16559800E+04, 0.15585600E+04, -.38128700E+03, -.28266000E+04, -.26567100E+04, -.10556200E+04, 0.46392100E+03, 0.24844300E+04, 0.52788500E+03, 0.42689100E+04, 0.28878800E+04, -.12894100E+04, 0.45106800E+03, 0.80255200E+03, 0.26695200E+04, -.64252900E+04, 0.55882200E+04, -.25297400E+04, -.46071800E+04, -.27944200E+04, -.36302100E+04, -.35453200E+03, -.68516700E+03, -.30020100E+04, -.18902600E+04, -.18280200E+03, 0.17671800E+03, -.11434500E+05, 0.55598300E+04, 0.61857800E+04, 0.57174600E+04, 0.30955800E+04, -.14346300E+04, 0.25348000E+04, 0.58578700E+03, 0.24470600E+04, -.12561200E+04, 0.11469400E+04, 0.35900900E+04, -.12560300E+04, 0.60479700E+03, -.17954400E+04, -.13478100E+03, 0.21058300E+04, -.11589100E+04, 0.11180900E+04, -.52276200E+03, 0.16256100E+04, -.21878700E+04, 0.27332300E+03, -.42351000E+03, 0.90750500E+03, -.13666600E+03, 0.49320000E+03, -.25514100E+04, 0.15928200E+04, 0.29006400E+04, -.26741700E+03, -.23226900E+04, 0.44112700E+04, 0.11034800E+05, -.52850500E+04, 0.64713700E+04, -.55173800E+04, -.44986000E+04, 0.27178400E+04, -.60005600E+04, -.80644400E+04, -.60819800E+04, 0.24613400E+04, -.10368900E+05, -.12337400E+05, 0.61311900E+04, -.27688000E+04, 0.61688100E+04, 0.75306900E+03, -.14759200E+04, 0.23224600E+04, -.14982500E+04, 0.43241600E+04, -.11240600E+04, 0.29488000E+04, -.18593300E+04, 0.92448200E+03, 0.15288300E+03, 0.92936600E+03, -.37837300E+04, -.14732600E+04, -.12901000E+04, -.38481000E+04, -.15368300E+04, -.16138300E+04, 0.68299200E+04, 0.16166000E+04, -.70112600E+03, -.75224400E+04, -.80836900E+03, -.27480700E+03, 0.65544600E+03, -.85195800E+03, -.19647600E+04, -.11505800E+04, -.14432700E+03, 0.71708100E+04, -.18623900E+05, 0.94319800E+04, -.11525400E+04, 0.93119600E+04, 0.47634400E+04, -.12224000E+03, 0.49926400E+04, 0.36522000E+04, 0.83196900E+04, -.31244000E+03, -.17232300E+04, -.15127100E+04, 0.85429400E+03, 0.60766900E+03, 0.75626300E+03, 0.46509400E+03, -.35282100E+03, -.48991800E+03, -.14565600E+04, 0.12946700E+04, -.52544400E+03, -.28508600E+04, 0.70845800E+04, -.35503600E+04, -.75353300E+04, -.35425600E+04, -.76849200E+04, -.64085700E+04, -.11510100E+04, -.30617000E+04, 0.10810500E+03, -.62954700E+04, 0.31431200E+04, -.22091100E+05, 0.11149400E+05, 0.55543100E+04, 0.11044300E+05, 0.21639500E+04, 0.42301800E+02, 0.40580100E+04, -.53435100E+03, 0.51588100E+04, 0.26182500E+03, 0.70911800E+04, 0.39899900E+04, -.18657100E+04, -.39787700E+04, -.19948200E+04, -.13528600E+04, -.48432900E+03, 0.28439600E+03, 0.61679200E+03, -.19675400E+04, -.26503200E+03, 0.46667900E+04, 0.14557300E+05, -.74882500E+04, 0.50713600E+04, -.72784600E+04, -.49560700E+04, -.32014100E+04, -.14700100E+04, -.89547400E+03, -.70014000E+04, -.23229000E+04, 0.19143300E+04, 0.98584400E+03, 0.42485100E+03, -.11470000E+04, -.24730500E+04, -.37747800E+04, 0.38404000E+03, -.23159400E+03, -.33601300E+04, 0.16962900E+04, -.27024000E+03, 0.13505500E+04, 0.16680300E+03, -.46648600E+03, 0.17558400E+04, 0.28498200E+03, -.10543200E+04, -.78843800E+03, 0.27934800E+04, -.10944300E+04, -.59373900E+03, -.24921400E+03, -.17446100E+04, -.11369500E+04, 0.10537700E+04, 0.44113400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.76885900E+00, -.40015500E-01, 0.40641000E+00, -.22791000E+00, -.37680800E+00, 0.17310100E+00, -.15862500E-01, -.30014100E-01, 0.67544100E-01, -.12266600E+00, -.32521300E-01, -.11348000E+00, -.36349500E+00, 0.21422000E+00, -.12198700E+00, -.19459100E+00, -.75902800E+00, -.31532200E+00, 0.33394000E-01, -.10978700E+00, -.37081700E-01, -.29549500E-01, 0.13148500E-01, -.37935800E+00, 0.12975800E-01, -.25801600E-01, 0.49961600E+00, 0.88272000E+03, -.33975700E+03, -.90225300E+03, 0.24742000E+03, 0.95247200E+03, -.56638500E+03, -.49975200E+03, 0.27997200E+03, -.81382900E+03, 0.24988600E+03, -.19024300E+04, -.24989500E+04, 0.58955400E+03, -.17616300E+03, -.73854100E+03, -.21370600E+04, 0.16772300E+04, 0.58475300E+04, -.28949000E+04, -.19305800E+04, -.29237700E+04, 0.56145400E+03, 0.25743300E+04, -.21041200E+04, 0.21258500E+03, -.63628400E+04, 0.23101900E+04, -.35994100E+04, 0.44420800E+04, -.22112200E+04, -.26056000E+04, -.22210300E+04, -.12413900E+02, 0.17038100E+03, -.14921700E+04, 0.15801300E+03, -.29577400E+04, 0.30507800E+03, 0.12380100E+03, -.33174300E+04, 0.16298600E+04, 0.31214800E+04, 0.16586100E+04, 0.32861100E+04, 0.41818400E+04, -.65455200E+03, -.54077200E+03, 0.29932400E+03, 0.36793900E+04, -.35253500E+03, 0.83281000E+03, -.54279600E+03, -.11586700E+04, -.41647900E+03, -.14054500E+04, -.11785000E+04, -.17911000E+02, -.10907900E+04, -.11087400E+04, -.78166900E+03, -.64840400E+03, -.17002300E+04, 0.80589400E+03, 0.37249200E+03, 0.85012500E+03, -.13865000E+04, 0.28190500E+03, -.64781400E+03, -.15772400E+04, -.10318100E+04, 0.49908100E+03, 0.16232600E+04, 0.32103800E+04, -.16069800E+04, -.23866700E+04, -.16051800E+04, -.10469100E+04, -.11265800E+04, -.31056500E+03, 0.58841900E+03, -.29009600E+04, -.94547400E+03, 0.79401700E+03, -.38657500E+04, 0.19801800E+04, 0.28433700E+04, 0.19328900E+04, 0.56966500E+03, -.14642000E+03, 0.48111500E+03, 0.58059500E+02, 0.30836700E+03, -.72579900E+02, 0.18768700E+04, 0.79383000E+04, -.39930600E+04, -.43022200E+04, -.39691500E+04, -.12131100E+04, -.11143600E+04, -.54849000E+03, 0.29863500E+04, 0.10105400E+04, -.12152800E+04, -.28641000E+04, -.13170200E+03, 0.16127400E+03, 0.52870400E+03, 0.65898300E+02, 0.93246200E+03, 0.74920400E+03, 0.46819500E+02, 0.99668500E+03, 0.69899300E+03, 0.44441800E+03, 0.29912700E+03, -.13716300E+04, 0.64127600E+03, -.63524200E+03, 0.68581400E+03, 0.23521300E+03, 0.55600800E+03, 0.21350400E+03, -.12554400E+04, 0.23367800E+04, 0.55473000E+03, -.15347400E+04, 0.54653000E+03, -.23165300E+03, 0.48759300E+03, -.27326600E+03, -.98031800E+03, -.22831300E+04, 0.10636500E+04, 0.25162000E+04, -.56243300E+03, -.23348500E+04, 0.21976700E+04, -.16616200E+04, 0.83502600E+03, 0.17714800E+03, 0.83079900E+03, 0.10134800E+02, -.50738400E+03, 0.69018000E+03, 0.17422900E+03, 0.45591800E+02, -.33983700E+03, 0.18503800E+04, -.34185700E+04, 0.17068700E+04, 0.18429900E+04, 0.17093000E+04, 0.60762600E+03, 0.68423300E+03, 0.70267800E+03, -.38138600E+03, 0.24264600E+04, 0.57663500E+03, -.47529400E+03, -.58265700E+03, 0.29734100E+03, 0.10143300E+04, 0.29130500E+03, 0.85741900E+03, 0.16363400E+04, 0.17758200E+03, 0.95021200E+02, 0.53484200E+03, 0.16184400E+04, -.20804400E+04, 0.85787400E+04, -.42625600E+04, -.34986000E+04, -.42893700E+04, -.50170900E+03, -.54646600E+03, -.20068600E+04, -.62722100E+03, -.43657200E+04, -.96167600E+02, -.81893400E+03, 0.30060100E+04, -.14797500E+04, -.80211600E+03, -.15030000E+04, -.10300100E+04, -.39898200E+03, -.41841300E+03, 0.40478900E+03, -.30654400E+04, -.81015200E+02, -.33306500E+03, -.51717800E+04, 0.25901000E+04, 0.44482500E+04, 0.25859300E+04, 0.93190300E+03, 0.24039400E+04, -.53806900E+03, -.35792400E+04, -.42430100E+04, 0.25299200E+04, 0.57358500E+03, 0.82851600E+04, -.41626800E+04, -.53579200E+04, -.41424300E+04, -.31678900E+04, -.35613700E+04, -.13661900E+03, 0.11431600E+04, 0.31937200E+03, -.32569600E+04, -.26408900E+04, -.19866000E+04, 0.10070900E+04, 0.12828700E+04, 0.99327700E+03, 0.79396400E+03, 0.65859300E+03, 0.61383000E+03, 0.58035300E+03, 0.36702500E+04, 0.52397100E+03, -.12511900E+04, -.66591200E+04, 0.32793300E+04, 0.26024800E+04, 0.33295500E+04, -.11847100E+04, 0.19883400E+03, 0.56709300E+03, -.14076000E+04, 0.39717700E+04, 0.30009200E+03, 0.68421200E+03, -.42401700E+03, -.52531700E+02, -.70675300E+03, -.59909600E+02, 0.11519700E+04, 0.31245200E+03, 0.19908800E+03, 0.14014600E+04, -.12561200E+04, -.25535900E+03, -.99182800E+03, 0.56762200E+02, 0.19470200E+03, -.15476000E+04, 0.16139900E+01, -.12547800E+03, 0.67179400E+03, -.84108700E+03, 0.19077800E+02, 0.13219500E+03, -.76140600E+03, 0.45203000E+03, 0.63536000E+03, -.99355300E+03, -.51108100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18901400E+01, -.29953500E+00, -.11415400E+01, -.55889700E+00, -.58321100E+00, -.10611400E+00, 0.32070900E+00, -.34485400E-01, -.90330900E-02, -.55687500E+00, 0.65940300E-01, -.85844600E+00, -.70936500E+00, 0.58840800E+00, -.82680800E-01, 0.40073000E-01, -.16725900E+00, -.85675400E-01, -.13759300E+00, -.13808800E+00, -.65057600E-01, -.80074700E-02, -.78713700E-01, -.76956500E-01, -.62926900E-01, 0.52667400E-01, -.23274500E+00, 0.15220600E+01, 0.20789800E+04, 0.49027900E+04, 0.58955300E+03, -.65219100E+03, -.16788400E+04, 0.36963400E+04, -.17882900E+04, 0.15030200E+04, -.18483500E+04, 0.26400800E+04, 0.50290200E+04, -.13051900E+04, 0.10265500E+04, 0.32194500E+03, 0.44237900E+04, -.42432100E+03, -.86524500E+04, 0.40680900E+04, 0.63381800E+04, 0.43262900E+04, -.79566200E+03, -.51064200E+04, 0.48136200E+04, 0.16931800E+04, 0.10289600E+05, -.46478600E+04, 0.13020500E+04, -.91311700E+04, 0.45082800E+04, 0.74091300E+04, 0.45656800E+04, 0.10857300E+03, 0.57709100E+03, 0.29460600E+04, 0.73483800E+03, 0.62781600E+04, -.58894900E+02, 0.52508300E+04, 0.25882800E+04, -.11812400E+04, -.52674400E+04, -.12941400E+04, -.47581600E+04, -.79442300E+04, 0.16172400E+04, 0.59061200E+03, 0.92524300E+03, -.71399900E+04, -.32237800E+04, 0.35387800E+04, -.99225400E+03, 0.29074200E+04, -.17695600E+04, 0.23516300E+04, 0.21860000E+04, -.84740700E+03, 0.23927600E+04, -.97431600E+02, 0.15078400E+04, -.25732300E+04, 0.84977800E+04, -.39784600E+04, 0.23584800E+04, -.42488800E+04, 0.95554900E+03, -.27056600E+04, 0.17167500E+04, 0.39824600E+04, 0.15246700E+03, -.25538700E+04, -.72850500E+04, -.27715200E+04, 0.14254200E+04, 0.52641000E+04, 0.13857100E+04, 0.18805000E+04, 0.43400500E+04, -.80009600E+03, -.37873100E+03, 0.46456300E+04, 0.36871600E+04, 0.36401900E+04, 0.44791100E+04, -.25274600E+04, -.64840300E+04, -.22394300E+04, -.24675100E+04, -.34027000E+04, 0.22197000E+04, 0.23023500E+04, 0.18488500E+04, -.30416600E+04, -.27947800E+04, -.14403200E+05, 0.73721300E+04, 0.10243100E+05, 0.72015300E+04, 0.26838800E+04, 0.33382700E+04, 0.54538200E+03, -.54148100E+04, -.17721700E+04, 0.33823700E+04, 0.65626100E+04, -.45456900E+04, 0.16731600E+04, -.11189800E+04, 0.22729600E+04, -.13612400E+04, -.99506900E+03, 0.41143700E+03, -.24871400E+04, 0.45442700E+03, -.50395000E+03, 0.28109900E+04, 0.77182500E+04, -.35548400E+04, 0.25086000E+04, -.38591200E+04, 0.20856300E+03, 0.63610600E+02, -.88598400E+03, 0.31289300E+04, -.68491500E+04, -.11382700E+03, -.55762800E+04, -.31947600E+04, 0.13481600E+04, 0.32570300E+04, 0.15973800E+04, 0.13606000E+04, 0.10399800E+04, -.24162000E+04, -.68595700E+04, 0.15901600E+04, 0.20397700E+04, 0.32795900E+04, 0.44238400E+04, -.21813900E+04, -.38911700E+04, -.22119500E+04, -.45337600E+03, 0.62122900E+03, -.20534800E+04, -.11943000E+04, -.41663600E+03, 0.29764600E+03, -.20494700E+04, 0.55533200E+04, -.27612800E+04, -.55486800E+04, -.27765500E+04, -.12859900E+04, -.39193300E+04, -.64282400E+03, 0.80395700E+03, -.36107100E+04, -.33504200E+04, -.41846800E+04, -.60461000E+03, 0.19534900E+03, -.76195700E+04, 0.30236700E+03, -.21212100E+04, -.47842300E+04, 0.33064200E+04, 0.46536200E+04, 0.14481000E+04, -.48285100E+04, -.32664900E+04, -.26597200E+05, 0.13146200E+05, 0.41543400E+04, 0.13298600E+05, 0.10571200E+04, 0.30492200E+04, 0.49487100E+04, 0.14153300E+04, 0.12990800E+05, 0.14046200E+04, 0.15065700E+05, -.60654200E+04, 0.28977700E+04, 0.80385100E+03, 0.30327400E+04, 0.95089400E+03, -.65264500E+03, 0.70601100E+03, -.13636100E+04, 0.60489400E+04, -.10695000E+04, 0.35091900E+04, 0.44363900E+04, -.22430600E+04, -.11611400E+05, -.22181300E+04, -.32504100E+04, -.95700900E+04, 0.37783300E+04, 0.72038200E+04, 0.10150000E+05, -.89451100E+04, -.49496200E+04, -.10402100E+05, 0.51870100E+04, 0.94902000E+04, 0.52014200E+04, 0.50762600E+04, 0.70214700E+04, -.16524600E+04, -.32250500E+04, -.25757200E+04, 0.65042300E+04, 0.68397200E+04, 0.15692700E+04, -.89526100E+03, -.31648900E+04, -.78468200E+03, -.91840700E+03, -.16165100E+04, -.58181500E+03, -.19200800E+04, -.66799400E+04, -.13372700E+04, -.25952700E+04, 0.16749300E+05, -.81128800E+04, 0.17169500E+04, -.83747300E+04, 0.58367000E+03, -.47390600E+04, 0.13944100E+04, 0.47917000E+04, -.90366000E+04, -.37734500E+04, -.12660200E+05, 0.29696700E+03, -.36093600E+03, 0.16569900E+04, -.21947800E+03, -.16926300E+04, -.12410100E+04, -.78247400E+02, -.20110900E+04, 0.27857300E+04, 0.10461700E+04, 0.17626600E+04, -.56282000E+03, -.52312900E+03, 0.30329100E+04, -.48916300E+03, 0.10954300E+03, -.24342700E+04, 0.80147600E+03, 0.13785200E+04, -.13283900E+04, 0.18808300E+04, -.38339400E+03, -.98666800E+03, 0.16364600E+04, -.16312700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27226700E+01, -.36314100E+00, -.12113300E+01, -.68204000E+00, -.15506200E+01, 0.61263400E-02, -.14113900E+00, -.11219700E+00, -.18175400E+00, -.91809100E-01, -.13278500E+00, -.23180800E+00, -.43628200E+00, -.93358400E+00, 0.12311800E+00, 0.50385300E-01, -.79616700E+00, -.93598400E+00, -.74767000E-01, -.93804700E+00, 0.48925000E+00, 0.63361000E-01, -.18222200E+00, -.10955500E+01, -.15289000E+00, 0.25553800E+00, 0.53822900E+00, -.52108100E+00, -.93300100E+00, -.31984500E+04, 0.34090700E+03, 0.45237800E+03, -.10169600E+05, -.17401200E+05, 0.88000700E+04, 0.11361800E+05, 0.87000000E+04, 0.22066100E+04, -.40309700E+04, 0.71495900E+04, 0.17241000E+04, 0.74574800E+04, -.33649300E+04, 0.34282900E+04, -.56031600E+04, 0.20173300E+04, 0.97062000E+04, 0.28018200E+04, -.31862900E+04, 0.26188500E+04, -.22584500E+04, -.50932400E+04, 0.48830600E+04, 0.34098200E+04, 0.66713500E+04, 0.89929200E+04, -.46449200E+04, 0.27267600E+03, -.44960400E+04, -.25026600E+04, 0.43381600E+04, -.34367500E+04, -.59761700E+03, -.20541200E+04, 0.36809500E+04, 0.10763900E+05, 0.33655600E+05, -.16322500E+05, -.18902800E+05, -.16828300E+05, -.38977400E+04, 0.40054100E+04, -.10135700E+05, -.80521500E+03, -.96154500E+04, 0.28165800E+04, -.11406600E+05, -.14553300E+05, 0.94116400E+04, 0.58033600E+04, 0.72756500E+04, 0.62200400E+03, -.26588900E+04, 0.23435700E+04, -.46921800E+04, 0.46622400E+04, -.17607500E+04, 0.12618100E+04, 0.14605200E+05, -.65068200E+04, -.16987400E+04, -.73025600E+04, -.27022300E+04, -.88051800E+03, -.87558200E+03, 0.17808700E+03, -.20355500E+04, 0.27233800E+03, -.11711500E+05, -.21502800E+03, 0.27282300E+03, 0.34271000E+04, 0.10739300E+03, 0.18847400E+04, 0.10192600E+04, -.96035500E+03, 0.91627500E+03, 0.36217300E+04, 0.41988400E+03, 0.55352900E+04, -.25738000E+04, 0.42629600E+03, -.25596100E+04, 0.12874100E+04, 0.75978900E+03, -.55623100E+04, 0.50996600E+04, 0.77345000E+04, 0.69793200E+04, -.59498800E+04, -.21075900E+04, 0.67449200E+04, -.28396000E+04, -.80851200E+03, -.33727600E+04, -.11908400E+04, 0.47004500E+04, -.34714300E+04, -.76952500E+04, -.84021800E+04, 0.49882000E+04, 0.48730400E+04, 0.72835900E+04, -.53625600E+04, -.31286800E+04, -.36411400E+04, -.25379900E+03, 0.28373000E+04, -.18223200E+04, 0.24225800E+04, -.28680800E+04, 0.21282000E+04, 0.96105400E+03, 0.13411200E+05, -.58148900E+04, -.51486700E+04, -.67056000E+04, -.99854200E+03, 0.25184800E+04, -.44465900E+04, -.50983300E+04, -.10611800E+05, 0.36602100E+04, -.10014300E+05, -.30170200E+04, 0.80893500E+03, 0.48994800E+04, 0.15085000E+04, 0.92070100E+03, -.17541600E+04, 0.70531300E+03, 0.55667800E+04, 0.27703000E+04, -.23655000E+04, 0.13630600E+05, 0.51240700E+04, -.24387200E+04, -.54046400E+04, -.25622100E+04, -.75959500E+03, -.48922300E+01, -.15003100E+04, 0.42311800E+03, -.49541900E+03, -.44947300E+03, 0.30861200E+04, 0.10780200E+04, -.52315400E+03, -.40011000E+04, -.53852100E+03, -.45447200E+04, -.32137900E+04, -.11840100E+03, -.11112900E+04, -.16999900E+04, -.22414400E+04, -.54528700E+04, -.88701500E+04, 0.40327400E+04, -.33100800E+04, 0.44351800E+04, -.81526600E+03, -.38260600E+04, 0.18499200E+04, -.30905800E+04, 0.50694000E+04, -.30517000E+04, -.12118600E+05, -.90513100E+04, 0.41177800E+04, -.37149200E+04, 0.45256700E+04, -.40874100E+03, 0.70092300E+04, -.18406700E+04, 0.41940200E+03, 0.58735000E+04, 0.47742000E+04, 0.20446700E+05, 0.31641700E+04, -.19601500E+04, -.18394800E+04, -.15819400E+04, -.15213700E+04, 0.24709900E+04, -.32025300E+04, -.85593400E+03, 0.23640900E+04, 0.17539100E+04, 0.59182200E+04, 0.40092100E+04, -.21139300E+04, -.12597700E+05, -.20041600E+04, -.47160100E+04, 0.17492600E+04, -.50554300E+04, 0.20429700E+04, 0.60883900E+04, 0.17626100E+04, 0.42401400E+04, -.32393000E+05, 0.15933000E+05, 0.15393300E+05, 0.16198600E+05, 0.22311100E+04, -.18067300E+04, 0.74719600E+04, -.17773700E+04, 0.60801300E+04, -.65878300E+03, 0.13769200E+05, -.10359100E+04, 0.16808100E+03, -.41276800E+03, 0.51765600E+03, 0.35283300E+03, -.10344300E+04, 0.16040000E+04, -.20581600E+04, -.42108000E+04, -.65322700E+03, -.92374000E+04, 0.14674100E+05, -.66231900E+04, 0.13635000E+04, -.73373600E+04, -.10618600E+04, -.51873000E+04, 0.19061500E+04, 0.29968300E+02, -.77894300E+04, -.26824600E+04, -.27808700E+05, -.10677100E+04, -.46937500E+03, 0.57731500E+03, 0.21285600E+04, -.25192100E+04, -.72953600E+03, -.37581200E+03, -.18275800E+04, -.62817900E+03, 0.22318600E+03, -.73859200E+02, -.28456200E+03, 0.30359000E+03, -.57276100E+03, -.82170900E+03, 0.59737800E+03, -.18460600E+04, -.26610800E+03, 0.23523600E+04, -.12824500E+04, 0.24509500E+04, 0.33599800E+03, 0.10425300E+04, 0.69097100E+02, 0.48180400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.62199400E+01, 0.75821300E+00, 0.20262300E+01, 0.72744000E+01, 0.54787600E+01, -.40108000E+01, 0.13106600E+01, 0.21661400E+00, -.81639000E+00, 0.27767100E+01, 0.14609100E+01, 0.11843800E+01, 0.13173500E+01, 0.30984700E+01, 0.79194000E+00, 0.10757000E+01, 0.36503600E+01, 0.25673600E+01, 0.28824900E+01, -.61459700E+00, -.29693900E+01, -.16056900E+00, -.48860500E+00, 0.26672000E+01, 0.70454300E+00, 0.67501200E+00, -.89962300E+00, 0.49098400E+01, -.26333600E+01, -.11102400E+01, -.13134800E+05, 0.18168900E+03, 0.32508300E+05, 0.32235100E+03, -.29451400E+03, 0.15649200E+05, -.16095600E+03, 0.22675100E+05, 0.15119000E+05, 0.62977100E+04, 0.13213800E+05, 0.20027400E+05, 0.12487600E+05, -.36163700E+05, 0.24492000E+05, -.13299800E+05, -.98708500E+04, -.12246100E+05, -.12080800E+05, -.28162700E+05, 0.86881500E+04, 0.14057200E+05, 0.65878400E+05, -.27158200E+05, -.80273500E+04, -.35205600E+05, 0.17352200E+05, 0.29584900E+05, 0.17602200E+05, 0.24415700E+04, -.65216600E+04, 0.17863900E+05, 0.91846400E+04, 0.41499200E+05, -.14422700E+05, -.56171300E+05, 0.68090200E+05, -.33573200E+05, -.51947900E+05, -.34042900E+05, -.41733300E+05, -.29748500E+05, -.12274000E+05, -.53023000E+04, -.18977200E+05, -.26626500E+05, 0.21882000E+05, -.39589900E+05, 0.22786500E+05, 0.90615000E+04, 0.19796900E+05, 0.13412800E+05, -.44007200E+03, 0.12944400E+05, 0.17255500E+05, 0.30417500E+05, -.10539700E+04, 0.29778000E+05, -.49733700E+04, 0.35832300E+04, 0.74575100E+04, 0.24864800E+04, 0.79628500E+04, -.75981000E+04, 0.16008200E+05, 0.98868500E+04, 0.16973000E+05, -.49817000E+04, -.14535900E+04, -.27526900E+05, 0.13864500E+05, 0.23485000E+05, 0.13763300E+05, 0.16492100E+05, 0.94526000E+04, 0.16408700E+04, 0.66455900E+03, 0.38630200E+05, 0.52216500E+04, -.53910900E+05, 0.33053300E+05, -.17694800E+05, -.27361800E+05, -.16527200E+05, -.51591800E+04, 0.27419900E+04, -.27337400E+04, -.45640000E+04, -.10192800E+04, 0.11134400E+04, -.24697000E+05, -.99743200E+05, 0.50541700E+05, 0.51210200E+05, 0.49871800E+05, 0.16388800E+05, 0.13610800E+05, 0.79378500E+04, -.40034600E+05, -.13964000E+05, 0.13901400E+05, 0.29689900E+05, 0.19888400E+05, -.12292600E+05, -.43951200E+04, -.99454800E+04, -.88217100E+04, 0.15140600E+04, -.94398300E+04, -.14184400E+05, -.17509000E+05, 0.16865800E+04, -.19397600E+05, -.18618600E+04, 0.21021600E+04, 0.48974500E+04, 0.93093400E+03, -.38706400E+04, -.42420600E+04, 0.51158200E+03, 0.63705200E+04, -.30502000E+05, 0.29403500E+03, 0.65931700E+05, -.10098700E+05, 0.40688700E+04, -.18910600E+04, 0.50493900E+04, 0.65467800E+04, 0.14351700E+05, -.10064200E+05, -.19004800E+05, 0.17909500E+05, 0.13611800E+05, -.74142100E+05, 0.11079800E+05, -.54683900E+04, -.47379800E+03, -.55396000E+04, 0.30322100E+04, 0.34674800E+04, -.79011400E+04, -.70634100E+04, 0.13421500E+04, -.72229900E+03, -.36738100E+05, 0.34053400E+05, -.16977700E+05, -.17152000E+05, -.17027200E+05, -.11203200E+05, 0.24163800E+04, -.17991400E+05, -.91947000E+04, -.42792300E+05, 0.51676300E+04, 0.42126600E+05, 0.15683900E+05, -.82224500E+04, -.17380700E+05, -.78415500E+04, -.99826000E+04, -.11801700E+04, -.13286300E+05, -.21107000E+05, -.25035000E+05, -.16769400E+03, 0.64937200E+05, -.11439000E+06, 0.56520900E+05, 0.48272500E+05, 0.57194900E+05, 0.12077700E+05, 0.13161700E+04, 0.28940100E+05, 0.18943200E+05, 0.69016300E+05, -.12569200E+05, -.42190300E+05, -.25563300E+05, 0.12181600E+05, 0.61518200E+04, 0.12781400E+05, 0.86082800E+04, -.16146400E+04, 0.18494500E+04, -.37843300E+04, 0.41855900E+05, -.74583400E+04, -.30127900E+05, 0.54327400E+05, -.27364800E+05, -.50735600E+05, -.27164700E+05, -.17536000E+05, -.27352100E+05, -.62453400E+04, 0.31201900E+05, 0.55310700E+05, -.27455600E+05, -.25007400E+04, -.16570500E+06, 0.82986700E+05, 0.80366900E+05, 0.82848200E+05, 0.43744400E+05, 0.31691400E+05, 0.19229100E+05, -.10104800E+05, 0.14156400E+05, 0.30300400E+05, 0.43122600E+05, 0.18889300E+05, -.98086500E+04, -.11246000E+05, -.94440100E+04, -.11999500E+05, -.43680300E+04, -.34836100E+04, -.14470400E+05, -.49608400E+05, -.39675700E+03, 0.57969300E+05, 0.36418400E+05, -.17030600E+05, -.10021600E+05, -.18208800E+05, 0.20075200E+04, -.14708000E+04, 0.27170400E+04, -.32296600E+04, -.52693800E+05, 0.90470300E+04, 0.70552500E+05, 0.37768100E+04, 0.95768600E+03, 0.54276800E+04, -.59764800E+04, -.20443800E+05, -.43419200E+04, 0.12401000E+03, -.23045300E+05, 0.12178600E+05, 0.82877400E+03, 0.11605400E+05, -.59887200E+03, -.28044400E+04, 0.15642300E+05, 0.55665400E+03, -.85720500E+03, -.48827200E+04, 0.15144400E+05, -.53056200E+04, -.66330900E+04, 0.12439100E+05, -.64344900E+04, -.82930600E+04, 0.10686200E+05, -.23100800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.86504100E+00, -.16258500E-03, 0.58858600E+00, -.68020300E-01, 0.11523200E+01, 0.99869700E+00, -.14983800E+01, -.47148100E-02, 0.40543000E-01, 0.47054400E+00, 0.39412500E+00, 0.34048300E+00, 0.88344900E+00, 0.30783100E+00, -.19335000E+00, -.51504100E+00, -.15238000E+00, 0.26025900E+00, 0.17459500E+00, 0.42860200E+00, -.67023600E+00, 0.47676300E-01, -.13146200E-01, 0.11093100E+01, 0.52499500E-01, 0.11371800E+00, -.65982600E+00, 0.13350300E+01, -.11317000E+00, 0.18166800E+00, -.52880600E-01, -.80609200E+03, 0.14287900E+04, -.85236300E+04, 0.42677800E+04, 0.10488700E+05, 0.42618100E+04, 0.41638700E+04, 0.36669600E+04, 0.14449700E+04, 0.78214500E+03, 0.58757500E+04, 0.31689000E+04, 0.10688900E+04, -.13728400E+05, 0.67161200E+04, 0.24116500E+04, 0.68641800E+04, 0.36187100E+03, -.50231700E+04, 0.53803100E+04, -.73236200E+03, 0.13925300E+05, -.46739500E+04, 0.95641700E+04, -.43464300E+04, 0.21264800E+04, 0.29218500E+04, 0.21731700E+04, -.84872200E+03, 0.17973200E+04, 0.16826800E+04, -.20592600E+03, 0.37439900E+04, 0.26780900E+04, 0.13390700E+04, 0.19759300E+05, -.98922100E+04, -.18937800E+05, -.98794200E+04, -.73896900E+04, -.74988100E+04, -.16967300E+04, 0.86390400E+03, -.51100000E+04, -.67060900E+04, -.59758300E+04, -.10801200E+04, 0.83527400E+03, 0.10089200E+05, 0.54023500E+03, 0.30953200E+04, 0.25988000E+04, -.96336000E+03, 0.50162100E+03, 0.24087000E+04, 0.13876800E+04, 0.78535700E+03, 0.10830000E+05, -.53208000E+04, 0.13386500E+04, -.54150000E+04, 0.21567200E+04, -.24545900E+04, 0.10420900E+04, 0.30144400E+04, 0.38522100E+03, -.30068600E+04, -.63520400E+04, -.57596200E+04, 0.28496000E+04, 0.77519200E+04, 0.28797900E+04, 0.43922400E+04, 0.46540500E+04, -.47662500E+03, -.10869400E+04, 0.58686700E+04, 0.43122300E+04, -.11033900E+04, 0.37246300E+04, -.19631000E+04, -.80708800E+04, -.18623600E+04, -.22419000E+04, -.48846900E+04, 0.30563200E+04, 0.33075100E+04, 0.22141000E+04, -.46993500E+04, -.34871900E+04, -.10252700E+05, 0.51841600E+04, 0.10393300E+05, 0.51263500E+04, 0.20476500E+04, 0.64664600E+04, -.30327200E+04, -.10364200E+05, -.54041700E+04, 0.70456700E+04, 0.60767500E+04, -.10292900E+04, 0.28767900E+03, -.67832200E+04, 0.51453200E+03, -.18917900E+04, -.12228400E+04, 0.37438300E+03, -.12420300E+04, -.13183900E+04, -.32088500E+03, 0.44615300E+03, 0.18918700E+05, -.93393100E+04, 0.17577800E+04, -.94593700E+04, 0.16136600E+03, 0.41592100E+04, -.59441100E+04, 0.85371500E+03, -.11805200E+05, 0.31394700E+04, -.29647300E+04, -.69023700E+04, 0.33556300E+04, 0.26648000E+04, 0.34511900E+04, 0.28808400E+04, -.85163000E+03, 0.32221300E+03, -.38436300E+04, 0.27443800E+04, 0.14526300E+03, -.36961100E+04, 0.82565200E+04, -.41203400E+04, -.35273300E+04, -.41282400E+04, -.15396300E+04, 0.62130400E+03, -.21981000E+04, 0.72256700E+03, -.13592200E+04, 0.10373900E+04, -.53357200E+04, 0.41238400E+04, -.20312300E+04, -.67634500E+04, -.20619600E+04, -.39842600E+04, -.41209200E+04, -.55725500E+03, -.35374100E+03, -.39819600E+04, -.37398300E+04, 0.19012500E+04, -.26090900E+04, 0.12998200E+04, -.74688800E+04, 0.13045900E+04, -.25782000E+04, -.51169800E+04, 0.19164100E+04, 0.48759700E+03, 0.17706000E+04, -.59121200E+04, 0.39243700E+04, -.20179500E+05, 0.99914400E+04, 0.55316000E+03, 0.10089800E+05, -.33378000E+03, 0.62546000E+04, 0.25879600E+04, 0.14011100E+04, 0.91188100E+04, 0.62282800E+04, 0.79048000E+04, -.74658100E+04, 0.36484700E+04, 0.56324200E+03, 0.37328800E+04, 0.17227500E+04, 0.63220800E+03, 0.11414700E+04, -.10676500E+04, 0.67954000E+04, 0.42028800E+03, 0.35173400E+04, 0.10037000E+05, -.50362800E+04, -.18591000E+05, -.50185900E+04, -.61576500E+04, -.79773000E+04, 0.26360400E+04, 0.79456100E+04, 0.81284200E+04, -.76044400E+04, 0.13989300E+04, -.26795600E+05, 0.13462800E+05, 0.22942800E+05, 0.13397400E+05, 0.78665400E+04, 0.84756300E+04, 0.58823500E+03, -.44072100E+04, 0.14183700E+04, 0.78164700E+04, 0.10871000E+05, 0.39788700E+04, -.19970700E+04, -.48718800E+04, -.19893800E+04, -.23764500E+04, -.27086000E+04, -.38686400E+03, -.71175600E+03, -.68668100E+04, -.28601000E+04, 0.11364600E+04, 0.17766400E+05, -.87357200E+04, 0.12114000E+04, -.88831500E+04, 0.25726600E+04, -.59631100E+04, 0.99039200E+03, 0.35399700E+04, -.81159000E+04, -.71104700E+04, -.62684200E+04, 0.58905600E+02, -.79785000E+03, 0.21619700E+04, -.33432200E+03, -.28321700E+04, -.12196600E+04, 0.37381500E+03, -.32136400E+04, 0.32021800E+04, 0.16224100E+04, 0.14056700E+04, -.89473800E+03, -.37601600E+02, 0.36334900E+04, -.98252100E+03, -.75732600E+01, -.22890100E+04, 0.16262600E+04, 0.15084700E+04, -.16038500E+04, 0.23999200E+04, -.19619000E+03, -.12500900E+04, 0.11643800E+04, -.41492700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36000200E+00, -.53399600E-01, -.77487400E+00, -.17255900E+00, -.11092900E+01, -.62016200E+00, 0.11255200E+01, 0.40150600E-01, 0.11318900E-01, 0.60050500E+00, -.42446600E-01, -.24501800E+00, -.20447300E+00, 0.32534100E+00, 0.32493500E-01, 0.40340400E+00, 0.17683200E+00, 0.19429600E+00, -.38002400E+00, -.71616700E-01, 0.23313700E+00, -.54617200E-01, -.34925000E-01, -.31827400E+00, 0.16251900E-01, 0.15331500E+00, 0.84906500E+00, -.17026000E+01, -.25696400E+00, 0.24674600E+00, -.11456900E+00, -.55163500E-01, 0.45729200E+04, -.30379600E+04, 0.15162800E+04, -.29106500E+04, 0.15186900E+04, 0.23408100E+04, 0.24515100E+04, -.28891800E+04, -.42340600E+04, 0.85744900E+03, 0.17106900E+04, 0.37414700E+04, -.14050800E+05, 0.71046500E+04, 0.41704700E+04, 0.70254900E+04, 0.24281200E+04, 0.22814500E+04, 0.25154000E+04, 0.82308600E+03, 0.78053800E+04, 0.17551000E+04, 0.30740100E+04, -.52654900E+04, 0.26425700E+04, -.81848300E+03, 0.26329200E+04, -.20791000E+04, -.47083300E+03, 0.24196100E+03, -.25887200E+04, 0.13081300E+04, -.76510600E+03, -.70902900E+03, 0.87966800E+04, -.44585200E+04, 0.17576100E+04, -.43985000E+04, -.38351300E+04, -.32679000E+04, 0.34312900E+04, 0.68043400E+04, -.17413500E+04, -.25584000E+04, -.64068200E+04, -.17317300E+05, 0.84691600E+04, -.14687700E+04, 0.86582800E+04, 0.15817000E+04, 0.18796800E+03, 0.31222700E+04, 0.19836300E+03, 0.74239500E+04, 0.16111900E+03, 0.10408500E+05, -.12385200E+05, 0.61192200E+04, -.13832300E+04, 0.61926000E+04, 0.96071900E+03, 0.20948100E+04, 0.81266600E+03, -.20175900E+04, 0.53121300E+04, 0.14676900E+04, 0.81001800E+04, -.58936700E+04, 0.29244800E+04, 0.75289800E+03, 0.29467700E+04, 0.26174000E+03, 0.15335500E+04, -.79273900E+03, -.22822600E+04, 0.19896700E+04, 0.96671500E+03, 0.25741900E+04, 0.38797900E+04, -.18573800E+04, 0.27624300E+04, -.19396700E+04, 0.95160400E+03, 0.11165700E+04, -.31708400E+03, 0.19150500E+04, -.84983400E+01, 0.83893300E+03, -.33889400E+04, -.90554500E+04, 0.44737700E+04, -.10791000E+04, 0.45275800E+04, -.36123500E+03, 0.65292200E+03, 0.34103500E+03, -.35271500E+04, -.88269600E+03, 0.88737700E+03, 0.35022900E+04, 0.12804200E+05, -.62405100E+04, 0.13691200E+04, -.64018200E+04, -.13016300E+04, -.44170200E+03, -.21243400E+04, -.93650600E+02, -.56288600E+04, -.34496100E+03, -.79082000E+04, -.11838900E+05, 0.58408900E+04, -.17227700E+04, 0.59194400E+04, 0.11056200E+04, -.69996700E+03, 0.26632700E+04, 0.21181300E+03, 0.45161000E+04, -.24972200E+03, 0.74622800E+04, 0.23967100E+03, -.61664100E+02, -.14275800E+04, -.11983900E+03, -.23863900E+04, 0.11901900E+04, 0.35508700E+03, 0.13438700E+04, -.15673000E+03, 0.78680400E+03, -.51549400E+04, -.35590500E+03, 0.16290900E+03, 0.15330400E+04, 0.17788300E+03, 0.30714100E+03, -.74848000E+03, 0.36091200E+03, -.44906600E+03, 0.14176900E+03, -.58404800E+03, -.20016000E+04, 0.92593300E+04, -.46251800E+04, -.45818700E+03, -.46294500E+04, -.88683600E+03, -.13474400E+04, 0.51459700E+03, 0.36349700E+04, -.33814800E+04, -.68503700E+03, -.40741600E+04, 0.39036500E+04, -.18991400E+04, 0.70783600E+04, -.19517500E+04, 0.27852100E+04, 0.23145300E+03, 0.12246600E+04, 0.40050800E+04, -.72221800E+02, 0.45194200E+03, 0.10495100E+04, 0.12042200E+05, -.59878900E+04, 0.40657200E+04, -.60210900E+04, -.16917300E+04, -.20514600E+04, -.24137500E+04, -.18044700E+04, -.49280000E+04, -.21300700E+04, -.82425100E+04, -.17570800E+04, 0.91301700E+03, 0.29442200E+04, 0.87860100E+03, 0.12001900E+04, 0.20693300E+04, -.59389900E+03, -.47011500E+03, 0.12663000E+04, 0.12232200E+04, -.14591400E+04, 0.32883300E+04, -.16204500E+04, 0.84311800E+04, -.16440000E+04, 0.29860800E+04, -.16044000E+03, 0.17498000E+04, 0.57031200E+04, 0.46453500E+04, 0.21692100E+03, -.77250300E+04, -.12091200E+05, 0.60898900E+04, -.16771600E+04, 0.60464200E+04, 0.21087200E+04, 0.95531200E+03, -.10696600E+04, -.54981700E+04, 0.12758600E+04, 0.11196800E+04, 0.75636700E+04, 0.24903900E+04, -.12121700E+04, 0.31889600E+03, -.12453100E+04, 0.24989700E+03, -.69587600E+03, 0.58363000E+03, 0.69979000E+03, -.21783900E+04, -.55241300E+03, 0.87958300E+03, -.15742700E+05, 0.78096000E+04, -.32317200E+04, 0.78712400E+04, 0.20377000E+04, 0.34757600E+04, 0.17506300E+04, 0.68235100E+02, 0.56334100E+04, 0.26427600E+04, 0.13575600E+05, 0.72474000E+03, 0.98799100E+02, -.50207800E+02, -.11167000E+04, -.80501600E+02, -.18164000E+03, -.57028700E+03, -.46254100E+03, -.42292300E+03, -.56047400E+03, 0.41311200E+03, 0.58948800E+03, -.23031900E+01, 0.53284900E+03, 0.11743700E+03, -.65791200E+03, 0.83904500E+03, 0.93425800E+02, -.56506900E+03, 0.97451700E+03, 0.38350100E+03, -.16041000E+03, 0.10869000E+04, 0.96677200E+03, -.38037100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19647900E+01, -.26258700E+00, -.90314800E+00, -.46218400E+00, -.10648000E+01, 0.90389000E-01, 0.28614300E-01, -.62800100E-01, 0.36487100E-01, -.15898300E-02, 0.18959600E+00, -.40779900E+00, -.44750100E+00, 0.26878300E+00, 0.49943800E-01, 0.14511900E+00, -.44989000E+00, 0.60520200E-02, -.18361100E+00, -.30656300E+00, 0.23338700E+00, 0.77847000E-01, -.62871600E-01, -.59122400E+00, -.12761900E+00, 0.64100800E-01, 0.31814900E+00, 0.24067000E+00, -.20975700E+00, 0.60224700E+00, -.27508600E-01, -.51206100E-01, 0.14791800E+00, -.16745600E+05, 0.80869200E+04, 0.50271200E+04, 0.83727800E+04, -.22405100E+04, -.53506000E+04, 0.75766800E+04, 0.30704500E+04, 0.79499500E+04, -.41239800E+04, 0.56157600E+04, 0.86736800E+04, -.43167400E+04, -.32071500E+04, -.43368300E+04, -.22113800E+04, -.13572900E+04, -.18584000E+04, -.20698100E+04, -.31271800E+04, -.96378800E+03, -.21444000E+04, 0.27320300E+04, -.13713100E+04, -.60085700E+03, -.13660100E+04, 0.10395700E+04, -.10333900E+03, 0.65520100E+03, 0.18246100E+04, -.28967600E+03, 0.25106700E+03, -.27922000E+04, 0.20215600E+05, -.99108700E+04, -.67041600E+04, -.10107800E+05, 0.24571700E+04, 0.55288700E+04, -.86714700E+04, -.33436900E+04, -.81857100E+04, 0.42122200E+04, -.65498000E+04, 0.57236300E+04, -.29945700E+04, 0.97839800E+03, -.28618300E+04, -.17831400E+04, -.12898600E+04, -.14162300E+04, -.22127700E+04, -.19453200E+04, -.10192500E+04, -.28539300E+04, 0.60921700E+04, -.30538900E+04, 0.71840900E+03, -.30460800E+04, -.17353400E+04, -.85985400E+03, -.13048300E+03, 0.92984700E+03, -.22524600E+04, -.64561200E+03, -.30117600E+04, 0.30248500E+04, -.15250200E+04, 0.50713900E+03, -.15124300E+04, 0.14754600E+04, -.22785400E+03, 0.71373100E+03, 0.18878900E+04, -.65607200E+03, -.59555100E+02, -.41545000E+04, -.20746700E+04, 0.10406400E+04, -.96022300E+03, 0.10373500E+04, 0.12868500E+02, -.13662000E+03, 0.21642900E+03, -.92193800E+03, 0.17784400E+03, -.21666500E+02, 0.11607800E+04, 0.79103400E+03, -.39950200E+03, 0.11227200E+04, -.39552800E+03, -.28097500E+02, 0.16798900E+03, 0.11933300E+01, -.15815400E+03, 0.10606900E+03, 0.96987700E+02, -.50943600E+03, -.30083400E+04, 0.15456500E+04, -.99612400E+03, 0.15041800E+04, 0.11751200E+04, 0.91718600E+03, 0.83464600E+03, 0.17926600E+04, 0.12854500E+04, 0.67666000E+03, 0.15716900E+04, 0.58279700E+04, -.29410900E+04, 0.21140000E+03, -.29139800E+04, -.12156300E+04, 0.64752700E+03, -.23227000E+04, -.13721900E+04, -.27244700E+04, 0.30248200E+03, -.48485800E+03, 0.29552100E+04, -.14497600E+04, 0.11042500E+04, -.14776100E+04, 0.23392900E+04, 0.83559500E+03, -.12374400E+04, -.10219500E+04, -.14709400E+04, 0.67212800E+03, -.31552900E+04, -.50040400E+03, 0.23591800E+03, -.16082800E+04, 0.25019900E+03, -.14470100E+03, -.35587000E+03, 0.44418600E+03, 0.66966500E+03, 0.68988900E+03, -.25595600E+03, -.33648000E+03, -.41233500E+04, 0.20571500E+04, 0.35149700E+03, 0.20616900E+04, -.14655300E+04, 0.76892600E+03, -.15545300E+04, -.36524000E+04, 0.38581800E+03, 0.46652100E+03, 0.44992800E+04, -.22901500E+04, 0.11607100E+04, -.29765700E+04, 0.11450800E+04, -.15105000E+04, 0.58973800E+03, -.16127600E+04, -.37033700E+04, 0.57501600E+01, 0.37941000E+03, 0.34142900E+04, -.67429100E+04, 0.33702400E+04, -.11142800E+04, 0.33714500E+04, 0.23288100E+04, 0.96047600E+03, 0.22155800E+04, 0.21728200E+04, 0.28947500E+04, 0.12200600E+04, 0.36844500E+03, 0.19867800E+04, -.99845300E+03, -.17134000E+04, -.99338600E+03, 0.12821300E+03, -.40087700E+03, -.67951000E+02, -.11370800E+03, -.76150800E+03, -.55745600E+02, -.16710000E+04, 0.39234000E+04, -.19819000E+04, -.63377100E+04, -.19617000E+04, -.22319100E+04, 0.13905700E+04, -.38393700E+04, -.46141600E+04, -.38376100E+04, 0.11390900E+04, 0.18649800E+04, -.71354100E+04, 0.34982600E+04, 0.59466200E+04, 0.35677400E+04, -.13462100E+04, -.65644700E+03, 0.24543300E+04, 0.81526300E+03, 0.17200500E+04, -.55886600E+03, 0.12576100E+04, -.96509100E+02, 0.70431400E+02, -.13012200E+04, 0.48251200E+02, -.94862200E+03, -.19595100E+03, -.46802100E+03, -.42459100E+03, 0.43474200E+03, -.20914600E+03, 0.22127500E+04, 0.98659000E+04, -.49192800E+04, 0.44971200E+03, -.49329600E+04, -.30395700E+04, -.75212300E+03, -.20662600E+04, -.78770700E+03, -.40853100E+04, -.78643600E+03, -.22669400E+04, -.35196700E+03, -.19672400E+02, 0.27484200E+02, 0.24576300E+03, -.35260500E+03, 0.16191000E+03, 0.45028300E+03, 0.78941600E+02, -.10154200E+04, -.54509200E+02, 0.16703700E+03, -.25506600E+03, -.19420800E+02, -.14727600E+04, 0.49758200E+02, 0.47835400E+03, -.43582100E+03, 0.73988000E+03, -.61317500E+02, -.53682900E+03, -.93630900E+02, -.21295200E+03, 0.32922500E+03, -.46379600E+03, 0.82764000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.90204300E+01, -.92067600E+00, 0.10154000E+01, 0.48237500E+01, 0.55626700E+01, 0.34104800E-01, -.20942500E+01, 0.16209600E+00, -.14497600E+00, -.12693500E+01, -.13305200E+01, -.18272400E-01, 0.50698900E+00, 0.48758100E+01, -.68486900E+00, -.16557800E+01, -.10979700E+01, 0.79932400E+00, 0.15122600E+01, -.14218100E+01, -.31054500E+01, -.86421300E-01, -.10733900E+01, -.40657000E+00, -.12557400E+00, -.24469500E+01, 0.30518400E+01, -.29699400E+01, -.14896600E+01, -.50038600E-01, 0.17840500E+00, -.22950500E+01, 0.31967200E+01, -.42841700E+01, -.10238800E+04, -.12717700E+05, 0.37821500E+01, -.24483800E+05, -.38517200E+05, 0.40167500E+05, 0.40220400E+05, 0.14707000E+05, -.27092200E+05, -.17335100E+05, 0.17364300E+06, -.86143100E+05, -.58047000E+05, -.86822900E+05, -.41421100E+05, -.34835800E+05, -.23302000E+05, 0.96091600E+04, -.70802500E+05, -.32120700E+05, -.53922300E+05, -.23723900E+05, 0.11956400E+05, 0.27520900E+05, 0.11859300E+05, 0.15902000E+05, -.14591700E+05, 0.24595600E+05, 0.22901200E+05, 0.18374600E+05, -.65633600E+04, -.14562000E+05, -.37175100E+05, 0.18418400E+05, 0.30553900E+05, 0.18591100E+05, 0.36385800E+05, 0.47714900E+05, -.46246800E+05, -.59826000E+05, -.72537600E+04, 0.35810100E+05, 0.37314700E+05, 0.14996900E+06, -.77658000E+05, -.27316700E+05, -.74978200E+05, -.15157100E+05, -.85025000E+04, -.25589700E+05, 0.25981500E+04, -.56736600E+05, -.67864500E+04, -.72093500E+05, 0.96065400E+05, -.49094600E+05, 0.46747000E+04, -.48033100E+05, -.14670400E+05, -.82638200E+04, -.10353000E+05, 0.74646900E+04, -.43316900E+05, -.93745100E+04, -.49656600E+05, 0.62379100E+05, -.31592600E+05, -.67201800E+04, -.31188800E+05, -.37856500E+04, -.18920300E+05, 0.15750300E+05, 0.29318000E+05, -.12520100E+05, -.13572200E+05, -.51686800E+05, -.19346400E+05, 0.10657400E+05, -.16828900E+05, 0.96699400E+04, -.62197500E+04, 0.75474500E+04, -.93757300E+04, -.21039600E+05, -.12566700E+05, 0.79960100E+04, 0.21298300E+05, 0.74270100E+05, -.37720400E+05, -.11653100E+05, -.37133200E+05, -.63033400E+03, -.20187600E+05, 0.70382900E+04, 0.27724100E+05, 0.19402700E+05, -.19301800E+05, -.43961400E+05, -.10533900E+06, 0.54640100E+05, 0.17980400E+05, 0.52665200E+05, 0.11730300E+05, 0.70812200E+04, 0.17727800E+05, -.66497700E+03, 0.42631200E+05, 0.51908400E+04, 0.51232500E+05, 0.70070400E+05, -.36151500E+05, 0.50440100E+04, -.35035200E+05, -.10710400E+05, 0.17488700E+04, -.21720100E+05, -.45607200E+04, -.28521500E+05, -.25053900E+04, -.16286900E+05, 0.28186300E+05, -.13172200E+05, 0.23121300E+05, -.14093100E+05, 0.25711100E+05, 0.13235800E+05, -.12933400E+05, -.10255500E+05, -.15981600E+05, 0.99471900E+04, -.31511700E+05, -.43663700E+05, 0.21609200E+05, -.80052300E+04, 0.21836200E+05, 0.21394300E+04, -.13025800E+04, 0.83108200E+04, 0.41465600E+03, 0.13411200E+05, 0.17261100E+04, 0.15229800E+05, -.65023700E+05, 0.32564800E+05, 0.56658000E+04, 0.32508800E+05, 0.10446700E+05, 0.24843600E+05, -.18635100E+05, -.37020800E+05, 0.98102100E+04, 0.16842100E+05, 0.51299100E+05, -.13492400E+05, 0.72563000E+04, -.52329600E+05, 0.67455700E+04, -.19633600E+05, 0.12242500E+05, -.26067200E+05, -.36996400E+05, -.13365300E+05, 0.70037000E+04, 0.38869400E+05, -.16307700E+06, 0.81912500E+05, 0.14349000E+05, 0.81538200E+05, 0.28072900E+05, 0.10160600E+04, 0.45605000E+05, 0.19655700E+05, 0.62099500E+05, 0.97235800E+04, 0.39163100E+05, 0.22794000E+05, -.11144100E+05, -.18517100E+05, -.11397900E+05, -.67967300E+04, -.13515900E+05, 0.64378300E+04, 0.67311300E+04, -.12279100E+05, -.80759000E+04, -.18800600E+05, -.89220600E+04, 0.43360100E+04, -.56660100E+05, 0.44581700E+04, -.20907800E+05, 0.18145000E+05, -.32299300E+05, -.46222700E+05, -.62682400E+05, 0.92111100E+04, 0.50402700E+05, 0.87857500E+05, -.43545400E+05, -.14203400E+05, -.43942300E+05, -.20753800E+05, -.17845800E+05, 0.14203100E+05, 0.41832900E+05, -.61287000E+04, -.16478800E+05, -.58005400E+05, -.24948500E+05, 0.13107300E+05, -.78445700E+04, 0.12476100E+05, 0.94125300E+02, 0.10347300E+05, -.12639500E+05, -.16095500E+05, 0.18804000E+05, 0.82544600E+04, 0.29531300E+05, 0.16297100E+06, -.82148700E+05, -.39898900E+04, -.81483500E+05, -.30302400E+05, -.41152200E+04, -.36173700E+05, -.11690800E+05, -.57801900E+05, -.11077700E+05, -.55672000E+05, -.26362400E+04, 0.17757900E+04, 0.10305100E+04, 0.31893900E+04, -.18986000E+04, 0.18268600E+04, 0.53146700E+04, 0.15418300E+04, 0.95201800E+03, -.75698400E+03, 0.25793300E+04, -.26326400E+04, 0.41799200E+04, -.53496200E+04, 0.15538900E+04, 0.60620500E+04, -.65852900E+04, 0.46291700E+04, -.33463300E+04, -.46743400E+04, -.49182700E+04, 0.88652400E+03, -.61838900E+04, -.49368800E+04, 0.24934200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11167400E+00, -.62197500E-01, -.51334400E+00, 0.34587700E+00, -.40724800E+00, -.57770700E+00, 0.82221100E+00, -.83181500E-03, 0.38446100E-01, -.57264400E+00, -.69095600E-01, -.13739600E+00, -.73156300E-01, 0.21956300E+00, -.51192700E-01, 0.20507300E+00, 0.13864400E+00, -.23301100E+00, 0.15001200E-01, -.26682400E+00, 0.32842800E+00, 0.82161600E-02, -.12992100E+00, -.51850900E+00, 0.29006800E-01, 0.89675400E-01, 0.74941100E+00, 0.60742600E+00, -.33928500E+00, 0.34021400E+00, 0.46607200E-01, 0.21213900E+00, -.16711500E+00, -.20906400E+00, 0.40584700E-01, -.73731000E+04, -.44795900E+00, 0.22944200E+04, 0.67719800E+04, -.79912100E+04, -.78492500E+04, -.28112000E+04, 0.48195400E+04, 0.68436500E+04, -.24380200E+05, 0.12409600E+05, 0.61574600E+04, 0.12190300E+05, 0.44580600E+04, 0.44252200E+04, 0.57676800E+04, 0.17829000E+04, 0.57947000E+04, 0.45647900E+04, 0.48040400E+04, 0.33699100E+04, -.16641100E+04, -.63364300E+04, -.16846400E+04, -.30045300E+04, 0.26300500E+04, -.35254400E+04, -.21986400E+04, -.30479000E+04, 0.11086200E+04, 0.49857600E+04, -.32447600E+04, 0.14392800E+04, 0.10777600E+05, 0.16219400E+04, -.26973600E+04, -.77042100E+04, 0.10394000E+05, 0.10557600E+05, 0.25616500E+04, -.55090600E+04, -.69508300E+04, -.22479400E+05, 0.10588500E+05, -.17761300E+04, 0.11238900E+05, 0.19581400E+04, 0.39279800E+04, 0.25575000E+04, -.13181400E+04, 0.83108200E+04, 0.35046800E+04, 0.11393100E+05, -.22756200E+05, 0.11131800E+05, -.37420100E+04, 0.11378200E+05, 0.16367200E+04, 0.26264200E+04, 0.16661000E+04, -.23233100E+04, 0.68459000E+04, 0.26720800E+04, 0.12681500E+05, -.80884300E+04, 0.39612600E+04, -.20031700E+04, 0.40441200E+04, -.20027400E+04, 0.16628600E+04, -.18430000E+04, -.40088700E+04, -.21956800E+03, 0.11285000E+04, 0.11194800E+05, 0.74545600E+04, -.34406800E+04, 0.58312100E+04, -.37268900E+04, -.30209300E+03, -.17371100E+04, 0.12023500E+04, 0.35123300E+04, -.21276700E+04, -.14764100E+04, -.47814800E+04, -.13540500E+05, 0.65895100E+04, -.29919600E+04, 0.67700400E+04, 0.12974900E+03, 0.39086100E+04, -.13002100E+04, -.11211500E+04, 0.34099500E+04, 0.31710300E+04, 0.74399500E+04, 0.17852600E+05, -.83927400E+04, 0.15692400E+04, -.89258100E+04, -.17366400E+04, -.35505000E+04, -.17115200E+04, 0.13902200E+04, -.66850700E+04, -.30807100E+04, -.90152500E+04, -.22778900E+05, 0.11129300E+05, -.25596600E+04, 0.11389400E+05, 0.29520700E+04, 0.12721500E+04, 0.45258900E+04, -.84463400E+03, 0.10636200E+05, 0.12418600E+04, 0.42737500E+04, -.46993800E+04, 0.25573200E+04, -.47781700E+04, 0.23496800E+04, -.50180600E+04, -.34698400E+04, 0.35166500E+04, 0.37219700E+04, 0.30467700E+04, -.24564800E+04, 0.78307800E+04, 0.97876200E+04, -.49241800E+04, 0.92447900E+03, -.48940700E+04, -.25792800E+03, -.28327500E+03, -.10656800E+04, 0.97202100E+03, -.32302800E+04, -.92281000E+03, -.25881500E+04, 0.10802100E+05, -.53786700E+04, 0.43767500E+04, -.54006600E+04, 0.12592700E+04, -.32661700E+04, 0.31954700E+04, 0.66252200E+04, -.25469200E+03, -.19756500E+04, -.11750900E+05, 0.11930500E+05, -.57945900E+04, 0.12555600E+05, -.59651900E+04, 0.32791500E+04, -.42958800E+04, 0.53752300E+04, 0.94485900E+04, -.17176100E+04, -.28964500E+04, -.13049200E+05, 0.41495800E+05, -.20655600E+05, 0.47699000E+03, -.20747900E+05, -.48087800E+04, -.32109600E+04, -.82770000E+04, -.20750000E+04, -.16192300E+05, -.41004600E+04, -.97683200E+04, 0.19659400E+04, -.87785700E+03, 0.14368400E+04, -.98285900E+03, -.12401400E+03, -.70906300E+01, 0.76413000E+02, 0.10489900E+04, -.19610400E+04, -.24196000E+03, 0.15980100E+04, 0.82794400E+04, -.40703100E+04, 0.19368700E+05, -.41393800E+04, 0.44380000E+04, -.52507900E+04, 0.79686900E+04, 0.79217200E+04, -.36935100E+03, -.30427400E+04, -.16095300E+05, 0.23528500E+04, -.10774300E+04, -.11269600E+05, -.11748100E+04, 0.62380100E+03, 0.40301600E+04, -.69314900E+04, -.72724700E+04, -.23679500E+03, 0.33707000E+04, 0.48918900E+04, 0.16976400E+04, -.72629700E+03, 0.24444800E+04, -.84904500E+03, 0.19041100E+04, -.78339400E+03, 0.12863700E+04, 0.24563600E+04, 0.80893000E+03, -.68875500E+03, -.62966300E+04, -.42963900E+05, 0.21288400E+05, -.14834200E+04, 0.21481700E+05, 0.48122200E+04, 0.37403100E+04, 0.63318700E+04, 0.16776800E+03, 0.16359600E+05, 0.43867100E+04, 0.14421300E+05, 0.14585900E+04, -.89518100E+03, 0.59974300E+03, -.14845500E+04, 0.18192800E+04, -.94007600E+03, 0.26709900E+03, 0.11347100E+04, -.79493600E+03, 0.88070600E+02, 0.56351900E+02, 0.63454400E+03, -.33299100E+03, 0.41804300E+03, -.91344900E+03, -.21715700E+04, 0.79080400E+03, -.12040200E+04, 0.49867300E+03, 0.39971200E+03, 0.66490900E+03, 0.27767300E+03, 0.13867900E+04, 0.11784200E+04, -.11912000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37485400E+01, -.40897000E+00, -.24069100E+00, 0.68874100E+00, 0.10533000E+01, 0.54109700E+00, -.10012700E+01, -.15124900E-01, 0.80311900E-01, -.84661000E+00, 0.45730800E-01, -.10809300E+01, -.47522200E+00, 0.72173300E+00, 0.71932800E-01, -.13008300E+01, -.21592000E+01, 0.94899100E-01, 0.17235400E+00, -.53257500E+00, -.69910800E+00, 0.28791000E-02, -.34770900E+00, -.54591200E+00, 0.10099600E+00, -.23227200E+00, 0.77438200E+00, 0.60401100E+00, 0.10134200E-01, -.18565800E+00, 0.11393600E+00, -.29094100E+00, 0.63431000E+00, -.97447500E+00, 0.17118800E+00, -.11289500E+01, -.13951600E+02, 0.21229300E+04, 0.48724200E+04, -.59584000E+04, -.56098700E+04, -.27658600E+04, 0.33858800E+04, 0.58104700E+04, -.24583600E+05, 0.12792500E+05, 0.39158000E+04, 0.12292000E+05, 0.72881400E+04, 0.54090500E+04, 0.59576900E+04, 0.22912600E+04, 0.44864400E+04, 0.53806400E+04, 0.55224900E+04, 0.62392900E+04, -.30500800E+04, -.74307200E+04, -.31238200E+04, 0.53893100E+03, 0.28571000E+04, -.42088500E+04, -.14729700E+04, -.46634300E+04, 0.18224900E+04, 0.35737300E+03, -.70839100E+04, 0.30567500E+04, 0.24337200E+04, 0.35656400E+04, -.22958100E+04, -.51250200E+04, 0.82216200E+04, 0.75506400E+04, 0.35589400E+04, -.34851500E+04, -.37712700E+04, -.16371900E+05, 0.66296500E+04, 0.23285600E+04, 0.81809500E+04, 0.19802600E+04, 0.26516900E+04, 0.23885200E+04, -.12884800E+04, 0.63581000E+04, 0.27024200E+04, 0.75990300E+04, -.21942000E+05, 0.10375500E+05, -.20876100E+04, 0.10967800E+05, 0.33459000E+04, 0.10021100E+04, 0.31751100E+04, 0.37276100E+03, 0.63009000E+04, 0.14788100E+04, 0.12961400E+05, -.77542300E+04, 0.36960700E+04, -.38753100E+04, 0.38773400E+04, -.21722600E+03, 0.87892400E+03, -.19699600E+04, -.41677700E+04, -.19396100E+04, 0.10348100E+04, 0.98287000E+04, 0.47660000E+04, -.17162000E+04, 0.48865300E+04, -.23857000E+04, -.88355200E+03, -.36043500E+03, 0.30237300E+03, 0.73131900E+03, -.27241700E+04, -.53391800E+03, -.19560100E+04, -.86915600E+04, 0.39325800E+04, -.92651300E+03, 0.43480700E+04, 0.15953800E+04, 0.28992800E+04, -.17707500E+04, 0.16017100E+04, 0.36714800E+04, 0.22668500E+04, 0.40372300E+04, 0.12031800E+05, -.47502100E+04, -.25207500E+04, -.60130200E+04, -.13916600E+04, -.21801900E+04, -.16345200E+04, 0.11730300E+04, -.44660900E+04, -.22128000E+04, -.54431700E+04, -.21160300E+05, 0.99368900E+04, 0.80460400E+03, 0.10578000E+05, 0.29160400E+04, -.10213900E+04, 0.56769400E+04, 0.35375600E+03, 0.11929400E+05, -.96944300E+03, 0.38907200E+04, -.42236100E+04, 0.26274400E+04, -.87861200E+04, 0.21120400E+04, -.46964900E+04, -.42064700E+04, 0.32994800E+04, 0.31058500E+04, 0.26451100E+04, -.29002100E+04, 0.76561300E+04, 0.12862200E+05, -.65068400E+04, 0.18991400E+04, -.64313500E+04, -.30642500E+03, -.25905400E+02, -.14472300E+04, 0.14250100E+04, -.44166900E+04, -.70632400E+03, -.46761500E+04, 0.55863100E+04, -.27665800E+04, 0.50854700E+04, -.27951000E+04, 0.21414200E+03, -.86598600E+03, 0.30096300E+04, 0.50508700E+04, 0.23007200E+04, -.59281100E+03, -.82782000E+04, 0.77384400E+04, -.35185800E+04, 0.11858600E+05, -.38665300E+04, 0.46571300E+03, -.23865200E+04, 0.51971800E+04, 0.72187900E+04, -.56338100E+03, -.20030200E+04, -.90709800E+04, 0.42985300E+05, -.21254200E+05, -.27374200E+04, -.21492900E+05, -.44845300E+04, -.23072700E+04, -.97416900E+04, -.39665100E+04, -.18052400E+05, -.27089800E+04, -.13947300E+05, 0.60083600E+03, -.57004900E+02, 0.72993500E+03, -.30196100E+03, 0.68490400E+03, -.76142000E+02, 0.58644800E+03, 0.10704500E+04, -.28001500E+04, 0.19468100E+03, 0.97642000E+03, 0.57579200E+04, -.27868100E+04, 0.17482000E+05, -.28794200E+04, 0.25338500E+04, -.23889700E+04, 0.69642300E+04, 0.33681700E+04, -.37075400E+04, -.11351400E+04, -.12742000E+05, 0.48030400E+04, -.21370300E+04, -.72550500E+04, -.24185900E+04, 0.21994300E+04, 0.43898600E+04, -.71240200E+04, -.65437700E+04, -.18582400E+03, 0.37677900E+04, 0.28145400E+04, 0.32171400E+04, -.13074400E+04, 0.32703800E+04, -.16111100E+04, -.22330600E+03, -.12795000E+04, 0.19224900E+04, 0.44406500E+04, 0.27736200E+04, -.13792200E+04, -.62872400E+04, -.44196100E+05, 0.21628700E+05, 0.18471700E+04, 0.22100800E+05, 0.55270800E+04, 0.18130900E+04, 0.82627100E+04, 0.29749200E+04, 0.18308400E+05, 0.24741800E+04, 0.17525000E+05, 0.95101100E+03, -.56744100E+03, -.18846400E+03, -.97992800E+03, 0.41652800E+03, -.19746400E+03, 0.69522700E+02, 0.77072600E+02, 0.11858900E+04, 0.37909300E+03, -.91251600E+03, 0.48377300E+03, -.41662600E+03, 0.17926900E+04, -.77218000E+03, -.17667600E+04, 0.19324600E+04, -.11746400E+04, 0.31875400E+03, 0.12370600E+04, -.33133500E+03, -.86821300E+02, -.15142400E+03, -.67235000E+02, -.10171100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.78111600E+01, -.72636400E+00, 0.16146600E+01, -.11550500E+01, -.10017300E+01, 0.22363900E+01, -.91908300E+00, 0.12517200E+00, 0.10308100E+01, -.11039100E+01, -.25383400E+00, 0.36371700E+00, 0.27050100E+00, 0.27816000E+01, -.88593800E+00, -.28937900E+00, 0.62195700E+00, 0.27304500E+01, -.81054800E+00, -.48848800E-01, -.72496500E-01, 0.26907200E-01, -.19040800E+00, -.26774300E+01, -.24230500E+00, -.40739300E+00, 0.56405500E+00, -.21965200E+01, 0.10484200E+01, -.66071700E+00, -.15657600E+00, -.17108100E+01, -.17601100E+00, 0.20336400E+01, -.70609600E+00, 0.20815700E+01, -.51019100E-01, -.20580400E+05, -.38700400E+05, 0.39572800E+05, 0.33476800E+05, 0.13702700E+05, -.26483500E+05, -.29275200E+05, 0.15566000E+06, -.78926400E+05, -.50520200E+05, -.77830100E+05, -.39094900E+05, -.33082800E+05, -.23645000E+05, 0.10145300E+05, -.43321900E+05, -.33646700E+05, -.41120100E+05, -.42079000E+05, 0.20919600E+05, 0.36700100E+05, 0.21038800E+05, 0.12872500E+05, -.18149300E+05, 0.29568000E+05, 0.20121900E+05, 0.29906700E+05, -.94986900E+04, -.59962100E+04, 0.23919300E+04, -.38110400E+03, -.66187000E+03, -.11941700E+04, 0.28035800E+05, 0.44683000E+05, -.49335700E+05, -.47307700E+05, -.10428000E+05, 0.31900400E+05, 0.33808900E+05, 0.14094300E+06, -.67378200E+05, -.13332900E+05, -.70470600E+05, -.13591000E+05, -.19221000E+05, -.18885200E+05, 0.71750700E+04, -.53700600E+05, -.17554500E+05, -.72399000E+05, 0.11604200E+06, -.56968300E+05, 0.56637500E+04, -.58021500E+05, -.15680500E+05, -.84657500E+04, -.14021700E+05, 0.36362900E+04, -.41609100E+05, -.11013500E+05, -.62685600E+05, 0.53345800E+05, -.26373200E+05, 0.41535700E+04, -.26672700E+05, 0.20367400E+04, -.14883700E+05, 0.14626900E+05, 0.25839800E+05, 0.92157300E+03, -.10870500E+05, -.57828100E+05, -.29522900E+05, 0.13430600E+05, -.21582400E+05, 0.14760700E+05, -.19619200E+04, 0.52868300E+04, -.63878000E+04, -.18076100E+05, -.34409600E+03, 0.59326500E+04, 0.20219100E+05, 0.83994500E+05, -.41144400E+05, -.93281100E+04, -.41996800E+05, -.31577100E+04, -.17910900E+05, 0.47116000E+04, 0.12559900E+05, -.28583100E+04, -.15764400E+05, -.43542200E+05, -.10159200E+06, 0.48299500E+05, 0.95204500E+04, 0.50795300E+05, 0.11245900E+05, 0.16068200E+05, 0.12628500E+05, -.56646100E+04, 0.39575300E+05, 0.14290700E+05, 0.52865400E+05, 0.11525800E+06, -.56426600E+05, -.29274100E+04, -.57629200E+05, -.14820200E+05, 0.63403600E+04, -.31518300E+05, -.14805800E+04, -.54730800E+05, 0.27257900E+04, -.26524900E+05, 0.25570000E+05, -.13741400E+05, 0.34039900E+05, -.12785000E+05, 0.29794700E+05, 0.17729200E+05, -.17331600E+05, -.19027600E+05, -.16738300E+05, 0.12567000E+05, -.38215700E+05, -.55894500E+05, 0.28050500E+05, -.86935500E+04, 0.27950000E+05, 0.23922900E+04, -.15720600E+04, 0.76511300E+04, -.30004000E+04, 0.18157900E+05, 0.28162300E+04, 0.18079400E+05, -.49995600E+05, 0.24954500E+05, -.10326100E+05, 0.24997100E+05, 0.19882800E+04, 0.18121100E+05, -.18380600E+05, -.31658300E+05, -.18914400E+04, 0.10797600E+05, 0.52951200E+05, -.36171300E+05, 0.17312000E+05, -.54727400E+05, 0.18085600E+05, -.16292300E+05, 0.15545400E+05, -.27772100E+05, -.40652500E+05, -.66397400E+04, 0.96291700E+04, 0.49450200E+05, -.22145100E+06, 0.11028400E+06, 0.25031400E+05, 0.11072600E+06, 0.29089800E+05, 0.35300700E+04, 0.55370000E+05, 0.22877400E+05, 0.88426500E+05, 0.12278400E+05, 0.63769500E+05, -.33584300E+04, 0.11313600E+04, -.75849900E+04, 0.16789700E+04, -.37345700E+04, -.10381700E+05, 0.69930900E+04, 0.31596200E+04, 0.71716400E+04, -.70012500E+04, -.87063000E+04, -.26967000E+05, 0.13114400E+05, -.76347300E+05, 0.13482900E+05, -.24035700E+05, 0.16836200E+05, -.32912000E+05, -.29636200E+05, -.25864200E+05, 0.59473400E+04, 0.70343600E+05, 0.39161800E+05, -.19915500E+05, 0.19014400E+05, -.19584200E+05, -.15638100E+05, -.22699000E+05, 0.26530100E+05, 0.37772300E+05, -.66460800E+04, -.20284800E+05, -.43146600E+05, -.21949600E+05, 0.10471900E+05, -.10219700E+05, 0.10975000E+05, -.18807700E+04, 0.92585000E+04, -.11822500E+05, -.19243400E+05, 0.27967700E+04, 0.81157200E+04, 0.33643700E+05, 0.20651500E+06, -.10235400E+06, -.81004800E+04, -.10325700E+06, -.32842500E+05, -.69039600E+04, -.41316200E+05, -.17525900E+05, -.81532200E+05, -.14520900E+05, -.73497100E+05, -.51654500E+04, 0.26681400E+04, 0.12708700E+04, 0.54676400E+04, -.21253800E+04, 0.16315900E+04, 0.33477300E+04, 0.87297400E+03, 0.98791500E+03, -.16969600E+04, 0.23196700E+04, -.29331900E+04, 0.36426600E+04, -.56111300E+04, 0.37749200E+04, 0.93466800E+04, -.75159700E+04, 0.55419300E+04, -.20969100E+04, -.62625800E+04, -.17428600E+04, 0.11522200E+04, -.44340300E+04, -.41205200E+04, 0.43661300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25158600E+01, -.26028000E+00, -.98482100E-01, 0.15101300E+00, -.42585600E+00, -.20471900E+00, -.40023100E-01, -.10424200E+00, -.22212500E+00, -.78824600E-01, -.12493900E+00, -.45351300E+00, -.42937000E+00, -.48610500E+00, 0.94752800E-02, -.78119900E-02, -.62304400E+00, 0.76350800E+00, -.40158200E+00, -.11004500E+00, 0.14522300E+00, 0.17599900E-01, 0.61151700E-01, -.25196600E+00, -.24859800E-02, 0.12965200E+00, 0.14311600E+01, -.48852900E+00, -.88533000E-02, 0.21306100E+00, -.16839900E-01, -.11328100E+00, -.44587900E+00, 0.80366600E-01, 0.46031900E-01, 0.91599600E+00, 0.24366800E-02, -.11083600E+00, -.55945300E+04, 0.59142300E+04, 0.33142900E+04, 0.21754900E+04, -.33310300E+04, -.91422100E+04, 0.26343000E+05, -.13364400E+05, -.14671400E+05, -.13171500E+05, -.61517700E+04, -.39227200E+04, -.56100300E+04, 0.10313100E+04, -.54777100E+04, -.52342700E+04, -.57568600E+04, -.10018900E+05, 0.49911800E+04, 0.35338800E+04, 0.50094100E+04, 0.12562600E+04, -.58903800E+04, 0.70617400E+04, 0.50621800E+04, 0.72431200E+04, -.45399500E+04, -.31766600E+04, 0.47349800E+04, -.23073300E+04, -.16309500E+04, -.23673600E+04, -.60432600E+03, 0.61221700E+04, -.74804000E+04, -.42440500E+04, -.13439900E+04, 0.36018000E+04, 0.90659000E+04, -.70750200E+04, 0.38813300E+04, 0.45668700E+04, 0.35375800E+04, -.21538100E+03, -.67645100E+04, 0.68656700E+04, 0.61800000E+04, 0.40658600E+04, -.61161700E+04, -.33396300E+03, 0.11754200E+05, -.57145900E+04, -.99373800E+03, -.58771300E+04, -.22006300E+04, 0.63512300E+02, -.17011200E+04, -.21320900E+04, -.36851300E+04, -.72355800E+03, -.73425400E+04, 0.10668900E+05, -.52911900E+04, -.17618900E+04, -.53344500E+04, 0.19475700E+03, -.30203400E+04, 0.24756500E+04, 0.52415300E+04, 0.29944500E+03, -.25078700E+04, -.13180300E+05, -.73626400E+04, 0.34658600E+04, -.39037600E+02, 0.36812700E+04, 0.87788400E+03, 0.24184700E+04, -.18970300E+04, -.48906700E+04, 0.60749100E+03, 0.25634500E+04, 0.28361800E+04, 0.17264000E+05, -.84910700E+04, -.65532200E+04, -.86319700E+04, -.23299900E+04, -.39204600E+04, 0.15563400E+04, 0.29565700E+04, -.17649400E+04, -.35678800E+04, -.71642400E+04, 0.56852900E+04, -.31415800E+04, -.39315100E+04, -.28426900E+04, 0.24258700E+03, 0.53170000E+04, -.52776600E+04, -.45665500E+04, -.29122200E+04, 0.46767700E+04, 0.21183600E+03, 0.14837700E+05, -.72384800E+04, -.20875100E+04, -.74188400E+04, -.30165400E+04, 0.29188600E+04, -.47281600E+04, -.29038500E+02, -.81080300E+04, 0.24816600E+04, 0.20874300E+04, -.16126900E+01, -.13790200E+03, 0.58139900E+04, 0.80788500E+00, 0.31895200E+04, 0.33225100E+04, -.17146400E+04, -.31338900E+04, -.13202200E+04, 0.20426200E+04, -.69808200E+04, -.10037200E+05, 0.50339300E+04, 0.89564400E+03, 0.50188700E+04, 0.98338600E+03, -.10867700E+04, 0.16854500E+04, 0.33556600E+02, 0.33518500E+04, 0.26075800E+02, 0.17676200E+04, -.80995100E+04, 0.40381700E+04, 0.13424200E+04, 0.40497100E+04, -.60374100E+03, 0.31044100E+04, -.35535900E+04, -.59467600E+04, -.15700100E+04, 0.15911300E+04, 0.11337900E+05, -.72070400E+04, 0.34686700E+04, -.15102200E+04, 0.36035200E+04, -.15198400E+04, 0.46182600E+04, -.68736100E+04, -.99760100E+04, -.16663800E+04, 0.35315300E+04, 0.94165000E+04, -.32204800E+05, 0.16031000E+05, 0.94967600E+04, 0.16102400E+05, 0.41857900E+04, -.41426400E+04, 0.10575600E+05, 0.73246200E+04, 0.13870200E+05, -.21168100E+04, 0.34285000E+04, -.17286000E+04, 0.76777500E+03, -.32967500E+02, 0.86428400E+03, -.30916600E+02, -.23030200E+04, 0.11906700E+04, 0.56141200E+03, 0.24704800E+04, -.19924100E+04, -.28876300E+04, -.63308900E+04, 0.30806600E+04, -.58954900E+04, 0.31654100E+04, -.38066800E+04, 0.47562400E+04, -.85185500E+04, -.64490800E+04, -.38419600E+04, 0.25498900E+04, 0.15866000E+05, -.71520100E+04, 0.35444100E+04, 0.42987100E+04, 0.35757800E+04, 0.86112600E+03, -.46567100E+04, 0.74401800E+04, 0.59117400E+04, 0.19413500E+04, -.42221300E+04, -.34745300E+04, -.45209900E+04, 0.21905400E+04, 0.26485600E+03, 0.22605100E+04, 0.31361200E+03, 0.14685200E+04, -.14698600E+04, -.39358700E+04, 0.37888500E+03, 0.16417200E+04, 0.76747800E+04, 0.22849800E+05, -.11274600E+05, -.40413900E+04, -.11424900E+05, -.46900900E+04, 0.33190800E+04, -.70953200E+04, -.86646300E+04, -.10630900E+05, 0.13758500E+04, -.41874700E+04, -.12686800E+04, 0.73676600E+03, -.64785100E+02, 0.12812500E+04, -.24607700E+04, 0.55118100E+03, 0.95498000E+03, -.20752500E+04, -.35465300E+03, -.11332300E+04, 0.21432700E+03, -.12524500E+03, 0.24624600E+03, -.99826000E+03, 0.14541800E+04, 0.19743700E+04, 0.39552000E+02, 0.11018900E+04, -.68124600E+03, -.15240400E+04, -.23729100E+03, 0.33956900E+02, -.11386300E+04, -.10106700E+04, 0.82795500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.61082700E+00, 0.12707800E+00, 0.99753200E+00, 0.24932000E+00, 0.43214500E+00, 0.34751500E+00, -.65385400E+00, 0.76594400E-02, -.62952100E-01, 0.70370100E+00, 0.32483200E+00, 0.51353300E+00, 0.72814600E+00, 0.19823700E+00, -.43583300E-01, 0.43906200E-02, -.65521900E-01, 0.55268800E-01, 0.63766800E-02, 0.34371700E-01, 0.99658700E-02, -.12438000E-01, 0.33520100E-01, 0.80271000E-02, -.36320100E-01, -.49832000E-01, -.97109000E-01, -.54513400E-01, -.20104400E-01, 0.52003000E-01, -.12510700E-01, -.52343400E+00, 0.80540200E-01, 0.27538900E+00, -.88562900E-01, -.46356500E+00, -.12450600E-01, -.42253200E-01, -.76443700E-01, 0.13937800E+04, 0.17118500E+04, 0.14364600E+04, 0.70978200E+03, -.12762200E+04, 0.79847400E+04, -.39284900E+04, -.40387200E+04, -.39924500E+04, -.36241200E+04, -.52815200E+04, 0.16039400E+04, 0.19938800E+04, -.84649200E+03, -.51680200E+04, -.10639000E+04, -.67273400E+04, 0.33657300E+04, 0.39710000E+04, 0.33634500E+04, 0.72064900E+03, -.41668200E+03, 0.34267700E+04, 0.20777900E+04, 0.40822300E+04, 0.79260100E+03, 0.35058300E+04, -.99919800E+03, 0.35289400E+03, -.11014700E+03, 0.50021900E+03, -.15582900E+03, -.92492000E+03, -.12743900E+04, -.22503800E+04, -.16297900E+00, -.14579900E+04, 0.17397100E+04, 0.11080900E+05, -.58010500E+04, 0.81545500E+03, -.55401300E+04, 0.50662900E+03, 0.11280800E+04, -.23390300E+04, 0.10733000E+04, -.34675500E+04, 0.56879100E+03, -.55271000E+04, 0.12705800E+05, -.64823100E+04, -.34636400E+03, -.63529800E+04, -.36854500E+03, -.13809900E+04, -.11192400E+04, 0.13632000E+04, -.39606100E+04, -.20831000E+04, -.66810900E+04, 0.17852100E+04, -.95893800E+03, 0.29476700E+04, -.89256700E+03, 0.83334500E+03, 0.33074600E+03, 0.13631600E+04, 0.14228600E+04, 0.13699300E+04, 0.99141600E+03, -.24474800E+04, 0.69100100E+03, -.21998800E+03, -.40072200E+04, -.34573300E+03, -.22155900E+04, -.25320500E+04, 0.95327400E+03, 0.15026800E+03, -.82938400E+03, -.20609000E+04, -.97671800E+03, 0.22875300E+04, -.12220000E+04, 0.18812100E+04, -.11436300E+04, 0.83945200E+03, 0.20480900E+04, -.14678000E+04, -.16495400E+04, 0.27047300E+03, 0.21401400E+04, -.42766200E+02, -.83177300E+04, 0.43852500E+04, -.31400600E+03, 0.41586400E+04, -.92073900E+02, -.47732900E+03, 0.14714600E+04, -.10357500E+04, 0.26727600E+04, -.10823800E+03, 0.43476800E+04, 0.13513800E+05, -.68804200E+04, 0.31754600E+03, -.67569200E+04, -.37368500E+03, 0.30395400E+04, -.46601100E+04, 0.15077900E+03, -.66731600E+04, 0.17539300E+04, -.42821700E+04, -.13848700E+04, 0.78823200E+03, 0.42890300E+04, 0.69244100E+03, 0.28814600E+04, 0.23444300E+03, -.32391100E+03, -.21789600E+04, 0.14452600E+03, 0.15911000E+03, -.21496300E+04, 0.90336700E+02, -.72316000E+02, -.27569000E+04, -.44750800E+02, -.49628200E+03, -.59767000E+02, -.16281700E+03, 0.78928900E+03, 0.68416800E+03, 0.55018600E+03, 0.21469900E+03, -.19750800E+04, 0.10089600E+04, -.21731100E+04, 0.98732900E+03, -.13658000E+03, -.31876900E+03, -.11989600E+04, -.17908700E+04, -.50577400E+03, -.10154500E+04, 0.25031200E+04, 0.40100500E+03, -.11763400E+03, -.68975300E+04, -.20048000E+03, -.26632100E+04, -.26228500E+04, -.20379900E+03, -.42741000E+03, -.10211800E+04, -.29960400E+04, 0.12563300E+04, -.21911800E+05, 0.10982500E+05, 0.29896100E+04, 0.10955900E+05, 0.20310800E+04, 0.18163700E+04, 0.54375200E+04, 0.22043400E+04, 0.85484700E+04, 0.33217900E+04, 0.95295500E+04, -.21612100E+04, 0.11010000E+04, -.46718600E+03, 0.10805200E+04, -.78443000E+02, -.15744200E+04, 0.19964200E+04, 0.66338200E+03, 0.16704400E+04, -.96162100E+03, 0.10931000E+04, 0.51574600E+04, -.25803400E+04, -.10765200E+05, -.25789300E+04, -.46329400E+04, -.41295100E+04, 0.95305900E+03, 0.16335000E+04, -.31527600E+04, -.47776200E+04, 0.13003200E+04, 0.16314300E+04, -.68550100E+03, 0.42423100E+04, -.81683100E+03, 0.15005800E+04, 0.26747600E+04, -.57041400E+03, 0.50386800E+03, -.10814100E+04, 0.23396700E+04, -.15470300E+04, -.98336300E+03, 0.57465200E+03, -.28441100E+04, 0.49176800E+03, -.14448700E+03, 0.11348800E+02, -.15880300E+04, -.14376900E+04, -.65581600E+03, -.43833600E+03, 0.13946900E+04, 0.18287200E+05, -.92066900E+04, -.21721200E+03, -.91434400E+04, -.12894800E+04, -.27774500E+04, -.25858200E+04, 0.17414600E+03, -.69067700E+04, -.43965900E+04, -.92725900E+04, 0.12680500E+03, -.42493100E+03, 0.13840800E+04, -.25651100E+03, -.83586000E+03, -.63660000E+03, 0.86556400E+03, -.86869600E+03, 0.17260100E+04, 0.70925800E+03, 0.94163400E+03, -.61965700E+03, 0.40345100E+03, 0.14970600E+04, -.48995500E+03, 0.12923500E+03, -.19206400E+04, 0.77933100E+03, 0.62363400E+03, -.13092900E+04, 0.66889500E+03, 0.13673300E+03, -.10357900E+04, 0.37276500E+03, -.12953000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37187700E+01, -.76712700E-01, 0.29752800E+01, 0.13093800E+01, -.13032000E+01, 0.37863900E+00, -.15644300E+00, -.26834600E+00, 0.12782800E+00, -.38119900E+00, 0.24579700E+00, -.64048200E+00, -.24704900E+01, 0.11660900E+01, 0.42809000E+00, 0.12216200E+00, -.13371100E+01, 0.15327600E+01, 0.10896600E+01, -.22300000E-01, 0.56657500E+00, 0.32103900E+00, 0.28641500E+00, -.13670000E+01, -.73952800E-01, -.64696500E+00, -.70292400E+00, 0.22137500E+01, 0.60923700E+00, -.76352300E+00, 0.19676600E+00, -.53237200E+00, -.16812500E+01, -.38204100E+00, 0.65157000E-01, -.46391600E+00, -.50168600E-01, 0.13693800E-01, 0.32082100E+00, 0.10817400E+01, 0.42563800E+04, 0.32318700E+03, -.23929900E+04, -.74973100E+03, -.61188700E+04, 0.32554200E+04, 0.24864500E+04, 0.30592700E+04, 0.41488300E+04, 0.98414800E+04, -.59652900E+04, -.12145900E+05, -.57738400E+04, 0.10729500E+05, 0.28701700E+04, 0.25301700E+05, -.12587600E+05, -.12627200E+05, -.12651300E+05, 0.10742800E+04, 0.47316000E+04, -.96867900E+04, -.32284800E+02, -.12970000E+05, 0.15386500E+04, -.12928300E+05, -.91103800E+03, 0.44794400E+03, 0.29008500E+04, 0.45675900E+03, 0.10182200E+02, 0.23254800E+04, -.98616200E+03, -.53950700E+04, -.40331100E+04, 0.45056200E+04, 0.26194800E+04, -.13082600E+05, 0.63258100E+04, -.56347300E+04, 0.65419800E+04, -.20242400E+04, -.36101300E+04, 0.44944000E+04, -.55686000E+03, 0.54715300E+04, -.23144100E+04, 0.86730700E+04, -.20389900E+05, 0.10134400E+05, 0.62760100E+03, 0.10194800E+05, -.90284600E+03, -.71315600E+02, 0.42858300E+04, 0.87081000E+03, 0.52117100E+04, 0.26281800E+04, 0.11677900E+05, -.22881900E+04, 0.12116500E+04, -.62092300E+04, 0.11441800E+04, 0.16430200E+04, 0.27475600E+04, -.50518700E+04, -.58951200E+03, -.58949900E+04, 0.11436100E+04, 0.34715500E+03, 0.15036200E+04, -.66928000E+03, 0.55990700E+04, -.75230100E+03, 0.55983900E+03, 0.17003700E+04, 0.56495300E+03, -.14347500E+04, 0.58807500E+03, 0.12034900E+04, 0.69800900E+03, -.17370300E+05, 0.86266400E+04, 0.22979700E+04, 0.86854400E+04, 0.12890300E+04, -.12692500E+03, 0.21003000E+04, 0.46750600E+04, 0.33248800E+04, -.69892100E+03, 0.69493300E+04, 0.10986400E+05, -.53264800E+04, 0.32333400E+04, -.54936500E+04, 0.11579600E+04, 0.18060700E+04, -.28416700E+04, 0.15572200E+04, -.40919200E+04, 0.93594200E+03, -.76070100E+04, -.29533900E+05, 0.14637600E+05, 0.16085600E+04, 0.14766900E+05, 0.23886200E+03, -.51420300E+04, 0.93889700E+04, -.29117300E+04, 0.14994700E+05, -.28108300E+04, 0.13589400E+05, 0.45651900E+04, -.21996300E+04, -.91394600E+04, -.22825800E+04, -.61146200E+04, -.23646400E+04, 0.25813200E+02, 0.31967600E+04, -.93901800E+03, -.11453300E+04, 0.12658100E+04, 0.56652500E+04, -.28540300E+04, 0.25480700E+04, -.28332600E+04, 0.10910900E+04, 0.43999400E+03, -.58275100E+03, 0.39880900E+03, -.18020400E+04, -.14941400E+04, -.16387600E+04, -.54458100E+04, 0.26587700E+04, 0.12810900E+05, 0.27224500E+04, -.69112900E+03, -.66147500E+01, 0.17759300E+04, -.41769300E+04, 0.36023100E+04, 0.21387400E+04, 0.22102800E+04, 0.53779100E+04, -.27008200E+04, 0.10357500E+05, -.26889100E+04, -.10228900E+03, 0.15575200E+03, 0.12632900E+04, -.36904500E+04, 0.16041100E+04, 0.16012500E+04, -.68256300E+03, 0.57140700E+05, -.28464600E+05, -.14707700E+05, -.28570400E+05, -.59726700E+03, -.10143400E+04, -.12347600E+05, 0.31151400E+04, -.20162000E+05, -.54811200E+04, -.28656900E+05, 0.11384100E+05, -.55905800E+04, -.52730900E+04, -.56922000E+04, 0.65865000E+02, 0.25781100E+04, -.59002900E+04, -.16240500E+04, -.69688900E+04, 0.15339200E+04, -.48634600E+04, 0.93735400E+03, -.45053900E+03, 0.18990300E+05, -.46908600E+03, 0.45818200E+04, 0.31852500E+04, -.38125900E+04, -.13967400E+05, -.93944700E+03, 0.62020800E+04, -.15595700E+04, -.12229300E+05, 0.60597700E+04, -.55332000E+04, 0.61123200E+04, 0.94369800E+03, -.29376900E+04, 0.26578300E+04, 0.34664800E+04, 0.71094200E+04, -.27656000E+04, 0.25693300E+04, 0.71189900E+04, -.35805800E+04, 0.21693300E+04, -.35593100E+04, -.27017300E+04, -.34027000E+04, 0.49142800E+04, 0.49893300E+04, 0.28926500E+04, -.23783400E+04, -.20786000E+04, -.37983900E+05, 0.18856500E+05, 0.50381000E+04, 0.18992200E+05, -.12327300E+04, 0.71322500E+03, 0.82598800E+04, -.26820600E+03, 0.13738600E+05, 0.63053400E+04, 0.20340400E+05, 0.53472000E+03, 0.22113200E+03, -.23226800E+04, -.63707800E+03, -.22078800E+04, 0.13761200E+04, -.85410700E+03, -.20480600E+04, -.18196600E+04, -.85163000E+03, -.10860900E+04, 0.10024300E+04, -.19078800E+04, -.18086300E+04, 0.13234200E+03, -.13219400E+04, 0.25287900E+04, 0.50056300E+03, -.11810700E+04, 0.98573100E+03, -.11501700E+04, -.19217900E+04, -.29892700E+03, -.94390600E+03, -.23457900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24523100E+01, -.14827100E+00, 0.15353300E+01, 0.52213300E+00, 0.10721400E+01, 0.11294100E+01, -.14087800E+01, -.28653700E-01, 0.48774700E-01, -.79515600E+00, 0.33971000E-01, 0.39586900E+00, 0.39221100E+00, 0.49778300E+00, 0.10804500E+00, -.91316900E+00, -.64707200E-01, 0.45275700E+00, 0.47735600E+00, -.20899300E+00, -.83439100E+00, 0.33758600E-01, -.17539200E+00, -.53737600E+00, 0.49603600E-01, 0.14305000E+00, -.23390700E+00, -.25073200E+00, 0.51010300E+00, -.33932300E+00, 0.22491300E-01, -.80505700E-02, -.26970100E+00, -.30831900E+00, -.28238200E+00, 0.15153500E+00, -.21466100E-01, 0.28458600E+00, -.44900000E+00, 0.20417200E+01, 0.25776300E+00, -.23426700E+04, -.10677300E+04, 0.95959300E+03, 0.32945600E+03, 0.18399300E+03, -.32590200E+04, -.16456100E+03, 0.42510600E+04, 0.79869500E+04, -.54267800E+04, -.14879700E+04, -.62269000E+04, 0.76102400E+04, -.23930800E+04, 0.10869000E+05, -.53629100E+04, -.89028000E+04, -.54340700E+04, -.90938900E+03, -.20126000E+04, -.29834200E+04, -.85025200E+02, -.58523900E+04, -.36312000E+04, -.79904600E+04, -.55447400E+04, 0.23949100E+04, 0.34126200E+04, 0.27710900E+04, 0.13041200E+04, 0.28858900E+04, -.49337600E+03, -.14206300E+04, 0.86628500E+03, 0.36475700E+04, 0.14298100E+04, -.26373100E+05, 0.11761700E+05, 0.11471600E+03, 0.13185900E+05, -.87245200E+03, -.45201500E+04, 0.74230200E+04, -.26222300E+03, 0.87836100E+04, -.32548100E+04, 0.11797100E+05, -.29406600E+05, 0.14221300E+05, 0.41808100E+03, 0.14703400E+05, 0.70568200E+03, 0.30565300E+04, 0.31031400E+04, -.30324600E+04, 0.77478500E+04, 0.41582000E+04, 0.15412700E+05, 0.53105400E+04, -.27744200E+04, -.10973600E+05, -.26553500E+04, -.36746500E+04, -.42717200E+04, -.18283100E+03, 0.14241400E+04, -.51520400E+04, -.47011000E+04, -.27623000E+02, -.94289800E+03, 0.98271600E+03, 0.90099400E+04, 0.47192200E+03, 0.45903700E+04, 0.71201400E+04, -.45164600E+04, -.34238800E+04, -.20076800E+04, 0.58820000E+04, 0.25264500E+04, 0.36888100E+04, -.21413000E+04, -.89247900E+04, -.18446900E+04, -.25526400E+04, -.65816300E+04, 0.41470800E+04, 0.78612900E+04, 0.46517700E+04, -.66093900E+04, -.37531300E+04, 0.21260900E+05, -.95289900E+04, -.13556400E+04, -.10630000E+05, -.43837800E+02, 0.25873000E+04, -.52319100E+04, 0.89041700E+03, -.68783400E+04, 0.16990500E+04, -.97218100E+04, -.30449800E+05, 0.14707700E+05, -.96773900E+01, 0.15225000E+05, 0.78877600E+03, -.44981300E+04, 0.80003400E+04, -.24908100E+04, 0.14867300E+05, -.23748300E+04, 0.12217000E+05, 0.20885200E+04, -.60540000E+03, -.10207800E+05, -.10442800E+04, -.49489000E+04, -.40810000E+03, 0.12657000E+04, 0.45159800E+04, -.92397700E+02, -.44164600E+03, 0.29661500E+04, 0.20940300E+02, -.48447300E+02, 0.67209800E+04, -.10800800E+02, 0.12350800E+04, -.41025800E+03, 0.82712000E+03, -.92100100E+03, -.21014100E+04, -.12434700E+04, -.11668200E+04, -.35027300E+04, 0.17526600E+04, 0.88205700E+04, 0.17518000E+04, 0.23758800E+04, 0.37766900E+04, 0.35254100E+03, -.39640600E+03, 0.28744400E+04, 0.39594500E+04, -.39690400E+03, 0.12584500E+04, -.42594900E+03, 0.15542100E+05, -.62925900E+03, 0.42859100E+04, 0.69723000E+04, -.36080200E+04, -.34730200E+04, -.14554900E+04, 0.69411400E+04, -.16489900E+04, 0.42985900E+05, -.21274500E+05, -.12102100E+04, -.21492900E+05, -.40367100E+04, -.68213200E+04, -.71528800E+04, -.70847900E+03, -.16982500E+05, -.84265900E+04, -.21844000E+05, 0.10588000E+05, -.51028200E+04, -.17366600E+04, -.52938400E+04, -.12616800E+04, 0.78586100E+03, -.31181000E+04, 0.64163100E+03, -.66200600E+04, 0.27932500E+03, -.52738700E+04, -.63407000E+04, 0.31910500E+04, 0.22873200E+05, 0.31707400E+04, 0.77131000E+04, 0.10747700E+05, -.68469600E+04, -.97544300E+04, -.67382900E+04, 0.10928200E+05, 0.75473500E+03, 0.40767400E+04, -.19255100E+04, -.12158600E+05, -.20361100E+04, -.39009600E+04, -.72262200E+04, 0.34883400E+04, 0.43688700E+04, 0.45366200E+04, -.67316100E+04, -.12284800E+04, -.16560700E+04, 0.10605400E+04, 0.78163300E+04, 0.82786500E+03, 0.11994100E+04, 0.16132300E+04, 0.14100300E+04, 0.10374700E+04, 0.50978000E+04, 0.22017000E+04, -.79324100E+03, -.42669000E+05, 0.20927600E+05, -.82648000E+03, 0.21334200E+05, 0.28408800E+04, 0.85835000E+04, 0.34974500E+04, -.37851100E+04, 0.17201400E+05, 0.10368300E+05, 0.23068300E+05, -.15792000E+03, 0.98640000E+03, -.27725000E+04, 0.64165000E+03, 0.24095100E+03, 0.15013800E+04, -.40983000E+03, 0.67649600E+03, -.31142900E+04, -.17237300E+04, -.13655900E+04, 0.12974900E+04, -.86493800E+02, -.28854800E+04, 0.96037500E+03, -.10847700E+03, 0.46906200E+04, -.12407000E+04, -.18221700E+04, 0.20956400E+04, -.19204600E+04, -.16996400E+03, 0.79470500E+03, -.12659700E+04, 0.12070400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.44657400E+00, -.71966800E-01, -.53636500E+00, -.52093300E+00, -.12238300E+01, -.13178500E-01, 0.16564500E+00, 0.54006300E-02, 0.88156700E-01, 0.73692700E-01, 0.46307100E-01, -.33638500E-01, -.31742400E-01, 0.33414100E+00, 0.88776200E-01, 0.20831700E-01, 0.11400600E+00, 0.32019700E+00, 0.57434600E-01, 0.57281700E-02, -.27887100E-02, 0.22321700E-01, -.63822900E-01, -.15032200E+00, 0.34090700E-02, -.11904900E-02, -.20846900E+00, -.12563700E+00, -.91681900E-01, 0.86434100E-01, 0.37383400E-01, -.30644200E-02, 0.53618400E-01, -.23479400E+00, 0.51962200E-01, 0.97798600E-01, -.38760600E-02, 0.37520500E-01, 0.41258000E-02, -.17487400E+00, -.12908800E+00, -.54902000E-01, -.42573700E+03, 0.71812700E+03, -.89171200E+04, 0.45920600E+04, 0.20712800E+04, 0.44585200E+04, 0.33676600E+04, 0.45949500E+04, -.12763400E+04, -.26063800E+04, 0.17704200E+04, 0.42629700E+04, 0.35418200E+04, 0.56242100E+04, -.27862300E+04, -.45351100E+04, -.28122000E+04, 0.30822900E+03, 0.92427700E+03, -.17831800E+04, 0.96230500E+02, -.27717800E+04, 0.37989200E+03, -.20665400E+04, -.61983900E+03, 0.16080500E+03, 0.19519800E+03, 0.31017700E+03, -.35808400E+03, -.81123300E+02, 0.37155300E+03, 0.24090400E+03, -.43421600E+02, 0.30600400E+03, -.32435700E+03, -.61159300E+04, 0.25467100E+04, 0.14691600E+03, 0.30580900E+04, -.32526800E+03, -.87893500E+03, 0.18140500E+04, 0.17942700E+03, 0.29236900E+04, -.68749200E+03, 0.32295100E+04, -.78597700E+04, 0.37459400E+04, -.57294600E+03, 0.39298500E+04, 0.43246000E+03, 0.11528700E+03, 0.10661200E+04, -.26514900E+01, 0.33487500E+04, 0.47738300E+03, 0.48738700E+04, -.20452200E+03, 0.54117600E+02, -.32139900E+04, 0.10228100E+03, -.30503200E+03, -.61809400E+03, -.35940200E+02, -.39205700E+03, -.11582000E+04, -.61878400E+03, 0.10007300E+04, -.18835900E+04, 0.11384300E+04, 0.39620700E+04, 0.94169100E+03, 0.11380700E+04, 0.17405800E+04, -.14363000E+04, -.14855300E+04, 0.73626500E+03, 0.16302800E+04, 0.10771000E+04, 0.31859000E+03, -.27544000E+03, -.22422700E+04, -.15923100E+03, -.81044100E+03, -.11359200E+04, 0.11381700E+04, 0.14821500E+04, -.78530000E+03, -.13576300E+04, -.16175600E+02, 0.49756100E+04, -.20901000E+04, -.49676000E+03, -.24878900E+04, 0.66057200E+02, 0.36980600E+03, -.11607300E+04, 0.15090400E+03, -.21659000E+04, 0.24189700E+03, -.26541200E+04, -.68331700E+04, 0.32167900E+04, -.12243800E+03, 0.34165700E+04, 0.32244700E+03, -.84017100E+03, 0.19383400E+04, -.19464300E+03, 0.34993300E+04, -.64349000E+03, 0.23380800E+04, -.36314100E+03, 0.34796800E+03, -.34218500E+04, 0.18157400E+03, -.18976500E+04, -.13028200E+04, 0.73868600E+03, 0.78992700E+03, 0.60813200E+03, -.82934200E+03, 0.17546600E+04, 0.41223400E+04, -.20788300E+04, 0.79168600E+03, -.20614400E+04, 0.13220500E+02, -.73144400E+02, -.21982800E+03, 0.94209800E+03, -.98661400E+03, -.34979700E+03, -.14599700E+04, -.20709600E+02, 0.10567200E+02, 0.29273300E+04, 0.10260400E+02, -.32429100E+03, -.32409000E+02, 0.64062700E+03, 0.69346600E+03, 0.10244700E+04, 0.93838100E+02, -.98697000E+03, -.19521000E+04, 0.10578400E+04, 0.66313400E+04, 0.97605300E+03, 0.13323300E+04, 0.18237200E+04, -.58754600E+03, -.59230300E+03, 0.15297600E+04, 0.18666500E+04, 0.27019600E+03, 0.17515400E+05, -.86786000E+04, -.22915600E+04, -.87577200E+04, -.12195100E+04, -.85853200E+03, -.30280700E+04, 0.42805800E+03, -.69319300E+04, -.12219700E+04, -.73248400E+04, -.21040900E+02, 0.81608900E+02, 0.54679600E+03, 0.10484800E+02, 0.31581300E+03, 0.58531100E+03, -.57696500E+03, -.28813300E+03, -.59026600E+03, 0.60097800E+03, 0.41140500E+03, -.31903200E+04, 0.16032600E+04, 0.95838100E+04, 0.15950800E+04, 0.25200600E+04, 0.29285600E+04, -.20495000E+04, -.25309000E+04, 0.10894800E+04, 0.33943800E+04, -.87535200E+02, -.25000000E+03, 0.17937800E+03, -.24794800E+04, 0.12452600E+03, -.16966100E+03, -.84389000E+03, 0.49017200E+03, 0.20111700E+03, 0.24975900E+03, -.90646900E+03, 0.23966800E+03, 0.18604100E+03, -.22810400E+01, 0.20084500E+04, -.92987800E+02, -.17175500E+03, -.14169500E+03, 0.77719500E+03, 0.10695400E+04, 0.76254800E+03, -.13588100E+03, -.76900300E+03, -.15977900E+05, 0.78404600E+04, 0.10436200E+04, 0.79890300E+04, 0.10458100E+04, 0.68505500E+03, 0.20840500E+04, -.71864900E+03, 0.64198000E+04, 0.13247100E+04, 0.76148400E+04, -.39936600E+03, 0.34221700E+03, -.98745400E+03, 0.30846100E+03, -.15752700E+02, 0.65066300E+03, -.45752200E+03, -.16839800E+02, -.80506600E+03, -.54934800E+03, -.72882100E+03, 0.48336200E+03, -.46491700E+03, -.73939600E+03, 0.38555500E+03, 0.38469900E+02, 0.14213900E+04, -.66064000E+03, -.31914800E+03, 0.80993000E+03, -.55912400E+03, -.17142100E+03, 0.15824400E+03, -.63405600E+03, 0.32337000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.87251400E+01, 0.14269700E+00, -.70343900E+01, 0.15297400E+01, 0.56676800E+01, -.24000400E+01, -.25058200E+00, 0.49921100E+00, -.75187400E+00, 0.12395200E+01, 0.33287600E+00, -.81128000E+00, 0.28785100E+01, -.22004600E+01, -.10740500E+01, -.96988100E+00, -.12708900E+01, -.33141400E+01, -.11477900E+01, -.15561100E+01, -.26821900E+01, -.10044300E+01, -.72664700E+00, -.93442500E+00, 0.47192700E+00, 0.10807000E+01, 0.46590600E+01, -.40715900E+01, -.15098900E+01, 0.13771500E+01, -.42944700E+00, -.39561000E-01, 0.53096800E+01, -.76193000E+00, -.22262900E+00, 0.10645100E+01, 0.45763800E-01, 0.93003400E+00, -.54772500E+00, -.33050200E+01, 0.93175700E-01, -.92354900E+00, -.64779600E+01, 0.16310000E+05, -.61147400E+05, 0.32866800E+05, 0.10649700E+05, 0.30573900E+05, 0.23914800E+05, 0.24928500E+05, -.65079100E+03, -.32289100E+04, 0.84760300E+04, 0.21475300E+05, 0.19366000E+05, 0.24482700E+05, -.11947400E+05, -.29047600E+05, -.12240900E+05, 0.46559700E+04, 0.29125200E+04, -.61479200E+04, 0.22939100E+01, -.13963600E+05, 0.39095800E+04, -.47553600E+04, -.27796800E+05, 0.10741300E+05, 0.64896100E+04, 0.13896900E+05, -.11476400E+04, -.17340900E+04, 0.69304700E+04, 0.14937600E+04, 0.91906400E+04, -.18706900E+04, -.74119000E+04, -.30408300E+05, 0.62438700E+04, 0.47767800E+04, 0.15203200E+05, 0.20136100E+04, -.92371800E+03, 0.76701900E+04, 0.96724000E+03, 0.18718400E+05, -.66869500E+03, 0.14401500E+05, -.53849700E+05, 0.23408900E+05, -.77479300E+04, 0.26925000E+05, 0.78509500E+04, 0.22996900E+04, 0.55943200E+04, 0.26100600E+04, 0.21470600E+05, 0.15985400E+04, 0.34477000E+05, 0.45780400E+04, -.35596400E+04, -.26815200E+05, -.22890500E+04, -.66475400E+04, -.13587500E+05, 0.78334400E+04, -.16551300E+04, -.83178800E+04, -.90159500E+04, 0.14675400E+05, -.13072500E+05, 0.10240900E+05, 0.29528700E+05, 0.65367300E+04, 0.83469700E+04, 0.14018900E+05, -.14899500E+05, -.12400600E+05, -.39533300E+04, 0.12999800E+05, 0.83305600E+04, 0.21520100E+05, -.12990200E+05, -.22875800E+05, -.10760300E+05, -.64260200E+04, -.89598300E+04, 0.47680000E+04, 0.12775800E+05, 0.25323700E+04, -.10344600E+05, -.84487000E+04, 0.24213300E+05, -.49422400E+04, -.81299900E+04, -.12106000E+05, -.20416400E+04, 0.18614600E+03, -.54055900E+04, -.15748200E+03, -.12701400E+05, -.22950000E+03, -.10387500E+05, -.44177000E+05, 0.18474500E+05, 0.76473200E+03, 0.22088500E+05, 0.45308200E+04, -.34782300E+04, 0.90725000E+04, -.34237400E+03, 0.26821800E+05, -.57225100E+04, 0.65296900E+04, -.80067600E+04, 0.69861000E+04, -.25084400E+05, 0.40033600E+04, -.75692500E+04, -.10371300E+05, 0.95213900E+04, 0.85447700E+04, 0.69871200E+04, -.72019400E+04, 0.15623600E+05, 0.36357200E+05, -.18611600E+05, 0.41924600E+04, -.18181000E+05, -.14613900E+04, -.20889300E+04, 0.80396400E+02, 0.98035200E+04, -.93990700E+04, -.18742700E+04, -.12641800E+05, -.84924300E+03, 0.69501400E+03, 0.13464400E+05, 0.42509000E+03, 0.52959100E+03, 0.56955600E+04, 0.39169200E+04, 0.97209800E+04, 0.12141000E+05, 0.15063300E+04, -.13586500E+05, -.13360400E+05, 0.86016000E+04, 0.46469200E+05, 0.66800500E+04, 0.79145500E+04, 0.14221700E+05, -.43519800E+04, 0.29102300E+04, 0.62640200E+04, 0.11172600E+05, -.42133800E+04, 0.10983800E+06, -.53709400E+05, -.52194200E+04, -.54919200E+05, -.11729500E+05, -.77130000E+04, -.17987900E+05, -.10363100E+05, -.51739400E+05, -.18668400E+04, -.39325900E+05, -.28280200E+04, 0.25186700E+04, 0.84230100E+04, 0.14142000E+04, 0.17982400E+04, 0.15702400E+03, 0.41650400E+04, 0.20082500E+04, -.73749900E+04, 0.35018900E+04, 0.46119500E+04, -.92563400E+04, 0.48721600E+04, 0.60830400E+05, 0.46287100E+04, 0.13521000E+05, 0.23050300E+05, -.10258800E+05, -.13852600E+05, -.17304100E+05, 0.21697000E+05, -.16379700E+05, 0.39541600E+05, -.18018200E+05, -.29797700E+05, -.19768100E+05, -.23031600E+04, 0.71933000E+02, -.79332600E+04, -.33154600E+04, -.59496800E+04, -.84473100E+03, -.47397100E+04, -.11108100E+05, 0.74786100E+04, 0.19639000E+05, 0.55537600E+04, 0.25509600E+04, 0.59251900E+04, -.12799500E+04, 0.58739500E+04, 0.11529500E+05, 0.30206900E+04, -.75486200E+04, -.11369700E+06, 0.54380200E+05, 0.19981200E+04, 0.56848200E+05, 0.14376600E+05, 0.78112000E+04, 0.10045500E+05, 0.23638400E+04, 0.52610200E+05, 0.32057500E+04, 0.47554200E+05, -.26945800E+04, 0.19197600E+04, -.52312000E+04, 0.24544200E+04, 0.72485100E+03, 0.37359200E+04, -.14406900E+04, 0.13804900E+04, -.90765000E+03, -.25204900E+04, -.52887000E+04, 0.27205700E+04, -.20556200E+03, -.25935400E+03, 0.17015100E+04, 0.52263100E+03, 0.99116700E+04, -.66945900E+04, -.13430400E+04, 0.76499200E+04, -.54832400E+04, 0.74128100E+03, 0.10016500E+03, -.50738900E+04, 0.17127800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14431100E+01, -.60968800E-01, 0.51551500E+00, 0.70606600E+00, 0.12992500E+00, -.14814100E-01, -.20371300E+00, -.12048000E+00, 0.29675400E-01, -.78994800E-01, 0.47393200E+00, -.65795500E+00, -.73588900E+00, 0.28933700E-01, -.35169100E-01, -.17033700E+00, -.88315000E+00, 0.45036000E+00, 0.82328300E+00, -.67209800E+00, 0.71974100E-02, -.10826000E-01, -.12591300E+00, -.69096500E+00, 0.10128800E+00, -.51811900E-01, 0.49544300E+00, 0.11215700E+01, -.29325500E+00, -.13100300E+00, 0.18505700E+00, -.37481500E+00, -.48709900E+00, -.44309400E+00, 0.11166900E-01, -.54010000E+00, -.11303200E-01, 0.32247100E-01, -.41094700E+00, -.39251600E+00, -.98382400E-01, 0.26621100E+00, -.17768900E+01, 0.11510800E+00, -.14460200E+05, 0.75098800E+04, -.10124700E+04, 0.72298600E+04, 0.28934700E+04, 0.32971900E+04, 0.16204500E+04, -.39369200E+04, 0.66778600E+04, 0.22449100E+04, 0.80156600E+04, 0.31147500E+04, -.14909300E+04, -.51487000E+04, -.15580000E+04, 0.18792000E+04, 0.21052300E+04, -.24690800E+03, 0.29962600E+04, -.10875500E+04, 0.18272300E+04, -.18531600E+04, -.25267400E+04, 0.10213200E+04, 0.61573700E+03, 0.12650300E+04, -.92403300E+03, -.10715700E+04, 0.13193400E+04, 0.79303800E+03, 0.10502100E+04, -.94672500E+03, 0.14018900E+04, -.22073600E+02, -.72278600E+03, 0.17979300E+04, 0.11901000E+02, 0.57965100E+03, 0.53433900E+03, 0.12538800E+04, 0.10234400E+04, 0.20134100E+03, 0.65700000E+03, -.33792300E+03, -.21642300E+04, 0.79046200E+03, -.19579100E+04, 0.10818900E+04, 0.12877300E+04, -.11082600E+04, 0.18810200E+04, 0.20528400E+04, 0.20458600E+04, -.99297500E+03, 0.17941700E+04, -.37797100E+04, 0.18405600E+04, -.23240300E+03, 0.18899700E+04, 0.21223300E+04, 0.22223100E+04, -.12728500E+04, -.48549100E+03, -.88763200E+02, 0.22185200E+04, 0.17173200E+04, -.15494100E+04, 0.10779300E+04, 0.15579500E+04, 0.77404600E+03, -.20298200E+04, -.12734400E+04, 0.11544000E+04, -.10866400E+04, 0.25904000E+04, -.10055200E+04, 0.10491500E+04, -.44692300E+04, 0.20463800E+04, 0.10478500E+04, 0.22350100E+04, 0.12662200E+04, 0.25813000E+04, -.97160900E+03, -.59102400E+02, -.30850600E+04, 0.23387200E+04, 0.28045900E+04, 0.26095600E+03, 0.47890400E+03, -.19522000E+04, -.13106000E+03, -.19585500E+03, -.44973800E+03, -.83184600E+03, -.46972000E+03, -.11075400E+03, -.56892800E+03, 0.16270000E+03, -.12694800E+04, 0.29594400E+03, 0.96128400E+03, 0.63464000E+03, 0.73984200E+03, 0.11637000E+04, 0.26268300E+03, -.46975600E+02, 0.27522500E+03, 0.71281300E+03, 0.11095400E+04, -.37393300E+04, 0.21280500E+04, -.17089700E+04, 0.18696900E+04, -.91745400E+03, -.23042400E+04, 0.19214000E+04, 0.67533600E+03, 0.24764800E+04, -.18315200E+04, 0.17813800E+04, 0.67548500E+04, -.34315500E+04, -.24393500E+03, -.33774900E+04, -.27207800E+03, 0.55394300E+00, -.82739400E+03, 0.18888600E+04, -.11153200E+04, 0.56880200E+02, -.27353100E+04, -.12365500E+03, 0.37666600E+02, 0.39983400E+04, 0.61227500E+02, -.97486800E+03, -.61406900E+03, 0.30717600E+00, -.11072600E+04, 0.61582600E+03, -.84030900E+03, -.38278600E+03, -.25828300E+04, 0.14070800E+04, 0.64407000E+04, 0.12914600E+04, -.14904200E+04, -.99207900E+03, 0.11599300E+04, -.14542500E+04, 0.37501100E+04, -.12821200E+04, 0.16181500E+04, 0.15662600E+05, -.76763200E+04, -.25366900E+04, -.78313400E+04, 0.33102100E+03, 0.95082900E+03, -.23587500E+04, 0.36986500E+04, -.51970900E+04, 0.10377600E+04, -.78471500E+04, -.42633300E+04, 0.22655900E+04, 0.50898300E+03, 0.21314400E+04, 0.16536700E+04, 0.70540100E+03, 0.22714000E+03, -.52460500E+03, 0.19965700E+04, 0.64541600E+03, 0.22425300E+04, -.16378100E+03, 0.79686500E+02, 0.59856300E+04, 0.81363900E+02, -.46020400E+03, -.83755500E+03, -.46336800E+02, -.23778700E+04, 0.55418600E+04, -.80798500E+03, 0.76685000E+03, 0.43411400E+03, -.66492700E+02, 0.49910300E+03, -.22011900E+03, 0.33202300E+04, 0.39540900E+04, -.32701400E+04, -.22970600E+04, -.32944000E+04, 0.35245700E+04, -.83466100E+03, 0.43922100E+04, -.20658700E+04, -.96043400E+03, -.21958800E+04, -.18562400E+04, -.27517200E+04, 0.16235800E+04, 0.17509900E+04, -.15590200E+04, -.24860200E+04, -.22307400E+04, -.12924300E+05, 0.62048400E+04, 0.16188300E+04, 0.64626000E+04, 0.94833500E+03, -.23357500E+04, 0.38426000E+04, 0.27359700E+03, 0.43915800E+04, -.21258200E+04, 0.57673300E+04, -.48904300E+03, 0.31630900E+02, -.61655600E+01, 0.10369600E+03, -.85226900E+03, 0.45878500E+03, 0.10037000E+02, -.92046700E+03, 0.14647700E+04, -.12364100E+03, -.36093800E+03, 0.31982100E+03, -.13788800E+04, 0.12185900E+04, -.94826200E+02, -.38693300E+02, 0.63503800E+03, -.64290000E+02, 0.35152900E+03, -.15493800E+03, 0.30964200E+03, -.11176900E+04, -.73489700E+03, -.50229500E+03, 0.25163100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54323300E+01, 0.61206100E+00, -.25079300E+01, -.21238400E+01, -.97218500E+00, -.93480200E-01, 0.44681300E+00, 0.74915800E-02, -.24454800E-01, -.99776900E-01, 0.35761400E+00, 0.17554900E+00, 0.45090500E+00, -.56362100E+01, -.11296800E+01, 0.38240500E+00, -.16782900E+01, -.39213400E+01, -.17805300E+01, -.42888400E+00, 0.24706500E+01, -.32739300E+00, 0.34782800E+00, 0.40771700E+00, 0.23622000E+00, 0.10932200E+01, 0.21730400E+01, 0.20075200E+01, -.10981500E+01, 0.79198100E+00, -.32664800E-01, 0.71071400E-01, -.62061000E+00, -.71361900E-01, 0.59000300E-01, 0.10221200E+01, 0.92354700E-01, -.29452700E+00, -.73021100E+00, 0.34417500E+01, -.63319900E+00, 0.59162000E+00, 0.22939700E+01, -.18013200E-01, 0.24232300E+01, -.23370500E+04, 0.17566000E+05, 0.11155300E+01, -.51000500E+04, -.91245000E+04, 0.83519100E+03, 0.32995600E+03, 0.50778200E+04, -.63644600E+04, -.94029000E+04, -.15065500E+05, 0.71232400E+04, 0.15897600E+05, 0.75357300E+04, -.83342800E+04, -.48516900E+04, -.12269100E+04, -.17467200E+05, 0.39470600E+04, -.53489500E+04, 0.43677100E+04, 0.30011200E+05, -.12376900E+05, -.14258200E+05, -.15013400E+05, 0.90457000E+01, -.68506200E+02, -.53384900E+04, 0.20729200E+04, -.51700800E+04, -.79688100E+03, -.14271300E+05, 0.24173200E+05, -.40720600E+04, -.16123700E+05, -.12090600E+05, -.65112900E+03, 0.53174100E+04, -.12275700E+05, -.71706100E+04, -.12259900E+05, 0.47809000E+04, -.87952700E+04, 0.83725500E+04, -.11599400E+04, 0.88148800E+04, -.41852400E+04, 0.49732400E+03, 0.58213500E+04, -.43328500E+04, -.51889500E+04, -.30665400E+04, 0.48329100E+04, -.13688100E+05, -.25385200E+04, 0.21433600E+04, 0.12019700E+05, 0.12686700E+04, -.89591600E+03, 0.42848200E+03, 0.62139600E+03, -.29763800E+04, 0.74581300E+04, -.27013600E+04, -.15910200E+04, 0.39722500E+04, -.52109900E+04, -.11701400E+05, -.19829900E+04, 0.78692200E+04, 0.19891800E+04, 0.32324200E+03, 0.98977400E+04, 0.17418800E+04, 0.55377200E+03, -.31772200E+04, -.63169800E+04, 0.51190100E+04, 0.10890100E+05, 0.31565900E+04, -.19852700E+04, -.40997500E+04, 0.20797900E+04, -.14462700E+05, -.47245300E+04, -.17480800E+04, -.16698300E+04, -.22220900E+05, 0.46404300E+04, 0.15778200E+05, 0.11113100E+05, -.68266400E+02, -.35955600E+04, 0.92307800E+04, 0.33936700E+04, 0.89571700E+04, -.30010100E+04, 0.78788700E+04, 0.14259300E+05, -.38546300E+04, -.73949900E+03, -.71291500E+04, -.37277300E+04, -.67507100E+04, -.40794000E+03, 0.21427900E+04, -.94176800E+04, -.23805300E+04, -.54392100E+04, 0.92749200E+04, -.72719800E+04, 0.95534100E+04, -.46375700E+04, 0.76574200E+04, 0.11009100E+05, -.59842700E+04, -.70025300E+02, -.62821500E+04, 0.59925300E+04, -.85153000E+04, -.29660500E+05, 0.15237200E+05, 0.35649900E+04, 0.14830000E+05, 0.15940100E+03, 0.73085300E+03, 0.19274100E+04, -.10135000E+05, 0.52846700E+04, 0.93814000E+03, 0.87311400E+04, 0.15591300E+05, -.78543000E+04, -.24879200E+05, -.77928100E+04, -.11891400E+04, -.23186300E+04, -.51728100E+03, 0.66469000E+04, -.89613600E+04, 0.18322900E+03, -.24826800E+04, -.27429500E+04, -.14734800E+03, -.20118800E+05, 0.13713100E+04, 0.71394400E+04, 0.29714800E+04, -.25387600E+04, 0.32383600E+04, -.45665300E+04, 0.48236800E+04, -.11269700E+04, -.49773200E+05, 0.23636100E+05, 0.21260900E+04, 0.24886800E+05, -.31335700E+04, 0.45897200E+04, 0.27158500E+03, -.17032400E+05, 0.18277500E+05, 0.96709000E+03, 0.23123800E+05, 0.69681700E+04, -.46257100E+04, 0.16306900E+03, -.34830100E+04, -.16579400E+04, 0.64575300E+04, -.54302000E+04, -.36237700E+04, 0.70657700E+03, 0.27615500E+04, -.58504100E+04, -.52900500E+04, 0.24822400E+04, -.33621100E+05, 0.26474600E+04, 0.43337700E+04, 0.14401900E+04, 0.19843600E+04, 0.16170800E+05, 0.14742800E+05, 0.14005000E+04, -.20480600E+04, -.24999200E+05, 0.11045200E+05, 0.15256500E+05, 0.12514000E+05, -.66697300E+04, -.56491400E+04, 0.89326900E+04, -.22160800E+04, 0.25337600E+04, -.32327300E+04, 0.14081300E+05, -.17383500E+04, -.67184200E+03, -.14212000E+04, 0.86816000E+03, 0.16649900E+04, 0.45620600E+04, -.36094800E+04, -.44140700E+04, -.81385900E+04, 0.58866500E+04, 0.54882700E+04, 0.60449400E+05, -.27872600E+05, -.90712800E+04, -.30226700E+05, 0.23813400E+04, 0.53406500E+04, -.88933500E+04, 0.80939200E+04, -.23764800E+05, 0.56126300E+04, -.26864200E+05, 0.90164400E+03, 0.35593600E+03, 0.55736500E+03, 0.58578100E+03, 0.41052500E+04, -.96779900E+03, -.28968300E+04, 0.43407000E+04, -.37573000E+04, 0.84551800E+03, 0.16347500E+04, -.84838700E+03, 0.33141000E+04, -.26255700E+04, 0.83829500E+03, 0.15299000E+04, -.17534700E+04, 0.92503200E+03, -.53316200E+03, 0.16791200E+04, 0.85726700E+03, 0.22867500E+04, 0.49733300E+04, 0.30274500E+04, -.27014000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34913500E+01, 0.32921900E+00, -.37773500E+00, -.55706700E+00, 0.73930700E+00, 0.34721700E+00, 0.56781800E-01, 0.24990900E+00, 0.49387600E+00, 0.12907000E+00, 0.40205500E-01, 0.10386600E+00, -.63979900E-01, 0.13443900E+01, 0.14470500E+00, 0.15555000E+00, 0.14961500E+01, 0.88198100E+00, 0.99011200E-02, 0.54390500E+00, -.85369000E+00, -.10619500E-01, 0.21729600E+00, 0.12451400E+01, 0.93829400E-02, -.41653900E+00, -.15671800E+01, -.15465300E+01, 0.45556200E+00, -.75312800E+00, 0.59507600E-01, -.58859700E+00, 0.52139400E+00, -.43673800E-01, 0.33977100E-01, -.98410600E+00, -.26196400E-01, 0.68475600E-01, 0.23861100E+00, -.21789500E+00, 0.27731200E+00, 0.11351600E+00, -.52557300E+00, 0.12880000E+00, -.93050000E+00, -.31721200E-02, 0.11902500E+05, -.35900400E+00, -.69129600E+03, 0.94070800E+03, 0.92468700E+02, -.13019800E+03, 0.28722000E+04, 0.10015500E+04, 0.22567900E+04, -.29704800E+04, 0.15154100E+04, 0.71326300E+04, 0.14842600E+04, 0.15871200E+04, 0.38991000E+04, 0.10063000E+04, 0.22575600E+04, 0.12647400E+04, 0.41842600E+04, 0.50054500E+04, 0.12244800E+04, -.47506600E+03, 0.11978200E+04, -.60958600E+03, -.72446200E+03, -.58335500E+03, 0.12786800E+03, 0.75874700E+03, -.29042400E+03, -.51725100E+03, -.48213100E+03, 0.40898900E+04, -.17816100E+04, -.32839800E+04, -.20435400E+04, -.51418200E+03, -.17967600E+03, -.40757300E+03, 0.65539700E+03, -.10771900E+04, -.16316100E+03, -.15249600E+04, 0.14058300E+05, -.69189200E+04, -.16185300E+04, -.70295000E+04, -.24263700E+04, -.23793000E+04, -.20555700E+04, 0.29923000E+04, -.28461700E+04, -.22742100E+04, -.50966300E+04, -.51251300E+04, 0.26590000E+04, 0.48936400E+04, 0.25627400E+04, 0.20114700E+04, 0.32465300E+04, -.20471900E+03, -.12427500E+04, 0.16047000E+04, 0.35032500E+04, 0.35158500E+04, 0.42537500E+03, -.32330100E+03, -.55105400E+03, -.21371500E+03, -.31783400E+04, -.37195000E+04, 0.24119800E+04, 0.23793600E+04, 0.33330600E+04, -.32589800E+04, -.15560300E+04, -.94346400E+04, 0.47819300E+04, 0.44715900E+04, 0.47179300E+04, 0.17631300E+04, 0.40113300E+04, -.77045700E+03, -.23542000E+04, -.36072500E+04, 0.37302300E+04, 0.67798300E+04, -.32202600E+04, 0.14107700E+04, 0.30779600E+04, 0.16091900E+04, 0.59566900E+03, 0.12953600E+03, 0.43143700E+03, -.46497300E+03, 0.73003000E+03, 0.18830900E+03, 0.11482700E+04, 0.97992600E+04, -.48257200E+04, -.29391100E+04, -.48997800E+04, -.91429300E+02, 0.58782900E+03, -.27272500E+04, 0.29174900E+03, -.48214400E+04, -.33295400E+03, -.48821100E+04, 0.17034400E+04, -.92655600E+03, 0.47274500E+04, -.85168300E+03, -.14186000E+04, -.81430300E+03, -.94853300E+03, -.22063000E+04, -.12920100E+03, 0.26993400E+03, -.24639800E+03, 0.36532500E+04, -.18166400E+04, -.57878600E+04, -.18266000E+04, -.33450100E+02, 0.25808800E+03, -.10865500E+04, -.90164400E+02, 0.96721100E+03, 0.25135300E+03, 0.64099600E+03, 0.14064000E+04, -.75838800E+03, -.23906100E+04, -.70413700E+03, -.17820900E+04, -.31359700E+04, 0.30053000E+03, -.21723700E+03, 0.57286900E+03, -.28507200E+04, -.24486700E+04, -.32363500E+04, 0.15095100E+04, -.48433900E+04, 0.16182600E+04, -.13683500E+04, -.34204200E+04, 0.27296500E+04, 0.20220300E+04, 0.51258100E+04, -.36348900E+04, 0.96179800E+03, -.19585800E+05, 0.98060800E+04, -.73643000E+03, 0.97928500E+04, 0.38212700E+04, 0.44102100E+04, 0.59178200E+04, 0.20449900E+04, 0.80606800E+04, 0.44954500E+04, 0.12868000E+05, -.70689700E+04, 0.35429900E+04, 0.36393900E+04, 0.35341300E+04, 0.62163000E+03, 0.59492800E+03, 0.97599900E+03, -.13558600E+04, 0.35087000E+04, 0.10927900E+04, 0.51416600E+04, 0.22828500E+04, -.11742600E+04, -.40414400E+04, -.11422700E+04, -.34295000E+04, -.53473800E+04, 0.27262600E+04, 0.19388300E+04, 0.96588700E+04, -.47318300E+04, -.38359000E+03, -.54507800E+04, 0.26423900E+04, 0.35870000E+03, 0.27205300E+04, 0.19004200E+04, 0.13164000E+04, 0.22408200E+02, -.12982200E+04, -.10957900E+04, 0.12706700E+04, 0.19617600E+04, 0.23786800E+04, -.12753900E+04, -.49079800E+04, -.11889700E+04, -.32627700E+03, -.18517300E+04, 0.15549200E+03, 0.10119400E+04, -.32446600E+04, -.22543600E+04, -.30257000E+04, 0.15844900E+05, -.78998600E+04, 0.22583900E+04, -.79217900E+04, -.43414600E+04, -.67466400E+04, -.13553600E+04, 0.45816500E+04, -.65817000E+04, -.63866800E+04, -.11166700E+05, -.23327300E+03, -.10565800E+03, 0.50498700E+03, -.39684800E+03, -.88911200E+03, -.61537000E+03, -.52209200E+03, -.96062900E+03, 0.58630700E+03, 0.17389900E+03, 0.43719200E+03, 0.52433600E+02, -.12183000E+04, 0.47018400E+03, -.26607900E+03, -.28816600E+03, -.26705900E+04, 0.88060700E+02, 0.88253300E+03, -.90293000E+02, 0.72369500E+03, -.10119500E+04, -.35579500E+03, 0.56579000E+03, 0.68273400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13449600E+01, 0.11243000E+00, -.30219700E+00, 0.48360200E+00, 0.12526600E+01, -.44676800E+00, -.31416600E+00, -.17759300E-01, -.50048600E+00, -.25134700E+00, -.53595400E+00, 0.13120700E+00, -.32982700E+00, -.17278100E+01, 0.16575600E-01, 0.32724600E-01, 0.10543900E+00, -.12826400E+01, 0.24324000E+00, -.44849100E+00, -.16947000E+00, 0.22634300E-01, 0.48909900E-01, 0.40790200E+00, 0.11515400E+00, 0.67321500E-01, 0.57408900E+00, 0.91309700E-01, 0.40526900E+00, -.17545100E+00, -.41796400E-01, -.34255000E+00, 0.73569500E+00, 0.38511500E+00, -.47186600E-01, -.21724100E-01, -.17241500E-01, 0.22999200E-01, -.69574900E-02, 0.82062900E+00, 0.72135800E-01, 0.28117400E+00, -.19162200E+00, 0.12908100E+00, 0.87375600E-01, 0.22713300E+00, -.31713200E+00, -.42927300E+00, -.11519900E+04, -.11672700E+03, 0.37320800E+03, -.44799700E+03, 0.25967000E+04, -.40695700E+03, 0.25916400E+04, 0.27418100E+04, -.13511200E+04, 0.18869700E+03, -.13720500E+04, 0.16264900E+04, 0.25073200E+04, 0.36914700E+03, 0.39406100E+04, 0.20149200E+03, 0.25630100E+04, 0.44298900E+01, -.20895300E+04, 0.11295500E+04, 0.12873000E+04, 0.10478500E+04, -.34818900E+03, -.49103700E+03, 0.45274900E+03, -.25564400E+03, 0.88008600E+02, -.27491500E+03, 0.88749800E+03, 0.17536900E+04, -.71079300E+03, 0.23461000E+04, -.87525500E+03, -.11766100E+03, 0.64834700E+03, 0.38648400E+03, 0.10104100E+04, -.85688100E+03, 0.41914700E+03, -.67001300E+03, 0.59313700E+04, -.28839300E+04, -.26449100E+04, -.29660800E+04, -.22621100E+03, -.13713900E+04, 0.16648000E+03, 0.23992900E+04, -.92037200E+03, -.11898000E+04, -.23803400E+04, -.88989400E+03, 0.51166200E+03, 0.25717800E+03, 0.44517000E+03, 0.11591900E+04, 0.12940900E+04, -.39938100E+03, 0.10681900E+04, 0.63303900E+03, 0.16984200E+04, 0.10883200E+04, -.33764800E+03, 0.91892100E+02, -.20952100E+03, 0.16761700E+03, -.24724900E+04, -.28794900E+04, 0.21315800E+04, 0.87053300E+03, 0.18896400E+04, -.25350400E+04, -.31911400E+03, -.38018600E+04, 0.19438100E+04, 0.18287600E+04, 0.19016600E+04, 0.12177800E+04, 0.35071100E+04, -.13243800E+04, -.72809300E+03, -.15151300E+04, 0.31734500E+04, 0.32921100E+04, -.12451300E+04, 0.50156100E+03, -.18173000E+04, 0.62149200E+03, 0.39419900E+03, -.44111900E+03, -.14271700E+03, -.39468300E+03, 0.67784300E+03, -.25604400E+03, 0.36844800E+03, 0.27631900E+04, -.13308100E+04, -.89350700E+03, -.13817800E+04, -.27076500E+03, 0.20626500E+04, -.18132600E+04, -.17155600E+04, -.26922000E+04, 0.13338400E+04, -.54016800E+03, -.38947200E+04, 0.18938500E+04, 0.16605600E+04, 0.19474000E+04, -.54510900E+02, -.22571600E+04, 0.20154300E+04, 0.12028300E+04, 0.28971700E+04, -.14470000E+04, 0.93173600E+03, 0.65313000E+04, -.32593200E+04, -.26057100E+04, -.32653600E+04, -.23816800E+03, 0.18532900E+03, -.15315400E+04, 0.87609000E+03, -.88222500E+03, 0.17633500E+03, -.17823300E+04, -.10757400E+04, 0.49800400E+03, 0.25739900E+04, 0.53677300E+03, -.40093800E+03, -.43190700E+03, -.49083900E+03, -.22507300E+04, -.65792000E+02, -.71027400E+03, -.85849600E+03, -.46413600E+03, 0.15959900E+03, 0.77085800E+03, 0.23213800E+03, -.23868600E+04, -.27745100E+04, 0.10571200E+04, -.10875200E+04, 0.18718100E+04, -.30345800E+04, 0.25732100E+03, -.44059700E+03, 0.22394700E+03, -.21092500E+03, 0.22023900E+03, 0.21970200E+04, 0.20485000E+04, 0.15450600E+04, 0.41512800E+04, 0.17205300E+04, 0.22396200E+04, 0.13761300E+04, -.18081300E+04, 0.90862400E+03, -.41257400E+03, 0.90365000E+03, 0.53316000E+03, -.56703300E+03, 0.41035200E+03, 0.26266300E+03, 0.18746300E+04, -.17119600E+03, 0.19976200E+04, 0.36049900E+04, -.18279200E+04, -.66623200E+03, -.18034500E+04, -.25778700E+04, -.28415100E+04, 0.11934600E+03, -.17193400E+04, 0.23645700E+04, -.28299100E+04, -.14098300E+03, -.13421400E+03, 0.23571800E+02, 0.15819900E+04, 0.61494900E+02, 0.24016800E+04, 0.26240700E+04, -.93267100E+03, 0.34504400E+03, -.10397000E+04, 0.21015000E+04, -.56277000E+03, 0.18316400E+04, -.97499200E+03, -.17612800E+04, -.91541800E+03, -.64412800E+03, -.17944300E+04, 0.56087400E+03, 0.92474900E+02, -.15531000E+04, -.18992900E+04, -.20246800E+04, -.55387100E+03, 0.30116100E+03, 0.94582700E+03, 0.27772100E+03, -.11878800E+04, -.33436500E+04, 0.16028200E+04, 0.63682300E+03, -.10926600E+04, -.31244700E+04, -.26768400E+04, -.30899000E+03, -.34595100E+03, 0.85973200E+03, -.14599900E+03, -.97891600E+03, -.47856600E+03, 0.59517300E+03, -.10498600E+04, 0.86524300E+03, 0.28306400E+03, 0.29828100E+03, -.18262700E+02, -.85750200E+03, 0.58265700E+03, -.52247700E+03, -.21673600E+03, -.12482200E+04, 0.24603000E+03, 0.75289000E+03, -.10359000E+04, 0.10387400E+04, -.73270100E+03, -.90284400E+03, -.40913900E+02, 0.33654000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17097900E+01, -.12436500E+00, 0.34117500E+00, 0.16794200E+00, -.69327500E+00, -.35481800E-02, -.11844300E+00, -.11572300E+00, -.14280700E+00, 0.20949500E+00, 0.20941700E+00, -.30333600E+00, -.14042800E+00, 0.11048100E+01, -.63674700E-02, 0.99709200E-01, -.51197600E+00, 0.14619400E+01, -.37766400E+00, 0.55206700E-01, -.46668700E+00, -.90396700E-01, 0.20224000E-01, 0.12941900E+00, 0.61664200E-01, 0.89432100E-01, 0.19895400E+01, -.12361900E+01, -.54950300E-01, 0.35639100E+00, -.64524100E-01, 0.64239900E-01, 0.49845600E+00, -.55735800E+00, 0.14120000E+00, 0.12286300E+01, -.13830600E-01, 0.14112200E+00, 0.28216900E+00, -.62618100E+00, 0.33976500E+00, -.33520300E+00, -.20095400E+00, 0.13522900E-01, -.57053500E+00, -.86185900E-01, 0.49790600E-01, -.10384700E-01, 0.27292900E+04, 0.20795500E+04, -.31515100E+04, -.38951300E+04, -.48797700E+03, 0.14348700E+04, 0.30296100E+03, 0.25056400E+04, -.12438100E+04, -.38409800E+04, -.12528100E+04, 0.71096000E+02, -.73379500E+03, -.52936500E+03, -.44169800E+03, -.17196400E+04, -.20215200E+03, -.17002200E+04, 0.60201700E+02, -.11643900E+02, -.47112900E+03, -.30132600E+02, -.41406100E+03, -.42369500E+03, 0.38544900E+03, 0.31852600E+03, 0.54116100E+03, -.43522800E+03, 0.17632000E+03, 0.65203400E+03, -.37149600E+03, 0.13093900E+04, -.32604900E+03, -.43699900E+03, 0.29477400E+02, 0.17177900E+03, 0.86621300E+03, 0.29935600E+03, -.12710000E+03, 0.20583900E+03, 0.17617400E+04, -.87550400E+03, 0.59088400E+03, -.88086400E+03, 0.45555600E+03, -.38837400E+03, -.93523600E+03, -.67460300E+03, 0.12878800E+03, -.61310300E+03, -.53408800E+03, -.86931100E+03, 0.45244900E+03, 0.11265400E+04, 0.43466100E+03, 0.62993600E+03, 0.79169700E+03, -.43207900E+03, -.49718100E+03, -.87457700E+03, 0.87633000E+03, 0.18276100E+03, -.10268700E+04, 0.51298200E+03, 0.96030300E+03, 0.51344400E+03, 0.15992300E+03, 0.45606600E+03, -.71885700E+03, -.14083800E+04, 0.97610100E+03, 0.59104300E+03, 0.83422100E+03, 0.81159600E+03, -.40136600E+03, -.66393500E+03, -.40579700E+03, -.49834100E+03, -.14874500E+04, 0.48695200E+03, 0.83357900E+03, -.13532400E+04, -.13832400E+04, -.45216900E+03, -.35440300E+03, 0.20025200E+03, -.85637100E+03, 0.17722000E+03, 0.12822000E+03, -.11752500E+03, -.70027500E+02, -.58358800E+03, -.26352300E+03, 0.92727300E+01, -.20130400E+03, 0.43929500E+03, -.22190200E+03, 0.19959900E+04, -.21964800E+03, 0.20204500E+03, -.31093500E+03, 0.30536100E+03, 0.16181800E+04, 0.70402700E+03, -.66857000E+03, -.36564700E+03, 0.13687000E+04, -.67588300E+03, 0.53437200E+03, -.68435000E+03, -.44664200E+03, 0.33268900E+03, -.26537700E+03, -.48823900E+02, -.76380400E+03, 0.26028000E+03, -.15581100E+03, -.34696800E+04, 0.17472400E+04, 0.22768800E+02, 0.17344100E+04, -.42187100E+03, -.78411800E+03, 0.30219100E+04, 0.25172300E+04, 0.18380900E+04, -.39606600E+03, 0.14536400E+04, -.83524500E+03, 0.40482600E+03, -.18326200E+04, 0.41763100E+03, -.24815900E+03, -.54242100E+02, 0.21608400E+03, 0.71020300E+02, 0.10741400E+04, -.32532300E+03, 0.77068900E+03, -.37924200E+04, 0.18739000E+04, -.52009900E+02, 0.18962000E+04, 0.89691000E+03, 0.17325400E+04, -.36688500E+03, -.15863100E+04, 0.23479700E+04, 0.13948100E+04, 0.25411000E+04, 0.37818200E+04, -.18775400E+04, -.33516800E+04, -.18909100E+04, -.52953100E+03, 0.42330200E+03, -.96943900E+03, -.11654000E+04, -.28804600E+04, 0.12303600E+04, -.26549600E+04, -.20875100E+04, 0.10539900E+04, 0.17231100E+04, 0.10437600E+04, 0.64408700E+03, 0.84124600E+03, 0.14020200E+02, -.96631300E+03, 0.17218600E+03, 0.95866800E+03, 0.76610200E+03, -.45319700E+04, 0.22584500E+04, 0.16144100E+04, 0.22660100E+04, 0.16729300E+04, 0.21589200E+04, -.12494400E+04, -.23473800E+04, 0.26644500E+04, 0.18945900E+04, 0.23235800E+04, 0.10039100E+04, -.54372900E+03, 0.57031700E+03, -.50188400E+03, -.37278500E+02, -.78395100E+02, -.10163200E+04, -.70300100E+03, -.15969000E+04, -.73656700E+02, -.77824300E+03, 0.10260300E+04, -.52235000E+03, -.10840800E+04, -.51303200E+03, -.86178700E+03, -.66577700E+03, 0.78630100E+03, 0.74219600E+03, 0.42371700E+03, -.76307900E+03, -.21432100E+02, 0.31441500E+04, -.15892000E+04, 0.50815400E+03, -.15720800E+04, 0.39150400E+03, -.49585000E+03, -.27718400E+04, -.20613100E+04, 0.22847500E+02, -.11010900E+04, -.68429900E+02, -.35635600E+03, 0.30777600E+03, -.93997700E+03, 0.25798700E+03, 0.19114100E+03, 0.67133600E+03, -.26782400E+03, 0.20461100E+03, -.50685700E+03, -.22347600E+03, -.43829300E+03, 0.15475900E+03, -.45096300E+03, -.57830700E+03, 0.35653000E+03, 0.29861000E+03, 0.74411100E+03, -.17754700E+03, -.22863000E+03, 0.60176900E+03, -.66611300E+03, -.32451600E+03, 0.23266400E+03, -.45123800E+03, 0.51998800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.89303700E+01, -.10237300E+01, 0.34866000E+01, 0.16170800E+01, 0.61686100E+00, 0.12105500E+01, -.92943200E+00, 0.44268500E-01, 0.52072400E+00, -.16189900E-01, -.32159400E+00, 0.62456400E+00, -.44924400E-01, 0.73907500E+01, 0.58503200E+00, -.77732600E-01, 0.22682500E+01, 0.42932500E+01, 0.18154900E+01, 0.39532100E-01, -.23650900E+01, 0.41982900E+00, -.72125200E+00, -.14822000E+01, -.27085100E+00, -.76342600E+00, -.28276600E+01, 0.20705000E+00, 0.72502200E+00, -.87507500E+00, 0.88003100E-01, 0.22134100E+00, 0.73659200E-01, 0.25633900E+01, -.16739000E+00, -.41450700E+01, 0.17322400E+00, -.25850000E+00, 0.43083000E-01, -.44214300E+01, -.13270300E-01, -.37420400E+00, -.51950400E+01, -.13899800E+00, -.33487200E+01, -.11117900E+01, 0.44102700E+00, -.23748900E+01, -.20356700E+01, 0.11798100E+05, -.73268700E+04, -.82545800E+04, 0.79705500E+04, 0.77511300E+04, 0.88977400E+04, 0.12574100E+05, -.61819900E+04, -.10771900E+05, -.62871400E+04, 0.41490100E+04, 0.61896800E+04, 0.10753800E+04, 0.13629100E+05, -.17578500E+04, 0.65739800E+04, -.91158800E+03, 0.13557900E+04, -.25250800E+03, 0.44744500E+04, -.67763200E+03, -.22312200E+04, -.16881000E+04, 0.15966300E+04, 0.14171900E+04, -.11275100E+04, -.12949700E+04, -.40722100E+03, -.34489600E+04, 0.26448600E+04, -.14466100E+05, 0.17247600E+04, -.20617900E+04, -.56775800E+04, 0.57957600E+04, 0.45372700E+04, 0.33841300E+04, -.52335600E+04, 0.35435100E+04, 0.75550400E+04, -.34076400E+04, -.11281200E+05, -.37775700E+04, -.28887300E+04, -.18616600E+04, 0.50611800E+03, 0.56561400E+04, 0.34465100E+04, -.25672100E+04, -.64602600E+03, -.59585600E+04, 0.33042600E+04, -.74650600E+03, 0.29792200E+04, 0.39057400E+04, 0.30370900E+04, -.82494500E+03, 0.27036200E+04, 0.18225700E+04, 0.46470700E+04, 0.52230500E+04, -.50062900E+04, 0.20858600E+04, 0.81251200E+04, 0.25030600E+04, -.35488000E+04, -.56941100E+04, 0.39199600E+04, -.82983500E+03, 0.94031500E+04, -.42463000E+04, 0.83253600E+03, -.11680000E+05, 0.60853400E+04, -.49493400E+04, 0.58399700E+04, 0.66589200E+03, 0.66237800E+04, -.12953400E+04, -.47498500E+03, -.84146300E+04, 0.56028100E+04, 0.11772700E+05, 0.34165900E+04, -.24244600E+04, 0.10056900E+05, -.17084600E+04, 0.19833200E+04, 0.37317800E+04, -.35409400E+04, -.22141700E+04, -.30853400E+04, 0.35660200E+04, -.34944000E+04, -.39908300E+04, 0.22580700E+04, -.87352500E+04, 0.19954100E+04, -.65280000E+03, 0.54870400E+04, -.30721400E+04, -.53324400E+04, -.24916000E+04, 0.28458600E+04, 0.38697200E+04, -.20166700E+04, 0.74528000E+03, 0.50476700E+04, 0.10083400E+04, -.35955500E+04, -.38438300E+04, 0.35571200E+04, 0.35707300E+04, 0.48454200E+04, -.21255500E+04, 0.12962300E+04, 0.89120000E+04, -.44471000E+04, -.70918600E+04, -.44567300E+04, 0.19799100E+03, -.32638500E+04, 0.12106100E+04, 0.62606900E+04, 0.33976400E+04, -.21328600E+04, -.51281100E+03, 0.13671600E+04, -.86596600E+03, 0.84938300E+04, -.68366700E+03, -.28600400E+04, -.12805800E+04, -.15297500E+04, -.53369500E+04, -.49663900E+03, -.26947900E+04, -.50202400E+04, -.77877100E+04, 0.35065800E+04, 0.15781000E+05, 0.38939900E+04, -.15639100E+04, -.28935800E+04, 0.19524700E+03, -.78070900E+04, 0.99237700E+04, -.40987900E+04, 0.30768700E+04, 0.25845900E+05, -.12865400E+05, -.24832500E+04, -.12922900E+05, 0.81836100E+04, 0.27121600E+04, 0.17810900E+04, 0.15930600E+05, -.60650800E+04, 0.50398500E+04, -.84411700E+04, -.84235800E+04, 0.42256900E+04, 0.57464000E+04, 0.42117400E+04, 0.31140800E+04, 0.14133000E+04, 0.23653800E+03, -.14418300E+03, 0.65044500E+04, 0.22269800E+04, 0.77030300E+04, 0.55305000E+04, -.28818000E+04, 0.10491700E+05, -.27654800E+04, -.36436300E+03, -.55702900E+03, -.63092800E+04, -.92801100E+04, 0.14322200E+05, -.12882000E+04, 0.16316900E+04, -.11879000E+05, 0.56644000E+04, -.86032500E+04, 0.59387900E+04, 0.51819000E+04, 0.26458300E+04, -.53050300E+03, -.96737100E+03, -.18810300E+04, 0.19863600E+04, 0.32052900E+04, 0.87810300E+04, -.46902400E+04, -.26089700E+04, -.43903700E+04, -.28759800E+04, -.54796500E+04, 0.28526300E+04, 0.11990700E+04, -.63209600E+04, -.61250300E+04, -.82757100E+04, -.18180400E+05, 0.91685100E+04, -.68250500E+03, 0.90902800E+04, -.56823900E+04, -.54119300E+04, 0.26507800E+04, -.41018200E+04, 0.29807900E+04, -.64492100E+04, 0.23948300E+04, -.10690900E+04, 0.22499100E+03, -.25545000E+03, -.10687000E+02, -.26271200E+04, 0.62258000E+03, 0.85777000E+03, -.28196000E+04, -.24235400E+03, -.16281000E+04, 0.56897300E+03, 0.15649100E+04, -.39173500E+04, -.55842500E+03, 0.88146900E+02, -.29348700E+03, -.49952500E+03, 0.53493900E+03, 0.78795700E+03, -.16761400E+04, 0.20738800E+04, -.35264400E+04, -.50295700E+03, -.30492100E+03, 0.17253600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.63056300E+00, 0.39163000E-01, -.12971000E+00, 0.18935000E+01, 0.12647400E+01, -.95843400E+00, 0.37147800E+00, -.58093700E-01, 0.13087300E+00, 0.24616900E+00, 0.38554200E+00, -.27424200E+00, -.41244300E+00, 0.69700200E+00, 0.78364700E-01, 0.13399700E+00, 0.57962400E-01, 0.48834000E+00, 0.40012900E+00, -.40757200E-01, 0.34158200E-01, 0.56734100E-01, -.51648200E-01, -.29533100E+00, -.34134400E-01, -.11751600E+00, -.49069400E+00, 0.13946200E+00, -.98423800E-01, 0.91243400E-02, 0.40916200E-01, -.47709500E-01, -.42042700E-01, -.28854900E+00, 0.20817600E-01, -.84960600E-01, -.30423200E-01, 0.27232900E-01, -.71309600E-01, -.26300300E+00, -.96145000E-01, -.32834600E+00, 0.85461500E+00, 0.68886400E-02, -.59886100E+00, -.11427000E+00, -.34828300E+00, 0.57147200E+00, 0.14961700E+00, -.49915000E-01, 0.18571100E+04, 0.20503800E+04, 0.56446400E+03, -.10186000E+03, -.71247800E+03, -.27331500E+04, 0.13711900E+04, 0.93855900E+03, 0.13665500E+04, 0.46293500E+03, 0.25025700E+03, 0.58815000E+03, 0.18827700E+03, 0.13688100E+04, -.35368700E+03, 0.14461500E+03, 0.14608700E+04, -.71467500E+03, -.20920100E+02, -.73036800E+03, 0.11430600E+03, 0.17561500E+03, -.36171000E+03, 0.50460300E+03, -.30352100E+03, 0.16684600E+03, -.68707200E+03, 0.51558600E+02, 0.27257600E+02, -.28416700E+04, -.25707400E+02, 0.27143500E+03, -.82158300E+03, 0.28288800E+03, -.34333500E+03, -.36183300E+03, -.35068700E+03, -.49995900E+03, -.25500200E+04, 0.12769000E+04, 0.62605100E+03, 0.12750000E+04, -.14177700E+02, 0.22526400E+03, 0.64044100E+03, -.17483300E+02, 0.45963400E+03, 0.40945900E+03, 0.11442100E+04, -.25002800E+04, 0.12579100E+04, 0.30901000E+03, 0.12501300E+04, 0.70988300E+03, 0.66886400E+03, -.21978500E+03, -.25627900E+03, 0.16473900E+04, 0.22244900E+03, 0.14142600E+04, 0.31949200E+04, -.16125000E+04, -.91404200E+03, -.15974800E+04, -.77236200E+03, -.52778100E+03, 0.76129100E+03, 0.87051800E+03, -.88159100E+03, -.69065500E+03, -.10398700E+04, -.22365600E+04, 0.11293000E+04, 0.19628900E+03, 0.11182800E+04, 0.10009400E+04, 0.84966200E+03, -.82888500E+03, -.33117800E+03, 0.10692000E+04, 0.90101000E+03, 0.65035900E+03, -.29138500E+03, 0.10340400E+03, 0.21687400E+04, 0.14565100E+03, -.66564100E+02, 0.62866500E+03, -.25262500E+03, 0.12732900E+03, 0.30532700E+03, 0.28125900E+03, 0.49197900E+03, -.20479600E+04, 0.10299500E+04, -.50059100E+02, 0.10239800E+04, 0.34291000E+03, -.75993400E+03, 0.46715800E+03, -.29551300E+03, 0.43906400E+03, -.21437700E+03, 0.75459500E+03, 0.20361300E+04, -.10234200E+04, -.88733000E+03, -.10180600E+04, -.50843200E+03, 0.66814500E+03, -.78578700E+03, -.29183600E+03, -.60671200E+03, 0.39517700E+03, -.22172400E+03, -.10343500E+04, 0.51249400E+03, 0.47119000E+03, 0.51715300E+03, 0.50955800E+03, 0.14018200E+03, -.12952700E+03, -.72453000E+03, -.16473900E+03, -.85381100E+00, -.14668700E+03, 0.21073800E+04, -.10568800E+04, 0.35504200E+03, -.10537100E+04, -.31220500E+03, -.29627100E+02, -.36162200E+03, 0.34227200E+03, -.11743600E+04, 0.22281900E+03, -.10260200E+04, 0.30270100E+04, -.15302100E+04, -.18772800E+03, -.15134700E+04, -.54407900E+03, -.10019300E+04, 0.12014400E+04, 0.15058500E+04, -.94690400E+03, -.85345000E+03, -.17557000E+04, 0.21452100E+03, -.10009900E+03, 0.58278200E+03, -.10726200E+03, 0.22394500E+03, -.15700700E+03, 0.47697700E+03, 0.12082100E+04, 0.67570300E+03, -.10604800E+04, -.59927500E+03, 0.11232000E+03, -.57386600E+02, -.11455000E+03, -.56171100E+02, 0.12569200E+03, 0.26461700E+03, 0.35830600E+03, 0.71173400E+03, 0.44442700E+03, -.19624800E+03, -.31924500E+03, 0.34922400E+04, -.17546800E+04, 0.56978300E+03, -.17461700E+04, -.14450300E+04, -.21158700E+04, 0.27427300E+04, 0.31002600E+04, -.53534400E+03, -.20521100E+04, -.13347600E+04, -.34285000E+04, 0.17049000E+04, -.84118000E+03, 0.17140800E+04, 0.70266100E+03, 0.66230900E+03, -.65287900E+03, -.16745100E+04, 0.74782200E+03, 0.80307200E+03, 0.18881400E+04, 0.82016700E+03, -.41710600E+03, 0.35058400E+03, -.41004700E+03, -.23292700E+03, -.26631300E+03, -.11652900E+03, -.29715800E+03, -.10134800E+04, 0.14310900E+03, -.71737300E+03, -.23450500E+04, 0.11675600E+04, 0.51063200E+03, 0.11725400E+04, -.33618700E+03, 0.15301700E+03, 0.54236400E+03, -.11858700E+03, 0.52423500E+03, 0.76116200E+03, 0.19782300E+04, 0.57346600E+03, -.11983000E+03, 0.11697700E+03, -.43943200E+03, -.27664500E+03, -.18095500E+03, 0.59617800E+02, -.25789600E+03, 0.68655000E+03, 0.95825600E+02, 0.58903800E+03, 0.53450100E+02, 0.76750000E+02, 0.70078800E+03, -.28968400E+03, -.46983000E+03, -.63168900E+02, 0.41515100E+03, -.41482800E+02, -.28664200E+03, 0.50290000E+03, -.14114600E+03, -.20708900E+02, 0.57597500E+03, -.26328100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.94378500E+00, 0.62068700E-01, -.28873700E+00, -.11355200E+01, -.14317400E-01, 0.12094300E+01, -.12928400E+01, -.41123500E-01, 0.19182800E+00, 0.23351800E+00, 0.29803200E+00, 0.69274100E-01, 0.36147800E+00, 0.51882000E+00, -.73537500E-01, -.23902500E+00, 0.15040700E+00, 0.93136100E+00, -.40798000E+00, 0.63986500E+00, -.28672000E+00, -.51815600E-02, 0.19805300E+00, 0.76807700E+00, 0.83906900E-01, -.86273000E-02, 0.25863200E+00, -.12365800E+01, -.45245500E+00, 0.12223800E+00, -.51048800E-01, 0.24698400E+00, 0.61300800E+00, 0.21687400E+00, -.15557600E-01, -.43437200E-01, -.14072600E-01, 0.98512500E-01, -.21951200E+00, -.65581000E+00, 0.15422000E+00, 0.23607700E+00, -.28838700E+00, 0.89559300E-01, -.75639500E+00, -.78967100E-01, -.88900000E-01, 0.60663800E+00, -.95255500E+00, -.52243800E-01, -.10154900E+01, -.43790900E+04, 0.22388400E+03, -.33050400E+03, -.12580200E+04, -.26665300E+04, 0.13577100E+04, -.22160600E+04, 0.13332500E+04, 0.85813800E+03, 0.11220100E+04, 0.51141500E+03, 0.93541800E+01, 0.23371900E+03, 0.16685600E+04, 0.11742900E+03, 0.30809200E+04, -.14069200E+04, -.88488700E+03, -.15404200E+04, -.64746400E+03, -.10006600E+04, 0.10864100E+03, 0.12724400E+04, 0.68726600E+03, -.82820000E+03, -.13129800E+04, 0.79931000E+04, -.36740300E+04, -.24198800E+04, -.39965100E+04, -.45599200E+02, 0.17920800E+03, -.69964200E+03, 0.15229300E+04, -.28732500E+04, 0.47679700E+03, -.44534300E+04, 0.13247200E+05, -.65185600E+04, 0.53765500E+03, -.66236100E+04, -.22757300E+03, -.11131600E+03, -.29196800E+04, -.11891400E+04, -.46411100E+04, -.31806100E+03, -.74175000E+04, -.48018600E+04, 0.24842500E+04, 0.62565300E+04, 0.24009200E+04, 0.32522300E+04, 0.39612300E+04, -.11329100E+04, -.83645200E+03, 0.13943900E+04, 0.30802700E+04, 0.17148800E+04, 0.95107900E+03, -.60192600E+03, -.28695400E+04, -.47555300E+03, -.26568900E+04, -.30634800E+04, 0.31994700E+04, 0.18081700E+04, 0.18601100E+04, -.25844900E+04, -.94774100E+03, -.55684100E+04, 0.28595100E+04, 0.34616100E+04, 0.27842000E+04, 0.11263800E+04, 0.94363800E+03, -.15859200E+04, -.21457400E+04, -.11236600E+04, 0.12459400E+04, 0.30700100E+04, -.63518900E+04, 0.29291200E+04, 0.24289300E+04, 0.31759200E+04, 0.17658200E+03, 0.20688100E+02, 0.34768900E+03, -.14646800E+04, 0.20121300E+04, -.20945700E+03, 0.35539800E+04, 0.13084500E+05, -.64488100E+04, 0.19010700E+04, -.65422700E+04, -.38746700E+03, 0.92788200E+03, -.32496100E+04, 0.13278200E+04, -.50267700E+04, 0.71992600E+03, -.52087600E+04, 0.38446100E+04, -.20095800E+04, 0.49404200E+04, -.19223000E+04, 0.78955100E+03, 0.18091400E+04, -.19710700E+04, -.21572300E+04, -.21345500E+04, 0.81724300E+03, -.20789200E+04, -.97799000E+04, 0.48893500E+04, -.11337800E+04, 0.48897000E+04, 0.39874400E+02, -.80877200E+03, 0.36464800E+04, 0.19591800E+04, 0.37381600E+04, -.11502500E+02, 0.33559000E+04, 0.15426400E+04, -.80915200E+03, -.44921600E+04, -.77133200E+03, -.16350500E+04, -.16074100E+04, -.57973300E+03, -.60731400E+03, -.16885900E+03, -.11808200E+04, 0.45370000E+03, -.22157300E+04, 0.10111300E+04, -.62580400E+04, 0.11078800E+04, -.15804100E+04, -.14652100E+04, 0.24196800E+04, 0.29529200E+03, 0.22880900E+04, -.93222000E+03, 0.83751100E+03, -.51957700E+04, 0.26129100E+04, -.71993500E+04, 0.25978800E+04, 0.17639000E+04, 0.43625200E+04, 0.90339100E+03, 0.20755900E+04, 0.11138100E+04, 0.46364500E+04, 0.20827600E+04, -.31159600E+04, 0.15576000E+04, 0.69400800E+03, 0.15579700E+04, 0.88781100E+03, 0.16258200E+04, 0.58440300E+03, -.98521300E+03, 0.10663400E+04, 0.14147600E+04, 0.10479400E+04, 0.18026500E+04, -.91487100E+03, -.76048200E+04, -.90136000E+03, -.38367100E+04, -.43746100E+04, 0.45521600E+04, 0.36048700E+04, 0.45984900E+04, -.36604900E+04, -.41742900E+03, -.47398600E+04, 0.22941600E+04, 0.31038100E+04, 0.23698300E+04, 0.20801000E+04, 0.23066700E+04, -.27085000E+04, -.38241600E+04, -.21301300E+04, 0.20606900E+04, 0.23381300E+04, 0.33494600E+04, -.17638600E+04, -.45380300E+04, -.16747100E+04, -.15780600E+04, -.19042200E+04, 0.48426000E+03, 0.73844100E+03, -.17450000E+04, -.13813700E+04, -.10331500E+04, 0.22908500E+05, -.11433200E+05, -.34420500E+02, -.11454200E+05, -.20262500E+04, -.25285400E+04, -.54509700E+04, -.19120100E+04, -.75465800E+04, -.26892000E+04, -.93120400E+04, 0.21118400E+03, -.14763100E+03, 0.18386100E+03, -.47432200E+03, -.50757400E+03, 0.25355200E+03, -.15867100E+03, -.44360100E+03, 0.10234300E+04, 0.47400900E+03, 0.54332100E+03, -.31422900E+03, -.43747600E+03, 0.72565900E+03, -.22625300E+03, -.30856700E+02, -.98067200E+03, 0.67313600E+03, 0.34634100E+03, -.57401700E+03, 0.16879500E+03, -.50499900E+03, 0.19410200E+02, 0.42362700E+03, 0.18644200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.23539600E+01, 0.25163900E+00, 0.59847700E+00, 0.49011000E+00, 0.18738800E+01, -.10506100E+00, 0.37479400E+00, 0.12421600E+00, 0.16908400E+00, -.29115000E+00, 0.25854300E+00, -.38428300E+00, -.57578600E-02, 0.11761800E+01, -.35890100E+00, 0.99988200E-01, 0.85439000E+00, -.35869900E+00, 0.16549100E+00, 0.65901200E+00, -.27593000E+00, -.41760400E-01, 0.19112100E+00, 0.80601000E+00, -.67850700E-01, -.51715000E+00, -.15189600E+01, -.27188900E+00, 0.12809200E+01, -.50364700E+00, -.11146700E+00, -.63572900E+00, 0.11095700E+01, 0.55442300E+00, -.14725500E+00, -.93154700E+00, -.38122200E-01, 0.80904800E-01, -.45458500E+00, 0.37875700E+00, 0.25645600E+00, 0.46955100E+00, -.29538400E+01, 0.10466600E+00, -.20360500E+00, -.54365700E-01, 0.26156700E+00, 0.48502000E+00, -.72488100E-01, 0.12363200E+00, 0.10213600E+01, 0.48343000E+00, -.92028300E+04, 0.13266900E+04, -.47756100E+03, 0.68976600E+04, -.34848900E+04, -.20748600E+04, -.34487500E+04, -.20662500E+03, 0.34438300E+02, -.36050000E+04, -.31386800E+04, -.43119600E+04, 0.20274300E+03, 0.79896700E+03, -.61956300E+04, 0.30318000E+04, 0.15737500E+04, 0.30975800E+04, 0.14067300E+04, 0.18903500E+04, -.75681900E+03, -.23197300E+04, 0.26294700E+03, 0.15831700E+04, 0.32338200E+04, -.59877300E+04, 0.28026200E+04, 0.55745800E+04, 0.29936300E+04, -.17475100E+03, 0.39888500E+03, 0.39555300E+03, -.49672600E+03, 0.32157200E+04, -.54379900E+02, 0.33297600E+04, -.29202600E+04, 0.14295300E+04, 0.23581800E+03, 0.14601700E+04, -.50795200E+03, -.35702700E+03, -.50376000E+03, -.84011900E+03, -.12278100E+04, 0.12233900E+03, 0.37733800E+04, 0.57252200E+04, -.29218500E+04, -.52345300E+04, -.28625700E+04, -.24689000E+04, -.37398700E+04, 0.20703400E+04, -.10274400E+04, -.41053500E+04, -.26651000E+04, -.41284100E+04, -.29014100E+04, 0.15325200E+04, 0.25642800E+04, 0.14507600E+04, 0.17101300E+04, 0.18686800E+04, -.31505700E+04, -.30971000E+04, -.49805200E+04, 0.20727300E+04, 0.12947800E+04, 0.75578800E+04, -.38352800E+04, -.17436300E+04, -.37789300E+04, -.99393200E+03, -.14330600E+04, 0.58502200E+03, 0.30597800E+04, 0.49958200E+04, -.18397300E+04, -.33652700E+04, 0.47281600E+04, -.22275800E+04, -.47073300E+04, -.23639400E+04, -.11911500E+03, -.32813900E+03, -.31428600E+03, 0.50911400E+03, -.18402400E+04, -.85906600E+02, -.23349200E+04, -.49001700E+03, 0.21849500E+03, -.28997300E+03, 0.24500800E+03, -.28615000E+03, 0.40998500E+03, 0.77839900E+03, 0.12009100E+04, 0.38916500E+04, -.14187900E+03, -.58276600E+03, -.39057900E+03, 0.22639300E+03, -.30360100E+04, 0.19528400E+03, -.87416400E+02, -.18647700E+04, -.35244100E+03, -.19178900E+04, -.11719800E+04, -.86160800E+03, 0.28472500E+03, 0.66373400E+04, -.33037700E+04, -.50353600E+03, -.33186500E+04, -.53520100E+03, 0.38959800E+03, -.15459000E+04, 0.81121700E+03, -.25064400E+04, -.25059000E+02, -.69095900E+03, -.63145700E+04, 0.31961800E+04, 0.31845600E+04, 0.31573500E+04, 0.68905500E+03, 0.42583300E+03, 0.19088600E+04, 0.16181400E+04, 0.46742000E+04, 0.18983700E+03, 0.34193900E+04, 0.44184000E+04, -.21052000E+04, -.78045300E+03, -.22093000E+04, -.67620200E+03, 0.15978900E+02, -.35677800E+03, 0.26282700E+04, -.45311700E+04, 0.42212500E+03, -.16730300E+04, 0.97397400E+04, -.49104200E+04, -.22773900E+04, -.48698600E+04, -.25172400E+04, -.23694100E+04, -.32767200E+04, -.41986400E+04, -.60431900E+04, -.15536600E+04, -.13708500E+04, 0.45882600E+04, -.22938100E+04, -.22313500E+04, -.22941000E+04, -.22947000E+04, -.31402900E+04, 0.10188300E+04, 0.62100800E+03, -.53425600E+04, -.18045600E+04, -.15641300E+04, -.34600800E+03, 0.23897800E+03, 0.36907700E+04, 0.17316900E+03, -.11685600E+04, 0.26737600E+01, 0.54382600E+03, -.26760600E+04, -.13435100E+05, 0.13062200E+04, -.10617400E+04, 0.69443400E+04, -.34577600E+04, -.18116600E+04, -.34716600E+04, -.29475400E+04, -.42051700E+04, 0.38593500E+04, 0.49284000E+04, 0.48919300E+04, -.40974700E+04, -.39391100E+04, -.56069100E+04, 0.28468800E+04, 0.33391800E+04, 0.28033500E+04, 0.19510400E+04, 0.30536000E+04, -.14400200E+04, 0.18774200E+04, 0.64743300E+04, 0.19439000E+04, 0.38485300E+04, -.95659600E+04, 0.48028600E+04, 0.18783900E+04, 0.47829300E+04, 0.71457600E+03, 0.68735800E+03, 0.13544900E+04, 0.43020800E+03, 0.58595600E+04, 0.72952900E+03, 0.31475900E+04, 0.30074800E+02, -.32151200E+03, -.13004200E+03, -.14297700E+03, 0.13572000E+03, 0.10405600E+03, 0.11661100E+03, 0.14444000E+03, -.10157900E+04, 0.30583600E+03, -.12711800E+04, -.38389600E+03, 0.12525900E+04, -.86143900E+03, 0.29587300E+03, -.20382000E+03, 0.26584500E+03, -.92304600E+03, -.17856300E+03, 0.65063300E+03, -.18667700E+04, 0.14152200E+04, -.83127000E+03, -.10423800E+04, -.49959200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.49168800E+00, -.12629800E+00, -.64447600E+00, 0.35951300E+00, -.54808100E+00, -.72071900E+00, 0.10709500E+01, 0.20173700E-01, 0.75296900E-01, 0.48777400E+00, -.22381100E-02, -.24363300E+00, -.97055500E-01, 0.39820800E+00, -.10313700E+00, 0.24988900E+00, 0.17884900E+00, -.22564700E+00, -.49252200E-01, -.26902600E+00, -.34074600E-01, -.46586400E-01, -.62647400E-01, 0.11790100E-01, 0.50239500E-02, 0.11405100E+00, 0.70591000E+00, 0.35911000E-01, -.44047500E+00, 0.47006400E+00, 0.41586700E-01, -.94540900E-01, -.26551600E+00, 0.26968100E-02, -.16710500E-01, 0.11392000E+01, -.19519000E-01, 0.26124900E-01, -.80638100E-02, -.20161600E+00, 0.21440300E-01, -.20994300E+00, -.11765300E+01, 0.12746300E+00, 0.10107500E+00, -.35883500E-02, 0.35236400E-01, 0.23145400E+00, 0.15954500E+00, 0.13140900E-01, -.19126400E-01, -.80818300E-02, 0.74260900E-01, -.39351200E+03, -.45657800E+03, -.13538100E+04, 0.68060600E+03, 0.28628200E+03, 0.67689900E+03, -.65802800E+03, -.60509300E+03, 0.20061000E+03, -.76480100E+03, 0.48712100E+03, -.88893600E+03, 0.54278900E+03, 0.13175000E+04, -.64191500E+03, -.32093500E+03, -.65871800E+03, 0.10195600E+03, 0.15351600E+03, -.32477100E+03, -.11741400E+02, -.37619700E+03, 0.11342300E+03, -.67121200E+03, -.10687800E+04, 0.50214100E+03, -.11029400E+04, 0.53442000E+03, -.24014300E+03, -.88385600E+03, 0.21681200E+03, -.16899200E+03, 0.30614600E+03, -.82853900E+03, 0.62613000E+03, -.13040000E+04, 0.65305600E+03, 0.56737800E+03, 0.65199500E+03, -.11425600E+03, 0.69508400E+03, -.78159500E+02, -.66637700E+03, 0.16618900E+03, 0.48601400E+03, 0.21563000E+02, -.21051500E+03, 0.11452300E+03, 0.43524100E+01, 0.10525300E+03, -.31180100E+03, -.10331600E+03, 0.17337100E+03, -.93569200E+02, 0.31909900E+03, -.40728300E+03, 0.15435400E+03, 0.13612300E+03, -.72100000E+02, -.37290400E+02, -.68068100E+02, 0.80167000E+03, 0.35088200E+03, -.25377000E+03, 0.20525400E+03, -.54638500E+01, 0.40270700E+03, -.18184800E+03, 0.78423300E+03, -.38610000E+03, -.33069800E+03, -.39211800E+03, -.38683100E+03, -.47467200E+03, 0.70460500E+02, -.49179300E+03, -.14396000E+03, -.43973900E+03, -.62303700E+03, 0.94758400E+03, -.46158700E+03, 0.10608300E+04, -.47381200E+03, 0.92248400E+02, 0.67254000E+03, -.21981900E+03, 0.34062800E+02, -.40784300E+03, 0.62847900E+03, -.53368500E+03, -.14474800E+03, 0.74381900E+02, -.19927100E+03, 0.72374400E+02, -.10170100E+03, -.35872500E+03, 0.15171600E+02, -.17434000E+03, -.16204600E+02, 0.39161500E+02, 0.43571000E+02, 0.10472200E+04, -.52073200E+03, 0.16809600E+03, -.52360700E+03, 0.14752900E+02, 0.81601100E+03, -.41075100E+03, -.61858200E+02, -.72548600E+03, 0.28159300E+03, -.48653000E+03, -.24736700E+04, 0.12418900E+04, 0.89147800E+03, 0.12370700E+04, 0.21054900E+03, 0.21573000E+02, 0.14112800E+03, -.77576300E+03, 0.36214100E+03, 0.16610900E+03, 0.77591800E+03, 0.80464500E+03, -.40578200E+03, -.77358500E+03, -.40232900E+03, 0.13974800E+03, -.14111300E+03, 0.23007200E+01, 0.55192900E+03, -.37804300E+03, -.60195800E+00, -.13204600E+03, 0.41784000E+03, -.22167200E+03, -.13404500E+03, -.20890900E+03, 0.93456400E+03, 0.54726700E+03, -.46705600E+03, 0.16016700E+03, -.53192200E+03, 0.76097900E+03, -.54424400E+03, -.16186900E+04, 0.81804900E+03, 0.77471700E+03, 0.80934500E+03, -.55055500E+03, -.63321400E+03, 0.31681900E+03, -.33291500E+03, 0.58975100E+03, -.72912500E+03, 0.70857000E+03, 0.33464200E+03, -.16260700E+03, 0.33191000E+03, -.16732500E+03, -.22850000E+03, 0.30488100E+03, -.90515200E+02, 0.46476000E+02, -.86048800E+02, -.27784000E+02, -.16641900E+03, -.22832700E+03, 0.11548900E+03, -.47334700E+03, 0.11414400E+03, 0.49436600E+03, 0.33525100E+03, -.59473700E+02, 0.90581100E+03, 0.41850100E+03, 0.37174500E+03, -.10593600E+03, -.11658100E+04, 0.54500800E+03, -.19505900E+03, 0.58284000E+03, -.69245200E+03, -.86852200E+03, 0.72789900E+03, 0.27877300E+03, 0.52277000E+03, -.79689200E+03, 0.76426800E+03, -.54685800E+02, 0.18489200E+02, 0.32754500E+03, 0.27355900E+02, 0.21204000E+03, 0.32912200E+03, -.24922100E+03, -.26963500E+03, -.27559700E+03, 0.54591800E+03, 0.20256700E+03, 0.15494500E+04, -.78657000E+03, -.84297200E+03, -.77471800E+03, 0.16145300E+03, 0.10741400E+04, -.57128400E+03, -.94763400E+02, -.64242300E+03, 0.98067400E+03, -.44733800E+03, 0.98796800E+02, 0.69617600E+02, -.10461300E+03, 0.11192900E+02, 0.25946200E+03, 0.71281400E+02, -.15095300E+03, 0.27373200E+03, -.51765700E+03, -.10232400E+03, 0.11980100E+03, 0.95986100E+01, 0.20438200E+03, -.45988500E+03, 0.11393400E+03, 0.63604900E+02, 0.17085700E+03, -.23509900E+02, -.15723700E+03, 0.62404300E+02, -.83250200E+01, 0.13789300E+03, 0.35646600E+03, 0.19060100E+03, -.32942000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12738200E+01, 0.47437400E-01, -.37834000E+00, 0.28284400E+00, -.88212000E+00, -.11696300E+00, 0.29424900E+00, -.27263800E-01, -.12117400E+00, 0.51781100E+00, 0.74095900E+00, -.23515800E+00, 0.13981800E-01, 0.69927200E+00, -.12534800E+00, 0.54077100E+00, 0.83688400E+00, 0.80706400E+00, -.12593300E+00, 0.24633700E+00, -.19445600E+00, -.31810600E-01, 0.13406100E+00, 0.35001100E+00, 0.82949300E-01, -.83779800E-01, 0.76305100E+00, -.99778900E+00, -.11688300E+00, -.85775100E-01, -.43312100E-01, 0.27815000E+00, 0.57902200E+00, -.30100300E+00, 0.44266100E-01, -.30241000E+00, 0.25739600E-01, -.25081200E-01, -.23407300E+00, -.65943800E+00, -.96878900E-01, -.17447700E-01, -.60185700E+00, -.51884100E-01, 0.11558800E-01, -.80152900E-01, -.27162800E+00, -.10147100E+00, 0.55333200E+00, 0.27074800E-02, 0.38328600E+00, -.59184800E-01, -.52616300E-01, -.18601800E+00, 0.27313600E+04, 0.36766100E+04, -.18341200E+04, -.14384900E+03, -.18383000E+04, -.21770800E+03, 0.14391000E+04, -.60395800E+03, 0.20521800E+04, -.96599700E+03, 0.10753000E+04, 0.67383200E+03, -.13751800E+04, 0.69140600E+03, 0.53633500E+03, 0.68755000E+03, -.34628900E+01, -.15688300E+03, 0.34424200E+03, -.34087800E+02, -.40010400E+03, -.25613000E+02, 0.59067200E+03, -.28365900E+04, 0.14584600E+04, 0.11808600E+04, 0.14182700E+04, 0.19273500E+03, -.27175300E+03, 0.13230500E+04, 0.93232200E+03, 0.14044100E+04, -.50187800E+03, 0.19535100E+04, -.17959700E+04, 0.90934900E+03, -.79514200E+03, 0.89798600E+03, -.50455700E+03, -.67698900E+03, 0.72437300E+03, 0.88023200E+03, 0.95560500E+03, -.54393800E+03, 0.19840900E+04, 0.14279800E+03, -.61176900E+02, -.53071300E+03, -.71395500E+02, 0.20119000E+02, 0.34648100E+03, -.22002800E+03, 0.20861400E+03, -.60661800E+03, 0.65615000E+03, -.55348100E+03, -.69332900E+02, 0.14944700E+02, 0.78196800E+03, 0.34670100E+02, -.70422500E+03, -.13463400E+04, 0.44656400E+03, -.11955900E+03, 0.31562100E+03, -.84969300E+03, -.29038700E+03, -.21623000E+04, 0.10913900E+04, 0.47621200E+03, 0.10811500E+04, -.16226400E+03, 0.20919500E+04, -.14791000E+03, 0.55001800E+03, 0.99867100E+02, 0.14398700E+04, 0.21283800E+04, 0.25726700E+04, -.13160800E+04, -.11875300E+04, -.12863100E+04, -.25464500E+02, 0.17180700E+03, -.97769900E+03, -.54977600E+03, -.11948900E+04, 0.34484900E+03, -.16110600E+04, -.12124500E+04, 0.61185400E+03, -.69052100E+03, 0.60622500E+03, 0.12273000E+03, 0.19239300E+04, -.29390100E+03, -.66288600E+03, 0.52313500E+03, 0.10742500E+04, 0.77203000E+03, -.38165000E+04, 0.18979200E+04, -.42595800E+03, 0.19082500E+04, -.68264600E+03, -.24567700E+04, 0.14772400E+04, -.13675600E+03, 0.18105400E+04, -.12362100E+04, 0.13011600E+04, 0.61534100E+04, -.30831300E+04, -.83074500E+03, -.30766600E+04, -.28163100E+03, 0.77825000E+03, -.19750100E+04, -.20593800E+03, -.15208200E+04, 0.33206900E+03, -.99731100E+03, -.16586400E+04, 0.82185400E+03, 0.26850700E+04, 0.82932400E+03, 0.24243200E+03, -.88904400E+03, 0.31671400E+03, -.10663000E+04, 0.51541600E+03, -.70319300E+03, 0.17941200E+03, 0.23263100E+04, -.11795300E+04, 0.79834300E+03, -.11631600E+04, -.28723500E+03, -.20157700E+04, 0.44495700E+03, 0.32108800E+03, 0.16933900E+03, -.17847400E+04, -.27731200E+03, 0.32218900E+04, -.16098500E+04, 0.81010000E+02, -.16109400E+04, 0.14728700E+03, -.33984300E+03, 0.51690700E+03, 0.22215800E+04, -.41353300E+03, -.34237700E+03, -.43696700E+03, -.10392700E+04, 0.51622100E+03, -.43656500E+02, 0.51963600E+03, 0.35330300E+03, -.12097400E+04, 0.29629100E+03, 0.12845200E+03, 0.43069500E+03, -.73198000E+03, 0.13432600E+04, 0.21987700E+04, -.11109900E+04, 0.18618000E+04, -.10993700E+04, 0.37643300E+02, -.15854700E+04, -.78916500E+03, -.18586100E+04, -.17896100E+03, -.11835900E+04, -.65622400E+01, -.64201900E+03, 0.32526300E+03, 0.10268400E+03, 0.32106200E+03, 0.66507700E+03, 0.87854000E+03, 0.18239600E+03, 0.70431500E+03, 0.77737400E+03, 0.47235800E+03, -.48543000E+03, 0.41232800E+03, -.21450900E+03, -.68312000E+03, -.20617300E+03, 0.14151500E+03, -.64472100E+03, 0.47689600E+03, 0.46599600E+03, 0.52121000E+02, -.83266400E+03, -.32172700E+03, -.77207800E+04, 0.38688400E+04, 0.15854200E+04, 0.38603800E+04, -.20546800E+03, -.13043000E+04, 0.23636400E+04, 0.61298500E+03, 0.21282500E+04, -.84456300E+03, 0.13868000E+04, -.68924200E+02, -.34514700E+03, 0.45932200E+03, -.20423200E+03, -.23807800E+03, -.41291400E+03, 0.49769600E+03, -.32061100E+03, 0.14042800E+03, 0.19076200E+03, -.32849500E+02, -.43387000E+02, -.54049700E+03, 0.14002900E+03, -.26576500E+03, -.33011700E+03, -.58099600E+03, -.51134600E+01, 0.30459800E+03, -.67844000E+03, 0.39326500E+03, -.15443700E+03, -.36485500E+03, -.62960400E+02, -.30024100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27720600E+01, -.95820300E-01, -.60030000E+00, -.20325500E+01, 0.72854400E-01, 0.54226700E+00, -.32056700E+00, 0.18622600E-01, 0.33326100E+00, -.16325500E+01, -.11472200E+01, -.28478000E+00, -.32010100E+00, 0.25101600E+00, 0.15437500E+00, -.25084700E+00, -.45213200E+00, -.28937400E+00, -.32916400E+00, 0.27318000E-01, -.13107100E-01, -.85837200E-02, 0.19618000E+00, 0.41325600E+00, -.54524800E-01, -.17952500E+00, -.18222800E+00, -.15108200E+01, -.22736600E+00, 0.11203900E+00, 0.35169200E-01, -.43049500E+00, -.75461200E-01, -.57836900E-01, -.10556000E-01, -.64324600E+00, -.26200100E-02, -.11580500E+00, -.37853400E+00, -.35322900E+00, -.51549200E+00, 0.27944500E+00, -.69376000E+00, -.52145500E-01, -.85585700E-01, -.25634600E+00, -.10885600E+00, 0.74793600E-02, 0.22649900E+00, -.10482200E-02, -.37355400E+00, 0.42546500E+00, 0.15868000E+00, -.90488100E-01, -.28340700E+00, 0.43582200E+04, -.21743600E+04, 0.63278500E+03, -.21791300E+04, 0.15567900E+04, 0.11274100E+04, -.11158200E+04, 0.13659900E+04, -.98071600E+03, -.15038600E+03, -.51233400E+04, 0.81623800E+03, -.43494900E+03, -.11207800E+03, -.40809000E+03, -.32281800E+02, -.31936900E+03, 0.50836900E+01, 0.30976700E+03, -.79101000E+03, -.28843900E+03, -.25338300E+03, -.85530100E+03, 0.41201000E+03, -.49877800E+04, 0.42768300E+03, -.27264800E+03, 0.44222100E+03, 0.44990000E+03, -.23086100E+02, 0.92018400E+02, 0.75186800E+03, 0.11307400E+04, -.83675500E+04, 0.41277800E+04, -.77248000E+03, 0.41837700E+04, 0.12334400E+04, 0.76061400E+03, 0.26843900E+04, 0.25531000E+04, 0.32093700E+04, 0.87193800E+03, 0.26245400E+04, 0.10583600E+04, -.54834000E+03, -.27941400E+04, -.52918600E+03, -.21931200E+03, -.74914900E+03, -.38481700E+03, 0.10165600E+04, 0.17375800E+02, -.87383500E+03, -.74844900E+03, 0.13556500E+04, -.65766500E+03, 0.82163900E+03, -.67783400E+03, -.12177900E+03, -.71193400E+02, -.11584500E+03, -.77210900E+02, -.53742800E+03, -.10451800E+03, -.42837200E+03, -.30983800E+04, 0.15431100E+04, 0.30415100E+03, 0.15491900E+04, 0.13728900E+03, 0.15839500E+04, 0.51522500E+03, 0.10745000E+04, 0.11986800E+04, 0.11504400E+04, 0.89379100E+03, 0.53285600E+03, -.26270800E+03, 0.34261300E+04, -.26644700E+03, 0.36432600E+03, -.45147100E+03, -.94574100E+02, 0.27931200E+03, 0.28186300E+02, -.67977200E+03, -.99758400E+03, -.10887500E+05, 0.54021800E+04, 0.31281900E+02, 0.54437500E+04, -.50516100E+03, -.75083600E+03, 0.29198000E+04, -.57503100E+03, 0.39842500E+04, -.31266000E+03, 0.57001300E+04, -.30293100E+04, 0.15476200E+04, -.25092600E+04, 0.15146500E+04, -.81996300E+03, -.15756200E+04, 0.18702900E+04, 0.23438000E+04, 0.19896800E+04, -.11312800E+04, 0.70511000E+03, 0.46934400E+04, -.23659100E+04, 0.16279900E+04, -.23466100E+04, 0.35694300E+03, 0.11056400E+04, -.27395600E+04, -.20386400E+04, -.18485900E+04, 0.37722200E+03, -.20973800E+04, 0.30297900E+03, -.14529000E+03, 0.36866500E+04, -.15150000E+03, 0.28226500E+03, 0.92091600E+03, -.41585700E+03, -.14633800E+04, -.12128000E+04, 0.11545600E+04, -.23540700E+03, 0.39076800E+04, -.19577300E+04, 0.34888800E+04, -.19538200E+04, -.16964300E+03, -.10347000E+04, -.88697600E+03, -.13772600E+04, -.17609700E+04, -.84436400E+03, -.95820000E+03, 0.86920800E+04, -.43281200E+04, 0.71717000E+03, -.43460400E+04, 0.19967000E+04, -.11158900E+04, -.10433500E+04, 0.19608000E+04, -.13473300E+04, -.25539700E+04, -.77177700E+04, 0.32782600E+04, -.16442100E+04, -.17140400E+04, -.16391400E+04, 0.99434500E+03, -.31544300E+03, -.11353800E+04, 0.58039800E+03, -.50220500E+03, -.80754900E+03, -.26307000E+04, 0.46826500E+04, -.23630300E+04, 0.31042000E+04, -.23413500E+04, 0.12425000E+04, -.23153100E+03, -.17570000E+04, -.17514500E+04, -.19612100E+04, -.23205600E+03, -.30176300E+04, -.26401200E+04, 0.13325000E+04, -.23006800E+04, 0.13199800E+04, 0.69688900E+03, 0.23398100E+04, 0.18709000E+03, 0.99179000E+02, 0.11029200E+04, 0.22327900E+04, 0.96317200E+03, 0.16794300E+03, -.59986400E+02, 0.14065000E+04, -.83953700E+02, 0.13274100E+03, -.22435800E+03, 0.39006400E+03, -.38743300E+03, -.39628900E+03, 0.12231500E+03, 0.33239300E+03, -.14304400E+05, 0.71269300E+04, 0.49949000E+03, 0.71522100E+04, 0.10988600E+04, 0.81896000E+03, 0.48733000E+04, 0.30531200E+04, 0.42424300E+04, 0.17192200E+04, 0.55241100E+04, 0.27125100E+03, -.19858700E+03, 0.33577700E+03, -.25680000E+03, -.34281800E+03, -.25530100E+03, 0.24557800E+03, -.39576300E+03, -.16119000E+03, 0.27791400E+03, 0.29029600E+03, 0.19421000E+03, -.35233300E+03, -.12384900E+03, -.41744800E+01, -.47941100E+03, -.28585900E+02, 0.42157700E+03, -.12477300E+03, -.33476700E+03, 0.51990100E+03, -.28438100E+03, -.26407400E+03, 0.18250900E+03, -.54229300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.67449400E+01, 0.60853200E+00, 0.31519100E+01, 0.18206100E+01, 0.14762600E+01, -.13825900E+01, 0.11845900E+01, 0.37840700E+00, -.28107800E+00, 0.22133800E+01, 0.18619700E+01, -.55496300E+00, 0.80102700E+00, 0.81198400E+01, -.53761600E+00, 0.10019300E+01, 0.33655300E+01, 0.53461700E+01, 0.12479300E+00, 0.18352200E+01, -.38876500E+01, -.22382400E+00, -.28356600E+00, 0.36510100E+01, 0.92253300E+00, -.13449800E-01, -.69544500E+00, 0.73818400E+00, 0.28201500E+01, -.88330600E+00, -.10840200E+00, -.10258500E+00, 0.34477700E+01, -.71558900E+00, 0.25792800E+00, -.18467700E+01, -.59965300E-02, 0.76450600E-01, 0.13715100E+00, -.52708400E+00, 0.51962500E+00, -.27046900E+00, 0.26043000E+00, -.11593900E+00, -.22652600E+01, -.31393100E+00, 0.11828400E+01, -.83672000E+00, 0.11466600E+01, 0.32526200E+00, 0.39565500E+01, -.11705400E+01, -.63763100E-01, -.20298700E+01, 0.41574700E+00, 0.13516800E+01, -.79203000E+02, -.13318100E+04, 0.93688700E-01, -.33801100E+04, 0.15646000E+03, -.20195700E+04, -.31109500E+04, -.12681500E+04, 0.27451000E+04, 0.21510100E+05, -.50508800E+04, 0.22159400E+04, 0.64130100E+03, 0.25252400E+04, -.14019200E+03, -.42014500E+03, 0.99388600E+03, -.25596100E+04, 0.30155600E+04, -.27641000E+03, 0.14769300E+04, -.24054800E+04, 0.27576100E+03, 0.17027700E+05, 0.12025100E+04, -.11444900E+04, -.14847900E+03, -.18452100E+03, 0.10400800E+04, 0.28109800E+04, -.18163500E+04, -.91890800E+03, 0.36767800E+05, -.18609900E+05, 0.23987700E+04, -.18383900E+05, -.47301900E+04, -.34859900E+04, -.58815800E+04, -.31963500E+04, -.13708900E+05, -.32511500E+04, -.14493500E+05, -.74381900E+03, 0.16231400E+03, 0.77680700E+04, 0.37195500E+03, 0.26410400E+03, 0.13155000E+04, -.11829900E+04, -.37906400E+04, -.28223200E+04, 0.16858200E+04, 0.33469700E+04, -.97358800E+04, 0.52066300E+04, -.73018800E+04, 0.48680200E+04, 0.20950000E+04, -.13920800E+04, 0.14052400E+04, -.35855400E+03, 0.42289100E+04, -.52567400E+02, -.15186900E+04, 0.12806400E+05, -.66090400E+04, 0.48702300E+04, -.64031800E+04, -.18716900E+04, -.17425200E+04, -.18645700E+04, -.42664600E+04, -.77554900E+04, -.16563200E+04, 0.21848500E+04, 0.14572600E+04, -.20978700E+02, -.11175200E+05, -.72849600E+03, 0.49071100E+02, 0.62768800E+03, -.49637700E+03, -.13190500E+04, -.18816200E+04, 0.16376200E+04, 0.14436100E+04, 0.41298400E+05, -.20849700E+05, -.83568800E+03, -.20649200E+05, -.24039600E+04, 0.27670600E+04, -.79633300E+04, 0.30243700E+03, -.16814800E+05, 0.19467200E+04, -.19365300E+05, 0.93054600E+04, -.44411800E+04, 0.85725900E+04, -.46527400E+04, 0.39919600E+04, 0.41117200E+04, -.64144500E+04, -.71267100E+04, -.56347400E+04, 0.27116100E+04, -.57137700E+04, -.41311200E+04, 0.21047500E+04, -.89207100E+04, 0.20653300E+04, -.22397100E+04, -.29825600E+04, 0.28968700E+04, 0.45011600E+04, 0.30957800E+04, -.10358700E+04, 0.55978300E+04, -.13567800E+04, 0.78544100E+03, -.10937400E+05, 0.67846300E+03, -.16684300E+04, -.42412700E+04, 0.29933700E+04, 0.49884600E+04, 0.51831000E+04, -.47065100E+04, -.15173300E+04, -.12150500E+05, 0.63563500E+04, -.16147300E+05, 0.60751500E+04, -.16530100E+03, -.63386700E+03, 0.34173900E+04, 0.44068800E+04, 0.62432500E+04, 0.30078100E+03, -.41177600E+04, -.35331300E+05, 0.17603500E+05, -.69760900E+04, 0.17665600E+05, -.39955300E+04, 0.53850300E+04, -.46106300E+03, -.57779500E+04, 0.10541200E+05, 0.86635200E+04, 0.41635500E+05, -.98205000E+04, 0.49255900E+04, 0.14702400E+04, 0.49102900E+04, -.36187200E+04, -.12313800E+04, 0.18520400E+04, -.11946900E+04, 0.23545800E+04, 0.67333000E+03, 0.13603400E+05, -.13896000E+05, 0.70318200E+04, -.20786000E+05, 0.69481900E+04, -.43111300E+04, -.33112200E+03, 0.11643100E+04, 0.31053800E+04, 0.76713300E+04, 0.11698000E+04, 0.68372800E+04, 0.89333200E+04, -.43175000E+04, 0.96314100E+04, -.44660900E+04, -.30399700E+04, -.49644000E+04, 0.15269600E+04, 0.55195000E+04, -.31565500E+04, -.60891400E+04, -.27167700E+04, -.13578700E+04, 0.89411700E+03, -.28773700E+04, 0.67880900E+03, -.62145500E+03, 0.33813000E+03, 0.15051400E+04, 0.26573900E+04, 0.22446000E+04, -.48465300E+03, -.30681900E+04, 0.51629000E+05, -.25858100E+05, 0.38735100E+04, -.25814500E+05, -.36683100E+04, -.56546400E+04, -.58675700E+04, -.27546100E+04, -.19155100E+05, -.63664500E+04, -.34128600E+05, -.13415100E+04, 0.24029100E+03, -.84645500E+03, 0.98417800E+03, 0.11326100E+04, 0.56947200E+03, -.98017600E+03, 0.12608400E+04, -.26200800E+04, -.68596100E+02, -.21715100E+04, -.19001800E+04, 0.31444700E+03, -.30009200E+04, 0.35517400E+03, 0.17807100E+04, -.97223400E+03, -.17869300E+04, 0.14751900E+04, -.84018200E+03, -.95864000E+03, 0.12673000E+04, 0.78449100E+03, -.11931600E+04, 0.10542700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24913700E+01, -.10446800E+00, 0.12705200E+01, 0.27173600E+01, 0.13066300E+01, -.78107500E+00, -.13558500E+00, -.19496600E+00, -.10696300E+00, 0.48884700E+00, 0.48980400E+00, -.49308000E+00, -.58333200E+00, 0.25571800E+01, 0.21661000E+00, 0.15158200E+00, 0.33977600E+00, 0.23228500E+01, 0.18645900E+01, -.10303500E+01, -.10428100E+01, 0.16724900E-01, -.48302100E+00, -.33022100E+00, 0.11506400E+00, -.24747900E+00, 0.85456900E+00, -.27680100E+00, -.62303200E+00, 0.10019900E+00, 0.20237700E+00, -.30508900E+00, 0.62200000E+00, -.15727800E+01, 0.36850600E+00, 0.71558300E+00, -.23709800E-01, 0.13248200E+00, 0.43613100E+00, -.16584300E+01, 0.47086400E+00, -.78456100E+00, -.86358700E+00, 0.23026600E+00, -.67045400E+00, -.21593900E+00, 0.45981200E+00, -.41543300E+00, 0.75847300E+00, 0.69205800E-01, 0.65207100E+00, 0.23824800E+00, -.39352600E+00, -.17413800E+01, -.30684500E+00, 0.29560900E+00, -.21520600E+00, 0.28001600E+04, 0.33885600E-01, -.20560700E+04, -.12048000E+04, -.11420900E+04, -.28298100E+04, -.60124500E+01, -.71277600E+03, 0.51996500E+04, 0.10691300E+04, -.40191600E+03, -.93401500E+03, -.53462800E+03, 0.84871400E+02, 0.42571800E+03, -.44486500E+03, -.11859400E+04, -.48805500E+03, 0.23889500E+03, -.65286100E+03, -.26606100E+04, 0.13537200E+04, 0.30073100E+04, 0.13302300E+04, -.98386000E+03, -.43542900E+03, -.47224400E+03, -.96097100E+03, 0.11915000E+04, -.13203500E+04, 0.16402100E+04, 0.84312300E+04, -.40838100E+04, 0.12844100E+04, -.42156000E+04, -.17332000E+04, -.43020400E+03, 0.33799300E+03, 0.11301600E+04, -.23195300E+04, -.65604000E+03, -.42559900E+04, 0.95788100E+03, -.40460000E+03, 0.17814800E+04, -.47892500E+03, -.13311000E+04, -.12017700E+04, 0.21768300E+02, -.16186200E+04, -.13775000E+04, -.70953800E+03, -.45201300E+03, -.72366400E+04, 0.35473600E+04, -.26282300E+04, 0.36183500E+04, 0.37699200E+04, 0.19286900E+04, -.67275800E+03, -.31067700E+03, 0.28877800E+04, 0.21777100E+04, 0.22475800E+04, 0.32866700E+04, -.16067800E+04, 0.44243100E+04, -.16433300E+04, -.81002700E+03, -.16037300E+04, 0.91736300E+03, -.30627800E+04, -.42811300E+04, -.14032500E+04, -.76311200E+03, 0.21501400E+04, -.11102800E+04, -.18594600E+04, -.10750300E+04, 0.25561100E+03, 0.65070400E+03, 0.46736600E+02, 0.46651300E+03, -.10905000E+04, 0.12002100E+04, -.11863300E+04, 0.49531300E+04, -.23786000E+04, -.67876600E+03, -.24765700E+04, -.14317800E+04, -.17619200E+04, 0.80364500E+03, -.24029400E+03, -.27844900E+04, -.12101200E+04, -.27589200E+04, 0.34142200E+04, -.17812000E+04, 0.19439000E+04, -.17071100E+04, 0.18959200E+04, 0.26444900E+04, -.14810900E+04, 0.70721000E+03, -.18089600E+04, 0.15457000E+04, -.24857100E+04, -.27117200E+04, 0.14022400E+04, -.10856500E+04, 0.13562400E+04, -.71354500E+03, -.11358200E+04, -.11298400E+04, -.15323000E+04, 0.21274900E+04, -.58125900E+03, 0.25204000E+04, 0.60350700E+03, -.32681300E+03, -.41042700E+04, -.30172600E+03, 0.25123400E+03, -.34786500E+03, 0.82314300E+03, 0.24633000E+04, 0.76296600E+03, -.77420600E+03, -.52547300E+03, -.54446900E+04, 0.26862300E+04, -.37992000E+04, 0.27223000E+04, 0.19538700E+04, 0.19695200E+04, -.12243800E+04, -.20059600E+03, 0.13295700E+04, 0.20887000E+04, 0.70718300E+03, -.12581200E+05, 0.62709100E+04, 0.11090300E+04, 0.62906200E+04, -.12896300E+04, 0.46177700E+03, -.24719400E+04, -.53782800E+04, 0.47495000E+04, 0.13006600E+04, 0.10977900E+05, -.68818100E+03, 0.36301500E+03, -.15661100E+03, 0.34410500E+03, -.11138900E+04, 0.53388900E+03, -.12179400E+04, -.13074200E+04, 0.22143600E+03, 0.64904300E+03, 0.20072200E+04, -.85899800E+04, 0.43422800E+04, -.10048000E+05, 0.42950600E+04, 0.28918200E+04, 0.44144700E+04, -.35370100E+04, -.14179400E+04, 0.56115200E+04, 0.42693100E+04, 0.29051300E+04, 0.14962000E+04, -.89183300E+03, 0.34263600E+04, -.74790500E+03, -.27727500E+04, -.31596300E+04, 0.31452800E+04, 0.34802100E+04, -.51337100E+03, -.31508800E+04, -.66988100E+03, 0.32881800E+03, -.24823300E+03, 0.48798300E+03, -.16445300E+03, -.10469200E+03, 0.77036900E+03, -.15846100E+01, 0.74032900E+03, -.12417900E+03, 0.21858200E+03, -.17869000E+02, 0.14261600E+05, -.70940200E+04, -.23971900E+03, -.71308400E+04, -.83528400E+03, 0.20842700E+03, 0.24168200E+04, 0.40421600E+04, -.68901700E+04, -.36822400E+03, -.96629700E+04, -.69361600E+03, 0.46228400E+03, -.73268900E+03, 0.98948300E+03, 0.11638600E+04, 0.54656200E+03, -.95314200E+03, 0.11542200E+04, -.22989500E+04, -.42217600E+03, -.96933500E+03, -.51083800E+03, 0.51637200E+03, -.22245400E+04, 0.58458500E+03, 0.11249800E+04, 0.44807500E+03, -.83736200E+03, 0.23563900E+01, 0.46600900E+03, -.56988800E+03, 0.58536000E+03, 0.95441200E+03, -.40871000E+03, 0.47844700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.46880200E+01, -.63674000E+00, -.15352200E+01, 0.20157400E+00, 0.69906100E-01, -.19143700E+00, 0.37439000E+00, 0.24356400E-01, 0.20979800E+00, -.88861800E+00, 0.26207500E+00, -.12870400E+01, -.57570900E+00, 0.25149200E+01, -.40374300E+00, -.97254700E-01, -.37540000E+00, 0.14505000E+00, 0.10363200E+00, -.40840200E+00, -.30550700E+00, -.62859000E-01, -.45457500E+00, -.83413800E+00, -.19680900E+00, -.87695800E+00, 0.31929400E+00, 0.23971300E+01, 0.52985000E+00, -.31229400E+00, 0.91892600E-01, -.30565900E+00, -.59745900E+00, -.11525500E+01, 0.15742000E+00, -.11675400E+00, 0.34421000E+00, -.97957700E-01, 0.18214400E+00, 0.11164300E+01, -.26783300E+00, 0.34485500E+00, 0.63516000E+00, -.11249300E-01, 0.28832300E+00, 0.25930200E+00, 0.42065300E+00, 0.25225000E+01, 0.16087100E+00, -.19437900E+00, -.36647500E+00, -.30468400E+00, 0.40011600E+00, -.29903100E+00, -.19909600E+01, -.11704300E+01, 0.21307900E+00, 0.62082700E+00, 0.66429900E+01, -.16953900E+04, -.25885700E+03, 0.28122400E+03, 0.86449300E+03, 0.16806600E+03, -.41895800E+04, -.11582200E+05, 0.79525100E+04, -.41662400E+04, -.13641400E+04, -.39895500E+04, 0.82755100E+02, -.33827700E+03, -.53966800E+02, 0.35975000E+04, -.31913200E+04, -.44265700E+03, -.34316000E+04, -.62666100E+04, 0.32807800E+04, -.20856100E+05, 0.31308600E+04, 0.20817600E+04, -.18729800E+04, 0.20019100E+04, -.17208400E+04, 0.91075700E+03, 0.36585800E+03, 0.48668600E+04, -.36478200E+05, 0.18004600E+05, 0.27774300E+04, 0.18242500E+05, 0.22821900E+04, 0.38252800E+04, 0.55757100E+04, -.67286800E+03, 0.11934200E+05, 0.37843500E+04, 0.15255500E+05, -.18309700E+04, 0.78428500E+03, -.22666400E+04, 0.91672800E+03, -.86468400E+03, 0.97115500E+03, -.13787500E+04, 0.20061400E+04, 0.26518100E+04, -.12411000E+04, -.17470200E+04, 0.13345300E+05, -.66158200E+04, 0.26044500E+04, -.66689200E+04, -.62660200E+03, 0.88407800E+03, -.92739900E+03, 0.16451500E+04, -.32154100E+04, 0.57491900E+03, -.30061500E+04, -.12736700E+05, 0.63480800E+04, -.47855300E+04, 0.63661700E+04, -.10177900E+04, 0.41680100E+03, 0.30882500E+04, 0.38378700E+04, 0.66483000E+04, -.37520500E+03, 0.97952900E+03, 0.43132400E+04, -.22551300E+04, 0.14573300E+05, -.21543300E+04, -.10267700E+04, 0.91452700E+03, -.11616900E+04, 0.11131500E+04, -.10907000E+04, -.60543800E+03, -.37855300E+04, -.34452400E+05, 0.17093200E+05, 0.12818400E+04, 0.17226100E+05, 0.32757400E+04, -.18232500E+04, 0.81129300E+04, 0.80259800E+03, 0.14183500E+05, -.73610400E+03, 0.15746800E+05, -.45212500E+04, 0.23519500E+04, -.71341700E+04, 0.22637200E+04, -.50481800E+04, -.17395800E+04, 0.22407400E+04, 0.19214800E+04, 0.18385800E+04, -.62914500E+03, 0.36430000E+04, -.15982300E+04, 0.68265300E+03, 0.83979700E+04, 0.79696200E+03, 0.20031400E+04, 0.35356800E+04, -.21749000E+04, -.52463500E+04, -.25553200E+04, 0.12016500E+04, -.12582400E+04, 0.48611900E+04, -.23673400E+04, 0.68473200E+04, -.24310000E+04, 0.21049000E+04, 0.51118500E+03, -.16376400E+04, -.26738100E+04, -.61679700E+04, 0.30453300E+04, -.56636100E+03, 0.16702900E+05, -.83098300E+04, 0.76871000E+04, -.83607800E+04, 0.38397500E+04, -.16836100E+04, -.13679200E+04, 0.56557500E+03, -.50333100E+04, -.34229100E+03, -.17045400E+04, 0.26757400E+05, -.13327600E+05, 0.26725800E+04, -.13378200E+05, 0.91913700E+03, -.55286200E+04, -.49072100E+03, 0.59943000E+04, -.65795300E+04, -.10544800E+05, -.27178600E+05, 0.67762400E+04, -.34422400E+04, -.79698400E+03, -.33851500E+04, 0.30808600E+04, 0.15361000E+04, -.26379100E+04, 0.10920300E+04, -.10254600E+04, -.10183300E+04, -.84291400E+04, 0.12177000E+05, -.61538800E+04, 0.15220200E+05, -.60767600E+04, 0.72110100E+04, -.11866900E+04, -.12388700E+04, 0.27849100E+04, -.25409100E+04, -.94438100E+03, -.69329200E+04, -.13740400E+05, 0.70905200E+04, -.11212800E+05, 0.68948400E+04, 0.11479900E+04, 0.34980600E+04, -.23451400E+04, -.71093300E+04, 0.35046800E+04, 0.44792200E+04, 0.56878900E+04, 0.10832600E+04, -.42115300E+03, 0.15259100E+04, -.54168100E+03, 0.14329400E+04, -.42290700E+03, 0.66247400E+03, -.31200500E+04, -.27338800E+04, 0.13817800E+04, 0.25089400E+04, -.40636900E+05, 0.20252400E+05, 0.29450200E+02, 0.20313400E+05, 0.39347200E+04, 0.58093800E+04, 0.56960300E+04, 0.56810600E+03, 0.14101400E+05, 0.86065100E+04, 0.24904200E+05, 0.21889000E+04, -.27371100E+03, 0.33274100E+03, -.15865100E+04, 0.19873300E+03, -.59002800E+03, 0.42339400E+03, 0.78985700E+02, 0.16646100E+04, 0.54735300E+02, 0.23273700E+04, 0.12212700E+04, -.69989800E+03, 0.25359000E+04, -.42703200E+03, -.20959900E+04, 0.87063800E+03, 0.17656100E+04, -.16109000E+04, -.32531800E+03, 0.12936400E+04, -.69387200E+03, 0.99434800E+03, 0.22072300E+04, -.14906500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11869900E+01, 0.10259600E+00, -.20006400E+00, -.14843600E+00, -.49080900E+00, -.74262300E+00, 0.98968300E+00, 0.28058500E-01, -.11280800E-01, 0.67040500E+00, -.25464200E+00, 0.13139500E+00, 0.97169300E-01, -.75281600E+00, -.32376600E+00, 0.81976100E+00, 0.51672600E+00, -.33443300E+00, -.55279400E+00, -.36047900E-02, 0.70460300E+00, -.66068700E-01, 0.89699800E-01, 0.72117600E+00, -.41807300E-01, 0.43238800E-01, -.15962900E+00, -.11834100E+01, -.14963700E+00, 0.17860100E+00, -.44574100E-01, -.24725400E+00, -.80553000E-02, 0.24978300E+00, -.45490000E-01, -.62062900E-01, -.16485700E-01, 0.24788000E-02, 0.87882900E-01, -.24089500E+00, 0.78660900E-02, -.41371800E-02, -.15208300E+01, 0.12386600E+00, 0.20584300E+00, -.96725500E-02, 0.29755200E+00, 0.34580400E-01, -.58424900E-01, -.43582400E-02, -.20754100E+00, 0.15013200E+00, 0.76199000E-01, -.49870100E+00, -.63887200E+00, 0.46024300E+00, 0.53089900E-01, -.61077200E-01, -.45361100E-03, -.14904700E+04, -.38548800E+03, -.27353300E+03, -.86437500E+03, -.35965000E+02, -.69241800E+03, 0.13235300E+04, 0.19363300E+04, -.96530200E+03, -.56586300E+03, -.96814800E+03, 0.16035800E+03, 0.26617900E+03, -.44553100E+03, -.78757200E+02, -.86283100E+03, 0.21959500E+03, -.81942200E+03, -.11225600E+04, 0.43823100E+03, 0.91158800E+03, 0.56129500E+03, -.29269700E+03, -.14290000E+04, 0.20883800E+03, -.32875000E+03, 0.27201900E+03, -.12078900E+04, 0.10934600E+04, -.21829500E+03, 0.10490400E+03, 0.97525500E+03, 0.10914800E+03, -.80570500E+03, 0.13814100E+03, -.27540800E+03, -.11741000E+04, -.18893500E+03, 0.24507900E+03, 0.29466100E+03, -.51608400E+03, 0.26210900E+03, 0.35588200E+03, 0.25804000E+03, -.45592500E+03, 0.64471000E+01, 0.16524700E+03, -.41058500E+03, 0.14507200E+03, -.20060700E+03, -.41769100E+03, -.17740100E+03, 0.99658800E+02, -.28234700E+03, 0.88699900E+02, 0.11229900E+04, 0.30707900E+03, -.29766900E+03, 0.13726200E+03, 0.19976100E+03, 0.45977600E+03, 0.74570200E+02, 0.66071000E+03, -.33310900E+03, 0.20606000E+03, -.33035700E+03, -.50148000E+03, -.39852000E+03, 0.21343800E+03, -.73131200E+03, -.43258000E+03, -.50701700E+03, -.53025400E+03, 0.11431400E+04, -.49687800E+03, -.28907300E+03, -.57157800E+03, 0.14339000E+03, 0.11469100E+04, -.28484200E+03, 0.13393100E+03, -.51515800E+03, 0.96638400E+03, -.94725500E+03, 0.58292900E+03, -.29745000E+03, -.30659500E+03, -.29146400E+03, -.22493500E+02, 0.91666700E+01, -.16212400E+03, -.37123100E+03, -.32540200E+03, 0.21227400E+03, -.44113200E+03, 0.81803000E+03, -.39518300E+03, 0.20039500E+03, -.40901300E+03, 0.39605900E+01, 0.48090600E+03, -.45234500E+03, -.39297200E+03, -.77630700E+03, 0.30451700E+03, -.33882000E+03, -.16987200E+04, 0.86082500E+03, 0.39340600E+03, 0.84964800E+03, 0.13894400E+03, 0.16301100E+03, 0.43262300E+02, -.38168200E+03, 0.36315200E+03, 0.10306900E+03, 0.10977400E+04, 0.68215600E+03, -.34151000E+03, -.60538700E+03, -.34108100E+03, 0.34041500E+03, -.58598900E+03, 0.19927500E+03, 0.84406900E+03, -.42197300E+03, -.27001500E+03, 0.22423600E+02, 0.84020300E+03, -.42280100E+03, -.10797700E+04, -.42010100E+03, 0.11235700E+04, 0.28222900E+03, -.29008400E+03, 0.70930600E+03, -.35054700E+03, 0.68760200E+03, -.26173600E+03, -.10710600E+04, 0.54154900E+03, 0.27239600E+03, 0.53553200E+03, -.12884900E+04, -.54362700E+03, -.27144000E+03, -.50126600E+03, 0.37439800E+03, -.76426200E+03, 0.14477700E+04, -.18049000E+03, 0.98200700E+02, 0.19545700E+03, 0.90245000E+02, -.38700700E+03, 0.58157400E+02, -.69256800E+02, -.78068300E+02, 0.44831300E+02, -.84992500E+02, 0.27772100E+03, -.18735800E+04, 0.94390400E+03, -.10623700E+03, 0.93678500E+03, 0.11942900E+04, 0.55329300E+03, -.28994800E+03, 0.73122300E+03, 0.10738000E+04, 0.81881100E+03, 0.66277700E+03, -.13502600E+04, 0.62672000E+03, 0.12421300E+04, 0.67511000E+03, -.10153900E+04, -.16276000E+04, 0.11565800E+04, 0.57840500E+03, 0.66826000E+03, -.14719000E+04, 0.33976700E+03, 0.28391400E+03, -.14456200E+03, -.36366000E+02, -.14195100E+03, 0.12669300E+03, 0.21573800E+03, -.13226200E+03, -.92050000E+02, -.14764600E+03, 0.28635900E+03, 0.52436900E+03, 0.21163600E+04, -.10727700E+04, -.14571700E+03, -.10581800E+04, -.26889700E+03, 0.52445600E+03, -.60029300E+03, -.10602100E+04, -.11566900E+04, 0.90853800E+03, -.77626300E+03, 0.44034600E+02, 0.23174700E+02, -.14623300E+03, 0.46488600E+02, 0.47006900E+03, -.15861200E+01, -.10861900E+03, 0.46211200E+03, -.58353100E+03, -.14840100E+03, 0.82369500E+01, -.64249800E+02, 0.19324400E+03, -.55796800E+03, 0.25171200E+02, 0.82604500E+02, 0.50412500E+02, -.15152500E+03, -.14106600E+03, -.49931100E+02, 0.13729500E+02, 0.29581400E+03, 0.46594200E+03, 0.13146600E+03, -.17999900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15581600E+01, 0.19191800E+00, 0.83880200E+00, 0.62497300E+00, 0.14697600E+01, -.12216300E+00, -.22550800E+00, 0.58300200E-01, -.15141500E+00, 0.66103700E-01, -.65222800E-01, 0.36493700E+00, 0.39691900E+00, -.27276900E+00, -.76587700E-01, -.11067600E-02, 0.42279900E+00, -.63546500E+00, 0.49575000E+00, -.13556300E+00, -.98572000E-01, -.63459700E-01, -.60942900E-01, 0.99108700E-01, -.65076900E-02, -.12208500E+00, -.81162000E+00, -.60260300E+00, 0.39285300E-01, -.13358600E+00, -.77478000E-01, -.70474100E-01, 0.94048600E-01, 0.73802000E-01, -.34118800E-01, -.27777400E+00, -.77942600E-02, 0.27180800E-02, 0.86906400E-01, 0.24840900E-01, 0.15385300E+00, -.15941800E+00, -.29091400E+00, 0.75142100E-01, 0.23037600E+00, 0.68024200E-01, 0.27468000E+00, -.16121900E+00, 0.52150900E-01, 0.94011600E-02, -.10309200E+00, -.36340200E+00, 0.59508400E-01, 0.23954900E+00, -.22794800E+00, -.30169300E+00, -.85494300E-01, 0.57698500E-01, -.19591200E-02, -.59968100E+00, 0.80058100E+03, -.37838200E+03, 0.13771400E+03, 0.13828300E+03, 0.40876300E+03, 0.15034300E+04, 0.11728600E+04, -.60388600E+03, -.62051200E+01, -.58643000E+03, 0.15722100E+03, 0.84331500E+02, -.31522700E+03, 0.48320300E+02, -.40624800E+03, 0.96225000E+02, -.47172800E+03, 0.10731300E+04, -.62646400E+03, 0.19228400E+01, -.53653200E+03, -.11141500E+03, -.94187300E+03, 0.31761500E+03, 0.58869500E+03, -.42103000E+03, -.63169100E+03, -.34296000E+03, 0.29277100E+04, -.14942500E+04, 0.23530100E+03, -.14638500E+04, -.46476700E+03, 0.75082300E+02, -.58342100E+03, 0.25826900E+02, -.10853200E+04, 0.13115900E+03, -.15539800E+04, -.26167700E+03, 0.11821600E+03, 0.36744700E+03, 0.13083400E+03, 0.10056500E+03, 0.17680500E+03, 0.20690400E+02, -.61915400E+01, 0.68849800E+03, -.13106200E+03, 0.20751900E+03, 0.62049500E+02, -.90873800E+01, -.78829000E+03, -.31027900E+02, -.10490100E+03, -.83470900E+03, 0.40705600E+03, 0.33620400E+03, -.11288200E+03, -.48847400E+03, -.12682400E+04, -.40513000E+03, 0.19382400E+03, 0.82818300E+03, 0.20255900E+03, -.52547200E+01, 0.64653100E+03, -.24832900E+03, -.48594900E+03, 0.31467900E+03, 0.49051600E+03, 0.14994700E+04, -.97740100E+03, 0.55224700E+03, 0.40009400E+03, 0.48868500E+03, 0.22537000E+03, 0.86434600E+03, -.35020100E+03, -.59323000E+03, 0.19188600E+03, 0.58552100E+03, 0.40642500E+03, 0.31493300E+04, -.15969300E+04, -.28509600E+03, -.15746700E+04, -.33434300E+03, 0.54957700E+03, -.66919800E+03, -.23027700E+03, -.13871900E+04, 0.60090800E+03, -.11149900E+04, 0.14117100E+04, -.68222100E+03, 0.11055400E+04, -.70584800E+03, 0.19901900E+03, 0.29791900E+03, -.70206800E+03, -.67241200E+03, -.72586400E+03, 0.12567200E+03, -.10551300E+04, -.21797600E+04, 0.10887900E+04, -.45683900E+03, 0.10902200E+04, 0.85747800E+02, -.61458400E+02, 0.35402500E+02, -.24675600E+03, 0.52007300E+03, -.93398200E+01, 0.15943700E+04, 0.64636000E+03, -.31603800E+03, -.18293100E+03, -.32319300E+03, -.37432800E+03, -.88235400E+03, 0.44859600E+03, 0.13865700E+03, -.47998200E+03, -.33810200E+03, -.17150700E+03, 0.77482300E+03, -.38109700E+03, -.15823800E+04, -.38741400E+03, -.44569000E+02, -.79694900E+03, 0.18913200E+03, 0.54079500E+03, -.66867000E+03, -.21730600E+03, -.13050700E+04, -.11190800E+04, 0.56754500E+03, -.11871000E+04, 0.55954200E+03, 0.48339400E+03, 0.92592900E+03, -.13846100E+03, 0.12469500E+04, 0.93147900E+03, 0.42397200E+03, 0.18084400E+04, -.32904700E+03, 0.16603600E+03, -.46761200E+03, 0.16452400E+03, -.54123900E+02, -.34966600E+03, 0.81336100E+02, 0.34417200E+03, 0.48976600E+03, -.46817700E+03, 0.56179600E+03, 0.13897800E+04, -.70078000E+03, -.17368000E+04, -.69489400E+03, -.12891300E+04, -.22370400E+04, 0.14111900E+04, 0.18159300E+04, -.58551700E+02, -.16309100E+04, -.10529100E+04, -.99129100E+03, 0.49456400E+03, 0.78669800E+03, 0.49561000E+03, -.10249900E+03, -.35591400E+03, 0.63857900E+03, 0.22729400E+03, 0.59874300E+03, -.35465500E+03, 0.63952000E+03, -.60680900E+03, 0.31869000E+03, -.13935800E+03, 0.30342400E+03, 0.30091100E+03, 0.29531700E+03, -.28488000E+03, -.27337400E+03, -.37872200E+03, 0.46405500E+03, 0.25190200E+02, 0.45919200E+04, -.23149200E+04, 0.14464800E+03, -.22959600E+04, -.81975300E+03, -.53351400E+03, -.21109700E+03, -.20123200E+03, -.18496700E+04, -.31237900E+02, -.35300800E+04, 0.12271100E+03, -.14590900E+03, 0.18378100E+03, -.22797000E+03, -.66926600E+02, -.14058900E+03, 0.16073800E+00, -.63181700E+02, 0.11252900E+03, 0.20427000E+03, 0.19160700E+03, -.23828200E+03, 0.86678800E+02, -.50061200E+01, -.79889600E+02, -.11403100E+03, -.39211200E+03, 0.15757700E+03, 0.16645700E+03, -.44747100E+03, 0.31115700E+03, 0.19810900E+03, -.47849300E+02, 0.24741000E+03, -.10864400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.33831800E+01, -.38115500E+00, -.21150600E+00, 0.31266800E-01, -.67626700E+00, -.12009100E+00, -.16747600E+00, -.15995600E+00, -.30342500E+00, -.18161300E+00, -.58777100E-01, -.43188700E+00, -.42981700E+00, -.76214400E+00, -.40430300E-01, 0.47349700E-01, -.13367100E+01, -.10135900E+01, -.61026800E+00, -.73482900E+00, 0.34350600E+00, -.45926600E-02, -.12513900E+00, -.70354700E+00, -.11120900E+00, 0.33366300E+00, 0.47513800E+00, 0.13870000E+01, 0.36551500E-01, 0.35682800E+00, 0.37994400E-01, 0.92890200E-01, -.12876000E+01, 0.16448300E+00, -.84448200E-01, 0.23519300E+00, 0.11395500E-01, -.11202000E+00, -.12613000E+00, 0.63819900E+00, -.29684000E+00, -.37095400E+00, 0.34740800E+00, -.14269600E-01, 0.28042100E+00, -.29149300E-01, -.58744600E+00, 0.22207200E-01, 0.27936300E+00, -.30667300E-01, 0.99364400E+00, -.27457300E+00, -.28616000E+00, -.26615800E+00, -.28757100E+00, 0.22506300E+00, -.73084900E-01, 0.42255000E+00, 0.25965100E-02, 0.79438000E+00, -.19390500E-01, 0.15021700E+04, 0.24025500E+04, 0.43308300E+03, -.80382400E+02, -.84093000E+03, -.15632900E+04, 0.74761100E+03, 0.55672200E+03, 0.78161400E+03, -.24716700E+03, -.49699300E+03, 0.71555000E+03, 0.25476600E+03, 0.63618500E+03, -.42293500E+03, 0.45718200E+03, -.45378600E+04, 0.22760900E+04, -.69044300E+02, 0.22688700E+04, 0.38060200E+03, 0.62750600E+03, 0.11871900E+04, 0.49044300E+03, 0.18095000E+04, 0.46785700E+03, 0.17934600E+04, -.75653200E+04, 0.37568800E+04, -.32846500E+03, 0.37826600E+04, 0.59766100E+03, 0.47585500E+03, 0.18895100E+04, 0.29830100E+03, 0.28764200E+04, 0.32396800E+03, 0.31773200E+04, 0.79621200E+03, -.41437500E+03, -.91868600E+03, -.39809900E+03, -.26537000E+03, 0.28685300E+03, -.16089000E+03, 0.89421400E+03, -.67244400E+03, 0.31505000E+03, 0.42704500E+03, 0.20056700E+04, -.98568900E+03, 0.96938700E+03, -.10028300E+04, -.61516600E+03, 0.84441600E+02, 0.48413300E+03, 0.71423700E+03, -.10371500E+03, -.13225000E+03, -.89901200E+03, -.30013200E+04, 0.14892400E+04, -.12057600E+04, 0.15006700E+04, 0.21558400E+02, 0.79848400E+03, -.96585900E+02, 0.13420600E+01, 0.43077500E+03, 0.69909000E+03, 0.15421600E+04, 0.36337600E+04, -.18145000E+04, -.51875000E+03, -.18168500E+04, -.29363500E+03, -.69041900E+03, -.70227300E+03, -.97395200E+02, -.12521700E+04, -.51822500E+03, -.14571000E+04, -.58875000E+04, 0.29192000E+04, 0.27917000E+03, 0.29437500E+04, 0.43951400E+03, 0.34062500E+03, 0.39889000E+02, -.12529800E+04, 0.18121800E+04, 0.24715200E+03, 0.32720800E+04, -.23237000E+04, 0.11768500E+04, -.13014500E+04, 0.11618400E+04, -.69874200E+03, -.60499500E+03, 0.15588900E+04, 0.13689900E+04, 0.16333000E+04, -.38302200E+03, 0.97286700E+03, 0.36932200E+04, -.18577200E+04, 0.13292500E+03, -.18467800E+04, -.22924500E+03, -.44055200E+02, -.67562700E+03, -.86648700E+03, -.14182600E+04, -.13583900E+03, -.21176400E+04, -.20148700E+03, 0.10257100E+03, 0.15341100E+04, 0.10076000E+03, 0.45728400E+03, 0.32078500E+03, -.75192300E+03, -.10858500E+04, 0.20630000E+03, 0.55654800E+02, -.38831800E+03, 0.12921200E+04, -.63632200E+03, 0.29649300E+04, -.64605800E+03, -.26993000E+02, -.70379900E+03, 0.14919700E+03, -.43498800E+03, 0.32277600E+03, -.92406600E+03, -.91827900E+03, 0.33465500E+04, -.16725600E+04, 0.13866600E+04, -.16732800E+04, 0.51854000E+02, -.67711300E+03, 0.19343100E+04, 0.27067700E+04, -.64859100E+03, -.82591400E+03, -.19296100E+04, 0.26658900E+04, -.13377100E+04, -.77895500E+03, -.13329400E+04, 0.19993100E+03, 0.10030600E+03, -.26696900E+03, 0.39076300E+03, -.86978900E+03, 0.65691200E+02, -.91313000E+03, 0.37576800E+04, -.18907100E+04, 0.23293500E+04, -.18788300E+04, 0.50075600E+03, 0.41533200E+03, -.13127500E+04, -.12855800E+04, -.90056600E+03, 0.12251100E+03, -.10100300E+04, -.94731100E+03, 0.51734300E+03, -.14662200E+04, 0.47372600E+03, 0.10479100E+04, 0.17309700E+04, -.10676500E+04, -.38900600E+03, -.25410500E+03, 0.14816300E+04, 0.63306600E+03, 0.82308000E+03, -.39192400E+03, -.84130800E+02, -.41156900E+03, 0.82442800E+01, -.94764100E+03, 0.38502600E+03, -.64608300E+02, 0.10949400E+03, -.80454700E+03, -.88389600E+03, -.10562800E+05, 0.52806700E+04, 0.25021900E+03, 0.52814100E+04, 0.11818000E+04, 0.11224200E+04, 0.15954700E+04, 0.10078500E+04, 0.42555900E+04, 0.76016900E+03, 0.46241000E+04, 0.14407600E+03, -.52665900E+02, 0.11086500E+03, -.78383400E+02, -.23149500E+03, -.15677200E+03, 0.42616000E+03, -.24488000E+03, 0.44348100E+02, -.10073400E+03, 0.30971800E+03, 0.21548100E+03, -.32578500E+03, 0.16752500E+03, -.25383700E+03, -.24662300E+03, 0.28037000E+03, 0.10274500E+03, 0.39991000E+02, -.17671700E+03, 0.26120100E+03, -.38347700E+03, -.43214300E+02, 0.83447100E+02, -.17187900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12043700E+02, 0.14025400E+01, 0.25901300E+01, 0.40632100E+01, 0.42201200E+01, -.42856700E+01, 0.26057000E+01, 0.47351900E+00, -.75542800E+00, 0.32058100E+01, 0.20419200E+01, 0.17952900E+01, 0.39870100E+01, 0.55242300E+01, 0.10760400E+01, 0.14065200E+01, 0.51919000E+01, 0.34143800E+01, 0.64966100E+00, 0.16792200E+01, -.38842500E+01, -.72011000E+00, -.12959400E+00, 0.67581900E+01, 0.95362100E+00, 0.51675500E+00, -.18670800E+01, 0.26189500E+01, -.15317000E+01, -.10945900E+01, 0.82363100E+00, 0.14414000E+01, -.28039400E+01, -.35521900E+01, 0.71363000E+00, -.57463200E+00, 0.52173900E-01, -.11028000E+01, 0.18154600E+01, -.20769300E+01, -.81900900E+00, -.15879900E+00, 0.30519400E+01, -.88229300E+00, 0.18108300E+01, -.56032400E+00, 0.25865900E+01, -.45398000E+01, -.60872200E+00, -.16660600E+00, -.24955200E+01, -.56601200E+00, 0.12461400E+00, 0.30015300E+00, -.77341600E+00, 0.17075400E+01, 0.95845500E+00, -.20650900E+01, 0.28656700E-02, 0.39204700E+01, -.24789300E+01, -.91502500E+00, -.30516000E+04, 0.10829100E+04, 0.11009900E+04, -.15370500E+04, 0.28440800E+02, 0.10516700E+03, -.14843300E+04, -.14280700E+02, 0.14113100E+03, 0.28608700E+02, -.31440100E+03, 0.64223700E+03, 0.89662600E+03, -.13972100E+03, -.59658400E+03, 0.11271100E+05, -.49696800E+04, -.14295600E+05, -.56356300E+04, 0.16397900E+04, 0.50046300E+04, -.62227800E+04, -.44158900E+04, -.57341500E+04, 0.41850500E+04, -.38828900E+04, -.79725600E+04, 0.40782900E+04, 0.20128000E+02, 0.39862800E+04, 0.34399300E+04, 0.23977800E+04, 0.37212300E+04, 0.62294200E+04, 0.58569800E+04, 0.98348000E+03, 0.12219300E+04, 0.29904900E+04, -.14706200E+04, -.13371600E+04, -.14952400E+04, -.27046100E+04, -.42423800E+04, 0.34451500E+04, 0.28610800E+04, 0.45654000E+04, -.30254400E+04, 0.55216100E+04, 0.34645800E+04, -.18511300E+04, -.34518000E+04, -.17322900E+04, 0.12580800E+04, 0.30089500E+04, -.14900300E+04, 0.33383100E+04, -.17278500E+04, 0.16768500E+04, -.37069000E+04, -.86037300E+04, 0.43613600E+04, 0.51329200E+04, 0.43018700E+04, 0.16885800E+04, -.17067600E+04, 0.92291100E+03, -.57298300E+04, 0.35254100E+04, 0.74300300E+02, 0.65374200E+04, -.13886000E+05, 0.65002200E+04, 0.99274300E+04, 0.69430500E+04, -.48794800E+03, -.30976800E+04, 0.51396500E+04, 0.26729100E+04, 0.61201200E+04, -.25345100E+04, 0.52386700E+04, -.23478300E+05, 0.11862400E+05, 0.37343000E+04, 0.11739100E+05, 0.21588700E+04, -.53426600E+04, 0.52947100E+04, -.19591400E+04, 0.59890100E+04, -.41519300E+04, 0.97998800E+04, 0.59999800E+04, -.31256000E+04, -.15025600E+04, -.30000000E+04, 0.15769700E+04, 0.46995700E+04, 0.21328200E+04, 0.11198800E+05, 0.12960900E+04, 0.24337200E+04, -.24702700E+04, -.92198200E+04, 0.45853500E+04, 0.17535400E+04, 0.46098200E+04, -.11077700E+04, -.29162000E+04, 0.15819400E+04, -.24134700E+04, 0.42798200E+04, -.17654000E+04, 0.26001900E+04, 0.64428300E+04, -.32120100E+04, -.53358100E+04, -.32214000E+04, 0.81143700E+02, 0.31068100E+04, -.15522900E+04, 0.33535100E+03, -.31797700E+04, 0.17588600E+04, -.66480900E+04, -.40089300E+04, 0.19888800E+04, 0.36810900E+04, 0.20044600E+04, 0.17850500E+04, 0.29754600E+04, -.27258600E+04, -.23219000E+04, -.31963300E+04, 0.12920100E+04, -.36718800E+04, 0.14428500E+05, -.72330700E+04, -.61971400E+03, -.72142700E+04, 0.10476800E+04, 0.52129400E+04, -.75866300E+04, -.70661400E+04, -.50328600E+04, 0.55673000E+04, -.67857600E+04, 0.11878700E+05, -.59656300E+04, -.32498700E+04, -.59393300E+04, 0.15495400E+03, 0.39137900E+04, -.25944400E+04, 0.61934800E+03, -.23432000E+04, 0.27280300E+04, -.56438900E+04, 0.12505400E+05, -.62324800E+04, -.12698100E+05, -.62526700E+04, 0.31743600E+03, 0.34266300E+04, -.53199500E+03, 0.29247600E+04, -.44020400E+04, 0.11739000E+04, -.72671800E+04, -.11736100E+04, 0.67093600E+03, -.35018400E+04, 0.58688100E+03, 0.61578600E+03, 0.18419900E+04, -.61517500E+03, -.41279200E+04, 0.58079600E+03, 0.26570300E+04, 0.42559200E+04, -.46571100E+04, 0.22721600E+04, 0.45779300E+04, 0.23285300E+04, 0.27050800E+04, 0.34615900E+04, -.44353700E+04, -.41739100E+04, -.35851700E+04, 0.24100500E+04, -.45367700E+04, -.44222300E+04, 0.22678900E+04, -.46084800E+04, 0.22111200E+04, 0.45803400E+04, 0.24952400E+04, 0.50369800E+04, 0.11519100E+05, 0.26999800E+04, -.83920900E+03, -.10486300E+04, 0.95306200E+03, 0.49424500E+03, -.28707300E+03, 0.40679200E+02, 0.45390000E+03, 0.69543400E+03, -.73643600E+03, 0.48582400E+03, 0.17222900E+04, 0.25968400E+03, 0.21642600E+04, 0.41511900E+01, 0.21876100E+04, 0.23216400E+04, -.88042600E+03, -.41938500E+03, 0.15779500E+04, 0.83773200E+03, -.28280200E+03, 0.15694500E+04, 0.63911700E+03, -.11488200E+02, 0.42093800E+03, 0.18747500E+04, 0.32511700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16020400E+01, -.12447200E+00, 0.17105500E+00, -.13110100E+01, -.19837800E+01, 0.68128000E+00, 0.82676800E+00, 0.98581200E-01, 0.10687700E+01, 0.50066200E+00, 0.35492600E+00, -.13404100E+00, 0.54166800E-02, 0.12806700E+01, 0.10438100E+00, 0.84476400E-01, 0.15111200E+00, 0.11503300E+01, -.71300400E+00, 0.15165300E+00, -.19961300E+00, 0.19933400E-01, -.44653300E-01, 0.23797200E+00, 0.44748600E-01, 0.11350300E+00, -.31929300E+00, 0.87271600E+00, 0.25473400E+00, -.27355300E+00, 0.14477000E+00, -.61379100E-01, -.10900200E+01, 0.57474600E+00, -.91184200E-01, -.40135300E+00, 0.11598200E-01, -.13290200E+00, 0.43012500E-01, -.14805100E+01, -.27876500E+00, 0.24991200E+00, -.34985500E+01, 0.20444100E+00, 0.33684400E+00, 0.41895100E-03, 0.18862800E+00, 0.46678700E+00, 0.20202600E+00, 0.57424100E-01, 0.66509100E+00, -.55172700E+00, -.17803200E+00, 0.76269900E-01, -.14833200E-01, -.33468700E+00, -.65118400E-02, 0.17814100E-01, 0.97722600E-03, 0.58974900E+00, 0.56012800E+00, 0.32897800E+00, -.14028300E+00, -.10377100E+04, 0.11928500E+04, 0.20061800E+04, -.51255200E+03, 0.27259700E+03, -.11858300E+04, 0.25631200E+03, -.53084400E+03, -.74196300E+03, 0.48099000E+03, 0.47317900E+03, 0.11498300E+04, -.67502400E+03, 0.22347100E+03, 0.79475900E+04, -.37872600E+04, -.31637100E+04, -.39737900E+04, -.38843500E+03, 0.15871100E+04, -.23425400E+04, -.43880300E+02, -.20621700E+04, 0.90938500E+03, -.37425100E+04, 0.72088800E+04, -.35950800E+04, -.31258600E+03, -.36044400E+04, 0.22227900E+03, -.51287300E+03, -.98384700E+03, 0.14266900E+04, -.21745700E+04, -.98889600E+03, -.31039200E+04, 0.42208100E+03, -.21076000E+03, 0.32305200E+04, -.21103900E+03, 0.28859400E+03, -.26518700E+02, 0.43734200E+03, -.10881700E+03, -.61812100E+03, 0.40180400E+03, 0.79109500E+03, -.36078300E+04, 0.17770900E+04, -.10401300E+04, 0.18039100E+04, -.29448600E+03, -.74883000E+02, -.18195500E+03, -.69912500E+03, 0.18211700E+04, 0.95073000E+02, 0.62370900E+03, 0.18498500E+04, -.91202100E+03, 0.14282200E+04, -.92492300E+03, -.36926300E+03, -.16068600E+03, -.89963000E+01, 0.70590500E+03, -.20472600E+04, -.39812700E+02, 0.50295300E+03, -.66746500E+04, 0.32008700E+04, 0.25898500E+04, 0.33373200E+04, 0.21098300E+03, -.11473000E+04, 0.18530200E+04, -.81416200E+02, 0.17707100E+04, -.63055900E+03, 0.31030800E+04, 0.86692900E+04, -.43173300E+04, -.70583000E+03, -.43346400E+04, 0.15114900E+03, 0.12190700E+04, -.15043700E+04, 0.17770900E+04, -.27277500E+04, 0.46070800E+03, -.43730700E+04, -.53068100E+03, 0.24018300E+03, 0.17349700E+04, 0.26533400E+03, 0.56337800E+03, -.12934000E+03, -.19224800E+03, -.13227800E+04, -.35654800E+03, -.18398400E+03, 0.84890200E+03, -.20882700E+04, 0.10279000E+04, -.51962800E+03, 0.10443300E+04, -.71350800E+03, -.44675200E+03, 0.10073000E+04, 0.99467500E+03, 0.17184700E+04, 0.10206600E+03, 0.91973300E+03, -.66062700E+03, 0.33276000E+03, -.39227500E+04, 0.33032300E+03, -.64016500E+03, -.47086200E+03, 0.36066500E+03, 0.18471600E+03, 0.16977200E+04, -.87680700E+03, -.30832300E+03, -.59613400E+04, 0.29789300E+04, -.22002900E+04, 0.29806800E+04, 0.27932000E+03, 0.11831500E+04, -.33029300E+03, -.15545900E+04, 0.27635600E+04, 0.79571800E+03, 0.11452200E+04, -.39079800E+04, 0.19508500E+04, -.27632000E+04, 0.19539900E+04, 0.32821900E+03, 0.21479500E+04, -.13342600E+04, -.33364900E+04, 0.16990300E+03, 0.34561200E+04, 0.44334800E+04, -.33121100E+04, 0.16455100E+04, 0.18432900E+04, 0.16560500E+04, 0.11429200E+03, 0.41227900E+03, 0.50397400E+03, -.91005900E+03, 0.64528200E+03, 0.85042700E+03, 0.21810600E+04, -.37661000E+04, 0.18905500E+04, -.59099200E+04, 0.18830500E+04, 0.26273800E+03, 0.92504400E+03, -.24607900E+03, -.11705300E+04, 0.34574400E+04, 0.68575200E+03, 0.91005800E+03, 0.19022500E+04, -.93111700E+03, 0.15308900E+04, -.95113000E+03, -.24896000E+02, 0.56054300E+03, -.55064600E+03, -.44757100E+03, -.17164900E+04, 0.30865500E+03, -.42823100E+03, -.12724400E+04, 0.62433800E+03, -.13497300E+04, 0.63620600E+03, 0.11178800E+03, 0.34848300E+03, -.27199400E+03, 0.10110400E+03, 0.90989000E+02, -.13008100E+03, -.74212500E+03, 0.10434500E+05, -.52008300E+04, -.13067600E+03, -.52172400E+04, 0.39003800E+03, -.17561200E+04, -.90588100E+03, 0.26216700E+04, -.33814200E+04, -.28153500E+04, -.58472900E+04, -.52197600E+03, 0.22728600E+03, -.16736900E+03, 0.37098500E+03, 0.89162200E+02, 0.36214500E+03, -.28856500E+03, 0.12221000E+03, -.48790100E+02, 0.17425300E+03, -.39973800E+03, -.22553300E+03, -.44601300E+03, -.80455100E+02, 0.36876700E+03, 0.47812300E+03, 0.31759300E+02, -.32046000E+03, 0.20060900E+03, 0.52903500E+03, -.59629700E+03, -.21972900E+03, -.55253800E+02, -.35702400E+03, 0.34894000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21001200E+01, -.12107800E+00, 0.15744700E+01, -.20860500E+01, -.27635800E+01, 0.10881400E+01, 0.80768700E-01, -.13620100E+00, 0.34108800E+00, -.38230100E+00, 0.26922900E+00, -.34190800E+00, -.86850000E+00, 0.55286700E+00, 0.19818100E+00, -.54155800E+00, -.12811100E+01, 0.19036300E+00, -.78455300E-02, 0.29867100E+00, 0.45430000E+00, 0.12127900E+00, 0.19526300E+00, -.54404200E+00, -.10699700E+00, -.57640800E+00, 0.65230500E+00, 0.12276600E+01, 0.17353400E+00, -.23975600E+00, 0.79341100E-01, -.39112200E+00, -.84496000E+00, -.13605000E+00, -.24167700E-01, 0.18183800E+00, -.84040900E-02, -.49263600E-01, 0.24105900E-01, 0.32369900E+00, -.20864300E+00, 0.51580300E+00, -.18775400E-01, -.60999300E-01, 0.51695400E+00, 0.11712000E+00, -.16849800E+00, 0.50386200E+00, -.28946000E+00, 0.39573400E-01, -.33465000E+00, -.38123100E-01, 0.20003600E+00, 0.76537700E+00, 0.10067300E+00, -.65999300E+00, 0.80397800E-01, -.17405500E-01, -.15959600E-02, -.75198300E+00, -.32067100E-01, -.10320400E+00, 0.89845000E-02, 0.21703500E+00, -.11680500E+04, -.31055200E+04, 0.21301500E+04, -.11378700E+04, 0.79242500E+02, -.10650700E+04, 0.14856200E+03, 0.15150300E+03, -.20196900E+03, 0.73761400E+03, -.87453300E+03, 0.60072900E+02, -.90443500E+03, -.41679600E+03, 0.84152800E+02, -.27327700E+04, 0.20843300E+03, 0.10295700E+03, -.78491400E+03, 0.22990400E+02, -.93161000E+03, -.53833300E+03, 0.38940100E+03, 0.64107900E+03, -.89880000E+04, 0.43997400E+04, 0.10635300E+04, 0.44940000E+04, 0.39638300E+03, 0.63252100E+03, 0.65366500E+03, -.12964500E+04, 0.23007300E+04, 0.10491200E+04, 0.42790700E+04, 0.94268600E+03, -.51661100E+03, -.23629900E+04, -.47134700E+03, -.10443500E+04, -.25251400E+03, 0.13214400E+03, 0.11112700E+04, 0.66267100E+03, -.10561200E+04, -.37099900E+03, 0.26571900E+04, -.12686200E+04, 0.22501500E+04, -.13286000E+04, -.51315500E+03, 0.89773000E+03, -.86135800E+03, -.35060500E+03, -.10566900E+04, 0.72772800E+03, -.45856500E+03, -.75619400E+03, 0.35141400E+03, -.24191600E+04, 0.37809000E+03, -.60856900E+03, -.95618500E+03, 0.12729700E+04, 0.22186600E+04, 0.19645400E+04, -.12309100E+04, -.68319200E+03, 0.39866200E+03, -.11367600E+03, 0.25961600E+04, -.19935000E+03, 0.95382600E+02, 0.42775500E+03, 0.52654500E+02, 0.66478600E+03, 0.12738100E+03, -.40696500E+03, -.69229900E+03, -.73342200E+04, 0.35975300E+04, 0.66498800E+03, 0.36671100E+04, 0.12493000E+04, -.31059500E+03, 0.17016100E+04, 0.50792400E+03, 0.31688100E+04, 0.21038900E+03, 0.28135100E+04, -.23757500E+04, 0.12510900E+04, -.20887800E+04, 0.11878800E+04, -.24774300E+04, -.17027700E+04, 0.10436900E+04, 0.30161200E+02, 0.88219400E+03, -.12224700E+04, 0.21565900E+04, -.15633800E+03, 0.60432000E+02, 0.31023800E+04, 0.78063800E+02, 0.16015500E+04, 0.19366400E+04, -.85617600E+03, -.12535300E+04, -.13142400E+04, 0.11869200E+04, -.91314300E+03, -.16494100E+02, 0.25529800E+02, 0.35361200E+04, 0.82348600E+01, 0.87065100E+03, -.10934100E+03, -.16960900E+03, -.67043700E+03, -.11331800E+04, 0.78044400E+03, 0.25271500E+01, 0.32145200E+04, -.15857900E+04, 0.29989600E+04, -.16072600E+04, 0.14929000E+04, 0.90021800E+03, -.66438500E+03, 0.31366600E+03, -.12209900E+04, 0.12056500E+04, -.42323500E+03, 0.66274300E+04, -.32921900E+04, 0.60383700E+03, -.33137100E+04, -.32482200E+03, -.18088900E+04, 0.69057700E+03, 0.20301400E+04, -.17493600E+04, -.32706400E+04, -.65873100E+04, 0.87323900E+03, -.43960900E+03, -.25772600E+03, -.43661900E+03, 0.28076400E+03, -.21996800E+02, -.16946700E+03, 0.23507500E+03, -.16090200E+03, -.59806800E+03, -.17225300E+04, 0.35652100E+03, -.19714200E+03, 0.92939800E+04, -.17826600E+03, 0.16096000E+04, -.20742800E+03, 0.22260400E+03, 0.67389600E+03, -.83238600E+03, 0.19684300E+03, -.90399300E+03, -.11075700E+04, 0.58848500E+03, -.30191700E+04, 0.55374400E+03, -.52004800E+03, -.61293700E+03, -.13962600E+03, -.11414900E+04, 0.67460600E+03, -.58145200E+02, 0.70199100E+03, -.17608000E+04, 0.93232800E+03, 0.96824600E+03, 0.88041800E+03, 0.12744600E+04, 0.69020400E+03, -.22194500E+03, -.14252800E+04, -.30395100E+03, 0.13029100E+04, 0.99537900E+03, -.10039700E+05, 0.49755300E+04, 0.49515100E+03, 0.50198600E+04, 0.40154600E+03, 0.12244500E+04, 0.12213100E+03, -.15451600E+04, 0.34481700E+04, 0.24662800E+04, 0.68902500E+04, 0.23663400E+03, 0.53414100E+02, -.16798400E+02, -.37438000E+03, 0.92017800E+02, -.20806200E+02, 0.54539900E+01, 0.82443700E+02, 0.45149000E+03, -.13191100E+03, 0.43728600E+03, 0.39265600E+03, -.16832800E+03, 0.53624400E+03, -.18530800E+02, -.53365400E+03, 0.87932600E+02, 0.43252600E+02, -.48344300E+03, -.50557000E+02, 0.96733100E+02, 0.11982700E+01, 0.19660400E+03, 0.38809600E+03, -.29525800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21482700E+01, -.15894100E+00, 0.58704200E+00, 0.30896100E+00, 0.73629600E+00, 0.26120600E+00, -.43099600E+00, 0.17939900E-01, 0.43322700E-01, -.47158400E+00, -.22233900E+00, 0.24693700E-01, -.12739200E+00, 0.65624300E+00, 0.10253400E+00, -.74509000E+00, -.95811000E+00, -.39999800E+00, 0.47911800E+00, -.46276700E+00, -.64793700E+00, -.21539400E-01, -.30622300E+00, -.47453600E+00, 0.10893000E+00, 0.34329400E+00, 0.58053500E+00, 0.18687000E+01, -.19124700E+00, 0.94543500E-01, 0.87735800E-01, 0.46514800E+00, -.25038800E-01, -.32280000E+00, -.42381600E-01, -.13889100E+00, 0.36211000E-01, -.10762900E+00, 0.54330100E+00, -.11316200E+01, -.42677100E-01, -.24712600E+00, -.12399100E+01, 0.19470900E+00, -.40994400E+00, -.12735100E+00, 0.15753300E-01, -.22269700E+00, -.63498600E+00, -.11358500E+00, 0.24979400E+00, 0.27492400E+00, -.24694500E+00, 0.79081700E-01, 0.80913400E+00, -.31999500E+00, -.80512600E-01, -.31258100E-01, 0.23170600E-03, -.37304800E+00, -.12837700E+00, 0.16057000E+00, 0.10366500E+00, 0.10370300E+00, 0.12374000E+00, 0.27889500E+04, -.16244300E+04, 0.92313000E+03, 0.59874400E+03, 0.81222800E+03, 0.41980500E+03, 0.66244400E+03, -.36985800E+03, -.12541100E+04, -.30687700E+03, 0.53203100E+03, 0.75274500E+03, 0.34243300E+04, -.15627200E+04, 0.10603400E+04, -.17121500E+04, -.10563800E+03, 0.32497700E+03, -.19127800E+04, -.12123700E+04, -.16951800E+04, 0.24420600E+03, -.14822100E+04, 0.59738300E+04, -.28882300E+04, 0.73061300E+03, -.29869200E+04, -.43466200E+03, -.11994800E+04, -.18652500E+03, 0.82449800E+03, -.22682400E+04, -.10855500E+04, -.21287600E+04, -.91881000E+03, 0.51272400E+03, 0.99724700E+03, 0.45940300E+03, -.78899200E+02, 0.13516000E+03, -.54816400E+02, -.82532900E+03, -.10561400E+04, 0.21061400E+03, 0.84830000E+03, -.17469100E+03, 0.27316700E+02, -.21594800E+04, 0.87344400E+02, -.65024500E+02, -.19775800E+03, -.47849600E+03, -.69609000E+03, 0.45692200E+03, -.38374800E+02, 0.12631900E+03, 0.22526200E+04, -.10977000E+04, 0.12603100E+04, -.11263100E+04, 0.53115500E+03, -.29739200E+03, 0.18111100E+03, 0.15698700E+03, -.10758800E+04, -.20673300E+03, -.90189600E+03, -.42088600E+04, 0.19885600E+04, -.31578800E+03, 0.21044200E+04, 0.14834300E+03, 0.14037200E+03, 0.15026500E+04, 0.73042200E+03, 0.17490100E+04, 0.92457000E+02, 0.18827800E+04, 0.23634600E+04, -.11088700E+04, 0.50369800E+03, -.11817300E+04, 0.27922100E+03, -.66942200E+03, 0.10637200E+03, 0.32080200E+03, -.10946300E+04, -.50426200E+03, -.18795300E+04, 0.30737200E+04, -.16032600E+04, 0.51321200E+03, -.15368600E+04, 0.18974200E+03, 0.10669100E+04, -.12602200E+04, -.45648500E+03, -.15252000E+04, 0.73638100E+03, -.63805100E+03, -.76921400E+03, 0.40795600E+03, -.14355400E+04, 0.38510800E+03, -.47710800E+03, -.52350600E+03, 0.59599700E+03, 0.10374600E+04, 0.49004400E+03, -.29334700E+03, 0.94679100E+03, -.75580300E+03, 0.35748500E+03, -.92113200E+03, 0.37789700E+03, 0.59261200E+02, -.63932300E+00, 0.20371200E+03, 0.66356900E+03, 0.86628000E+03, -.88109500E+02, -.36860900E+03, -.61430000E+03, 0.28081200E+03, -.31444800E+04, 0.30714900E+03, -.47026000E+03, -.21535400E+03, -.17401800E+03, 0.95422000E+02, 0.82080200E+03, -.12254900E+03, -.58955500E+03, -.40207300E+04, 0.19903000E+04, -.71827900E+03, 0.20103600E+04, -.17278500E+03, 0.10020500E+04, -.76994400E+03, -.83962500E+03, 0.13481900E+04, 0.87270600E+03, 0.53381800E+04, -.19586600E+03, 0.10563700E+03, -.38787500E+03, 0.97933300E+02, -.74753900E+03, -.13236400E+03, -.46135900E+02, 0.13244600E+03, -.54151200E+02, -.15069500E+03, 0.14695900E+04, -.32886800E+04, 0.16755300E+04, -.26640000E+04, 0.16443400E+04, -.96774400E+02, 0.26509100E+03, -.50415000E+03, -.24710800E+03, 0.11694200E+04, 0.39424400E+03, 0.14061500E+04, 0.22353600E+04, -.11997500E+04, 0.10642800E+04, -.11177000E+04, -.61814600E+03, -.87281200E+03, 0.48381000E+03, 0.15752600E+04, 0.67135300E+02, -.80911300E+03, -.12749500E+04, 0.19554700E+04, -.10434000E+04, -.10575600E+04, -.97772900E+03, -.58021400E+03, -.51406400E+03, 0.22814300E+03, 0.76467400E+03, 0.79792000E+03, -.60058500E+03, -.13041400E+04, 0.68043100E+04, -.33613300E+04, 0.11894100E+04, -.34021600E+04, -.20868600E+03, -.19354500E+04, 0.11429700E+03, 0.23587300E+03, -.22985300E+04, -.16948200E+04, -.43264000E+04, 0.25827400E+02, 0.14793400E+03, -.30075400E+03, 0.36761000E+02, -.28833800E+02, 0.21045200E+03, -.21108700E+03, -.44444500E+02, 0.75170500E+02, -.32479400E+02, -.15838400E+03, -.16818300E+03, -.46242400E+01, 0.80329200E+02, -.17648000E+02, 0.82378200E+02, 0.30146400E+02, -.18896900E+03, -.86939000E+01, 0.14012300E+03, -.16624200E+03, -.62025300E+01, -.21824300E+03, -.67682000E+02, 0.31712100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42897000E+01, -.34769900E+00, -.31115600E+00, 0.22264000E+00, -.81753400E+00, 0.12619800E+00, -.27555000E+00, -.33731600E+00, 0.72376100E-01, -.80530300E+00, 0.10740400E+01, -.20028600E+01, -.16536600E+01, -.21114900E+00, -.79555800E+00, -.40537000E-01, -.11823500E+01, 0.19679300E+00, 0.80258400E+00, -.76687800E+00, 0.78996700E+00, 0.13975000E+00, 0.20496300E-01, 0.24857800E+00, 0.19886300E+00, -.12168800E+00, 0.23827200E+01, 0.49235700E+01, -.13153400E+01, 0.38936100E+00, 0.37578600E+00, 0.80676300E+00, -.13202400E+01, -.11256400E+01, 0.24121600E+00, 0.32811100E+00, 0.60706200E-01, -.47468600E+00, 0.12593600E+00, -.11214400E+01, -.82408500E+00, -.19057200E+00, -.16142500E+01, 0.27649400E-01, 0.41803400E+00, -.23546600E+00, -.67939400E+00, -.13123600E+00, 0.17734500E+00, 0.24288700E+00, -.10209900E+00, -.11511800E+00, 0.23098700E+00, 0.14059000E+00, 0.40821100E-01, -.79628000E+00, -.17450500E+00, 0.89430400E+00, -.13769500E-01, -.13546400E+01, 0.52495100E+00, 0.10640200E+01, -.29141900E+00, 0.69819600E+00, 0.22199400E+01, -.98328000E+00, -.92702300E+04, 0.49571200E+04, 0.20200200E+04, 0.46351200E+04, 0.37852800E+03, 0.15843800E+04, -.35383800E+02, -.18275900E+04, 0.13025000E+04, 0.11624800E+04, 0.44881900E+04, -.11414300E+05, 0.64057900E+04, 0.12681000E+04, 0.57073100E+04, 0.21943000E+04, 0.43634300E+04, -.68556600E+03, -.27411800E+04, 0.38377600E+04, 0.32679400E+04, 0.52168600E+04, 0.38392100E+04, -.15581800E+04, -.48526700E+02, -.19196000E+04, 0.13899600E+04, -.68402500E+03, 0.16620700E+04, 0.45389900E+04, -.71036800E+03, -.90211900E+03, -.22136100E+04, -.19407400E+04, 0.11483000E+04, 0.98320500E+03, 0.97034500E+03, 0.46106800E+02, -.20018300E+03, 0.40447900E+03, -.26527200E+03, -.81418400E+03, 0.18159200E+03, 0.21437200E+04, 0.25929800E+04, -.15563500E+04, -.54902700E+04, -.12965100E+04, -.94011000E+02, 0.14207900E+03, -.51737100E+03, 0.81458400E+03, -.10722700E+03, -.47812600E+02, -.21718100E+02, -.63294400E+04, 0.32876000E+04, 0.66940700E+04, 0.31646800E+04, 0.32879200E+04, 0.65713400E+03, 0.18411400E+03, -.12882800E+04, 0.47066400E+03, 0.13077800E+04, 0.24177000E+04, 0.39625200E+04, -.24995600E+04, -.25144800E+04, -.19813500E+04, -.16101300E+04, -.25187100E+04, 0.82560800E+03, 0.19442600E+04, -.61991800E+03, -.20072600E+04, -.17462100E+04, -.10159600E+05, 0.53594600E+04, 0.32219100E+04, 0.50798100E+04, 0.12745000E+04, -.45068600E+04, 0.35278000E+04, -.16562800E+04, 0.27991100E+04, -.34361400E+04, 0.47925900E+04, 0.59457200E+04, -.32363300E+04, -.10869800E+03, -.29728100E+04, 0.17098200E+04, 0.49403600E+04, -.75975800E+03, 0.52436700E+04, -.45631100E+03, 0.29684700E+04, -.34179200E+04, 0.13603000E+04, -.63236000E+03, -.35852200E+04, -.67949700E+03, -.26781300E+04, -.32435600E+04, 0.80465000E+03, 0.91445000E+03, 0.55276900E+03, -.22531800E+04, 0.44313000E+02, 0.17874900E+03, -.15615600E+03, -.37017300E+04, -.89450100E+02, 0.43678900E+03, 0.26288900E+04, -.10871300E+04, -.60822100E+03, 0.98673000E+03, 0.15652300E+04, -.14539200E+04, 0.10867000E+04, -.63878800E+03, -.38932900E+04, -.54336700E+03, -.24907200E+04, -.13426700E+04, -.60044600E+03, -.14679700E+04, 0.24710900E+03, -.14001000E+04, -.11137600E+04, 0.19230200E+04, -.10405900E+04, -.79404100E+03, -.96150800E+03, -.54202500E+03, 0.31016200E+04, -.40031200E+04, -.34851900E+04, -.72005000E+03, 0.26491400E+04, 0.89401300E+03, 0.67475000E+04, -.33719700E+04, -.22571900E+04, -.33737400E+04, -.11248100E+04, 0.15352400E+04, -.18045700E+04, 0.49902500E+03, -.22355000E+04, 0.86359300E+03, -.20058000E+04, 0.24564900E+04, -.11430500E+04, -.12551600E+05, -.12282700E+04, -.93967100E+03, 0.83032100E+03, -.65335100E+03, -.23044500E+04, 0.24669400E+03, 0.23838100E+03, 0.96768700E+03, 0.21084300E+04, -.12277500E+04, -.12634600E+04, -.10544100E+04, 0.17191400E+04, 0.20101100E+04, -.87572000E+03, 0.39076800E+03, 0.10733900E+04, 0.18014500E+04, -.13817500E+04, 0.40416300E+04, -.22440700E+04, 0.33468600E+03, -.20207000E+04, -.15205000E+04, -.12093200E+04, -.46718900E+03, 0.84463200E+03, 0.10805100E+03, -.12967600E+04, -.30735100E+04, 0.35081800E+04, -.15769100E+04, -.60992300E+03, -.17541000E+04, 0.28625000E+04, -.15010600E+04, 0.31108100E+04, 0.57311300E+04, -.16976000E+03, -.22328500E+04, -.40358900E+04, 0.62128100E+03, 0.29954200E+03, -.34193000E+03, 0.95767200E+02, -.51142000E+03, 0.27781400E+03, -.41400200E+03, -.59773600E+03, 0.86861800E+03, 0.19218900E+03, 0.61883200E+03, -.15784100E+03, 0.28498500E+03, 0.16548200E+04, -.70346000E+03, -.65736000E+01, 0.95796300E+03, 0.48256000E+03, -.18138900E+03, 0.98910300E+03, 0.11549200E+03, -.66772300E+03, -.84612800E+03, 0.37362600E+03, 0.48151200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12568300E+01, 0.10377900E+00, -.29252400E+00, -.16261600E+00, -.38038000E+00, -.16301500E+00, 0.27735500E+00, -.98164400E-02, -.10259300E-01, 0.28653500E+00, 0.41094800E-01, 0.10801700E+00, 0.14902200E+00, -.48545400E+00, -.56207800E-01, 0.49062800E+00, 0.67308100E+00, 0.18858800E+00, -.28880000E+00, 0.25431900E+00, 0.47894300E+00, 0.27326000E-01, 0.15570400E+00, 0.28415200E+00, -.74478600E-01, -.20386600E+00, -.46542500E+00, -.12933800E+01, 0.94077400E-01, -.27637100E-01, -.54877300E-01, -.31946900E+00, 0.40727600E-01, 0.15675400E+00, 0.58304500E-01, -.72804400E-01, -.12754900E-01, 0.20917700E-01, -.31835000E+00, 0.40409900E+00, -.31668600E-01, 0.18234600E-01, 0.86104900E+00, -.10840600E+00, 0.16722100E+00, 0.72708200E-01, -.78301000E-01, 0.15755200E+00, 0.22742600E+00, 0.57389600E-01, -.18258500E+00, -.61924000E-01, 0.87963100E-01, -.14042900E+00, -.37088400E+00, 0.16098900E+00, 0.23264300E-01, -.20195400E-01, 0.55869200E-03, 0.35590200E+00, 0.16769600E+00, -.45655100E-01, -.59725900E-01, -.73198100E-01, -.19877000E+00, -.36917000E+00, -.29362700E-01, -.40778100E+02, 0.98941800E+02, 0.10695600E-02, -.76690800E+02, -.57140300E+02, 0.62444800E+02, 0.18079500E+03, 0.13368600E+03, -.53002400E+02, 0.22994400E+02, -.60765000E+03, 0.16282400E+03, -.13505500E+03, 0.30382100E+03, -.11864200E+03, -.17413900E+03, 0.37935900E+03, 0.23647900E+03, 0.43207400E+03, -.15878400E+03, 0.32977400E+03, -.11229200E+04, 0.51378500E+03, -.26700600E+03, 0.56145900E+03, 0.69968200E+02, 0.91588300E+02, 0.11304200E+03, 0.92769500E+02, 0.38959500E+03, 0.79649700E+02, 0.49706700E+03, 0.46379100E+03, -.25305900E+03, -.51166600E+03, -.23189500E+03, -.20912900E+03, -.17566000E+03, 0.11444000E+03, 0.25889400E+03, 0.63597600E+02, -.13883400E+03, 0.68067900E+02, 0.75536400E+02, 0.22765600E+01, 0.49464100E+03, -.37767700E+02, 0.27267300E+02, 0.78044000E+02, -.89805600E+02, 0.50057000E+02, -.18662700E+03, 0.25554300E+02, -.22840300E+03, -.94456700E+03, 0.45352200E+03, -.82928100E+01, 0.47228400E+03, 0.60675900E+01, 0.17861700E+03, 0.60949500E+02, -.32706300E+02, 0.32123200E+03, 0.19639100E+03, 0.68399800E+03, 0.31375800E+03, -.56643300E+02, 0.32127400E+02, -.15687700E+03, 0.18136100E+03, 0.14485700E+03, -.27065900E+03, -.17005500E+03, -.23849200E+03, 0.13688900E+03, -.21337500E+03, -.12988100E+04, 0.60905900E+03, -.72782500E+02, 0.64940600E+03, 0.14325400E+03, 0.75731600E+02, 0.17418800E+03, -.20652100E+03, 0.50058000E+03, 0.95103700E+02, 0.64123800E+03, -.48042600E+03, 0.28042900E+03, -.21459200E+03, 0.24021100E+03, -.28142800E+03, -.23644300E+03, 0.29484900E+03, 0.29026100E+03, 0.32527300E+03, -.18885400E+03, 0.24495900E+03, 0.95207000E+03, -.47742800E+03, 0.21996100E+02, -.47618700E+03, 0.10745100E+03, 0.46258700E+02, -.23664100E+03, -.14615800E+02, -.24003100E+03, 0.26578000E+02, -.42410800E+03, 0.10544200E+03, -.45577900E+02, 0.34557000E+03, -.52719100E+02, -.42313700E+02, -.71468600E+02, 0.37341500E+02, -.91845600E+02, 0.50756900E+02, -.10164200E+03, -.20041100E+03, 0.72774000E+02, -.24204100E+02, 0.82369700E+03, -.36386500E+02, 0.16566200E+03, 0.40633500E+02, -.71147900E+02, -.85974300E+02, -.13743200E+03, -.47100100E+02, -.32659700E+03, 0.90534600E+03, -.44203900E+03, 0.36623800E+03, -.45267300E+03, -.79517200E+02, -.23435100E+03, 0.56589200E+02, -.25002400E+02, -.29239100E+03, -.20281200E+03, -.37869800E+03, 0.32543600E+03, -.15963100E+03, 0.20151500E+02, -.16271800E+03, -.54464200E+02, -.34961300E+02, -.25620200E+02, -.13613100E+02, -.12655500E+03, -.34901200E+02, -.83236500E+02, 0.98548500E+03, -.50273300E+03, 0.64061100E+03, -.49274200E+03, -.57883400E+02, -.13149300E+03, -.33045100E+02, -.27929700E+03, -.43703200E+03, -.12679400E+03, -.60599000E+03, -.47741700E+03, 0.24734900E+03, -.43032700E+03, 0.23871300E+03, 0.15491400E+03, 0.68093200E+02, 0.79386100E+02, -.13792800E+03, 0.16634300E+03, 0.65418900E+02, 0.34555100E+03, -.66163500E+03, 0.35997600E+03, 0.41525500E+03, 0.33081400E+03, 0.31864400E+03, 0.23522300E+03, -.15446900E+03, -.17825100E+03, -.53575100E+02, 0.19528400E+03, 0.59704300E+02, -.19514200E+04, 0.94934500E+03, -.16840200E+03, 0.97570900E+03, 0.11060300E+03, 0.18011800E+03, 0.21824500E+03, 0.22004200E+03, 0.61360300E+03, 0.98334000E+02, 0.64932800E+03, -.64846800E+00, -.10926400E+02, 0.43355400E+02, -.27210200E+02, -.69773000E+02, -.22645900E+02, 0.29650200E+02, -.64107800E+02, -.58578000E+02, -.19616500E+02, 0.51413500E+02, 0.41985100E+02, 0.93619800E+00, -.11298900E+03, -.19734000E+02, -.61948900E+02, 0.16496000E+01, 0.77984700E+01, 0.21473600E+02, 0.89964600E+01, 0.10408200E+02, -.43695400E+02, -.15328800E+02, 0.33589300E+02, -.35967700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.64424700E+01, 0.64391000E+00, 0.15394800E+01, 0.23505000E+01, 0.41039100E+01, -.15677400E+01, 0.39451900E+00, 0.45779100E+00, -.27490300E+00, 0.11335900E+01, 0.17320700E+01, 0.11707500E+00, 0.17142300E+01, 0.65869200E+01, -.88997100E+00, 0.11686600E+01, 0.42920200E+01, 0.37194400E+01, 0.25432800E+00, 0.12441700E+01, -.37141300E+01, -.66152700E+00, 0.15340400E-01, 0.33854500E+01, 0.73693700E+00, -.57740600E+00, 0.29414700E+00, -.11844300E+01, 0.97802800E+00, 0.30466700E-01, -.21366200E+00, -.98619900E+00, 0.38016300E+01, -.10784000E+01, 0.32048200E+00, 0.73257100E-01, -.55058400E-01, 0.97792500E-01, 0.84649200E-01, 0.37718900E+01, 0.11475500E+01, 0.38652100E+00, 0.49809400E+00, -.91312500E-01, 0.10765200E+01, 0.34900700E+00, 0.12196500E+01, -.11628400E+01, 0.13018400E+01, 0.18649400E+00, 0.17237100E+01, -.15402600E+01, 0.30274900E+00, -.19630500E+00, 0.15313100E+01, -.13087800E+01, 0.27981600E+00, -.25997300E+00, 0.39855400E-02, -.16409900E+01, 0.83368600E+00, -.42007900E+00, 0.25441300E+00, -.15525600E+01, -.24819900E+00, 0.23145300E+01, -.10242000E+01, -.10894300E+01, -.26329600E+04, 0.56960000E-01, -.98012700E+03, -.93799000E+03, 0.15696100E+03, 0.11695800E+04, 0.23779300E+04, -.10471200E+04, -.92629100E+02, -.11604700E+05, 0.58487300E+04, -.63058500E+04, 0.58024200E+04, 0.54708000E+03, 0.36246600E+04, 0.13841200E+04, 0.65189700E+03, 0.56249600E+04, 0.25980700E+04, 0.54624400E+04, -.81702900E+03, 0.41347700E+03, -.70411100E+03, 0.40851600E+03, 0.27529400E+04, 0.28087900E+04, 0.11370500E+04, 0.41207400E+04, 0.17837800E+04, 0.18431300E+04, -.29586900E+04, 0.40005600E+04, -.19959100E+04, 0.11184700E+04, -.20002900E+04, -.26725000E+03, -.21400400E+04, 0.11662300E+04, 0.30248300E+04, 0.18829500E+04, -.23023100E+04, -.68008300E+03, -.35599800E+04, 0.17514100E+04, -.23446100E+04, 0.17799800E+04, 0.20778600E+04, 0.73922100E+03, 0.45875000E+03, 0.14681600E+04, 0.18606900E+04, 0.85775400E+03, -.62622700E+03, -.42441300E+04, 0.21411200E+04, 0.41554200E+04, 0.21220500E+04, -.47593200E+03, -.79396700E+03, 0.10620500E+04, -.54435300E+03, 0.47851300E+03, -.18414800E+03, 0.41727500E+04, 0.61349800E+04, -.31358400E+04, 0.30820400E+04, -.30675400E+04, -.66104700E+03, -.24170000E+04, -.90422800E+03, -.77998400E+03, -.28802200E+04, -.18054500E+04, -.29556100E+04, -.19727000E+04, 0.10001100E+04, 0.84710000E+03, 0.98635200E+03, -.10263600E+04, -.19254900E+04, 0.11081400E+04, -.10433500E+04, -.67834900E+03, -.10976300E+04, 0.26205800E+04, 0.19188600E+04, -.96638000E+03, 0.19744400E+04, -.95941800E+03, 0.26421100E+04, 0.41601100E+04, 0.10290300E+03, 0.41323900E+04, 0.10188700E+04, 0.20206600E+04, -.42635200E+04, -.21964600E+04, 0.10872700E+04, -.10103300E+04, 0.10972100E+04, -.21019200E+04, -.23782700E+04, -.49849900E+03, -.23263600E+04, 0.14645900E+04, -.13388900E+04, 0.17482800E+04, 0.21368700E+04, -.10633700E+04, -.75772800E+04, -.10684500E+04, -.53194600E+03, 0.20700500E+04, -.18163300E+04, -.19113200E+04, -.10816600E+04, 0.19112500E+04, -.15927400E+04, -.29516300E+04, 0.14697400E+04, -.15747600E+04, 0.14758200E+04, -.11826900E+03, 0.41672600E+03, -.19272700E+04, -.37959600E+04, -.46567200E+03, 0.10942200E+04, -.11169100E+04, 0.31906600E+04, -.15896000E+04, -.35573800E+04, -.15953300E+04, 0.12398300E+04, 0.39022800E+04, -.31947600E+04, -.23057900E+04, -.24865900E+03, 0.33901400E+04, -.13366800E+04, 0.58680100E+04, -.29414700E+04, -.62098800E+03, -.29340000E+04, 0.50560000E+03, 0.18829700E+04, -.19820200E+04, 0.74035000E+02, -.92353600E+03, 0.10534100E+04, -.27177500E+04, 0.78238200E+03, -.37334000E+03, -.15541800E+05, -.39120700E+03, 0.13895400E+03, 0.10326900E+04, -.91308500E+03, -.14698500E+04, 0.19819100E+04, 0.11315200E+04, -.23415800E+03, -.64922700E+04, 0.32060300E+04, -.11228500E+04, 0.32460400E+04, 0.95854100E+03, 0.31460200E+04, 0.74903600E+03, -.75574900E+03, 0.10257100E+04, 0.24887000E+04, 0.40037500E+04, -.43692200E+04, 0.21692300E+04, 0.36605900E+04, 0.21846500E+04, 0.66553700E+03, 0.18519500E+04, -.14320500E+04, -.28928100E+04, -.23164000E+04, 0.19819100E+04, 0.46223900E+03, 0.30197000E+04, -.15054000E+04, -.24442800E+04, -.15098500E+04, 0.39832100E+04, 0.17149600E+04, 0.26972000E+04, 0.76123500E+04, -.94506400E+03, 0.51564500E+03, -.74139400E+04, -.12688400E+02, 0.33793200E+03, 0.21936700E+02, 0.49503000E+03, -.35500600E+02, 0.33269100E+03, -.45168100E+03, 0.95541900E+02, -.15023900E+04, 0.57009900E+03, 0.75212100E+03, -.32678600E+03, 0.10451100E+03, -.88271000E+03, 0.19434400E+03, 0.61803800E+03, 0.91413800E+03, 0.64251600E+03, -.12539300E+03, 0.36715300E+03, 0.33246500E+03, -.17270100E+03, 0.44382500E+03, 0.32591800E+03, -.55580000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.90181000E+01, 0.79681400E+00, -.86774500E-01, -.21176900E+01, -.33920500E+00, 0.47090900E+00, 0.91468800E-01, 0.27665800E+00, 0.12136000E+00, 0.29652600E+00, 0.36948300E+00, 0.92962100E+00, 0.61433100E+00, 0.11105000E+01, 0.10820900E+01, 0.72499100E+00, 0.47040400E+01, 0.33984100E+01, -.83006800E+00, 0.18063000E+01, -.45842100E+00, 0.19728500E-01, 0.70167800E+00, 0.23069600E+01, 0.29550400E+00, 0.18572200E+00, -.17549600E+01, 0.47848800E+00, 0.79560400E+00, -.84544900E+00, 0.64217300E-01, 0.12895700E+01, 0.99288600E+00, 0.35746700E+00, 0.24331800E+00, 0.82133700E+00, 0.12860200E-02, -.22754600E+00, 0.14964600E+01, 0.83728200E+00, 0.64664400E+00, 0.83622300E-01, 0.36541400E+01, -.25170400E+00, -.15419600E+00, 0.27916400E+00, 0.73926800E+00, -.51562700E+00, 0.70912600E+00, 0.11715200E+00, 0.81839300E+00, -.11680300E+01, -.33321100E+00, 0.56249900E-01, 0.90262000E+00, -.20843100E+01, -.27706700E+00, 0.58594100E+00, 0.49342100E+00, -.36935000E+01, 0.15391900E+01, -.95788300E+00, 0.35886300E+00, 0.13436900E+00, -.55541500E+00, 0.13737100E+01, -.66154000E+00, 0.24306800E+00, 0.10423200E+00, 0.65148000E+01, 0.36113000E+03, 0.49609300E+03, -.95542600E+03, -.18368100E+04, -.41407100E+03, 0.55296300E+03, -.25948700E+03, -.76402500E+04, 0.34075600E+04, 0.93691800E+04, 0.38213300E+04, -.14941700E+04, -.13071000E+04, 0.15053000E+04, 0.99373700E+02, 0.28605800E+04, -.11028500E+04, 0.33764400E+04, 0.26342700E+04, -.12794000E+04, 0.36790200E+03, -.13187900E+04, -.52273100E+03, 0.63140800E+03, -.13094900E+04, -.30522000E+04, -.15560500E+04, 0.98233300E+03, -.13929700E+04, -.71564000E+03, 0.39549100E+03, -.21130000E+04, 0.35721400E+03, 0.49007100E+03, -.68680500E+02, -.33685800E+03, -.99176400E+03, -.71281800E+03, -.19298400E+03, -.21128800E+04, -.89307300E+03, 0.47832800E+03, 0.25103500E+03, 0.44470700E+03, 0.11090000E+04, -.16029000E+03, 0.80206500E+03, 0.59367400E+03, 0.42624500E+03, -.13449900E+03, 0.27447400E+04, 0.45196400E+04, -.22751100E+04, -.74035000E+03, -.22587500E+04, -.48454600E+03, -.96584100E+03, -.48360000E+03, -.42600900E+03, -.11279100E+04, -.11512600E+04, -.43303600E+04, 0.74284100E+04, -.34625900E+04, -.64211700E+04, -.37153300E+04, 0.54020600E+03, 0.84404700E+03, -.12495100E+04, 0.26915300E+03, -.26712300E+04, 0.64925800E+03, -.34867600E+04, 0.87627000E+04, -.43925600E+04, 0.32144800E+03, -.43812800E+04, -.23513400E+04, -.30038900E+03, -.27697000E+04, -.23226400E+04, -.36100200E+04, 0.68107800E+02, -.31723000E+04, 0.14574700E+04, -.69315500E+03, 0.53714400E+03, -.73024300E+03, 0.14690600E+04, 0.10809300E+04, -.12044600E+04, -.13401100E+04, -.82404700E+03, 0.52345900E+03, -.23121000E+04, 0.20765000E+04, -.98332400E+03, -.75399200E+03, -.10367300E+04, -.29404900E+02, 0.20070900E+03, -.13122700E+04, -.11603000E+04, -.21056600E+04, 0.41999400E+03, -.52421600E+03, -.16596100E+04, 0.80307300E+03, 0.62260200E+03, 0.83001000E+03, 0.54480600E+03, 0.89864400E+03, -.62874900E+03, 0.75481800E+03, 0.68841600E+03, 0.65599500E+03, 0.14637000E+04, 0.15002200E+04, -.76311600E+03, -.14990600E+04, -.74556600E+03, -.14259400E+04, -.54924100E+03, 0.88280900E+03, 0.18382400E+04, -.28759100E+03, 0.71650600E+02, 0.15469900E+04, -.63229300E+04, 0.31592300E+04, -.81813800E+03, 0.31612400E+04, -.12569300E+04, -.43303400E+03, 0.29850600E+04, 0.30058900E+04, 0.19305300E+04, -.12614100E+03, 0.41491400E+04, -.44684800E+02, 0.55515500E+02, -.87673600E+03, 0.20896400E+02, -.84896600E+03, -.51337300E+03, 0.13685600E+03, 0.41229900E+01, -.61813900E+03, -.11539400E+03, 0.70504100E+03, -.38795500E+04, 0.19603300E+04, 0.11035400E+04, 0.19340500E+04, -.11094700E+04, 0.62491400E+03, -.40929900E+03, 0.17237500E+03, -.31222300E+03, 0.10876600E+04, 0.50420700E+04, 0.28074600E+03, -.30010700E+03, 0.37383300E+04, -.15239900E+03, -.15955000E+04, -.21038500E+04, 0.27834500E+04, 0.47612400E+04, 0.14951500E+04, -.25636500E+04, -.16966900E+04, 0.21356100E+04, -.10862300E+04, 0.67393300E+03, -.10677800E+04, -.14254500E+04, -.64039600E+03, 0.11183300E+04, 0.15289200E+04, 0.68720600E+03, -.31161600E+03, 0.11902500E+04, 0.48991600E+04, -.24608800E+04, 0.36898800E+03, -.24471300E+04, -.64108100E+03, 0.12255100E+04, -.21297400E+04, -.36306000E+04, -.11045300E+04, 0.14926300E+04, -.22872200E+04, -.34836200E+03, -.44592400E+02, -.14404000E+03, 0.37461500E+03, 0.25187300E+03, -.91373300E+02, 0.68085500E+02, 0.30876300E+03, -.22807600E+04, -.15125000E+03, -.79945400E+03, 0.13757800E+02, 0.28004100E+03, -.24381100E+04, 0.51883600E+02, 0.57604400E+03, -.56498400E+02, -.58565400E+03, -.52335500E+02, -.51224800E+03, -.14665000E+03, 0.52995100E+03, 0.19867500E+03, -.69290000E+03, 0.22063200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.52964400E+01, 0.47498000E+00, 0.11050600E+01, 0.63236800E-01, 0.42547500E+00, -.28264600E+00, 0.26801600E+00, 0.26508800E+00, -.20822900E+00, 0.15237900E+01, -.12293900E+00, 0.15746300E+01, 0.14893500E+01, 0.77227800E+00, 0.43252300E+00, 0.66382700E+00, 0.23117200E+01, 0.14845400E+01, -.11365400E+01, 0.12795700E+01, -.10663400E+01, -.18735100E+00, 0.28395400E+00, 0.14340400E+01, 0.12173800E+00, 0.35549000E-02, -.22139200E+00, -.28188100E+01, 0.29477200E+00, 0.11564000E+00, -.14411600E+00, 0.11596600E+01, 0.13868400E+01, -.34144600E+00, 0.26719300E+00, 0.65074400E+00, 0.96157600E-02, 0.53128000E-01, 0.20163600E+00, -.26827500E+01, -.22850800E+00, -.90692000E+00, 0.22327400E+01, -.20277500E+00, -.14065600E+01, -.25634800E+00, -.85609100E-01, -.19855900E-01, 0.12498100E+01, 0.19681900E+00, 0.10194800E+01, -.36568900E+00, -.37362700E-01, 0.12456600E+01, 0.11587000E+01, 0.20620900E+00, 0.39026300E+00, 0.32967800E+00, -.99925000E-04, -.16726100E+01, -.69870600E+00, -.81615400E+00, 0.11983100E+00, -.14646200E+00, 0.63493400E+00, -.14580000E+01, 0.75955500E-01, -.47477200E-01, -.22412200E+00, 0.14401100E-02, 0.72627100E+03, 0.89840900E+03, -.10397100E+04, -.15639400E+04, -.73810700E+03, 0.89253100E+03, 0.13764400E+03, 0.36375600E+04, -.20276900E+04, 0.16119100E+04, -.18187800E+04, -.60067500E+03, -.12473400E+04, -.80386300E+03, 0.19910300E+03, -.17913400E+04, -.13076400E+04, -.10554600E+04, 0.69527300E+04, -.34911900E+04, 0.13787400E+04, -.34763600E+04, -.43353500E+03, -.50251900E+03, -.38144100E+03, 0.41107800E+02, -.24457000E+04, -.43247600E+03, -.35959000E+04, -.21671000E+04, 0.10876000E+04, 0.17504900E+04, 0.10835500E+04, 0.11726400E+04, 0.94706800E+03, -.95764000E+03, -.12234400E+04, 0.18355400E+03, 0.91313600E+03, -.11654700E+04, 0.81859700E+03, -.38553500E+03, -.38792200E+04, -.40929500E+03, 0.40722600E+03, -.13536600E+04, 0.98635600E+03, 0.50773500E+03, 0.31718700E+03, -.14090200E+04, 0.10284700E+04, 0.40104200E+04, -.20126000E+04, 0.71497700E+03, -.20052100E+04, 0.75907500E+03, 0.19793100E+03, -.13352700E+04, -.12236700E+04, -.88978900E+03, 0.55866600E+03, -.37366600E+04, -.33719200E+04, 0.18095700E+04, -.84265600E+03, 0.16859600E+04, 0.38358300E+03, 0.13734200E+04, 0.43484600E+03, -.43291100E+03, 0.13548100E+04, 0.13578500E+04, 0.11146200E+04, 0.54469200E+04, -.27448100E+04, 0.54918600E+03, -.27234600E+04, -.10888400E+04, -.93348900E+03, -.66594600E+03, -.48389500E+03, -.27633700E+04, -.61883500E+03, -.24223300E+04, 0.50677600E+04, -.25060900E+04, 0.94491300E+03, -.25338800E+04, 0.17940800E+04, 0.24139000E+04, -.25037800E+04, -.11560200E+04, -.24796900E+04, 0.19610200E+04, -.26211900E+04, -.42616900E+04, 0.21442900E+04, -.14442900E+04, 0.21317700E+04, -.89425800E+03, -.80807800E+03, 0.13157900E+04, 0.47244700E+03, 0.88885500E+03, -.72330700E+03, 0.29870000E+04, 0.16210500E+03, -.83485600E+02, -.17601100E+04, -.81050000E+02, -.11848700E+03, 0.35205200E+03, -.23884100E+03, 0.63357300E+03, -.50005700E+03, 0.47155100E+03, 0.10824000E+04, 0.13666100E+04, -.68410900E+03, -.54568800E+04, -.68331100E+03, -.18514300E+04, -.18066000E+04, 0.76599500E+03, 0.88652900E+03, 0.24455000E+03, -.16565800E+04, 0.17499900E+04, -.55053000E+04, 0.27605400E+04, -.22392400E+04, 0.27526500E+04, 0.27515400E+03, 0.16250200E+04, -.75262800E+03, 0.76049000E+03, 0.23674900E+04, 0.96605700E+03, 0.21245500E+04, -.77350900E+03, 0.39794000E+03, -.79177000E+03, 0.38675600E+03, -.28771200E+03, 0.26201300E+03, -.18882600E+03, 0.58978600E+03, 0.84231400E+03, -.63217800E+02, 0.56384300E+03, -.12640900E+04, 0.64493100E+03, -.66021900E+04, 0.63205400E+03, -.12291600E+04, -.12209000E+04, 0.74506500E+03, 0.23396100E+04, 0.23528000E+03, -.16112500E+04, 0.21563900E+04, 0.23805700E+03, -.19967200E+03, 0.33951300E+04, -.11901200E+03, -.55791200E+03, -.60150400E+03, 0.85293900E+03, 0.19912500E+04, 0.80596000E+03, -.55460600E+03, -.15422800E+04, 0.32943300E+04, -.16526900E+04, -.80777400E+03, -.16471700E+04, -.18362900E+04, -.12287000E+04, 0.86739300E+03, 0.88335100E+03, 0.18790900E+03, -.11751600E+04, 0.62996300E+03, 0.10517200E+05, -.52786700E+04, 0.13981400E+04, -.52585900E+04, -.43613800E+03, -.16746900E+04, -.33034100E+03, -.12700700E+04, -.32320600E+04, -.99716500E+03, -.48478200E+04, 0.27798800E+03, -.11303000E+03, -.10365100E+03, -.10282700E+02, -.42929200E+02, -.99151300E+02, 0.21722200E+02, -.12670100E+02, -.30501600E+03, 0.26990800E+03, -.13220400E+03, -.21879100E+03, 0.41628000E+03, -.48227100E+03, -.17577500E+03, 0.16939500E+03, -.13669400E+03, 0.24807100E+03, 0.11538700E+03, -.35324200E+03, 0.37699400E+03, 0.19151400E+03, -.18130400E+03, -.10430000E+03, 0.11087900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54874800E+01, 0.30559100E+00, -.32065000E+01, 0.17849100E+01, 0.47611400E+00, -.12454200E+01, 0.36090900E+00, 0.63642400E-01, -.66040600E+00, 0.80633900E+00, 0.83769200E+00, -.18800400E+00, 0.73669700E+00, 0.17580000E+00, -.17005100E+00, 0.19365900E+01, 0.31200500E+01, 0.13120300E+01, -.93370200E-01, 0.20563000E+00, -.48554100E+00, -.15098400E+00, 0.33702500E-01, 0.85480500E+00, 0.27681500E+00, 0.55329600E+00, 0.82818300E+00, 0.25157300E+00, -.27624600E+00, 0.29902600E-01, -.29162800E-01, 0.14777600E+01, 0.62172300E+00, -.43445000E+00, 0.15734300E+00, -.12490600E+01, 0.14830400E+00, -.38557300E+00, -.28073500E+00, -.14149300E+01, -.53546500E+00, -.64960400E+00, 0.15999300E+01, -.16432900E+00, -.61371400E+00, -.21450100E+00, 0.69942500E-01, -.18565900E+01, 0.27160300E+00, -.16792700E+00, 0.43033300E+00, 0.50721600E+00, -.10972800E+01, -.19499400E-01, 0.29628400E+01, 0.14927900E+01, 0.34947100E+00, -.55780000E+00, 0.85281200E-02, 0.47933000E+00, -.22646000E+01, -.38920400E+00, 0.13970300E+00, -.95738200E+00, -.14456600E+01, 0.62222100E+00, -.34979500E+00, -.12880200E+01, -.20581900E+00, 0.45994900E-03, 0.24287900E+00, 0.82430800E+03, -.82191500E+03, 0.63270300E+03, 0.80254100E+03, 0.58892400E+03, -.41498200E+02, 0.10813200E+03, 0.70750200E+00, 0.25557300E+04, -.54049600E+02, 0.39034700E+03, -.76249900E+03, 0.44364400E+03, 0.68443600E+02, 0.10144400E+03, -.37751500E+03, -.46960600E+03, 0.92326400E+03, -.43332800E+03, -.86543800E+03, -.46163100E+03, 0.67874200E+03, 0.49771700E+03, 0.18759200E+03, 0.26239000E+04, 0.47560500E+03, 0.43360900E+03, -.11734400E+04, 0.24272400E+04, -.12056300E+04, -.44491800E+03, -.12136200E+04, -.11893900E+04, -.15828100E+04, 0.14042200E+04, 0.18678600E+04, 0.24480200E+04, -.15498000E+04, 0.39182900E+03, 0.37051600E+03, -.22349800E+03, -.14082500E+04, -.18525900E+03, -.13461100E+03, -.69552300E+02, 0.11447300E+03, 0.11913100E+04, -.51997600E+03, -.49922600E+03, -.53940000E+03, -.71414500E+04, 0.35898800E+04, 0.41196800E+04, 0.35707200E+04, 0.20305100E+04, 0.13664800E+04, -.45018100E+03, -.17901300E+04, 0.13925800E+04, 0.20210200E+04, 0.41531500E+04, -.11879400E+04, 0.56107700E+03, -.21090500E+04, 0.59396300E+03, 0.13013800E+03, 0.98068200E+03, -.39338600E+03, -.11486400E+03, 0.29365500E+03, 0.61584600E+03, 0.86756500E+03, -.44955200E+04, 0.22757600E+04, -.48266100E+03, 0.22477600E+04, 0.79313000E+03, -.78202400E+03, 0.77261100E+03, -.13148800E+04, 0.96116600E+03, 0.12521500E+03, 0.20694400E+04, 0.16217800E+04, -.84230000E+03, 0.84114600E+03, -.81088400E+03, 0.98445700E+03, 0.14649000E+04, 0.85508400E+03, 0.37613500E+04, 0.83493400E+03, 0.18073200E+03, -.11548100E+04, -.39331100E+04, 0.19544100E+04, -.28768300E+02, 0.19670000E+04, -.28474900E+03, -.14707900E+04, 0.94344400E+03, -.35934500E+03, 0.17621500E+04, -.88904400E+03, 0.19373100E+04, 0.67289500E+03, -.33642100E+03, -.18174700E+04, -.33645400E+03, 0.24483900E+03, 0.94841700E+03, -.15339400E+03, -.63376800E+03, -.25825500E+03, 0.84211200E+03, -.13591600E+04, -.23199000E+04, 0.11560700E+04, 0.85870500E+03, 0.11599500E+04, -.49581200E+03, 0.79983700E+03, -.74556100E+03, -.24515400E+04, -.10486900E+04, 0.42522700E+03, -.84189900E+03, 0.70762700E+04, -.35468200E+04, -.63207800E+03, -.35381400E+04, 0.42724200E+03, 0.24702200E+04, -.36620500E+04, -.25697400E+04, -.21928800E+04, 0.18484000E+04, -.26430100E+04, 0.39530400E+04, -.19876400E+04, -.82862000E+03, -.19765200E+04, -.74453000E+03, 0.76126100E+03, -.81732600E+03, 0.24378400E+01, -.40418600E+03, 0.30123600E+02, -.15693300E+04, 0.34863800E+04, -.17394900E+04, -.69225300E+04, -.17431900E+04, -.14924800E+04, -.17047400E+04, 0.23349700E+04, -.10984100E+03, 0.12707200E+04, -.20214600E+04, -.10403300E+04, 0.86462500E+03, -.40406000E+03, 0.17055600E+04, -.43232900E+03, 0.75570700E+03, -.91484600E+03, 0.10417100E+04, -.11584900E+03, -.19731800E+03, -.30127500E+03, 0.24604300E+03, -.42319700E+04, 0.20968400E+04, 0.23238800E+04, 0.21160000E+04, 0.12451400E+04, 0.18150400E+04, -.20437400E+04, -.23765800E+04, -.24944500E+04, 0.17813100E+04, 0.21284900E+03, 0.17995500E+04, -.87385500E+03, -.29496300E+04, -.89977500E+03, 0.27503200E+03, 0.11246500E+03, 0.83152900E+03, 0.38297600E+04, -.96996700E+03, -.18474600E+03, -.31433800E+04, -.18050600E+02, 0.73128400E+02, 0.12855200E+03, 0.12159800E+03, -.40855000E+03, 0.84347600E+02, -.11473900E+03, -.34800800E+03, 0.10829900E+04, 0.19147900E+03, 0.72017300E+03, -.54034600E+02, 0.41476500E+03, 0.89995300E+03, -.14850100E+03, 0.80060500E+02, 0.35794100E+03, 0.28905200E+03, 0.11730700E+03, 0.56856700E+03, 0.38323000E+03, -.33816000E+03, -.50676200E+03, 0.54759300E+03, 0.14615100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19318500E+01, -.46645700E-01, 0.69996600E+00, -.39065400E+00, 0.91556200E+00, 0.23368500E+00, -.44982400E+00, 0.97905900E-02, 0.75958400E-01, -.75040500E+00, -.91512900E+00, 0.22070900E+00, -.22181200E+00, -.58973400E+00, 0.47894500E-01, -.38813500E+00, -.54788000E+00, -.44421100E+00, 0.17187000E+00, -.95304900E-01, -.56654900E-01, 0.33831200E-01, -.27753500E-01, -.21467500E+00, -.44464500E-01, 0.93395700E-02, -.22417300E+00, 0.10762500E+01, 0.14780700E+00, -.58385800E-02, 0.87422300E-02, 0.25545600E+00, -.11440400E+00, -.49745000E-01, 0.19151200E-01, 0.10553800E+00, -.84503200E-02, 0.47992500E-01, 0.40579100E-01, -.58203000E+00, 0.58326000E-01, -.34106200E+00, -.64816900E-01, 0.24200300E-01, -.23373800E+00, -.10757200E+00, 0.87850000E-02, -.11772200E+00, -.28367800E-01, 0.65513400E-01, -.12485100E-01, -.11872900E+00, 0.36890400E-01, 0.16832700E+00, -.51296100E+00, -.75896400E-01, -.13545300E+00, 0.11122600E+00, 0.14583500E-02, 0.48525100E+00, 0.29032000E+00, 0.29929800E+00, 0.55611000E-02, 0.30524700E+00, 0.52622700E-01, 0.18929600E-01, 0.12841300E+00, 0.13163100E+01, -.12027100E-01, -.30262100E-02, 0.15473300E-01, 0.16498900E-01, 0.17693600E+03, 0.56205800E+02, -.76877700E+02, -.88258600E+01, -.33366300E+02, -.25668900E+04, 0.13034400E+04, 0.68163800E+03, 0.12834000E+04, 0.34808700E+03, 0.34553100E+03, 0.33747500E+03, -.45243200E+03, 0.62596400E+03, 0.40136800E+03, 0.76594400E+03, 0.32152900E+03, -.15191200E+03, 0.49211100E+03, -.16077000E+03, -.10091500E+03, -.22570300E+03, 0.11658000E+02, -.47434200E+03, -.22110600E+03, -.16758100E+03, 0.27261000E+02, -.83139400E+02, 0.44295700E+02, 0.34482500E+03, 0.41573000E+02, 0.22767100E+03, 0.36197700E+03, -.57845800E+03, -.27658800E+03, -.39328600E+03, 0.26809200E+03, -.30770400E+03, -.26170400E+03, 0.12856000E+03, -.14113900E+03, 0.13084900E+03, -.24799800E+03, -.11064700E+03, 0.32017400E+03, -.10565100E+03, 0.18989300E+03, -.32318000E+02, 0.20629600E+03, 0.67390300E+03, -.33669200E+03, -.44537100E+03, -.33694100E+03, -.30793300E+02, -.51870200E+03, 0.30933800E+03, 0.44863100E+03, 0.79797400E+02, -.56554100E+03, -.55246100E+03, 0.25270300E+04, -.12724000E+04, -.65113300E+03, -.12635000E+04, -.41639500E+03, -.36753500E+03, -.32703600E+03, 0.35572000E+03, -.66869200E+03, -.39114300E+03, -.78901300E+03, 0.49422000E+03, -.24090200E+03, 0.61173600E+03, -.24711000E+03, 0.37836200E+03, -.99387400E+02, 0.17369700E+03, 0.33664700E+03, -.44929300E+02, -.27079100E+03, -.67334900E+03, 0.44690300E+02, -.26660200E+02, 0.58109300E+02, -.22357700E+02, -.15489400E+03, -.20867500E+02, -.31712100E+03, -.53512700E+03, -.22157600E+03, 0.23252200E+03, 0.12297000E+03, 0.46431400E+03, -.22853000E+03, -.18030100E+03, -.23235500E+03, 0.47003100E+02, 0.18279300E+03, -.19640500E+03, -.10297100E+03, -.46220200E+03, 0.66114400E+02, -.14508300E+03, -.22495100E+03, 0.11069100E+03, 0.18082000E+03, 0.11248900E+03, -.18384400E+02, -.48118400E+02, -.20465800E+02, -.23476200E+02, -.22262100E+03, 0.15356300E+03, 0.25691900E+03, 0.26927700E+03, -.13512500E+03, -.74177700E+03, -.13462300E+03, -.18684600E+03, -.25719700E+03, 0.40613900E+03, 0.64030500E+03, 0.17010100E+03, -.14428800E+03, 0.27449900E+03, -.16303400E+04, 0.81275600E+03, -.49094000E+03, 0.81517100E+03, 0.23968200E+03, -.31892500E+02, 0.38818100E+03, 0.63973700E+03, 0.74137500E+03, -.86769200E+02, 0.35447900E+03, -.56281700E+03, 0.28242100E+03, -.12037300E+03, 0.28140400E+03, 0.21109500E+03, -.12195000E+03, -.12847200E+03, -.12110600E+03, 0.16158700E+03, -.26897700E+02, -.22585700E+02, -.18789700E+04, 0.93725200E+03, 0.67420100E+03, 0.93947300E+03, 0.20345000E+03, -.31626400E+02, -.11034100E+03, 0.11464200E+03, 0.35225500E+03, 0.35229900E+02, 0.55579700E+03, -.36909800E+01, 0.10034100E+02, -.28725800E+03, 0.18581500E+01, -.11802200E+03, 0.15266300E+03, -.49587800E+03, -.47668000E+03, -.21075100E+03, 0.19784500E+03, 0.20476300E+02, 0.67722700E+03, -.33886000E+03, -.36265900E+03, -.33863500E+03, -.28347700E+03, -.28701500E+03, 0.51619400E+03, 0.21822700E+03, 0.24536500E+03, -.23003100E+03, 0.40384700E+02, 0.32317700E+03, -.15852000E+03, 0.11045700E+04, -.16158000E+03, -.31610000E+03, -.24014600E+03, 0.15243300E+03, -.71418900E+03, -.96491700E+02, -.60956500E+02, 0.16105400E+03, 0.29265500E+01, 0.28449700E+01, -.35466400E+02, -.20696400E+02, 0.86819700E+02, -.91161000E+01, -.33724900E+01, 0.74675500E+02, 0.13609100E+03, -.30781200E+02, -.13770600E+03, -.27736900E+02, -.39133200E+02, 0.24723900E+03, -.76533400E+02, -.96067600E+01, -.50362500E+02, 0.35598800E+01, 0.58305000E+01, -.18128700E+03, -.33595800E+02, 0.82184800E+02, 0.93028300E+02, -.82776700E+02, -.12625400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25620100E+01, -.37234700E+00, -.12771000E+01, -.21077600E+00, -.43017200E+00, -.26335000E+00, 0.47293500E+00, -.52638100E-01, 0.82872700E-01, -.70735300E+00, 0.21244400E+00, -.10753900E+01, -.96503700E+00, 0.10307300E+01, -.11233000E+00, 0.14179600E+00, -.35174500E+00, -.10141400E+00, 0.35410000E+00, -.48940700E+00, 0.73408000E-01, 0.46524700E-03, -.25910100E+00, -.74485600E+00, -.12935700E+00, -.16935000E+00, -.20764500E+00, 0.15584200E+01, 0.86086600E+00, -.85760200E-01, -.11253400E+00, 0.18117100E+00, 0.20969300E+00, -.46082900E+00, 0.57482000E-01, -.43803000E+00, 0.22712800E-01, -.90544300E-01, 0.28823100E+00, 0.80592100E+00, 0.65087800E-01, -.60024700E-01, 0.14485700E+01, -.23736700E-01, -.33806000E+00, 0.95354600E-01, 0.19579600E+00, -.30222900E+00, -.37895700E+00, -.82132200E-01, 0.47822000E+00, 0.30734600E-01, -.43283400E+00, -.11539800E+01, 0.89680800E-01, 0.92126900E+00, 0.13611900E+00, -.40546500E+00, 0.52320400E-02, 0.10522600E+01, -.13740300E+01, -.17813900E+00, -.78046700E-01, -.50923000E+00, -.65544600E+00, 0.33536300E+00, 0.41551100E-01, -.29323400E+00, 0.40318800E-01, -.39964300E-02, 0.41422000E-01, 0.11014800E+00, 0.60170300E+00, 0.50074400E+03, 0.78794900E+03, -.80978400E+02, 0.13254200E+03, 0.56898200E+04, -.27765900E+04, -.93442200E+03, -.28449500E+04, -.10450000E+03, 0.47449800E+03, -.14770200E+04, -.14937800E+03, -.20231900E+04, 0.63655400E+03, -.20614100E+04, 0.15646000E+04, -.79034700E+03, -.20166000E+02, -.78230400E+03, 0.44321700E+02, -.59657800E+01, -.24993500E+03, 0.95904500E+03, -.45545800E+03, 0.21049700E+02, -.59715000E+03, 0.22496800E+04, -.11339900E+04, 0.38434700E+03, -.11248400E+04, -.12776300E+04, -.99351000E+03, 0.11908200E+04, 0.10146800E+04, 0.68345400E+03, -.99964200E+03, -.18715600E+03, -.25213500E+04, 0.12598200E+04, 0.70966300E+03, 0.12606700E+04, -.40725400E+02, 0.88371500E+03, -.82724400E+03, -.94311700E+03, 0.30281100E+03, 0.10496400E+04, 0.31987900E+03, -.10173500E+04, 0.50862300E+03, 0.13408900E+04, 0.50868500E+03, 0.20100500E+03, -.41713200E+03, 0.63864300E+03, 0.39496100E+03, 0.78056700E+01, -.57562100E+03, 0.14666700E+04, -.49224000E+04, 0.24256700E+04, 0.11379100E+04, 0.24612200E+04, 0.30444300E+03, -.12343800E+03, 0.10200200E+04, -.11639200E+03, 0.15567500E+04, -.29603200E+03, 0.18698700E+04, 0.67435600E+03, -.33446900E+03, -.60686700E+03, -.33717700E+03, 0.74161000E+03, 0.25945400E+03, 0.22602700E+03, 0.12426400E+04, -.16760100E+03, 0.21426500E+03, -.69134100E+03, -.94325800E+03, 0.46567300E+03, 0.97850300E+03, 0.47161600E+03, -.52551900E+03, -.54065200E+03, 0.69878300E+03, 0.40802400E+03, 0.46113500E+03, -.64632000E+03, 0.69175000E+03, -.39820100E+04, 0.19837500E+04, 0.80648800E+03, 0.19911300E+04, 0.52598900E+03, -.10858500E+03, 0.75701900E+03, -.13843600E+03, 0.17103600E+04, 0.46389500E+02, 0.16676500E+04, -.34354300E+03, 0.17823100E+03, -.10023900E+04, 0.17178800E+03, 0.32730200E+03, -.31434700E+03, 0.33195200E+03, -.32321200E+02, 0.43346800E+03, -.92338300E+02, -.70979300E+02, -.31038000E+04, 0.15594400E+04, 0.29984200E+03, 0.15519100E+04, 0.10295500E+04, 0.18995000E+04, -.10533300E+04, -.13286600E+04, 0.23966500E+03, 0.19069500E+04, 0.88973700E+03, 0.11723100E+04, -.58571300E+03, -.10231800E+03, -.58615800E+03, 0.57530600E+02, 0.83410600E+03, -.14363400E+04, -.20807400E+04, -.50422000E+03, 0.80356300E+03, -.72488800E+03, -.10666100E+04, 0.52845500E+03, 0.79751900E+03, 0.53330200E+03, -.25158100E+03, -.24601500E+03, 0.47740800E+03, -.41310600E+03, 0.55421700E+03, -.19268100E+03, 0.21507300E+03, -.12627300E+04, 0.63041200E+03, -.72696000E+03, 0.63136100E+03, 0.29180000E+03, -.24062100E+02, 0.86307000E+03, 0.80424000E+02, 0.19475500E+04, 0.17200700E+03, -.85920000E+03, 0.35841800E+04, -.17540200E+04, -.69391800E+03, -.17920600E+04, -.59064100E+03, -.62013400E+03, -.11610700E+03, -.43182800E+03, -.16060300E+04, -.41562900E+03, -.10850700E+04, -.37319300E+04, 0.18718800E+04, 0.46693900E+03, 0.18659400E+04, 0.15212600E+04, 0.16030600E+04, -.14522300E+04, -.15636300E+04, -.84442600E+03, 0.15084000E+04, 0.10839600E+04, 0.35789800E+04, -.17897700E+04, -.13291600E+04, -.17894800E+04, -.30144100E+03, 0.30843600E+02, -.25398900E+03, 0.18987800E+04, -.18233100E+04, 0.10871200E+03, -.16457600E+04, -.39953700E+03, 0.19835000E+03, -.27681800E+02, 0.14079600E+03, 0.19207900E+03, 0.23151900E+03, -.24485400E+03, 0.22395000E+03, 0.50710300E+03, 0.25388100E+02, 0.10755900E+03, -.93618700E+02, -.66727900E+02, 0.40254300E+03, 0.26162400E+03, 0.16244400E+03, 0.84662000E+02, -.25285000E+03, -.93108400E+02, 0.44354400E+03, -.25807000E+03, 0.27801000E+02, -.70015100E+02, 0.10428800E+03, 0.10482200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34751700E+01, 0.22196200E+00, -.11393000E+01, 0.34850900E+01, 0.31312400E+01, -.18486400E+01, 0.97648000E-01, 0.14581300E+00, -.55823300E+00, 0.88480400E+00, -.10528400E+00, 0.20449400E+00, 0.51457900E+00, -.77045700E+00, -.45623600E+00, -.25467100E-01, -.60082300E+00, -.13990700E+01, 0.31773300E+00, -.89263500E+00, -.13247800E+01, -.43077700E+00, -.21646900E+00, 0.80035400E+00, 0.29512600E+00, 0.10029500E+01, 0.10073200E+01, 0.61695100E+00, -.73769300E+00, 0.67677900E+00, -.10849000E-02, 0.20997700E+00, 0.53693400E+00, -.15002300E+00, 0.14045800E+00, 0.24653300E+00, 0.37333500E-01, -.13429900E+00, 0.29512100E+00, -.11777600E+01, -.20603200E+00, -.39209900E+00, -.84074300E+00, 0.75141000E-01, 0.36124000E+00, -.62940300E-01, 0.10113900E+00, -.58013100E+00, -.38779200E-01, -.10289700E-01, -.40476700E+00, -.23329300E+00, -.97185000E-01, 0.56591100E+00, 0.90372700E-01, -.16608300E+00, -.12947800E+00, -.16550200E+00, -.42084800E-02, -.69866300E+00, 0.11363900E+01, 0.25337000E-01, 0.13812900E+00, 0.18277500E+00, -.35490300E+00, 0.41275100E+00, 0.74680100E-02, 0.10659600E+01, -.90349300E-02, 0.10528000E-01, -.95955200E-01, -.32425700E-01, -.72542400E+00, -.10941100E+01, 0.82560400E+03, -.35476900E+02, 0.18391000E+02, 0.35112000E+04, -.17964600E+04, 0.34140700E+04, -.17556000E+04, -.27510400E+03, -.24496700E+03, -.82235300E+03, -.10871400E+03, -.14445100E+04, -.29721400E+02, -.17008700E+04, 0.38996500E+04, -.19496000E+04, 0.74869800E+03, -.19498200E+04, -.50144100E+03, -.34733800E+03, -.10097200E+04, -.59001500E+03, -.15761200E+04, -.22590500E+02, -.14093100E+04, 0.28256600E+04, -.14123100E+04, -.24451900E+03, -.14128300E+04, -.11134600E+04, -.95348900E+03, 0.73899500E+03, 0.80743700E+03, 0.24721900E+03, -.10025200E+04, -.15077800E+04, -.33731600E+04, 0.16951400E+04, 0.96197500E+03, 0.16865900E+04, 0.95997100E+02, 0.11232200E+04, -.62969400E+03, -.11631700E+04, 0.55516800E+03, 0.12064300E+04, 0.15326100E+04, 0.35323600E+04, -.17703000E+04, -.30224600E+03, -.17661900E+04, -.55265900E+03, -.13596700E+04, 0.51384900E+03, 0.82019100E+03, -.73014800E+03, -.16322600E+04, -.13875900E+04, -.21740100E+04, 0.11177200E+04, -.18269800E+04, 0.10870000E+04, 0.20574700E+03, 0.31306600E+03, 0.35348200E+03, -.17349300E+03, 0.73388000E+03, 0.14536400E+03, 0.11069600E+04, 0.54790100E+04, -.27401200E+04, -.13683500E+03, -.27395000E+04, 0.24163700E+03, 0.43629400E+03, -.83945400E+03, 0.98052600E+03, -.20312200E+04, 0.31516400E+03, -.28794800E+04, -.11639200E+04, 0.58664000E+03, 0.11294100E+04, 0.58196600E+03, -.30358200E+03, -.87529700E+03, 0.12036800E+03, -.98729600E+03, 0.17963700E+03, -.63642700E+03, 0.37640100E+03, -.30206900E+04, 0.15180900E+04, 0.74456500E+03, 0.15100300E+04, 0.92967900E+03, 0.63989900E+03, 0.34371500E+03, -.88775100E+02, 0.87546300E+03, 0.54107800E+03, 0.11329300E+04, -.12004000E+04, 0.59953600E+03, -.20568900E+03, 0.60020500E+03, 0.16769100E+03, -.30162600E+03, 0.20641800E+03, 0.25060600E+03, 0.59320800E+03, -.14038300E+03, 0.83799000E+03, -.34846900E+04, 0.17450700E+04, -.68100900E+03, 0.17423200E+04, 0.74456700E+03, 0.21095600E+04, -.45030600E+03, -.14507100E+03, 0.79963400E+03, 0.20475700E+04, 0.20731800E+04, -.28379900E+04, 0.14205000E+04, -.69896600E+03, 0.14190000E+04, -.61687300E+03, 0.50379900E+03, 0.75237100E+02, -.56844200E+03, 0.93646300E+03, 0.48319500E+03, 0.13434500E+04, -.28632200E+04, 0.14363500E+04, 0.61751500E+03, 0.14316200E+04, -.41058800E+03, -.58855200E+03, 0.84686400E+03, -.37644900E+03, 0.10176000E+04, -.28450000E+03, 0.10763400E+04, -.35497500E+04, 0.17795600E+04, 0.13968400E+04, 0.17749000E+04, -.37465700E+03, 0.77395400E+03, 0.18788600E+03, 0.30601900E+03, 0.14115100E+04, 0.91464400E+03, 0.11010000E+04, 0.39783900E+04, -.19979900E+04, 0.44789800E+03, -.19891400E+04, -.10735000E+04, -.15047500E+04, 0.24747300E+03, 0.43873600E+03, -.16269700E+04, -.13649400E+04, -.16872600E+04, -.41446900E+04, 0.20734700E+04, 0.60593600E+03, 0.20723400E+04, 0.14532900E+04, 0.15161000E+04, -.64041600E+03, -.12669100E+04, -.15436000E+03, 0.15077600E+04, 0.22651700E+04, 0.64150500E+04, -.32139800E+04, 0.20607400E+03, -.32075400E+04, -.10717100E+04, -.33469100E+03, -.13206300E+04, -.43377400E+03, -.27500900E+04, 0.19400900E+03, -.21348400E+04, -.69557800E+03, 0.21666200E+03, -.15680600E+03, 0.31209400E+03, 0.29574100E+03, 0.24921200E+03, -.25922700E+03, 0.35325400E+03, 0.14157300E+03, -.78445500E+02, -.41749300E+03, -.11911900E+03, 0.28572800E+00, -.51207900E+02, 0.28900500E+03, 0.40989000E+03, -.14225600E+03, -.55434300E+03, -.54460200E+02, 0.13946100E+03, -.38097100E+03, 0.30298600E+03, 0.75316100E+02, -.33953600E+03, 0.17780800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19728000E+01, -.44554600E+00, -.33753300E+01, -.15855000E+01, -.15184200E+01, -.45527300E+00, 0.14731600E+01, 0.27690700E-01, 0.24089200E+00, -.65759100E+00, -.51198100E+00, -.16678200E+01, -.20443900E+01, 0.62848500E+00, 0.13159200E+00, 0.41278200E-02, 0.48578000E+00, 0.42979600E+00, -.14738100E+00, 0.17745300E+00, 0.33167100E+00, 0.85949900E-01, 0.20605100E+00, 0.69942400E-01, -.12616600E+00, -.22671200E+00, 0.35739700E+00, -.11082300E+01, 0.31811000E+00, -.30593400E+00, -.51227600E-01, -.33790100E+00, 0.29612500E+00, -.80795200E-01, 0.20393000E-01, 0.10016800E+01, -.34831700E-01, 0.12434600E+00, 0.98031700E+00, -.58216000E-01, 0.65515100E+00, -.43431300E+00, 0.33236900E-01, 0.78888800E-01, -.62651300E+00, -.29072700E-01, 0.36889600E+00, -.11595400E+00, 0.37060500E-01, 0.84969500E-01, 0.24600600E+00, -.34914100E+00, 0.60858100E-01, 0.51905300E+00, -.66738200E+00, -.21362800E+00, 0.12503800E-01, 0.52894100E-02, 0.11331300E-03, 0.49375900E+00, -.15996700E+00, 0.24719100E+00, 0.18496000E+00, 0.53751200E+00, 0.43636700E+00, 0.35906200E-01, 0.12795600E+00, 0.19509200E+00, -.12167400E+00, -.10294000E-02, 0.28870000E+00, 0.14655200E-01, 0.43913200E+00, -.30226800E+00, 0.10942700E+00, -.71423400E+02, 0.22559400E+03, -.17805400E+04, 0.88922300E+03, -.12900000E+04, 0.89026700E+03, 0.12752400E+03, 0.14714000E+04, 0.85657100E+02, 0.43303000E+03, 0.67687300E+03, 0.16305400E+04, 0.12696700E+04, -.17205400E+04, 0.84634500E+03, -.39466100E+03, 0.86026600E+03, 0.54035100E+03, 0.37399300E+03, 0.26075100E+03, 0.40540800E+03, 0.70285000E+03, 0.19624400E+03, 0.80076300E+03, 0.17114200E+04, -.86587700E+03, -.61594900E+03, -.85571000E+03, -.57489700E+03, -.52260600E+03, 0.42674000E+03, 0.74656900E+03, -.12361700E+02, -.72924200E+03, -.76630500E+03, -.14479300E+04, 0.74289200E+03, 0.65150600E+03, 0.72396100E+03, 0.26164400E+02, 0.93155100E+02, -.13749300E+03, -.39491600E+03, 0.26153800E+03, 0.46807000E+03, -.17448000E+03, -.30810500E+04, 0.15285700E+04, 0.12895700E+04, 0.15405300E+04, -.16155200E+03, -.58739100E+03, 0.14212600E+04, 0.92471900E+03, 0.10790200E+04, -.66127300E+03, 0.21180900E+04, 0.70374400E+03, -.33130400E+03, 0.89074100E+03, -.35187100E+03, -.23946600E+02, -.11244800E+04, 0.70574000E+02, -.32090500E+03, -.26221900E+03, -.13068800E+04, -.78977100E+03, -.20585100E+04, 0.10188700E+04, 0.24934600E+03, 0.10292500E+04, 0.23462800E+03, -.12882600E+03, 0.67213900E+03, 0.90235500E+03, 0.94912800E+03, -.11781100E+03, 0.12725200E+04, 0.26504100E+03, -.12222200E+03, 0.57779900E+03, -.13252200E+03, -.66101100E+03, 0.66297300E+03, 0.88723500E+02, 0.15792900E+03, -.12580300E+03, 0.33139900E+03, 0.34904400E+02, 0.11762100E+04, -.58472500E+03, -.50443000E+03, -.58849100E+03, -.57714000E+02, -.44784600E+03, -.87714700E+03, -.77804800E+03, -.44249400E+03, -.76145200E+02, -.36501400E+03, -.87598200E+03, 0.44236400E+03, -.41389400E+03, 0.43799000E+03, 0.33032200E+01, -.92590300E+02, -.24338200E+02, -.81881300E+03, -.33471000E+02, 0.36441200E+03, 0.43854800E+03, 0.15810700E+03, -.68816800E+02, 0.51829400E+03, -.79047600E+02, 0.34288900E+03, 0.31067700E+02, -.68917700E+03, -.85170500E+03, -.60110900E+03, 0.66097600E+03, -.32792700E+03, 0.10318500E+04, -.51522300E+03, 0.52911100E+02, -.51592800E+03, 0.52827100E+03, 0.59016700E+02, -.21980400E+03, -.30887300E+03, -.28897400E+03, 0.20836800E+03, -.90487700E+03, 0.14913100E+04, -.74380200E+03, 0.17743300E+02, -.74565700E+03, 0.92525300E+02, -.25075600E+03, -.46816700E+03, -.51189700E+03, -.54943500E+03, -.23057400E+03, -.99729900E+03, -.92384900E+03, 0.45345000E+03, -.13052900E+04, 0.46191700E+03, 0.22682200E+03, -.88655300E+03, -.13639500E+02, -.58654200E+03, 0.74530500E+03, -.70527500E+02, -.55167200E+03, -.81860800E+03, 0.44267300E+03, -.11092400E+04, 0.40929100E+03, -.51472900E+01, 0.42201200E+03, 0.45960500E+03, 0.33057800E+03, 0.52422100E+03, 0.31552300E+03, 0.35060000E+03, -.11749200E+04, 0.60556700E+03, 0.66090100E+03, 0.58746300E+03, 0.73153600E+03, 0.71389100E+03, -.57838500E+03, -.73151900E+03, -.41325300E+03, 0.75574100E+03, 0.46605800E+03, -.23834800E+04, 0.11840800E+04, -.35854800E+03, 0.11917400E+04, 0.51222000E+03, 0.70788300E+03, 0.83960700E+03, 0.11092500E+04, 0.65871400E+03, 0.42268900E+03, 0.75874000E+03, 0.26983200E+02, 0.83316200E+02, 0.67997700E+02, -.72370800E+02, -.11209600E+03, 0.60590600E+02, -.79576800E+02, -.12312000E+03, -.20556400E+03, -.75263700E+01, 0.25680400E+03, -.87138700E+01, -.13935700E+03, -.85867800E+02, 0.17523600E+03, -.57959500E+02, 0.15599800E+03, 0.17031000E+03, -.16283400E+03, 0.66422600E+02, -.15164300E+03, -.49706900E+01, -.82148200E+02, 0.21152700E+03, -.47321600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.81342200E+01, -.93109800E+00, -.19362900E+01, -.91581700E+00, -.41769100E+00, 0.22124300E+01, -.21480200E+01, -.22664700E+00, 0.28214100E+00, -.24100700E+01, -.23914700E+01, -.89553200E+00, -.28489900E+01, -.49073100E+01, 0.15977900E+01, -.27664400E+01, -.45687100E+01, -.20331700E+01, 0.58884300E+00, -.15274300E+01, 0.17391500E+01, 0.87589900E+00, -.51637500E+00, -.48386800E+01, -.22004200E+00, 0.72926900E+00, 0.14716800E+01, 0.15899800E+01, -.10350700E+01, 0.84743100E+00, 0.68768200E-01, 0.96509000E+00, 0.16151100E+01, 0.43729200E+00, 0.19881600E+00, -.77846700E+00, 0.56929700E-01, -.50468700E+00, 0.10416300E+01, -.40338400E+01, -.14762500E+00, -.15436300E+01, -.22051000E+01, 0.38912500E+00, -.22424000E+01, -.58548800E+00, -.17628400E+01, 0.12671800E+01, -.56839000E+00, 0.20948300E+00, 0.18268000E+01, -.20712500E+00, 0.20815100E-02, 0.26273100E+01, 0.11498200E+01, -.16703600E+01, -.44667300E+00, 0.41788400E+00, -.21246700E-02, -.25297900E+01, 0.68365200E+00, 0.67446000E+00, -.21408800E+00, 0.24416400E+00, -.54847100E+00, 0.79894300E+00, -.64106800E-01, 0.23094500E+01, 0.22199100E+00, 0.43192600E-03, 0.48251000E+00, 0.68112400E-01, 0.72869100E+00, -.25539500E+00, -.68737600E+00, -.89724700E+00, 0.11626200E+04, 0.52933700E+04, -.28163100E+04, -.30572100E+04, -.26466000E+04, -.17064300E+04, -.39658200E+03, -.22683300E+04, -.14573400E+04, -.16687500E+04, 0.11091000E+03, 0.35833400E+04, -.93476300E+03, 0.45169100E+03, -.83805700E+03, 0.46739000E+03, -.30609300E+02, -.87783100E+02, -.65649100E+03, -.46259900E+03, 0.33598000E+02, -.27224300E+01, 0.46659100E+03, 0.13867000E+04, -.69626200E+03, 0.84382900E+02, -.69336100E+03, -.81737500E+03, -.79314900E+03, 0.15950800E+04, -.33682900E+03, -.31130400E+03, -.92519500E+03, -.72761900E+03, -.47711400E+04, 0.24175800E+04, 0.34119400E+04, 0.23855700E+04, -.23580400E+02, 0.84323600E+03, -.13271200E+04, -.27599200E+04, 0.17973500E+03, 0.17201400E+04, -.14244600E+03, -.10865100E+04, 0.52654400E+03, 0.69683100E+03, 0.54323200E+03, -.22858800E+03, 0.39838600E+03, 0.94916500E+03, 0.15573400E+04, -.14836700E+04, -.52805500E+03, 0.39141200E+04, -.29824500E+04, 0.16205000E+04, 0.35199300E+04, 0.14911800E+04, 0.11696300E+04, 0.21745000E+03, 0.16441000E+04, 0.14009500E+04, 0.84040200E+03, -.24548400E+03, -.37179200E+04, 0.69951200E+04, -.35178400E+04, -.23313000E+04, -.34975600E+04, 0.34053900E+03, 0.24059400E+04, -.18676300E+04, 0.28120500E+04, -.15860400E+04, 0.16476300E+04, -.14843700E+04, -.40051900E+04, 0.20269500E+04, 0.13100300E+04, 0.20026200E+04, -.11980800E+04, -.21584800E+04, 0.10340600E+04, -.25745300E+04, 0.74645900E+03, -.19208500E+04, 0.18211300E+04, 0.12535800E+04, -.61155800E+03, 0.59638100E+03, -.62688000E+03, 0.11248500E+04, 0.36792500E+03, -.11142100E+04, -.73926100E+03, 0.61903300E+02, 0.73010000E+03, -.12502400E+04, -.19918200E+04, 0.99611800E+03, -.54672200E+03, 0.99587500E+03, 0.10984700E+03, -.13417100E+04, 0.10577400E+04, 0.43760100E+03, 0.16703300E+04, -.90551000E+03, 0.21717600E+04, -.34135200E+04, 0.17111300E+04, 0.23959500E+04, 0.17067300E+04, 0.16646800E+04, 0.23567900E+04, -.18695800E+04, -.23845600E+04, -.68654800E+03, 0.32037600E+04, 0.12633800E+04, -.54630300E+03, 0.27632600E+03, 0.11665900E+04, 0.27315300E+03, -.72947000E+03, -.10138900E+04, 0.10320200E+04, -.11515300E+04, -.23816800E+03, -.30766900E+03, -.16572700E+03, -.27037100E+04, 0.13627200E+04, 0.22125600E+04, 0.13518600E+04, -.28645200E+03, -.18289700E+04, 0.13820600E+04, -.12988100E+04, 0.32368300E+03, -.11275600E+04, 0.82870000E+03, -.39018000E+04, 0.19447400E+04, 0.28531800E+04, 0.19509100E+04, -.18237700E+03, -.12669600E+04, 0.14723900E+04, -.52493200E+03, 0.40321800E+04, -.92172900E+02, 0.85596600E+02, 0.25993500E+04, -.13141200E+04, -.13079500E+04, -.12997400E+04, -.15105400E+04, -.10457100E+04, 0.94330800E+03, 0.15212200E+04, -.72878400E+03, -.13697100E+04, -.12343100E+04, -.21139400E+04, 0.10716000E+04, -.34643600E+03, 0.10570200E+04, 0.11664200E+04, 0.14574600E+04, -.16822500E+04, -.33609800E+01, -.63427400E+03, 0.15159200E+04, 0.13369800E+04, -.75560700E+03, 0.35925400E+03, -.14300200E+04, 0.37779000E+03, -.42993200E+03, 0.97256800E+03, -.97300300E+03, 0.58533200E+03, -.87036200E+03, 0.91884100E+03, 0.17525500E+04, -.66231700E+03, 0.12738700E+03, 0.13334200E+03, 0.12839000E+03, 0.16612300E+03, 0.16836300E+03, -.15519800E+03, 0.10422800E+03, -.39060800E+03, -.10238500E+03, -.25035400E+03, -.16062300E+03, -.74144000E+03, -.25313400E+03, 0.77624400E+03, 0.25530600E+03, -.55647200E+02, -.44567600E+03, -.17212800E+03, 0.25021700E+03, -.80661200E+03, 0.51226000E+02, -.10492500E+03, -.54572000E+02, -.13150500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24029400E+01, 0.13285700E+00, 0.85116200E+00, -.15217100E+01, -.41882400E+00, 0.59494500E+00, -.21231200E+00, 0.17775500E+00, -.25663700E+00, 0.25543500E+00, -.57195700E+00, 0.76279400E+00, 0.10590500E+01, -.12500800E+00, -.68848100E-01, -.58997400E-01, 0.42013100E+00, -.64787800E+00, -.57888300E+00, 0.34576900E+00, -.38893500E+00, -.15936800E+00, -.80897200E-02, 0.53878100E+00, 0.41626900E-01, -.33021200E-01, -.11925000E+00, -.18856500E+01, 0.28358400E+00, 0.58223600E-01, -.16966400E+00, 0.16518700E+00, 0.45130300E+00, 0.31093200E+00, 0.42050600E-01, -.17233400E+00, 0.38383800E-01, -.54222400E-01, 0.21502300E+00, -.68482800E+00, 0.21042300E+00, 0.19650600E+00, -.24637300E+01, 0.40753200E-01, 0.73904400E+00, 0.21929600E-01, 0.80178700E+00, -.11183200E+01, 0.12927800E-02, 0.21689900E+00, -.79335700E+00, -.14184500E+00, 0.50643500E+00, 0.13922500E+01, 0.56323900E+00, -.38180900E+00, 0.21936400E-01, -.41148100E-01, 0.98523500E-03, -.81276800E+00, -.55130000E+00, -.37667700E+00, 0.15424500E+00, -.25084100E-01, 0.37749200E+00, 0.20925500E+00, -.43228500E-01, 0.47078500E+00, 0.76936000E-01, 0.17661200E-02, 0.37108800E+00, -.27158900E+00, -.99863400E+00, 0.33067500E+00, 0.69545800E+00, -.10207200E+01, -.12980100E+00, -.82182400E+04, 0.40741800E+04, -.59966000E+02, 0.41091000E+04, 0.19300100E+03, 0.12663700E+04, 0.19617600E+04, 0.90605300E+03, 0.31862900E+04, 0.15903600E+04, 0.40934000E+04, -.48325300E+04, 0.24181800E+04, -.84340400E+03, 0.24162500E+04, 0.94674600E+03, 0.94716700E+03, 0.46886000E+03, -.34908800E+03, 0.19923100E+04, 0.69092200E+03, 0.15656400E+04, 0.46783100E+03, -.23618900E+03, -.13189600E+04, -.23391800E+03, 0.21254800E+03, -.26996900E+02, -.35774900E+03, 0.89823600E+02, 0.63987600E+03, -.51822100E+03, 0.23601000E+03, 0.10059300E+04, -.48711600E+03, 0.29288600E+03, -.50297500E+03, -.33998100E+03, -.89472800E+03, 0.11128300E+04, 0.82209400E+03, -.50778200E+03, -.63354700E+03, -.16039500E+04, -.56684800E+04, 0.28217900E+04, 0.13773700E+04, 0.28342500E+04, 0.23534600E+03, 0.45424300E+03, 0.57471200E+03, 0.10686300E+03, 0.16820200E+04, 0.46320000E+03, 0.39006000E+04, 0.68733100E+04, -.33843500E+04, -.31056300E+03, -.34366500E+04, -.36411700E+03, -.13928300E+04, -.12319100E+04, -.18399100E+03, -.23987700E+04, -.16608200E+04, -.36437600E+04, -.23521400E+04, 0.11702600E+04, 0.29069800E+03, 0.11760700E+04, -.29945300E+03, -.15180500E+02, -.66764300E+02, -.71187400E+02, 0.99285900E+03, 0.15346100E+03, 0.22551700E+04, 0.89606100E+03, -.44097300E+03, -.91945200E+02, -.44803900E+03, -.49420500E+02, 0.13587500E+04, -.19117000E+03, 0.20674500E+03, -.76797500E+02, 0.68813000E+03, -.54339400E+03, 0.33903100E+04, -.16854600E+04, -.89561100E+03, -.16954800E+04, -.55769500E+03, -.86205500E+03, -.14724000E+04, -.13688500E+04, -.18171400E+04, -.31257400E+03, -.17442000E+04, -.76640300E+03, 0.38276800E+03, 0.74132900E+02, 0.38320200E+03, -.15580600E+03, 0.19916000E+03, 0.42456000E+02, -.78284000E+03, -.16994300E+03, 0.78647600E+03, 0.34867000E+03, 0.15330800E+04, -.76013900E+03, 0.17394100E+04, -.76651600E+03, -.53429600E+03, -.12372300E+04, 0.31481000E+03, -.75775000E+03, -.17354200E+04, -.30324500E+03, -.17868900E+04, 0.19489400E+04, -.98016800E+03, 0.38967600E+03, -.97447000E+03, 0.90423000E+03, -.24328400E+03, 0.88736900E+03, 0.14202300E+04, -.53705000E+03, -.17528700E+03, -.80822100E+03, 0.36190800E+04, -.18056100E+04, -.81242700E+03, -.18095500E+04, 0.11472100E+03, -.25806300E+03, -.90720300E+03, -.44894900E+03, -.11012300E+04, -.39261000E+03, -.14451300E+04, 0.23820600E+04, -.12078100E+04, -.25701700E+04, -.11910600E+04, -.11198600E+04, -.26240300E+04, 0.12556900E+04, 0.51013200E+03, 0.24207900E+02, -.17077300E+04, -.46378200E+03, -.25628400E+04, 0.13191800E+04, -.31484100E+03, 0.12813700E+04, 0.49198600E+03, 0.95833200E+03, 0.50723000E+03, 0.95989600E+03, 0.12973300E+04, 0.71236500E+03, 0.13344300E+04, 0.19407500E+03, -.80336400E+02, 0.11549600E+04, -.97039400E+02, -.12143900E+03, 0.70650300E+02, 0.16377300E+02, -.11622100E+03, -.10402800E+04, 0.41634000E+03, -.77593400E+03, -.62661200E+04, 0.31340800E+04, -.76229800E+03, 0.31330700E+04, 0.94057400E+03, 0.18183100E+04, 0.83120400E+03, 0.20818500E+03, 0.24688600E+04, 0.12960800E+04, 0.19565200E+04, 0.36036500E+03, -.15775500E+03, 0.22044400E+03, -.21207300E+03, -.34140900E+03, -.17722400E+03, 0.16168500E+03, -.35810600E+03, -.50071700E+03, 0.77745500E+02, 0.37203200E+03, -.29802700E+02, -.92620100E+02, -.26517400E+03, 0.19398500E+01, -.20868000E+03, 0.28486600E+03, 0.44746800E+03, 0.12980600E+02, -.25768300E+03, 0.16772400E+03, -.98099000E+02, -.15566300E+03, 0.42082400E+03, -.26084800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57681100E+01, 0.52624500E+00, -.12512100E+01, 0.17360100E+00, 0.24540700E+00, -.14161200E+01, 0.72447200E+00, -.82340100E-01, -.64892800E+00, 0.92236100E+00, 0.26913500E+00, -.15250000E+00, 0.78347800E-01, -.21896000E+01, -.92255400E-01, 0.68163500E+00, 0.74556600E-02, -.19842900E+01, 0.20858300E+00, -.98294400E-02, 0.27451900E+00, -.13633200E+00, 0.26020100E+00, 0.24395800E+01, 0.21715800E+00, 0.68913800E-01, 0.57493900E+00, 0.16724200E+01, -.10948800E+01, 0.52517000E+00, 0.12619700E+00, 0.95888400E+00, 0.29190400E-01, -.17208300E+01, 0.57210200E+00, -.11258600E+01, 0.44405000E-01, -.69631100E+00, -.42508900E+00, 0.13113600E+01, -.16776200E+00, 0.12158100E+00, 0.12191900E+01, -.68781400E-01, 0.65028500E+00, 0.24181300E+00, -.14217100E-01, -.60766400E-01, 0.42869800E+00, 0.15197500E-01, -.18983600E+00, -.33145400E+00, -.25699300E+00, -.56156500E+00, -.35352100E+00, 0.39965900E+00, 0.30119300E-01, -.24206100E+00, 0.88537400E-02, 0.13103000E+01, -.41500600E+00, -.38693200E+00, -.14951500E+00, -.80356500E-01, -.39543100E+00, -.38237700E+00, -.14087900E+00, -.20461700E+01, 0.99101400E-01, -.13157800E-01, -.73989900E+00, 0.28216600E+00, -.36394000E-01, 0.70106600E+00, -.10447200E+00, 0.23264000E+00, -.26339300E+00, 0.80344700E+00, -.34888800E+03, 0.16862500E+04, -.88820700E-01, 0.63724200E+02, -.10671200E+04, -.51195600E+03, -.11690900E+04, -.10228300E+03, -.15219000E+04, 0.36943800E+03, 0.22112000E+04, -.11537500E+04, 0.12193700E+04, -.11056100E+04, -.79045600E+03, -.79438800E+03, 0.39149900E+03, -.21972900E+03, -.12289300E+04, -.58997000E+03, -.51002400E+03, -.23629500E+04, 0.11791600E+04, 0.83337700E+03, 0.11814800E+04, 0.50811600E+03, 0.95232100E+03, -.65753800E+03, -.11346800E+04, -.14630300E+04, 0.13312800E+04, 0.19669200E+03, 0.12975500E+04, -.59100100E+03, -.13123700E+04, -.64877200E+03, 0.27000700E+03, 0.32614900E+03, -.34730700E+03, 0.16123900E+03, 0.12861000E+02, -.67269800E+02, 0.11515500E+04, 0.40834900E+04, -.20629400E+04, -.12775000E+04, -.20417200E+04, 0.28547400E+03, -.49712300E+02, -.10658000E+04, -.98357400E+03, -.14209600E+04, 0.13862900E+03, -.38158900E+04, -.13076400E+04, 0.86085900E+03, -.14376700E+04, 0.65386400E+03, 0.65408500E+02, 0.12851100E+04, 0.26541400E+03, 0.49682000E+03, 0.45176200E+03, 0.16037800E+04, 0.44171200E+03, 0.22410600E+03, -.16490100E+03, 0.76201300E+03, -.11205200E+03, 0.12212600E+03, -.86466500E+03, 0.40797100E+03, -.12116600E+04, -.49907600E+03, -.75627000E+03, -.77925800E+03, 0.11829000E+04, -.53101800E+03, -.70204500E+03, -.59147400E+03, 0.15433300E+03, -.46326000E+02, -.71512300E+03, -.15929100E+03, -.55658100E+03, 0.38223100E+03, -.49060000E+03, -.58819300E+03, 0.31315300E+03, -.11150700E+03, 0.29447500E+03, 0.49721200E+02, 0.40943000E+03, 0.75878700E+03, 0.81625500E+03, 0.23313500E+03, -.54972400E+02, 0.79932400E+03, 0.16233000E+04, -.81479800E+03, 0.27978300E+03, -.81161400E+03, -.26346100E+02, -.16201500E+03, -.25330000E+03, 0.11872700E+04, 0.26922500E+03, -.78441700E+03, -.66143100E+03, 0.17113400E+04, -.85511800E+03, -.22773200E+04, -.85564600E+03, -.52019400E+03, -.66533600E+03, 0.70171300E+03, 0.21582200E+04, 0.12179400E+04, -.14226500E+04, 0.89725800E+03, -.32822000E+04, 0.16594600E+04, -.39859500E+03, 0.16411000E+04, -.10849100E+04, -.10825200E+03, 0.11950000E+03, 0.38664100E+03, 0.13267900E+04, -.33122400E+03, 0.18175800E+04, -.16326400E+04, 0.83687800E+03, -.39224100E+03, 0.81631200E+03, -.32267200E+03, 0.42913200E+03, 0.25378600E+03, 0.72661400E+03, 0.29479800E+03, 0.45434600E+03, 0.12432600E+04, -.91290100E+03, 0.47555500E+03, 0.20831500E+04, 0.45644300E+03, 0.42256700E+03, 0.18082400E+04, -.12819700E+04, -.27038400E+03, -.11674500E+04, 0.89688400E+03, 0.11505900E+04, -.61492700E+03, 0.17374900E+03, 0.37437000E+03, 0.30752600E+03, -.27754000E+02, -.12903200E+03, -.29396100E+03, -.57354100E+03, -.56355800E+02, -.74008700E+02, -.54495300E+03, 0.30758800E+04, -.15342200E+04, -.12461600E+04, -.15379900E+04, -.10084900E+04, -.13317600E+04, 0.97237600E+03, 0.15020500E+04, 0.16702800E+04, -.15498700E+04, -.81001400E+02, 0.26996600E+04, -.13963300E+04, 0.19376500E+04, -.13498200E+04, -.39982500E+03, -.14229500E+04, 0.38291500E+03, -.66993200E+03, -.57212800E+03, -.10116400E+04, -.64009700E+03, 0.77351000E+02, 0.37442800E+02, -.24823100E+03, 0.11420700E+02, 0.13037500E+03, 0.19276300E+01, -.29904500E+02, 0.15063600E+03, 0.21948300E+02, -.96630900E+02, -.35298100E+03, 0.80005200E+02, 0.23103800E+03, 0.64764900E+01, -.33516000E+03, -.17856100E+02, -.12742100E+03, -.23581900E+03, 0.22542200E+02, -.96320700E+02, 0.50448000E+02, 0.33699800E+02, 0.13292200E+03, -.35110100E+03, 0.12133600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.59307700E+01, 0.61029000E+00, -.42678700E+01, -.17690100E+01, 0.21060400E+01, 0.44728900E+00, -.89423100E+00, 0.28578700E+00, 0.46150100E-01, -.21693900E+01, -.58583200E+00, -.23073000E+00, -.37456500E+00, -.32083700E+01, -.12124900E+00, -.82511600E-01, 0.10407500E+01, -.84082400E+00, -.11366200E+01, -.89281800E-01, 0.14475300E+01, -.26394300E-01, 0.41410300E+00, -.79117600E+00, 0.24115700E+00, 0.17603500E+00, 0.65491500E+00, 0.21755500E+01, -.46676900E+00, -.77889600E+00, 0.20985400E+00, 0.13158500E+00, -.40250400E+00, 0.59020600E-01, 0.12321000E+00, -.20092500E+01, 0.13277400E+00, -.50847600E+00, -.46822100E-01, 0.14005800E+00, -.62557400E+00, 0.67059400E+00, -.29931000E-01, -.28901300E+00, -.45809800E+00, -.17833400E+00, 0.86818700E+00, -.18901800E+01, -.89418300E+00, 0.92694000E-01, 0.33820400E+00, 0.37870900E+00, -.55259500E+00, -.29991800E+01, 0.47843100E+00, 0.12584100E+01, 0.97471300E-01, 0.60199500E+00, -.59019900E-03, 0.75320100E+00, -.42345500E+00, 0.22932700E-01, 0.10570600E+00, 0.88580100E+00, 0.60930900E+00, -.51785300E+00, 0.12235100E+00, -.24459100E+01, -.98081300E-01, 0.16842400E-02, -.20420600E+00, 0.96248000E-01, -.19334200E+01, -.14430800E+01, 0.95599400E+00, -.16729900E+00, 0.41892900E-01, 0.20658200E+00, -.15884800E+00, 0.79813500E+04, -.15267400E+00, 0.10474800E+04, 0.89600300E+02, 0.46526800E+03, 0.77809800E+02, -.78272600E+03, -.25827300E+03, -.85445500E+03, 0.34389000E+04, -.16757600E+04, 0.62703400E+03, -.17194800E+04, 0.25256000E+01, -.81299700E+03, -.17376300E+03, -.35356500E+03, -.10446900E+04, -.65213200E+03, -.15649200E+04, -.34544900E+04, 0.17413700E+04, 0.12189300E+04, 0.17272600E+04, 0.81367700E+03, 0.85352700E+03, -.64299000E+03, -.14050500E+04, -.13382900E+03, 0.92929800E+03, 0.14233400E+04, 0.16882800E+04, -.87032100E+03, -.18702300E+04, -.84415000E+03, -.24209100E+03, -.53802100E+03, 0.58505100E+03, 0.54033300E+03, -.28888500E+03, -.74521500E+03, -.50964900E+03, 0.13508900E+04, -.66648400E+03, -.18942700E+03, -.67540300E+03, 0.10791700E+04, 0.59093000E+03, -.13152900E+04, -.12467100E+04, -.81166600E+03, 0.89224600E+03, -.10401500E+04, -.40145700E+03, 0.22517700E+03, -.64999200E+04, 0.20080900E+03, -.48833900E+03, 0.24243700E+03, -.46972700E+03, -.88494400E+02, 0.72621900E+03, 0.47991000E+03, 0.10472200E+04, 0.77101200E+03, -.35614200E+03, 0.10322800E+04, -.38550500E+03, 0.18237700E+03, -.46775600E+03, -.33431800E+03, -.11240200E+04, -.63637100E+03, -.36491900E+03, -.78921600E+03, 0.21498900E+04, -.11069000E+04, -.73330200E+02, -.10750000E+04, 0.14865500E+04, 0.79259700E+03, -.61106800E+03, 0.63956500E+03, -.42710900E+03, 0.76575700E+03, -.11698600E+04, -.17840200E+04, 0.89545000E+03, -.51495700E+03, 0.89175100E+03, -.37758600E+03, -.31522200E+03, 0.13791800E+04, 0.10181300E+04, 0.17999900E+02, -.37727900E+03, 0.79017900E+03, 0.13229400E+04, -.67050200E+03, 0.15298000E+03, -.66141800E+03, -.16334900E+03, 0.36442300E+03, 0.19711000E+03, 0.94772000E+03, -.45285600E+03, 0.22863800E+03, -.39510000E+03, 0.10022200E+04, -.50300800E+03, -.20616400E+04, -.50104800E+03, -.14327400E+04, -.84661100E+03, 0.91679700E+03, 0.10123400E+04, 0.30989400E+03, -.11288400E+04, -.14858900E+02, -.20124300E+03, 0.85844000E+02, -.14796400E+04, 0.10061800E+03, 0.18378100E+03, 0.10474800E+04, -.72985300E+03, 0.84441400E+03, 0.81926300E+02, 0.62032700E+03, -.16306300E+03, -.54995200E+02, 0.24534000E+02, -.12102000E+04, 0.27477700E+02, 0.11837200E+03, 0.32682700E+03, -.55391400E+02, 0.63327400E+03, 0.22867000E+03, 0.16618100E+03, -.73820800E+02, -.16378300E+04, 0.81906800E+03, -.28910000E+03, 0.81886900E+03, -.50998900E+03, -.27067700E+03, 0.12147500E+04, 0.81885800E+03, 0.36139200E+02, -.74985300E+03, 0.71995900E+03, 0.15106600E+04, -.71417300E+03, 0.38737500E+04, -.75529000E+03, 0.12104600E+04, 0.83878400E+03, -.10833700E+04, -.53966000E+03, -.12434500E+04, 0.90682100E+03, -.80727800E+03, 0.35251000E+04, -.17794300E+04, -.14971000E+04, -.17626300E+04, -.13408900E+04, -.12361100E+04, 0.45164600E+03, 0.10132100E+04, 0.46714800E+03, -.11943400E+04, -.92735300E+03, 0.36183700E+04, -.17798600E+04, 0.89608600E+03, -.18091500E+04, -.79006600E+03, -.13902900E+04, -.67319700E+03, -.21451600E+04, -.23460700E+03, -.11983200E+04, -.11144400E+04, 0.15201700E+03, -.10833600E+03, 0.29514300E+02, 0.71948900E+00, -.48287600E+02, -.15480500E+03, 0.16332800E+03, -.40413900E+02, 0.10364700E+04, 0.41002000E+02, -.13257800E+03, -.13882600E+03, 0.18545200E+03, 0.76769500E+03, -.43976200E+03, 0.15412600E+02, -.12312300E+03, 0.46929200E+02, 0.18712000E+03, -.12451800E+03, 0.35175400E+03, 0.50619100E+02, -.23903400E+03, -.93013600E+02, 0.21297200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11660900E+02, -.11920200E+01, -.18721600E+00, 0.19274500E+01, 0.21066900E+01, 0.15129700E+01, -.19528000E+01, -.34612800E-01, 0.49481600E+00, -.19684300E+01, -.60171000E-01, -.11012100E+01, -.12935100E+01, 0.25681700E+01, 0.19134200E+01, -.26235700E+01, -.20298400E+01, 0.10240000E+01, 0.24439200E+01, -.20206600E+01, -.79844500E+00, 0.58551500E+00, -.13510400E+01, -.52168900E+01, -.47803200E+00, -.14296100E+01, 0.32293300E+00, 0.29790300E+00, -.68938900E+00, 0.25809700E+00, 0.24422600E+00, -.12749600E+01, 0.21247700E+00, 0.12323500E+01, -.85697900E-01, -.48635000E+00, -.36017400E+00, -.18253700E+00, 0.74711100E+00, -.25546700E+01, 0.83547000E-01, -.39322700E+00, -.69606300E+01, 0.47616300E+00, -.29332500E+00, -.51296100E+00, -.62351100E+00, 0.19735100E+01, 0.33543900E+00, -.21486700E+00, 0.19765600E+01, -.13647100E+01, 0.17923300E+00, 0.15959200E+01, -.38808000E+00, -.32891800E+01, -.69096700E+00, 0.65638700E+00, -.90809400E-01, -.29816300E+01, 0.36716000E+01, 0.11151800E+01, 0.10132200E+00, 0.11912300E+01, 0.13143300E+01, 0.20471200E+01, -.56795900E+00, -.13398200E+01, 0.17309300E+00, 0.44269200E+00, -.49787000E+00, 0.39445700E-01, 0.61172400E+00, 0.21331100E+00, -.11338700E+01, -.27376300E+01, 0.66162600E+00, -.16194500E+00, -.30270000E+00, -.12014400E+01, -.35885800E+01, 0.10814800E+04, 0.62010100E+03, 0.21233300E+04, 0.38357100E+04, 0.10946200E+04, -.65717000E+02, -.24290800E+04, -.43291400E+03, 0.21272400E+03, -.57989900E+03, 0.21689300E+03, 0.15549900E+04, 0.79651900E+03, 0.13240600E+04, 0.16087700E+04, 0.60722400E+03, 0.80488300E+02, -.48416700E+03, -.66284700E+03, 0.32354600E+03, -.86092600E+03, 0.33214100E+03, 0.92573900E+03, -.57457000E+03, -.31863200E+03, 0.99205100E+02, -.11366200E+04, -.28957500E+03, -.24457600E+04, 0.18722800E+04, -.94252300E+03, -.34203600E+04, -.93535600E+03, 0.16896100E+04, -.49246200E+03, 0.20469500E+03, 0.10918800E+04, -.27208500E+03, -.36380700E+03, 0.34619700E+03, -.54938700E+04, 0.27463800E+04, 0.28357900E+04, 0.27469700E+04, 0.44932200E+03, -.62541500E+03, 0.16044900E+04, -.94193600E+03, 0.26608000E+04, -.12861600E+03, 0.55912800E+03, -.27698400E+04, 0.14113600E+04, -.71426800E+03, 0.13872900E+04, -.12854700E+03, 0.12601900E+03, -.14918500E+04, -.34477000E+04, 0.11943300E+02, 0.52878900E+03, 0.32088400E+04, -.90149000E+04, 0.45096000E+04, 0.23307300E+04, 0.45068900E+04, -.10808000E+04, -.29246400E+04, 0.26353100E+04, -.20443200E+04, 0.32521500E+04, -.25239000E+04, 0.48368800E+04, 0.68457700E+04, -.34287000E+04, -.23384700E+03, -.34219800E+04, 0.23339500E+04, 0.48488700E+04, -.21346100E+04, 0.20748900E+04, -.23323900E+04, 0.38807500E+04, -.44819000E+04, 0.22870600E+04, -.11514200E+04, -.29649500E+04, -.11469600E+04, -.17615400E+04, -.22122200E+04, -.74846600E+03, -.57743600E+03, -.11051400E+04, -.17669600E+04, 0.78134700E+03, 0.14704700E+04, -.73159900E+03, -.14104400E+04, -.73544100E+03, -.40574000E+03, 0.19640400E+04, -.15060300E+04, -.10397400E+04, -.14081700E+04, 0.17861600E+04, -.30628300E+02, 0.63925600E+04, -.31949000E+04, -.29691400E+04, -.31990100E+04, -.23856000E+04, -.33763800E+04, -.43606600E+03, 0.32303200E+03, -.15508400E+04, -.27349800E+04, -.71585600E+03, 0.17634800E+04, -.88200100E+03, -.82312400E+03, -.88162900E+03, 0.12352100E+04, 0.75325900E+03, -.17103700E+04, 0.52987000E+03, -.61791600E+03, 0.74017800E+03, -.16274300E+04, 0.55929100E+04, -.28024700E+04, -.21273600E+04, -.27957700E+04, 0.75943800E+03, 0.96632700E+03, -.21268000E+04, 0.66835200E+03, -.19506100E+04, 0.62815400E+03, -.28101700E+04, 0.34882900E+04, -.17556400E+04, -.10092500E+05, -.17397400E+04, 0.13083000E+04, 0.42893000E+03, -.31756400E+04, -.14646100E+04, -.40048600E+04, 0.58837000E+03, -.11270300E+04, -.34474700E+04, 0.17780000E+04, 0.15461800E+04, 0.17303200E+04, 0.20384100E+04, 0.24081000E+04, 0.35615900E+03, 0.17561300E+02, 0.14346900E+04, 0.18385500E+04, -.31516200E+03, 0.50971100E+04, -.25364300E+04, 0.12315700E+04, -.25499300E+04, -.20567000E+04, -.89126000E+03, 0.61822000E+03, 0.10574300E+04, 0.61332000E+03, -.10840500E+04, 0.19303700E+03, -.25425600E+04, 0.12762200E+04, -.26443500E+03, 0.12701600E+04, 0.17472800E+04, 0.82099300E+03, 0.30322200E+04, 0.17302700E+04, 0.20242800E+04, -.26777300E+02, -.83573200E+03, 0.98223100E+03, 0.45016800E+01, 0.51442600E+02, -.12079500E+03, -.47453500E+03, -.10854500E+03, 0.94597400E+02, -.43943400E+03, 0.28995300E+03, 0.85447900E+02, 0.48723900E+03, 0.38198000E+02, 0.50309200E+03, -.25719600E+02, -.37252200E+03, -.83747300E+02, 0.54254100E+03, 0.96152400E+03, -.38121500E+03, 0.27495700E+02, 0.33699300E+03, -.22704100E+02, -.42996600E+03, 0.20949600E+03, 0.38180800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22350400E+01, -.12530600E+00, 0.14072800E+01, -.79287200E-01, 0.98723600E-01, 0.58868000E+00, -.33865300E+00, 0.77074000E-02, 0.20505800E+00, -.20314100E+00, -.35929900E-01, 0.27264600E+00, 0.10633200E+00, 0.76586500E+00, -.43352100E+00, -.24074800E+00, -.20071100E+00, -.17572600E-01, 0.10317200E+00, -.11834300E+00, -.23273000E+00, -.74723200E-03, -.10388500E+00, -.15692700E+00, 0.28263100E-01, 0.25191400E+00, -.11286400E+00, 0.24007700E+00, 0.18706400E-01, 0.38760600E-01, 0.44334100E-02, 0.14108700E+00, -.11405000E-01, 0.23577500E+00, -.12975300E+00, -.14992100E-01, 0.16672800E-01, 0.35247200E-01, 0.27006100E+00, -.32161600E+00, 0.19467200E+00, 0.22016500E+00, -.20834300E+01, 0.15047200E+00, -.33869100E-01, -.26277000E-01, 0.16523800E+00, -.13034800E+00, -.19846300E+00, -.22634900E-01, 0.13866200E+00, 0.16304800E+00, 0.49091100E-01, -.10041600E+00, 0.42304100E+00, -.13397600E+00, -.46996000E-01, 0.58316200E-01, -.33495300E-02, -.45485500E+00, 0.22858200E+00, 0.10443600E+00, 0.11658000E+00, 0.84155500E-01, 0.11124500E+00, 0.54283200E+00, 0.87548700E-02, 0.83551300E+00, -.28238300E-01, 0.69527700E-02, 0.31231500E+00, -.27777600E+00, -.49654300E+00, -.36378600E-01, 0.15967400E+00, -.67736000E-01, 0.55317300E-01, 0.53089200E-01, -.32672000E+00, 0.21365100E+00, -.13612600E-01, -.40687800E+03, -.12247200E+03, -.28397700E+03, -.43529500E+03, 0.60925500E+02, -.17841600E+03, 0.57262200E+02, 0.10895800E+04, -.53199900E+03, 0.27422300E+03, -.54477400E+03, -.23089600E+03, -.24611400E+03, -.28535800E+03, -.20831200E+03, -.47292300E+03, -.16634600E+03, -.34530800E+03, 0.35366700E+03, -.16768100E+03, 0.13781100E+03, -.17682600E+03, 0.82243000E+01, 0.79008700E+02, 0.59735400E+01, 0.11772400E+03, -.17462400E+03, 0.11053700E+03, -.54788900E+03, -.52654900E+03, 0.25495000E+03, 0.19993200E+03, 0.26329200E+03, -.67422000E+02, 0.12203500E+03, -.11436800E+03, -.21021700E+03, 0.25965300E+03, 0.14281200E+03, 0.82846300E+03, 0.19606100E+04, -.97518900E+03, -.63112100E+03, -.98031900E+03, -.15633000E+03, -.40668200E+03, 0.21227800E+01, 0.45818200E+03, -.32052100E+03, -.48378900E+03, -.16933700E+04, 0.64256400E+03, -.33824200E+03, 0.17792700E+03, -.32127600E+03, 0.11816700E+03, -.20825200E+02, 0.17456600E+03, 0.39585100E+03, -.24882100E+03, 0.51011700E+02, -.37056900E+03, 0.19661100E+04, -.97657800E+03, 0.20028800E+02, -.98306200E+03, 0.58876800E+02, 0.89681600E+02, -.33497000E+03, 0.17794800E+03, -.68610900E+03, -.28147400E+02, -.12600600E+04, -.70106200E+03, 0.34682100E+03, 0.60426000E+02, 0.35056000E+03, -.19670200E+03, -.47618000E+03, -.13276400E+02, -.52351600E+03, 0.88645000E+02, -.26384700E+03, 0.43805400E+03, 0.46489000E+03, -.22916700E+03, 0.99537100E+02, -.23238100E+03, 0.12879400E+03, 0.37743800E+03, -.75134300E+02, 0.24377200E+03, -.33003200E+02, 0.24924600E+03, -.19375200E+03, -.21548700E+03, 0.10268700E+03, -.13178000E+03, 0.10772600E+03, 0.18285400E+03, -.56481100E+01, -.12530500E+03, 0.13166300E+03, 0.45119900E+02, -.92318900E+02, 0.14895300E+03, -.42684400E+03, 0.20662500E+03, -.52702300E+03, 0.21335900E+03, 0.37817900E+02, 0.23923400E+03, 0.98069500E+02, 0.35058600E+03, 0.44471300E+03, 0.16623900E+03, 0.77313100E+03, -.17337100E+04, 0.86584600E+03, -.10458400E+03, 0.86686000E+03, -.20573300E+03, -.82931300E+02, 0.52391100E+03, 0.12450000E+03, 0.61804700E+03, -.76221600E+01, 0.82444100E+03, -.11131400E+04, 0.55850200E+03, 0.37944800E+03, 0.55658600E+03, -.45903200E+02, -.37257700E+02, 0.28598000E+03, 0.26353300E+02, 0.31880900E+03, 0.69317600E+02, 0.50721000E+03, -.18862100E+04, 0.94954900E+03, 0.10278800E+04, 0.94318800E+03, 0.31203300E+03, 0.60199600E+03, -.23995700E+03, -.20712500E+03, 0.28235500E+03, 0.54325500E+03, 0.10505800E+04, 0.70582200E+03, -.38349900E+03, -.20713700E+03, -.35282000E+03, -.45442300E+03, -.34866900E+03, -.22945600E+02, 0.14710700E+02, -.22316900E+03, -.35705300E+03, -.60596600E+03, -.31281800E+03, 0.14539000E+03, -.16448100E+03, 0.15641400E+03, -.12015500E+03, -.69655800E+02, 0.19636700E+03, -.30490400E+02, 0.31533000E+03, -.95475300E+02, 0.51272800E+03, 0.13493500E+04, -.67055800E+03, 0.56219100E+03, -.67470600E+03, -.23777600E+03, -.37911100E+03, -.45465700E+03, -.46265000E+03, -.61306000E+03, -.23890000E+03, -.21502200E+03, -.13418000E+03, 0.47330400E+02, -.75953100E+02, 0.79666900E+02, 0.12770100E+03, 0.55710400E+02, -.59280900E+02, 0.13253500E+03, -.28000100E+03, -.25652800E+02, -.14243400E+03, 0.31643000E+02, -.32548800E+02, -.25632600E+03, 0.26676000E+02, 0.87861800E+02, -.94248500E+02, -.15639100E+03, -.27262200E+02, -.38239800E+02, -.96557000E+02, 0.72198500E+02, 0.67105100E+02, -.19187600E+03, 0.48440100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34601100E+01, 0.25631100E+00, -.17398000E+01, -.21429300E+00, -.11613600E+01, -.14479000E+01, 0.15784500E+01, -.10686000E-01, -.11428200E+00, -.11586400E+00, 0.34539300E-01, -.67028600E+00, -.72851000E+00, -.54847200E+00, 0.19814900E+00, 0.77132100E+00, -.57696000E+00, -.91083700E+00, -.45283400E+00, 0.13967600E+00, 0.14261900E+01, 0.72884400E-01, 0.70774000E-01, -.51456500E+00, 0.56002100E-01, -.58671000E-01, 0.87634100E+00, 0.25880700E+01, -.55211300E+00, 0.17675800E+00, 0.99313400E-01, 0.13241400E+00, 0.39379000E+00, 0.29503700E+00, 0.11324700E+00, -.33653400E+00, -.83270200E-02, -.26172400E+00, 0.23663800E+00, -.11081400E+01, 0.61160500E-02, -.21967000E+00, -.44008100E+00, -.51351000E-01, -.33633600E+00, -.32751900E-01, -.35539300E+00, 0.79820500E+00, -.73510700E+00, -.16153800E+00, -.13169500E+00, 0.40030600E+00, 0.18076300E+00, 0.13402600E+01, 0.12094200E+01, -.13283600E+01, -.89104100E-02, 0.64994900E-02, -.56295600E-02, -.23237600E+01, -.36200900E+00, -.12656600E-01, 0.32302800E-01, -.43993700E-01, 0.79411500E+00, 0.47224500E+00, -.67602700E-02, -.28548800E+00, 0.10356400E+00, 0.10984600E-01, 0.29793700E+00, 0.51816900E-02, 0.86308200E+00, -.15004300E+00, -.38330000E+00, -.43000800E+00, 0.36240300E+00, -.87051700E+00, -.43914800E+00, -.24654900E+00, -.20949100E-02, -.75510500E+00, 0.12044700E+04, 0.18739700E+03, 0.80342600E+03, 0.10999700E+03, 0.12552400E+04, -.43164300E+03, 0.11220300E+03, -.43252700E+02, -.33860600E+03, -.56083600E+02, 0.61462500E+03, 0.20136900E+03, 0.38080200E+03, 0.73943500E+03, 0.42302700E+03, -.48637400E+02, -.48612300E+03, -.21140700E+03, 0.11040600E+03, -.44299300E+02, 0.10571100E+03, 0.11962100E+03, -.21777800E+03, 0.46571900E+02, 0.66379300E+01, 0.38478000E+03, -.24172100E+03, 0.30297100E+02, 0.80771800E+03, -.41039400E+03, -.10213900E+04, -.40383900E+03, -.11419600E+00, -.51035200E+03, 0.23595600E+03, 0.41547300E+03, 0.15112700E+02, -.37398200E+03, -.20902300E+03, -.17337000E+04, 0.86720400E+03, 0.10395500E+04, 0.86683400E+03, 0.31074900E+03, 0.27491900E+03, 0.16915300E+03, -.87139000E+02, 0.44862600E+03, 0.35069400E+03, 0.38441300E+03, -.45187100E+03, 0.23269400E+03, -.10546200E+03, 0.22594000E+03, 0.71424800E+02, -.92394500E+03, 0.23889300E+02, -.50407000E+03, 0.13357500E+03, -.10139100E+04, 0.41445500E+03, -.14733200E+04, 0.74159100E+03, 0.35658800E+03, 0.73665500E+03, -.29402300E+03, -.55756700E+03, 0.31228000E+03, 0.24263600E+01, 0.50430600E+03, -.42850000E+03, 0.85078400E+03, 0.17827800E+04, -.89760600E+03, 0.22156200E+03, -.89136200E+03, 0.61226300E+03, 0.14156700E+04, -.39699700E+03, 0.62691400E+03, -.57225100E+03, 0.88139100E+03, -.81128400E+03, 0.46190100E+03, -.22945500E+03, -.89762400E+03, -.23113900E+03, -.64250900E+03, -.76778800E+03, 0.31700900E+02, 0.60644600E+02, 0.15971800E+02, -.44343700E+03, -.15911500E+03, 0.18655000E+03, -.96446800E+02, -.81746500E+03, -.93288400E+02, -.11607200E+03, 0.49637700E+03, -.13162700E+03, -.64419300E+02, -.31990800E+03, 0.53563800E+03, -.12485600E+03, 0.59936900E+03, -.30174300E+03, -.43052700E+03, -.29975000E+03, -.54438800E+03, -.77156300E+03, -.26069100E+02, -.49240500E+03, -.28061600E+03, -.43661400E+03, -.37616200E+03, 0.65840600E+02, -.38232600E+02, -.12690000E+03, -.32917200E+02, 0.70549900E+03, 0.40656200E+03, -.41696700E+03, -.30194600E+03, 0.22279900E+02, 0.41230800E+03, 0.86774500E+02, 0.15034200E+04, -.75246800E+03, -.37464700E+03, -.75169000E+03, 0.20151000E+03, 0.24582300E+03, -.41925300E+03, 0.37844100E+02, -.29090300E+03, 0.44848000E+02, -.59881100E+03, 0.94746900E+03, -.47874300E+03, -.32313900E+04, -.47365000E+03, 0.96736000E+02, -.43017000E+03, -.23613300E+02, 0.16649800E+03, -.24233100E+02, -.21313900E+03, -.16748300E+03, -.49741900E+03, 0.26178700E+03, 0.72488700E+03, 0.24881400E+03, 0.49500800E+03, 0.10151500E+04, -.15812900E+03, 0.79251900E+02, 0.83935800E+01, 0.86132500E+03, -.19286800E+02, 0.42847200E+03, -.21523700E+03, 0.29452900E+03, -.21423400E+03, -.36291100E+03, -.19092400E+03, 0.84781400E+02, -.88559400E+02, -.30030300E+03, -.17626000E+03, -.27776100E+03, -.94737600E+02, 0.58162200E+02, -.28125300E+03, 0.47336900E+02, 0.65963500E+03, 0.22866900E+03, 0.48333700E+03, 0.60665900E+03, 0.21018000E+03, -.17086100E+03, -.58856300E+03, 0.25703300E+03, -.30188400E+02, 0.13662400E+02, -.49393400E+02, -.93880500E+02, -.99996200E+01, -.69395600E+01, -.93175300E+02, -.19117900E+03, 0.98130100E+02, 0.20181400E+03, -.10697800E+02, -.13587700E-01, -.25800500E+03, -.19161100E+02, -.33882100E+02, 0.12117300E+03, 0.24402900E+03, -.49868600E+02, 0.35697300E+02, 0.13236900E+03, -.78798400E+02, -.11107000E+03, 0.16598200E+03, 0.16106600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35081400E+01, 0.26241800E+00, 0.30618300E+00, 0.20187000E+01, 0.23674000E+01, -.15219300E+01, -.37758500E+00, -.12643600E+00, -.16220200E+01, -.10645100E+00, -.75393200E+00, 0.24081900E+00, 0.39205800E-01, -.21651400E+01, -.79744600E-01, -.13550600E+00, 0.77988400E+00, -.21703000E+01, 0.72812900E+00, -.66998200E+00, -.10712100E+01, -.14397800E+00, 0.22864800E+00, 0.20419000E+01, 0.15703500E-01, 0.16667800E+00, -.10895600E+01, -.12285400E+01, -.86932100E+00, 0.13870200E+00, 0.76088700E-01, -.58026400E+00, -.17401700E+00, 0.74819000E+00, -.11252700E+00, 0.21968000E+00, -.54544800E-01, 0.32604700E-01, -.24597700E+00, 0.16379900E+01, 0.81616300E-01, 0.44352700E+00, -.18509300E+01, 0.17784200E+00, 0.11064900E+01, 0.14435900E+00, 0.53145100E+00, 0.60597300E-01, 0.40865600E+00, 0.52989300E-01, 0.29657400E+00, -.35644500E+00, 0.11148000E+00, 0.50750300E+00, -.87987700E+00, 0.57384000E+00, -.40337700E+00, 0.53836200E+00, 0.75368100E-02, 0.45775200E+00, 0.16062100E+01, 0.13683200E+01, 0.29451300E-01, -.49665300E-01, -.52106900E+00, 0.30791000E+00, -.66026300E-01, -.14822800E+01, 0.53187100E-01, 0.94207700E-03, -.91839400E-01, -.10592200E+00, -.37387400E+00, -.40361100E+00, 0.12828800E+01, -.62514500E+00, -.24691600E+00, 0.44316200E+00, -.17964300E+00, -.46287700E+00, 0.48507400E-01, -.12617500E+01, 0.45327100E+00, -.13285600E+04, -.21100400E+04, -.17820500E+03, -.55222700E+03, 0.10482900E+04, 0.30616500E+04, -.14840200E+04, 0.11998000E+04, -.15308600E+04, -.21953300E+03, 0.48548400E+00, -.62899700E+03, 0.68208700E+03, -.13101000E+04, -.57120500E+02, -.17942000E+04, -.72535000E+03, 0.38425400E+03, -.73282200E+02, 0.36266100E+03, 0.22701000E+02, -.36865700E+03, 0.19776200E+03, -.34714900E+03, -.80794800E+03, -.35916100E+02, -.25641600E+03, -.10218400E+04, 0.46660300E+03, -.40315400E+03, 0.51088700E+03, 0.12097500E+04, 0.14690900E+04, -.62221000E+03, 0.27653300E+03, 0.53054200E+01, 0.98154400E+03, 0.11789700E+04, 0.32289000E+04, -.15881300E+04, -.15684900E+03, -.16144200E+04, 0.67953200E+02, -.11502900E+04, -.20771200E+03, -.12377900E+04, -.66253700E+03, -.79552000E+03, -.25145300E+04, -.97756700E+03, 0.46895300E+03, -.54290500E+03, 0.48876500E+03, 0.64966900E+02, 0.43297000E+03, 0.72674900E+03, 0.12174200E+04, 0.48039300E+03, 0.82654800E+03, -.34249400E+03, -.41642300E+02, 0.64749200E+02, 0.13814300E+04, 0.20843300E+02, -.89475000E+02, -.14872700E+04, 0.40957300E+03, -.17346500E+04, -.22221800E+03, -.12507800E+04, -.17727700E+02, 0.10721100E+04, -.57140600E+03, -.38555000E+03, -.53613100E+03, 0.70748200E+03, 0.35054700E+03, -.55692500E+03, 0.74549600E+03, -.23345700E+03, 0.51320400E+03, -.14917100E+04, -.10247200E+04, 0.51491500E+03, 0.72167100E+03, 0.51208200E+03, 0.66003400E+03, 0.68958300E+03, -.34683000E+03, -.34803900E+03, -.21456900E+03, 0.34067200E+03, 0.20673700E+03, 0.18240200E+04, -.91787300E+03, -.75651300E+03, -.91195400E+03, 0.17026000E+03, 0.66756100E+03, -.42745900E+03, 0.79255600E+03, -.39893100E+03, 0.31499000E+02, -.39287600E+03, -.96703500E+03, 0.47256600E+03, -.13995700E+04, 0.48366500E+03, 0.45538400E+03, 0.12527000E+04, -.16160100E+03, 0.14632700E+04, 0.30863000E+03, 0.48991800E+03, 0.10625800E+04, -.10712300E+04, 0.53120600E+03, -.10116900E+04, 0.53560900E+03, -.80338700E+03, 0.69430900E+03, 0.93720600E+02, 0.13702500E+04, 0.36421100E+03, 0.53089000E+03, 0.77386300E+03, -.16484200E+03, 0.79959900E+02, -.56260500E+03, 0.82381700E+02, -.10084300E+03, 0.64848200E+03, -.16263400E+03, 0.74082800E+03, -.33152900E+03, 0.66562300E+03, 0.21158300E+03, -.21464500E+04, 0.10979800E+04, 0.16011200E+03, 0.10730300E+04, 0.98057900E+03, 0.25280700E+04, -.99572600E+03, 0.47857500E+02, -.11944000E+04, 0.15606300E+04, 0.11031500E+04, 0.59998300E+03, -.33206900E+03, -.10889000E+04, -.30017300E+03, -.80211600E+03, -.51402300E+03, -.49740600E+02, -.56552800E+03, 0.10939200E+03, -.49367200E+03, -.15872400E+03, 0.14272000E+04, -.74959500E+03, 0.10973300E+03, -.71362200E+03, -.48885800E+03, 0.34706000E+03, -.29358900E+03, 0.65315500E+03, 0.87616600E+03, 0.17455900E+03, 0.33517000E+03, 0.49503300E+04, -.24570300E+04, 0.63726100E+03, -.24751000E+04, -.74137200E+03, -.80024200E+03, -.12840300E+03, 0.11684300E+04, -.78888700E+03, -.87594000E+03, -.18147600E+04, -.14908200E+03, 0.23976000E+03, -.13603700E+03, 0.27535300E+03, 0.55691900E+03, 0.17165100E+03, -.18215500E+03, 0.56832200E+03, -.20426500E+03, -.57713900E+02, -.29604700E+03, -.22465300E+02, 0.59671600E+03, -.77972900E+02, -.26261700E+03, 0.28254500E+03, -.43806300E+02, -.23240500E+03, -.11872400E+03, 0.12459200E+03, -.93706100E+02, 0.37283900E+03, 0.47335800E+03, -.31456600E+03, 0.27183800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27324400E+01, -.28890700E+00, 0.93107500E-01, 0.14285600E+00, 0.24343700E+00, 0.74965100E+00, -.46978800E+00, 0.12282900E+00, 0.52675300E+00, -.35436300E+00, -.40247800E-01, 0.11707700E+00, -.40835000E-01, 0.16820300E+01, 0.77648500E+00, -.72699300E+00, -.26247900E+00, 0.10797500E+01, -.13586900E+00, -.38759500E+00, -.37645700E+00, 0.12402100E+00, -.39556300E+00, -.23064500E+01, -.39404700E-01, 0.17971900E-01, 0.19371600E+00, 0.66644100E+00, -.25003200E+00, 0.66523700E-01, 0.43250000E-01, -.24557800E-01, -.11634600E-01, 0.86785300E+00, -.19170600E+00, 0.19947500E+00, -.52633000E-01, 0.11860800E+00, 0.28796900E+00, -.52594600E+00, 0.28908500E+00, -.18258100E+00, -.12899300E+01, 0.11413600E+00, -.55503600E+00, -.18919300E+00, 0.75328300E-01, 0.38608000E+00, -.57771300E+00, 0.95584600E-01, 0.12024200E+00, -.39320000E+00, 0.93581600E-01, 0.12174100E+01, -.81382100E+00, -.64979500E+00, 0.17513500E-01, -.16549200E+00, 0.24701000E-03, 0.50052300E+00, 0.52751300E-01, -.14066700E+00, 0.12943600E-01, 0.26625800E+00, 0.20974100E+00, -.11142200E+00, -.99977200E-01, -.19573100E+01, 0.97552800E-01, -.14411600E-02, -.52785600E-01, -.10948700E+00, 0.84076700E-01, 0.22902800E+00, -.60528300E+00, 0.60078300E+00, -.23727700E+00, -.51324900E+00, 0.18125500E+00, -.25254600E+00, 0.10517000E-02, 0.84375500E+00, -.14203200E+00, 0.45488400E+00, -.15666600E+04, -.73238800E+03, 0.53014600E+03, 0.11634900E+04, -.61770900E+04, 0.30918200E+04, -.11693500E+04, 0.30885500E+04, 0.14288300E+04, 0.48467900E+03, 0.15161700E+04, 0.73371500E+03, 0.30867800E+04, 0.21644600E+03, 0.23865700E+04, -.16506200E+04, 0.81732500E+03, 0.30173100E+03, 0.82531000E+03, 0.14958300E+03, 0.50140000E+02, -.41370100E+03, -.10518600E+04, 0.11626000E+04, -.15342100E+03, 0.22346700E+04, 0.32657100E+04, -.16372600E+04, -.37336600E+03, -.16328500E+04, -.11008700E+04, -.96730900E+03, 0.68524500E+03, 0.38926500E+03, -.12107700E+04, -.77947600E+03, -.30127700E+04, -.80128700E+04, 0.40018100E+04, 0.17917500E+04, 0.40064300E+04, 0.13772900E+04, 0.23663700E+04, -.37276600E+03, -.53800900E+03, 0.36662100E+03, 0.21413700E+04, 0.61617200E+04, 0.87780200E+03, -.38360600E+03, -.54797000E+02, -.43889700E+03, 0.14397700E+03, -.29532200E+03, 0.30159500E+03, 0.20023100E+04, 0.50610400E+03, -.70826400E+03, -.15615400E+04, -.27743800E+04, 0.13904200E+04, -.74679700E+03, 0.13871900E+04, 0.69748200E+03, 0.72954900E+03, -.16171600E+03, 0.53872800E+03, 0.13416100E+04, 0.52268400E+03, 0.23612100E+04, 0.59464600E+01, -.16208900E+02, -.55121500E+03, -.29619900E+01, 0.37850700E+03, 0.47082500E+03, 0.38669600E+03, 0.28000400E+03, 0.51390500E+03, 0.57624500E+02, -.14478700E+03, 0.18454300E+04, -.93081900E+03, -.61086600E+03, -.92301500E+03, -.72712500E+03, -.11472200E+04, -.23183800E+03, -.68298900E+03, -.56298800E+03, -.69814900E+03, -.14085900E+04, 0.98859100E+02, -.44927100E+02, 0.33940500E+02, -.49441200E+02, -.17830300E+03, 0.24601300E+03, 0.64281600E+03, 0.22353300E+03, 0.28377800E+03, 0.50103000E+03, -.44266000E+03, 0.97012300E+03, -.47950900E+03, 0.27306400E+04, -.48507800E+03, -.79231100E+03, -.11238000E+04, 0.47064200E+03, -.15103000E+04, -.14219100E+04, -.66883400E+03, -.19199800E+04, 0.46579300E+04, -.23389400E+04, 0.76190900E+03, -.23289700E+04, 0.76931700E+03, -.61106500E+02, -.45351000E+03, -.35075300E+03, -.15175200E+04, -.14483100E+03, -.15833800E+04, 0.26322300E+04, -.13239700E+04, -.38188700E+03, -.13161100E+04, 0.18920100E+03, -.40824200E+03, -.51579100E+03, -.70994600E+03, -.52997700E+03, -.56481300E+03, -.83310500E+03, 0.57058000E+04, -.28799800E+04, -.26398000E+04, -.28528800E+04, -.13198200E+04, -.27728800E+04, 0.19396800E+04, 0.86612900E+03, 0.16574500E+04, -.24832600E+04, -.23729700E+04, -.78855700E+03, 0.49298500E+03, 0.11243500E+04, 0.39428900E+03, 0.11932500E+04, 0.15737600E+04, -.40953400E+03, 0.51723000E+03, -.35515200E+03, 0.15034400E+04, 0.94812700E+03, 0.68249700E+03, -.32533900E+03, 0.25593100E+03, -.34124200E+03, -.10474800E+03, -.29290100E+03, -.85251100E+02, 0.20421800E+03, -.20144800E+04, -.83495500E+01, -.17359200E+04, -.86194200E+04, 0.43251400E+04, -.13985700E+04, 0.43097100E+04, 0.15818200E+04, 0.14444700E+04, 0.15724000E+04, 0.13231100E+04, 0.30703700E+04, 0.82343700E+03, 0.32521300E+04, 0.44733200E+03, -.24187900E+03, 0.23126800E+03, -.31549700E+03, -.54400200E+03, -.15838400E+03, 0.17953300E+03, -.58699500E+03, 0.78715900E+03, 0.17887300E+03, 0.39795900E+03, -.63453800E+02, -.50205400E+03, 0.74198000E+03, -.24829200E+02, -.33721800E+03, 0.39003900E+03, 0.45610900E+03, 0.89124900E+02, 0.40155000E+02, 0.18267000E+03, -.58108100E+03, -.47668400E+03, 0.71933100E+03, -.28276300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11081000E+02, -.11060400E+01, -.74354400E-01, 0.10768900E+01, 0.10413200E+01, 0.13815600E+01, -.18585000E+01, -.16347700E+00, 0.20575900E+00, -.22959500E+01, -.16565800E+00, -.20231200E+01, -.19950300E+01, 0.16972700E+01, 0.17507100E+01, -.29726800E+01, -.34428700E+01, 0.71437900E+00, 0.18876400E+01, -.11776700E+01, -.73277100E+00, 0.59296200E+00, -.95305000E+00, -.40021000E+01, -.16696900E+00, 0.15765000E+00, 0.10447600E+00, 0.34546400E+01, 0.29530000E+00, 0.35429200E-01, 0.21020800E+00, 0.57189100E+00, -.48857800E+00, 0.34764100E+00, -.86003400E-01, -.38191900E+00, -.18818200E+00, -.45360000E+00, 0.28482700E+01, -.46942900E+01, 0.42895800E+00, -.15574400E+01, -.43758600E+01, 0.61228300E+00, -.26696500E+01, -.79461700E+00, -.35922500E+00, 0.29268700E+01, -.72927500E+00, -.27520700E+00, 0.25320000E+01, -.57967700E+00, 0.29995000E+00, 0.20862800E+01, -.12834800E+01, -.26613000E+01, -.59359900E+00, 0.49374200E+00, -.59629700E-02, -.86571800E+00, 0.19819000E+01, 0.11396400E+01, -.68143600E-02, 0.12525700E+01, 0.88581000E+00, 0.19181600E+01, -.18357700E+00, -.74540900E+00, 0.20503100E+00, 0.18197100E-01, -.10407200E+00, -.48252600E-01, 0.34805900E+01, 0.11868300E+01, -.15086800E+01, -.22398700E+01, 0.39903000E+00, 0.25430000E+00, 0.18963400E+00, -.16713000E+01, -.91819200E+00, -.51975900E+01, 0.40895500E+00, -.10157100E+01, -.17535400E+00, 0.11897100E+04, -.18990100E+04, -.15602800E+04, 0.45662100E+04, -.21578800E+04, 0.11434600E+04, -.22826300E+04, 0.10427000E+04, -.38793900E+02, 0.87085900E+03, 0.25418200E+04, -.11043600E+04, -.80192200E+03, -.25533100E+04, -.20666000E+04, 0.10879700E+04, -.25537900E+03, 0.10339900E+04, 0.14842300E+04, -.91416400E+03, -.44427900E+03, -.70026800E+03, -.33826100E+04, 0.20531200E+03, -.52236700E+04, 0.11936200E+04, -.72255700E+03, -.47099900E+04, -.59601400E+03, 0.28248800E+04, 0.13896800E+04, -.10456600E+04, 0.75431900E+03, -.11695800E+03, 0.10844300E+04, 0.42068000E+04, 0.69417800E+03, -.28438400E+03, 0.13260800E+04, -.34711100E+03, 0.10255400E+04, -.28406000E+04, 0.19013300E+04, -.12097600E+04, 0.14661900E+04, -.20842100E+04, -.69525900E+04, -.30743900E+04, 0.15117600E+04, -.18139700E+04, 0.15393400E+04, 0.66120000E+03, 0.10873200E+04, -.30413400E+03, -.75325500E+03, 0.25812300E+03, 0.23911900E+04, 0.25621600E+04, -.83242200E+04, 0.42664400E+04, 0.39737200E+04, 0.41615800E+04, -.10637300E+04, -.50722900E+04, 0.34535500E+04, -.40210900E+04, 0.31803100E+04, -.48875900E+04, 0.38664200E+04, 0.80453800E+04, -.41191400E+04, -.10783900E+04, -.40217700E+04, 0.35699600E+04, 0.51323600E+04, -.34500200E+04, 0.21179400E+04, -.28077700E+04, 0.48711700E+04, -.67594500E+04, 0.34902800E+04, -.17520100E+04, -.25165400E+04, -.17492800E+04, -.12466200E+04, -.11051700E+04, -.14947800E+04, -.34233300E+03, -.18175700E+04, -.14118600E+04, 0.43626800E+03, 0.40961700E+04, -.20709100E+04, -.24090600E+04, -.20483100E+04, 0.32445300E+03, 0.38092900E+04, -.29218500E+04, 0.45949500E+03, -.23450900E+04, 0.22536600E+04, -.22400700E+03, 0.73773600E+04, -.37303400E+04, -.64753200E+04, -.36914200E+04, -.30756200E+04, -.26387600E+04, -.38839800E+03, 0.32193400E+04, -.72251200E+03, -.31019700E+04, 0.28622300E+04, -.50533600E+03, 0.23345300E+03, -.23736800E+04, 0.25278200E+03, 0.49224200E+03, 0.13607100E+04, -.16336000E+04, 0.24670700E+04, 0.60616300E+02, 0.14065000E+04, -.31589400E+03, 0.41275600E+04, -.20777500E+04, -.24207000E+04, -.20630800E+04, 0.10817400E+04, 0.17277700E+04, -.23587200E+04, 0.16740700E+04, -.21838600E+04, 0.17198300E+04, -.21783200E+04, -.34558600E+04, 0.17605200E+04, -.87298600E+04, 0.17322500E+04, 0.39867400E+04, 0.56128600E+04, -.64564300E+04, -.33338800E+04, -.54374000E+04, 0.41745700E+04, 0.31671500E+04, -.29290500E+04, 0.14422500E+04, -.29686900E+03, 0.14709300E+04, 0.99501600E+03, 0.24220600E+04, -.11868300E+03, -.92297000E+03, 0.13346500E+04, 0.14567800E+04, -.22225600E+04, 0.92425300E+04, -.46978400E+04, 0.29342300E+03, -.46225100E+04, -.40712300E+04, -.15154000E+04, 0.13927000E+04, 0.26833500E+04, 0.27197200E+04, -.20601000E+04, 0.21196300E+04, 0.27663300E+04, -.13134700E+04, 0.18831000E+04, -.13843100E+04, 0.24262400E+03, -.10005100E+04, 0.35646800E+04, 0.23110700E+04, 0.15591900E+04, -.18895400E+04, -.12896600E+04, 0.87182300E+03, 0.38978600E+03, -.25395500E+03, 0.31056200E+03, 0.14603200E+03, 0.18341600E+03, -.18262900E+03, 0.21010700E+03, -.36819000E+03, -.12417600E+03, -.16241800E+03, 0.19669200E+03, 0.10348700E+04, -.63357400E+03, -.69847900E+03, 0.38351000E+03, 0.47086700E+03, 0.64142400E+03, -.82459900E+03, 0.21967000E+03, 0.18198900E+02, 0.36737700E+03, 0.96303400E+01, -.57727000E+03, 0.55108100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19999800E+01, -.16024300E+00, 0.45265900E+00, 0.30991100E+00, 0.95343200E+00, 0.10769700E+01, -.14473900E+01, -.25725800E-01, 0.33491100E-01, -.94768500E+00, 0.17773400E+00, 0.53261700E-01, 0.11505900E+00, 0.10861400E+01, 0.51058100E+00, -.12819300E+01, -.79456300E+00, 0.31894900E+00, 0.80238500E+00, -.14291500E+00, -.10807300E+01, 0.81983300E-01, -.28098700E+00, -.93988700E+00, 0.90501500E-01, 0.14089800E+00, 0.25513400E+00, 0.17884100E+01, 0.11271600E+00, -.82215400E-01, 0.69109000E-01, 0.58316500E+00, 0.33715900E-01, -.43200900E+00, 0.21468600E-01, -.88123500E-01, 0.18031000E-01, -.36501600E-01, 0.85006400E-01, -.69147300E+00, -.60067700E-01, -.24828000E+00, 0.10616900E+01, -.16620200E-02, -.73174900E+00, -.10203800E+00, -.41096200E+00, 0.23170900E+00, -.23375500E+00, -.10322900E+00, 0.32880100E+00, 0.19062600E+00, -.23136400E+00, 0.35601700E+00, 0.10442300E+01, -.76886200E+00, -.19205900E+00, 0.32038900E+00, -.12517000E-02, -.12007300E+01, 0.25358700E+00, 0.30545200E+00, 0.11740600E-01, 0.17440100E+00, 0.26402000E+00, 0.60988400E+00, 0.11898500E+00, 0.14566700E+01, -.11221300E-01, 0.33535900E-02, 0.13443000E+00, -.16903400E+00, -.54418500E-01, 0.25784800E+00, -.21009000E-01, -.45435300E+00, 0.10252500E+00, 0.30739500E+00, -.11415600E+00, -.83135000E-01, -.21576000E-03, -.41430100E+00, 0.28037800E+00, 0.82557800E-01, 0.60207400E-01, -.63633200E-01, -.41117500E+03, -.55189700E+03, 0.16465900E+04, -.83728300E+03, 0.56594300E+03, -.82325700E+03, -.39231700E+03, -.41089200E+03, -.64145000E+02, -.41924700E+02, -.73091600E+03, -.34539500E+03, -.46298900E+03, 0.23899900E+03, -.12270600E+03, 0.17952900E+03, -.11945200E+03, 0.15755200E+03, 0.13565800E+03, -.22754800E+03, 0.24182500E+03, -.55594600E+03, 0.35088100E+03, -.12808600E+04, -.46273000E+03, 0.23894700E+03, -.38834200E+03, 0.23142700E+03, 0.21192200E+03, 0.16297200E+03, -.14172500E+03, -.13156100E+03, 0.29364000E+03, 0.33688100E+02, 0.13535100E+04, 0.25610800E+04, -.12818500E+04, -.95550500E+03, -.12805500E+04, -.14090600E+03, -.69502600E+03, 0.10796800E+03, 0.26546500E+03, -.34055500E+02, -.55218600E+03, -.28316900E+04, -.10642600E+03, 0.36958800E+02, -.23394400E+03, 0.53351100E+02, -.31300700E+02, 0.16572800E+03, -.13188000E+03, -.21260000E+03, 0.29206700E+00, 0.49677200E+03, 0.59920300E+03, -.17304000E+03, 0.76872800E+02, 0.49678400E+03, 0.86484300E+02, -.25454500E+02, -.44890400E+03, 0.52267800E+03, -.25433100E+03, -.15528200E+02, -.51439900E+03, -.57855600E+03, 0.11846000E+03, -.48801300E+02, -.13409800E+03, -.59159600E+02, 0.51837500E+02, -.15341600E+03, -.29324800E+03, -.89177700E+02, -.15927900E+03, 0.23522200E+03, -.11483400E+03, 0.53183900E+02, -.28545000E+02, 0.11417200E+02, -.26833400E+02, 0.61818500E+02, 0.42298300E+03, 0.10507700E+03, 0.40992600E+03, -.38354200E+02, 0.96326600E+02, 0.47240600E+03, 0.35712700E+03, -.17822300E+03, 0.12417700E+03, -.17858200E+03, 0.12757400E+03, 0.21918400E+03, -.44596200E+03, -.54758700E+02, -.42065900E+03, 0.19200400E+01, 0.94880400E+02, 0.74592600E+03, -.37344400E+03, -.14317000E+04, -.37316900E+03, -.29887200E+03, -.28121900E+03, 0.17459300E+03, 0.94799400E+03, 0.59376800E+03, -.62845900E+03, 0.11037300E+04, -.14069400E+04, 0.70927700E+03, -.41548300E+03, 0.70348100E+03, -.10811800E+03, -.44993200E+02, -.98716100E+02, 0.24046000E+03, 0.62771600E+03, -.98815100E+02, 0.24012800E+03, -.10158500E+04, 0.50932800E+03, -.13340100E+01, 0.50797800E+03, 0.16044000E+03, 0.22392200E+03, -.67809900E+01, 0.33066700E+03, 0.30637600E+03, 0.26909200E+03, 0.24980700E+03, -.20427300E+04, 0.10276800E+04, 0.80473600E+03, 0.10216800E+04, 0.72960200E+03, 0.11764100E+04, -.11100200E+04, -.69269400E+03, -.80391800E+03, 0.77377000E+03, 0.85437600E+03, -.10114100E+02, -.21684100E+02, -.42739900E+03, 0.55194000E+01, -.13589900E+03, 0.69589500E+02, -.17868700E+03, -.47974400E+03, -.49538100E+02, 0.60264400E+02, -.63867300E+03, 0.54418700E+03, -.27068800E+03, -.20374900E+03, -.27217400E+03, -.35517300E+03, -.27158200E+03, 0.42641700E+03, 0.56698900E+02, 0.72191700E+03, -.43375700E+03, 0.99536800E+03, 0.14377400E+04, -.72868200E+03, 0.11670000E+04, -.71895900E+03, -.48483400E+03, -.84780700E+03, 0.17194500E+03, -.56733200E+03, -.43452100E+03, -.60216900E+03, -.23909800E+03, -.36487100E+02, 0.54702800E+02, -.90910600E+02, 0.72506100E+02, 0.10644000E+03, 0.19025800E+02, -.20234300E+02, 0.12381200E+03, -.12442100E+03, -.53351400E+02, -.14115100E+03, 0.72849600E+02, 0.14182800E+03, -.15502500E+03, -.98828500E+02, 0.59338900E+02, -.12119000E+03, -.33601700E+02, -.39981500E+02, -.80835200E+02, 0.11950200E+02, 0.10249200E+03, 0.76394900E+02, -.27058400E+03, 0.10015200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36856600E+01, -.57278900E+00, -.15153200E+00, -.49818500E+00, -.54346800E+00, 0.20020500E+00, 0.15899100E+00, 0.14729000E-01, 0.23546900E+00, -.55582700E+00, 0.52436100E+00, -.70396600E+00, -.26953900E+00, 0.11028700E+01, -.18807500E+00, 0.25459400E-02, -.48018400E+00, 0.19548500E+00, -.17473200E+00, 0.83008100E-01, 0.33373500E+00, -.40348200E-01, -.28507200E-01, -.87700700E+00, -.79109000E-01, -.12752500E+00, 0.23529900E-01, 0.21752400E+01, 0.10795300E+01, -.46586600E+00, -.53781900E-01, -.14346100E-01, -.66839200E+00, 0.15354900E+00, -.16670300E+00, 0.34691700E+00, -.20145000E-01, 0.82154200E-01, 0.97227700E+00, 0.63341700E+00, 0.71271900E+00, -.24613500E+00, -.99198100E+00, 0.25101300E+00, -.78795200E+00, 0.21682000E+00, 0.69649100E+00, 0.25317800E+00, -.49343200E+00, -.53852500E-01, -.23264100E+00, 0.43505200E+00, -.11302800E+00, -.64538500E+00, -.86759800E-01, -.29482900E+00, 0.19644200E-01, 0.45260500E+00, -.53161800E-02, -.39672500E+00, -.59920700E+00, -.38147300E+00, -.95880300E-01, -.48712200E-01, 0.10841300E+01, -.26386000E+00, 0.42623700E+00, 0.71861900E+00, -.18763400E+00, 0.89929900E-03, 0.36895200E+00, -.29589100E+00, 0.60783500E+00, 0.85580700E+00, -.56927400E+00, 0.90290200E+00, -.30634200E+00, -.80245600E+00, -.65151700E-01, -.12265700E+00, -.12153100E-01, 0.84075400E+00, 0.52039900E-01, -.19527200E+00, 0.41798300E+00, -.11226100E+00, 0.75208300E+00, 0.20728400E+04, -.11014400E+04, 0.58115300E+03, 0.10276500E+03, 0.55073500E+03, 0.91415300E+03, 0.81563500E+03, 0.82315900E+03, 0.11853900E+04, 0.88408100E+03, 0.39345600E+03, -.83616000E+03, -.63125200E+03, 0.32478500E+03, 0.16598500E+03, 0.31566300E+03, 0.39252200E+03, -.44811100E+03, -.15246900E+03, -.16548600E+03, 0.69146500E+03, -.47378200E+03, 0.37975000E+03, 0.13075600E+04, -.67564400E+03, -.15358300E+04, -.65374900E+03, 0.17656900E+03, -.60532500E+02, 0.49359700E+03, 0.92739100E+03, -.33748200E+03, -.17722900E+03, -.13276600E+04, -.18335700E+04, 0.92494500E+03, 0.89062000E+03, 0.91679800E+03, 0.33913700E+03, 0.45646100E+03, -.30374300E+03, -.12197900E+04, 0.12835000E+03, 0.73072800E+03, 0.17912500E+04, -.16148700E+03, 0.96103600E+02, -.32618600E+03, 0.80876300E+02, 0.72219300E+02, -.24887600E+02, 0.79332900E+02, 0.14878800E+03, 0.98705200E+02, -.41625000E+02, -.17258000E+04, -.18209100E+04, 0.93450600E+03, 0.17678400E+03, 0.91043000E+03, -.50754100E+03, -.63865600E+03, 0.36486600E+03, -.58991100E+03, 0.47336500E+03, -.32855500E+03, 0.23265400E+04, 0.16354600E+04, -.84051700E+03, 0.52629800E+03, -.81770200E+03, 0.12322200E+04, 0.16050600E+04, -.16358100E+03, 0.13635900E+04, -.22173400E+03, 0.88344500E+03, -.21527000E+04, -.13430900E+04, 0.67367000E+03, -.24339400E+03, 0.67148700E+03, -.28447900E+03, -.90254200E+03, 0.15381600E+02, -.91969300E+03, -.13432900E+02, -.54881300E+03, 0.35167500E+03, 0.11550200E+04, -.58002800E+03, -.99274500E+03, -.57750800E+03, -.26336500E+02, 0.96966900E+03, -.31838400E+03, 0.20599700E+02, -.77274600E+03, 0.88873900E+03, -.40574200E+03, 0.34517700E+03, -.17406000E+03, 0.59563900E+02, -.17270000E+03, -.58854400E+03, -.45305700E+03, 0.24154200E+02, -.63021300E+03, -.10298900E+04, -.32143000E+03, -.69630400E+03, 0.25112500E+04, -.12642900E+04, -.74939700E+03, -.12556200E+04, 0.48232700E+03, 0.82362600E+03, -.11595500E+04, 0.18055700E+03, -.70062200E+03, 0.58039300E+03, -.75908400E+03, 0.27841700E+04, -.13949500E+04, -.10120800E+04, -.13920600E+04, 0.46135600E+03, 0.62832300E+03, -.86167300E+03, 0.30457100E+03, -.61415700E+03, 0.21810700E+03, -.10503000E+04, 0.22826700E+04, -.11406700E+04, -.41835200E+04, -.11411400E+04, -.29260500E+03, -.43329500E+02, 0.55627000E+02, 0.92491100E+03, -.25776700E+03, -.34155400E+03, -.48378800E+03, -.10449900E+04, 0.55080600E+03, 0.58492500E+03, 0.52281300E+03, 0.67982100E+03, 0.74512500E+03, -.71136200E+02, 0.14994700E+03, 0.29946800E+03, 0.70056300E+03, 0.54639500E+03, 0.11784300E+04, -.59966600E+03, 0.37821100E+03, -.58929800E+03, -.62387300E+03, -.10197900E+03, 0.64558900E+02, 0.12982900E+03, -.75497500E+03, 0.54078300E+00, -.60651900E+03, 0.84231200E+02, -.23471100E+02, -.82978900E+03, -.42158200E+02, 0.77952200E+03, 0.10526200E+04, 0.12239100E+04, 0.21643600E+04, 0.56226300E+03, 0.39133900E+03, -.14334300E+04, 0.30935800E+03, 0.60970400E+00, 0.22894500E+02, -.22545600E+02, -.16231900E+03, -.39146900E+01, -.19257700E+02, -.17168000E+03, 0.23033300E+03, 0.14514300E+03, 0.23489900E+03, -.11104500E+03, 0.23259400E+03, 0.28558700E+03, -.41563800E+02, 0.43522900E+02, 0.27904700E+03, 0.35862900E+03, -.44758500E+02, 0.53042800E+02, 0.26734400E+03, -.49334700E+02, -.80461400E+02, 0.28916600E+03, -.38113200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28065400E+01, -.52504400E+00, -.27242000E+01, -.23736900E+01, -.23112800E+01, 0.99515000E+00, 0.25692200E-01, -.87037200E-01, 0.34983500E+00, -.10154900E+01, -.89803300E+00, -.59276400E+00, -.12655500E+01, -.17146700E+01, 0.47108000E+00, -.41041800E+00, -.10417000E+01, -.17746300E+00, -.66134400E+00, -.13284600E+00, 0.16345100E+01, 0.22072100E+00, 0.88049800E-01, -.14243100E+01, -.41134800E+00, 0.16903700E+00, -.28068300E+00, 0.17414500E+01, 0.85435800E+00, -.51968900E+00, 0.45677100E-01, 0.43606800E+00, 0.77809100E+00, 0.24811100E+00, 0.57867500E-01, -.65627100E+00, 0.27441100E-01, -.73947400E-01, -.31159100E+00, -.20606300E+00, -.19154400E+00, 0.21674600E-01, 0.24135900E+01, -.67470700E-01, -.76466100E+00, 0.16371100E+00, -.85974700E+00, 0.11649200E+01, -.55033600E+00, 0.38512800E-01, 0.54892900E+00, 0.18813000E+00, -.53649800E-01, 0.23419600E+00, 0.10887800E+01, -.10578800E+01, -.11406400E+00, 0.36254700E+00, -.17207600E-02, -.14225900E+01, 0.46055200E+00, 0.19733000E+00, -.21742300E+00, 0.28744000E-01, 0.73608900E-01, 0.26405900E+00, -.11960900E+00, 0.22350800E+01, 0.16597900E+00, 0.59795100E-03, 0.30901000E+00, -.80478300E-01, 0.72609300E+00, 0.54577600E+00, -.83216000E+00, -.84157600E+00, 0.67299700E-01, -.23676300E+00, -.36904700E+00, 0.16858800E+00, -.22532600E-01, 0.12536600E-01, 0.14739700E+00, 0.68337000E-01, -.18992600E+00, -.13742100E+00, -.46570100E+00, -.32345200E+00, -.13798200E+04, 0.70276300E+03, -.28802300E+03, 0.69001900E+03, 0.13978800E+03, -.32115100E+02, 0.34759600E+03, -.34319900E+01, 0.74000000E+03, -.20890500E+03, 0.99762200E+03, 0.29868800E+03, -.14609500E+03, 0.12011800E+03, -.14920700E+03, -.79773900E+02, -.29567500E+02, -.32132000E+03, -.21932100E+03, -.31992100E+03, -.50800900E+02, -.44728100E+03, 0.21619800E+03, -.11610200E+03, -.41082600E+02, -.10792800E+03, -.47498400E+03, -.22426800E+03, 0.18068100E+03, -.12680700E+02, 0.12112300E+03, -.81403700E+02, 0.55586600E+03, -.93701200E+03, 0.46980700E+03, -.25404300E+03, 0.46848200E+03, -.34595000E+02, -.24194900E+03, 0.71362300E+03, 0.99796200E+03, 0.36330900E+03, -.30725400E+03, -.18138300E+03, 0.23834200E+03, -.10568800E+03, -.12349900E+03, -.11875600E+03, 0.71612700E+01, -.83014500E+02, 0.39072700E+02, 0.82405000E+02, -.75433400E+02, -.79214000E+02, -.25456600E+03, -.77968200E+03, 0.39832600E+03, -.31839800E+02, 0.38972900E+03, 0.26351500E+03, 0.18273500E+03, 0.41749400E+03, 0.81577400E+03, 0.52221500E+03, -.56713000E+02, -.63406300E+02, 0.30467600E+03, -.16174700E+03, -.89692600E+02, -.15212000E+03, -.21413700E+03, 0.18991000E+03, -.33662400E+03, -.46041500E+03, -.17844300E+03, 0.35771700E+03, 0.88703000E+03, 0.11042900E+04, -.55183400E+03, -.20988600E+03, -.55310400E+03, -.19737000E+03, -.18165400E+03, -.46129500E+03, -.34584300E+03, -.36330600E+03, -.12016900E+03, -.32529700E+03, -.68639200E+03, 0.34018800E+03, 0.38045400E+03, 0.34312100E+03, 0.11309600E+03, 0.13102100E+03, -.10416600E+03, -.16205800E+03, 0.78724000E+02, 0.26740800E+03, -.62119300E+00, 0.72133600E+03, -.36364800E+03, 0.43772400E+03, -.36127300E+03, -.22711600E+03, -.49945300E+03, 0.13656400E+03, -.42139400E+02, -.18922700E+03, -.31966900E+03, 0.16618000E+03, 0.12495300E+04, -.62938500E+03, 0.17079400E+03, -.62474100E+03, 0.35247900E+03, -.22486000E+03, -.91249800E+02, 0.28262000E+03, -.35317800E+03, -.16115100E+03, -.51389000E+03, 0.31837800E+03, -.16033400E+03, -.31770100E+02, -.15903300E+03, 0.15590400E+03, -.29887200E+03, -.35375600E+03, -.42929300E+03, -.92301700E+02, -.21717500E+03, -.70139300E+02, -.82977400E+03, 0.40843500E+03, -.12060900E+03, 0.41581600E+03, 0.32756900E+02, -.21562800E+03, -.48279400E+03, -.49652300E+03, 0.57621200E+03, -.54270800E+02, 0.55239500E+03, -.98952100E+02, 0.72617600E+02, -.59948900E+03, 0.50794600E+02, 0.13036500E+03, 0.33371500E+03, 0.31192200E+02, 0.24967600E+03, 0.10252300E+03, 0.18826800E+03, -.54607600E+03, 0.19354600E+03, -.95651900E+02, -.56960600E+02, -.96993000E+02, 0.11325100E+03, -.14350300E+03, 0.39525100E+03, 0.19491800E+02, -.10981100E+03, -.14515400E+03, -.68757500E+02, -.31642200E+04, 0.15910300E+04, 0.13522400E+03, 0.15818500E+04, 0.17413900E+03, 0.28941500E+03, 0.87505400E+03, 0.70812100E+02, 0.10875000E+04, 0.60929400E+02, 0.15969400E+04, 0.83567700E+02, -.63078500E+01, -.27183200E+01, -.18790900E+02, -.15586900E+03, -.12582600E+01, 0.92963500E+01, -.16146800E+03, 0.12744800E+03, -.68875700E+02, -.20275200E+02, 0.90774000E+02, -.19045000E+03, 0.13622400E+03, 0.76556100E+02, -.65576900E+02, 0.12790600E+03, 0.45674600E+02, -.78634900E+02, -.30440500E+02, -.74355100E+02, -.10598800E+03, -.16262800E+03, 0.83346100E+02, -.13356900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31056400E+01, 0.33136000E+00, 0.78909700E+00, 0.13839700E+01, 0.11665900E+01, -.13579400E+01, 0.91303800E-01, -.14071900E+00, -.12130100E+01, -.20752100E+00, -.46609600E+00, -.40437900E-01, -.81622800E+00, -.16138900E+01, 0.11469500E+00, 0.35181500E+00, -.29614000E+00, -.17397400E+01, 0.11179400E+01, -.20045700E+00, 0.64488500E-01, 0.29541400E-02, 0.19587600E+00, -.59453800E-01, -.45244000E-01, -.21968700E+00, -.36026900E-01, -.38335300E+00, 0.51669000E+00, -.23625700E+00, -.64222300E-01, -.29220000E+00, 0.19968200E+00, -.51887400E+00, 0.66766800E-01, -.98074900E-01, 0.21171300E-01, 0.53880100E-01, 0.18683500E+00, 0.67883100E-01, -.84083800E-01, -.49163600E+00, 0.24735500E+01, -.25012100E+00, -.20400900E+00, -.14765000E+00, -.14339700E+00, -.93999900E+00, 0.64025300E+00, 0.23220700E-01, 0.33758300E+00, 0.16058400E+00, 0.36186000E+00, -.20852200E-01, 0.20002600E+00, 0.87200100E+00, -.81628600E-01, -.44364800E-01, 0.29764800E-03, -.78579100E-01, -.10440600E+01, 0.18516300E+00, 0.10324500E+00, -.31009500E+00, -.42578900E+00, 0.38300200E+00, 0.23960700E-01, 0.12399600E+01, -.13761100E+00, 0.19901600E-02, 0.10203100E+00, 0.41457800E-01, 0.10921900E+01, 0.38311100E+00, 0.12513600E+00, -.88835600E+00, 0.24419100E+00, 0.44418400E+00, -.26947800E+00, 0.14098300E+00, -.25159200E-01, -.63997800E+00, 0.17726800E+00, -.14339800E+00, -.46363000E+00, -.16683800E+00, 0.25570900E+00, -.30055900E+00, -.66967700E+00, 0.48643100E+02, -.23914000E+03, 0.17319500E+00, 0.39754700E+03, 0.44380800E+03, 0.28596200E+03, 0.47349500E+03, 0.25126700E+03, 0.18730200E+03, 0.15657100E+02, 0.68483500E+03, -.32577200E+03, 0.44473800E+03, -.34220200E+03, 0.94220600E+02, -.30729900E+03, -.36950300E+03, 0.54160200E+02, -.50573000E+03, -.42239200E+03, -.14581300E+04, -.47016900E+03, 0.18482500E+03, -.91624300E+03, 0.23535400E+03, -.26998500E+02, 0.19931400E+03, 0.11733200E+03, 0.67859800E+02, 0.38492200E+03, 0.44510000E+03, 0.57129000E+03, -.11830200E+04, 0.61455000E+03, 0.30724800E+03, 0.59147200E+03, -.12799500E+03, -.85893200E+03, 0.13094200E+04, 0.11704900E+04, 0.62390800E+03, -.86237100E+03, 0.36403200E+03, -.34320200E+03, 0.18453100E+03, -.37070200E+03, 0.17225600E+03, 0.18341900E+03, 0.12728200E+03, -.56349900E+02, -.36101000E+02, 0.15134200E+03, 0.55278700E+02, -.79178400E+01, -.95094300E+03, 0.51869000E+03, 0.18445400E+03, 0.47529200E+03, -.37947200E+03, -.34609200E+03, 0.96272100E+03, 0.87055800E+03, 0.57073700E+03, -.36455300E+03, 0.11424000E+04, 0.10599900E+04, -.57225800E+03, 0.82513000E+03, -.52964500E+03, 0.66374500E+03, 0.12427900E+04, -.53427100E+03, 0.17063300E+03, -.30803700E+03, 0.95605900E+03, -.12421000E+04, -.12885600E+03, 0.59016000E+02, -.45153400E+03, 0.63044100E+02, -.22127900E+03, -.62608000E+03, -.57829900E+03, -.91872300E+03, -.12968100E+03, -.42480200E+03, 0.38365200E+03, -.44459500E+03, 0.21729300E+03, -.48880500E+03, 0.22217200E+03, 0.23832900E+03, 0.75597600E+03, -.55683400E+03, -.65106100E+03, -.49065200E+03, 0.82653600E+03, 0.39161900E+03, 0.61920700E+03, -.32214300E+03, -.46621800E+03, -.31056500E+03, -.48126100E+03, -.38398900E+03, -.35221800E+03, -.40165200E+03, -.39929300E+03, 0.16881300E+02, 0.46023200E+03, 0.18655100E+04, -.94278700E+03, -.86704200E+03, -.93271400E+03, 0.41613900E+03, 0.33608600E+03, -.10611700E+04, -.18193500E+02, -.41966800E+03, 0.32783400E+03, -.54180900E+03, 0.14588400E+04, -.73792300E+03, -.48295300E+03, -.72917600E+03, 0.50822800E+03, 0.67060900E+01, -.10088300E+04, -.48032100E+03, -.45373200E+03, -.15042700E+02, -.90256900E+03, -.15997400E+04, 0.80313700E+03, -.29363400E+04, 0.80134200E+03, 0.47716300E+03, 0.57724800E+03, -.11534500E+04, -.70152800E+03, 0.56486700E+03, 0.67242400E+03, 0.11981600E+04, -.36200000E+03, 0.20976800E+03, -.66003600E+03, 0.18307700E+03, 0.29877800E+03, 0.66407700E+03, -.11152700E+03, 0.55985100E+02, 0.17804000E+03, 0.29808100E+03, -.47339300E+03, 0.69295100E+03, -.36975300E+03, 0.16425000E+03, -.34681700E+03, -.24416700E+03, -.93447500E+02, 0.36427700E+03, -.97632600E+02, -.94678900E+02, 0.72736500E+02, 0.21566600E+03, -.19506800E+03, 0.12792900E+03, -.41984400E+03, 0.97128000E+02, 0.13504100E+03, 0.85399100E+03, 0.11498900E+04, 0.11115000E+04, 0.11181700E+03, 0.56717900E+03, -.24783000E+03, 0.90012900E+02, 0.10608900E+03, 0.14471800E+02, 0.85416300E+02, -.10407900E+03, 0.64261200E+02, -.74923100E+02, -.10554400E+03, 0.16261500E+03, -.33018500E+02, -.60273400E+00, -.20224100E+02, -.13073500E+03, 0.11147900E+03, 0.19650400E+03, 0.15550700E+03, 0.21619200E+03, 0.20113500E+03, -.20536200E+03, 0.32524000E+01, -.83174600E+02, -.13073500E+02, -.96894500E+02, 0.35362000E+02, 0.28650800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.93497000E+00, -.14510600E+00, -.46998800E+00, -.50610400E+00, -.41932700E-01, 0.49254800E+00, -.44708500E+00, -.50554800E-02, 0.71550400E-01, -.58897500E+00, 0.11215600E-01, -.39133200E+00, -.59794400E-01, 0.18021800E+00, -.17051200E+00, -.45484400E+00, -.15986500E+00, 0.13270900E+00, -.19746700E+00, 0.27461600E+00, -.12936600E+00, 0.35745100E-01, 0.85129000E-01, 0.45218600E+00, 0.92839100E-02, -.76469900E-01, 0.57864500E-01, 0.10258100E+01, 0.18016100E+00, -.18575900E+00, 0.19158400E-01, 0.22800500E+00, -.12717000E+00, -.15371800E+00, 0.28070100E-01, 0.10203200E+00, 0.13146500E-01, -.16636700E-01, 0.13779700E+00, 0.43474500E+00, 0.23975800E-01, 0.11758000E+00, 0.86781900E+00, -.83820300E-01, 0.17638700E+00, 0.58096600E-01, -.55391800E-01, -.20772500E+00, 0.31243700E-01, 0.61757100E-01, 0.21680900E-01, -.30704000E+00, 0.32409800E-01, -.27680200E-01, 0.20542300E-01, -.23666000E+00, -.32004000E-01, -.69022700E-01, 0.19862300E-04, -.65318600E-01, 0.95263900E-01, -.42981500E-01, 0.34009700E-01, 0.56284700E-01, 0.64620400E-01, -.54986600E-01, -.56935600E-02, -.72290500E+00, 0.18581500E-01, 0.23409000E-03, -.32078400E-01, -.55897100E-01, -.97466400E-01, 0.11183200E+00, -.57204000E-03, 0.26332500E+00, -.82017900E-01, 0.95578400E-03, 0.11339800E+00, 0.26103300E-01, -.49259100E-02, 0.33755300E+00, 0.12921500E+00, 0.41118500E-01, 0.10664300E+00, 0.19892300E-02, -.30841100E+00, -.57073100E-01, 0.21615600E+00, -.15923900E+00, 0.22398100E+03, 0.14603800E-01, -.47868000E+02, 0.30534100E+02, -.13711900E+03, -.27466000E+03, -.23172800E+03, 0.11848900E+03, 0.38985500E+02, 0.24510000E+03, -.12248300E+03, -.81311500E+02, -.12253000E+03, 0.13344000E+03, 0.17382900E+03, -.22678200E+03, 0.12255400E+03, -.28319000E+03, 0.11381800E+03, -.41377100E+03, -.19880100E+03, 0.95180800E+02, 0.11206600E+03, 0.99424200E+02, -.32608500E+01, 0.14199200E+03, 0.81680400E+02, 0.56815300E+02, 0.13907400E+02, 0.86687500E+02, 0.16111200E+03, 0.37519600E+03, -.18421200E+03, -.22498200E+03, -.18760000E+03, -.74212000E+02, -.37537400E+03, 0.89917900E+02, 0.30886600E+02, 0.23586500E+03, -.34704100E+03, -.36796600E+03, -.11740200E+03, 0.55843800E+02, -.77217700E+02, 0.58761800E+02, 0.28950600E+02, 0.48868600E+02, -.59843200E+02, -.72397200E+02, 0.44779300E+02, 0.44691400E+02, 0.73999600E+02, 0.14595300E+03, -.69872000E+02, 0.22110400E+03, -.72992500E+02, -.59797100E+02, -.12215600E+03, 0.66539800E+02, -.17533400E+03, -.95293600E+01, -.75860400E+02, 0.16669700E+02, -.22562900E+03, 0.11066900E+03, -.38160300E+02, 0.11284400E+03, -.52876500E+02, -.15119500E+03, -.46109700E+02, -.10848000E+03, 0.27499300E+02, -.57191700E+02, -.18037200E+03, 0.79115300E+02, -.41625100E+02, 0.15640100E+03, -.39699100E+02, 0.15218500E+03, 0.19209300E+03, -.16405600E+03, -.16290300E+03, -.22857600E+03, 0.93782600E+02, -.49363200E+02, -.58001100E+02, 0.29754400E+02, 0.16420200E+03, 0.28991500E+02, 0.27049900E+02, -.40580900E+01, -.13725200E+03, -.20101400E+03, -.10262400E+03, 0.23208200E+02, 0.18939900E+03, 0.14006200E+03, -.71071600E+02, -.22611400E+03, -.70113900E+02, -.44963500E+02, 0.77195700E+02, 0.10384400E+03, 0.32606900E+03, 0.19563100E+02, 0.44286500E+02, 0.20111000E+03, -.43953500E+03, 0.22107700E+03, -.16465500E+03, 0.21977100E+03, -.10981300E+03, -.80858700E+02, 0.23356200E+03, 0.30328200E+03, 0.13199100E+03, -.73714600E+02, 0.11321400E+03, -.18223000E+02, 0.80264600E+01, -.11417600E+03, 0.91326700E+01, 0.28918300E+02, 0.50308300E+02, -.10442300E+03, 0.13325800E+02, -.11381600E+03, 0.96359700E+02, -.80290600E+02, -.48571800E+03, 0.24584100E+03, 0.46481000E+03, 0.24298800E+03, 0.42311800E+02, 0.17737800E+03, -.13012200E+03, -.49160500E+02, -.38835500E+03, 0.17047700E+03, 0.23022700E+03, -.22603900E+03, 0.10954000E+03, -.14722300E+03, 0.11320600E+03, -.97734500E+01, -.48765900E+02, -.66983000E+02, -.14375800E+03, 0.13267200E+03, -.53430000E+02, 0.47474300E+02, 0.16540700E+03, -.85231100E+02, -.58113600E+02, -.82736900E+02, -.97133600E+02, -.37097400E+02, 0.15784300E+03, 0.65321900E+02, 0.25709000E+03, 0.13575400E+02, 0.24581000E+03, 0.25839300E+03, -.13001000E+03, 0.21264500E+03, -.12923100E+03, -.18005800E+03, 0.52543600E+02, -.89463200E+02, -.17914400E+03, -.46434000E+02, 0.19673200E+03, 0.11537000E+03, -.27640600E+02, 0.21562200E+02, -.23160500E+01, 0.44706600E+01, 0.19094500E+02, 0.10681900E+01, 0.46193000E+00, 0.24176900E+02, 0.15687400E+02, -.12283400E+02, -.59847800E+02, 0.23783800E+01, 0.69249200E+02, -.11413900E+01, -.27486800E+02, 0.17382800E+02, -.13690900E+02, 0.34158500E+01, -.18837700E+02, -.46367400E+02, -.30469600E+02, 0.69297300E+02, 0.38853000E+02, -.90690700E+02, -.17692000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14259700E+02, -.15291900E+01, -.22674200E+01, 0.27524100E+01, 0.55642900E+01, 0.90463000E+00, -.29700700E+01, 0.15545900E+00, 0.93092000E-01, -.32107500E+01, -.18605300E+01, -.37810900E-01, 0.71643000E+00, 0.77165100E-01, -.20527300E+00, -.21271800E+01, -.37862600E+01, -.34882100E+01, 0.17000000E+00, -.29645200E+01, -.20933100E-01, 0.11174300E+00, -.16129500E+01, -.47352100E+01, -.39550900E+00, -.12542400E+01, 0.24033200E+01, 0.45998200E+00, -.12399100E+01, 0.24160400E+00, 0.15779500E+00, -.21962000E+01, 0.88976400E-01, -.20647600E+01, 0.20519800E+00, -.33148800E+00, -.24589200E-01, -.25292700E+00, 0.47471000E-01, 0.25281100E+01, -.62211800E+00, -.60799100E+00, 0.20226000E+01, 0.35984900E+00, 0.61202600E+00, 0.46204900E+00, -.12727400E+01, 0.19099700E+01, -.15278500E+01, -.53023400E+00, 0.43072200E+00, -.81327200E+00, -.64451600E+00, 0.18719400E+01, -.20297500E+00, -.20826700E+01, -.49965100E+00, -.74161800E+00, 0.72405800E-02, 0.10489700E+01, 0.68580400E+00, 0.13627300E+01, -.30389700E+00, -.46135200E+00, -.11087100E+01, 0.22861800E+01, -.51719600E+00, 0.21612600E+01, 0.42747700E+00, -.10434300E-01, -.57816700E+00, 0.42032300E-01, 0.44121600E+00, 0.18587600E+01, -.21111100E+01, -.31231300E+00, -.43685000E+00, -.38702000E+00, 0.12688700E+00, -.56910900E+00, -.79142200E-02, 0.10381700E+01, 0.25675000E+00, 0.75256400E-01, 0.35521700E+00, -.24673300E+00, -.35436400E+00, 0.37839600E+00, 0.10700200E+01, -.50855300E+00, 0.34648800E+01, 0.32699200E+01, 0.17034400E+03, 0.30109600E+03, 0.39291500E+03, 0.20931800E+03, 0.36831700E+03, 0.14664400E+03, 0.16334600E+03, 0.30149000E+03, -.15241000E+03, 0.15510100E+04, -.15068500E+03, -.20391100E+03, -.66277400E+03, 0.29033900E+03, -.18591900E+03, -.43855800E+03, -.71631500E+03, -.10392900E+04, -.11866200E+04, 0.59761500E+03, -.11212200E+04, 0.59337100E+03, 0.36046400E+03, 0.47575100E+03, -.89931400E+02, -.59822500E+02, 0.60338100E+03, 0.73900800E+03, 0.73048000E+03, -.25336200E+04, 0.12632000E+04, 0.11241200E+04, 0.12668200E+04, 0.84973700E+02, -.46184400E+03, 0.10183700E+04, 0.44540800E+02, -.65088000E+03, -.51841400E+03, 0.21815900E+04, 0.55086200E+03, -.26505700E+03, 0.19613500E+03, -.27522500E+03, -.83815100E+02, -.11398200E+02, -.92414200E+02, -.13052600E+03, -.35968000E+03, -.31990700E+02, -.25524200E+03, 0.90077300E+02, -.44645800E+02, -.47762400E+02, -.45083700E+02, -.14962400E+03, -.10733300E+03, 0.54994200E+03, 0.76623600E+03, -.23035300E+03, -.12853800E+03, 0.52325300E+03, 0.13615600E+04, -.68034500E+03, 0.10535700E+04, -.68071600E+03, 0.85637800E+03, 0.13289900E+04, -.36086000E+03, 0.49485400E+03, -.51716300E+02, 0.76954700E+03, -.15904100E+04, -.16405100E+04, 0.82463300E+03, -.36644100E+03, 0.81718100E+03, -.13154300E+03, -.94632400E+03, -.87998400E+02, -.96493900E+03, 0.60232200E+03, -.64354100E+03, 0.98796700E+03, 0.30458000E+03, -.15180100E+03, -.18307400E+04, -.15229700E+03, 0.13674100E+03, 0.56779100E+03, -.36766300E+03, -.18917200E+03, -.12848000E+03, 0.57703700E+03, 0.12856800E+03, 0.73183200E+02, -.36470500E+02, -.96668500E+03, -.36802500E+02, -.22467200E+03, 0.27078500E+02, -.52269200E+03, -.56115200E+03, -.25499900E+03, 0.40392700E+03, 0.49339200E+03, 0.24742300E+04, -.12363200E+04, -.15601400E+04, -.12371100E+04, 0.65926600E+03, 0.13411500E+04, -.19533400E+04, -.56525200E+03, -.43323800E+03, 0.10817300E+04, -.69778500E+03, 0.88881600E+03, -.44249900E+03, -.26174600E+03, -.44435600E+03, 0.40679000E+03, -.82325500E+02, -.58028800E+03, -.35169500E+03, 0.19192200E+02, -.12055900E+03, -.60464300E+03, -.15895900E+04, 0.78789500E+03, -.46847400E+04, 0.79514200E+03, 0.36153200E+03, 0.36191700E+03, -.55651500E+03, -.39912800E+03, 0.26115200E+04, 0.37332200E+03, 0.75407200E+03, 0.83998400E+03, -.40672800E+03, -.22230300E+03, -.41944800E+03, -.14404900E+03, 0.22132700E+03, 0.13823000E+02, -.99002500E+02, -.79085200E+03, 0.55606400E+02, -.59343000E+03, 0.80752800E+03, -.39912600E+03, -.14680500E+03, -.40389000E+03, -.10004400E+03, 0.17015500E+03, -.28097700E+03, 0.13920700E+02, -.56725400E+03, 0.33830000E+03, 0.41881700E+03, 0.64937800E+03, -.32825100E+03, -.30734800E+03, -.32477300E+03, -.25309100E+03, 0.55286400E+03, 0.14529200E+04, 0.15148700E+04, -.39723500E+03, 0.47290000E+03, -.74376800E+03, -.85502100E+02, 0.12510000E+03, -.65412800E+01, 0.15464500E+03, 0.17143400E+03, 0.11244900E+03, -.14357200E+03, 0.14471300E+03, -.13479900E+02, -.85654500E+02, -.82786600E+01, -.10206800E+03, -.19576600E+03, 0.24833800E+02, 0.24546700E+03, 0.25160700E+03, 0.29082600E+03, 0.69078900E+02, -.16786500E+03, 0.79649000E+02, -.41154800E+02, -.53846000E+02, 0.54418800E+02, 0.11557800E+03, 0.52244800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.49989000E+01, 0.23977400E+00, -.26393900E+01, 0.26294400E+01, 0.15997400E+01, -.16212100E+01, 0.29060600E+00, 0.12007500E+00, -.61842500E+00, 0.11411700E+01, 0.76936100E+00, -.17409600E+00, 0.64890200E+00, -.83461700E-01, -.58009800E+00, 0.93870100E+00, 0.90458900E+00, -.55056500E+00, 0.96544000E-01, -.40607200E+00, -.10633200E+01, -.39003700E+00, 0.10011900E+00, 0.13345700E+01, 0.35309000E+00, 0.82537700E+00, 0.12140300E+01, -.41722600E+00, -.11497300E+01, 0.57862000E+00, 0.37638900E-02, 0.55603300E+00, 0.13225000E+01, -.39385100E+00, 0.10170100E+00, -.40665600E+00, 0.23006100E-01, -.21925400E-01, -.32334400E+00, -.18474500E+01, -.28698000E-01, -.35600800E+00, -.21944700E+01, 0.14925000E+00, -.30736500E+00, -.17965900E+00, 0.77319800E-01, -.16960600E+00, 0.16489100E+00, 0.14439500E+00, 0.17070000E+00, 0.36659000E+00, 0.64192700E-01, -.42802600E+00, -.12606100E-01, 0.86448600E+00, 0.17259300E+00, 0.14833700E+00, -.97975600E-03, 0.68182600E+00, -.82083300E+00, 0.11357700E+00, -.51361400E-01, -.67200300E-01, -.31956700E-01, -.52777400E+00, 0.10633100E+00, -.92040400E+00, -.13635600E+00, -.21810000E-03, -.44856200E-01, 0.59624900E-01, 0.79937300E-01, 0.17638800E+00, 0.27563600E-01, -.21438800E+00, 0.27096900E+00, -.48376700E-01, -.61147400E-01, 0.19770000E+00, -.87892800E-02, -.19360400E+01, -.72939300E-01, -.85130600E-01, -.26424700E+00, 0.38137200E-01, 0.53816600E+00, -.17611100E+00, -.10993300E+01, 0.99167400E+00, 0.47135500E+00, -.18021200E-01, 0.80694600E+03, -.16716900E+03, 0.44421200E+03, 0.89841200E+03, 0.71545200E+03, -.50100000E+03, -.71324300E+03, -.13579500E+04, 0.68273200E+03, 0.30750100E+03, 0.67887300E+03, 0.27786600E+03, 0.12456900E+03, -.13788300E+03, -.67178300E+03, 0.10966500E+04, 0.20962200E+03, 0.18862200E+04, 0.99782100E+03, -.48425500E+03, -.66493700E+03, -.49901900E+03, 0.31890900E+03, -.90950200E+03, 0.50711900E+03, 0.25201200E+03, -.19546100E+02, -.86611000E+03, -.99530000E+03, 0.18708200E+03, -.10281000E+03, 0.49786700E+03, -.93551500E+02, 0.40270600E+03, 0.10677200E+04, -.94912100E+03, -.39391300E+03, -.54046700E+03, 0.11164800E+04, 0.16586600E+02, 0.72102000E+03, -.36746700E+03, 0.44677800E+03, -.36084600E+03, -.22293200E+03, -.23757400E+03, 0.14625100E+03, 0.30638100E+03, -.18755900E+03, -.18344300E+03, -.37835900E+03, 0.83368600E+03, -.42955800E+03, 0.30436200E+03, -.41676700E+03, 0.57908900E+03, -.24210500E+03, -.56616200E+03, -.64246400E+02, -.55207400E+03, -.42076900E+03, -.11076900E+04, 0.14864600E+04, -.73176000E+03, -.42007800E+03, -.74334600E+03, 0.13861700E+03, 0.78560500E+03, -.70395900E+03, -.54159700E+03, -.74238200E+03, 0.79116800E+03, 0.63149900E+03, 0.12757500E+04, -.62968100E+03, -.69817300E+03, -.63695800E+03, -.64229400E+03, -.20358000E+03, 0.14305000E+03, 0.52922500E+03, -.11172100E+03, -.58196600E+02, -.53670900E+03, 0.60334000E+03, -.30625400E+03, -.13329700E+04, -.30165300E+03, -.49753600E+03, -.19246900E+02, 0.39510100E+03, 0.85080000E+03, 0.10668500E+01, 0.93248300E+02, -.67488000E+03, -.37211200E+03, 0.18619900E+03, -.34956600E+03, 0.18642500E+03, -.21710200E+03, -.82663800E+03, 0.47167200E+03, -.33998000E+03, 0.10982300E+03, -.74469800E+03, -.55704200E+03, -.19589900E+04, 0.97600200E+03, -.46422000E+01, 0.97947900E+03, 0.40934100E+03, 0.56121900E+03, 0.70774200E+03, 0.60549400E+03, 0.97491100E+03, 0.34996000E+03, 0.50637100E+03, -.25102700E+03, 0.13090100E+03, 0.41752100E+03, 0.12542100E+03, -.11121800E+03, 0.12182800E+03, 0.29304200E+03, 0.24622700E+03, 0.55673900E+03, -.85761500E+02, 0.58708400E+03, 0.14185600E+04, -.71546800E+03, -.27467300E+04, -.70988000E+03, -.47256900E+03, -.12764700E+04, 0.10210200E+04, 0.11167100E+04, 0.68580400E+03, -.13005300E+04, -.67249600E+03, -.40240000E+03, 0.18369500E+03, 0.13552300E+04, 0.20027600E+03, 0.35869700E+03, 0.59109400E+03, -.89698800E+02, 0.40230700E+03, 0.17316300E+01, 0.69462900E+03, 0.36853500E+03, 0.30239100E+03, -.14856900E+03, 0.59669900E+03, -.15099200E+03, -.37844300E+03, -.25084000E+03, 0.95765800E+02, 0.90444400E+02, -.76075500E+03, -.43165600E+03, -.12181800E+04, -.10241800E+04, 0.51270900E+03, 0.78394200E+03, 0.51224200E+03, 0.13755700E+04, -.10368000E+04, 0.33963200E+03, 0.65063900E+02, 0.55488000E+03, -.13573700E+04, -.35844700E+03, 0.28134200E+03, -.11297800E+03, -.44455100E+02, -.93788200E+02, -.17267500E+03, -.32476700E+02, 0.14492400E+01, -.18174900E+03, 0.71933300E+02, 0.19083200E+03, 0.17149700E+03, -.46369700E+02, -.64573100E+02, 0.14407200E+03, -.20445100E+03, -.15188000E+03, -.10830300E+02, 0.16806500E+03, 0.14887800E+03, -.10293100E+03, 0.22174000E+03, -.16476100E+03, -.16881200E+03, 0.25947100E+03, 0.44850400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46996200E+01, 0.45941800E+00, 0.15522700E+01, -.57864900E+00, 0.10264500E+01, -.15436400E+00, 0.27207000E+00, 0.40607900E+00, -.30983700E+00, 0.75625400E+00, -.20171200E+01, 0.27876500E+01, 0.23083200E+01, -.71166200E+00, 0.86037400E-01, 0.90682600E-01, 0.97705300E+00, -.17641200E+00, -.14701400E+01, 0.85130600E+00, -.93160000E+00, -.41110500E+00, -.11523200E-01, 0.61684900E+00, 0.27904900E+00, 0.94047000E+00, 0.85201600E-01, -.25203900E+01, 0.10823400E+01, -.33130700E+00, -.20272800E+00, 0.29734400E+00, 0.51894700E+00, -.96626300E+00, 0.29166500E+00, 0.81819200E+00, 0.15656000E+00, -.57016100E-01, 0.12231500E+01, -.96430100E+00, -.14186200E+00, -.31232700E+00, 0.44070400E+01, -.13527400E+00, -.10842300E+00, 0.24087200E+00, 0.10840700E+01, -.24769500E+01, -.16261000E+01, 0.19215900E-01, -.18262900E+01, 0.77976300E+00, -.82625200E+00, 0.61397300E+00, 0.13483900E+01, 0.16914400E+01, 0.71109100E+00, -.12117800E+01, 0.77966000E-03, 0.86647100E+00, -.28162300E+01, -.15130500E+01, 0.38498500E+00, -.13985000E+01, -.19842200E+01, 0.29954400E+00, -.64664700E+00, 0.21547800E+01, 0.13777400E+00, 0.22945700E-01, 0.69038600E+00, 0.40690400E-01, -.17484700E+01, 0.12666000E+01, 0.53619300E+00, 0.83425600E+00, -.28200200E+00, 0.12178100E+01, 0.55392300E+00, 0.36601300E+00, -.10112500E+00, 0.10321600E+01, -.14392900E+01, 0.52569200E+00, 0.24417500E+00, -.92282800E-03, -.28754000E+00, -.74622800E+00, 0.11206700E+00, 0.42340500E+00, -.13420200E-01, 0.21015800E-01, -.51924200E+00, -.16329200E+04, 0.12981700E+04, 0.11409300E+04, 0.13251000E+04, -.19293000E+04, -.22481800E+03, -.40481300E+04, 0.20319100E+04, 0.11515300E+04, 0.20240000E+04, 0.17126200E+04, 0.13418800E+04, -.91545200E+03, -.17105400E+04, 0.19030200E+04, 0.17040800E+04, 0.24537800E+04, 0.47418500E+04, -.23301700E+04, -.18326300E+04, -.23709300E+04, -.15630000E+04, -.30053600E+04, 0.13114700E+04, 0.53014000E+03, -.81792700E+03, -.29947900E+04, -.18074300E+04, 0.44310400E+03, -.24897900E+03, -.76009300E+03, -.22164800E+03, 0.14152300E+04, 0.36713100E+04, -.26955400E+04, -.95969700E+03, -.11355000E+04, 0.37893300E+04, -.15900900E+04, 0.17474400E+04, -.88397100E+03, -.14986700E+03, -.87402500E+03, -.43087300E+03, -.69572200E+03, 0.42690000E+03, 0.82315900E+03, -.20515800E+03, -.55528200E+03, -.77953700E+03, -.90856100E+03, 0.41989400E+03, -.48681300E+03, 0.45430800E+03, 0.93526900E+03, 0.71933900E+03, -.53593100E+03, 0.59491600E+03, 0.32312500E+03, 0.22893700E+03, -.92170500E+03, 0.80688100E+03, -.37484200E+03, -.10220700E+04, -.40337300E+03, -.74243800E+02, -.19048700E+03, -.27217500E+03, -.68235200E+03, -.69027700E+03, 0.24750100E+03, 0.18730100E+04, 0.43522300E+04, -.21557100E+04, -.19250500E+04, -.21746600E+04, -.13256400E+04, -.36893200E+03, 0.11845900E+04, 0.28416000E+04, -.43328800E+03, -.34917200E+03, -.23456000E+04, 0.17235700E+04, -.87715000E+03, 0.38823800E+03, -.86188900E+03, -.97082500E+03, -.20983800E+03, 0.71064400E+03, 0.16099700E+04, -.85264600E+03, -.18491400E+03, -.12102900E+04, 0.16977100E+04, -.84716500E+03, -.30964500E+03, -.84886900E+03, -.17043000E+04, -.30064600E+04, 0.19788600E+04, 0.26870300E+03, 0.53856800E+01, -.32858500E+04, -.69818800E+03, -.20017400E+04, 0.99075300E+03, 0.12176200E+04, 0.10008700E+04, 0.13145900E+04, -.30967100E+03, 0.41176500E+03, 0.13654800E+03, 0.11094400E+04, -.53920700E+03, 0.28128700E+02, -.92479800E+03, 0.47650800E+03, 0.34635400E+03, 0.46241300E+03, 0.50882800E+03, 0.22075600E+03, 0.64177000E+03, 0.73597700E+03, 0.12980500E+04, -.26791300E+03, 0.42048800E+03, 0.32514900E+04, -.16409500E+04, 0.27524900E+03, -.16258500E+04, -.14146900E+04, -.27599000E+04, 0.20920800E+04, 0.15866600E+04, 0.12647200E+02, -.31085300E+04, -.16735000E+04, -.28243600E+04, 0.13814000E+04, 0.26601400E+04, 0.14117800E+04, 0.15427600E+04, 0.16898900E+04, -.97690200E+03, -.73450300E+03, -.15558800E+03, 0.20832500E+04, 0.96593500E+03, 0.24997100E+04, -.12405000E+04, -.13333100E+04, -.12496100E+04, -.17238600E+04, -.21574200E+04, 0.12868300E+04, 0.10951300E+04, -.53555100E+03, -.25773200E+04, -.15449500E+04, -.37955800E+04, 0.19017800E+04, 0.24805300E+04, 0.18977600E+04, 0.52354100E+03, -.25660600E+04, 0.49934800E+03, -.19615700E+04, 0.13100000E+04, -.30228300E+04, 0.24112000E+04, 0.73422300E+03, -.48192200E+03, -.25501100E+02, -.49826800E+03, -.67787800E+03, -.33348000E+03, 0.31299000E+03, -.68012000E+03, 0.47373500E+03, 0.24144100E+03, 0.31562200E+03, 0.67175500E+02, -.23251200E+03, 0.61045900E+03, -.42209400E+03, -.62456400E+03, -.41496300E+03, 0.51520300E+03, 0.45469200E+03, -.34826900E+03, 0.69053600E+03, -.53078100E+03, -.47179300E+03, 0.35324400E+03, 0.79864900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29575300E+01, -.35969900E+00, 0.85791000E+00, 0.12701100E+00, -.21899700E+00, 0.55691600E+00, -.46028400E+00, -.23341400E-01, 0.15555900E+00, -.14133500E+00, 0.11361100E+00, -.66806900E+00, -.92550500E-01, 0.38119400E+01, -.17115900E+00, -.26208800E+00, 0.18449900E+00, 0.19857800E+01, -.53311400E-02, 0.50178200E+00, -.16896800E+01, -.10932500E-01, -.87201700E-01, 0.15337100E+01, 0.88369700E-01, -.30635500E+00, 0.65346100E-01, -.30683300E+00, 0.41753200E+00, -.13553200E+00, 0.22543200E-01, 0.37436500E+00, 0.12804100E+01, -.93134600E+00, 0.24453200E+00, 0.36866500E+00, -.23392900E-01, 0.16195000E+00, 0.16128500E+00, -.97657900E+00, 0.43657200E+00, -.23059300E+00, 0.13999600E-01, 0.45090200E-01, -.11536100E+01, -.17404100E+00, 0.42317200E+00, -.72371100E-01, 0.51329800E+00, 0.13945200E+00, 0.58944300E+00, 0.12174400E+00, 0.19914500E+00, -.16509800E+00, -.31648700E-01, 0.55698200E+00, 0.33050000E-01, 0.28991300E+00, 0.30965100E-02, -.42380900E+00, -.28492400E+00, -.11601600E+00, 0.38894800E-01, 0.14377500E+00, 0.11893100E-01, -.56999100E+00, 0.15091700E+00, 0.14720600E+00, -.22078200E+00, -.33241900E-02, 0.30053100E+00, 0.13612800E+00, 0.10991500E+01, -.25911700E+00, 0.40226500E+00, 0.63928700E+00, 0.26519000E-01, -.18946000E+00, 0.22075300E+00, -.25028200E+00, 0.12914600E-01, -.23828300E-01, 0.87476200E-02, -.19343400E+00, -.68212500E-01, 0.11343900E+00, -.27820800E+00, 0.17227600E+00, -.47296700E+00, 0.15761800E+00, -.11893500E+01, -.79015800E-02, -.46539400E+00, 0.25855000E+00, -.54355700E+03, -.44868200E+03, -.17197800E+03, 0.12680500E+03, -.89933900E+02, 0.68475400E+02, -.34213600E+02, -.22978200E+03, -.34294900E+02, -.61801800E+02, 0.21724700E+03, -.18158000E+03, 0.83556000E+02, -.61320900E+02, 0.63756500E+02, 0.70815900E+03, -.86636000E+03, 0.42885400E+03, 0.79435500E+03, 0.43309500E+03, 0.33740600E+03, 0.18348400E+03, 0.24402400E+03, 0.11850800E+03, 0.18156600E+03, 0.11060100E+03, -.44122200E+02, 0.34280800E+03, -.16671100E+03, -.60587200E+02, -.17137400E+03, -.11545300E+03, -.58365600E+03, -.79332500E+02, -.92016900E+02, 0.26916100E+03, -.50007900E+03, 0.19661300E+03, -.12762200E+02, 0.54401300E+01, -.62534200E+02, 0.62335500E+01, 0.20070100E+02, 0.99952800E+02, -.12875500E+03, -.39064200E+02, 0.77878200E+01, 0.80669900E+02, 0.45446000E+02, 0.89053800E+03, -.43985200E+03, 0.10298400E+03, -.44522000E+03, 0.30578200E+02, -.14361300E+03, -.38143300E+03, -.43718200E+03, -.39188900E+03, -.70026000E+02, -.71881700E+03, -.16825300E+03, 0.82034300E+02, -.31185400E+03, 0.84007300E+02, -.17950000E+03, -.29755400E+03, -.65771000E+02, -.20448200E+03, 0.13996500E+03, -.20208400E+03, 0.54908700E+03, 0.26344600E+03, -.13315600E+03, 0.56561000E+03, -.13178100E+03, 0.26980000E+03, 0.40957000E+03, -.25891200E+03, -.12045200E+03, -.36818300E+03, 0.36309400E+03, -.25893200E+03, -.35710000E+03, 0.18084200E+03, -.15547200E+03, 0.17860300E+03, 0.80535800E+02, -.18165300E+03, 0.19215500E+03, -.18867000E+03, 0.22676000E+03, -.16977400E+02, 0.11714500E+03, -.92935100E+03, 0.46386000E+03, 0.30835000E+03, 0.46497900E+03, 0.37734800E+03, 0.65563200E+03, -.17774500E+02, -.89288600E+02, 0.59282400E+02, 0.68754700E+03, 0.98526600E+01, 0.27586700E+03, -.13679100E+03, -.15372900E+03, -.13794600E+03, -.12361400E+03, 0.38801700E+03, 0.50281200E+03, 0.81379500E+03, -.28496100E+03, 0.31536600E+03, -.33926400E+03, 0.13752200E+03, -.69779700E+02, 0.14682800E+03, -.68841300E+02, -.25783600E+03, 0.19856400E+02, 0.17027100E+02, 0.20199700E+02, -.15691100E+03, 0.74743400E+02, 0.10812500E+03, -.81838700E+03, 0.41006300E+03, 0.38376700E+03, 0.40875200E+03, -.56500100E+01, -.22995800E+03, 0.63932100E+03, 0.29005500E+03, 0.67834800E+02, -.10593400E+03, 0.32105700E+03, 0.70620600E+03, -.35334100E+03, -.24636800E+03, -.35368900E+03, -.20747500E+03, -.25259900E+03, -.12368400E+03, 0.17617600E+03, 0.43954900E+02, -.24390200E+03, 0.86750000E+02, -.20142300E+03, 0.99669000E+02, 0.20476700E+03, 0.10077600E+03, 0.10563800E+03, 0.26266600E+03, -.19493300E+03, -.14281200E+03, 0.38128200E+01, 0.33289100E+03, -.48997500E+03, -.74156900E+02, 0.34237100E+02, -.34858200E+03, 0.37211900E+02, -.18811400E+03, -.31616500E+03, -.60583800E+03, -.60496200E+03, 0.40980700E+03, -.10483300E+03, 0.27785400E+03, -.10788000E+03, 0.30977600E+02, 0.47132400E+02, 0.73396400E+02, 0.99781000E+02, 0.35351500E+01, 0.19203100E+00, 0.10252600E+03, -.26026300E+02, -.45234500E+02, -.55022400E+02, -.14593600E+02, 0.10251500E+03, -.48422300E+02, -.61801600E+02, 0.37690200E+02, -.12884900E+02, -.69698000E+02, 0.23209600E+02, 0.60143700E+02, -.24646600E+02, 0.11547900E+03, 0.89498600E+02, -.60253100E+02, 0.85124500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.90172700E+01, 0.31941300E+00, -.47585300E+01, -.17387700E+01, 0.46539800E+01, 0.16937700E+00, -.11589700E+01, 0.72087500E+00, -.64198800E-01, -.16599900E+00, -.33485500E+00, 0.70659800E+00, 0.62864100E+00, 0.10110600E+01, 0.11373100E+00, 0.62527100E+00, 0.42825300E+01, 0.18675500E+01, -.59337800E+00, 0.74793300E+00, -.80613800E+00, -.13917600E+00, 0.33813500E+00, 0.92368900E+00, 0.13164700E+00, -.69107800E+00, -.45335700E-01, -.11257300E+01, 0.60637400E-01, -.57411500E+00, -.27873700E-01, -.48927400E-01, 0.23911100E+01, -.74771300E+00, 0.31918000E+00, 0.16471900E+01, -.36968600E-01, 0.22295400E+00, 0.93186800E+00, 0.21689700E+01, 0.92535000E+00, 0.30246900E+00, 0.16916400E+01, -.24170800E-01, 0.67063600E+00, 0.53453200E+00, 0.78767500E+00, -.15279500E+00, 0.89689900E+00, 0.17459700E+00, 0.63966000E+00, -.13274600E+01, -.12337500E-01, -.49634500E+00, -.15176000E-01, -.21247700E+01, -.47662700E+00, 0.66450300E+00, 0.54834100E-02, -.12854100E+01, 0.21192400E+01, -.41435300E+00, 0.11275300E+00, -.22732800E-01, 0.39347300E+00, 0.24262700E+00, -.17259900E+00, 0.12195900E+01, 0.32024400E+00, -.51621300E-02, 0.48933500E+00, -.94157800E+00, -.12413900E+01, -.56719300E+00, 0.79985600E+00, 0.79818900E+00, -.71978500E+00, -.47767800E-01, -.72495900E+00, 0.12058400E+00, 0.52708800E-01, 0.12174600E+01, -.48423500E+00, 0.11141700E+01, 0.36793000E+00, -.23124300E-01, -.12934400E+01, 0.31991500E+00, 0.11594100E+01, -.11041500E+01, -.72423200E+00, 0.33462400E-01, -.21877100E+00, 0.11447100E-01, -.19590700E+01, -.11422000E+04, -.42720300E+03, 0.31361900E+03, -.22692300E+02, -.88752200E+03, 0.43519200E+03, 0.14191600E+04, 0.44377500E+03, 0.40837900E+03, 0.11775600E+04, -.11590500E+04, -.44174800E+03, -.89876400E+03, 0.80989300E+03, 0.30051500E+03, -.97853400E+03, 0.48127600E+03, -.18333700E+03, 0.48925500E+03, 0.35495200E+03, -.43741800E+03, 0.80713200E+03, 0.21562500E+03, 0.11952300E+04, -.16580900E+03, 0.95756500E+03, -.67166800E+03, 0.33960100E+03, 0.12050300E+03, 0.33588000E+03, 0.93482400E+02, -.93718700E+03, 0.37938100E+03, 0.55212600E+03, -.10322300E+03, -.98684300E+03, -.62301800E+02, -.53405300E+03, 0.24658700E+03, -.72743400E+02, 0.26712100E+03, 0.82408300E+02, 0.47848000E+03, -.29640400E+03, -.17373500E+03, 0.96699400E+02, 0.32750300E+03, 0.35558700E+03, 0.28124100E+04, -.14020300E+04, -.38841900E+03, -.14062000E+04, -.37344900E+03, -.11866600E+03, -.27347700E+03, 0.15452700E+03, -.11639400E+04, -.44776700E+02, -.17606700E+04, 0.25707800E+03, -.13901200E+03, 0.34747900E+03, -.12859400E+03, 0.34146400E+03, 0.14193700E+03, -.51279700E+03, -.86233500E+03, -.74674300E+02, -.85795700E-01, 0.11068900E+03, 0.67034800E+03, -.34921900E+03, 0.22194600E+03, -.33567300E+03, -.24882600E+02, 0.21650700E+03, -.40211600E+03, -.46616400E+03, -.39919700E+03, 0.25557500E+03, 0.33701400E+03, -.80924100E+03, 0.41305600E+03, -.12326000E+04, 0.40467800E+03, 0.64088700E+03, -.11162300E+03, -.14401800E+03, -.45570400E+03, 0.34738300E+03, 0.16221200E+03, 0.34085800E+03, 0.48247700E+03, -.22582600E+03, -.14129400E+04, -.24117000E+03, -.25830200E+03, -.36156000E+03, 0.14067200E+03, -.51952300E+02, 0.64386500E+03, 0.25505000E+03, 0.46217600E+03, -.12957700E+04, 0.63384300E+03, -.14989600E+04, 0.64788200E+03, 0.21407800E+03, 0.82848900E+03, -.38678000E+02, 0.24804900E+03, 0.58352000E+03, 0.70876400E+03, 0.52903000E+03, 0.13159000E+03, -.75173700E+02, 0.45623500E+03, -.65816800E+02, -.12709400E+03, 0.76079800E+02, -.55587300E+03, -.54764800E+03, -.20019000E+03, 0.19468500E+03, 0.22237300E+03, -.34963700E+04, 0.17729400E+04, -.18620900E+04, 0.17481400E+04, 0.91014500E+03, -.56616900E+03, 0.30955800E+03, -.64526800E+02, 0.24085500E+04, -.49132100E+02, 0.23845200E+04, 0.85320600E+03, -.44928900E+03, 0.53553000E+02, -.42654900E+03, -.14258300E+03, 0.50172100E+03, -.58446200E+03, 0.55449900E+03, -.45268400E+03, 0.13429000E+03, -.69301200E+03, 0.19970400E+04, -.10051700E+04, -.56734900E+03, -.99861500E+03, -.87325100E+03, -.79161000E+03, 0.72480800E+03, 0.28604000E+03, -.99230600E+02, -.47279000E+03, -.99721400E+03, 0.15710800E+02, 0.12425400E+02, 0.19765800E+03, -.78161800E+01, -.88907200E+02, -.33311000E+03, 0.23649800E+03, -.11296700E+04, -.17988500E+03, 0.38417800E+03, -.40499500E+03, -.24980700E+02, 0.28999700E+02, 0.61517600E+01, 0.92251600E+02, 0.13613600E+03, -.22747400E+02, -.19930400E+02, 0.13602100E+03, -.56193200E+02, -.98514200E+02, -.15458200E+03, 0.35524700E+01, -.26943800E+03, -.11887400E+03, 0.70179500E+02, 0.12972300E+03, 0.43649200E+02, -.30958800E+02, -.64823300E+02, -.12764400E+03, -.50180600E+02, 0.60034000E+01, 0.92690700E+02, -.12333200E+03, 0.42883700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.82529400E+00, 0.15543400E+00, -.20182600E+00, -.12297600E+01, -.26694900E-01, 0.14709400E+01, -.16262900E+01, -.10477900E+00, 0.18153600E+00, -.15547600E+01, 0.16470100E+00, 0.10959900E+00, 0.36075900E+00, 0.22341100E+00, -.25184300E-01, -.34497000E+00, 0.12296300E+00, 0.82939900E+00, -.48467000E+00, 0.66073800E+00, 0.19492000E+00, 0.71024500E-01, 0.18299800E+00, 0.19497900E+00, 0.10946700E+00, -.54223300E-01, 0.37518900E+00, -.85448300E+00, -.42940300E+00, -.10548500E+00, -.42948200E-01, 0.57345900E+00, 0.59681500E+00, 0.10140000E-01, 0.23792600E-01, 0.37614000E+00, -.11717500E-01, 0.13859000E+00, -.16071000E-01, -.21744400E+00, 0.23724000E+00, 0.39869300E+00, 0.10569600E+01, 0.34344300E-01, -.58479100E+00, 0.65038500E-01, -.15488100E+00, 0.69067200E+00, -.99050500E+00, -.76328300E-01, -.10124300E+01, 0.76620400E+00, 0.28246000E-01, -.16778400E+00, -.79554900E-01, -.48903700E+00, -.12249000E+00, 0.82223500E-01, -.27969200E-03, -.42162600E+00, 0.62087300E+00, 0.27520000E+00, 0.13608400E-01, -.29184700E-01, 0.33220700E+00, 0.20755800E+00, 0.32977700E-02, 0.40948400E-01, 0.88111800E-01, -.96954400E-03, 0.53261900E-02, -.17611100E+00, -.33995500E+00, 0.28473100E-01, -.80052800E-01, 0.61276800E-01, -.96319100E-01, -.21033700E-01, -.33875900E-01, 0.46719500E-01, 0.46675500E-02, 0.26146000E+00, 0.33342000E-03, 0.12695500E+00, 0.12624200E+00, -.38325500E-02, -.17239400E+00, -.53618200E-01, -.23319100E+00, 0.28518000E-01, -.13787600E+00, 0.86526000E-02, -.53275300E-01, -.45554400E-01, -.46537600E+00, -.13613800E+00, 0.17158000E+03, -.14968200E+03, 0.72786300E+02, 0.27961200E+03, -.14109800E+03, 0.32966500E+03, -.13980000E+03, 0.17109300E+02, 0.19749000E+03, -.49657400E+03, -.12413900E+03, -.19047300E+03, 0.10389800E+03, -.10262000E+03, -.82073600E+03, 0.41264900E+03, 0.25996600E+03, 0.41036800E+03, -.52730100E+02, -.17271100E+03, 0.44471100E+03, 0.14121900E+03, 0.46109200E+03, -.74911000E+02, 0.66536200E+03, -.15296800E+03, 0.75456300E+02, 0.34124500E+01, 0.76497200E+02, -.14764800E+01, -.43146900E+03, 0.27680900E+03, 0.32919600E+03, 0.14737900E+03, -.39422900E+03, -.40400300E+03, 0.30511200E+03, -.15156700E+03, -.86858200E+02, -.15252200E+03, -.48893700E+02, 0.34506000E+02, -.10570200E+03, -.24450100E+00, -.12118500E+03, 0.15690900E+02, -.15011100E+03, 0.82665700E+03, -.41266000E+03, -.39684100E+02, -.41333000E+03, 0.17086000E+03, 0.12819600E+02, 0.17682700E+01, 0.37007400E+03, -.20877000E+03, -.11070800E+03, -.98323400E+03, 0.11634500E+03, -.56935600E+02, 0.13663700E+03, -.58185400E+02, -.11155300E+03, -.82199600E+01, -.24712100E+03, -.40054300E+03, -.14254500E+03, 0.88463400E+02, 0.71270000E+03, 0.37938000E+03, -.18913700E+03, 0.84246600E+02, -.18994400E+03, 0.13105400E+02, 0.50761100E+02, -.29612800E+03, -.28289400E+03, -.17730600E+03, 0.13061700E+03, -.13574600E+03, -.58520500E+03, 0.29363900E+03, -.25758800E+03, 0.29261900E+03, 0.14199000E+03, -.24250300E+02, 0.54299400E+02, -.16957100E+03, 0.68625000E+02, 0.18690900E+03, 0.16198100E+03, -.61652600E+03, 0.31031500E+03, -.24486200E+02, 0.30827400E+03, 0.41188000E+02, 0.89087300E+02, 0.20277900E+03, -.55836900E+02, 0.14042300E+03, 0.23428500E+03, 0.61395700E+03, -.25212600E+03, 0.12377900E+03, -.32829900E+03, 0.12606200E+03, 0.39362800E+03, 0.36658000E+03, 0.94605200E+02, 0.44407600E+03, 0.14434100E+03, 0.33225300E+03, -.92377800E+02, 0.48879300E+02, -.24282700E+02, 0.19635200E+03, -.24443700E+02, 0.20032100E+02, -.76461200E+02, -.24857900E+03, -.23893400E+03, 0.10420300E+02, -.52597400E+02, 0.49863000E+02, -.15617000E+04, 0.78043000E+03, -.42417200E+03, 0.78084900E+03, 0.13579000E+03, -.21172000E+03, 0.10704400E+03, -.65298800E+00, 0.84476500E+03, -.58531200E+02, 0.72001000E+03, 0.58651400E+03, -.29213800E+03, -.29398700E+03, -.29322000E+03, -.13434800E+03, 0.66554400E+02, -.13825400E+03, 0.19599000E+03, -.15254400E+03, 0.25870400E+01, -.44645800E+03, -.14433900E+02, 0.10555300E+02, -.86013000E+02, 0.71853800E+01, -.25074400E+02, -.31391300E+02, 0.29376900E+03, -.63288900E+02, -.10108600E+03, -.22409800E+02, -.10718000E+03, -.20446800E+03, 0.10256500E+03, 0.31345600E+01, 0.10224200E+03, -.19312400E+03, -.76730500E+02, 0.21662700E+03, 0.31706100E+02, 0.20817200E+03, -.24792800E+03, 0.32843100E+03, -.58555800E+02, 0.19969300E+02, -.16540700E+02, 0.62166600E+02, 0.32432600E+02, 0.18503200E+02, -.34095200E+02, 0.27505100E+02, 0.35981200E+02, -.49267900E+02, -.11669200E+03, 0.27755600E+02, -.28848100E+02, 0.39359100E+02, 0.27574100E+02, 0.45807700E+02, 0.30482200E+02, -.21656500E+02, -.13585200E+02, -.12344900E+02, -.36847000E+02, 0.31180000E+02, -.17019600E+01, -.43508400E+02, 0.59420100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.43658800E+01, 0.51853600E+00, -.10609800E+00, 0.34941000E+01, 0.35669900E+01, -.23660700E+01, 0.47800500E+00, -.16649800E-01, -.94849600E+00, 0.12451800E+01, -.38370600E+00, 0.76477900E+00, 0.20701400E+00, -.28294100E+01, 0.30802900E+00, 0.32862400E+00, -.65564100E-01, -.13700400E+01, 0.20787900E+01, -.61167300E+00, -.34133300E+00, -.18195700E+00, -.15907500E+00, -.30375000E+00, 0.85571000E-01, 0.39219300E+00, 0.33194700E-01, -.18278300E+01, -.43617300E+00, 0.84040100E+00, -.14377600E+00, 0.11408600E+00, 0.16586200E+01, -.43130600E+00, 0.11172900E+00, 0.48920700E+00, -.34584900E-01, 0.25281400E+00, -.31739400E+00, -.37097700E+00, 0.29478500E+00, -.70539200E+00, 0.20112200E+00, 0.44629700E-01, -.58829100E+00, -.28653100E+00, -.37574200E+00, -.15887000E+00, 0.17143500E+01, 0.16710800E-02, 0.99542200E+00, 0.15069400E+00, 0.22299600E+00, -.17426600E+01, -.76750300E+00, 0.91737700E+00, -.89312400E-01, 0.30425600E+00, -.23997500E-02, -.29928700E+00, 0.48043800E+00, -.26585600E+00, -.14026600E+00, -.37116300E+00, -.94246000E+00, -.50581400E+00, 0.35673500E-01, 0.53168000E-02, -.17350300E+00, 0.43938600E-02, -.33321900E+00, 0.14182200E+00, 0.25379300E+00, -.51252700E+00, 0.13723900E+00, 0.36600100E+00, 0.78621900E-01, -.45387100E+00, 0.35144400E+00, -.33027200E+00, 0.12184200E-02, 0.21707100E+00, 0.55770400E-01, -.36568000E+00, -.40004900E-01, 0.28867100E+00, -.76340000E+00, 0.35762500E+00, -.12938700E+01, -.44584500E+00, -.33043600E+01, 0.41615400E-01, -.39836300E+00, -.80213600E-01, 0.74492500E+00, 0.41512100E+00, -.98748800E+00, -.29904700E+03, 0.51128600E+02, 0.12094700E+04, -.60244700E+03, -.58790900E+03, -.60458500E+03, 0.33680700E+03, 0.21129600E+03, -.10026000E+04, -.80679600E+02, -.60022100E+03, 0.19782100E+03, -.14544700E+04, -.94763800E+03, 0.48086900E+03, 0.32699100E+03, 0.47404300E+03, -.43198900E+03, -.44590200E+03, 0.69954700E+03, 0.15508900E+01, 0.14272000E+03, -.31903400E+03, 0.94055800E+03, 0.84167400E+03, -.42422600E+03, -.83733500E+03, -.42092000E+03, -.22068300E+03, -.47446900E+03, 0.68225300E+03, 0.11487900E+04, 0.11099500E+04, -.52521800E+03, -.17757200E+04, 0.10650800E+04, -.52554100E+03, -.25478800E+03, -.53214200E+03, -.15562000E+03, -.17492400E+03, -.10813100E+03, 0.11792200E+03, -.32311800E+03, -.12358100E+03, -.57522400E+03, -.52286200E+03, 0.25937900E+03, 0.55043800E+03, 0.26129400E+03, 0.23348500E+03, -.45239100E+02, 0.67775700E+03, 0.72471000E+03, 0.78717200E+03, -.38025100E+03, -.57716200E+03, -.36778300E+03, 0.19050000E+03, 0.24903000E+03, 0.18422100E+03, -.26234900E+03, -.10323100E+03, -.39561100E+03, -.73025700E+03, -.49292100E+03, 0.47392900E+03, 0.10435700E+04, 0.25355200E+04, -.12609000E+04, -.67615100E+03, -.12680600E+04, 0.65526900E+02, 0.96187800E+02, -.94291700E+03, -.22293200E+03, -.10200600E+04, -.72783000E+01, -.93995400E+03, -.93238700E+03, 0.46142500E+03, 0.10737700E+04, 0.46603700E+03, -.86904100E+02, 0.72972700E+02, -.16839500E+03, -.42249100E+03, -.38640400E+03, 0.42831300E+03, 0.42040400E+03, 0.21863200E+03, -.11397100E+03, 0.30362200E+03, -.11013600E+03, -.39187400E+03, -.68206300E+03, 0.56251300E+03, 0.49771300E+03, -.32885700E+03, -.56405600E+03, 0.94009800E+03, -.15795600E+04, 0.79394900E+03, 0.59512100E+03, 0.78981600E+03, 0.25495200E+03, -.10116900E+04, 0.75844700E+03, 0.83574400E+03, 0.67686800E+03, -.77231700E+03, -.21113900E+03, -.34178900E+03, 0.17575000E+03, -.19043700E+03, 0.17111000E+03, 0.45924200E+03, -.37598900E+03, -.46766000E+03, -.36693500E+03, -.12909200E+02, -.21477200E+03, -.36553700E+03, -.14425100E+04, 0.71250500E+03, 0.76187300E+03, 0.72244500E+03, -.78204100E+01, -.89225300E+02, -.84840600E+03, -.44740000E+03, -.97987300E+03, -.56391500E+01, 0.54627800E+02, -.32956500E+03, 0.17069400E+03, -.91387100E+03, 0.16633600E+03, -.24963500E+02, 0.27963800E+03, -.32888600E+02, -.14038600E+02, 0.41608600E+03, 0.25362900E+03, -.49628500E+03, 0.48920400E+02, -.18069000E+02, 0.29480900E+03, -.24621400E+02, -.13336900E+03, -.22166100E+03, 0.94014800E+03, 0.20922600E+03, 0.44111100E+03, -.32805700E+03, 0.51157100E+03, -.15033600E+04, 0.74308500E+03, 0.88924200E+03, 0.75132200E+03, -.23842600E+03, 0.44053500E+03, 0.61459500E+03, -.24335500E+03, 0.30032700E+03, 0.10067100E+03, 0.98416800E+03, 0.36095300E+02, -.51756800E+02, 0.43164800E+01, 0.54816600E+01, -.10691900E+03, -.65835200E+02, 0.59793900E+02, -.10136500E+03, 0.16342000E+03, -.13169900E+02, -.23891800E+03, 0.56894000E+02, 0.63132300E+02, 0.19903100E+03, -.22484800E+02, -.22644600E+02, -.78881500E+02, 0.71937700E+02, 0.30542600E+02, -.25996400E+03, -.86785800E+02, 0.11991900E+03, -.89899600E+02, -.17416600E+03, -.87372600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.64087600E+01, 0.27973000E+00, -.33308900E+01, 0.31441100E+01, 0.13584700E+01, -.20534500E+01, 0.68608500E+00, 0.10130400E+00, -.89194600E+00, 0.14961100E+01, 0.95908600E+00, -.76022000E+00, 0.44594800E+00, -.34784500E+00, -.80612800E+00, 0.11759600E+01, 0.81015000E+00, -.29301200E+00, -.15096400E-01, -.31823000E+00, -.16704400E+01, -.56738900E+00, 0.28318500E+00, 0.26336100E+01, 0.47780300E+00, 0.55142700E+00, 0.26100300E+01, -.13867600E+01, -.13507400E+01, 0.39620400E+00, 0.31376200E-01, 0.58210700E+00, 0.12435600E+01, -.19468000E+01, 0.38720700E+00, -.23344000E+00, 0.10147900E+00, -.10854700E+00, -.91302600E+00, -.12301500E+01, -.73356100E+00, -.48214400E+00, 0.22316600E+01, -.20678600E+00, -.64569100E+00, -.24261700E+00, -.48883100E+00, -.96864100E+00, 0.62212600E+00, 0.14487900E+00, -.44941800E-01, 0.52949600E+00, -.54932300E+00, -.12097600E+01, 0.68977500E+00, 0.19569700E+01, 0.31909400E+00, 0.59316300E-01, -.11185500E-01, 0.13178100E+01, -.25615200E+01, -.72237500E-01, -.29043600E+00, 0.40720400E-01, -.14160400E+00, -.97140500E+00, 0.18587900E+00, -.29472800E+01, -.45529100E+00, 0.12605000E-01, -.50822600E+00, 0.11259600E+01, 0.12635600E+01, 0.80494800E+00, -.87440100E+00, 0.61818700E+00, 0.20665100E+00, 0.74540600E-01, 0.51389800E+00, 0.23368600E+00, -.10182000E+00, -.14938500E+01, -.29117500E+00, -.56189800E+00, -.10036900E+00, 0.86047000E-01, 0.11938600E+01, 0.31132500E-01, -.45539900E+00, 0.14642500E+01, 0.10428400E+01, -.59765900E-01, 0.92554500E+00, -.48620100E+00, 0.55411800E+00, -.42201200E+00, 0.20387700E+00, -.14355500E+00, -.86424800E+03, -.13760000E+04, 0.69367300E+03, -.17278200E+04, 0.68778200E+03, 0.86377400E+01, -.29583400E+03, 0.77070000E+03, 0.67144200E+02, 0.11783700E+04, 0.16169900E+03, 0.16893400E+04, 0.59378700E+03, -.27654500E+03, 0.86161100E+03, -.29708700E+03, 0.12170700E+04, -.34846000E+02, -.38502500E+03, -.77047200E+02, -.58881100E+03, -.31867700E+03, -.11806200E+04, 0.25931700E+04, -.13069000E+04, -.43873000E+03, -.12966700E+04, -.21477300E+03, 0.14104100E+04, -.18269400E+04, -.16803200E+04, -.88578500E+03, 0.14432800E+04, -.60628200E+03, 0.23179400E+03, -.15495800E+03, 0.47441300E+03, -.11668900E+03, -.22725500E+03, -.65427700E+02, 0.74981800E+02, 0.34912800E+02, -.19251500E+02, -.16214700E+02, 0.19784200E+03, -.57248900E+03, 0.27004300E+03, 0.21342900E+03, 0.28639500E+03, -.44345600E+03, -.32755200E+03, -.79960000E+03, -.19291300E+04, -.21565700E+03, -.18397600E+03, 0.19184100E+02, -.85359800E+03, 0.44320700E+03, -.62942500E+03, 0.42664900E+03, 0.41873000E+03, -.55718200E+03, 0.91442200E+03, 0.10606900E+04, 0.35158300E+03, -.49456500E+03, -.30951800E+03, 0.12387400E+04, -.60639400E+03, -.27948800E+03, -.61845800E+03, -.68965300E+02, 0.41027200E+03, 0.59135200E+03, 0.12043300E+04, -.75653700E+02, 0.25383000E+03, -.40251200E+03, 0.16140700E+04, -.81165000E+03, 0.33242200E+03, -.80707900E+03, -.24449400E+03, -.20390900E+03, 0.35158800E+03, 0.90972400E+03, -.38068200E+02, -.62031600E+03, -.65859700E+03, -.98108800E+02, 0.54564300E+02, 0.89999900E+03, 0.49675600E+02, 0.32811500E+03, -.10404500E+03, 0.13353900E+03, 0.31021400E+03, 0.36570200E+03, -.55742600E+03, -.97578000E+03, -.24231200E+04, 0.12065300E+04, 0.14440300E+04, 0.12115400E+04, -.11072600E+04, -.86763200E+03, 0.12116100E+04, -.15475700E+03, 0.57214900E+03, -.66798800E+03, 0.62710400E+03, -.96703700E+03, 0.49195100E+03, 0.26092700E+03, 0.48337000E+03, -.24339900E+03, 0.45508900E+03, 0.10575200E+04, 0.10319600E+04, 0.32377700E+03, 0.32835600E+03, 0.41936400E+03, 0.31393100E+04, -.15551300E+04, 0.27061700E+04, -.15707600E+04, 0.77004900E+03, 0.75352200E+03, 0.33041000E+03, 0.37380700E+03, -.22745200E+04, 0.30667800E+03, -.21923600E+04, -.15355500E+03, 0.23018500E+01, 0.12256800E+04, 0.74910400E+02, -.22571700E+03, -.39281900E+03, 0.10803800E+03, -.12593600E+03, -.16960000E+01, -.10304000E+02, 0.10095600E+04, -.38157800E+03, 0.18229200E+03, 0.10673600E+04, 0.19131600E+03, -.27409100E+03, 0.49876900E+02, -.48292600E+03, 0.14550800E+03, 0.59957200E+02, -.33249400E+03, -.32961300E+03, 0.20317300E+03, -.10072700E+03, 0.18443200E+03, -.10135100E+03, 0.95039800E+03, -.53061900E+03, -.11801400E+04, -.97230500E+03, 0.15022900E+03, -.71527900E+03, -.12388700E+04, 0.40372900E+02, -.13015900E+03, -.51102100E+02, 0.14221600E+02, 0.33608200E+03, -.11049700E+03, 0.11108000E+03, 0.35009800E+03, -.46994700E+03, 0.80034200E+02, 0.59083200E+02, -.62971200E+01, 0.27838400E+03, -.41579700E+03, -.29892100E+03, -.36398900E+02, -.25678900E+03, -.14477200E+03, 0.24170000E+03, -.63467700E+01, 0.25236700E+03, 0.91403800E+02, 0.35009300E+03, -.11861300E+03, 0.15637600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36348900E+01, -.35719300E+00, -.12000700E+01, 0.12630800E+00, -.97663200E+00, 0.25723500E+00, -.18520600E+00, -.30324500E+00, 0.30681900E+00, -.64751900E+00, 0.15992800E+01, -.22104000E+01, -.17677100E+01, 0.59742500E+00, -.41155700E+00, -.45496800E-02, -.89994400E+00, -.62919800E-01, 0.10855900E+01, -.65869100E+00, 0.84972600E+00, 0.27268400E+00, -.11826700E-01, -.32342500E+00, -.15543000E+00, -.72096000E+00, 0.23800100E+00, 0.27356300E+01, -.76539200E+00, 0.31106800E+00, 0.18226700E+00, -.50774200E-01, -.34873800E+00, 0.65239400E+00, -.21574500E-01, -.79628300E+00, -.67152500E-01, -.14534100E+00, -.10919000E+01, 0.34217400E+00, -.32692300E+00, -.80008200E-01, -.16295800E+01, -.65043400E-01, 0.27467400E+00, -.26258500E+00, -.95826600E+00, 0.10761000E+01, 0.10861400E+01, 0.71951700E-01, 0.89208800E+00, -.71870600E+00, 0.54387800E+00, 0.53021800E+00, -.67239900E+00, -.13014300E+01, -.48568300E+00, 0.83335800E+00, 0.53583900E-03, -.16436800E+01, 0.17824800E+01, 0.10432600E+01, -.27880000E+00, 0.10240700E+01, 0.16577700E+01, -.38409100E+00, 0.61866100E+00, 0.75766600E-01, -.94158800E-01, -.21223000E-01, -.34573000E+00, 0.57244200E-01, 0.77536300E+00, -.75826500E+00, 0.70652000E+00, -.94442100E+00, 0.23053500E-01, -.18148400E+00, -.29245100E+00, -.38869900E+00, 0.84880600E-01, -.12692000E+01, 0.49569700E+00, -.42232500E+00, -.11780100E+00, -.65907900E-01, 0.76844800E+00, 0.56221200E+00, -.58782900E+00, 0.72546300E+00, -.53175100E+00, -.49072300E-01, 0.10687400E+00, -.33690600E+00, 0.60010700E+00, 0.44087000E+00, -.13425300E+01, 0.88533700E+00, 0.27700600E-01, -.23800900E+04, 0.11942600E+04, 0.59247300E+03, 0.11898200E+04, 0.18643400E+03, 0.12068300E+03, 0.79436500E+03, -.73544400E+03, -.18698100E+03, 0.31711400E+03, 0.15539200E+04, 0.11616700E+04, -.57394200E+03, -.79216000E+02, -.58116400E+03, 0.58724800E+03, 0.19258200E+03, -.53623300E+03, 0.30885700E+03, -.80454900E+02, 0.14753200E+02, -.89045600E+02, -.57964200E+03, 0.28629900E+03, 0.10887200E+04, 0.28994300E+03, 0.33041300E+03, 0.76369500E+03, -.96962400E+03, -.17449900E+04, -.15358300E+04, 0.81149600E+03, 0.88874200E+02, -.24298100E+03, 0.10964200E+03, 0.68094400E+03, 0.12092000E+03, -.13395300E+03, -.90747900E+02, 0.19054600E+03, -.11658500E+02, 0.16455200E+02, -.73834200E+02, 0.13842200E+03, 0.51887600E+03, -.26573800E+03, -.52721700E+02, -.25924100E+03, -.14271800E+03, -.25761400E+03, -.85902000E+03, -.12138500E+04, -.45831200E+03, -.83830700E+02, -.25766100E+03, 0.83218900E+03, -.40808000E+03, -.80952700E+03, -.41657300E+03, 0.23926500E+03, 0.15345900E+03, 0.87335800E+02, 0.48939900E+03, -.21957000E+03, -.20483000E+03, -.12589800E+03, -.14058000E+04, 0.70943700E+03, 0.37838900E+03, 0.70354100E+03, -.26393100E+03, -.14666900E+03, 0.75987500E+03, 0.24612500E+03, 0.80971600E+03, -.20440800E+02, 0.22236200E+03, 0.10818500E+04, -.54398800E+03, -.10392700E+04, -.54069900E+03, -.44469300E+02, -.86031100E+02, 0.13777100E+03, 0.90881800E+03, 0.65212700E+03, -.53697500E+03, -.56855300E+03, 0.11412900E+03, -.60307300E+02, -.23629900E+03, -.55869900E+02, 0.21948300E+03, 0.33782800E+03, -.15426600E+03, 0.94110600E+02, 0.36289700E+03, 0.10785400E+03, -.59541400E+03, -.61594400E+03, 0.30858700E+03, 0.23448100E+03, 0.30792000E+03, -.23599000E+03, 0.44428200E+03, 0.34531500E+03, -.33736000E+03, -.17927900E+03, 0.49678300E+03, 0.89852300E+03, 0.51073500E+02, -.21151400E+02, 0.28279700E+03, -.25852100E+02, -.45052500E+03, 0.37857800E+03, 0.60230000E+03, 0.52117000E+03, -.29453200E+03, 0.32564300E+03, 0.54549500E+03, 0.10691200E+04, -.53584800E+03, 0.70534200E+02, -.53629300E+03, 0.49631700E+03, 0.68336000E+03, 0.30169900E+03, 0.20091400E+02, 0.53369300E+03, 0.55712500E+03, -.91795500E+02, 0.51967300E+03, -.28337800E+03, 0.15398800E+04, -.26209900E+03, -.24861400E+03, -.55254100E+03, 0.27388200E+03, 0.13797500E+03, -.64886900E+03, -.40618200E+03, -.13957200E+03, 0.20296500E+04, -.10155500E+04, -.87366100E+03, -.10145900E+04, -.71906100E+03, -.41695400E+03, -.47571500E+03, 0.98562000E+03, 0.17503100E+03, -.50467900E+03, -.94640000E+03, 0.13998400E+04, -.70294300E+03, -.69561500E+03, -.69939400E+03, 0.35466200E+03, -.29003100E+03, -.80535900E+03, 0.25635400E+03, -.10333100E+03, -.52626800E+03, -.32818100E+03, 0.33704700E+02, 0.13032600E+02, -.98503800E+02, 0.32930800E+02, 0.23126200E+03, 0.54668800E+02, -.45890600E+02, 0.22497600E+03, -.35211900E+03, -.25706900E+02, 0.44166300E+02, 0.52184200E+02, 0.62706100E+02, -.29693200E+03, -.11577100E+03, 0.60815000E+01, 0.10715700E+03, -.16062000E+03, -.34551700E+02, 0.25007100E+03, -.53202300E+00, -.76832700E+02, 0.13772500E+03, 0.20630800E+02, 0.79129500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39328500E+01, -.46143400E+00, -.12578100E+01, -.72764700E+00, -.20363200E+01, -.11480200E+00, -.88796500E-01, -.20497300E+00, -.37917400E+00, -.59183800E+00, -.30682000E+00, -.66665400E+00, -.78521500E+00, -.84844200E+00, 0.19217100E+00, -.22107200E+00, -.12791700E+01, -.18879200E+00, -.15286800E+00, -.81579000E+00, 0.29785400E+00, 0.25212500E-01, -.15448600E+00, -.82498200E+00, 0.25981100E-02, 0.48969400E+00, 0.17989000E+01, 0.75639900E+00, 0.16563100E+00, 0.25982300E+00, 0.66888500E-01, 0.24364800E+00, -.99164600E+00, -.61478300E+00, 0.90147900E-01, 0.14535400E+01, 0.13848000E-01, 0.70030600E-01, 0.52491000E+00, -.79346100E+00, -.64732100E-01, -.59193500E+00, 0.31554500E+01, -.66082100E-02, -.62622800E+00, 0.26090000E-01, -.58359100E+00, 0.33181200E+00, 0.35161700E-01, -.20398000E+00, -.51033000E+00, -.56699900E-02, -.91784200E+00, -.72188900E+00, 0.34650000E+00, -.10924800E+01, -.16639600E+00, 0.82732200E+00, -.62982600E-02, -.14851900E+01, 0.85539000E+00, 0.40061700E+00, -.11235400E+00, 0.20977200E+00, 0.86965100E+00, 0.20581300E+00, 0.96419000E-01, 0.12085100E+01, -.11728500E+00, 0.43165700E-02, -.56517400E-02, 0.19671900E+00, 0.72152700E+00, -.15886400E+00, -.89397000E+00, 0.44470300E+00, 0.90299200E-01, -.39999600E+00, -.18185100E+00, -.35327400E+00, -.13086700E-02, -.25704300E+00, -.16398600E+00, -.71115900E-01, 0.93330900E-01, 0.51467400E-01, 0.24431400E+00, 0.62119400E-01, 0.58409500E+00, -.11655900E+00, -.70944400E+00, -.17141800E-01, -.38798300E+00, -.13263200E+00, 0.11840800E+00, -.89519200E-01, 0.13902700E+01, -.26235000E+00, 0.62316100E-01, -.39972400E+00, 0.86393100E+01, -.98636000E+03, -.16646200E+00, -.60066000E+02, -.48739200E+03, 0.88594200E+03, 0.59098900E+03, 0.75580200E+03, -.18975000E+03, -.12124100E+03, 0.13775700E+04, -.68575200E+03, -.98777700E+02, -.68897500E+03, 0.23386600E+03, -.61774800E+02, -.52903600E+03, 0.18073500E+02, -.77232600E+03, -.22557600E+03, -.59308000E+03, 0.11030700E+04, -.55197400E+03, -.72937400E+03, -.55153400E+03, -.46693600E+03, 0.75211800E+03, -.50527100E+03, -.67781500E+03, 0.89794800E+02, 0.77229700E+03, -.70482500E+03, 0.21538400E+03, -.13569800E+03, 0.40191900E+03, -.10823100E+03, -.15947000E+03, -.29775100E+03, 0.27254400E+03, 0.11833600E+03, -.25670300E+02, -.19910600E+03, 0.48842700E+02, -.11642500E+04, 0.57217900E+03, 0.16867100E+03, 0.58225600E+03, -.10010100E+03, 0.18906300E+03, -.33116200E+03, -.10154100E+04, 0.10700200E+03, 0.20782300E+03, 0.68398400E+03, -.83096500E+03, 0.42330000E+03, -.33625800E+03, 0.41525800E+03, 0.15159800E+03, -.54183300E+03, 0.73306400E+03, 0.82889500E+03, 0.50702600E+03, -.51517900E+03, -.43592800E+03, -.54447700E+02, 0.32141400E+02, -.18716400E+03, 0.28822000E+02, -.34476400E+03, 0.13813400E+03, 0.76687600E+03, 0.10268000E+04, 0.12819000E+03, -.23028300E+02, 0.25463500E+03, 0.13464100E+04, -.67940700E+03, 0.58701100E+03, -.67314400E+03, -.29284100E+03, 0.19534500E+02, -.10917500E+03, 0.36357200E+03, -.30001000E+03, -.33031400E+03, -.58071800E+03, 0.17602200E+04, -.88739000E+03, -.19469000E+03, -.87945000E+03, -.22043200E+03, -.66664600E+03, 0.22212200E+03, 0.77344900E+03, 0.18989400E+02, -.10385700E+04, -.81336300E+03, -.12051700E+04, 0.60698400E+03, 0.11145000E+04, 0.60255700E+03, -.40929100E+03, -.69412400E+03, 0.51045700E+03, -.43316200E+03, 0.28185100E+03, -.57213300E+03, 0.33956400E+03, -.63245500E+03, 0.32085900E+03, -.12672200E+03, 0.31606100E+03, 0.11238000E+02, 0.24588900E+03, 0.74560700E+03, 0.80099500E+03, 0.35438900E+03, 0.17999200E+03, 0.57794800E+02, 0.33257300E+04, -.16563600E+04, 0.12317500E+04, -.16639200E+04, 0.39597800E+02, 0.53952800E+03, -.44621900E+03, 0.17860100E+02, -.25273500E+04, 0.33315600E+03, -.19428200E+04, -.56381500E+03, 0.23012900E+03, 0.10695400E+04, 0.28036200E+03, 0.68658700E+02, -.43116800E+03, 0.34696100E+03, -.33867900E+03, 0.10984600E+03, -.10433600E+03, 0.36223100E+03, -.86011400E+03, 0.41689800E+03, 0.51013200E+03, 0.43036100E+03, 0.25675900E+02, 0.54974800E+02, -.28497800E+03, -.16236000E+03, 0.38865500E+03, -.17582400E+03, 0.91106900E+03, 0.65162900E+02, -.35435400E+02, 0.38717800E+03, -.32309000E+02, 0.68783400E+03, -.33500400E+03, -.67109500E+03, -.52570600E+03, 0.62272200E+01, -.43117500E+03, -.55580900E+03, 0.10504200E+03, -.11542800E+03, -.17375200E+02, -.14027200E+03, 0.71099100E+02, -.76423000E+02, 0.97678000E+02, 0.85000700E+02, -.24177800E+03, 0.11999100E+03, 0.17508300E+03, 0.13554400E+02, 0.18516300E+03, -.17412700E+03, -.18815300E+03, -.14500200E+03, -.15869700E+03, 0.48108700E+01, 0.85532400E+02, -.32505400E+02, 0.20102800E+03, 0.35632900E+02, 0.86148100E+02, -.39186000E+02, -.51989900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44128400E+01, 0.53319000E+00, -.38678700E+01, -.24131400E+01, 0.59760000E-01, 0.42422500E+00, -.46200100E+00, 0.15347900E+00, -.12340500E+00, -.14192300E+01, -.24665200E+00, -.12124800E+00, 0.39987500E-01, -.35808500E+01, -.17203300E+00, 0.32603100E+00, -.22830500E+00, -.19921700E+01, -.20495500E+01, 0.11425100E+00, 0.17164600E+01, -.15263800E+00, 0.50336000E+00, -.98653600E+00, 0.11886400E-01, 0.48111500E+00, 0.12417000E+01, -.37030000E+00, -.27829300E+00, 0.26518800E+00, -.12737400E+00, 0.29805500E+00, -.37431900E+00, 0.72419000E+00, -.14703500E+00, -.66375800E+00, 0.78092300E-01, -.23038800E+00, -.28876800E+00, -.11899600E+01, -.74807700E+00, 0.30497700E-01, -.15398300E+01, -.12070400E+00, 0.91378200E+00, -.91948600E-01, 0.34624200E+00, -.12132500E+01, 0.11574000E+00, 0.11645400E+00, -.20134300E+00, -.39018800E+00, 0.17094300E+00, 0.14424000E+01, 0.52651900E+00, 0.10393400E+01, 0.27629400E+00, -.13165500E+01, 0.23544300E-02, 0.19863700E+01, -.15813600E+01, -.49500200E+00, 0.49522200E-01, 0.14795600E+00, -.93950500E+00, 0.23995400E+00, -.19368800E+00, -.24661200E+01, 0.69114900E-01, 0.13474700E-02, -.37269900E+00, 0.10170100E+00, -.97107900E+00, 0.47810500E+00, 0.40024200E+00, -.11947600E+01, 0.11920700E+00, 0.99437600E+00, -.40317600E-01, 0.53133200E+00, -.26623500E-01, -.11551700E+01, 0.25758700E+00, 0.30263400E+00, -.19638600E+00, -.13237100E+00, 0.41976600E+00, -.58264300E+00, -.79393700E+00, 0.79607400E+00, 0.22309900E+01, 0.66321800E-02, 0.72733900E+00, -.89832000E-01, -.13218700E+01, 0.65575400E-01, 0.17096000E+00, -.56733200E-01, 0.19826900E+00, -.26241500E+00, -.18864000E+00, 0.12945100E+04, -.40350500E-01, -.19985500E+03, 0.36244700E+03, 0.28815100E+02, 0.99141000E+02, -.45068100E+03, 0.21578400E+03, 0.67084200E+03, -.46762700E+03, 0.22965800E+03, 0.14737800E+02, 0.23373100E+03, -.10839600E+03, 0.40370400E+02, 0.20132400E+03, 0.40827800E+03, 0.51778500E+03, 0.49417000E+02, 0.29384100E+03, -.75036600E+03, 0.37911600E+03, 0.63438700E+03, 0.37523900E+03, 0.19303900E+03, -.56969800E+03, 0.22351300E+03, -.22927900E+03, -.87623200E+02, -.49283300E+03, 0.29011200E+03, -.38667000E+03, 0.20643900E+03, 0.64056000E+02, 0.19327200E+03, 0.62357300E+02, 0.64334600E+02, -.45728300E+01, -.14644400E+03, 0.19353600E+02, 0.54861200E+02, 0.10568800E+03, 0.84689800E+03, -.41643400E+03, -.10927900E+03, -.42340800E+03, 0.49271700E+03, -.10963400E+03, -.24317000E+03, -.12789300E+03, -.44915000E+03, -.40538600E+02, -.81548300E+03, 0.92700500E+03, -.46705500E+03, 0.34864000E+02, -.46363800E+03, -.37037300E+03, 0.25846400E+03, -.29676100E+03, 0.56078300E+02, -.32445700E+03, 0.48808000E+02, 0.61838400E+03, -.17757300E+04, 0.88776800E+03, 0.47579200E+03, 0.88811300E+03, 0.38642100E+02, -.17558600E+03, 0.22972300E+03, -.43212000E+03, 0.66787500E+03, -.28211600E+02, 0.51226600E+03, -.18221100E+03, 0.92060500E+02, -.12015500E+04, 0.91184700E+02, 0.33710500E+02, -.36126600E+03, 0.73066000E+02, -.15564700E+03, 0.41165200E+03, -.28859800E+03, -.18191900E+03, -.10543200E+04, 0.52283000E+03, -.35771400E+03, 0.52746700E+03, 0.51651700E+03, 0.64029700E+03, -.19687800E+03, -.33000300E+03, 0.23518400E+03, 0.64804400E+03, -.37883300E+02, 0.34383100E+03, -.16775000E+03, -.79908700E+03, -.17192900E+03, 0.45204300E+03, 0.11464500E+04, -.18829400E+03, 0.33365600E+03, -.19191000E+03, 0.91449600E+03, -.97390100E+02, 0.13950800E+03, -.69732200E+02, 0.43417200E+03, -.69838200E+02, -.32004200E+03, 0.10241300E+03, -.30095800E+02, -.72394800E+02, -.13790300E+03, 0.75554300E+02, 0.37933800E+03, -.11639600E+04, 0.57500300E+03, -.11326900E+04, 0.58157000E+03, -.22619900E+03, -.22808200E+03, 0.35636200E+03, -.30749500E+02, 0.11210200E+04, -.12215300E+03, 0.91249200E+03, 0.36316000E+03, -.16126500E+03, -.19444800E+03, -.18205800E+03, -.10748000E+03, -.17552000E+03, 0.46722800E+02, 0.21755500E+02, -.14167400E+03, -.18875600E+03, -.41913900E+02, 0.25801700E+03, -.12731100E+03, -.82313200E+03, -.12901100E+03, 0.19203100E+03, -.35111400E+02, -.26253300E+03, -.14318600E+03, 0.11172200E+03, 0.64341500E+02, -.60342700E+03, 0.48917500E+03, -.25173300E+03, -.44225500E+03, -.24444600E+03, -.28237300E+03, -.34533300E+03, 0.15795800E+03, 0.46707200E+03, 0.14721500E+03, -.27308900E+03, 0.11527900E+03, -.84390400E+02, 0.68369000E+02, 0.17452600E+02, 0.32469500E+02, 0.22485100E+02, 0.63055600E+02, -.76175500E+02, 0.18741100E+02, 0.15279800E+02, -.66211600E+02, 0.73333400E+02, 0.67096600E+00, 0.28585600E+02, 0.94308500E+00, -.33366400E+02, 0.29336900E+01, 0.11868300E+03, -.32880000E+02, -.13842400E+02, 0.14068800E+03, -.50053900E+02, -.10959500E+02, -.71833600E+00, 0.60236200E+02, 0.94885700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.93588400E+01, -.10564100E+01, -.67690200E+00, 0.42598400E+01, 0.80764700E+01, 0.32296200E+00, -.22235200E+01, 0.52997200E+00, 0.20417600E+00, -.16206500E+01, -.22446600E+01, 0.16196100E+01, 0.26463200E+01, 0.20308400E+01, -.63674300E+00, -.20607900E+01, -.12436200E+00, -.74417100E+00, 0.18611500E+00, -.15871800E+01, -.15950600E+01, -.75614100E-01, -.16434700E+01, -.31515900E+01, -.25896800E+00, -.19718100E+01, 0.18117000E+01, -.49079200E+01, -.11709600E+01, 0.12689000E+00, -.17378900E-01, -.23160300E+01, 0.35182100E+01, -.25763300E+01, 0.56863500E+00, 0.97696500E-01, -.44532800E-01, 0.16468800E+00, -.64440900E+00, 0.60370600E+00, -.46376800E+00, -.18341800E+00, -.59731000E-01, 0.11889700E+00, 0.84396600E+00, 0.24626300E+00, -.64721100E+00, 0.12479500E+01, 0.13726200E+00, -.17406600E-01, 0.16085400E+01, -.95286200E+00, 0.63574700E+00, 0.38705000E+00, -.84316100E+00, -.17866400E+01, -.18663200E+00, 0.24929700E+00, 0.85527200E-03, -.64544400E-01, 0.21652500E+01, 0.85391800E+00, -.34628200E+00, -.25333200E+00, -.38135500E+00, -.66584100E+00, -.15722800E+00, 0.24417900E+00, 0.20846200E+00, -.91687400E-02, -.11222900E+00, -.68337600E+00, -.16823300E+01, 0.31870800E+00, -.17906900E+01, 0.68621500E+00, -.35541600E+00, -.12646700E+01, 0.82825900E-01, -.49428500E-01, 0.19439900E-01, 0.11805300E+01, 0.15303200E+00, 0.49875000E+00, 0.35740000E+00, -.19004900E+00, -.13476100E+01, 0.52231100E-01, -.10784000E+01, -.47669300E+00, -.81098800E+00, 0.99497300E-01, 0.98612600E+00, -.13681000E+00, -.39983900E+00, 0.50144600E+00, 0.48116800E+00, 0.36680200E+00, -.85896800E+00, 0.25073300E+00, 0.30424800E+00, -.21131300E+00, 0.35918500E+01, 0.13480100E+02, -.32767400E+03, -.26598600E+03, -.42675700E+03, -.10873200E+04, -.20921100E+03, -.13814500E+04, -.66501200E+02, 0.39428100E+02, -.36826800E+03, 0.33729600E+02, -.49222500E+03, 0.27570200E+03, -.15167100E+03, -.33605600E+03, -.19053300E+03, 0.39291100E+03, 0.30743100E+03, -.88758500E+03, 0.44016300E+03, 0.32580300E+03, 0.44366900E+03, 0.61065700E+02, -.64698600E+03, 0.12125400E+04, 0.11456000E+04, 0.72994000E+03, -.78907000E+03, 0.56492000E+03, -.12156300E+03, 0.70124500E+02, -.42269000E+03, 0.61783500E+02, 0.15414900E+03, 0.13500200E+03, -.18783800E+03, -.30515600E+03, -.67847300E+02, 0.11972600E+03, 0.10647300E+02, -.29107700E+04, 0.14553700E+04, 0.73326100E+03, 0.14550800E+04, 0.94916100E+02, -.25256700E+03, 0.12480600E+04, 0.39829900E+03, 0.16116500E+04, -.44135200E+03, 0.14511400E+04, 0.36266400E+02, -.13941600E+02, 0.49735100E+03, -.17473300E+02, 0.32772000E+03, 0.39505000E+03, 0.51460300E+02, 0.80492400E+03, 0.38429500E+02, 0.44579300E+03, -.10916300E+04, 0.14996200E+04, -.74368200E+03, -.88777400E+03, -.75552500E+03, 0.19165400E+03, -.48918800E+03, -.85593100E+03, -.47944900E+03, -.66584500E+03, -.51141800E+03, -.23329800E+03, -.22695700E+03, 0.11021100E+03, 0.87669600E+03, 0.11320200E+03, 0.25258900E+03, 0.67060000E+03, -.50898100E+03, -.26422800E+03, -.27915400E+03, 0.67394900E+03, 0.18611100E+03, 0.12422600E+04, -.62401700E+03, 0.61100000E+02, -.62285600E+03, -.35096300E+03, -.19459400E+03, -.26846700E+03, 0.10128900E+03, -.69623000E+03, -.18221800E+02, 0.20546800E+03, 0.32345500E+04, -.16142200E+04, -.23837300E+02, -.16172000E+04, 0.10647700E+03, -.43462500E+03, -.95865500E+03, 0.91380100E+02, -.13796100E+04, -.20988800E+03, -.18031700E+04, 0.91681700E+03, -.45452100E+03, -.70080700E+03, -.45795900E+03, 0.57925200E+03, -.36076100E+03, -.77007600E+03, -.50227700E+03, -.68696500E+03, -.13908500E+03, -.12371500E+04, -.17423300E+04, 0.86327500E+03, 0.71493500E+03, 0.87374200E+03, 0.62322900E+03, 0.81326700E+03, -.12025000E+04, -.95560800E+03, -.35675600E+03, 0.68257200E+03, 0.16226700E+03, -.62689500E+03, 0.32565100E+03, -.13149300E+04, 0.31695100E+03, 0.28457900E+02, 0.44689900E+03, -.99118700E+02, -.47960600E+03, 0.28423900E+03, 0.28088400E+03, 0.25701700E+02, 0.12061900E+04, -.59437400E+03, -.54722300E+03, -.60356900E+03, -.30892900E+01, -.63061700E+02, 0.33654700E+03, 0.38071300E+03, 0.49754200E+03, -.54119800E+01, 0.51623500E+03, -.25464400E+04, 0.12659000E+04, 0.36694000E+03, 0.12724700E+04, -.44416200E+03, 0.88291200E+03, 0.11489400E+04, 0.17961500E+03, 0.11612400E+04, 0.84193600E+03, 0.42193300E+03, 0.34563900E+01, 0.57067700E+02, 0.43786400E+02, 0.30233000E+02, 0.52295100E+02, -.22598200E+02, 0.53142500E+02, 0.55748400E+02, 0.18685300E+03, -.70358800E+02, -.18674200E+03, 0.37171200E+01, -.60400900E+02, 0.14005700E+03, 0.37767000E+02, 0.64457600E+02, 0.11366700E+03, -.22752300E+02, -.14469400E+03, 0.46862600E+02, -.18159700E+03, 0.74264600E+02, 0.54649900E+02, -.72971000E+02, -.34444900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.82473700E+01, -.93225800E+00, 0.35827500E+01, 0.30080600E+01, 0.15721100E+01, 0.25498800E+00, -.74282500E+00, 0.32492700E-02, 0.51742200E-01, 0.12685700E+00, -.57898900E+00, -.12414500E+00, -.49503900E+00, 0.70893300E+01, 0.15349100E+01, -.10210000E+01, 0.15382100E+01, 0.45850000E+01, 0.24423000E+01, 0.18261200E+00, -.32567900E+01, 0.43676300E+00, -.70442400E+00, -.88982300E+00, -.33370600E+00, -.11887700E+01, -.31561900E+01, -.21597600E+01, 0.15957700E+01, -.84277900E+00, 0.56588400E-01, -.22709300E+00, 0.69147200E+00, 0.47196600E+00, -.67706300E-03, -.12993700E+01, -.96131600E-01, 0.16432500E+00, 0.11807200E+01, -.45572100E+01, 0.54895500E+00, -.93587700E+00, -.25072700E+01, -.86237800E-01, -.27112400E+01, -.12659500E+01, -.16725600E+00, -.20179900E+00, 0.68662000E+00, -.87473000E-01, 0.55278700E+00, -.85038200E+00, -.28339800E+00, 0.40129300E+00, 0.21633100E+00, -.64957000E+00, -.77326300E-01, 0.62817000E-01, 0.34534100E-02, -.20037500E+01, 0.15322900E+01, -.31092300E-01, 0.16538700E+00, 0.29163400E+00, 0.11253700E-01, 0.55490500E+00, -.20693900E+00, 0.67578100E+00, -.40299600E+00, -.47078000E-02, -.17245300E+00, 0.25197800E+00, -.26850100E+01, -.13009100E+01, 0.10418200E+01, -.17973800E+00, 0.16334800E+00, 0.86584300E+00, 0.14154700E+00, 0.28336200E+00, 0.41308400E-01, 0.93377500E+00, -.36082700E+00, -.20333900E+00, -.31445200E+00, -.57215700E-01, 0.26864500E+00, -.46998200E+00, -.83241400E+00, 0.10311100E+01, 0.98897000E+00, -.41829900E-01, 0.16267800E+01, -.74442100E+00, -.15922000E+01, 0.39471900E+00, 0.99326700E+00, 0.83374400E-01, 0.37939500E+00, 0.64456800E+00, 0.72394200E+00, 0.10302700E+01, 0.78698600E-01, 0.12141300E+04, -.32740500E+02, -.80689000E+03, -.39151800E+03, 0.12183200E+03, -.11820500E+03, -.18883700E+04, -.16224400E+03, 0.83760100E+02, -.56247200E+03, 0.81441300E+02, -.68545400E+03, -.30822100E+03, 0.51184700E+03, -.39616500E+03, -.32593500E+03, -.14380300E+03, -.12482200E+03, 0.37659300E+03, -.19025300E+03, -.12362500E+04, -.18834000E+03, 0.20853300E+03, -.14338200E+02, 0.36857300E+03, 0.10275000E+04, 0.67076100E+03, -.76596800E+02, -.36046400E+03, 0.84145500E+03, -.41199000E+03, 0.54929800E+03, -.41996200E+03, -.10480100E+03, -.14948000E+03, -.98756500E+02, 0.24524200E+03, -.15086700E+03, -.13891600E+03, -.46007900E+03, -.51202400E+02, 0.26778700E+02, -.28455400E+03, 0.25395300E+02, -.57693600E+03, 0.39658500E+03, 0.63037400E+03, 0.13218800E+04, 0.81433300E+03, 0.12115300E+03, 0.63820200E+03, -.10355000E+04, 0.52356700E+03, 0.45464200E+03, 0.51814900E+03, 0.86239600E+03, -.11443400E+03, -.11345800E+03, -.59723000E+03, 0.16631700E+03, 0.24670600E+03, -.84332600E+03, 0.14985100E+04, -.74440300E+03, -.48141100E+03, -.75094800E+03, -.54575200E+02, -.16079100E+03, -.51648600E+03, -.76750100E+02, -.97897400E+03, -.30441900E+03, -.67453200E+03, -.54576100E+03, 0.27054000E+03, 0.13187800E+04, 0.27274800E+03, 0.49525600E+02, 0.11213800E+04, -.54087900E+03, -.61814900E+03, -.13710600E+04, 0.14349000E+04, 0.84705600E+03, 0.10683600E+04, -.53664600E+03, 0.28732700E+03, -.53529600E+03, -.14409800E+04, -.64758800E+03, 0.15296400E+03, -.20935300E+03, -.13142900E+04, -.31736100E+03, 0.73251500E+03, 0.29619800E+04, -.14775700E+04, 0.16949000E+03, -.14809400E+04, 0.46494600E+03, -.99655200E+03, -.94706200E+03, -.82504300E+02, -.10971500E+04, -.77261200E+03, -.22047800E+04, 0.87847600E+03, -.43718900E+03, -.77813800E+03, -.43895000E+03, 0.12050400E+04, -.22775200E+03, -.82776400E+03, -.38822600E+03, -.22265200E+03, -.16496100E+03, -.18111700E+04, -.19086300E+04, 0.94327900E+03, -.27611000E+03, 0.95603200E+03, 0.85718100E+02, 0.60552500E+02, -.25833900E+03, -.26974400E+02, -.17317500E+03, -.21262000E+02, 0.60822300E+02, -.98203700E+03, 0.51596700E+03, 0.84852900E+03, 0.49346800E+03, 0.26383500E+03, 0.76628900E+03, -.48541300E+03, -.49826500E+03, 0.32849400E+02, 0.67807100E+03, 0.41608400E+02, 0.15103600E+04, -.74069800E+03, -.88408000E+02, -.75559200E+03, -.11882200E+04, -.38158500E+03, 0.79636600E+03, 0.43655700E+03, -.37131500E+03, -.24257900E+03, 0.57395100E+03, -.72847100E+03, 0.35891700E+03, -.11130100E+03, 0.36376200E+03, -.64819300E+03, 0.11183300E+04, 0.30439400E+03, -.40842300E+03, 0.36582900E+01, 0.11067700E+04, 0.83669100E+03, 0.13059600E+03, -.56998400E+02, 0.86030000E+02, 0.26423800E+01, -.14525200E+03, -.93548300E+02, 0.12618500E+03, -.14280000E+03, 0.33475200E+03, 0.44252800E+02, -.12623800E+03, -.62028900E+02, -.86343800E+02, 0.37017800E+03, 0.21154400E+03, 0.93976500E+02, 0.55764200E+01, 0.30878200E+03, -.88749700E+02, -.13009800E+03, -.70767400E+01, 0.40396200E+02, -.11018200E+03, -.83844500E+02, -.13842800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.73221400E+01, 0.20881700E+00, -.49361000E+01, -.33895900E+01, 0.12808000E+01, -.15012000E+00, 0.15911800E+00, 0.45469300E+00, -.29974300E-01, 0.75890000E+00, -.13447800E+00, 0.62415700E+00, 0.22519500E+01, -.11906500E+01, -.11745100E+01, 0.75371100E+00, 0.11194300E+01, -.19338600E+01, -.19541700E+01, 0.91086600E-01, 0.22581100E-01, -.49328500E+00, -.81693600E-01, -.34296900E+00, 0.10653900E-01, 0.20786500E+00, 0.10982600E+01, -.42530400E+01, 0.10206200E+00, 0.37461400E+00, -.42623700E+00, -.50573100E+00, 0.29998300E+01, -.43507400E+00, 0.55640600E-01, -.73796300E-01, 0.13216900E+00, 0.52018500E+00, -.13739400E+01, -.76903800E+00, -.25668700E-01, -.52640500E+00, -.29123400E+00, 0.28235200E+00, 0.70650000E+00, 0.17559400E+00, 0.56294900E+00, -.22400000E+01, -.15988300E+01, -.68284400E-01, -.25688300E+01, 0.88793400E+00, -.10440500E+01, -.64227500E+00, 0.10199100E+01, 0.15337300E+01, 0.51021900E+00, -.11990500E+01, 0.13251100E-01, 0.32377500E+01, -.26873500E+01, -.12323700E+01, 0.21454900E+00, -.15255000E+01, -.17159100E+01, 0.10053600E+01, -.83147100E+00, 0.51228000E+00, 0.33276900E+00, -.12979500E-01, 0.44231100E-01, 0.43482300E+00, -.20898200E+01, 0.42394700E-01, -.35351200E+00, 0.93996600E+00, -.46436600E-01, 0.33420800E+00, 0.89535600E+00, 0.63698700E+00, -.10375000E-01, -.80898600E+00, 0.31376100E+00, 0.81916800E-01, 0.93697300E-01, -.27105400E-01, -.29088000E+00, -.65670400E+00, 0.35363400E+00, 0.62045300E+00, 0.47080700E+01, -.52203300E-01, -.59222300E+00, 0.51993800E+00, 0.10004500E+01, -.71242200E+00, 0.20008600E+01, -.10770300E+01, 0.43863300E+00, -.99911500E+00, 0.15236200E+00, 0.11028100E+01, -.21220700E-01, -.48393400E+00, -.11037300E+04, 0.12206200E+04, -.84619400E+03, 0.15518900E+04, -.91535200E+03, -.33281000E+02, -.15475800E+03, 0.10347500E+03, 0.19789500E+03, 0.77414700E+02, -.32629200E+03, -.16789000E+03, -.60334100E+03, -.10031200E+04, -.28395100E+03, 0.53327200E+01, -.63186500E+03, 0.82040200E+03, -.43238100E+03, -.47515700E+03, -.41016100E+03, -.43038700E+03, 0.22629700E+04, -.44714100E+03, 0.65760600E+03, -.19780900E+04, 0.16312000E+04, 0.15631800E+04, 0.27898000E+04, -.13761700E+04, 0.22123900E+04, -.13946800E+04, -.79322300E+03, -.92221200E+03, 0.22860300E+03, 0.36197400E+03, -.11759700E+04, -.67414500E+03, -.13684400E+04, 0.42458700E+04, -.21454400E+04, -.58382800E+03, -.21229700E+04, -.22048000E+02, 0.19619400E+04, -.10000200E+04, 0.23064100E+04, -.12553700E+04, 0.13509800E+04, -.17640700E+04, -.32234300E+04, 0.16274100E+04, 0.48832900E+03, 0.16117300E+04, -.55996300E+01, -.13461200E+04, 0.80479500E+03, -.15238700E+04, 0.83213700E+03, -.87265600E+03, 0.13219000E+04, 0.20331000E+04, -.10044100E+04, -.63942700E+03, -.10169300E+04, 0.10525500E+03, 0.20693100E+03, -.36315000E+03, 0.29003000E+03, -.26746500E+03, 0.10082500E+03, -.11413500E+04, -.79593000E+03, 0.39170200E+03, 0.67562100E+03, 0.39799500E+03, -.37646400E+03, -.68446200E+01, 0.36075100E+03, 0.86928900E+03, 0.20026600E+03, -.25046100E+02, -.44330000E+02, -.91998300E+03, 0.46856100E+03, 0.10701100E+04, 0.45988200E+03, 0.21796600E+02, -.15939400E+03, -.46834900E+02, -.41459200E+03, -.35281300E+03, -.46659900E+02, -.72797700E+03, -.19657200E+04, 0.97417700E+03, 0.94141400E+03, 0.98286300E+03, -.78870500E+03, -.18220200E+04, 0.60661800E+03, -.17487400E+04, 0.12261800E+04, -.14246200E+04, 0.14208600E+04, -.25724700E+04, 0.12927300E+04, 0.40137300E+03, 0.12862600E+04, 0.36568700E+03, -.95620700E+03, 0.99555600E+03, -.74992700E+03, 0.11783100E+04, -.71149800E+03, 0.36764000E+03, 0.16616000E+04, -.83918500E+03, 0.42030500E+03, -.83057100E+03, -.71974100E+03, -.67375000E+03, 0.59128700E+03, 0.10856800E+04, 0.23227500E+04, -.65479000E+03, -.17006200E+04, 0.14076800E+04, -.69878900E+03, 0.15070600E+04, -.70340600E+03, -.10568700E+04, -.11441200E+04, 0.10349200E+04, 0.57571800E+03, -.90720000E+03, -.84297900E+03, -.29092500E+03, -.18465500E+04, 0.93466600E+03, 0.92261200E+03, 0.92311600E+03, 0.44186000E+03, 0.67153400E+03, -.46633500E+03, 0.21325900E+03, -.16953000E+04, 0.51466700E+03, 0.12153800E+03, 0.31537900E+03, -.14816900E+03, 0.99700700E+03, -.15772400E+03, 0.84829200E+03, 0.10520700E+04, -.46442500E+03, 0.35252600E+03, -.22762800E+04, 0.92479600E+03, -.14756100E+04, -.22166200E+03, -.12947600E+03, -.68960400E+02, 0.52545100E+02, 0.18585500E+03, 0.10695700E+02, -.17737400E+00, 0.14992100E+03, -.15463600E+03, 0.21185400E+03, -.13120300E+03, -.10808200E+03, -.54855300E+03, 0.13756500E+03, 0.39493300E+03, 0.97297200E+02, -.14906000E+03, -.31271300E+03, 0.18703400E+03, -.39521500E+03, -.18233700E+03, -.12726500E+03, -.16541600E+02, 0.18899000E+03, -.42381300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.71163400E+01, -.78034500E+00, 0.17166200E+00, -.38634900E+01, -.35884900E+01, 0.30537200E+01, -.10415500E+01, -.18516600E-01, 0.89576100E+00, -.16760600E+01, -.13193600E+00, -.17285700E+00, 0.54955000E+00, 0.16989900E+01, 0.17290900E+00, -.92858000E+00, -.11738900E+00, 0.20579000E+01, -.17483000E+01, 0.63198700E+00, 0.12747700E+01, 0.36759600E+00, -.42800800E+00, -.21277400E+01, -.16665400E+00, -.38897200E+00, 0.22381700E+00, -.62854600E+00, 0.13465900E+01, -.33724000E+00, -.61455700E-01, 0.29682500E+00, -.76572700E-01, -.74179000E+00, 0.15050900E+00, 0.54328000E+00, 0.56067400E-01, -.21347500E-01, 0.64248900E-01, -.16948600E+01, -.10645400E+01, -.35187300E+00, 0.45954900E+01, -.17395200E+00, 0.21067200E+00, 0.16481900E+00, -.50037000E+00, 0.18207000E+00, -.10416100E+01, 0.59712800E-01, 0.23822600E+00, 0.10075100E+00, 0.22153000E+00, 0.12960700E+01, 0.38867000E+00, -.11981100E+01, 0.10312800E+00, 0.40558200E+00, 0.24251500E-02, -.11595100E+01, 0.93572900E+00, 0.92147100E+00, -.97973200E-01, 0.35241900E-01, 0.54346400E+00, -.47353000E+00, 0.11135800E+00, 0.34182000E+01, -.26033700E+00, -.93464000E-02, 0.70279300E+00, -.13322600E+00, -.97769100E+00, 0.87832200E+00, -.13753100E+01, 0.54692500E+00, -.20912300E+00, -.36878500E+00, -.67500700E+00, 0.36686800E+00, 0.94270700E-02, 0.13568500E+01, -.97059800E+00, 0.76117900E+00, 0.29880200E+00, -.34095900E+00, -.41007600E-01, -.49276100E+00, -.25811600E+00, 0.39047600E+00, 0.16860900E+01, 0.36207900E-01, 0.82851500E+00, 0.37894600E+00, -.81954700E+00, 0.31680800E+00, 0.17478300E+01, -.54626000E+00, -.56135300E+00, 0.81552000E-01, 0.72742800E+00, -.76880000E+00, 0.80072500E-01, -.14803400E+00, 0.14392400E+00, -.82085700E+03, -.63472400E+03, -.16405800E+04, 0.10414800E+03, -.96183600E+03, 0.29397800E+03, -.15364100E+03, -.33549400E+03, -.14664000E+03, -.34550000E+03, 0.48371800E+03, -.21046600E+03, -.42178400E+03, -.25307400E+03, 0.53805200E+03, 0.20112100E+03, 0.60131100E+03, -.29656200E+03, 0.99024400E+01, -.30068800E+03, 0.12671700E+03, -.10826700E+04, 0.85798300E+03, 0.13363900E+04, 0.56871900E+03, -.12679700E+04, -.63525400E+03, -.90947700E+03, 0.48098500E+03, -.67409800E+03, 0.45563400E+03, 0.26800700E+03, 0.22041100E+03, -.85023000E+02, -.25533400E+03, 0.34690100E+03, 0.16346800E+03, 0.26175400E+03, -.29160100E+04, 0.14664300E+04, 0.79525400E+03, 0.14577700E+04, 0.27560200E+02, -.74263700E+03, 0.13387700E+04, 0.24979100E+03, 0.16806400E+04, -.95298700E+03, 0.12774100E+04, 0.12702700E+04, -.63646200E+03, -.66155500E+02, -.63470300E+03, 0.15470400E+03, 0.84160500E+03, -.73294100E+03, 0.28219800E+03, -.69730900E+03, 0.10515700E+04, -.89489900E+03, 0.43113800E+03, -.21395800E+03, -.70351400E+03, -.21829200E+03, -.54821900E+02, -.56753800E+03, -.46677500E+03, -.39909400E+03, -.10539600E+03, -.67531400E+03, 0.13435100E+03, 0.44732300E+02, -.25416500E+02, 0.48148500E+03, -.22503300E+02, 0.23172200E+03, 0.51177200E+03, -.50611600E+03, 0.21767300E+03, 0.86531500E+01, 0.49797600E+03, 0.25513700E+02, 0.77156700E+03, -.39741700E+03, 0.31077200E+02, -.38701000E+03, -.16423300E+03, -.66311700E+01, -.22340500E+03, 0.14151400E+03, -.35030300E+03, 0.69057200E+02, 0.48774400E+03, 0.25199600E+04, -.12489600E+04, 0.13429600E+03, -.12599300E+04, 0.10471000E+03, -.31646900E+03, -.55154900E+03, 0.43782300E+03, -.12963500E+04, -.16047300E+03, -.15216400E+04, 0.37736500E+03, -.18771800E+03, -.41133200E+03, -.18836900E+03, 0.37136700E+03, -.36517000E+03, -.63117400E+03, -.38294200E+03, -.59528400E+03, -.78186100E+02, -.51268400E+03, -.20436800E+04, 0.10025200E+04, 0.11723400E+04, 0.10237500E+04, 0.77045500E+03, 0.13500600E+04, -.14876100E+04, -.99349400E+03, -.66012700E+03, 0.10165900E+04, 0.48394900E+03, -.91259200E+03, 0.50126600E+03, -.15854900E+04, 0.45903900E+03, 0.16678400E+03, 0.77623500E+03, -.44455700E+03, -.51181200E+03, 0.32208900E+03, 0.51520300E+03, -.19800200E+02, 0.13798400E+04, -.67669900E+03, -.68145300E+03, -.69040800E+03, -.13239100E+03, -.34044000E+03, 0.82702600E+03, 0.63515400E+03, 0.11244900E+04, -.24628400E+03, 0.24875200E+03, -.22795600E+04, 0.11266300E+04, 0.51794100E+02, 0.11392600E+04, -.29047600E+03, 0.75185700E+03, 0.99884700E+03, 0.90123000E+01, 0.14517400E+04, 0.80773600E+03, 0.93375900E+03, 0.57592300E+02, 0.91417600E+02, -.44983300E+02, 0.64601000E+02, 0.32014900E+01, 0.32581000E+02, 0.64185700E+01, 0.10348800E+02, 0.95140600E+02, -.10559300E+03, -.31297400E+03, 0.20889700E+02, -.63444000E+02, 0.44963100E+01, 0.27521800E+02, 0.61135900E+02, 0.22937100E+03, -.88876400E+02, -.18122200E+03, 0.17257900E+03, -.26712700E+03, 0.51952100E+02, 0.41897700E+02, -.16043500E+03, 0.46915000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35065900E+01, 0.22397200E+00, -.20920900E+01, -.34346400E+00, -.11732000E+01, -.16821000E+01, 0.18781300E+01, 0.39877400E-01, -.10397500E+00, 0.10397900E+01, -.65892900E-01, -.54338400E+00, -.65115200E+00, -.66192600E+00, 0.24646800E+00, 0.10015200E+01, -.19448400E+00, -.58313100E+00, -.65210100E+00, 0.23112600E+00, 0.10062000E+01, -.94412300E-02, 0.19970700E+00, 0.30397300E+00, -.32905400E-01, -.33124200E-01, 0.61287000E+00, 0.83570600E+00, -.62267200E+00, 0.41666400E+00, -.13856600E-01, -.53704100E-03, 0.37124500E+00, 0.69574000E+00, 0.14733300E+00, -.11533400E+00, -.16859600E-01, -.28396000E+00, 0.79209400E+00, -.23763500E+01, 0.12138300E+00, -.65639400E+00, -.39140300E+01, 0.21809200E+00, 0.39814800E+00, 0.99178200E-01, 0.15312600E+00, 0.84375400E+00, 0.96585700E-01, 0.52327500E-01, 0.16281500E+00, -.18244000E+00, 0.63421500E+00, 0.31661500E+00, -.20719700E+00, -.11994300E+01, -.16109100E+00, 0.42528800E+00, -.91945400E-02, -.81901200E+00, 0.13585700E+01, 0.52487400E+00, 0.35211800E-01, 0.54251800E+00, 0.11882300E+01, -.31113800E-01, 0.31291900E+00, 0.36566200E+00, -.64295200E-01, 0.12450200E-01, 0.30980100E+00, -.35462600E+00, 0.39041800E+00, -.38193300E+00, 0.15513500E+00, -.40527300E+00, 0.24034900E+00, -.47228400E+00, -.72191100E+00, -.19373900E+00, 0.11386800E-01, -.20198300E+00, 0.35415400E+00, -.94916200E-01, -.42055200E-01, 0.35594300E-01, 0.98851900E+00, 0.31401300E+00, 0.84811500E+00, -.26893300E+00, -.21263100E+00, -.34318700E-01, 0.29367500E+00, -.13370100E+00, 0.24666000E+00, 0.71217100E-01, -.38408600E+00, -.19600800E+00, 0.13373200E+00, 0.27051800E+00, -.22889900E+00, 0.33082300E+00, -.21902800E-02, 0.43956800E+00, -.37776300E+00, -.21166300E+00, -.42442100E+03, 0.47697800E+03, -.44472500E+01, 0.27137900E+03, 0.10258300E+04, -.51128800E+03, -.12312400E+03, -.51294600E+03, -.52531300E+03, -.35824600E+03, -.11089500E+03, -.20173300E+03, -.39627900E+03, -.29857000E+03, -.10393300E+04, 0.43447100E+03, -.22142700E+03, -.33558000E+03, -.21725400E+03, -.33647900E+03, 0.12527200E+04, -.40884900E+03, 0.44397600E+03, -.55162300E+03, 0.94917000E+03, 0.88462200E+03, 0.41077300E+03, -.19383500E+03, 0.34296900E+02, -.20553100E+03, -.12628600E+03, -.32050500E+03, 0.17884300E+03, 0.16558200E+03, -.61933000E+02, -.24577900E+03, -.22211500E+03, 0.13742500E+04, -.69524300E+03, -.36071900E+02, -.68709900E+03, 0.35312600E+02, 0.97658000E+03, -.37208500E+03, 0.90959200E+03, -.46886900E+03, 0.71532500E+03, -.24868800E+03, -.13790100E+04, 0.68972000E+03, 0.18061600E+03, 0.68948200E+03, -.21434000E+03, -.62224100E+03, 0.30769100E+03, -.65043200E+03, 0.34089500E+03, -.40851700E+03, 0.32829400E+03, 0.14157300E+04, -.71032000E+03, -.77017100E+03, -.70747100E+03, -.20719600E+03, -.28981200E+02, 0.33946700E+02, 0.52632500E+03, -.83633800E+02, -.10807400E+03, -.75922500E+03, 0.36774000E+02, -.21160500E+02, 0.54347900E+03, -.18393100E+02, -.35553500E+03, -.45498200E+03, 0.31704600E+03, 0.52466900E+03, 0.23210100E+03, -.45064900E+03, -.22113400E+03, -.18843300E+03, 0.95361200E+02, 0.33677600E+03, 0.94317800E+02, 0.12521100E+03, -.50973900E+03, 0.38940000E+03, 0.15947700E+03, 0.21911600E+03, -.54027400E+03, -.66927700E+03, -.23232300E+04, 0.11592400E+04, 0.44404400E+03, 0.11616100E+04, -.29079700E+03, -.86966100E+03, 0.76282400E+03, -.59808400E+03, 0.11808400E+04, -.76876500E+03, 0.14899100E+04, -.14517200E+04, 0.72453000E+03, 0.10891700E+03, 0.72583800E+03, 0.53206700E+02, -.43830700E+03, 0.49140000E+03, -.24694300E+03, 0.71546700E+03, -.36657800E+03, 0.51728600E+03, 0.25657700E+04, -.12849300E+04, 0.79573300E+03, -.12830700E+04, -.75885600E+03, -.69531900E+03, 0.30506200E+03, 0.82202000E+03, 0.62902900E+02, -.70370000E+03, -.14519000E+04, -.53293900E+03, 0.27335000E+03, 0.13994100E+03, 0.26615800E+03, 0.20591700E+02, -.27451400E+02, 0.89913700E+02, -.45408200E+02, -.15507700E+02, 0.12125000E+02, 0.53700100E+03, -.13069500E+04, 0.65007500E+03, 0.13387500E+03, 0.65356700E+03, 0.46147600E+03, -.64247600E+02, 0.23907800E+03, 0.13693000E+03, -.12447800E+03, -.68903600E+02, 0.45739800E+02, -.10950700E+03, 0.62812500E+02, 0.94524600E+03, 0.54789800E+02, 0.58956100E+03, 0.23756600E+03, -.27079100E+03, -.75108100E+02, -.84481900E+03, 0.22436200E+03, -.69892800E+03, -.17014300E+02, -.13119300E+03, -.79855900E+01, -.11576700E+03, -.39759900E+02, -.54448700E+02, 0.52940300E+02, -.48586200E+02, -.68231600E+02, 0.17992500E+03, -.91191700E+02, -.73228900E+02, -.29106300E+03, -.21155500E+02, 0.87080700E+02, -.87418300E+02, -.15706400E+03, -.11818900E+03, 0.19345100E+03, -.30488000E+03, 0.56254200E+01, -.96318600E+02, 0.19463800E+01, 0.67080400E+02, -.24300800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.55222000E+01, -.45226700E+00, -.12329200E+01, 0.11560500E+01, 0.10435900E+01, -.35376600E+00, -.59683400E+00, -.28723000E+00, -.54826900E-01, -.13331400E+01, 0.29929900E+00, -.99163200E+00, -.11819700E+01, -.15886900E+01, -.14203000E-01, 0.57550800E-01, -.21541400E+01, -.22261000E+01, 0.96412400E+00, -.20270600E+01, 0.13801300E+01, 0.11978600E+00, -.47362100E+00, -.26480500E+01, -.24651500E+00, 0.20399100E+00, -.11094200E+00, 0.16790400E+01, -.45944800E+00, 0.40807600E+00, 0.61188500E-01, -.62718700E+00, -.14284800E+01, -.32860500E+00, -.23952900E+00, -.65063000E+00, -.16971800E-01, -.28487000E-01, -.46594900E+00, 0.17044900E+01, -.63573400E+00, -.32564900E+00, 0.29707800E+01, 0.19944000E+00, 0.54455400E+00, 0.21144500E+00, -.48188700E+00, 0.52925000E+00, -.62538100E+00, -.40191800E+00, 0.31988600E+00, 0.14733600E-01, -.76336900E+00, -.48457900E+00, -.24934000E+00, 0.45663700E+00, -.25414100E+00, -.45149600E+00, 0.41978900E-02, 0.19142100E+01, -.68549600E+00, 0.13638100E+01, -.15383500E+00, -.77623400E+00, -.12954800E+01, 0.14454100E+01, -.22830900E+00, 0.10413300E+01, 0.33722000E+00, -.41241900E-02, -.20388600E+00, 0.19743500E+00, 0.10261400E+01, 0.18420200E+01, -.11161400E+01, -.68939700E+00, 0.31750700E-01, 0.15938300E+00, -.23067800E+00, 0.24603700E+00, -.43566600E-01, -.38884500E+00, -.22901700E+00, 0.12337000E+00, -.14353000E+00, -.36801600E+00, 0.67921300E+00, -.49751300E+00, 0.54374300E+00, 0.86422400E+00, 0.14357700E+01, -.58648400E-02, 0.64478600E+00, -.16958200E+00, -.13965300E+00, -.30593500E+00, 0.24788000E+01, -.12529700E+01, 0.90640000E-01, -.41173900E+00, 0.55297400E+00, -.65591100E+00, 0.53495800E-01, 0.21962600E+00, 0.72404500E-01, -.32139200E+00, 0.47436500E+00, -.25857800E+04, 0.16329100E+03, -.14284800E+04, 0.16826000E+03, -.94813800E+02, -.74035700E+03, -.83866700E+02, 0.30348300E+03, 0.96018700E+03, -.52277900E+03, 0.41194700E+03, -.43187600E+03, 0.73835000E+03, 0.12017900E+04, -.18755300E+04, 0.94679100E+03, 0.90185300E+03, 0.93774300E+03, 0.57738400E+03, -.16843400E+04, 0.95750400E+03, -.99312600E+03, 0.93144200E+03, -.13903200E+04, -.64798200E+03, -.10896700E+04, 0.56785800E+03, -.72043400E+03, 0.54554300E+03, 0.36353200E+03, 0.33768700E+03, -.13615200E+03, -.40276200E+03, 0.30030200E+03, 0.26994400E+03, 0.29258800E+03, -.45116000E+04, 0.22728600E+04, 0.98498000E+03, 0.22556100E+04, -.12108600E+03, -.17817800E+04, 0.13072600E+04, -.17008200E+04, 0.19858100E+04, -.13665200E+04, 0.26614000E+04, 0.29699900E+04, -.14927700E+04, -.25430800E+03, -.14846600E+04, 0.40067600E+03, 0.16794400E+04, -.92115000E+03, 0.13309200E+04, -.11293100E+04, 0.12043200E+04, -.19449900E+04, -.60955300E+03, 0.30672900E+03, 0.83766000E+02, 0.30415600E+03, 0.34222100E+03, -.54391500E+03, -.67716200E+03, -.84969200E+03, -.62838600E+02, -.52179900E+03, -.43286700E+02, 0.95066100E+03, -.47487300E+03, -.51049600E+03, -.47544400E+03, 0.14095400E+03, 0.47042000E+03, -.76587200E+03, -.27294000E+03, 0.88493300E+02, 0.19774900E+02, 0.10880600E+03, 0.10959700E+04, -.56101900E+03, -.39487000E+03, -.54892900E+03, -.26688200E+02, 0.48026800E+03, -.78828400E+03, 0.32611200E+03, -.93570200E+03, 0.28187500E+03, 0.36528400E+03, 0.27950500E+04, -.13836100E+04, -.12758400E+02, -.13974800E+04, 0.27168300E+02, 0.43826400E+03, -.90630600E+03, 0.10054500E+04, -.17959800E+04, 0.52328700E+03, -.10989800E+04, 0.25737900E+04, -.12855200E+04, -.86721300E+03, -.12866600E+04, -.17543200E+02, 0.29446400E+03, -.90175400E+03, 0.39668800E+03, -.17126400E+04, 0.37892000E+03, -.90637100E+03, -.12746000E+04, 0.62219900E+03, -.13190900E+04, 0.63877800E+03, 0.57116100E+03, 0.16210800E+04, -.18263500E+04, -.17281900E+04, -.21530900E+04, 0.12928900E+04, 0.12778200E+04, -.98423500E+03, 0.53354000E+03, -.14852700E+04, 0.49422800E+03, 0.25468700E+03, 0.23828300E+03, 0.12964600E+03, -.62233000E+03, 0.56317600E+03, 0.72013900E+02, -.25481200E+03, 0.34491000E+04, -.17182900E+04, -.11038200E+04, -.17249300E+04, -.58658300E+03, -.35572000E+03, -.86061000E+02, 0.10755500E+04, 0.17937900E+04, -.29966500E+03, 0.14531700E+03, -.13058700E+04, 0.63273500E+03, -.68034400E+03, 0.65254100E+03, -.92115500E+03, 0.40190900E+03, 0.13767300E+04, 0.76351100E+03, 0.19416400E+04, 0.36246500E+03, 0.17105000E+04, 0.15829100E+03, 0.19403900E+03, 0.19172900E+02, 0.77401400E+02, -.31693200E+02, 0.96200600E+02, -.73802400E+02, -.21217100E+02, 0.11526000E+03, -.26394200E+03, 0.64142100E+01, 0.92620600E+02, 0.52663800E+03, 0.90834600E+01, -.14314500E+03, 0.87265800E+02, 0.30996100E+03, 0.15037400E+03, -.31754400E+03, 0.46709200E+03, -.22058900E+03, 0.17224700E+03, -.17422300E+02, -.13641700E+03, 0.25457300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32392400E+01, -.37382100E+00, 0.20213100E+00, -.14989600E+01, 0.38985300E+00, 0.15510700E+01, -.10976700E+01, 0.59615000E-01, 0.25753700E+00, -.48562800E+00, -.14606400E+00, 0.24187400E+00, 0.96430900E+00, 0.25305000E+00, -.10388900E+00, -.66451400E+00, 0.27967200E+00, 0.44304400E+00, -.70329600E+00, 0.25858300E+00, -.34926900E-01, 0.83094800E-01, -.18703900E+00, 0.34638700E-02, -.18153700E+00, -.26474200E-02, -.76778300E+00, -.22636900E+01, 0.12310600E+01, -.81387300E-01, -.26219400E+00, 0.17175400E+00, 0.11419800E+01, 0.43315600E+00, -.96316100E-01, -.40212400E+00, -.11083600E-01, 0.13284800E+00, -.22101900E+00, -.37714500E+00, 0.80765600E-01, 0.93245400E-01, -.10465200E+01, -.40792000E-01, 0.17777300E+00, -.23521300E-01, 0.14449900E+00, -.73195300E-01, 0.63857600E+00, 0.30185800E-01, 0.88833800E+00, -.23873600E+00, 0.42160900E+00, -.98110500E+00, -.34471600E+00, -.19901400E-01, -.81911600E-01, 0.13558600E+00, 0.38360000E-02, 0.57337400E+00, 0.10526500E+01, 0.60900600E+00, -.40874900E-01, 0.15166300E-01, -.68021700E+00, -.45350700E+00, 0.12148900E+00, 0.10440800E+01, -.12932500E+00, -.40176300E-02, 0.80839200E-01, -.12071600E+00, 0.12114800E+00, 0.15495600E+00, -.26458400E+00, -.16654100E+00, 0.17181700E+00, 0.37111000E-01, -.16192000E+00, -.15556700E+00, 0.27885700E-01, 0.13130500E+00, -.23560500E+00, 0.13620700E+00, -.20863000E+00, 0.21640700E-01, -.14221700E+00, -.35842500E+00, -.27029000E-01, -.65810500E-01, -.83311500E+00, 0.34344900E-02, 0.19139200E+00, 0.76941000E-02, -.83610700E-01, 0.13118700E+00, -.57031200E+00, 0.37647800E+00, -.31362600E-01, -.33993000E-01, -.12139300E+00, 0.24123800E+00, -.89072800E-02, -.15369000E-01, -.94030500E-01, -.82358200E-01, -.55940700E-01, 0.55833100E-01, 0.15049900E+03, -.49555900E+03, 0.27764400E+03, -.14208300E+03, 0.11908400E+03, -.13885600E+03, -.34779700E+03, -.22288400E+03, -.18983800E+03, -.42446400E+03, -.84744200E+02, -.78234200E+02, -.14265500E+03, 0.87026400E+03, -.43422300E+03, -.42913000E+03, -.43509100E+03, -.22102700E+03, 0.24686600E+03, 0.50101700E+02, 0.64727700E+03, -.13102600E+03, 0.60727400E+02, -.28117700E+03, -.50330800E+02, 0.22827700E+02, 0.32303800E+02, 0.25164600E+02, -.98068400E+01, -.35504000E+02, 0.54565300E+02, 0.22474900E+02, 0.53574000E+02, -.40139200E+02, 0.78273500E+02, 0.35011500E+03, -.17683900E+03, -.23027400E+03, -.17503400E+03, -.23551800E+02, 0.47767600E+03, -.45770200E+02, 0.45665400E+03, 0.31924700E+01, 0.21480600E+03, -.86352900E+02, -.10156600E+04, 0.50753100E+03, 0.26782000E+03, 0.50774600E+03, 0.39606600E+02, -.47611200E+03, 0.36964700E+03, -.94019500E+01, 0.33938200E+03, -.35392100E+03, -.83762100E+02, 0.13438600E+03, -.70697800E+02, -.16365600E+03, -.67766400E+02, -.18131300E+03, -.27200600E+02, 0.20709500E+03, 0.29690300E+03, 0.74957600E+02, -.45053900E+02, 0.12933700E+03, -.22273500E+03, 0.11098100E+03, 0.41689000E+03, 0.11143600E+03, 0.16757700E+03, -.69756900E+01, -.88105000E+02, 0.83860300E+00, 0.42285600E+02, -.49062000E+02, 0.13716300E+03, 0.36152300E+03, -.18093100E+03, 0.43629100E+02, -.18060200E+03, -.41480200E+02, -.18133000E+03, -.57256300E+02, -.13264500E+03, 0.11265500E+03, -.11152600E+03, 0.75749300E+02, 0.22454500E+03, -.11355900E+03, 0.22601400E+03, -.11228000E+03, -.15643100E+02, -.40853400E+03, -.83151200E+02, -.61051100E+03, -.22352000E+03, -.20145700E+03, -.27621300E+03, -.60361500E+03, 0.29982300E+03, 0.20936700E+03, 0.30176400E+03, 0.12446500E+03, -.22121700E+03, 0.19366500E+03, -.98472400E+02, 0.15548400E+03, -.94572800E+02, -.10924300E+03, -.20017900E+03, 0.10285800E+03, 0.11631200E+04, 0.99892500E+02, 0.30883800E+03, 0.22778200E+03, -.33401700E+03, -.27555900E+03, -.19281900E+03, 0.25765800E+03, -.21760900E+03, 0.18116100E+02, -.13969000E+02, 0.11292900E+03, -.92227900E+01, -.55646500E+02, 0.51808300E+02, -.99227500E+02, -.84899000E+02, -.12047500E+03, 0.21203100E+02, -.90575900E+02, -.27324000E+03, 0.13538100E+03, -.33659300E+03, 0.13657600E+03, 0.35108600E+02, -.16733400E+03, 0.26519300E+03, -.16086900E+02, 0.22139300E+03, -.23956500E+03, 0.44443700E+03, -.34665300E+03, 0.17829000E+03, 0.95134500E+02, 0.17339900E+03, 0.29290600E+03, 0.16332900E+03, -.23977100E+03, -.26605000E+03, 0.54692600E+02, 0.10383800E+03, -.21699000E+03, -.35279700E+02, -.42039000E+02, -.79197900E+01, -.41358000E+02, 0.23282100E+02, -.33772700E+02, 0.52197400E+02, 0.27716900E+02, -.29294900E+02, 0.66725000E+02, -.63623700E+02, 0.51257500E+00, -.18175900E+03, -.23992000E+02, 0.56161800E+02, -.11405200E+02, -.37316200E+02, -.70222400E+02, 0.49483800E+01, -.10889000E+02, -.52604300E+02, -.18805500E+02, 0.15845800E+02, -.74216600E+02, -.62112800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21169600E+01, 0.43870700E-01, -.11722900E+01, 0.86483900E+00, 0.56207700E+00, -.31033400E+00, 0.50177300E-01, 0.12437400E+00, 0.72564100E-02, 0.38725100E+00, 0.59967000E+00, -.93807400E-01, 0.74231200E+00, 0.12179300E+01, 0.15835200E-01, 0.27831000E+00, 0.11319900E+01, 0.13094000E+01, -.30656600E+00, 0.27963500E+00, -.71441200E+00, -.15097300E+00, -.12997900E-01, 0.39808900E+00, 0.11162700E+00, 0.51588600E-01, 0.11815600E+00, -.62577300E+00, 0.19738200E+00, -.30245700E+00, -.12909300E-01, 0.15447400E-01, 0.15280500E+00, 0.36068400E-01, -.57520500E-01, 0.18376600E+00, 0.17315600E-01, 0.16088300E+00, -.23921400E+00, -.29466900E+00, -.18284700E+00, -.32140500E-03, 0.75880400E+00, -.14018000E+00, 0.11114700E+00, -.44605900E-01, 0.10613100E+00, -.56030100E+00, 0.11658200E+00, 0.11914500E+00, -.18357600E+00, -.21844400E+00, 0.26187800E-01, 0.43764700E-01, 0.37317200E-01, 0.16307600E+00, 0.11677300E+00, -.10763400E+00, -.37970200E-02, 0.30685100E+00, -.30749500E+00, -.11881600E+00, -.14472700E-02, -.47294200E-01, 0.10964600E+00, -.48552700E+00, 0.10166100E+00, -.27483400E+00, -.44320000E-01, 0.54274100E-02, 0.29989200E-01, -.76138000E-02, 0.20846700E-01, 0.17919400E+00, -.15596300E+00, -.45521100E-02, -.10591300E+00, -.59213600E-01, 0.17121500E-01, 0.96157600E-01, -.24505500E-01, -.31922900E+00, -.50916500E-01, 0.17272000E-01, -.15877600E-01, -.42245600E-01, -.20647600E+00, -.48833500E-01, -.25986100E+00, 0.17485700E+00, 0.54296300E+00, 0.15821200E-01, 0.19301700E+00, -.58742300E-01, -.79839200E-01, -.39777600E-01, 0.49478000E+00, -.76993300E-01, -.58195200E-01, -.10221200E+00, 0.21980300E+00, 0.59975000E-01, 0.18169200E-01, -.48406500E-01, 0.83172400E-01, 0.25559600E-01, 0.18103400E-02, 0.61264800E-01, -.16088900E+00, -.22715200E+03, -.22476500E+02, 0.10748200E+02, 0.28633900E+02, 0.11309900E+02, -.55562500E+02, -.68121500E+02, -.41963700E+02, -.10551200E+03, 0.99155800E+02, -.32141900E+01, 0.17494600E+03, 0.21311000E+03, -.10652700E+03, -.23082200E+01, -.10658700E+03, -.31542700E+02, -.52352100E+01, 0.51335800E+02, 0.24995000E+03, -.11399600E+03, -.52084300E+02, -.25313300E+03, -.14844800E+03, 0.69847200E+02, 0.36518800E+02, 0.74325200E+02, 0.30609600E+02, 0.74885200E+02, -.21787900E+02, -.39840900E+02, 0.45289100E+02, 0.51401600E+02, 0.63867400E+02, 0.35669500E+03, -.17918500E+03, -.71563600E+02, -.17838700E+03, -.67585200E+02, 0.81783800E+02, -.52189000E+02, 0.17171500E+03, -.85851100E+02, 0.44022800E+02, -.15342900E+03, -.51607300E+02, 0.26597000E+02, 0.49948600E+02, 0.25907800E+02, 0.54266600E+02, -.18443800E+01, -.96555200E+01, -.11984700E+03, -.20665900E+02, -.11182000E+02, 0.39073000E+01, 0.18927700E+03, -.95437000E+02, -.44268300E+02, -.95109200E+02, -.29219700E+02, 0.91585000E+01, -.85847700E+02, -.44580700E+02, -.12435500E+02, 0.31698500E+02, -.77050400E+01, -.18114600E+03, 0.90364200E+02, -.79515200E+01, 0.90522600E+02, 0.80069900E+02, 0.29067200E+02, -.60225300E+02, -.31923900E+02, 0.44110600E+01, 0.28759900E+02, 0.10680700E+03, 0.72678100E+02, -.36350700E+02, -.37343100E+02, -.36595100E+02, 0.45232600E+01, -.32326800E+02, -.59687400E+02, -.10688700E+03, 0.53296100E+02, 0.44134900E+02, 0.12369500E+03, 0.81299600E+02, -.41512800E+02, -.90878200E+02, -.40638600E+02, 0.97857200E+01, -.64379000E+02, -.60882900E+01, -.11822300E+03, -.54546700E+02, 0.58039400E+01, -.22145900E+02, -.67224300E+02, 0.33184600E+02, 0.94856900E+02, 0.33681000E+02, 0.18713100E+02, -.43411900E+02, -.18378100E+02, -.10405900E+03, -.20003100E+02, -.14065500E+02, -.20122300E+01, -.45362500E+03, 0.22802400E+03, 0.14016600E+03, 0.22717600E+03, 0.15857200E+03, 0.50255700E+02, -.99673900E+02, -.87595700E+02, 0.27097800E+03, 0.11220300E+03, 0.27191300E+03, 0.52134500E+02, -.30883300E+02, 0.14848300E+02, -.25599400E+02, -.60320700E+02, 0.82923600E+02, -.22986100E+02, 0.48011400E+02, -.56957500E+02, 0.79241900E+01, -.17022700E+03, -.30245000E+02, 0.15739300E+02, -.39136800E+02, 0.15084700E+02, -.12320500E+01, -.18862400E+02, 0.72595000E+02, -.47332900E+02, -.68110400E+02, -.36948500E+01, 0.15244800E+03, -.12643000E+03, 0.64939700E+02, 0.12525800E+02, 0.63100100E+02, 0.56823000E+02, 0.63795600E+02, -.31864100E+02, -.55392000E+02, -.16207500E+02, 0.54267900E+02, 0.25923400E+01, -.15029600E+02, 0.56248000E+01, -.94486700E+01, 0.13490200E+02, 0.39409100E+02, 0.51390700E+01, -.56981000E+00, 0.39631400E+02, -.34132300E+02, 0.23715700E+00, -.16523000E+02, 0.16511300E+02, -.76257900E+02, -.43353900E+02, 0.43333600E+02, 0.21929600E+02, 0.15592700E+01, -.16324900E+02, -.28265000E+02, -.63360900E+01, -.36687000E+02, -.10036500E+02, 0.17277600E+02, -.12756700E+02, -.91828200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45279200E+01, 0.42311400E+00, -.19489000E+01, 0.45958800E+00, -.17776500E+01, -.19928200E+01, 0.22136900E+01, -.15677200E-02, -.31245100E+00, -.33088800E+00, -.13035500E+00, -.13411800E+00, -.46759900E+00, -.61155500E+00, 0.21523600E+00, 0.16685300E+01, -.54591900E+00, -.18221300E+01, 0.10681100E+00, -.14225400E+01, 0.20691000E+01, -.10894200E+00, -.62543400E+00, -.36977600E+01, 0.80937000E-01, 0.58057900E+00, 0.21628900E+01, 0.17465200E+01, -.66267300E+00, 0.10606400E+01, 0.43056800E-01, 0.23150800E+00, 0.34771200E+00, -.40400700E+00, 0.68773000E-01, 0.35988400E+00, 0.66730800E-01, -.21649500E+00, -.49486800E+00, -.62840200E-01, -.10223300E+01, -.47892100E-01, 0.37463700E+01, -.27988900E+00, 0.14536600E+00, -.16828500E+00, 0.11102300E+00, -.13108500E+01, -.67357700E+00, -.69638400E-01, 0.80025700E-03, 0.56927900E+00, -.19983300E+00, -.10754400E+01, 0.27779900E+00, 0.11625500E+01, 0.26648100E+00, -.57617900E+00, 0.97739700E-03, 0.57923300E+00, -.26439900E+01, -.40942200E+00, -.53697900E-01, -.12736200E+01, -.10946900E+01, 0.44488300E+00, -.45774300E+00, -.21051100E+01, 0.34454700E+00, 0.50198300E-02, 0.17498900E+00, 0.30370800E+00, 0.27807500E+00, 0.14570000E+01, -.11359600E+01, -.11821000E+01, 0.11962500E+00, -.44471500E+00, 0.11024600E-01, 0.36582100E+00, -.61570300E-01, -.35780500E+00, 0.10361000E+01, -.74947900E-01, -.23017300E-01, -.19723400E+00, -.47723600E+00, -.22339400E+00, -.57299300E+00, -.91505600E-01, 0.13906200E+01, 0.65711700E-01, 0.55331200E+00, -.29067900E+00, -.79838000E-01, -.77456900E-01, -.51699200E+00, 0.86041200E+00, -.44130100E+00, -.68237700E-01, -.56654400E+00, -.58675800E+00, -.19726800E-01, -.35667200E+00, 0.32854700E+00, -.44580800E+00, -.11764400E+01, 0.21551400E+00, -.33892200E+00, 0.16480400E+01, 0.18443100E+04, -.92788300E+03, -.64468200E+03, -.92219200E+03, -.82312900E+03, -.37304500E+03, -.21868400E+03, -.16470800E+02, -.79286500E+03, -.19756600E+03, -.16551200E+04, -.18513400E+04, 0.92748400E+03, 0.76887500E+03, 0.92567700E+03, -.94020000E+02, 0.88049900E+03, 0.19432500E+03, 0.13487800E+03, 0.53367900E+03, 0.68663800E+03, 0.21822100E+04, -.62491000E+03, 0.32255000E+03, -.38869500E+03, 0.31236900E+03, 0.17401900E+03, -.18359300E+03, 0.23169000E+03, 0.87525400E+01, 0.39131800E+03, -.16939800E+03, 0.29063600E+03, -.16686900E+04, 0.83339200E+03, 0.30903600E+03, 0.83436700E+03, 0.18787500E+03, 0.57905300E+03, 0.26971700E+03, 0.15912300E+03, 0.65260100E+03, 0.46153400E+03, 0.15944900E+04, -.88252200E+03, 0.43553200E+03, 0.39078700E+03, 0.44121300E+03, -.12038400E+03, -.24227700E+03, 0.73766100E+03, 0.91704300E+03, 0.54860800E+03, -.52372000E+03, -.10381000E+04, 0.98112900E+03, -.49516700E+03, -.75916000E+03, -.49077600E+03, -.19009400E+03, -.38352000E+03, 0.15869100E+03, 0.48580100E+03, -.21755900E+03, -.30172500E+03, -.63697500E+03, 0.10181400E+04, -.51025300E+03, 0.43740600E+03, -.50905600E+03, -.35624700E+03, -.21623400E+03, 0.61696600E+02, 0.24030300E+03, -.14227100E+03, -.32787600E+03, -.47882200E+03, 0.10838400E+04, -.54423900E+03, -.73436100E+02, -.54178300E+03, -.46911100E+02, -.60396700E+03, 0.17170900E+03, 0.26865200E+03, -.13538300E+03, -.57007100E+03, -.12488800E+04, 0.64781700E+02, -.30997400E+02, 0.29602500E+03, -.32396600E+02, 0.25598100E+02, -.19880100E+03, -.23167600E+03, -.61126500E+03, -.46799000E+02, -.37788600E+02, 0.15796000E+03, 0.95211700E+02, -.50143500E+02, -.29313900E+03, -.47641000E+02, 0.29392800E+03, -.16461100E+03, 0.73184500E+02, 0.62131700E+02, 0.60933700E+02, -.13830200E+03, -.50355800E+03, 0.28388200E+04, -.14202100E+04, 0.88028100E+03, -.14196200E+04, -.64003800E+03, -.49050300E+03, 0.11824600E+02, 0.10217600E+03, -.11850400E+04, -.41455300E+03, -.19188200E+04, -.19915700E+04, 0.10046800E+04, 0.10561300E+02, 0.99549200E+03, 0.64852700E+03, 0.46436100E+03, -.26494900E+03, -.88172300E+03, 0.34611500E+03, 0.40548100E+03, 0.14959900E+04, -.61228300E+03, 0.29885000E+03, -.58096000E+03, 0.30618900E+03, 0.35254800E+03, -.23661100E+03, 0.15598800E+03, 0.10385300E+03, 0.56982700E+03, -.12841500E+03, 0.37197100E+03, -.59624800E+03, 0.30173600E+03, 0.55232600E+03, 0.29818200E+03, 0.11333000E+03, 0.42756900E+02, 0.80526500E+02, 0.26779200E+02, 0.25194100E+03, -.10607200E+03, -.36213700E+03, 0.98886400E+02, -.12497300E+03, 0.90247900E+02, -.24505700E+03, -.12440500E+03, -.11814400E+03, 0.13054300E+03, -.12173700E+03, 0.63207600E+02, 0.14023000E+03, 0.48471600E+02, -.12596700E+03, -.13117200E+03, 0.26189000E+02, -.77304200E+02, -.18055900E+03, -.15125900E+03, 0.42372800E+02, 0.12628700E+03, -.10601100E+03, 0.11093300E+03, -.55405200E+02, 0.41081300E+02, 0.63480200E+02, -.12871100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14242400E+02, -.23311400E+00, 0.10397500E+02, 0.28611400E+01, -.66063600E+01, 0.12191300E+01, 0.44389300E+00, -.98459900E+00, 0.49717800E+00, -.17251500E+01, -.32709500E+00, 0.91272000E+00, -.33961300E+01, 0.11891000E+01, 0.13388200E+01, 0.11047700E+01, -.15440600E+01, 0.13207800E+01, 0.13307200E+01, -.25251100E+00, 0.32273900E+01, 0.94859800E+00, 0.33195800E+00, -.36089700E+01, -.50139600E+00, -.12751300E+01, -.21828900E+01, 0.63127200E+01, 0.66939500E+00, -.12736000E+01, 0.48643500E+00, -.86161200E+00, -.66858400E+01, 0.25545400E+00, 0.67156700E-01, -.42357300E+00, -.23805100E-01, -.86497100E+00, 0.11969500E+01, 0.47882300E+01, 0.46750900E+00, -.25038900E-01, 0.63650700E+01, -.37055900E+00, 0.32250900E+00, 0.64788700E+00, -.10609700E+01, 0.14384500E+01, -.13630300E+01, -.24527400E+00, -.97190800E+00, -.61210100E+00, -.70846700E+00, 0.26678100E+01, 0.99556300E+00, -.21296900E+01, -.48217000E+00, -.69277900E+00, 0.26349000E-02, 0.47541500E+00, 0.33760200E+00, 0.78712900E+00, -.17864100E+00, -.20191700E+00, -.30945600E+00, 0.21746500E+01, -.18870000E+00, 0.57547400E+01, 0.39631000E+00, -.69650200E-02, -.36384800E-01, -.36934700E+00, 0.43819300E+00, 0.22028800E+01, -.96617000E+00, -.10486000E+01, -.78092600E+00, 0.53770600E+00, -.44646400E+00, 0.10520000E-02, -.38456000E-01, 0.10146500E+01, -.74213200E+00, 0.48160900E+00, 0.15781000E+00, -.55317700E+00, 0.22089300E+00, 0.20278200E+00, 0.26097600E+01, 0.67251700E+00, 0.54515200E+01, -.56765500E-01, 0.49623800E+00, -.90711900E-01, -.13793600E+01, -.53113200E-01, 0.24440700E+01, -.17763500E+01, 0.33350700E+00, -.12874800E+00, 0.22499000E+00, -.28658400E-01, 0.20273200E-01, 0.25527400E+00, 0.47152100E+00, -.43379200E+00, -.63248100E+00, 0.47529500E+00, 0.10782100E-02, 0.95661900E+00, 0.64608100E+00, 0.22832800E+02, -.18271600E+03, -.31589900E-01, 0.55917900E+03, 0.28357800E+03, 0.10871300E+02, 0.11190500E+03, -.54529400E+02, 0.12595000E+03, -.24152100E+02, 0.91725800E+03, -.46988200E+03, -.16615000E+03, -.45867400E+03, -.80329800E+02, -.64577000E+02, -.52314900E+03, -.46416600E+03, -.20182900E+03, -.23945500E+02, -.50843900E+03, 0.53391700E+03, -.24305400E+03, -.71649500E+03, -.26717500E+03, -.89499500E+02, -.21925500E+02, -.29922000E+01, 0.17858100E+03, -.12675600E+03, -.72878200E+01, -.19571300E+03, 0.30810500E+03, -.16562800E+03, 0.20646600E+03, -.15402200E+03, -.33022800E+03, -.49782800E+03, -.20929300E+03, -.50896500E+03, -.33732700E+03, -.36556300E+03, 0.12190100E+03, 0.12709600E+04, -.61048100E+03, -.30806900E+03, -.63548000E+03, 0.30584400E+03, 0.76051900E+03, -.67559000E+03, -.43157900E+03, -.58255000E+03, 0.82502800E+03, -.48317100E+03, -.14793200E+03, 0.91161700E+02, -.51714800E+03, 0.74845600E+02, -.29165300E+03, -.25686400E+03, 0.27575600E+03, 0.28110800E+03, 0.40794600E+03, -.33244000E+03, 0.18870600E+03, 0.53951400E+03, -.27538700E+03, -.77041800E+03, -.26979800E+03, -.15630100E+03, -.72841100E+02, 0.28874700E+02, 0.26627300E+03, 0.61284400E+02, -.89567800E+02, 0.12446300E+03, -.67986700E+02, 0.26668500E+02, -.46372600E+03, 0.34078700E+02, -.16115800E+03, -.24980600E+03, 0.17635000E+03, 0.19722700E+03, 0.28029800E+03, -.37718600E+03, 0.50258000E+03, -.15323100E+04, 0.78111300E+03, -.24863600E+03, 0.76615300E+03, 0.10075500E+03, 0.20634200E+03, 0.45722300E+03, 0.40370100E+03, 0.79147700E+03, -.37240200E+02, 0.62422100E+03, -.66753000E+03, 0.34485800E+03, 0.15796000E+02, 0.33374800E+03, -.11127400E+03, 0.12445200E+03, 0.29910900E+03, 0.33204900E+03, 0.42467500E+03, 0.47253100E+02, 0.66999500E+03, 0.12514400E+04, -.65424300E+03, -.14738600E+04, -.62591500E+03, -.96945800E+02, 0.16045800E+03, -.10174300E+03, 0.36653800E+03, -.35720200E+03, -.10514200E+03, -.18682600E+03, 0.39954600E+03, -.17102900E+03, -.45436000E+03, -.20018000E+03, 0.13709800E+03, 0.18911200E+03, -.11734200E+03, 0.19633400E+03, -.13983800E+03, 0.23175200E+03, -.43172200E+03, -.12926700E+03, 0.90294600E+02, 0.47740300E+03, 0.64794500E+02, -.11435100E+03, -.52691400E+02, 0.55533800E+01, 0.36848900E+02, 0.10346700E+03, -.70480000E+02, 0.34146700E+03, 0.60640300E+03, -.33106700E+03, 0.23590300E+03, -.30317700E+03, 0.47117000E+02, -.16994700E+03, -.81461700E+02, -.47077900E+02, -.39811800E+03, 0.13507000E+02, 0.12892800E+03, 0.65297100E+02, 0.12882200E+02, -.38657100E+02, 0.60534400E+02, -.28506500E+02, 0.36352500E+02, -.44859000E+02, -.27542200E+02, -.94925700E+02, -.95567900E+01, 0.11537800E+02, -.90482700E+01, 0.93661700E+02, -.85137100E+02, -.26591600E+02, 0.54799300E+02, 0.59751400E+02, 0.61059000E+02, 0.92989100E+01, -.68463900E+02, 0.65678600E+02, -.23464800E+02, -.32597200E+02, -.19510800E+02, 0.65295300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54433600E+01, 0.69099000E+00, 0.20918800E+01, 0.11495000E+01, 0.28044300E+01, -.96710300E-01, -.14898300E+00, 0.17646900E+00, -.43048800E-02, 0.61156000E+00, -.35476800E-01, 0.82323300E+00, 0.96442900E+00, -.62620700E-02, -.36659900E+00, 0.16920200E+00, 0.18202900E+01, -.54460400E+00, 0.12776100E+00, 0.11219000E+01, -.30115000E+00, -.99117800E-02, 0.30493400E+00, 0.14686000E+01, 0.52188400E-01, -.65840600E+00, -.20196500E+01, -.21605400E+00, 0.42842000E+00, -.12356000E+01, -.52956400E-01, -.26827400E+00, 0.36702900E+00, 0.11702700E+01, -.20633500E+00, -.10533400E+01, -.21602700E-02, -.10320400E+00, -.10876900E+00, 0.67392100E+00, 0.39490900E-01, 0.94640500E+00, -.40475600E+01, 0.11425900E+00, 0.68778400E+00, 0.25507700E+00, 0.89541900E+00, 0.25274500E+00, -.82750400E+00, 0.16040200E+00, 0.46252100E+00, 0.45978500E+00, 0.11432100E+01, 0.60864900E+00, 0.57993700E-01, -.35750600E+00, 0.14968800E+00, -.34776700E+00, -.21135400E-02, -.45684000E+00, -.26618600E+00, -.48064400E+00, 0.18828000E+00, -.48249300E+00, 0.22121300E+00, -.24690200E+00, -.31878300E+00, -.27157400E+01, 0.22685900E+00, 0.61228000E-02, 0.33642900E+00, 0.10407700E+00, -.13850800E+01, -.64658100E-01, -.52572500E+00, 0.66404800E+00, -.43573100E-01, -.65296300E+00, 0.36737200E+00, 0.57941000E+00, -.33931800E-01, 0.16202700E+01, 0.37154900E+00, -.19738100E-01, 0.15701000E+00, -.63446600E-01, -.78509200E+00, -.78585200E-01, 0.35737600E+00, -.50001600E+00, 0.76505800E+00, 0.30195900E-01, 0.62095300E+00, -.99897000E-01, 0.45127100E-01, 0.55837200E-01, -.93222500E+00, 0.56281700E+00, -.29218600E+00, 0.14100600E+00, -.64134000E+00, -.82922800E+00, -.18780000E-01, -.20007500E+00, 0.24506000E+00, -.40199200E+00, -.41584000E+00, 0.39149200E+00, -.38801400E+00, 0.84075200E+00, 0.12046700E+00, 0.55128800E-01, 0.39628100E+03, -.78690900E-01, -.48235800E+03, -.60531700E+02, -.19093400E+03, -.53487000E+03, -.17855900E+03, 0.18444400E+03, -.73005600E+03, -.65181400E+03, 0.32532500E+03, 0.17885000E+03, 0.32595500E+03, -.87233600E+02, -.21923800E+03, 0.66775900E+03, 0.97093800E+03, 0.56853800E+03, -.37610400E+03, 0.10968800E+04, -.64493200E+03, 0.32994500E+03, -.27120500E+03, 0.32236800E+03, 0.17848200E+03, 0.56497600E+02, 0.50324200E+02, -.45855100E+02, 0.32956900E+03, 0.15912100E+02, 0.34278600E+03, -.93061900E+03, 0.46554900E+03, -.21302700E+02, 0.46535800E+03, 0.35492400E+03, 0.32413300E+03, 0.33785300E+03, 0.58125700E+03, 0.76112700E+03, -.13284300E+02, 0.43857700E+03, -.82008100E+03, 0.41191000E+03, 0.25242000E+03, 0.40990100E+03, -.26051800E+03, -.44675000E+03, 0.46597900E+03, 0.30086700E+03, 0.30774700E+03, -.40161800E+03, -.35246900E+03, -.27193600E+02, 0.14437800E+02, 0.98138900E+00, 0.12632600E+02, -.22739600E+02, -.19245200E+02, 0.95983000E+02, 0.94908000E+02, -.23785000E+02, 0.74227800E+01, -.83722900E+02, 0.15477000E+03, -.78535500E+02, 0.52622500E+03, -.77300700E+02, 0.15063900E+03, 0.80192900E+02, -.78442100E+02, 0.13462500E+03, -.18599600E+03, 0.22567800E+03, -.14386500E+03, -.23646600E+03, 0.11657600E+03, 0.43031800E+03, 0.11854300E+03, 0.29044300E+03, 0.39825900E+03, -.29567300E+03, -.20365600E+03, -.15073100E+03, 0.58406500E+03, -.21360100E+02, 0.91769700E+03, -.45819800E+03, 0.13449600E+03, -.45886200E+03, 0.34334000E+03, -.92430500E+02, -.18196900E+03, -.31797400E+03, -.66016700E+03, 0.10660100E+03, -.76860200E+03, -.28292600E+03, 0.14177000E+03, 0.33500600E+03, 0.14138100E+03, 0.37862900E+03, -.17671000E+03, 0.68227500E+02, -.19448600E+03, -.34610000E+02, -.49193700E+02, -.48573200E+03, -.13853700E+04, 0.68818900E+03, 0.22760800E+04, 0.69225700E+03, 0.31548800E+03, -.79093100E+01, 0.30893300E+03, -.19093000E+03, 0.15015400E+03, 0.18855100E+03, -.40065500E+03, -.78263200E+03, 0.40124200E+03, -.78545900E+02, 0.39081900E+03, 0.18316000E+03, 0.32459800E+03, -.30712200E+03, -.55876600E+03, 0.83694300E+02, 0.23239000E+03, 0.82120200E+03, -.33677900E+03, 0.17239900E+03, -.55124100E+03, 0.16840000E+03, 0.15638700E+03, 0.29404900E+02, 0.53942600E+02, -.67577100E+02, 0.27970200E+03, 0.56960700E+02, 0.12630700E+03, -.22551900E+03, 0.11213300E+03, -.19528800E+03, 0.11289800E+03, -.16998200E+03, 0.18206400E+03, -.20078600E+03, -.15875100E+03, 0.38325700E+03, 0.52059000E+02, 0.41498700E+02, -.31586600E+02, 0.65721700E+01, -.26792900E+01, -.88472300E+02, 0.10407800E+02, -.83285800E+01, 0.27202000E+02, 0.15071500E+02, 0.73212000E+02, -.21638300E+01, -.39214800E+02, -.51297000E+02, -.16621700E+03, 0.19676400E+02, 0.31441400E+02, -.48029000E+02, -.28676400E+02, -.10102000E+03, -.42407100E+02, 0.11879000E+03, -.98598700E+02, 0.23692200E+02, 0.60564300E+02, -.35001800E+02, 0.20725000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20626100E+02, 0.22109900E+01, 0.12352000E+01, -.57846600E+01, -.95465300E+01, -.89518000E+00, 0.37195500E+01, -.17301800E+00, -.16881700E+00, 0.37835800E+01, 0.30927700E+01, -.13063600E+00, -.73293200E+00, -.77884100E+00, 0.89404800E+00, 0.39123200E+01, 0.37470100E+01, 0.28814300E+01, -.17676900E+01, 0.33489100E+01, 0.11047200E+01, -.23847400E+00, 0.21581100E+01, 0.50557700E+01, 0.69930000E+00, 0.25443400E+01, -.18174700E+01, 0.40890200E+01, 0.85346700E+00, -.38459600E+00, 0.27609900E-03, 0.32705400E+01, -.22341400E+01, 0.44746700E+01, -.73520400E+00, -.11267500E+01, 0.12643100E+00, -.41073900E+00, 0.42818500E+00, -.25402400E+01, 0.79489600E-01, 0.55052800E+00, -.27820700E+01, -.23086600E+00, -.84619700E+00, -.41079600E+00, 0.16410800E+01, -.25035400E+01, -.58576500E+00, 0.36943400E+00, -.16739600E+01, 0.18593000E+01, -.15390200E+00, -.43412300E+00, 0.20086700E+01, 0.28466700E+01, 0.72699600E+00, -.83689300E-01, 0.35610500E-02, -.31862000E+00, -.46200400E+01, -.21355100E+01, 0.53208800E+00, -.24891000E+00, 0.81321300E+00, -.29535400E-01, -.29563600E+00, -.51582700E+01, -.35540400E-01, 0.74119600E-02, 0.57255300E+00, 0.71484100E+00, 0.15172200E-01, -.49383800E+00, 0.13863700E+01, -.12580000E+01, 0.75220700E+00, 0.13362700E+01, 0.19329900E+00, 0.10792100E+01, -.40012100E-01, -.15438500E+01, 0.21777100E+00, -.72613600E+00, -.55818600E+00, 0.18010900E+00, 0.11797700E+01, -.50848000E+00, 0.29735800E+00, 0.99443000E+00, 0.15915900E+01, -.94793900E-01, -.94133600E-01, -.62652800E-01, -.15634200E+00, -.10367700E+01, -.51877300E+00, -.37253900E+00, 0.91326000E+00, -.15570500E+00, -.11451300E+01, 0.42192200E-01, -.11007200E+00, -.19523500E+00, -.28352700E+00, -.49084500E+00, 0.50408600E+00, -.23490500E+00, 0.12928700E+00, -.25528300E+01, -.97618600E+00, -.29016200E+00, 0.61734100E+00, 0.32559300E+01, -.11986900E+03, -.23570200E+03, -.50757600E+02, -.19599600E+03, -.68439300E+02, -.14242400E+02, -.44101400E+03, 0.39878600E+02, -.19245400E+02, 0.76265100E+02, -.19930600E+02, -.11309000E+03, 0.12176400E+03, 0.13197500E+03, 0.27741400E+03, 0.31382500E+03, -.24143400E+02, 0.38981100E+02, -.44399600E+03, 0.21748500E+03, 0.79013300E+02, 0.22206200E+03, 0.13160200E+03, 0.32566800E+02, 0.77673600E+02, 0.46599600E+02, 0.22271500E+03, -.13805600E+01, 0.18727900E+03, -.58692600E+02, 0.27733400E+02, -.21249300E+03, 0.29336300E+02, -.17616800E+01, 0.19402100E+03, -.38917200E+02, 0.13496400E+03, 0.12289900E+03, 0.12184300E+03, 0.35677600E+03, 0.28764400E+03, -.14029500E+03, 0.99611900E+02, -.14381500E+03, -.52056900E+02, 0.13424800E+03, -.62809000E+02, -.92812200E+02, -.23638700E+03, 0.18179400E+02, -.31411500E+03, -.28864500E+03, 0.14466700E+03, 0.35291000E+02, 0.14811700E+03, -.93464100E+02, -.29898700E+02, 0.11206000E+03, 0.13500300E+03, 0.72345700E+02, 0.30364600E+02, 0.89818000E+02, 0.32103500E+03, -.16061000E+03, -.10943300E+03, -.16050700E+03, -.27863000E+03, -.21672000E+03, 0.10318400E+03, 0.17449200E+03, -.89368600E+02, -.18857800E+03, -.11245100E+01, 0.34747000E+03, -.17659200E+03, -.15938700E+03, -.17378100E+03, 0.13460500E+03, -.16043200E+03, -.14157800E+03, -.90011800E+02, -.11616700E+03, -.17445300E+02, -.28207500E+03, -.43773700E+03, 0.22299500E+03, 0.13549200E+03, 0.21887100E+03, 0.20933000E+03, -.20171800E+02, -.13255800E+02, -.19326300E+03, 0.55078300E+02, 0.92558900E+02, -.16162000E+03, -.28386300E+03, 0.14257000E+03, 0.15957800E+03, 0.14194300E+03, 0.87540200E+02, -.15855200E+03, 0.10868600E+03, -.41260600E+02, 0.67324900E+02, -.69784900E+02, -.73400200E+02, 0.73762100E+03, -.37020300E+03, -.12249300E+03, -.36872500E+03, -.34688500E+03, -.27199500E+03, -.19155400E+03, -.34238900E+02, -.44761200E+03, -.71742600E+02, -.41665100E+03, -.93524800E+03, 0.46298000E+03, 0.89111800E+02, 0.46778500E+03, 0.23132700E+03, 0.29707700E+03, -.30640200E+01, -.15418600E+03, 0.27906100E+03, 0.15721400E+03, 0.52212100E+03, -.26100000E+03, 0.13461000E+03, -.21587100E+03, 0.13045100E+03, 0.20547000E+03, -.33276200E+02, 0.46823800E+02, -.30963700E+02, 0.22787800E+03, 0.66626100E+01, 0.15215900E+03, 0.73398600E+02, -.41541000E+02, 0.23305100E+02, -.36717700E+02, -.58701300E+02, -.20906000E+03, 0.18185200E+02, -.75396700E+02, 0.80894700E+02, -.18155500E+03, 0.14529200E+03, 0.37569100E+02, -.48052800E+02, 0.81601600E+02, -.91322500E+02, -.65598500E+02, -.41893000E+02, 0.45012300E+02, -.62618100E+02, -.11387100E+02, 0.49562100E+02, 0.18219800E+02, -.65882400E+02, -.50882600E+02, -.40036700E+02, 0.19697700E+02, -.59498100E+02, -.87859500E+02, 0.48292400E+02, 0.94812400E+01, -.17074400E+01, -.10027500E+02, 0.14142800E+02, -.78838700E+01, 0.26540700E+02, -.14044900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.94856600E+01, -.85692900E-01, 0.89782700E+01, 0.67251200E+00, -.57909600E+01, 0.18374200E+01, 0.82246900E+00, -.56023200E+00, 0.87432600E+00, -.74900200E+00, -.10755200E+00, 0.11494900E+01, -.34576500E+01, 0.36794400E+01, 0.16623000E+01, 0.13048700E+01, 0.16614800E+01, 0.50190700E+01, 0.14564100E+01, 0.14953000E+01, 0.30338600E+01, 0.11627400E+01, 0.54930300E+00, -.11808500E+01, -.47853700E+00, -.16337000E+01, -.42334800E+01, 0.45522600E+01, 0.14203100E+01, -.16683100E+01, 0.56072000E+00, -.24476500E+00, -.61656200E+01, 0.14046000E+00, 0.41076100E+00, -.37299900E+00, -.11360100E-01, -.10204000E+01, 0.12010300E+01, 0.28215000E+01, 0.25468300E+00, 0.24486500E+00, 0.66225300E+01, -.89179800E+00, -.11237700E+00, 0.56461100E-01, -.23362500E+00, -.27431700E+00, -.32874900E+00, 0.10089500E+00, -.81734700E-01, -.43102300E+00, -.14179200E+00, 0.12857400E+01, 0.78755300E+00, -.14083900E+01, -.18701900E+00, 0.10717700E+00, -.33274000E-03, -.48230500E+00, 0.11501800E+01, -.65073700E-01, -.43373400E-01, 0.34286100E+00, 0.33601000E+00, 0.41388200E+00, 0.87144800E-02, 0.26352600E+01, 0.12220800E+00, -.30658200E-02, 0.99764000E-01, -.50191800E+00, -.24051100E+01, 0.13976000E-01, -.18947400E-02, 0.38004500E+00, -.61497100E+00, 0.20182900E+00, -.28666400E+00, 0.53600900E+00, 0.26903000E-02, 0.18710200E+01, -.64667900E+00, 0.69893700E+00, 0.46474100E+00, -.41008400E+00, -.23460800E-02, -.25966600E-01, 0.95074400E+00, -.15748700E-01, 0.29785700E+01, 0.15597900E-01, 0.80025000E+00, -.99175400E-01, -.13107200E+01, 0.21481800E+00, 0.70068200E+00, -.46509000E+00, -.13247900E+00, 0.54437100E+00, 0.13225400E+01, 0.70085500E+00, 0.13856700E+00, 0.26026000E+00, -.12374400E+00, 0.10667100E+01, 0.74215300E+00, -.31378900E+00, -.17255600E+01, 0.36120500E+01, -.78860200E+00, 0.47610600E+00, -.69610600E+00, -.48649600E-01, -.94102100E+03, -.37502600E+03, -.28001900E+02, -.34400100E+03, -.48920400E+03, 0.19663300E+02, -.15479300E+04, -.39701600E+04, 0.19804700E+04, 0.10013300E+04, 0.19852800E+04, 0.97998800E+02, 0.35833900E+03, 0.10989100E+04, 0.44642000E+03, 0.14731800E+04, 0.29500000E+03, 0.42618100E+04, 0.12047300E+02, 0.23898500E+02, -.36726500E+03, -.58899200E+01, 0.17820400E+03, -.12155600E+03, -.28843800E+02, 0.40310200E+02, 0.10846000E+03, -.15366700E+03, 0.88741500E+02, -.19726300E+04, 0.99405700E+03, -.21083600E+03, 0.98638100E+03, 0.32105700E+03, 0.82320600E+03, 0.73581100E+03, 0.87612300E+03, 0.10928000E+04, 0.57859200E+03, 0.17836400E+04, -.25478800E+04, 0.12574000E+04, 0.12911800E+04, 0.12736000E+04, -.17648000E+03, -.92750400E+03, 0.15289200E+04, 0.13202000E+04, 0.15331000E+04, -.13248000E+04, -.11099100E+04, 0.14485700E+04, -.73101000E+03, 0.45407900E+02, -.72465700E+03, 0.45011900E+03, -.38996200E+02, -.47565800E+03, -.52509700E+02, -.11837000E+04, 0.22385900E+03, -.10002800E+04, -.23852900E+03, 0.12875700E+03, 0.11403900E+04, 0.11953100E+03, 0.29369600E+03, 0.55043800E+02, 0.19261400E+03, -.62256200E+03, -.22507400E+03, 0.18866900E+03, 0.16664700E+03, -.56890100E+02, 0.49649100E+02, 0.74478500E+03, 0.29091100E+02, 0.94472400E+02, 0.27797400E+03, -.49069000E+03, -.46056200E+03, -.71859900E+03, 0.68588800E+03, -.89677400E+03, 0.27513700E+04, -.13926500E+04, 0.93075400E+02, -.13757100E+04, 0.94506500E+02, 0.44890600E+02, -.13777700E+04, -.91934400E+03, -.12722100E+04, 0.34631800E+03, -.11697000E+04, 0.16834800E+04, -.84884500E+03, -.41863800E+03, -.84192300E+03, 0.49465800E+03, -.27698100E+03, -.54228600E+03, -.33758800E+03, -.62503600E+03, -.21049100E+03, -.18847100E+04, -.26217200E+02, 0.23175300E+02, 0.10904100E+04, 0.12357000E+02, -.38889600E+03, -.12287000E+04, 0.92792500E+03, -.16004300E+03, -.34110200E+03, -.75366900E+03, -.94382200E+03, -.62564600E+03, 0.35383000E+03, -.27388600E+03, 0.31221300E+03, 0.44935700E+03, 0.12162700E+03, -.28217200E+03, -.65997100E+03, 0.34164000E+03, 0.49894600E+02, 0.14973100E+04, -.10706500E+03, 0.62658200E+02, -.78394400E+03, 0.53297100E+02, 0.27715600E+03, 0.10689000E+03, -.32709000E+03, -.30865600E+02, 0.17245500E+03, 0.15714000E+03, -.41898300E+03, -.33948100E+03, 0.19001000E+03, -.37408100E+03, 0.17005700E+03, -.55268700E+03, 0.32494600E+03, 0.27485500E+03, 0.25109400E+03, 0.66288600E+03, -.41035400E+02, -.44700600E+03, -.14934500E+02, -.59130400E+02, 0.20452400E+03, -.21766800E+03, -.21113600E+03, -.14529900E+03, 0.13478700E+03, -.20751000E+03, 0.48310500E+03, 0.52747400E+02, 0.74549700E+02, -.17758500E+03, -.91412500E+02, 0.43483900E+03, 0.12131900E+02, -.10241200E+03, -.17196800E+03, 0.56721200E+02, 0.70230800E+02, 0.75303100E+02, 0.41488100E+02, 0.64355500E+02, -.71577300E+02, 0.77274200E+02, -.16283600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26888600E+02, 0.23613900E+01, -.31044600E+01, -.84988000E+01, -.69015000E+01, -.88879500E+00, 0.31841700E+01, 0.32025000E+00, -.81081400E+00, 0.27461500E+01, 0.12201500E+01, 0.21349900E+01, 0.14034100E+01, -.72499700E+01, 0.69468800E+00, 0.41579900E+01, 0.66121300E+01, 0.43687700E+00, -.47295700E+01, 0.41530400E+01, 0.33030600E+01, -.56028100E+00, 0.28611100E+01, 0.38094000E+01, 0.84947100E+00, 0.26875000E+01, 0.18325100E+01, -.12626200E+01, 0.31908900E+00, 0.67756700E+00, -.78909700E+00, 0.40045500E+01, 0.92589100E+00, 0.47353000E+01, -.68683900E+00, 0.26704700E+01, 0.98212300E-01, -.27589900E+00, 0.10331800E+01, 0.45974100E+01, -.26590400E-01, 0.10758800E+01, 0.88083300E+01, -.90618100E+00, 0.30846300E+01, 0.89065000E+00, 0.12887900E+01, -.10580000E+02, -.35545600E+01, 0.78991500E+00, -.61397500E+01, 0.20518900E+01, -.88856600E+00, 0.46591300E+01, 0.84986400E+01, 0.47891900E+01, 0.63358400E+00, -.42182200E+01, -.12590400E+01, -.70178500E+00, -.87837000E+01, -.30283600E+01, 0.11572600E+01, -.39037600E+01, -.24328700E+01, 0.31249600E+01, -.43471700E+00, 0.33542100E+01, -.15121800E+00, 0.93138200E+00, 0.20299000E+01, 0.30285800E+00, 0.10526000E+01, 0.32831500E+01, 0.10401900E+01, -.12089900E+00, -.28793000E+00, 0.11044000E+01, -.93310800E+00, 0.23381200E+01, -.22035300E+01, -.16952700E+01, 0.41195900E-01, -.20298900E+01, -.79686600E+00, 0.20906800E+00, 0.23113300E+01, -.62156100E-01, -.45397200E+01, 0.22266800E+01, 0.38938700E+01, 0.11668000E+01, 0.30010500E+01, -.44570300E+00, 0.75396400E+00, -.63799000E+00, -.20845500E+01, 0.20508200E+01, -.17537400E+01, 0.91058400E+00, -.28006100E+01, -.47757900E+01, 0.12196900E+01, -.20278300E+01, -.42869000E+00, -.35465400E+01, -.27378000E+01, 0.13746900E+00, 0.35589900E+01, -.36212200E+01, 0.39929800E+01, 0.39241800E+00, 0.14683900E+01, -.66175200E-01, -.22100700E+01, 0.13705000E+04, -.23906500E+03, 0.74544000E+03, 0.42747000E+03, 0.84992400E+03, 0.14157200E+04, 0.49569600E+04, -.24876900E+04, -.23776600E+04, -.24765500E+04, -.54490900E+03, -.28944500E+04, 0.10534100E+04, 0.21017100E+04, 0.15301200E+04, -.27386700E+04, -.43098700E+04, -.12867900E+03, 0.16187100E+03, 0.31824500E+04, 0.66481100E+02, -.32034500E+03, -.15217600E+03, -.60525300E+02, -.27404200E+03, -.33460500E+03, -.36894900E+02, -.65024200E+03, 0.14419400E+04, -.68285300E+03, 0.13125900E+04, -.72397700E+03, -.61175000E+03, -.14574800E+04, 0.10464400E+04, 0.11726300E+04, 0.18739900E+03, -.14164200E+04, -.19112300E+04, 0.35727200E+03, -.20438400E+03, -.67692800E+03, -.17090500E+03, -.24496000E+03, 0.42579700E+03, -.13250600E+04, -.13350800E+04, -.74834100E+03, 0.12335100E+04, 0.30359900E+04, 0.10093800E+04, -.50307500E+03, 0.20876700E+03, -.50615300E+03, 0.24942400E+03, 0.36368600E+03, -.93705400E+03, -.54963400E+03, -.23404300E+03, 0.43417500E+02, -.29246700E+03, -.31758300E+04, 0.16045600E+04, 0.96715300E+03, 0.15787100E+04, 0.18282200E+04, 0.12092900E+04, -.10141800E+04, -.12414500E+04, -.25169300E+03, 0.11468400E+04, 0.80084800E+02, -.15037300E+04, 0.78563800E+03, 0.99264900E+03, 0.72949600E+03, -.12779500E+03, 0.98282300E+03, -.58704000E+03, 0.63324700E+02, -.44702000E+03, 0.87380400E+03, -.21266800E+02, 0.17037400E+04, -.87016400E+03, 0.40911500E+03, -.85122800E+03, -.18922100E+04, -.11795800E+04, 0.65095600E+03, 0.89448900E+03, -.16474400E+04, -.86897500E+03, 0.11697900E+03, 0.10856100E+04, -.55035500E+03, -.19107700E+03, -.53911100E+03, -.10088800E+01, 0.47834800E+03, -.96401400E+03, -.76717800E+03, -.13070900E+04, 0.66754800E+03, -.37162100E+03, -.51033900E+04, 0.25438100E+04, 0.12204700E+04, 0.25759000E+04, 0.18682700E+04, 0.30124200E+04, -.10703500E+04, -.16851300E+02, -.92638000E+03, 0.24466100E+04, 0.42881300E+04, 0.34101900E+04, -.15314500E+04, -.32836800E+03, -.16874300E+04, -.18927800E+04, -.19033400E+04, 0.90626800E+03, 0.88020900E+03, 0.43497100E+03, -.17279400E+04, -.25445000E+04, 0.18301400E+03, -.25654000E+02, 0.10269000E+04, -.92426100E+02, -.55846800E+03, 0.27940800E+03, 0.10975200E+02, -.69118300E+03, -.43871600E+03, 0.19567800E+03, -.21512900E+04, -.83059300E+03, 0.42918900E+03, -.14407300E+04, 0.40974300E+03, 0.10688800E+04, 0.15198100E+04, -.93789700E+02, -.10228000E+03, 0.11301500E+04, 0.13377100E+04, -.17152100E+03, 0.13495300E+03, 0.34324000E+03, -.25814500E+03, 0.50312200E+03, 0.24948800E+03, 0.25331900E+03, -.24780400E+03, 0.29320300E+03, 0.16874800E+03, -.25815200E+03, 0.10580200E+03, 0.23544000E+03, 0.37710000E+03, 0.29922500E+03, 0.98790100E+02, 0.29020700E+03, 0.40725200E+03, -.23016600E+03, -.29641500E+03, 0.39722000E+03, -.49902200E+03, 0.27355200E+03, -.49745800E+02, 0.33263700E+01, 0.23125000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.47725900E+01, 0.50378000E+00, 0.62685200E+00, 0.27071500E+00, 0.21335400E+01, 0.19100900E+00, 0.73227500E-01, 0.29190200E+00, 0.45811000E+00, 0.26927600E+00, -.10684100E+00, 0.70437600E+00, 0.52143100E+00, 0.33319400E+00, 0.73047400E-01, 0.12703200E+00, 0.19574300E+01, 0.51239500E+00, 0.63120800E+00, 0.77530600E+00, -.25170800E+00, 0.24758100E-01, 0.11990700E+00, 0.79346400E+00, 0.24460300E-01, -.55663700E+00, -.20926400E+01, -.59219100E+00, 0.27022900E+00, -.87597600E+00, 0.24859600E-02, -.15243100E+00, 0.76387700E+00, 0.25373700E+00, -.99917200E-02, -.12917200E+01, -.70519900E-02, -.80931700E-02, 0.28128600E-01, 0.12948600E+01, 0.24275500E+00, 0.84675600E+00, 0.64570100E+00, 0.40412000E-01, 0.26743800E+00, 0.29517000E+00, 0.79169800E+00, -.25904500E-02, -.95279100E+00, 0.38678700E-01, -.88165100E+00, 0.30566400E+00, 0.31996000E+00, -.34986300E+00, 0.14735200E-01, 0.67877900E-01, 0.93900500E-01, -.49724300E+00, -.72768300E-03, 0.47164000E+00, -.72633500E+00, -.89431800E+00, 0.12801300E+00, -.35271700E+00, -.15744200E+00, 0.26157200E+00, -.12880300E+00, -.20746900E+00, 0.10745100E+00, -.11305700E-02, 0.66156500E-01, -.53669900E-02, 0.15052100E+00, 0.70275000E+00, -.37760100E+00, -.16026100E+00, -.79522700E-01, 0.23709200E+00, 0.11672100E+00, 0.13888600E+00, -.23169600E-01, -.18054800E+00, -.15289100E-01, -.89507100E-02, 0.80719000E-01, -.11334300E+00, 0.69641600E+00, 0.60422800E-01, 0.73366500E+00, 0.17195500E+00, 0.21808300E+01, -.27822300E-01, 0.38086400E+00, -.49284600E-01, -.85287600E+00, -.20679100E+00, -.35353400E+00, -.26133200E+00, 0.14353000E+00, -.22780600E-01, -.24345100E+00, 0.18760600E+00, -.28103600E-01, -.10348300E+00, 0.12707100E+00, -.46120800E-01, -.17083800E+00, -.40051900E-02, -.18578900E+00, -.38770900E+00, -.34866200E+00, -.16378300E+00, 0.16192100E-02, -.23935200E-01, -.13083200E-01, 0.74165800E-01, -.33555600E+03, -.54740800E+03, -.32631000E+03, 0.24706500E+03, -.73630500E+03, -.11447500E+04, 0.57380600E+03, 0.38492500E+03, 0.57224100E+03, -.11550700E+03, 0.65777700E+02, 0.33013300E+03, 0.16868200E+03, 0.30373800E+03, -.14500200E+02, 0.12178500E+04, -.16594200E+03, 0.76786400E+02, -.60173400E+03, 0.82599000E+02, 0.11771100E+03, 0.63055400E+02, 0.12500500E+02, 0.10903000E+03, 0.23141400E+03, -.43608800E+00, 0.17066100E+03, 0.18669600E+03, -.97501900E+02, -.36988700E+03, -.93069600E+02, -.13320500E+03, 0.35545100E+03, -.84098000E+02, 0.27518300E+03, 0.15157700E+02, 0.22149500E+03, 0.52742500E+03, -.21027700E+03, 0.10952800E+03, 0.21064800E+03, 0.10446500E+03, 0.15232800E+03, -.80761400E+02, 0.12945300E+03, -.20112100E+03, 0.10176900E+03, -.24859600E+03, -.84172700E+03, 0.39594000E+03, -.19812000E+03, -.19649600E+03, -.19796500E+03, -.78504300E+02, -.45156100E+02, 0.79453500E+02, 0.28969500E+03, -.65032900E+02, 0.39241400E+02, -.29545300E+03, 0.45340900E+03, -.22831200E+03, -.71476300E+02, -.22598900E+03, -.70705900E+02, -.21853000E+03, 0.15561800E+03, 0.11330500E+03, 0.59309300E+01, -.18440400E+03, 0.27205200E+03, -.36025300E+02, 0.14728400E+02, 0.48384100E+01, 0.19955600E+02, 0.22318600E+03, 0.15653500E+03, -.42608400E+03, -.33789700E+03, -.36588200E+02, 0.34606600E+03, 0.80524400E+01, -.22280700E+03, 0.11494400E+03, -.26124700E+02, 0.11134400E+03, 0.23433100E+03, 0.51222900E+02, -.19181100E+03, -.43673100E+03, -.14205400E+02, 0.19544000E+03, -.14548300E+03, -.20635800E+03, 0.10371100E+03, 0.21348700E+03, 0.10283300E+03, 0.17265300E+03, -.13200700E+03, 0.12699100E+03, 0.85911500E+01, 0.13001400E+03, -.80984600E+02, -.90512200E+02, 0.58388300E+03, -.29276600E+03, -.18615600E+02, -.29418000E+03, -.49344500E+02, -.47276400E+03, 0.13639400E+03, -.60173900E+02, -.11068300E+03, -.19821200E+03, -.38433600E+03, -.38325000E+03, 0.17848000E+03, -.20521400E+01, 0.18967800E+03, 0.26699500E+03, 0.39343800E+03, -.22778200E+03, -.12128900E+03, -.24191600E+02, 0.23100200E+03, 0.57947600E+03, -.32605400E+03, 0.15910800E+03, -.23077600E+03, 0.16321100E+03, 0.14523800E+03, 0.98543900E+02, -.14146700E+03, 0.10856500E+02, 0.17230700E+03, 0.11672800E+03, 0.27495200E+03, 0.33822100E+03, -.17225200E+03, 0.22856900E+01, -.16858000E+03, -.17491400E+03, -.12541500E+03, -.12897400E+03, -.37435500E+02, -.47136000E+02, -.15468500E+03, 0.24695100E+03, 0.28938900E+02, -.17131200E+02, 0.50020200E+02, -.94277700E+02, -.57248300E+02, -.97151200E+01, 0.14622100E+02, -.57480100E+02, 0.88985000E+01, 0.29901400E+02, 0.16572000E+02, -.93359600E+02, -.11930200E+03, -.34867400E+02, 0.90218500E+02, -.17423100E+02, -.85440300E+02, 0.52723800E+02, -.32431600E+02, 0.44271100E+02, -.11909500E+02, -.17349600E+02, 0.16337800E+01, 0.20082700E+02, -.10639200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28719200E+01, -.35692900E+00, -.79466200E+00, -.10584400E+01, -.84095800E+00, 0.12130800E+01, -.95324200E+00, -.10962300E+00, 0.20539800E+00, -.12569100E+01, -.35553000E+00, -.10202500E+01, -.94319800E+00, -.12818500E+01, -.25047700E+00, -.83876200E+00, -.16986000E+01, -.37352900E+00, -.59208500E+00, 0.90656800E-01, 0.86518100E+00, 0.43935500E+00, -.61795600E-01, -.32252200E+00, 0.20515900E+00, 0.42608600E+00, 0.10936200E+00, 0.20667700E+01, -.17649800E+00, -.47450500E+00, 0.17864400E+00, 0.21481500E+00, -.19794900E+00, 0.54992500E+00, -.17401100E+00, -.47917800E+00, 0.24715900E-02, 0.86519700E-01, -.38463400E+00, 0.19689800E+00, -.13475700E+00, 0.51646700E+00, -.96115900E+00, 0.20175800E-01, 0.10577000E+01, 0.11471300E+00, -.32636100E+00, 0.22935400E+00, -.19079300E+00, 0.34264400E-01, 0.24192500E+00, -.40739200E+00, 0.31752200E+00, -.22793200E+00, -.49040900E+00, -.47407500E+00, -.15074000E+00, -.17211100E+00, -.65992000E-03, 0.19133100E-01, 0.87497700E+00, 0.12659700E+00, -.14824400E-02, 0.27322900E+00, -.28886800E+00, 0.30636800E-01, -.71770800E-01, -.41936200E+00, 0.15153300E-01, -.11967500E-03, -.46808900E+00, -.32888100E+00, -.49590700E+00, -.49708800E+00, 0.34329200E+00, 0.98770200E-01, -.16348800E+00, -.12836600E+00, 0.25559700E+00, -.64689600E-01, 0.31527200E-03, 0.51001800E+00, 0.18182100E+00, -.46804900E-01, 0.11670400E-01, 0.12357200E+00, -.11199000E+01, 0.10505000E+00, -.92414200E+00, -.26648900E+00, -.17723600E+01, 0.42184100E-01, 0.12898000E-01, -.32235500E-02, 0.10803100E+00, 0.37811100E+00, -.49622000E+00, 0.53986800E+00, -.10340000E+00, -.46991700E-01, -.19779800E-01, 0.43624100E+00, 0.21636800E-01, 0.16889400E+00, -.15404300E+00, -.22496600E-01, 0.50821700E+00, 0.74602900E-01, -.32151400E-01, 0.66344500E+00, -.23882300E+00, -.93261200E-01, -.27174000E+00, -.10282400E-01, 0.29130600E+00, 0.68848400E-01, -.54843800E-01, -.23398400E+03, -.58511800E+02, 0.38224800E+02, -.10835600E+03, -.37453700E+03, 0.18985300E+03, 0.39045200E+03, 0.18710200E+03, 0.12875500E+03, 0.14984400E+03, -.67422600E+02, -.46781700E+02, -.22867300E+03, 0.59377000E+02, 0.48626100E+02, 0.81978400E+02, -.53097400E+02, -.36381500E+03, -.41182900E+02, 0.11795400E+02, 0.24034700E+02, 0.15727700E+02, 0.51103900E+02, 0.59449000E+02, 0.17423600E+02, 0.14918700E+02, -.45659300E+03, 0.22345300E+03, -.42887000E+01, 0.22851100E+03, 0.91335300E+02, -.18480600E+02, -.13859900E+02, -.74170700E+02, 0.17175500E+03, -.60814400E+02, 0.14403600E+03, 0.35535000E+03, -.16959500E+03, -.20215600E+03, -.17819900E+03, 0.46486200E+02, 0.13413300E+03, -.87306500E+02, -.55895800E+01, -.23668000E+03, 0.16615700E+03, -.13598200E+03, -.95030700E+03, 0.47748400E+03, -.47419100E+01, 0.47505900E+03, -.12129300E+03, -.17971900E+03, 0.41739400E+03, 0.33906000E+02, 0.54832300E+03, -.17768200E+03, 0.90509800E+02, 0.43061400E+03, -.21965800E+03, -.11430600E+03, -.21467500E+03, -.15000800E+03, -.72974600E+02, 0.64419900E+02, 0.29702000E+03, -.71786100E+02, -.51344600E+02, -.25422400E+02, -.16502500E+03, 0.72106400E+02, 0.16324200E+02, 0.84089000E+02, 0.40181900E+02, 0.17701400E+02, 0.14903200E+03, -.53854100E+02, 0.10081100E+03, -.28923000E+02, 0.21797800E+03, -.15861700E+03, 0.87411700E+02, 0.95137900E+02, 0.79264400E+02, 0.28180200E+03, 0.28011900E+02, 0.34059700E+01, -.13738600E+03, 0.12421400E+03, 0.23733200E+02, -.23208400E+03, -.63978900E+03, 0.32287600E+03, 0.65535800E+02, 0.31964000E+03, 0.72730900E+02, -.56475200E+02, 0.23277000E+03, 0.51121900E+02, 0.30675100E+03, -.22723400E+02, 0.19292800E+03, -.81158300E+02, 0.34843000E+02, 0.26863300E+03, 0.38865200E+02, 0.77303300E+02, 0.87549600E+02, 0.53175900E+02, -.19764900E+03, 0.41575700E+03, 0.82985000E+02, -.44757300E+03, -.39079000E+03, 0.17471700E+03, 0.22529300E+03, 0.19410200E+03, 0.21061400E+03, 0.28987700E+03, -.19212600E+03, -.18307400E+03, -.21982200E+03, 0.25992700E+03, 0.22975700E+03, 0.33724000E+02, -.22048800E+02, -.11548700E+03, -.16745100E+02, -.26682900E+02, -.82524600E+02, 0.41809000E+02, 0.69761500E+02, 0.18050100E+02, -.57793300E+02, 0.33099200E+03, 0.41220900E+03, -.21582600E+03, 0.21685800E+02, -.20572700E+03, -.15809200E+03, -.35177000E+02, -.13936200E+03, 0.77370200E+02, -.34131900E+03, -.20999000E+02, 0.42470700E+03, 0.77807500E-02, -.18120200E+02, 0.80751900E+01, -.15389200E+02, -.86007900E+01, 0.79984500E+01, 0.12453800E+01, -.15076000E+02, -.25532800E+02, 0.15793500E+02, -.17102200E+02, -.25354800E+02, -.82802000E+02, -.32714700E+02, -.75280500E+01, -.12581300E+02, 0.37454600E+01, 0.59462300E+01, 0.31728300E+01, -.12035500E+01, 0.59832100E+01, -.64178800E+02, 0.81867100E+01, -.12532700E+02, -.27023200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26201100E+01, 0.35039000E+00, 0.12093900E+01, 0.65986700E+00, 0.15469100E+01, -.10861500E+00, -.17956100E-01, 0.10501600E+00, 0.63011700E-03, -.11930700E-01, -.23822100E+00, 0.51978800E+00, 0.56352800E+00, -.15633200E+00, 0.22895600E-01, -.23807700E+00, 0.61420300E+00, 0.28888000E+00, 0.35695400E+00, 0.42332700E+00, -.37949900E+00, -.10332300E+00, 0.34926500E-01, 0.82567300E+00, 0.21137300E+00, -.17827400E-01, -.52155300E+00, 0.23456500E+00, 0.46243800E+00, -.90112900E+00, 0.59486800E-01, 0.27159200E+00, -.29586100E+00, -.12858400E+01, 0.19828800E+00, -.18411700E+00, 0.49709900E-01, -.21852700E+00, 0.21443900E+00, -.56999300E+00, -.25790300E+00, -.38571800E+00, 0.19502500E+01, -.13672500E+00, -.12012500E+00, -.75990800E-01, -.35094400E-02, -.77728000E+00, -.26227600E+00, 0.32453300E-01, -.36469200E+00, -.19288500E+00, -.41606100E+00, 0.33432500E-01, 0.19678100E+00, 0.15669000E+00, 0.88087300E-01, -.17670800E+00, 0.40742300E-03, -.32869600E+00, -.20498600E+00, -.26571300E+00, 0.27508600E-01, -.21186800E+00, -.40686200E+00, 0.44727700E-01, -.13671600E+00, 0.28436300E+00, 0.11881900E-01, -.12611400E-02, -.14006500E+00, 0.18736200E+00, -.28283400E-01, -.19054300E+00, 0.11459700E+00, 0.54333500E-01, -.42629600E-01, -.55592500E-01, 0.19847900E+00, -.49631400E-01, -.53124300E-02, -.83656200E-01, -.25776600E+00, -.58545100E-01, -.11784800E+00, 0.53072400E-01, -.70258600E+00, 0.99833800E-02, -.12959300E+00, 0.69864900E-01, -.66589600E+00, 0.53740300E-02, 0.20410500E-01, -.63015500E-03, -.72071400E-01, 0.41950800E-01, -.14977400E+00, 0.13258900E+00, -.81929700E-01, -.17742300E-01, 0.18257300E+00, 0.98653600E-02, 0.20120400E-03, 0.37950800E-01, -.26218600E-01, -.12662200E+00, 0.32127100E-01, 0.44653900E-01, 0.44646000E-01, 0.97065200E+00, -.23559900E+00, 0.62332400E-01, -.87637200E-01, -.17952500E-01, 0.67075100E-01, -.33089800E-02, -.12963300E+00, 0.18403900E+00, -.16356600E+03, 0.34808300E+02, -.27758100E+03, -.71396000E+03, 0.35724500E+03, 0.43134100E+03, 0.35702000E+03, 0.92982700E+02, 0.49499900E+02, 0.10609100E+03, -.11253900E+03, 0.28879800E+03, 0.48706200E+02, 0.61568500E+03, -.16838700E+03, 0.87236900E+02, -.44384000E+02, 0.84132200E+02, 0.43745800E+02, 0.10670300E+02, 0.25023100E+02, -.20574100E+02, 0.64950300E+02, 0.88955100E+01, 0.12054000E+03, -.40625200E+03, 0.20443400E+03, 0.10822000E+03, 0.20313400E+03, 0.99413300E+02, -.40808500E+01, 0.86154700E+02, -.11921300E+03, 0.16331300E+03, -.87716300E+01, 0.24373500E+03, -.68787000E+02, 0.32908300E+02, 0.10725800E+03, 0.34367000E+02, -.37421900E+02, -.10911900E+02, 0.11659500E+03, 0.22143300E+03, 0.66252800E+02, -.71530600E+02, -.26659200E+03, 0.24303800E+03, -.12093800E+03, -.18413800E+03, -.12155900E+03, 0.30100500E+01, -.11257100E+03, -.56914200E+02, -.48233700E+01, -.13895700E+03, -.73895700E+02, -.61882000E+02, 0.26266000E+03, -.13093100E+03, -.75265300E+02, -.13135900E+03, -.47724800E+02, -.55642800E+02, 0.32217200E+02, 0.34863400E+02, -.43562100E+02, -.21399200E+02, -.46261400E+02, 0.22496100E+03, -.11178500E+03, -.99223600E+02, -.11243500E+03, -.38105800E+02, -.31276400E+02, -.29963600E+02, 0.92723600E+02, -.18075800E+03, 0.14591700E+01, -.11810300E+03, 0.12566600E+03, -.62880900E+02, 0.20962700E+01, -.62837500E+02, -.30828500E+02, 0.14369900E+03, -.61048500E+02, 0.82431700E+02, -.10153900E+03, 0.14585700E+03, -.20360400E+03, 0.22332600E+03, -.11152000E+03, -.42440000E+02, -.11169200E+03, 0.17603100E+02, -.11958100E+02, -.49040300E+02, 0.16959000E+02, -.99362700E+02, -.30423800E+01, -.21849800E+03, 0.15164000E+03, -.75463800E+02, 0.89015400E+02, -.75936700E+02, -.10131000E+03, -.21016700E+03, 0.20522700E+03, -.25823000E+02, -.23221000E+03, -.16232500E+03, -.26078000E+03, -.37070900E+03, 0.18748200E+03, 0.56841500E+02, 0.18510000E+03, 0.71384500E+02, -.25355100E+02, 0.12890600E+03, -.59038200E+02, 0.16238800E+03, -.65090200E+01, 0.33200100E+03, -.25482500E+02, 0.11230300E+02, -.66053600E+02, 0.12766400E+02, 0.26036600E+02, 0.54620000E+02, -.12235800E+03, 0.97718900E+01, 0.77222100E+02, 0.56077600E+02, 0.12174900E+03, -.94159500E+02, 0.46600000E+02, -.45767400E+02, 0.47133100E+02, -.55592800E+02, -.40868900E+02, 0.88896100E+02, 0.41268200E+02, 0.22130100E+03, -.80750300E+02, 0.38617000E+02, 0.12960300E+02, -.10247100E+02, 0.30979400E+02, -.37767800E+02, -.29327500E+02, -.24779100E+02, 0.21218400E+02, -.28597700E+02, 0.30027600E+02, 0.98195500E+01, 0.17963500E+02, -.35644100E+02, 0.48670900E+02, 0.18652000E+02, -.44665100E+02, -.23820200E+02, -.11721800E+02, 0.18601800E+02, 0.11908300E+02, 0.15993000E+02, 0.18549900E+02, 0.28505200E+02, -.58805500E+01, 0.10156500E+02, 0.61416700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39732500E+01, 0.50706800E+00, 0.11187000E+01, 0.57419800E+00, 0.19337700E+01, 0.20216000E+00, 0.88322700E-01, 0.19568200E+00, 0.41799700E+00, 0.46820300E+00, 0.34364400E+00, 0.38242100E+00, 0.61735900E+00, 0.11126300E+01, -.23769500E+00, 0.16072600E+00, 0.10718500E+01, 0.31831900E+00, 0.17859100E+00, 0.93459800E+00, -.40127900E+00, -.44697800E-02, 0.18357000E+00, 0.96019100E+00, 0.21287800E-01, -.46485400E+00, -.15473700E+01, 0.35671200E+00, 0.48563600E+00, -.70226200E+00, -.54837300E-01, -.21812900E+00, 0.54905100E+00, 0.10039700E+01, -.17865400E+00, -.14713400E+01, -.12299800E-01, -.86336900E-01, -.82460500E-01, 0.73384300E+00, 0.35297400E+00, 0.56104000E+00, -.25922200E+01, 0.15695300E+00, -.65503200E+00, 0.44793600E-01, 0.57508100E+00, 0.41944900E+00, -.13330100E+01, 0.43631200E-01, -.92470600E-01, 0.11587700E+01, 0.42786700E+00, -.14172200E+00, 0.33056600E+00, 0.29651600E+00, 0.10560000E+00, -.70218300E-01, 0.91709800E-03, 0.35149700E+00, -.17433700E+01, -.48690400E+00, 0.68718900E-01, -.35536700E+00, 0.11275400E+00, 0.44018300E+00, -.16142300E+00, 0.12082600E+00, 0.98744200E-01, -.28683800E-03, 0.32257000E+00, 0.50922400E-01, 0.59352800E+00, 0.55986600E+00, -.36143600E+00, -.51120300E+00, 0.82139700E-01, -.29760200E-02, -.49609400E-01, 0.13239000E+00, -.23106800E-01, -.45966100E+00, 0.32962500E+00, -.15303700E+00, -.69394400E-01, -.43396200E-01, 0.51391000E+00, 0.22950800E+00, 0.19550700E+00, 0.18647900E-01, -.30773800E+00, -.20475600E-02, 0.98093600E-01, -.16827100E-01, -.62821800E-01, -.68496800E-01, -.57088200E+00, 0.34551100E-01, -.14105400E-01, -.11170700E+00, -.23143800E+00, -.13053200E+00, -.24459700E-01, -.38688100E-01, -.48282400E-01, -.30563700E+00, 0.21367600E+00, 0.16017000E+00, 0.17943400E+00, -.98721100E+00, -.50633700E+00, 0.22870200E-01, 0.22647100E+00, 0.16824100E-01, 0.16408300E+00, -.53861200E-01, -.21376600E+00, 0.47889500E+00, -.37927400E+00, 0.10796400E+03, -.33647300E+03, -.24095200E+03, 0.11984200E+03, 0.46919500E+03, 0.12058400E+03, -.13011700E+03, -.17682000E+03, 0.32379600E+03, 0.44073300E+03, 0.45785200E+03, -.24662100E+03, 0.36089200E+03, -.33869000E+03, 0.17391500E+03, 0.29041300E+03, 0.16951700E+03, 0.47185100E+02, 0.90265300E+01, 0.35695200E+02, -.42574000E+02, 0.14297100E+03, -.78313900E+01, 0.10848400E+03, 0.35975100E+02, -.15663700E+02, 0.21955000E+03, -.18236800E+02, -.13176800E+03, -.10599000E+03, 0.13296300E+03, 0.21793900E+03, 0.12016800E+03, -.13236700E+03, 0.21515700E+03, 0.14574000E+03, -.75070400E+02, 0.76795500E+02, -.72204800E+02, -.66545400E+02, 0.19347000E+03, -.72223300E+02, -.56609400E+02, -.16346500E+03, 0.12893100E+03, -.19318500E+03, 0.84849900E+03, -.42392500E+03, -.36575200E+03, -.42523800E+03, 0.90158600E+01, -.13657200E+03, -.26176500E+03, -.24142800E+02, -.15778400E+03, -.56858200E+02, -.30167500E+03, -.19162100E+03, 0.96793900E+02, -.12981500E+03, 0.95054500E+02, 0.12703600E+02, -.13187300E+02, -.35372200E+02, -.13936200E+03, 0.92860500E+01, 0.10053700E+02, 0.95859700E+02, -.65628500E+02, 0.35775500E+02, 0.20431500E+02, 0.30964400E+02, 0.10546100E+03, 0.38676000E+02, -.22797800E+03, -.19114200E+03, -.50106500E+02, 0.18842400E+03, -.11297300E+03, -.66511300E+02, 0.31637400E+02, 0.77198100E+02, 0.33311200E+02, -.28135500E+03, -.22457700E+02, 0.84621100E+02, -.81694700E+02, -.16829400E+03, 0.11749900E+03, -.16379200E+02, 0.21354200E+03, -.10731600E+03, 0.11712500E+03, -.10644800E+03, 0.63617300E+02, -.92362100E+01, -.14075900E+03, -.20550300E+03, -.23287800E+03, 0.68140700E+02, -.20137800E+03, 0.13542100E+03, -.66627200E+02, -.10068200E+03, -.65678600E+02, 0.95483200E+02, 0.16619000E+03, -.18052400E+03, -.14767600E+03, -.32306700E+03, 0.29005100E+03, 0.17956500E+03, -.31358600E+03, 0.16468100E+03, -.45113800E+02, 0.15831900E+03, -.66386900E+02, -.21813400E+02, 0.13649400E+03, 0.17527900E+02, 0.28202000E+03, -.12455000E+03, 0.18829500E+03, -.26485900E+03, 0.13518500E+03, 0.81933400E+02, 0.13239000E+03, 0.90417700E+02, 0.52515700E+02, -.51177800E+02, -.10269200E+03, 0.31944600E+02, 0.65719900E+02, -.11053500E+03, -.35474500E+03, 0.17921200E+03, -.10451600E+03, 0.17687900E+03, 0.14964400E+03, 0.12593600E+03, 0.78222100E+02, 0.44403500E+02, 0.29057500E+03, 0.49010600E+02, 0.10762200E+03, 0.28855500E+02, 0.15053800E+02, 0.75045600E+01, -.22472900E+01, 0.15648000E+02, -.43247200E+01, 0.23318800E+01, 0.21934600E+02, -.19781800E+02, -.34652000E+01, 0.15763900E+02, -.34351000E+02, -.22985800E+02, -.28355300E+02, 0.14957700E+02, 0.74124000E+01, -.35806100E+01, 0.99505700E+01, -.23909600E+02, 0.50835200E+02, -.63806700E+02, 0.24155800E+02, 0.26681000E+02, 0.78999200E+01, 0.11537500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10217600E+02, -.12277900E+01, -.53168700E+01, -.39812100E+01, -.28985300E+01, 0.28712000E+01, -.18424300E+01, -.43364800E+00, 0.61087900E+00, -.35090300E+01, -.17901300E+01, -.21953800E+01, -.29932600E+01, -.69954600E+01, 0.21869100E+00, -.21813100E+01, -.47794200E+01, -.39423500E+01, -.26416900E+00, -.11068800E+01, 0.35265400E+01, 0.67994400E+00, 0.35275000E+00, -.22262600E+01, -.91590900E+00, 0.11327400E+00, -.87193800E+00, -.65449900E+00, -.91234900E+00, 0.26926900E+00, 0.17554100E+00, -.47949800E+00, -.29874200E+01, 0.18018800E+00, -.25064300E+00, 0.61336300E+00, -.27514300E-01, 0.79723200E-01, -.10016500E+00, -.16829800E+00, -.18296900E+00, 0.16616900E+00, -.19742800E+01, 0.14726300E+00, 0.18987700E+01, 0.45779000E-01, -.48683000E+00, 0.17819100E+00, -.22981400E+00, -.30910500E+00, -.12473100E+01, 0.13494400E-01, 0.17159700E+00, 0.43280500E+00, -.16938000E+01, 0.27519700E+00, -.65683900E+00, -.73973800E+00, 0.61492800E-02, 0.31111300E+01, 0.14826900E+01, 0.12951700E+01, 0.23094800E+00, 0.12537500E+01, -.16749200E+01, 0.13494800E+01, 0.26182400E+00, 0.50688400E+01, -.61999700E+00, -.92884500E-02, -.10347200E+01, 0.32900400E-01, 0.17290900E+01, -.84819800E+00, 0.11753400E+01, -.12308000E+01, 0.71236600E-01, 0.14721200E+01, -.34640800E+00, -.58726700E+00, 0.36807500E-01, -.11849800E+01, -.10576000E+01, -.23521500E+00, -.69656600E+00, 0.10995700E+00, 0.64479500E+00, 0.52655100E+00, -.47155200E+00, 0.35594100E+00, -.11800700E+01, -.26275900E-01, -.18455500E-01, 0.36149700E-01, -.72208500E-01, 0.22363200E+00, -.51624600E+00, -.12288900E+00, -.55785200E+00, 0.36810300E+00, 0.53589500E+00, -.70487300E+00, -.22517400E-01, -.26258300E+00, -.23034800E+00, 0.11082600E+00, -.82824500E+00, -.35616900E+00, 0.81265700E+00, 0.18972500E+00, -.29140900E-01, -.37828000E+00, -.36053600E+00, 0.13758200E-01, -.68056900E+00, 0.26717200E+00, 0.86687500E+00, 0.46788500E+00, 0.18415700E+01, -.63793800E+00, -.14987700E+04, -.50234400E+03, 0.24815600E+03, -.79976200E+02, 0.25088400E+03, -.36618700E+03, 0.64333000E+03, -.25151700E+03, 0.13785000E+02, 0.86451800E+01, 0.54452700E+03, 0.30953700E+04, 0.44141200E+03, -.18971400E+03, -.63088400E+03, -.22069200E+03, 0.19539600E+02, -.11740300E+03, -.36863700E+02, 0.11526300E+03, -.18677300E+02, -.94170600E+02, -.19313700E+03, -.10440700E+04, 0.52191600E+03, 0.28395900E+03, 0.52234700E+03, -.34880600E+03, 0.26984800E+03, 0.48781200E+03, 0.53924300E+03, 0.34055200E+03, 0.30665300E+03, 0.23703100E+04, -.16241500E+04, 0.80731200E+03, 0.65406700E+03, 0.81122600E+03, -.60605200E+01, -.22994600E+03, 0.73043800E+03, 0.43638400E+03, 0.86745900E+03, -.24257400E+03, -.81791500E+03, 0.17177000E+04, -.86211300E+03, -.20680100E+03, -.85942400E+03, 0.44695700E+03, 0.11516100E+03, -.29780400E+03, 0.34065000E+03, -.29611500E+03, 0.52731900E+02, -.11079800E+04, 0.14733200E+03, -.72166000E+02, 0.13892900E+03, -.72511400E+02, -.81311200E+02, -.25588100E+03, 0.18388300E+03, -.38426200E+03, -.58766300E+02, -.34232000E+03, 0.15317100E+03, -.15017400E+04, 0.75681700E+03, 0.77506800E+03, 0.75337000E+03, 0.44222300E+03, -.57141900E+01, -.19161800E+02, -.39828100E+03, 0.43706300E+03, -.75388000E+02, -.68643100E+03, -.17859300E+03, 0.87025000E+02, -.45865400E+03, 0.89231600E+02, -.38554500E+03, -.16978400E+03, -.46664900E+03, -.77462300E+03, 0.34834600E+03, -.21709800E+03, 0.71066900E+03, -.43160400E+03, 0.21262200E+03, 0.19031200E+02, 0.21543500E+03, 0.41285000E+03, -.52051500E+02, 0.43370500E+02, -.72587200E+02, 0.35091200E+03, -.10774500E+03, -.27457600E+03, 0.19216400E+04, -.96503400E+03, -.67274900E+02, -.96331600E+03, -.14451700E+03, -.81853300E+02, 0.22427500E+03, 0.33583000E+03, -.30918000E+03, -.28565100E+03, -.12046700E+04, -.54715300E+03, 0.30858700E+03, -.11010700E+04, 0.27222600E+03, 0.42073300E+03, 0.32026400E+03, -.58680800E+03, -.74847900E+03, 0.44286700E+02, 0.29278800E+03, 0.10412700E+04, -.65867700E+03, 0.33530200E+03, 0.29590100E+03, 0.32931600E+03, 0.32453800E+03, -.77308400E+02, -.50826100E+02, 0.23592500E+02, 0.17155000E+03, -.15448500E+02, -.46977200E+03, -.42010600E+02, 0.26716800E+02, 0.59357300E+03, 0.21538200E+02, 0.49323100E+02, 0.12249600E+02, 0.25105400E+03, 0.28912700E+03, -.40368100E+03, 0.13296000E+02, -.10113800E+04, -.55198200E+02, -.24937200E+02, 0.63167300E+02, -.15546000E+01, -.28876800E+02, -.50919600E+02, 0.28981800E+02, -.25843900E+02, 0.12546000E+03, 0.35236400E+02, -.17306700E+02, -.13503300E+03, -.15232700E+03, 0.11114100E+03, 0.86305700E+02, 0.39645300E+02, -.17132700E+03, 0.32300000E+02, 0.21321400E+03, -.15983300E+03, 0.83039800E+02, -.27163100E+02, 0.10478600E+03, -.13149700E+02, -.63822100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.48006900E+01, -.38237700E+00, 0.12363500E+01, -.14402000E+01, 0.14028800E+01, 0.26446000E+01, -.25789600E+01, -.77211200E-03, 0.49737400E+00, -.16013100E+01, 0.10457200E+00, 0.69387100E+00, 0.17214600E+01, 0.73159800E+00, -.15299900E+00, -.14253000E+01, 0.50068700E+00, 0.14656900E+01, -.46699200E+00, 0.81491800E+00, 0.16157200E+00, 0.29384000E+00, -.28287100E+00, -.16426600E+00, -.99430800E-01, -.21972000E+00, -.14081100E+01, 0.46478100E+00, 0.73582800E+00, -.21107000E+00, -.55774800E-01, 0.45766000E+00, 0.10410500E+00, 0.67124400E+00, -.16748200E+00, 0.18980900E+00, -.41046400E-01, 0.14538100E+00, -.33875200E+00, 0.14001100E+01, 0.17736400E+00, 0.58315100E+00, -.83069400E+00, -.72327600E-01, 0.10566300E+01, 0.18367700E+00, 0.11560400E+00, 0.17392700E+00, 0.52419700E+00, 0.11630300E+00, 0.77570000E+00, -.82857300E+00, 0.71420500E+00, -.24036700E-01, -.10250400E+01, -.47981400E+00, -.19568200E+00, 0.53566700E-02, 0.75047400E-02, 0.80432200E+00, 0.25544400E+01, 0.11303200E+01, -.87774000E-01, 0.34704200E+00, -.38168600E+00, -.67844200E+00, 0.28480800E+00, 0.17904600E+01, -.35544000E-01, -.11616300E-01, 0.25135100E+00, -.54965700E+00, -.78155300E+00, 0.32508500E-01, 0.26047200E+00, -.69631800E-01, -.13277400E+00, -.33207200E-01, -.50545600E+00, -.10347600E-01, 0.68127600E-01, 0.19377700E+00, -.31529700E-01, 0.94207600E+00, 0.95303600E-01, -.23587000E-01, -.75393000E+00, -.62663900E+00, -.22834000E+00, -.54126000E+00, 0.42774900E+00, 0.38683200E-01, 0.15992600E+00, 0.29249500E+00, -.10569600E+01, 0.50070300E+00, 0.77599800E+00, -.88616100E-01, -.33196700E+00, -.87395700E-01, 0.31263100E+00, 0.33425400E+00, 0.40811600E-01, 0.22992000E+00, -.10236400E+00, 0.36071700E+00, 0.63164300E+00, 0.16655600E-01, 0.65518700E+00, -.14504100E+00, -.19174100E+00, 0.19527000E+00, -.14653300E+00, -.26322700E-02, 0.10283500E-01, -.63051600E-01, -.55014600E+00, -.37697900E+00, -.92804300E+00, 0.12861700E+01, -.13182200E+00, -.25179600E+04, 0.12606600E+04, 0.15628700E+04, 0.12588400E+04, 0.48996000E+03, 0.53800100E+03, -.12493800E+03, -.93262500E+03, -.17242600E+03, 0.52378300E+03, 0.14394000E+04, 0.36490000E+03, -.18020500E+03, -.67358700E+03, -.18282100E+03, -.95395200E+01, 0.45818500E+01, -.32836800E+02, 0.57012400E+02, -.10044300E+03, -.71448400E+01, -.11504100E+03, -.84874100E+03, 0.42453900E+03, -.99610700E+02, 0.42477900E+03, 0.44115700E+02, -.14157400E+03, 0.10728800E+03, -.21289000E+03, 0.27900300E+03, -.39869800E+02, 0.52441200E+03, -.24127200E+03, 0.12288100E+03, 0.12528100E+03, 0.11955100E+03, -.24034200E+02, -.32956300E+02, 0.39601500E+03, 0.55057100E+03, 0.14937900E+03, -.23746200E+03, -.22539400E+03, -.55406600E+03, 0.27925800E+03, 0.41231400E+03, 0.27774300E+03, 0.22979800E+03, -.25979700E+01, 0.85260000E+02, -.22396700E+03, 0.16482900E+03, 0.62931500E+02, -.19785300E+03, 0.22600500E+03, -.11420000E+03, -.36837300E+03, -.11184400E+03, 0.86472000E+02, 0.25663000E+02, 0.76156400E+02, 0.40451400E+02, 0.57066100E+02, -.22639700E+01, -.35885900E+02, -.57427400E+03, 0.28118000E+03, 0.12762700E+03, 0.29015700E+03, 0.59596600E+02, 0.19545300E+03, 0.12713800E+03, -.15999300E+03, 0.10118800E+03, 0.18809600E+03, 0.13680100E+03, 0.91292400E+02, -.40925700E+02, -.24051900E+02, -.45740300E+02, 0.14856800E+03, 0.41723200E+03, -.32880600E+03, -.35515300E+03, 0.49520600E+02, 0.37851500E+03, 0.15417500E+03, 0.23358100E+03, -.11475500E+03, 0.41145900E+02, -.11734100E+03, -.15873200E+02, 0.93492800E+02, 0.37311900E+02, 0.88505400E+02, 0.24027700E+02, 0.29790200E+02, -.15833900E+03, 0.93967400E+02, -.53263000E+02, 0.51625600E+02, -.50387300E+02, 0.10534400E+03, -.23791400E+03, 0.42938700E+03, -.17686500E+03, 0.81817100E+03, -.18200600E+03, -.62115600E+03, -.13123800E+03, 0.64698000E+02, -.21989600E+03, 0.62818700E+02, 0.29972500E+03, 0.13533300E+03, -.26691800E+03, -.23773900E+03, -.33503200E+03, 0.17018200E+03, 0.21408100E+03, 0.39782700E+03, -.20177200E+03, -.29128200E+03, -.19878700E+03, -.18302400E+03, -.68134900E+02, -.70479700E+02, 0.25454800E+03, -.15486300E+03, -.52546800E+02, 0.20656000E+02, 0.66049800E+03, -.33782200E+03, -.20872900E+03, -.32939900E+03, -.33713300E+03, -.15731200E+03, 0.33225100E+02, 0.48688900E+03, -.40435500E+03, -.18642200E+03, 0.23231200E+02, -.33553800E+02, 0.12256500E+01, -.17721600E+02, 0.60075100E+01, -.62458800E+02, 0.16225200E+02, -.28322800E+02, -.76192200E+02, 0.81566300E+02, -.25755000E+02, 0.69496300E+01, -.14971100E+02, 0.16692500E+02, 0.76649400E+02, -.12526600E+02, 0.18918000E+02, 0.10659200E+02, 0.13456500E+02, 0.17392500E+02, 0.60478000E+02, 0.44163900E+02, -.65567400E+02, -.23318000E+02, 0.22910800E+02, 0.19118000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20617600E+02, 0.36618700E+00, -.16811300E+02, -.51605700E+01, 0.87665800E+01, -.16325700E+01, -.12115900E+01, 0.14980900E+01, -.81813500E+00, 0.17438200E+01, 0.68141300E+00, -.12333100E+01, 0.46682900E+01, -.22892900E+01, -.22947500E+01, 0.10769900E+00, 0.80617400E+00, -.44971300E+01, -.33040000E+01, -.64992500E+00, -.32406100E+01, -.14903900E+01, -.38713000E+00, 0.16438600E+01, 0.65132900E+00, 0.17922500E+01, 0.52843300E+01, -.59662500E+01, -.17500800E+01, 0.15710800E+01, -.68382200E+00, 0.16903100E+00, 0.81371400E+01, 0.12951400E+01, -.73390300E+00, 0.96030700E-01, 0.41564700E-01, 0.12311800E+01, -.16654800E+01, -.41396200E+01, -.31172500E+00, 0.47278200E-01, -.11804000E+02, 0.11132300E+01, 0.38064400E+00, -.19960500E+00, 0.15066600E+01, -.89014500E+00, -.53914100E+00, 0.16098900E+00, -.21388700E+00, 0.13936900E+01, 0.60254200E+00, -.18329700E+01, -.63087600E+00, 0.24714000E+01, 0.60076700E+00, 0.63382200E-01, 0.51218800E-04, 0.22254800E+01, -.35092400E+01, -.90418500E+00, 0.21301800E+00, -.80031100E+00, 0.38591800E-01, -.81025000E+00, -.27972400E+00, -.92842400E+01, 0.62713700E-01, 0.39632100E-02, -.25983800E+00, 0.37438900E+00, 0.67429400E+00, -.48496400E+00, 0.10817800E+00, -.35957200E+00, 0.97769100E+00, -.75887400E-01, 0.34365100E+00, 0.24750200E+00, -.11389300E-01, -.31119200E+01, 0.91302400E+00, -.10024700E+01, -.42338500E+00, 0.47695700E+00, 0.12702900E+01, 0.45783200E-01, -.22258800E+01, 0.91304900E+00, -.10608700E+01, -.49287900E-01, -.22926500E+00, 0.40290900E+00, 0.12455700E+01, -.73862000E+00, -.15647100E+01, 0.50110100E+00, 0.20274700E+00, -.29593700E+00, -.59270700E+00, 0.12389200E+01, -.84099000E-01, -.59949900E+00, -.39272200E+00, 0.63118300E+00, 0.13575100E+01, -.78216200E+00, -.78594000E+00, -.38525400E+00, -.15366000E+01, -.30005900E+00, -.69314900E+00, -.73108500E-01, 0.12887000E+01, -.16513200E+00, 0.55283100E+00, -.39307000E+00, -.14760600E+01, -.64226000E+00, -.95037300E-01, -.50264100E+00, 0.13243300E+02, 0.65220100E+03, 0.23204600E+00, 0.23117800E+03, -.54404600E+02, 0.15350800E+02, -.42528900E+02, 0.25418100E+01, -.16308700E+03, -.81158400E+03, -.14198500E+04, 0.65626900E+03, 0.11301100E+04, 0.70976300E+03, 0.18603400E+03, 0.24548200E+03, 0.11405200E+03, -.29015100E+03, 0.44104500E+03, 0.23710800E+03, 0.55339100E+03, -.89395200E+03, 0.44538700E+03, 0.55103000E+03, 0.44655400E+03, 0.32743700E+03, -.37754300E+03, 0.32361800E+03, -.15322900E+03, 0.43522900E+03, -.38541500E+03, -.25098800E+03, 0.10600700E+04, -.52451400E+03, -.47131600E+03, -.52877500E+03, -.26188900E+03, 0.38062900E+03, -.47428300E+03, -.66308800E+02, -.86426700E+03, 0.57420400E+03, 0.64558600E+03, -.13323800E+04, 0.66544700E+03, -.13686200E+03, 0.66563300E+03, -.14692100E+03, -.26785400E+03, 0.43630400E+03, 0.36930400E+02, 0.10143900E+04, -.37086800E+03, 0.51933600E+03, 0.64174100E+03, -.32625400E+03, -.30670900E+03, -.32249600E+03, -.24022600E+03, -.14990700E+03, -.15503700E+03, 0.44021500E+03, -.27432600E+03, -.25790000E+02, -.65462400E+03, 0.19899600E+03, -.11982200E+03, -.89727500E+02, -.10294400E+03, 0.10810200E+03, -.14843000E+03, 0.11070000E+03, 0.20249900E+03, -.18475000E+03, -.25032000E+03, -.21444100E+03, -.21803000E+03, 0.12381200E+03, 0.30423600E+03, 0.10911100E+03, -.14419700E+03, -.13691700E+03, 0.13050200E+03, -.64439900E+02, -.15241400E+03, -.59526100E+02, -.59821200E+03, -.94437800E+03, 0.47521900E+03, 0.17172700E+03, 0.47274000E+03, 0.13116200E+03, 0.30282400E+02, 0.16987600E+03, -.52252800E+02, 0.19775200E+03, 0.13362600E+03, 0.19239800E+03, -.87839400E+03, 0.44679700E+03, 0.98444900E+03, 0.44266000E+03, 0.35582100E+03, 0.56143600E+03, -.17024000E+03, -.31567200E+03, 0.24216200E+03, 0.53530100E+03, -.82478500E+03, -.19909600E+04, 0.92258000E+03, 0.89128200E+03, 0.99731100E+03, -.11839600E+03, 0.10805600E+03, 0.28540600E+03, -.60805600E+03, 0.29086800E+03, 0.15091500E+03, 0.74591000E+03, 0.70003700E+02, -.61005700E+02, -.26862000E+02, -.34768300E+02, 0.24897600E+02, -.46424600E+02, 0.52895100E+02, 0.26156100E+02, 0.50647200E+02, -.44938400E+02, 0.27440600E+03, -.17188700E+03, 0.70102300E+02, -.31060000E+02, 0.85117200E+02, 0.27275200E+03, -.52897300E+02, 0.12851200E+03, 0.21739400E+03, 0.37248400E+02, 0.19762800E+02, 0.27664600E+03, 0.56453500E+02, -.82185000E+01, -.12920700E+02, 0.57184500E+01, 0.15037400E+03, 0.21656100E+02, -.11154400E+02, 0.14857300E+03, -.21631700E+03, 0.32212500E+02, 0.20405300E+02, -.71168700E+00, 0.39634500E+02, -.24186500E+03, -.84012300E+02, -.53348000E+02, 0.23129100E+02, -.47278200E+02, -.26709100E+01, 0.69723500E+02, -.62125800E+02, 0.36619900E+01, 0.15138100E+03, 0.29574400E+02, -.30989200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.75968500E+01, 0.82386300E+00, 0.41827400E+00, 0.11980100E+01, 0.11524500E+01, -.20161100E+01, 0.17296300E+01, 0.18877900E+00, -.41259500E+00, 0.19240200E+01, -.79240400E+00, 0.29789800E+01, 0.15987800E+01, -.16933600E+01, 0.10138100E+01, 0.17865400E+01, 0.43085600E+01, -.13724900E+00, 0.80803200E+00, 0.81816800E-01, 0.33971000E+00, -.38965400E-01, 0.28820200E-01, 0.20895500E+00, -.11886500E+00, -.27247400E-01, -.51503400E+00, -.18175200E+01, -.11474200E+01, 0.74754300E+00, -.49603700E-01, 0.45341500E+00, -.37269500E+00, 0.27278800E+00, 0.18715500E+00, 0.19877400E+01, 0.42413400E+00, -.23369700E+00, 0.93193000E+00, 0.47044800E+00, -.15426200E+00, -.84867400E+00, 0.33368200E+01, -.12520900E+00, -.12270500E+01, 0.14557700E+00, 0.66209500E-01, 0.12354000E+00, 0.88609400E-01, 0.22811400E-01, -.97996300E+00, 0.14189300E-01, -.80227900E+00, 0.10399600E+01, 0.45883500E+00, -.62790500E-01, 0.24501600E+00, 0.22027200E+00, -.52157200E-02, 0.37839200E+00, -.20224200E+01, -.25385400E+00, -.12896500E-01, -.63023600E+00, 0.84371900E+00, -.30920700E-01, -.18760900E+00, -.44794100E+00, 0.28748100E+00, 0.68073400E-02, 0.68684800E+00, -.28093400E-01, -.14455300E+01, 0.12705500E+01, -.11470800E+01, -.78622700E+00, -.15546700E+00, 0.50933200E+00, -.28310800E+00, 0.48942800E+00, -.53795900E-01, -.72248600E+00, -.12887400E+00, 0.50326700E+00, 0.90492300E-01, -.37096200E+00, 0.11342200E+01, -.39924300E+00, 0.13475900E+01, 0.42459900E+00, 0.26881900E+01, -.10801100E-01, 0.11037900E+01, -.36923300E+00, -.65255500E+00, -.48623500E+00, 0.12270900E+01, -.10196600E+01, 0.14765000E-01, -.36589300E+00, 0.38614300E+00, -.14680800E+00, 0.30647900E-01, 0.59555300E-01, 0.52728000E+00, -.16823300E+00, -.33896100E+00, 0.40690400E+00, -.28345800E+00, 0.13735500E+01, 0.63064100E-01, 0.47333300E-01, 0.55990900E+00, -.53529500E-02, -.34040800E+00, -.29911600E-01, -.32987300E+00, -.62155300E+00, 0.24040200E+01, 0.66948900E+00, -.13107900E+00, 0.42443300E+00, -.53073900E-01, -.92344200E+03, -.19134000E+00, -.19543900E+03, 0.73560800E+02, -.92338300E+02, -.16413300E+03, -.36511300E+02, 0.88065000E+02, 0.16608700E+03, 0.30264400E+03, -.16829200E+03, -.91333800E+03, -.15141600E+03, 0.80678500E+02, 0.59572600E+02, -.13858600E+03, 0.11439200E+03, -.14861100E+02, 0.21894900E+02, -.11857300E+03, 0.23079800E+03, -.12199000E+03, -.29538400E+03, -.11523200E+03, -.23295300E+03, 0.18667300E+03, -.17229200E+03, 0.25897000E+02, -.11006500E+03, 0.15462500E+03, 0.40267600E+03, -.27595100E+03, 0.14141600E+03, 0.55769200E+02, 0.13758700E+03, 0.22203100E+03, -.11021800E+03, -.76586000E+01, -.35605500E+03, 0.25202900E+03, -.51713400E+02, -.33210700E+03, 0.55067400E+03, -.28096600E+03, 0.25734400E+03, -.27421800E+03, 0.97200000E+02, 0.35545700E+03, -.13399800E+03, 0.19421900E+03, -.31794800E+03, 0.28535800E+03, -.55655300E+03, 0.13949400E+03, -.69740300E+02, 0.31533700E+03, -.69190400E+02, -.17359500E+03, -.11673000E+02, 0.15938100E+03, -.61314500E+02, -.79328700E+02, -.11642300E+03, 0.22829400E+03, -.14749900E+03, 0.75011200E+02, 0.81900200E+02, 0.74950600E+02, 0.82274600E+01, -.46149300E+02, 0.16497100E+03, 0.17064700E+03, 0.22767200E+03, -.93720700E+02, 0.98182300E+02, -.75974300E+03, 0.37716600E+03, -.41927700E+03, 0.37984300E+03, 0.47872000E+03, -.16079800E+03, 0.28845600E+02, -.65938200E+02, 0.53243500E+03, -.19862800E+03, 0.66215600E+03, -.16658100E+03, 0.80903500E+02, -.15739000E+03, 0.83129500E+02, 0.12923500E+03, -.81300900E+01, 0.29476200E+02, 0.60199400E+02, 0.17692400E+03, -.29727700E+02, 0.14752400E+03, 0.15299800E+04, -.75885400E+03, -.78597600E+03, -.76620900E+03, -.37121700E+03, -.34143000E+03, -.99877000E+02, 0.44429200E+03, -.36592600E+03, -.31584300E+03, -.31012300E+03, 0.11498900E+03, -.79550400E+02, -.69352200E+03, -.58174100E+02, 0.31492000E+03, 0.45817900E+03, -.47086800E+03, -.57435500E+02, -.51329300E+02, 0.31998700E+03, 0.58974400E+02, -.15377100E+03, 0.74699100E+02, 0.10524100E+03, 0.76945500E+02, 0.17976600E+03, 0.39113800E+02, 0.40934100E+02, 0.10237000E+02, -.57765800E+02, 0.32052500E+02, -.35736300E+02, 0.35938600E+03, -.17353200E+03, 0.45997400E+03, -.17946800E+03, -.34275200E+03, -.67818000E+02, -.29266900E+02, -.10308800E+03, -.47908600E+03, -.30727600E+02, 0.58873600E+02, 0.17489300E+02, -.19000700E+02, 0.39818700E+02, -.33016100E+02, -.68600100E+02, -.17849800E+01, 0.48866400E+01, -.69886500E+02, 0.51136600E+02, 0.17168300E+01, 0.35470600E+01, -.34687300E+01, -.50106000E+02, 0.75159500E+01, 0.52821200E+02, -.23351700E+01, -.10505300E+03, 0.88577000E+02, 0.12110500E+02, -.14324800E+03, 0.36691200E+02, -.22657700E+02, -.12572000E+02, 0.28458500E+02, -.38240300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21278600E+02, -.21980300E+01, -.24373100E+01, 0.50276400E+01, 0.97240300E+01, 0.12929500E+01, -.41988100E+01, 0.18468300E+00, 0.33730300E+00, -.45283400E+01, -.28891100E+01, -.50685800E-01, 0.10138700E+01, 0.10471500E+01, -.12003900E+01, -.37757500E+01, -.28319100E+01, -.21885200E+01, 0.13910100E+01, -.33068100E+01, -.65514800E+00, 0.37135400E+00, -.21898900E+01, -.51724900E+01, -.51642100E+00, -.25411800E+01, 0.29189600E+01, -.14037300E+01, -.79241500E+00, -.68529200E+00, 0.29229000E+00, -.33273800E+01, 0.80861900E+00, -.29186400E+01, 0.35065000E+00, 0.20109700E+01, -.12112100E+00, 0.55517100E+00, -.37549200E+00, 0.30473600E+01, 0.45449800E+00, 0.74418000E+00, -.22354500E+01, 0.63796600E+00, 0.22488900E+01, 0.96521700E+00, -.10045300E+01, 0.32624700E+01, -.74951200E+00, -.39841200E+00, -.60685300E+00, -.77860700E+00, 0.32407900E+00, -.15586300E+01, -.23020800E+01, -.49479800E+01, -.95230400E+00, 0.15374100E+01, -.12967300E-01, -.21904800E+00, 0.62537500E+01, 0.30380700E+01, -.63947700E+00, 0.40287800E+00, 0.10870800E+01, -.43151700E-01, 0.34688400E+00, 0.56810300E+01, 0.15082700E+00, -.88370500E-02, -.55893700E+00, -.57055300E+00, -.33052100E+00, 0.84627400E+00, -.38280300E+01, 0.16169000E+01, -.34494200E+00, -.19231600E+01, -.59137200E+00, -.10219900E+01, 0.43657400E-01, 0.60028000E+00, -.82297200E+00, 0.76947400E+00, 0.71069600E+00, 0.15475100E+00, -.11283700E+01, -.14865600E+00, 0.12198200E+01, -.19989800E+01, 0.48957700E+00, 0.53133000E-01, 0.19239700E+00, 0.27107500E-01, -.12531100E+01, 0.49634300E+00, 0.46839300E+01, -.91427000E+00, -.56836700E+00, -.15340200E+01, 0.27857800E+01, -.39252100E-02, 0.71559400E-01, 0.12766500E+00, 0.39833200E+00, 0.37570000E+00, 0.38582400E+00, 0.60576400E+00, -.49796500E+00, 0.11428000E+01, 0.26130600E+00, 0.18758400E+00, -.16579700E+00, -.49432000E-01, 0.11874000E+00, 0.13389700E+00, 0.57756300E+00, -.34311500E-01, -.35772700E+01, 0.12418000E+01, 0.53546200E-02, 0.10590600E+01, -.59223400E-02, -.43645400E+00, 0.31808000E+01, 0.13607600E+03, 0.12073500E+03, -.39473200E+03, -.28995400E+03, -.23127300E+03, 0.15999300E+03, 0.28871300E+03, -.29437800E+03, 0.12942700E+03, -.35597600E+03, 0.14679200E+03, 0.49484000E+02, 0.10208000E+03, 0.30767600E+02, -.55518100E+01, 0.63817800E+02, 0.70157300E+02, 0.22981600E+03, 0.56670900E+03, -.28781600E+03, -.84998300E+02, -.28305000E+03, 0.66445100E+02, 0.53064700E+02, -.35408400E+03, -.29536600E+03, -.46606900E+03, 0.62289800E+02, -.23848900E+03, 0.15527000E+03, -.76291100E+02, -.24299200E+02, -.78428500E+02, 0.13036100E+03, 0.10944000E+03, -.47922500E+01, 0.82892400E+02, 0.22895900E+03, 0.26165500E+02, -.35496400E+03, 0.38042500E+03, -.19168100E+03, -.22440900E+03, -.19382900E+03, -.19652100E+03, -.13939000E+03, -.18520600E+02, -.14299600E+02, -.26936700E+03, -.58386900E+02, 0.90163800E+02, 0.19954700E+03, -.10165000E+03, -.16359700E+03, -.99007600E+02, -.28859700E+02, 0.78934600E+02, 0.44305300E+01, 0.10716500E+03, 0.62635200E+02, 0.63244100E+02, -.96324400E+01, 0.27958300E+03, -.14079300E+03, -.19316000E+03, -.13760800E+03, -.23169800E+03, -.74873200E+02, 0.27169500E+02, -.19132300E+02, 0.14802100E+02, 0.59314400E+00, 0.16592500E+03, 0.34207900E+03, -.17373800E+03, -.50548300E+03, -.17111200E+03, 0.20301900E+03, 0.43915700E+03, -.46169400E+02, 0.26997100E+03, 0.10197000E+03, 0.29610200E+03, 0.22510000E+02, 0.36973400E+03, -.18496500E+03, -.11000000E+03, -.18529200E+03, -.14543800E+03, 0.40930200E+02, 0.50081200E+02, 0.21799200E+03, 0.10217500E+03, -.54462400E+02, 0.10729200E+03, -.14074700E+03, 0.76304100E+02, -.27350000E+03, 0.67801000E+02, -.14850700E+03, -.31141000E+03, 0.30512100E+03, 0.11095800E+03, 0.12409400E+03, -.28896400E+03, 0.20388700E+03, -.96426100E+02, 0.19987800E+02, 0.16166100E+03, 0.45844600E+02, 0.13941500E+03, 0.14478600E+03, 0.72458700E+02, 0.26351300E+03, -.61824700E+01, 0.98200400E+02, -.77941100E+02, 0.38254200E+02, -.28682700E+02, -.45998800E+02, -.18971200E+02, -.79202000E+02, -.37547000E+02, 0.35754800E+02, 0.38724900E+02, 0.11430200E+03, -.54731000E+02, 0.22759400E+03, 0.71430500E+02, -.30589000E+02, 0.28268900E+02, -.35049200E+02, -.23517900E+02, -.52776100E+02, -.10636300E+03, -.16984800E+03, 0.36789400E+02, -.83815800E+02, -.11794300E+03, -.18459500E+02, 0.95961100E+01, -.38712200E+02, 0.39427300E+01, -.33886300E+02, 0.91036400E+00, 0.14953600E+01, -.31233300E+02, -.72016500E+02, -.12043500E+02, -.10500000E+02, 0.50985100E+01, -.21484100E+02, -.93099000E+02, -.26281400E+02, 0.13734700E+02, 0.70234300E+02, -.89963500E+00, -.16296000E+02, -.57178500E+02, 0.85186000E+02, -.13906700E+02, -.30073900E+02, -.26662300E+02, 0.13921600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54153900E+01, -.27428600E+00, 0.22807000E+01, -.29820600E+01, -.14718000E+01, 0.17534400E+01, -.45007100E+00, -.99816300E-01, 0.69468800E+00, -.13703600E+01, -.86912900E+00, 0.43482000E+00, -.36742800E+00, 0.48019900E-01, 0.55569400E+00, -.78143800E+00, -.23136900E+00, 0.81664300E+00, -.19059400E+00, 0.59314500E+00, 0.13748300E+01, 0.46742500E+00, -.48081000E-01, -.14483900E+01, -.31128900E+00, -.90246100E+00, -.11548700E+01, 0.37087800E+00, 0.92531900E+00, -.76412900E+00, 0.38238300E-01, -.51356400E+00, -.10288400E+01, 0.65459900E+00, -.14599700E+00, 0.33637400E+00, -.24058300E-01, 0.88631000E-01, 0.11788700E+00, 0.16284500E+01, 0.11935200E+00, 0.70616300E+00, 0.53810800E+00, -.95305000E-01, 0.57977700E+00, 0.26040200E+00, 0.21144100E+00, 0.27032000E+00, -.16669200E+00, 0.37294400E-01, 0.72565200E-01, -.30022800E+00, 0.35349100E+00, -.29689700E+00, -.11852900E+01, -.22941200E+00, -.45124900E-01, 0.19338100E-02, 0.10314800E-02, 0.48840900E+00, 0.97619900E+00, 0.49630800E+00, -.35155800E-01, 0.28209100E+00, -.10709700E+00, -.45280200E+00, 0.86209800E-01, 0.35826400E+00, -.11080400E+00, -.19420100E-03, 0.62069300E-01, -.12752300E-01, -.21558500E+00, 0.18508300E+00, -.56709500E+00, 0.50467100E+00, 0.66558600E-01, 0.90835300E-01, -.12681100E+00, 0.19322200E+00, 0.13226500E-02, 0.92925300E+00, -.28557100E+00, 0.41089300E+00, 0.72185800E-01, 0.92730300E-01, -.80908100E+00, -.70532500E+00, -.36795300E+00, -.43658300E+00, 0.63088400E+00, 0.35838900E-01, -.22398300E+00, 0.13092900E+00, -.11553400E+01, 0.92813500E-01, 0.20191100E+01, -.48732100E+00, -.23914400E-02, -.63901100E+00, 0.70797900E+00, 0.16362900E+00, 0.27699400E-01, -.26432200E-01, 0.13071800E+00, 0.47442700E+00, -.12526500E-01, -.56617300E-01, 0.11439000E+00, -.47613500E+00, -.12286000E+00, -.60278100E-01, 0.10541200E+00, -.48561100E-02, -.89249800E-01, 0.29902700E-01, 0.16492400E+00, -.10919500E+00, -.15033900E+01, 0.38348900E+00, 0.35010700E-02, 0.40204000E+00, -.62265100E-02, -.28351800E+00, -.49869400E-02, 0.27819500E+03, -.18294100E+02, -.98574000E+02, -.12275700E+03, 0.38136300E+02, 0.73530300E+01, -.26110900E+03, -.18691100E+03, 0.96065800E+02, -.25923100E+03, 0.93351200E+02, 0.86271900E+02, 0.76284700E+02, -.40743700E+01, -.10338500E+02, 0.56575100E+02, 0.51091900E+02, 0.58219200E+02, 0.38548000E+03, -.19270700E+03, -.23194700E+03, -.19266700E+03, 0.75957200E+01, -.10886000E+02, -.17032400E+03, -.10848300E+03, -.11466400E+03, 0.57944600E+02, 0.30615700E+02, -.30148700E+02, 0.14730300E+02, 0.12577300E+02, 0.14887900E+02, -.80578600E+02, 0.15611800E+02, -.84232400E+02, -.24773400E+03, -.43501100E+02, 0.82872800E+01, -.71726200E+02, -.50135700E+02, 0.23960200E+02, 0.28348600E+03, 0.25450000E+02, 0.12550900E+03, 0.17209400E+03, -.14354800E+03, -.13452000E+03, -.10427800E+03, 0.14871500E+03, -.17958000E+02, -.82826500E+02, 0.41551800E+02, -.12125200E+02, 0.41592200E+02, -.60558000E+02, 0.83213900E+02, 0.77613500E+01, 0.37526000E+02, -.67029500E+02, 0.38947800E+02, 0.49061500E+02, -.18043600E+03, 0.89863300E+02, 0.10605500E+02, 0.90734600E+02, -.16491500E+02, 0.96479200E+02, -.65276200E+02, -.38076600E+02, -.41409400E+02, 0.87482600E+02, 0.97042900E+02, -.21795300E+03, 0.10898300E+03, -.21045600E+03, 0.10895900E+03, 0.93008300E+02, 0.62333900E+02, 0.63049800E+02, 0.17977900E+03, 0.14111200E+03, 0.38756600E+02, 0.20711500E+03, -.37277100E+02, 0.18254900E+02, 0.86298600E+02, 0.18538400E+02, 0.68752500E+01, 0.97767000E+01, 0.42773900E+01, 0.32567400E+02, 0.21470200E+02, -.25893900E+01, 0.17483500E+03, -.23432800E+03, 0.11622300E+03, 0.17602400E+02, 0.11655100E+03, -.17533600E+03, -.13343800E+03, 0.58097000E+02, 0.59769000E+01, 0.51054300E+02, -.11447000E+03, 0.37355600E+03, -.36575200E+03, 0.18662500E+03, -.23387000E+03, 0.18230400E+03, 0.17592600E+03, 0.15941100E+03, 0.81841200E+02, 0.14717900E+03, 0.22648000E+03, 0.76346900E+02, 0.26517700E+02, 0.87043900E+02, -.42392000E+02, -.62714700E+02, -.43478100E+02, 0.29940700E+02, 0.30168700E+02, -.11498900E+02, 0.16864200E+02, -.50053600E+02, 0.31302700E+02, -.71914700E+02, 0.16099200E+03, -.80634300E+02, 0.45298000E+02, -.80339000E+02, -.18461000E+03, -.45057300E+02, 0.44862200E+02, -.35745800E+01, -.10242800E+03, -.20756300E+01, 0.66389600E+02, -.89024500E+00, 0.13271200E+02, -.36696200E+01, 0.13185300E+01, -.11731200E+03, 0.14632200E+02, -.12851400E+02, -.11748500E+03, 0.45319900E+02, -.12698700E+02, 0.11405200E+02, 0.45899700E+01, 0.26675000E+02, 0.21231100E+02, 0.30162200E+02, 0.11765700E+02, -.57737800E+01, 0.26718200E+02, -.15970900E+02, -.27194900E+02, -.59712000E+01, -.42517300E+01, -.83594600E+02, 0.19970600E+02, 0.46879100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.38325900E+01, -.30363000E+00, 0.11585000E+01, -.46479100E+00, 0.10928400E+01, 0.16782000E+01, -.15817700E+01, -.68513500E-02, 0.26752800E+00, 0.35412900E-01, 0.20315900E+00, 0.33492500E+00, 0.10311400E+01, 0.10383000E+01, -.63630700E+00, -.74893800E+00, 0.55398400E+00, 0.10493100E+01, -.23481900E+00, 0.51697100E+00, -.11251600E+01, 0.23071100E-02, -.32963500E-01, 0.13915000E+01, -.20700700E-01, -.46090800E-01, -.69790300E+00, -.15349200E+01, 0.41234500E+00, -.12127500E+00, -.10747000E+00, 0.64233400E+00, 0.38864100E-01, -.18080700E+00, -.24950700E-01, 0.39054300E+00, -.13362400E-01, 0.24343600E+00, -.46328900E+00, -.51318400E+00, -.18724200E+00, -.46664400E-01, -.26272600E+00, 0.10547600E+00, 0.53890300E-02, -.24161200E-01, -.63014300E-02, 0.17574100E+00, 0.62286600E+00, 0.23482700E-03, 0.45782900E+00, 0.25834000E+00, 0.11502400E+00, -.99495500E+00, -.88061500E+00, 0.78660700E+00, -.19144500E+00, 0.56346400E+00, 0.16276300E-02, 0.16584100E+01, 0.12072500E+01, 0.95813600E+00, -.11559300E+00, 0.38550800E+00, -.31781600E+00, -.87493400E+00, 0.46022600E+00, 0.26449200E+01, -.27636700E+00, -.62901600E-02, 0.12168200E+00, -.27770700E+00, -.62573200E+00, 0.80495700E-01, -.97563900E-01, 0.11655000E+01, -.21088900E+00, 0.12995600E+00, 0.12537500E-01, 0.22054400E+00, 0.11198900E-01, 0.26456600E+00, -.58647200E+00, 0.50393600E+00, 0.29358700E+00, -.22974800E+00, 0.10412700E+01, -.19824000E+00, -.35420000E+00, 0.52479100E+00, 0.11004400E+01, 0.50254700E-02, 0.18331400E+00, 0.24330400E+00, -.67558000E-02, 0.74354400E-01, 0.10417300E+01, -.41276500E+00, 0.17831700E+00, -.31866900E+00, 0.56903000E+00, -.54198400E-01, 0.51042900E-01, -.45111600E-01, 0.23645100E+00, 0.41280700E+00, 0.55889200E-01, 0.21581600E+00, -.16195000E-01, 0.15612500E+00, 0.69081900E-01, -.99755900E-01, -.15382200E+00, -.18037700E-01, -.31918000E-01, 0.62050200E-02, -.20559900E-01, 0.37712300E+00, -.57844200E+00, -.12449200E+00, -.71865800E-01, 0.21317500E+00, -.88755500E-01, -.64109700E-01, 0.53702100E-01, 0.27993300E-01, -.39575900E+03, 0.16447100E+03, 0.16715700E+03, 0.43692300E+03, -.34447100E+03, -.75265600E+02, -.10838900E+03, 0.59462800E+02, 0.70893400E+02, 0.54324400E+02, 0.18965400E+02, 0.14646800E+02, 0.12742800E+02, 0.61897100E+02, 0.32856600E+02, 0.70792100E+01, -.42891200E+02, 0.40774700E+03, -.20109400E+03, -.14778900E+03, -.20403300E+03, -.11407400E+03, -.17656500E+03, -.65648800E+02, 0.33707700E+02, -.49059600E+02, -.19885800E+03, -.11385900E+03, 0.40105400E+03, -.20314900E+03, -.13857800E+03, -.20015500E+03, -.14130600E+02, 0.13264100E+03, -.28252800E+03, -.32888600E+03, -.20147700E+03, 0.12624800E+03, 0.29144100E+02, -.14311300E+03, 0.69788100E+02, 0.18988000E+03, 0.71770300E+02, 0.65973900E+02, 0.60056600E+02, -.85723200E+02, -.83088700E+02, -.67294200E+02, 0.80131300E+02, 0.13349400E+03, -.40425900E+03, 0.20451100E+03, -.44438500E+02, 0.20163500E+03, 0.18956000E+03, 0.14399200E+03, -.35367000E+02, -.12627900E+03, 0.72089200E+02, 0.18715000E+03, 0.21748700E+03, -.26537100E+03, 0.13593100E+03, 0.35351100E+02, 0.13150600E+03, 0.27249400E+02, 0.21608400E+03, -.23935600E+03, -.23435200E+03, -.43003900E+02, 0.29500500E+03, 0.23401900E+03, 0.11889100E+03, -.61689400E+02, 0.99557500E+02, -.59415200E+02, 0.37690800E+02, 0.12446500E+03, 0.37171600E+02, 0.10738900E+03, -.25581200E+03, 0.13920500E+03, -.96255500E+02, 0.21077600E+03, -.10689900E+03, 0.17839400E+03, -.10521700E+03, -.24513200E+02, 0.11260100E+02, -.49768200E+02, -.42570900E+02, -.13692500E+03, 0.36015200E+02, 0.90624500E+01, -.26439000E+03, 0.13348500E+03, -.32545200E+03, 0.13343400E+03, 0.31674600E+02, -.42212400E+02, 0.33605800E+02, 0.49773000E+02, -.11635600E+03, -.22120800E+02, 0.63380600E+03, 0.19195500E+03, -.85621300E+02, -.53788400E+02, -.95133600E+02, -.52236600E+02, 0.10696500E+03, 0.17276700E+02, 0.20532800E+03, 0.95395800E+02, 0.93130700E+02, -.19798800E+03, -.30169900E+02, 0.20068700E+02, 0.34004500E+02, 0.14981200E+02, -.57765600E+02, 0.89081200E+02, -.31522400E+02, -.69928100E+02, -.17126500E+02, 0.90846700E+02, -.16657000E+03, 0.59887500E+02, -.27691300E+02, -.38088900E+03, -.30188300E+02, -.11125500E+03, 0.55444900E+02, -.34994900E+02, -.32041100E+02, 0.27549200E+03, 0.60663500E+02, 0.10814200E+03, 0.35030700E+02, 0.23961000E+02, -.80226300E+01, 0.16465300E+02, -.38821500E+02, 0.16189400E+02, -.13399700E+02, -.34064700E+02, 0.26846300E+02, -.23797300E+02, 0.15785700E+02, 0.11257800E+02, 0.52567500E+02, 0.22481600E+02, 0.26151900E+02, 0.14154700E+02, 0.42654600E+02, 0.99684700E+01, -.51860800E+02, 0.11142500E+03, -.38901400E+02, 0.15618900E+02, -.53920900E+02, 0.47989700E+01, 0.45831300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12330200E+02, 0.14110200E+01, -.46303600E+01, -.11127000E+01, 0.13844400E+00, -.20521500E+01, 0.12771100E+01, -.16815500E-02, -.71806800E+00, -.34438500E-02, 0.29330600E+00, -.71742600E+00, -.95201300E-01, -.93112000E+01, 0.46289100E+00, -.48586400E+00, -.33763500E+01, -.47649700E+01, -.21139200E+01, -.19147800E+00, 0.27599500E+01, -.46460000E+00, 0.68274200E+00, 0.12241100E+01, 0.54411200E+00, 0.16308300E+01, 0.40055500E+01, 0.13157400E+01, -.76553900E+00, 0.10563700E+01, -.73164700E-02, 0.38472900E+00, -.51189600E+00, -.27339300E+01, 0.51426100E+00, 0.46866600E+01, -.11620300E+00, -.40616200E+00, 0.10598400E+01, 0.33208200E+01, -.42883100E-01, 0.28203800E+00, 0.37275700E+01, 0.12745900E+00, 0.41144300E+01, 0.11158700E+01, -.23530400E+00, 0.17881000E+01, 0.17716500E+01, -.90791500E+00, -.77182700E+00, -.64700600E+00, 0.21550900E-01, 0.18328300E+01, 0.14195100E+00, -.14293800E+01, 0.14630800E+00, 0.24190800E+00, -.16738800E-01, -.32125300E+01, 0.18040400E+01, 0.19443100E+00, 0.17163700E+00, 0.13253000E+00, 0.10358600E+01, -.39590200E+00, 0.13394700E+00, 0.12709700E+01, -.50190300E+00, 0.26214900E-01, 0.33048600E+00, 0.10776000E+00, -.37677300E+01, -.17107600E+01, 0.58367500E+00, 0.10467400E+01, 0.76645200E-01, -.76094300E+00, -.90922400E+00, -.82400800E-01, 0.19374000E-01, -.37678400E+00, -.35576500E+00, 0.10845000E+01, 0.53153400E-01, -.19302000E+00, 0.98264000E+00, -.28120600E+00, -.12363200E+01, 0.17187400E+01, 0.20972300E+01, -.30480900E-01, 0.13111300E+01, 0.39266000E+00, -.10776600E+01, 0.13185600E+01, 0.17916300E+01, -.14302000E+00, -.14275900E+00, 0.13661600E+00, 0.20903400E+01, 0.14969100E+01, 0.10140100E+00, 0.52579400E+00, 0.52839300E+00, 0.38474500E+00, 0.13835700E+01, 0.32108000E+00, -.87291700E+00, 0.25224100E+01, -.10204500E+01, 0.23335900E+00, 0.43457800E+00, -.43073100E-01, 0.67582400E+00, 0.16403800E+00, -.21166000E-01, 0.14818100E+01, 0.60240400E+00, -.28491300E+00, 0.74481500E-01, -.31509000E+00, 0.14614500E+00, -.13050700E+01, -.13923700E+00, 0.76744900E+00, -.15645700E+01, -.77908700E+03, -.10696000E+04, -.25041500E+02, 0.45709900E+02, 0.77544400E+03, -.16585100E+03, 0.68965000E+02, -.17741500E+04, 0.82669600E+02, 0.22095000E+03, 0.23331300E+03, -.13038100E+03, 0.28140800E+03, 0.15119300E+03, 0.11150600E+03, 0.74402400E+02, 0.25062200E+04, -.12540900E+04, -.78983500E+03, -.12528500E+04, -.57690400E+03, -.14282100E+03, -.11877800E+04, -.65429000E+03, -.12059100E+04, -.10584000E+03, -.57063000E+02, 0.13601000E+04, -.68045100E+03, -.13504400E+03, -.68067600E+03, 0.55349200E+03, 0.57216000E+03, -.58131800E+03, -.75607400E+03, -.26564800E+03, 0.29227300E+03, -.10461500E+04, -.11257400E+04, 0.55956200E+03, 0.23476800E+03, 0.56438900E+03, -.18021900E+03, -.15053200E+03, 0.28228600E+03, -.18435400E+01, -.61079100E+02, 0.59442000E+02, 0.72162800E+03, -.74394600E+03, 0.37513200E+03, -.49963200E+03, 0.37272200E+03, -.35124800E+03, -.16342100E+03, 0.46177600E+03, -.35852500E+03, 0.84463600E+03, -.19057400E+03, 0.12758600E+04, -.44064600E+03, 0.22141000E+03, -.43735700E+03, 0.22210300E+03, -.32504700E+03, 0.23460500E+03, -.14951900E+03, -.66171100E+03, 0.47588100E+03, 0.42694000E+03, 0.99780700E+03, -.10448300E+04, 0.51962300E+03, -.55742200E+03, 0.52236400E+03, 0.50417900E+03, 0.89119500E+03, 0.38386900E+02, -.79249100E+02, 0.36216100E+03, 0.67222000E+03, 0.10309700E+04, 0.51205200E+03, -.25748300E+03, -.29866700E+02, -.25631500E+03, -.51709300E+03, -.51674900E+02, 0.22692000E+03, 0.26165800E+03, 0.10697500E+02, -.11487000E+03, 0.66775200E+03, 0.36105200E+04, -.18045000E+04, -.27745100E+04, -.18072200E+04, -.11941700E+04, -.74138900E+03, -.59026700E+02, 0.60294500E+03, -.94836400E+03, -.66351100E+03, 0.53303400E+03, 0.82786100E+03, -.41791700E+03, -.93548100E+03, -.41536200E+03, 0.48107300E+03, 0.89612800E+03, -.66455100E+03, 0.64833100E+03, -.61222500E+02, 0.64815600E+03, -.62783400E+03, -.37928600E+03, 0.19152900E+03, -.17568900E+03, 0.18973800E+03, 0.10876300E+03, 0.19165700E+03, -.40743200E+02, 0.40684100E+02, -.21567200E+02, 0.19256700E+03, 0.21723700E+03, 0.14788900E+04, -.73692700E+03, -.74167400E+03, -.73901200E+03, -.45270400E+03, -.81321100E+02, -.42573600E+03, -.68048000E+02, -.20826700E+03, 0.18733200E+01, -.76128900E+02, -.20390000E+02, -.47807200E+01, 0.20024900E+02, 0.84132500E+00, -.22676900E+03, 0.12499400E+02, -.64934100E+01, -.22776200E+03, 0.32457800E+01, -.76528100E+01, -.37674800E+02, -.22321000E+02, 0.82499100E+02, -.99309600E+02, 0.34835200E+02, 0.61465100E+02, 0.13728000E+03, 0.19236100E+03, -.59003700E+02, 0.98401100E+02, 0.60839300E+02, -.73922400E+02, -.17640100E+03, -.76816300E+01, 0.48936000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20744000E+02, 0.26865600E+01, -.76677500E+01, 0.27799500E+00, 0.31710600E+01, -.37261600E+01, 0.12120300E+01, 0.11605800E+00, -.17919900E+01, -.26476100E+00, -.10590700E+01, 0.29038500E+00, -.18339300E+01, -.15016800E+02, -.46236500E+00, 0.22497500E+01, -.26938300E+01, -.10292300E+02, -.67038100E+00, -.16094300E+01, 0.31544100E+01, -.88408800E+00, 0.16424400E+01, -.57780700E+00, 0.39965200E+00, 0.13255400E+01, 0.41247000E+01, 0.53873500E+00, -.38990700E+01, 0.23977400E+01, -.88561800E-01, -.38440500E+00, 0.41399300E+00, 0.21047700E+00, 0.11206700E+00, 0.14522700E-01, 0.15376000E+00, -.53351600E+00, -.23882100E+01, 0.30657100E+01, -.19695300E+01, 0.16270600E+01, 0.12917300E+01, -.37960300E+00, 0.53810800E+01, 0.40772600E+00, -.33833900E+00, -.24585700E+01, -.37804000E+00, -.54339100E+00, -.37194300E+01, 0.16022100E+01, -.33123300E+00, -.73936400E+00, 0.10836900E+01, 0.47425300E+01, 0.67289400E+00, -.34335700E+01, -.22392200E-02, 0.29575500E+01, -.41149800E+01, -.25077300E+01, 0.64647700E+00, -.28374600E+01, -.41885700E+01, 0.28850900E+01, -.21013100E+01, -.11165100E+02, 0.93234400E+00, 0.28810700E-01, -.22074800E+01, 0.20945200E+01, -.98627100E+00, -.24131500E+01, 0.14926600E+01, -.36199200E+01, 0.13868500E+01, 0.20982300E+01, 0.13511200E+01, 0.18400400E+01, -.15563600E+00, -.43859900E+00, -.33186400E+00, -.17142500E+01, -.15442500E+01, 0.71238000E+00, -.14249600E+01, -.13876900E+01, -.94602200E+00, -.27303800E+00, -.14986400E+01, 0.73644800E-02, -.63352900E-01, -.95032600E+00, -.17885000E+01, -.14125400E+01, -.16819800E+01, 0.10240700E+01, 0.11939700E+01, 0.44421500E+00, -.36203100E+01, -.11489800E+01, -.19044700E+00, -.10146500E+01, -.15440900E+00, -.47362600E+00, -.22247000E+01, -.11643500E+01, 0.25244200E-01, 0.51096600E+00, 0.11493700E+01, -.39292300E+00, 0.14449100E+01, 0.23040300E-01, -.79476300E+00, 0.31916600E+00, 0.46587600E+00, 0.21167700E+00, 0.33166500E+01, -.13218600E+01, 0.46832900E+00, 0.13328700E+00, 0.94262000E-02, 0.44079500E+00, -.61835900E-01, -.50301300E+00, 0.59900100E+00, -.56496500E+00, -.83851500E+03, 0.13653500E+03, 0.11254200E+03, -.11566800E+04, -.51346400E+02, 0.29092000E+02, -.90075600E+03, 0.25512400E+02, 0.25133000E+03, 0.46928000E+02, -.20576000E+02, 0.26146500E+03, 0.20166000E+02, 0.40935900E+01, -.68797500E+02, 0.81069800E+02, -.39727700E+02, -.52235400E+03, -.40070300E+02, -.11768300E+03, -.26067200E+03, -.20554500E+03, -.20134100E+03, 0.48363600E+02, 0.42261900E+01, 0.65878800E+03, 0.14947900E+04, -.75232700E+03, 0.91144000E+02, -.74858900E+03, -.28288900E+03, 0.78600300E+03, -.69098800E+03, -.88180100E+03, -.10787800E+04, 0.73257300E+03, -.32409800E+03, -.14294100E+04, 0.71335300E+03, 0.32712400E+03, 0.71812400E+03, 0.21359300E+03, 0.23560400E+03, 0.55540900E+02, -.88296900E+02, 0.13787800E+03, 0.22300700E+03, 0.81238300E+03, -.28662900E+03, 0.14639600E+03, 0.95557100E+02, 0.14489400E+03, -.86585200E+03, -.36034500E+03, 0.37825000E+03, -.17372100E+03, -.20562500E+01, -.19252100E+03, 0.38077100E+03, 0.48799800E+03, -.24085700E+03, -.47734900E+03, -.24047100E+03, -.14245900E+03, -.36071700E+03, -.87986100E+01, 0.47589800E+01, -.15214200E+03, -.34725000E+03, 0.28213700E+03, -.24375500E+04, 0.12214600E+04, -.26241800E+03, 0.12186800E+04, 0.51753400E+03, -.16474000E+03, 0.10062700E+03, -.10943100E+03, 0.11511800E+04, -.24694900E+03, 0.10362400E+04, -.18221800E+03, 0.90357500E+02, -.25635400E+03, 0.90580500E+02, -.13437900E+03, -.62308600E+01, -.48507900E+02, 0.71624400E+02, 0.31261900E+02, -.37096600E+02, 0.56499700E+03, 0.24387200E+04, -.12201600E+04, -.34616400E+03, -.12230000E+04, -.14434500E+04, -.58660500E+03, -.88511900E+03, 0.29242700E+02, -.10314400E+04, -.22027200E+03, -.48260500E+03, -.10467400E+04, 0.54598700E+03, -.14211100E+04, 0.52117100E+03, 0.62177500E+03, 0.16858600E+03, 0.26376000E+03, 0.40991400E+03, 0.79919800E+03, 0.53023800E+02, -.19225600E+03, 0.22964800E+03, -.11550900E+03, -.43056500E+03, -.11475800E+03, 0.44844100E+03, 0.51380600E+02, 0.25310300E+02, 0.20878900E+03, -.69485100E+02, -.75007200E+02, 0.46324000E+02, 0.99709900E+03, -.50180000E+03, 0.49578900E+03, -.49777800E+03, -.49019600E+03, -.29679100E+03, 0.26529200E+03, 0.15809900E+03, -.88820300E+03, -.21549700E+02, 0.26801100E+02, 0.87370600E+02, -.83389300E+01, 0.44862100E+02, -.10772900E+03, -.49636000E+03, 0.39275700E+02, -.53249300E+02, -.50598700E+03, 0.22877500E+03, 0.48335100E+01, 0.12986300E+03, 0.18111600E+02, 0.21359500E+03, 0.15827800E+03, 0.61280600E+02, -.76674800E+02, -.92447400E+02, 0.30287900E+03, -.49616700E+02, -.11498700E+03, -.18351500E+02, -.54539200E+02, -.32875500E+03, 0.21667700E+03, -.25311100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.79671800E+01, -.63381100E+00, -.17052300E+01, 0.18713200E+01, 0.13621400E+01, -.45649800E+00, -.70182100E+00, -.47899800E+00, -.88844100E-02, -.24481400E+01, 0.14113900E+00, -.24309000E+01, -.28708000E+01, -.13364700E+01, -.23197200E+00, -.10272500E+01, -.31170900E+01, -.20772200E+01, 0.20693500E+01, -.18403600E+01, 0.11411500E+01, 0.30904300E+00, -.19567800E+00, -.16875200E+01, -.27765100E+00, -.17331800E+00, -.30580300E+00, 0.46421100E+01, 0.12166800E+00, -.55860900E+00, 0.29541500E+00, -.12842600E+01, -.33212400E+01, 0.15095200E+00, -.32703700E+00, 0.46157200E+00, -.81215600E-01, 0.38829600E-01, 0.48707800E+00, 0.27165300E+01, 0.86569900E+00, 0.43387500E+00, -.27124300E+01, 0.45280600E+00, 0.10857100E+00, 0.26127100E+00, -.60229500E+00, 0.18144400E+01, -.51465100E+00, -.43100800E+00, 0.23498200E+00, 0.10402500E+00, -.41286100E+00, -.91996000E+00, -.80549000E+00, -.17093900E+01, -.81705400E+00, 0.39568100E+00, -.44136900E-02, -.26088900E-01, 0.28691800E+01, 0.11816800E+01, -.10945300E+00, 0.12600500E+01, 0.30172700E+00, 0.20206000E+01, 0.12150500E-01, 0.13742500E+01, -.93886700E-02, 0.46320800E-02, -.10844300E+01, 0.25306800E+00, 0.10295000E+01, -.59627700E+00, -.28476500E+00, 0.45598200E+00, -.42179800E-01, 0.28837600E-01, 0.78337200E-01, -.37388600E+00, -.76194000E-03, 0.81286800E+00, 0.16319300E+00, -.22444800E+00, 0.75868700E-01, 0.19533500E+00, 0.78705000E-01, 0.52490200E+00, 0.52153300E+00, -.51800700E+00, -.95090600E+00, -.21035900E-01, -.12802700E+01, 0.27489200E-01, 0.57044600E+00, 0.39327500E+00, 0.41662200E+00, 0.53133700E+00, -.83669300E-01, -.23096200E+00, 0.83752800E+00, -.49247900E+00, -.65355700E-01, -.38861000E+00, 0.31172400E+00, -.24570300E+00, -.62309300E+00, 0.72820200E-01, 0.45633300E+00, -.20226400E+01, 0.21959400E+00, 0.14514100E+00, 0.20876500E+00, 0.26710700E-01, -.52951200E+00, 0.84010100E-02, 0.25992900E+00, -.22150000E+00, 0.22537200E+00, 0.54001300E+00, 0.18307900E+00, 0.17078800E+00, -.20952200E+00, -.79836500E-01, 0.99187500E-02, 0.61620900E+00, 0.65115900E+00, 0.12136500E-01, -.36461500E+00, 0.67147900E+03, -.80534800E+02, -.47829600E+03, -.68302100E+03, 0.34086100E+03, 0.83594800E+01, 0.34142800E+03, 0.18953000E+03, 0.14765700E+03, -.32771900E+02, -.11187400E+03, 0.26740800E+03, 0.11354300E+03, 0.31237700E+03, -.13783900E+04, 0.69172700E+03, 0.16228300E+03, 0.68935000E+03, 0.15933900E+03, -.26570700E+03, 0.33436500E+03, -.11592000E+03, 0.54033300E+03, -.26461500E+03, 0.36604100E+03, 0.98918000E+03, -.49859800E+03, -.91645000E+02, -.49493300E+03, -.65413800E+02, 0.41707000E+03, -.29450000E+03, 0.18234700E+03, -.51803700E+03, 0.48842900E+03, -.99066500E+02, -.14522100E+04, 0.72705500E+03, -.44775500E+02, 0.72599300E+03, -.98507300E+02, -.18514400E+03, 0.39373600E+03, 0.28031100E+02, 0.48900900E+03, -.22483000E+03, 0.66204000E+03, 0.21052000E+03, -.10424000E+03, 0.15403000E+03, -.10473400E+03, -.42686200E+03, -.19476200E+03, 0.10957600E+03, 0.30454800E+02, -.17489500E+03, -.49312300E+02, -.11399100E+03, 0.30679100E+03, -.15356000E+03, -.80022000E+02, -.15227600E+03, 0.54441400E+02, -.19926500E+03, 0.10000500E+03, 0.94240600E+02, -.14876500E+02, -.20933700E+03, 0.51138100E+02, -.24719200E+03, 0.12433200E+03, 0.29316500E+03, 0.12357100E+03, 0.38239200E+03, -.54700700E+02, -.22617000E+03, -.18004200E+03, 0.22709200E+03, -.13195700E+03, -.29395800E+03, -.24886800E+03, 0.12434000E+03, -.25934900E+03, 0.12429800E+03, 0.20635000E+02, -.80572500E+02, 0.18328000E+02, -.18392200E+02, 0.17653500E+03, -.55096500E+02, -.24850500E+02, 0.12281400E+04, -.61745200E+03, -.50421400E+02, -.61518000E+03, -.29295900E+03, -.66198400E+02, -.36596900E+03, -.22162500E+02, -.78903500E+03, -.47290000E+02, -.10528200E+04, -.90851800E+03, 0.46883700E+03, -.10107200E+03, 0.45369100E+03, 0.18212200E+03, 0.12575700E+03, -.78577300E+02, -.38509600E+03, 0.44646800E+03, 0.13243500E+03, 0.38051600E+03, -.23459900E+03, 0.11822200E+03, 0.37815000E+02, 0.11737900E+03, 0.22611800E+03, 0.51513800E+02, 0.91172000E+01, -.12676600E+03, 0.13178000E+03, 0.19032900E+02, 0.25485800E+03, -.11698600E+03, 0.57865400E+02, 0.14397100E+03, 0.58676000E+02, -.97303800E+02, -.10442800E+03, 0.23006800E+03, -.69174000E+02, -.76750300E+02, 0.61735200E+02, 0.18333500E+03, 0.51507200E+02, -.25891300E+02, 0.50469600E+02, -.65170200E+02, -.41017700E+02, -.26549900E+02, 0.23786200E+02, -.35688500E+02, 0.24020300E+02, 0.17677000E+02, 0.42759800E+02, 0.23186300E+01, 0.96337200E+02, -.31847900E+02, -.77736200E+02, -.82286400E+02, -.98310100E+01, 0.88113400E+02, 0.47217000E+01, -.22678100E+02, 0.37116200E+02, -.24792000E+01, 0.12947800E+02, 0.46270400E+02, -.16777200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36071400E+01, 0.34130900E+00, -.12068100E+00, -.32187900E+00, 0.11425000E+01, 0.27700700E+00, -.11087500E+00, 0.23157700E+00, 0.35327200E+00, -.14435200E+00, -.81981100E-01, 0.38634300E+00, 0.17856800E+00, 0.61655500E+00, 0.92046700E-01, 0.15392400E+00, 0.18994100E+01, 0.54860100E+00, 0.12145600E+00, 0.66750500E+00, -.30614300E+00, 0.52298300E-01, 0.21180600E+00, 0.82846800E+00, 0.24489700E-01, -.54709700E+00, -.19060800E+01, -.67705100E-01, 0.42080400E+00, -.98580800E+00, 0.26637400E-01, -.19422500E+00, 0.70101700E+00, 0.98452800E-02, 0.45083300E-01, -.67243900E+00, -.17352200E-01, 0.15901600E-01, 0.54131600E+00, 0.16470600E+01, 0.25494400E+00, 0.65604500E+00, 0.16315300E+01, 0.57442200E-01, 0.28180100E+00, 0.41929500E+00, 0.69185000E+00, 0.27008200E+00, -.62479200E+00, -.28396000E-01, 0.14179200E+00, -.91196200E-01, -.43042300E-01, -.71726900E+00, 0.53464800E-01, -.58940700E+00, -.15032500E+00, 0.54551100E-01, 0.29549700E-02, -.21876200E+00, 0.20712100E-01, 0.16194400E+00, 0.10340400E+00, -.56982300E-01, 0.43245000E-01, 0.74527000E+00, -.15714600E+00, 0.11737300E+01, 0.76951800E-01, -.24296900E-03, 0.49306500E+00, -.83150500E-01, 0.96510000E+00, 0.12798600E+00, 0.36127700E-01, -.12976200E+00, -.11302200E-01, -.12004000E+00, -.37330100E+00, 0.69248300E-02, -.18047800E-03, 0.10776700E+00, 0.12328100E+00, 0.14839300E+00, 0.66054800E-02, -.74342500E-01, 0.29839700E+00, 0.17355600E+00, -.50447800E+00, 0.10017400E+00, -.21121500E+01, 0.27741000E-01, -.29218600E+00, 0.70483400E-01, 0.55478700E-01, 0.33065200E+00, -.60220600E+00, 0.48938600E+00, -.35738000E+00, 0.16867000E+00, 0.42350900E-01, -.43945000E+00, -.84936700E-02, -.21458500E+00, -.36900800E-01, 0.16214100E+00, -.27438700E+00, -.14520800E+00, 0.59294900E+00, -.13010500E+01, -.15255400E+00, -.20743800E-01, 0.17002300E+00, 0.41838800E-01, -.19574700E+00, 0.55159400E-01, 0.28415300E+00, -.27434500E+00, 0.43626200E+00, -.13155500E-01, 0.96027800E-01, 0.35328000E+00, -.28140900E-01, -.45572100E-01, -.34030400E-01, 0.15868200E-02, -.92501300E-02, -.16570500E-01, -.78077200E-02, -.12850800E+00, -.44499400E+02, -.23708200E+03, -.31345400E+03, 0.15107600E+03, 0.17418900E+03, 0.15693600E+03, 0.71759100E+02, 0.29767400E+02, -.11602400E+02, -.74106800E+02, 0.13396100E+03, 0.24905000E+02, 0.12019400E+03, -.41744100E+03, 0.20761000E+03, 0.10516400E+03, 0.20865200E+03, 0.75758900E+02, -.10915800E+03, 0.12635600E+03, -.27461300E+02, 0.22596500E+03, -.10339800E+03, 0.20617900E+03, 0.33565500E+03, -.16876600E+03, -.83944600E+02, -.16761700E+03, -.13403300E+03, 0.15753900E+03, -.17941300E+03, -.12531800E+03, -.29967300E+03, 0.20061700E+03, -.59477600E+02, -.19906800E+03, 0.98301700E+02, -.60287700E+02, 0.98654400E+02, 0.19586200E+02, -.11953600E+02, -.42191000E+01, -.50799000E+02, 0.19132000E+03, -.33794100E+02, -.10541700E+02, -.21059300E+02, 0.10706700E+02, 0.12503100E+03, 0.10485000E+02, -.28825200E+03, -.10143800E+03, 0.77073700E+02, -.34617800E+02, -.63145200E+02, -.10806900E+03, 0.21390100E+02, -.40279500E+01, 0.32189400E+01, 0.23062000E+02, 0.15960000E+01, 0.76812900E+02, -.44352300E+02, 0.80106000E+02, 0.83459700E+02, 0.13233600E+02, -.90454700E+02, -.67888800E+02, -.62110800E+03, 0.30936900E+03, 0.12804500E+03, 0.31057700E+03, 0.10299400E+03, -.22025400E+03, 0.49783900E+02, -.10279800E+03, 0.27981300E+03, -.15630400E+03, 0.29435500E+03, -.26813300E+03, 0.13325700E+03, -.13666600E+02, 0.13421400E+03, 0.39740700E+02, -.36665900E+02, -.22210200E+02, -.92006400E+02, 0.28701000E+02, 0.67347200E+01, 0.13602900E+03, 0.59643700E+03, -.29615700E+03, -.13341000E+03, -.29753900E+03, -.19436700E+03, 0.32943200E+02, -.21039100E+03, -.10400100E+03, -.15269300E+03, 0.44646300E+02, -.22781100E+03, -.67733900E+03, 0.33623300E+03, 0.43400000E+02, 0.33966500E+03, 0.59636900E+02, 0.23699900E+02, 0.77208800E+02, -.12367200E+03, 0.28144900E+03, -.19978800E+02, 0.31119100E+03, -.16790300E+03, 0.81995000E+02, 0.10486000E+03, 0.83917100E+02, 0.20883000E+03, 0.10388400E+03, -.35741900E+02, -.48646300E+02, -.12169700E+03, 0.10129000E+03, 0.48168100E+02, -.59461100E+02, 0.32373300E+02, 0.19503100E+03, 0.29474400E+02, -.48354800E+02, 0.39286800E+02, 0.15128600E+03, 0.70173800E+02, -.17784900E+03, 0.69676100E+02, 0.10739100E+03, 0.11461300E+02, -.43552700E+01, 0.19002900E+02, -.28662800E+02, -.14288600E+02, 0.28669900E+01, -.62074300E+01, -.16373200E+02, -.59788500E+01, 0.48823800E+01, 0.81470900E+01, 0.36530100E+00, -.28008300E+01, -.25675300E+02, -.96943100E+01, -.29207800E+02, -.31186600E+02, 0.52637300E+02, 0.32302400E+01, -.37960800E+02, -.29547800E+02, -.25355200E+02, 0.13194100E+02, 0.38417900E+02, -.30744300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30618700E+01, 0.35287200E+00, -.24087800E+00, 0.16149500E+01, -.68054600E+00, -.18917200E+01, 0.18261600E+01, -.79282900E-01, -.19124300E+00, 0.12136300E+01, 0.33387800E+00, -.56184100E+00, -.11666400E+01, 0.36854900E+00, -.17223000E+00, 0.95727100E+00, -.18852200E+00, -.22075500E+00, 0.41072500E+00, 0.10754500E+00, -.18621400E+00, -.13520600E+00, 0.38290700E+00, 0.90620200E+00, 0.10740600E+00, 0.39336400E-01, 0.35047600E+00, 0.11503900E+01, -.84157300E+00, -.75490300E-01, 0.20348000E+00, -.41655200E+00, -.42763600E+00, 0.13852000E+00, -.46207900E-02, -.28583600E+00, 0.12455000E-01, -.44973400E-01, -.31712900E+00, -.21778700E+00, -.73347400E-01, 0.54418100E+00, -.31572100E+01, 0.60071500E-01, 0.13848300E+00, -.13512100E+00, 0.17031000E-01, 0.20108200E-01, -.46535500E-01, 0.16049700E+00, -.40127900E+00, 0.44789700E+00, 0.27457400E+00, -.13127100E+00, -.52051700E-01, 0.52938100E+00, 0.67973100E-01, 0.37593800E-01, -.39850400E-02, 0.58404300E-01, -.81908700E+00, -.48753100E+00, 0.30148100E-01, 0.23175600E+00, 0.57400100E+00, -.36487600E+00, 0.93466100E-01, -.15160200E+01, 0.58177400E-01, 0.62506000E-02, -.14341000E+00, -.28754200E+00, -.91977900E+00, -.78970600E+00, 0.80766600E+00, 0.19049000E-01, -.10627100E-01, -.75153900E-01, 0.94722500E-01, 0.29610400E+00, -.84759800E-02, -.28990800E+00, 0.46205000E+00, 0.12524700E+00, 0.10838900E+00, -.13188700E-01, -.13752200E-01, 0.57875600E-01, -.27187900E+00, -.11110700E+00, -.28842900E+00, 0.19880300E-01, 0.31271500E+00, -.80198000E-01, -.78694300E-02, -.58948100E-01, -.55362600E+00, -.12766500E+00, -.12414100E+00, 0.20215500E-01, -.19754700E+00, 0.10613100E+00, 0.20715600E-01, 0.16482500E+00, -.90733900E-02, 0.60000100E-01, -.20453800E+00, -.18123600E+00, -.17709800E+00, -.73657400E+00, 0.70512100E-01, 0.12472500E-01, 0.10415200E+00, 0.39199400E-01, -.58746100E-01, 0.24882600E-01, -.19904900E+00, -.25268300E+00, -.59668900E-01, 0.21312100E+00, -.10477500E+00, 0.41448500E+00, -.22271900E-02, 0.35741800E+00, -.28334200E-01, -.15508800E+00, 0.22420800E+00, -.15825000E+00, -.37867700E-02, -.51808400E-01, -.10361300E+01, -.51512000E+03, -.47724400E+03, 0.22344200E+03, -.64298200E+02, 0.23890200E+03, 0.13993500E+03, 0.10452200E+03, -.34635400E+02, -.98316000E+02, 0.18382500E+03, 0.81320200E+02, 0.21844800E+03, 0.10257900E+03, -.55535500E+02, -.23704300E+02, -.51284300E+02, 0.33937400E+02, 0.87816200E+01, -.10680500E+03, -.10997600E+03, -.21036500E+02, 0.81418500E+02, 0.55963000E+02, 0.16903000E+03, -.85100700E+02, -.55494800E+02, -.84473200E+02, -.13012900E+03, 0.10334000E+03, -.15122600E+03, -.31978400E+03, -.23462900E+03, 0.12130200E+03, -.19751000E+03, 0.36692100E+03, -.18641900E+03, -.25253200E+03, -.18466900E+03, 0.29732300E+02, 0.21247100E+02, -.17671500E+03, -.47420500E+02, 0.93425800E+01, 0.10065200E+02, -.11165400E+03, -.15241800E+03, 0.75907900E+02, 0.23883400E+03, 0.76513200E+02, -.36762900E+03, -.54278700E+02, 0.14094600E+03, -.73542100E+02, -.82821100E+02, -.94688600E+02, 0.15385600E+03, 0.12954800E+03, -.63053800E+02, -.58245400E+02, -.64571800E+02, -.43763700E+01, -.77045000E+02, 0.37940700E+02, 0.78038200E+02, 0.79855500E+02, -.13442600E+03, 0.89658300E+02, -.10624700E+04, 0.52805400E+03, 0.30899200E+02, 0.53125000E+03, 0.68338600E+02, -.26063600E+03, 0.17788800E+03, -.73663100E+02, 0.55075700E+03, -.18939600E+03, 0.50504300E+03, -.22553100E+03, 0.11145800E+03, -.39332900E+02, 0.11286600E+03, 0.23925800E+02, -.93394800E+01, -.53664000E+02, -.88840200E+02, 0.56964900E+02, 0.14821600E+02, 0.25638300E+03, 0.80483900E+03, -.39600300E+03, -.12242600E+03, -.40224500E+03, -.27872700E+03, -.26597100E+02, -.27183300E+03, -.14685500E+03, -.21462600E+03, 0.48215800E+02, -.17744200E+02, -.83690400E+03, 0.40097600E+03, -.33535600E+02, 0.41944600E+03, 0.12591500E+03, 0.10059800E+03, 0.21668200E+03, 0.11882400E+03, 0.42251500E+03, -.51218500E+01, 0.27238900E+03, -.27663300E+03, 0.12988100E+03, 0.80033200E+02, 0.13828700E+03, 0.27879700E+03, 0.11879600E+03, -.55367700E+02, -.63169500E+02, -.12169900E+03, 0.10152700E+03, 0.19282400E+03, -.13317600E+03, 0.72633200E+02, 0.39963200E+03, 0.66378000E+02, -.87377000E+02, 0.59562900E+02, 0.16208400E+03, 0.24414100E+02, -.28105800E+03, 0.79966100E+02, 0.19785800E+03, 0.26576300E+01, -.18064200E+01, 0.28408700E+02, -.37736900E+02, -.64827200E+02, 0.58133000E+01, -.83076000E+01, -.65828400E+02, -.11805300E+02, 0.16877300E+02, -.17864300E+01, 0.88710500E+01, -.14809400E+02, -.54036500E+02, 0.15484000E+02, -.21437900E+02, -.63103400E+02, 0.74181200E+02, -.78443300E+01, -.93907900E+02, -.14400600E+02, -.44365500E+02, -.17324400E+02, 0.31370600E+02, -.56263700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44863900E+01, 0.41401600E+00, -.85372400E+00, 0.17175800E+01, -.11737300E+01, -.23461000E+01, 0.22200900E+01, -.10420600E+00, -.36905600E+00, -.52855300E-01, 0.45642300E+00, -.99282800E+00, -.16101500E+01, -.67194900E-01, -.20721400E+00, 0.13611500E+01, -.61980800E+00, -.12789600E+01, 0.76324700E-01, -.45068000E+00, 0.69100700E+00, -.12703400E+00, 0.34346500E+00, -.44295100E+00, 0.22888900E+00, -.83562300E-01, 0.26570200E+01, 0.32477800E+01, -.10679000E+01, 0.68419800E-01, 0.28017800E+00, -.55393900E+00, -.12408800E+01, -.32311700E+00, 0.80441300E-02, 0.61459700E+00, 0.45850300E-01, -.27886100E+00, -.92733500E-01, 0.15837700E+01, -.32277800E+00, 0.63431000E+00, -.15688200E+01, -.15215200E+00, 0.10250900E+01, 0.60960500E-01, -.14745500E+00, -.49956600E+00, 0.14236300E+00, 0.77867000E-01, -.74043500E+00, -.11346100E-02, 0.17220500E+00, 0.43309600E+00, 0.42314400E+00, 0.39235000E+00, 0.20783200E+00, -.45124700E+00, -.84188200E-02, 0.44114300E+00, -.12186900E+01, -.43316100E+00, 0.52551200E-01, -.10197700E+00, 0.80236600E+00, -.12036900E+00, 0.19258700E-01, -.24868600E+01, 0.16362600E+00, 0.10987500E-01, -.42303400E+00, 0.80650400E-01, -.89979000E+00, -.47848300E+00, 0.32293200E+00, 0.38329700E+00, -.10362000E+00, -.46292100E+00, 0.16362900E+00, 0.26618800E+00, -.32525800E-01, 0.15949400E+00, 0.41295200E+00, -.67111500E-01, 0.13920500E+00, 0.52330200E-01, -.55925200E+00, 0.81303900E-01, -.52752200E+00, -.32288600E+00, 0.65117700E+00, 0.35980000E-01, -.21625500E+00, 0.18860800E+00, -.61145600E-01, 0.43859400E-01, -.15294400E+01, 0.62149400E+00, -.38652100E+00, 0.25048800E+00, -.80333700E+00, 0.12324800E+00, -.37294500E-01, -.31281400E+00, 0.11253100E+00, -.40468000E-01, -.29115000E+00, -.26727600E+00, -.18699000E+00, -.12893000E+00, 0.19648700E+00, 0.16374600E+00, -.40002500E+00, 0.12268100E-01, 0.17958300E+00, -.51170900E-01, -.18705000E-01, -.39469400E+00, -.32927700E+00, 0.20921100E+00, -.16650800E+00, 0.24371300E-01, 0.78926500E-01, 0.17358600E+00, -.25263100E-01, -.27905800E+00, 0.63206100E+00, -.22698900E+00, 0.42331000E-02, -.44197300E-01, -.86666400E-02, -.63900400E+00, -.66290400E+03, 0.31455300E+03, -.34227700E+03, 0.33143600E+03, 0.17870300E+03, 0.21723500E+03, -.67325000E+02, -.14089800E+03, 0.26669400E+03, 0.16035800E+03, 0.39108900E+03, 0.19826100E+03, -.10305500E+03, 0.17295500E+03, -.98925300E+02, 0.12603700E+03, 0.37289100E+02, -.22349000E+03, -.27264900E+03, -.17052000E+03, 0.30833100E+02, -.85212400E+02, 0.27240400E+03, -.13249900E+03, -.18705200E+02, -.13661900E+03, 0.95565100E+02, 0.16528000E+03, -.13337200E+03, -.16083400E+03, -.10331900E+03, 0.18870100E+03, -.41276900E+03, 0.23868700E+03, -.11824900E+03, -.55042200E+03, -.12101200E+03, -.29096100E+03, -.17117300E+03, 0.22614400E+02, 0.83213300E+02, 0.34575500E+02, -.17419100E+03, 0.13470100E+03, 0.17497600E+03, -.89487500E+02, -.11697600E+02, -.86682300E+02, -.42077500E+03, -.14579400E+03, 0.13061900E+03, 0.66157900E+02, 0.81436200E+02, -.13136400E+03, 0.10560000E+03, 0.32482500E+03, -.16460000E+03, -.30584300E+03, -.16084400E+03, -.12237700E+03, -.15632200E+03, 0.85119700E+02, 0.14680500E+03, 0.17371800E+03, -.16333100E+03, 0.19847300E+03, -.85810600E+03, 0.42849100E+03, -.36447100E+03, 0.42902600E+03, 0.24893300E+03, 0.14467000E+02, 0.17276700E+03, 0.39131600E+02, 0.51966300E+03, -.26489600E+02, 0.43673300E+03, -.27337500E+03, 0.13775000E+03, -.15952500E+03, 0.13655400E+03, -.30507600E+02, -.35555500E+02, 0.28832500E+02, -.29338000E+02, 0.15663100E+03, -.40677700E+02, 0.29345000E+03, 0.67679500E+03, -.33751600E+03, -.20885500E+03, -.33979700E+03, -.14116100E+03, -.10802800E+03, -.17915300E+03, -.45018600E+02, -.33816900E+03, -.37458900E+02, -.14146900E+03, -.77792400E+03, 0.37021800E+03, 0.72292800E+02, 0.38858500E+03, 0.19931100E+03, 0.31731900E+03, -.12267400E+01, 0.40520900E+01, 0.26317200E+03, 0.19089600E+03, 0.36152000E+03, -.31281400E+03, 0.14875600E+03, 0.17268400E+02, 0.15654400E+03, 0.18258300E+03, 0.69298700E+02, -.15596700E+01, -.71770700E+02, 0.68520900E+02, 0.40444700E+02, 0.34243700E+03, 0.58835400E+01, -.18508600E+01, 0.42689300E+03, -.27978100E+01, -.11405700E+02, -.65512500E+01, -.12799200E+02, -.15680400E+03, -.22880400E+03, 0.47613500E+02, -.73428100E+02, -.13014500E+02, -.82279100E+01, 0.24292700E+02, -.30710500E+02, -.70274100E+01, -.61122900E+01, 0.77660300E+01, -.65189800E+01, -.71104000E+02, 0.25571800E+02, -.25696400E+02, -.20874400E+00, -.32440000E+02, -.13549600E+03, -.41760700E+02, -.87804200E+01, -.52746700E+01, 0.47903500E+02, -.15238700E+01, -.12268700E+03, 0.24053900E+02, -.18114100E+02, 0.32481600E+02, -.17248800E+02, -.50941600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.37087200E+01, 0.39186000E+00, -.88595400E-01, 0.20425800E+01, 0.24487600E+00, -.17470800E+01, 0.98475500E+00, -.20101700E-01, -.33739700E+00, 0.11063200E+01, 0.27443300E+00, -.13084300E+00, -.65973300E+00, -.26177900E+00, 0.76784600E-02, 0.68533000E+00, -.16731800E+00, -.39473800E+00, 0.46018500E+00, -.35087400E+00, -.41602700E+00, -.18551800E+00, 0.19094900E+00, 0.69894700E+00, 0.21025200E+00, 0.37932100E-01, 0.11763600E+01, 0.18900400E+01, -.11012200E+01, 0.20630500E+00, 0.20930400E+00, -.10316900E+00, -.83236200E+00, -.47921400E+00, 0.17746300E+00, 0.18678800E+00, 0.42658600E-01, -.27134800E+00, 0.12250000E+00, 0.73926000E-01, -.26280500E+00, 0.26095500E-01, -.47232000E+00, -.10924000E-01, 0.31025400E+00, -.21993700E-02, 0.16798400E-01, -.40638400E+00, -.86840800E-02, 0.53891900E-01, -.93578400E+00, -.45298800E-01, -.21825000E+00, 0.37856800E+00, 0.20783900E+00, 0.69313500E-01, 0.53317100E-01, -.13925500E+00, -.60610300E-02, -.37196700E+00, -.22202600E+00, -.61999300E+00, 0.35060600E-01, 0.16967300E+00, 0.49657300E+00, 0.54493200E-01, -.41207600E-01, -.15529300E+01, 0.21823900E-01, 0.74485900E-02, -.39729500E+00, 0.20413000E+00, -.11607900E+01, -.42687400E+00, 0.49818100E+00, 0.33538300E-01, -.11920800E+00, 0.36274500E+00, 0.28097400E+00, 0.74961200E-01, -.17171700E-01, -.27623800E+00, -.19577600E-01, -.38871400E-02, 0.19063100E+00, 0.49105300E-01, 0.43049800E+00, 0.15542800E+00, 0.54025300E+00, 0.15607200E-01, 0.20775000E+01, -.34509100E-01, 0.14718500E+00, -.97700900E-01, -.34907800E+00, -.12701200E+00, 0.11889200E+00, -.23389500E+00, 0.32827200E+00, -.20878100E-01, 0.63449300E-01, 0.17167300E+00, -.15833100E-01, -.51199700E-01, 0.21611200E+00, 0.71175400E-01, -.16109400E+00, -.91391000E-01, -.52341400E+00, -.56866700E+00, -.12278300E+00, -.89221800E-01, -.12788800E+00, -.17346600E-01, 0.98093900E-01, -.14586200E-01, 0.44700600E+00, -.21064800E+00, -.34808300E+00, 0.11710500E+00, -.72049500E-01, -.12065700E+00, 0.21413300E-01, -.38527200E-01, -.39050200E-02, 0.21059800E+00, 0.56757800E-02, 0.10929700E+00, -.15670800E+00, -.18252500E-01, -.77226000E+00, 0.65680300E+00, 0.13803000E+00, 0.14949000E+02, -.24525700E+02, -.10905700E+00, 0.82998400E+00, -.39421800E+02, 0.36795500E+02, 0.43148100E+02, 0.36031200E+02, -.27878100E+02, -.27601100E+02, -.88276000E+03, 0.44328000E+03, 0.17611300E+03, 0.44136300E+03, 0.86131500E+02, -.17091400E+03, 0.32067700E+03, 0.10367500E+03, 0.39951000E+03, -.19527600E+03, 0.31448700E+03, 0.55598000E+03, -.27671600E+03, -.51697600E+02, -.27794700E+03, -.84073900E+02, 0.25569400E+03, -.16593600E+03, 0.13164000E+03, -.26899300E+03, 0.29838600E+03, 0.12684000E+03, -.73524600E+03, 0.36964400E+03, 0.12558200E+03, 0.36840400E+03, -.36950700E+02, -.52235600E+02, 0.18963100E+03, -.31479600E+02, 0.27283600E+03, -.74922200E+02, 0.17553300E+03, 0.30181000E+03, -.15206900E+03, -.81083800E+02, -.15107100E+03, 0.50901700E+01, -.80098300E+02, -.52482300E+02, 0.12759100E+03, -.14730400E+03, -.10355700E+02, -.22989300E+03, 0.99569900E+01, -.84201800E+01, 0.16929400E+02, -.51863600E+01, 0.11148600E+03, -.56455600E+02, 0.75792200E+02, 0.13436200E+03, -.75593000E+02, -.71773200E+02, -.16203000E+03, 0.24162300E+03, -.11601500E+03, -.68028300E+02, -.12081100E+03, 0.19267100E+03, 0.83327800E+01, -.12037900E+03, 0.48057700E+02, -.84963200E+02, -.31425400E+02, -.24048900E+03, -.97731100E+02, 0.49892000E+02, -.12801900E+02, 0.48859100E+02, 0.52837600E+02, 0.73639800E+01, -.44631400E+00, 0.26097300E+02, 0.20226300E+02, -.19283500E+01, -.87496700E+02, -.51239000E+03, 0.24610900E+03, 0.36470000E+03, 0.25628200E+03, 0.47875700E+01, -.90957200E+02, 0.11439400E+03, 0.25328600E+02, 0.12294300E+03, -.98923900E+02, -.32901900E+03, -.16037200E+03, 0.10541100E+03, -.12754900E+03, 0.79940900E+02, 0.57062800E+02, 0.58895600E+01, -.12967800E+03, -.30206000E+03, -.34107600E+02, 0.57336700E+02, 0.79061600E+02, 0.88651500E+02, -.36999700E+02, 0.69140700E+01, -.44294300E+02, 0.32650600E+01, 0.21997400E+02, 0.14808700E+02, 0.13021100E+02, 0.19650100E+02, 0.80839100E+01, -.18706500E+02, 0.78669700E+02, -.45702300E+02, -.19496100E+02, -.39307500E+02, -.48968000E+02, -.77893400E+02, 0.56357600E+02, 0.85202300E+01, -.10119500E+02, -.36477600E+02, 0.38315800E+02, 0.40328100E+02, 0.49332200E+01, -.86438800E+01, -.12178800E+02, 0.74391800E+01, 0.35466500E+01, -.61451800E+01, 0.60435100E+01, 0.15388600E+02, -.20438500E+02, 0.37502300E+02, 0.36812400E+01, 0.22393600E+02, 0.15869000E+02, -.23354700E+02, -.33225200E+02, 0.14619400E+02, 0.72778500E+01, 0.34283300E+01, 0.84211500E+01, -.54537100E+01, 0.99303300E+01, 0.89473800E+01, 0.41112800E+02, 0.23307900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15828100E+02, 0.16272000E+01, 0.19902600E+00, -.32364000E+01, -.40119400E+01, -.17969200E+01, 0.27845900E+01, -.10198800E-01, -.50560500E+00, 0.23867800E+01, 0.50773200E+00, 0.94188200E+00, 0.10815800E+01, -.28034400E+01, -.22262600E+01, 0.34065400E+01, 0.21213400E+01, -.75716500E+00, -.37656600E+01, 0.31470600E+01, 0.14176500E+01, -.68189300E+00, 0.19265600E+01, 0.67546000E+01, 0.78861600E+00, 0.26692900E+01, -.58230500E+00, 0.22426700E+01, 0.16383200E+01, -.70263100E+00, -.28504400E+00, 0.24278700E+01, -.14047300E+01, 0.76312800E-01, 0.53779500E-01, 0.15226700E+00, 0.12105200E+00, -.21072800E+00, -.64451800E+00, 0.16816900E+01, -.30356800E+00, 0.14702100E+01, 0.44979600E+01, -.69720600E+00, 0.20261700E+01, 0.57447400E+00, 0.12650600E+01, -.21857400E+01, -.60549100E+00, 0.43866700E+00, -.37480200E+01, 0.78908200E+00, 0.57983700E+00, -.60555600E+00, -.22069300E+00, 0.21226400E+01, 0.10626800E+01, -.46320600E+00, -.11703700E+00, 0.14828900E+01, -.13268000E+01, -.51615500E+00, 0.37388300E-01, -.10792100E+01, 0.11544000E+01, -.45636000E+01, 0.13038800E+01, 0.12790300E+01, -.48998000E-01, 0.69612400E+00, 0.94961100E+00, -.91757800E+00, 0.45731000E+00, 0.12430800E+01, -.92473300E+00, 0.21945200E+01, -.80537600E-01, -.26998300E+01, -.14828000E+01, 0.85125400E+00, -.39709200E+00, -.44679100E+01, -.35650600E+00, 0.11075400E+01, 0.29161100E-01, -.56035600E+00, 0.24560300E+01, -.41123100E+00, 0.43386700E+00, 0.17665300E+01, 0.31469100E+01, 0.38457600E+00, 0.60310100E+00, 0.16196500E+01, 0.19068200E+01, -.62255500E+00, -.59459300E+00, -.97952400E+00, -.66976100E+00, -.11922000E+01, 0.37714500E+00, 0.88480600E-01, 0.95894600E-01, -.31076800E+00, -.24149000E+00, -.73148800E+00, 0.27965900E+01, 0.97898900E+00, -.73149000E+00, 0.41448100E+01, -.24465300E+00, -.48168200E-01, 0.11495700E+01, 0.34535600E+00, -.86801100E+00, 0.50421400E-01, -.38269900E+00, -.90228600E+00, 0.65189600E-02, 0.76833800E+00, -.62912300E+00, 0.13000400E+01, -.14592900E+00, 0.20217100E-01, -.30006600E+00, -.17498500E+00, 0.27520400E+00, 0.75576300E+00, -.81008900E-01, -.15281600E+00, 0.88322000E+00, -.29826800E-01, -.16233200E+00, -.19296700E+01, 0.26240300E+04, 0.59325800E-01, -.28546200E+03, -.18701200E+03, 0.21116400E+03, 0.60311500E+01, -.85551500E+02, -.11339600E+03, 0.33081300E+01, -.45302600E+03, 0.22768500E+03, 0.15852600E+03, 0.22676500E+03, 0.38863300E+03, 0.21320900E+03, 0.17890900E+03, 0.14513700E+03, 0.16526800E+03, 0.19073000E+03, -.32466600E+03, -.66830600E+03, 0.33326400E+03, 0.81758600E+01, 0.33426900E+03, 0.24189600E+02, -.28516400E+03, 0.41463900E+03, 0.50229000E+03, 0.21333600E+03, -.33460600E+03, 0.71527600E+03, -.12918000E+03, 0.62233400E+02, 0.25929100E+02, 0.63031000E+02, -.18269300E+03, -.12154100E+03, 0.41415800E+03, 0.35407600E+03, 0.48827200E+03, -.47088000E+02, -.55933600E+03, 0.31755400E+03, -.15394400E+03, -.25028800E+03, -.15822400E+03, 0.23407000E+03, -.11879800E+03, -.81917500E+02, 0.36234900E+03, -.18320700E+02, -.27838400E+02, -.51885700E+03, 0.42501800E+02, -.12410500E+02, 0.23682800E+03, -.21552600E+02, -.16133400E+03, 0.54879400E+02, 0.18789700E+03, 0.93487700E+02, -.23794000E+03, 0.49835800E+02, -.66891500E+03, 0.15114600E+04, -.76160900E+03, 0.14488900E+03, -.75567400E+03, 0.37424000E+02, -.35651200E+02, -.46407800E+03, -.47295200E+03, -.70802500E+03, 0.72407400E+02, -.11570200E+04, 0.64481100E+02, -.35694100E+02, -.23410800E+03, -.31865700E+02, 0.63187500E+01, 0.49873000E+02, 0.33651200E+02, 0.41475700E+01, -.13592100E+02, 0.15479600E+02, -.55498600E+03, -.23292900E+04, 0.11712500E+04, 0.95702600E+03, 0.11651900E+04, 0.68134700E+03, 0.33401200E+03, 0.37211300E+03, -.30492300E+03, 0.62959400E+03, 0.45624300E+03, -.11482000E+03, -.12638000E+03, 0.59236200E+02, 0.26337600E+04, 0.66984600E+02, -.46516000E+03, -.12495700E+04, 0.60469800E+03, 0.16264200E+02, -.29076600E+03, -.93115400E+03, 0.31971100E+03, -.10554200E+03, 0.60719000E+02, 0.15094200E+03, 0.53081100E+02, -.43905300E+03, -.15411100E+03, 0.13776900E+03, -.76542400E+02, 0.19904400E+03, -.18446900E+03, 0.15298200E+03, 0.49023400E+03, -.23784500E+03, -.23473300E+03, -.24581500E+03, 0.30174600E+03, 0.96567600E+02, -.36977100E+03, 0.42251000E+02, -.14883700E+03, -.13307100E+03, -.25278700E+03, -.18026200E+02, 0.15968100E+02, -.27876900E+02, 0.32216200E+02, 0.97338100E+02, 0.14540900E+02, -.20435100E+02, 0.10097500E+03, -.50833000E+02, -.49762800E+00, -.27172400E+02, -.34569600E+01, 0.10154100E+02, 0.77446700E+02, -.38060700E+02, 0.12232900E+02, -.36941100E+01, -.15183700E+03, 0.12440200E+02, 0.75575500E+02, -.15367000E+02, 0.50109000E+02, 0.56868300E+02, -.93715000E+02, 0.13264600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.74340300E+01, 0.73452900E+00, 0.73730900E-01, -.68542100E+00, -.26607000E+00, -.97532200E+00, 0.12363900E+01, 0.15754300E+00, -.13200200E+00, 0.16021900E+01, -.20247600E+00, 0.18308200E+01, 0.17629500E+01, -.10772700E+01, -.10345800E+01, 0.18406100E+01, 0.23335400E+01, -.81516600E+00, -.12402100E+01, 0.55429000E+00, 0.29853800E+00, -.41998900E+00, 0.37539500E+00, 0.28776100E+01, 0.22617700E+00, 0.33658500E+00, -.83688700E-02, -.10488400E+01, -.42850400E+00, 0.28065300E+00, -.70401500E-01, 0.19721400E+00, 0.48376600E+00, -.52620100E+00, 0.35899200E+00, -.53866600E+00, 0.23080600E+00, -.20515200E+00, -.15191900E+01, 0.10816600E+01, -.92136500E+00, 0.30167600E+00, 0.40835700E+01, -.48612100E+00, 0.12439400E+01, 0.41661200E+00, 0.54168500E-01, -.25793000E+01, -.93183400E-01, 0.19786700E+00, -.14782100E+01, 0.60941400E+00, -.65852900E+00, -.13000900E+01, 0.18890100E+01, 0.16404100E+01, 0.39067900E+00, -.46588200E+00, 0.96360000E-03, 0.57798400E-03, -.13976800E+01, -.78300400E+00, 0.96747000E-01, -.84280900E+00, -.97139300E+00, -.26736200E+00, -.89898300E-01, 0.22770200E+01, -.15974800E+00, -.31621500E-02, 0.17765400E+00, 0.30841500E+00, -.28683400E+01, -.87025000E+00, 0.93879400E+00, 0.12024700E+01, -.11429400E+00, 0.19127500E+00, 0.28037100E-01, 0.12270700E+01, -.21856400E-01, 0.13781700E+01, -.16977300E+00, 0.17126600E+00, -.18861000E+00, -.17491800E+00, -.48794700E+00, -.37272100E+00, -.10632200E+00, -.21327100E+00, 0.15576100E+01, 0.39594900E-01, 0.36196800E+00, -.15672200E+00, -.62960300E+00, 0.20965500E-01, 0.60956200E+00, 0.11601800E+00, 0.81211900E-02, -.21341700E+00, 0.73907400E+00, 0.34809800E+00, 0.67648000E-01, 0.63774300E-01, 0.81577600E-01, 0.12695800E+00, 0.65485400E-01, -.59250400E-01, -.52765200E+00, 0.39978400E+00, -.36435800E+00, 0.26172900E+00, 0.53488300E+00, 0.54350600E-01, 0.22460900E-01, 0.32726600E-01, 0.16584400E+00, -.44543100E+00, -.13798200E+01, 0.69055400E+00, 0.57290000E-02, 0.37727000E+00, 0.71542800E-01, -.11232300E+00, -.28440900E-01, 0.12289100E+00, -.74449900E+00, 0.14833400E+00, -.11136600E+00, -.16815900E+00, -.43540900E+00, 0.33293900E+00, 0.41020400E+00, -.44102900E+00, 0.14201900E+00, 0.37671000E+01, -.59721900E+02, -.15155300E+03, 0.10947300E+03, 0.88821000E+02, 0.94074400E+01, -.12075600E+03, -.78019600E+02, -.77182300E+03, 0.38868300E+03, -.66234100E+01, 0.38575100E+03, -.35640700E+02, -.21387900E+03, 0.32835700E+03, 0.12053000E+03, 0.33077200E+03, -.20397900E+03, 0.38577400E+03, 0.52387200E+03, -.26551800E+03, 0.14693800E+02, -.26188600E+03, -.18436300E+03, 0.23501000E+03, -.13137300E+03, 0.18276900E+03, -.20749200E+03, 0.21284000E+03, 0.75908400E+02, -.64626700E+03, 0.32330100E+03, 0.34432600E+03, 0.32407400E+03, 0.17876000E+03, 0.35693900E+02, 0.13681900E+01, -.25495400E+03, -.35382700E+02, 0.49055100E+02, 0.21093400E+03, -.20326700E+02, 0.12265500E+02, 0.43730600E+02, 0.99795200E+01, 0.92699900E+02, 0.29926800E+02, -.29077600E+02, -.81330300E+02, -.15214500E+03, 0.65946100E+02, -.52272300E+02, -.47731400E+02, 0.25867300E+02, 0.13086900E+03, 0.23394200E+02, 0.85594000E+02, -.13147500E+01, -.23578500E+02, -.24999200E+02, -.15187000E+03, 0.13288700E+01, -.12478800E+03, 0.40530100E+03, -.20427500E+03, 0.20397000E+03, -.20265000E+03, 0.35888500E+02, 0.68786600E+02, -.19158300E+03, 0.13327000E+03, -.10287300E+03, 0.22530100E+02, -.17416900E+03, 0.32210500E+03, -.16116600E+03, 0.27985900E+01, -.16106500E+03, -.68054000E+01, -.11517000E+02, -.10834200E+03, 0.26507900E+02, -.10971200E+03, -.17968900E+02, -.18588300E+03, -.27488100E+03, 0.14119100E+03, 0.17942400E+03, 0.13807300E+03, -.16928300E+03, -.11367400E+03, 0.13494000E+02, -.10003900E+03, 0.14710500E+03, -.17738500E+03, 0.24175700E+02, 0.13538500E+03, -.69715800E+02, -.36258800E+03, -.67345500E+02, 0.14041300E+02, -.87131300E+02, 0.51880800E+01, -.73174100E+02, -.16326600E+02, -.61860000E+01, -.11617300E+03, 0.31952500E+03, -.15985100E+03, -.35407900E+02, -.16023300E+03, -.31878200E+02, -.88471900E+01, -.35810800E+02, 0.58474000E+02, -.86381500E+02, 0.45111200E+01, -.22859000E+03, -.11738100E+03, 0.59692500E+02, -.22370300E+03, 0.58752300E+02, -.14632100E+03, -.84427000E+02, 0.17776900E+03, 0.43210100E+02, 0.17030300E+03, -.52676100E+02, 0.15561300E+03, 0.25651400E+02, 0.60116900E+01, -.52269400E+01, -.26972000E+01, -.54618600E+02, -.78604300E+01, -.20625200E+00, -.57065100E+02, 0.37247900E+02, -.42264200E+02, 0.54736000E+02, 0.73473000E+01, 0.39368100E+02, 0.55924900E+02, 0.12934400E+01, -.23570400E+02, 0.13596400E+02, 0.40394500E+02, 0.30657400E+01, 0.42033300E+02, 0.68352700E+01, -.69249300E+01, -.54515100E+02, 0.59716400E+02, 0.56439400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30748400E+01, 0.24272200E+00, 0.15459800E+00, -.17855900E+00, 0.70298800E+00, -.15179800E+00, 0.22258100E+00, 0.25261800E+00, -.47370200E-01, 0.57878800E+00, -.87470500E+00, 0.15614300E+01, 0.12596300E+01, 0.35979000E+00, 0.61662400E+00, -.15267200E-02, 0.81551900E+00, -.27585800E+00, -.63472200E+00, 0.54937800E+00, -.63205500E+00, -.80963100E-01, -.10950500E+00, -.14981600E+00, -.71029900E-01, 0.27590300E+00, -.15465100E+01, -.23632900E+01, 0.83482700E+00, -.15485400E+00, -.22382000E+00, -.14119100E+00, 0.10830800E+01, 0.58142700E+00, 0.39522900E-01, -.70309100E+00, 0.30964500E-01, 0.27457900E-01, 0.17866400E+00, -.48372900E+00, 0.23256900E+00, -.29032700E+00, 0.19362100E+01, -.87987300E-01, -.67349200E+00, 0.10728700E+00, 0.37925700E+00, -.38474300E+00, -.67121900E+00, -.99448200E-01, 0.15233900E-01, 0.34594600E+00, -.24987800E+00, -.49613800E-01, 0.48360600E+00, 0.51096000E+00, 0.19571100E+00, -.68376000E+00, 0.52004500E-02, 0.66474900E+00, -.32821400E+00, -.53776000E+00, 0.25478600E+00, -.50062500E+00, -.15944500E+01, 0.81871700E+00, -.68964600E+00, 0.57824400E+00, -.66227300E-01, 0.91822400E-02, 0.13906800E-01, 0.24617500E+00, -.37464800E+00, -.37629600E+00, 0.70883800E-01, 0.66153600E+00, 0.71117200E-01, -.33293600E+00, 0.48345500E-01, 0.25718000E-01, -.17698000E-01, -.24605800E+00, -.34689100E+00, 0.78072200E-01, 0.91691600E-01, 0.32319400E-01, 0.16118100E+00, -.14021400E+00, -.20724200E-01, 0.37153600E+00, -.14815300E+00, -.14778900E-01, 0.20924100E-01, 0.20612100E+00, 0.41840600E+00, 0.12184300E+00, -.14533500E+00, 0.99809000E-01, 0.14421700E+00, 0.91981600E-01, 0.27406000E+00, 0.21127900E+00, 0.12214900E-01, 0.13331200E+00, -.11359100E+00, 0.77158200E-01, 0.64935500E+00, 0.41996100E-01, -.25365900E+00, 0.28985200E+00, -.21891000E+00, 0.93960300E-01, 0.23659700E+00, -.73324200E-02, 0.90072700E-01, 0.25475100E-01, 0.12555100E+00, -.35282600E-01, -.58423000E+00, -.14139900E+00, -.26679800E-01, 0.14283300E+00, 0.37852300E-01, -.19331200E+00, -.55286300E-02, 0.20575300E+00, -.12403700E-01, 0.90967000E-01, -.48503200E-01, -.97228800E-01, 0.22273000E+00, -.63949600E-01, 0.50421500E+00, -.78727800E-01, 0.15659200E+00, 0.64415000E-02, -.37297500E+02, -.80080000E+02, 0.32527300E+02, 0.31895300E+02, 0.53523700E+02, -.72636500E+02, -.52005600E+02, -.15557300E+03, 0.80093800E+02, -.10960200E+03, 0.77676600E+02, -.81498600E+02, -.69294200E+02, 0.10562700E+03, 0.80785700E+02, 0.82464400E+02, -.52955500E+02, 0.19495200E+03, 0.22332800E+03, -.11391100E+03, -.20317600E+02, -.11157400E+03, -.62771700E+02, 0.66051800E+02, -.53780500E+02, 0.55924100E+02, -.76901700E+02, 0.24244800E+02, 0.29529100E+02, -.37032200E+03, 0.18587600E+03, 0.28204200E+03, 0.18635100E+03, 0.15919900E+03, 0.60392300E+02, -.26009800E+02, -.16412800E+03, -.22896500E+02, 0.76515500E+02, 0.12044100E+03, -.12354400E+03, 0.63392700E+02, 0.50676600E+02, 0.61413100E+02, 0.75180000E+02, 0.16745900E+02, -.44234800E+01, -.10083900E+03, -.33830200E+02, -.92672700E-01, 0.84869000E+02, -.13859500E+03, 0.70442300E+02, 0.11804900E+03, 0.68839400E+02, 0.93696100E+02, 0.81611400E+02, -.81215400E+02, -.11555700E+03, -.66733600E+02, 0.75586700E+02, -.39283500E+02, 0.21847700E+03, -.10988500E+03, 0.19960500E+03, -.10924200E+03, -.78000700E+02, 0.34535500E+02, -.80417600E+02, 0.39371800E+02, -.10518800E+03, 0.33957600E+02, -.60744200E+02, 0.20741200E+03, -.10347300E+03, 0.64341500E+02, -.10374200E+03, -.27204100E+02, -.71080400E+01, -.54977600E+02, -.40913600E+01, -.94628600E+02, 0.28930300E+01, -.65084200E+02, 0.92705700E+02, -.44106500E+02, -.88130300E+02, -.46013400E+02, -.14400500E+03, -.20878100E+02, -.20645600E+02, -.12181600E+02, 0.82930400E+02, -.70403200E+02, 0.23857600E+03, 0.30654300E+03, -.15431100E+03, -.20569400E+03, -.15381700E+03, -.40822700E+02, -.73142500E+02, -.33329200E+02, -.30988600E+02, -.34257800E+02, -.52748600E+02, -.16256400E+03, 0.15447400E+03, -.76576300E+02, -.90340700E+01, -.77374300E+02, 0.19957800E+01, 0.17065400E+02, -.50255200E+02, 0.34208100E+02, -.93767400E+02, 0.44227900E+02, -.17582400E+03, -.42631300E+02, 0.20926000E+02, -.23747500E+03, 0.21419300E+02, -.81951400E+02, -.31099300E+02, 0.83499600E+02, 0.68612900E+02, 0.13661100E+03, -.31969300E+02, 0.12652200E+03, 0.41062300E+01, 0.34165400E+01, 0.59178000E+01, 0.49070300E+01, -.13682400E+02, -.43746600E+01, 0.17828400E+01, -.15816800E+02, 0.32752300E+02, -.22739800E+02, 0.20714200E+02, 0.49590900E+00, 0.19772600E+02, 0.39977800E+02, 0.17567000E+02, -.36255600E+01, 0.30610100E+01, 0.22320200E+02, -.78413900E+00, 0.49772100E+02, -.53717200E+01, -.85473600E+01, -.28183200E+02, 0.30275300E+02, 0.35688000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.45922300E+01, 0.66847700E-01, 0.52351700E+01, 0.26251600E+01, -.34678100E+01, -.82417700E+00, 0.18840800E+01, -.44266400E+00, 0.19141900E+00, 0.41489000E-01, 0.47356600E+00, -.18953200E-01, 0.94952500E-01, 0.23876500E+01, 0.43663700E-01, 0.32447100E+00, 0.55237700E+00, 0.12388600E+01, 0.20218400E+00, 0.33513500E+00, -.55854200E+00, -.91863500E-01, -.14979700E+00, 0.34709300E-01, -.18331100E-02, -.15334700E+00, -.11350700E+01, 0.24281200E+01, 0.94436100E+00, -.51464700E+00, 0.76277900E-01, 0.43089700E+00, -.85123000E+00, -.50089600E-01, 0.40226200E-01, -.51699100E+00, 0.20834200E-01, -.17564800E+00, 0.36862600E+00, 0.38628500E+00, -.30806500E-02, 0.16774800E+00, 0.14445400E+01, -.78818400E-01, -.22003900E+00, 0.54199900E-01, 0.46090800E+00, -.44573500E+00, -.10417400E+01, -.77054600E-01, -.11500500E+01, 0.39613900E+00, -.36134100E+00, -.13153200E+00, 0.49439300E+00, 0.89771800E-01, 0.50649600E-01, -.28868300E+00, 0.22021300E-03, 0.17962000E+00, -.93508000E+00, -.82995600E+00, -.43613600E-02, -.57047400E+00, -.13790200E+00, 0.34767100E+00, -.58244100E-01, 0.14961100E+01, 0.12930100E+00, -.17612800E-02, 0.38931500E+00, -.19463000E+00, 0.37436000E+00, 0.10622000E+01, -.48953700E+00, 0.16258900E+00, -.40384900E+00, -.26591800E+00, -.14358400E+00, 0.23026800E-01, -.20204600E-01, 0.11013900E+01, -.17468700E+00, 0.16480500E+00, 0.32162200E+00, -.14691600E+00, 0.86063700E-01, 0.49210700E+00, 0.10513400E+01, -.86348700E+00, 0.92260600E+00, 0.26820000E-01, 0.72863100E-01, -.11955800E+00, -.89762900E+00, 0.77251200E-01, 0.42756500E+00, -.42844800E+00, -.38228500E-01, 0.40236200E-01, 0.19136300E+00, -.34243500E+00, 0.36781700E-01, 0.18745500E+00, -.15172600E+00, -.73815500E-02, 0.24116400E+00, 0.75887400E-01, -.59152100E+00, 0.22982000E+00, -.22035700E+00, 0.20094700E+00, 0.22019500E+00, 0.21167400E-01, 0.11856200E+00, 0.10631800E+00, -.69440800E-01, 0.38586700E+00, -.69149000E+00, 0.73432200E+00, 0.90012200E-01, 0.90888500E-01, -.10646800E+00, -.20878600E+00, -.59793500E-01, 0.20528200E+00, -.88831100E+00, 0.10366400E+00, 0.12966800E+00, -.14958900E+00, 0.41242600E+00, -.64193300E+00, 0.39885000E+00, -.74802500E+00, 0.83314600E-01, 0.12526600E-01, -.28614600E+00, -.88404200E+02, 0.53614100E+02, 0.52705300E+02, 0.50109600E+01, -.66721600E+02, -.71259700E+02, -.58511600E+03, 0.28652500E+03, -.11520300E+03, 0.29254500E+03, -.86887800E+01, -.10390000E+03, 0.25032200E+03, 0.11379900E+03, 0.20675200E+03, -.70459100E+02, 0.37579500E+03, 0.26473000E+03, -.11691900E+03, -.98152100E+02, -.13254300E+03, -.15472500E+03, 0.84714300E+02, -.27892300E+02, 0.20512500E+03, -.22626700E+02, 0.17372700E+02, 0.50371900E+02, -.47556800E+03, 0.23357900E+03, 0.48051300E+03, 0.23882000E+03, 0.26404400E+03, 0.11586100E+03, -.57489000E+02, -.25450700E+03, -.10246600E+03, 0.13921500E+03, 0.49794800E+02, 0.35891800E+02, -.16461200E+02, 0.21129400E+02, -.17954700E+02, 0.53850900E+02, 0.48703700E+02, -.20177400E+02, -.31703000E+02, -.11982400E+03, 0.10552800E+02, -.41032400E+02, -.11989300E+03, 0.60449700E+02, 0.14785600E+03, 0.60221000E+02, 0.13499700E+03, 0.86601800E+02, -.64601100E+01, -.19083500E+02, -.10807100E+03, 0.48948000E+02, -.14497600E+03, 0.55730400E+03, -.27938100E+03, 0.14584300E+03, -.27867500E+03, -.24230000E+02, 0.15624500E+03, -.17363000E+03, 0.18053700E+03, -.18105800E+03, 0.11434800E+03, -.22129100E+03, 0.31884900E+03, -.15920500E+03, 0.75655700E+02, -.15957400E+03, -.22987300E+02, 0.86344500E+01, -.68819300E+02, 0.39817200E+02, -.10639300E+03, 0.74049600E+01, -.14524600E+03, -.95755700E+02, 0.68477900E+02, 0.26998900E+02, 0.47472100E+02, -.25625100E+03, -.11169800E+03, 0.12593400E+03, 0.31593000E+02, 0.10653700E+03, -.17348700E+03, 0.23323100E+03, -.47400200E+02, 0.22235000E+02, -.22019000E+03, 0.22811200E+02, 0.46631800E+02, -.32267900E+02, 0.19132500E+02, -.95731800E+02, 0.37298600E+02, 0.52495000E+01, -.40829600E+01, 0.20417200E+03, -.11921200E+03, 0.64542900E+01, -.10225500E+03, 0.26740900E+02, 0.58792500E+01, -.36346800E+02, 0.45111700E+02, -.23489100E+02, 0.41052500E+02, -.16780600E+03, -.50979300E+02, 0.24904400E+02, -.23769100E+03, 0.25761700E+02, -.17455300E+03, -.13724000E+03, 0.15147500E+03, 0.94763400E+02, 0.21776000E+03, -.15817400E+03, 0.21885000E+03, 0.43934400E+01, 0.52581200E+01, 0.14053500E+02, -.44134000E+01, -.36267100E+02, -.98773500E+01, 0.36102700E+01, -.37927700E+02, 0.69894600E+02, -.32553100E+02, 0.24329700E+02, -.60073800E+00, 0.30009400E+02, 0.74013100E+02, 0.48649600E+01, -.23617500E+02, -.52577200E+01, 0.21511800E+02, 0.10737100E+02, 0.48453100E+02, 0.13255500E+02, 0.58038200E+00, -.31141600E+02, 0.31814200E+02, 0.54094800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18050700E+01, 0.17687600E+00, -.14591000E-01, -.16080400E+00, 0.27605600E+00, 0.14110200E+00, 0.15741600E-01, 0.78094700E-01, 0.14851400E+00, 0.50640800E-01, 0.75018500E-01, 0.35387200E+00, 0.32279600E+00, 0.35788900E+00, 0.13651300E-02, 0.69566400E-02, 0.49790900E+00, -.62924000E+00, 0.30906300E+00, 0.51438000E-01, -.10501900E+00, -.26269800E-02, -.72098400E-01, 0.17360300E+00, 0.13778600E-01, -.61392100E-01, -.11150600E+01, 0.71895000E+00, -.34031800E-01, -.12033600E+00, 0.29349500E-01, 0.17219900E+00, 0.37684200E+00, -.12946900E+00, 0.71710300E-01, -.80879700E+00, 0.31737400E-01, -.46162800E-01, -.66981800E+00, -.23387300E+00, -.14874100E+00, -.14016000E+00, 0.75597100E+00, -.81398900E-01, 0.38368100E-01, 0.11648000E-01, -.40351100E-01, -.34250500E+00, -.10504300E+00, 0.43003100E-01, -.23174900E-01, -.77076400E-01, -.11216700E+00, 0.21123200E+00, 0.26831700E+00, 0.78914400E-01, 0.49532600E-01, -.20609100E+00, 0.14902700E-02, -.15261400E+00, -.20341600E+00, -.18243300E+00, 0.30518000E-01, -.10981000E+00, -.34038900E+00, 0.87041300E-01, -.10928400E+00, 0.70126800E-01, -.24673900E-01, -.66147500E-03, -.20270900E-01, 0.12374100E+00, -.15776600E+00, -.14284000E+00, 0.59003000E-01, 0.28279100E+00, -.53326000E-01, -.48228000E-01, 0.11586100E+00, 0.64353100E-01, -.41607200E-02, 0.32670300E+00, -.15682700E+00, 0.34413800E-01, 0.18402200E-01, 0.14106900E-01, -.43059200E+00, -.45729800E-01, -.32282500E-02, -.37581900E-02, -.46463000E-02, 0.37994200E-02, 0.98841800E-01, -.51622400E-01, -.23246900E+00, 0.40353100E-01, 0.24060200E-01, -.26374400E-02, 0.36581300E-01, -.38560700E-02, 0.15480300E+00, 0.80412200E-01, 0.11996100E-01, 0.98363200E-01, -.73617800E-01, 0.52720300E-01, 0.89508100E-01, -.36302000E-01, -.15542300E+00, 0.10904400E+00, -.95483100E-01, 0.41370400E-01, 0.12993000E+00, 0.16278300E-02, 0.10375800E-01, 0.80493200E-02, -.57801400E-01, 0.66681800E-01, -.15951400E+00, 0.18221700E+00, -.83992900E-02, 0.95588600E-01, -.31708900E-02, 0.89003100E-02, -.59520000E-03, 0.44205400E-01, -.18517900E+00, 0.74677000E-01, -.14570700E-01, -.66770400E-01, 0.89659200E-02, 0.48967600E-02, -.13944200E-01, -.73635600E-01, 0.71848900E-01, 0.13137600E-01, 0.43369100E+00, -.86739100E-01, 0.35910300E+02, 0.59484100E+01, -.40280500E+02, 0.88290600E+01, -.78285800E+01, -.55788500E+02, 0.26734800E+02, 0.15950900E+02, 0.27916000E+02, 0.27276300E+02, 0.40382900E+01, 0.17183700E+02, 0.51418500E+00, 0.10832200E+02, 0.11510900E+02, 0.25022900E+00, -.54892900E+02, 0.28816900E+02, 0.22086900E+02, 0.27376800E+02, -.31839600E+02, -.10140500E+02, 0.27753400E+02, 0.12969600E+02, 0.16903000E+02, -.78569700E+01, 0.22756600E+02, 0.72390000E+02, -.37001600E+02, -.19851600E+02, -.36467700E+02, 0.85035300E+01, 0.57949400E+01, -.19764400E+02, 0.64581400E+01, -.23484900E+02, 0.44949400E+01, -.21747700E+02, -.17420500E+01, 0.57841200E+00, 0.72552300E+01, 0.99057200E+00, -.13928000E+02, 0.72988800E+01, -.23638700E+01, -.63133000E+01, -.13485100E+02, 0.13346100E+02, -.43006700E+02, -.43068900E+01, 0.21227600E+01, 0.20542300E+01, 0.23841900E+01, -.36225000E+01, -.11433300E+02, 0.14633200E+02, 0.15548400E+02, -.16772500E+01, -.16953500E+02, -.82918500E+01, -.30093700E+01, 0.11457300E+01, -.47905500E+02, 0.14997900E+01, -.37381500E+01, 0.39739700E+01, -.23572200E+02, -.83651100E+01, 0.24494600E+02, 0.80839500E+00, 0.17335800E+02, -.27983400E+01, 0.12534200E+01, -.13589200E+02, 0.13726400E+01, 0.80085800E+01, 0.35459800E+01, -.11464000E+02, -.60122600E+01, 0.77276200E+01, 0.72380000E+00, -.11347700E+02, -.47765200E+02, 0.25760100E+02, 0.51602400E+02, 0.23688500E+02, -.64336400E+01, -.76998300E+01, 0.92772900E+01, -.10790500E+01, -.31019200E+01, -.27517900E+00, -.54566700E+02, -.27349200E+02, 0.13052000E+02, -.13089600E+02, 0.13617400E+02, 0.32436700E+01, -.19157800E+02, 0.54675100E+02, 0.24544800E+02, 0.74101600E+01, -.31848700E+01, -.59020600E+01, 0.60568000E+00, -.31659800E+01, 0.91552000E+00, -.31946200E+00, 0.14989800E+02, -.45998300E+01, 0.38944500E+01, -.15710700E+01, 0.78254700E+01, -.11801700E+02, -.12908400E+01, -.36135800E+01, 0.25845100E+01, 0.55598900E+02, 0.18416700E+01, 0.12040800E+02, -.12838700E+02, 0.18463900E+02, -.48852600E+01, -.35789600E+02, -.46077600E+01, -.51780400E+02, -.36947600E+01, 0.24488900E+01, -.65626000E+01, -.57036900E-02, -.27624300E+01, 0.28659900E+01, -.41555300E+01, -.23780700E+01, -.16797500E+01, -.11161800E+01, 0.91632500E+00, 0.16887500E+01, 0.45129700E+00, 0.45511600E+01, 0.16077300E+00, -.48988900E+00, -.13200500E+01, -.14261300E+01, 0.27034000E+01, -.99942700E+01, -.20358300E+00, 0.11999800E+01, -.27073300E+01, 0.14120300E+01, -.99353000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.66045900E+01, 0.77622500E+00, -.25950200E+01, 0.38984100E+01, 0.40606800E+01, -.30171400E+01, 0.58654700E+00, 0.65506000E-01, -.68566300E+00, 0.48832100E+00, -.63717700E+00, 0.66667600E+00, -.29858100E+00, -.31054400E+01, 0.59293200E+00, 0.98662700E+00, 0.41751400E+00, -.13753600E+01, 0.11461800E+01, -.12612300E+01, -.23997200E+00, -.36710100E+00, 0.15277300E+00, 0.12043800E+00, 0.37146700E+00, 0.56517900E+00, 0.21508200E+01, 0.21225500E+01, -.22699200E+01, 0.10151000E+01, 0.21238500E+00, 0.72350500E+00, -.64398500E+00, -.96664900E+00, 0.46857000E+00, 0.68763800E+00, 0.90796600E-01, -.58127200E+00, 0.83621000E+00, -.11363300E+01, -.16948000E+00, -.11124200E+01, 0.51311500E+00, 0.71252200E-01, -.76017000E+00, -.23870300E+00, -.16677100E-01, -.11434700E+01, 0.22635700E-01, 0.14525000E+00, -.17745000E+00, 0.11854000E+00, -.88258900E+00, 0.62340000E+00, 0.14194700E+00, 0.16269800E+01, 0.13255800E+00, -.16998200E+00, 0.10121900E-02, -.23953400E+00, -.24154600E+01, -.99800200E+00, 0.16924800E+00, 0.38036400E-01, -.40567400E+00, 0.48880100E+00, -.33421400E+00, -.31668500E+01, -.19706600E+00, 0.11564800E-01, -.16448100E+00, 0.74093600E+00, -.12691400E+01, 0.21353600E-01, 0.11353700E+01, -.61243800E+00, 0.17153300E-01, 0.15365400E+01, 0.79199700E+00, 0.32049200E+00, -.54767600E-01, -.45923100E+00, 0.41265700E+00, -.27855200E+00, 0.63506100E-01, 0.13022400E+00, 0.71339900E+00, 0.87835600E-01, -.72553100E+00, 0.73484500E+00, 0.11945900E+01, -.33688700E-01, 0.39759800E+00, -.34697100E+00, -.10808700E+00, 0.29739900E+00, 0.28254800E+00, 0.32715600E+00, 0.26486800E+00, -.39806700E-02, 0.55968600E+00, -.28172800E+00, -.25481000E-01, 0.61832800E-01, 0.17589400E+00, -.38276500E+00, -.16142000E+00, 0.85813500E-01, -.49700400E+00, -.89867400E+00, -.42320800E+00, 0.29462400E+00, 0.38731400E+00, 0.16255400E-01, 0.10300500E+00, 0.57335300E-03, -.79323100E-01, 0.46913400E+00, 0.92312300E-01, 0.75475400E+00, 0.99967900E-01, 0.52968200E-01, -.67249800E-01, 0.12225400E-01, -.47730500E-02, 0.78905700E+00, -.58768800E+00, 0.15902200E+00, -.24491100E+00, -.29234000E-01, 0.43371500E+00, -.19513700E+00, 0.66096000E+00, 0.15564600E+01, 0.17240700E+00, 0.78125200E-01, 0.56501200E-02, 0.70972800E+00, -.13562300E+01, -.11213500E+03, -.13179600E+03, 0.20492300E+02, -.21646400E+02, 0.81528900E+03, -.40060400E+03, -.49602100E+02, -.40780000E+03, -.97589500E+02, 0.99488300E+02, -.18310000E+03, -.20139700E+02, -.40511400E+03, 0.13128700E+03, -.49859400E+03, -.78598800E+03, 0.37520900E+03, 0.10409400E+03, 0.39333200E+03, -.82548900E+02, -.37816100E+03, 0.27249100E+03, -.12320200E+02, 0.43973100E+03, -.35495700E+03, 0.12829200E+03, 0.10044700E+04, -.50097600E+03, -.17480500E+03, -.50318700E+03, 0.24000100E+03, 0.70752600E+02, -.31785900E+03, -.10926300E+02, -.37396700E+03, 0.39756600E+02, 0.55864000E+02, -.35302200E+03, 0.17807000E+03, 0.23793700E+03, 0.17622500E+03, 0.12869300E+03, 0.23191700E+03, -.45326500E+02, -.25791100E+03, -.17641900E+01, 0.19654700E+03, 0.36174700E+02, 0.15488200E+03, -.72820200E+02, 0.25318500E+02, -.78309400E+02, -.12422100E+03, -.60436600E+02, -.13369100E+03, -.11171200E+03, 0.10330300E+03, -.55846800E+02, 0.16268600E+03, -.11007300E+03, 0.50563100E+02, 0.13922100E+03, 0.55066400E+02, -.51252300E+03, -.30687300E+01, 0.23851200E+02, -.10614500E+03, 0.61799300E+02, -.22240400E+01, 0.12311800E+02, 0.20118900E+03, -.10173900E+03, 0.63759900E+02, -.10041700E+03, 0.67835000E+02, 0.43283400E+02, -.95165900E+02, -.37963200E+02, -.18516900E+02, 0.56514800E+02, -.49269700E+02, 0.40777700E+03, -.20620900E+03, -.20543400E+02, -.20275900E+03, 0.15805800E+03, 0.27864100E+03, -.19562600E+03, -.69549900E+01, -.25622100E+02, 0.18472400E+03, 0.61388300E+02, 0.43617500E+03, -.22278100E+03, -.47392200E+03, -.21707900E+03, -.17147800E+03, 0.12088400E+03, 0.53833100E+01, 0.10025100E+03, -.11385800E+03, 0.14559700E+03, -.32404700E+03, -.33623300E+02, 0.18057100E+02, 0.14020500E+03, 0.16680100E+02, -.20311800E+02, -.47411200E+02, -.30424500E+02, -.23950100E+02, -.84856100E+02, -.33180500E+02, 0.24078200E+02, -.53601600E+03, 0.27450000E+03, 0.11886800E+03, 0.26772600E+03, 0.14133800E+03, 0.75147800E+02, 0.14898500E+03, 0.24682400E+02, 0.13363400E+03, 0.11678200E+03, -.21150800E+03, -.47965000E+02, -.72157800E+01, -.17756300E+02, 0.31206800E+02, 0.69135100E+02, -.15648100E+02, 0.15607700E+02, 0.71854400E+02, -.50231800E+02, 0.24388300E+02, -.31469600E+02, 0.10331900E+02, -.15160700E+02, -.40483700E+02, 0.17743800E+02, 0.28749800E+02, -.20499200E+02, -.33124100E+02, 0.17927800E+02, -.22013800E+01, 0.27460200E+02, -.59371500E+01, 0.49492500E+02, -.43307000E+02, -.32416400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.73487100E+01, 0.74591400E+00, -.65749800E+00, 0.25459100E+01, 0.14029800E+01, -.26346900E+01, 0.89022200E+00, -.15294200E+00, -.13200000E+01, 0.98252700E+00, -.25843200E+00, -.35299000E-01, -.93181400E+00, -.31714100E+01, 0.15453400E+01, 0.11467500E+00, -.87776800E+00, -.29018600E+01, 0.18195500E+01, -.64933400E+00, -.26609300E+00, -.45158100E-01, 0.11050600E+00, 0.10862300E+01, 0.64517500E-01, 0.66562900E+00, -.19855800E+01, 0.58874600E+00, -.87190100E+00, 0.55001800E+00, 0.10622000E+00, 0.97241400E+00, -.73679300E+00, -.93854300E+00, 0.36783100E+00, -.12186800E+01, 0.75197100E-01, -.62811200E+00, 0.95938000E+00, -.86374400E+00, 0.50043000E+00, -.73657300E+00, 0.44371500E+00, 0.96796400E-01, -.12497400E+01, -.32621500E+00, 0.34260000E+00, -.13573000E+01, -.63974900E+00, -.12362200E+00, -.23006700E+00, 0.52123500E+00, -.90374500E+00, 0.52352500E+00, 0.13813000E+01, 0.11077300E+01, 0.13524100E+00, -.38061200E+00, 0.72440000E-02, -.11434100E+01, -.22982400E+01, -.99427800E+00, 0.29093400E+00, -.57906600E+00, -.94566500E+00, 0.17969900E+01, -.60125500E+00, -.57766100E+00, -.54141100E-02, 0.59700500E-02, 0.32377800E+00, 0.40185400E+00, -.14404600E+01, -.23758400E+00, 0.98452200E+00, -.78846500E+00, 0.13872300E+00, 0.11695300E+01, -.16710000E+00, 0.34231500E+00, -.82127600E-02, 0.11471300E+01, -.23331500E+00, -.22407200E+00, -.24787300E+00, 0.43801600E-01, 0.26443500E-01, 0.13028600E+00, 0.47488200E-01, 0.12221400E+00, 0.13076900E+00, -.19053400E-01, 0.12003100E+00, -.31804400E+00, -.69892600E+00, -.38858500E-01, -.13207500E+01, 0.56180200E+00, 0.29911600E+00, 0.58284100E+00, -.85024300E+00, -.46857600E+00, -.45993200E-01, -.25140000E+00, 0.45521500E-01, -.11302600E+00, -.10136300E+01, -.29429700E+00, 0.60428800E-01, -.20012300E+01, 0.10945500E+00, 0.93822800E-01, 0.67012000E-01, 0.38401900E-01, 0.12005400E+00, -.68772100E-01, -.10891000E+00, 0.40081800E+00, 0.73756500E+00, -.63639700E-01, -.12298400E-01, -.65615600E+00, -.48976500E-01, 0.15153000E+00, 0.79870000E-02, 0.62888500E-01, -.25581100E+00, -.28500800E-01, 0.72587000E-01, 0.26224400E+00, 0.30129300E-01, -.58449700E+00, 0.17402700E+00, 0.82661700E+00, 0.10577400E+00, 0.12025700E+00, -.99696300E+00, -.47289300E+00, -.12224300E+01, -.10611400E+00, -.14318000E+03, 0.18279400E+02, -.85700400E+02, 0.96915800E+03, -.48553800E+03, -.33418100E+03, -.48495000E+03, -.24346800E+03, 0.11865800E+03, -.15455000E+03, 0.14047400E+03, -.41572800E+03, 0.20772100E+03, -.17868800E+03, -.90500000E+03, 0.45519700E+03, 0.39119600E+02, 0.45310900E+03, -.15457400E+03, -.45682900E+03, 0.29905500E+03, -.11887700E+03, 0.50230000E+03, -.51850000E+03, 0.16934800E+03, 0.98117400E+03, -.49406500E+03, 0.40877100E+03, -.49031200E+03, 0.52450500E+03, 0.33255100E+03, -.57138800E+03, -.28589400E+03, -.71596800E+03, 0.33200500E+03, -.15472700E+03, -.78353300E+03, 0.39394200E+03, 0.39980200E+03, 0.39094800E+03, 0.21990100E+03, 0.34091900E+03, -.49125000E+01, -.50847100E+03, -.13603000E+02, 0.18240200E+03, 0.29162500E+03, -.24333300E+03, 0.12542300E+03, 0.25001400E+03, 0.11984000E+03, 0.38345000E+02, 0.17999000E+03, -.16526200E+03, -.24242300E+03, -.26683700E+02, 0.16396800E+03, 0.55685000E+02, 0.24147200E+03, -.12595800E+03, 0.29970800E+03, -.12069400E+03, -.67601900E+03, -.23959400E+02, -.15443000E+02, 0.41946600E+02, -.18832000E+03, 0.61740000E+02, 0.14795800E+03, 0.62486000E+03, -.31321400E+03, 0.21650500E+03, -.31220100E+03, -.11278100E+02, 0.20737500E+02, -.19214000E+03, -.70220100E+02, -.28689300E+03, 0.67241900E+02, -.15909500E+03, 0.84106900E+03, -.40282100E+03, -.37566800E+03, -.41840200E+03, -.26750000E+03, 0.19339000E+02, -.22176700E+01, 0.16351500E+03, -.13186400E+03, -.48742300E+02, 0.54665900E+03, 0.97632300E+03, -.49489300E+03, -.59380300E+03, -.48717100E+03, -.26541300E+03, 0.13968500E+01, 0.16531100E+03, 0.48749500E+03, -.36979700E+02, -.26090100E+02, -.58018800E+03, 0.18878000E+03, -.11075500E+03, 0.50030800E+02, -.94794000E+02, 0.72056400E+02, 0.41464000E+02, -.14133200E+03, 0.48815100E+02, -.21191600E+03, 0.96604900E+02, -.34334800E+03, -.57181500E+03, 0.29143200E+03, -.25918700E+03, 0.28559600E+03, 0.31454300E+02, 0.76989900E+02, 0.21134000E+03, 0.88361900E+02, 0.38796100E+03, 0.54226300E+02, -.35923100E+02, -.57520500E+02, 0.57282000E+01, -.97936800E+01, 0.38509300E+02, 0.44688200E+02, -.13336200E+02, 0.96059900E+01, 0.45305800E+02, 0.21099000E+02, -.73151900E+01, -.16510800E+02, -.10681900E+01, 0.31259800E+01, 0.28380400E+02, 0.73344100E+02, 0.36972900E+02, -.20194900E+02, 0.10767300E+02, 0.12362300E+02, 0.62529300E+02, -.14421800E+02, 0.25467200E+01, -.53412300E+01, 0.39367300E+01, 0.16412700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.89114200E+01, 0.11445200E+01, -.28747400E+01, 0.24268900E+01, 0.32120900E+01, -.29166100E+01, 0.93822600E+00, -.26714200E-01, -.91798100E+00, 0.35924200E+00, 0.35767500E+00, -.64432800E+00, -.10451100E+01, -.38138500E+01, -.60413200E+00, 0.10831000E+01, -.74140500E+00, -.40472200E+01, 0.10918200E+01, -.10187300E+01, -.49708300E-01, -.49315200E+00, 0.46156600E+00, 0.14975300E+01, 0.17807300E+00, 0.10014200E+01, -.47136700E+00, 0.18525500E+01, -.16545200E+01, 0.84802600E+00, 0.81091200E-01, -.36140400E-01, -.90053400E+00, 0.11605000E+01, -.25219800E+00, 0.47064200E-01, -.20973400E-01, -.46968600E-01, -.83911600E+00, 0.22612300E+01, 0.13929200E+00, 0.74961500E+00, -.21907100E+01, -.54302100E-02, 0.19529200E+01, -.30393500E-02, -.74203800E-01, -.67914500E+00, -.26816900E+00, -.17919200E+00, -.95141100E+00, 0.81311100E+00, 0.94077900E-01, -.25511100E-01, 0.65109400E+00, 0.90065800E+00, -.10655200E+00, -.11753100E+00, -.68554300E-02, -.76266800E+00, -.10327300E+01, -.68752700E+00, 0.49309800E+00, -.60630700E+00, 0.44651100E-01, 0.15605800E+01, -.47414600E+00, -.15894600E+01, 0.26318400E+00, 0.21334100E-01, -.15095200E+00, 0.27348500E+00, 0.82587100E+00, -.21667300E+01, 0.23985100E+01, -.18755100E+01, 0.37503900E+00, 0.77111500E+00, -.67906300E-01, 0.85090600E-01, -.33374700E-01, -.11405200E+01, 0.38718600E+00, -.10408600E+01, -.68360500E+00, 0.54338800E+00, -.56929800E+00, 0.54719900E+00, -.94630000E+00, -.66187500E+00, -.57338000E+01, 0.20151300E-01, -.14666000E+01, -.10252300E+00, 0.14540400E+01, -.91764100E-02, -.19153200E+01, 0.74775500E+00, -.13502400E+00, 0.51796400E+00, -.74492600E+00, -.93455100E+00, -.63349300E-01, -.15305600E+00, -.64639700E+00, -.45800500E+00, 0.11776600E+01, -.24128300E+00, 0.32992800E-01, -.31081400E+01, -.54229800E+00, -.99986900E-01, 0.56342900E+00, 0.11850500E+00, -.99379800E-01, 0.66208400E-01, 0.11009900E+00, 0.32157000E+00, -.12425300E+01, 0.35174000E+00, -.12456700E-01, 0.32379300E-01, 0.98704900E-02, -.33827800E+00, -.88407600E-01, 0.50116900E+00, -.37664500E-01, -.20800600E-01, 0.83418700E-02, 0.34457900E+00, 0.67578300E+00, -.44052300E+00, -.23755500E+00, -.11711400E+01, 0.68048700E-01, 0.76023200E-01, -.38367300E+00, -.16128200E-01, -.10201400E+01, 0.34639300E+00, 0.13086200E-01, 0.19968400E+02, -.58744600E+00, -.15429400E+04, 0.76695700E+03, 0.22669200E+03, 0.77153200E+03, 0.26190300E+03, -.12223800E+03, 0.48816000E+03, 0.53396400E+02, 0.61949700E+03, -.97652000E+02, 0.73483800E+03, 0.64276700E+03, -.31226600E+03, -.16951000E+03, -.32165300E+03, -.12386600E+03, 0.29488100E+03, -.15237900E+03, 0.32427900E+03, -.17735900E+03, 0.31302700E+03, 0.16397700E+03, -.73764800E+03, 0.36750800E+03, 0.16105900E+03, 0.36894200E+03, 0.97230100E+01, -.85699700E+02, 0.87436600E+02, -.20930500E+03, 0.18082100E+03, -.81959900E+02, 0.20933000E+03, 0.22746600E+01, -.26130400E+01, 0.40603800E+03, -.69429000E+00, -.13826800E+03, -.30713900E+02, -.20159700E+02, -.89019000E+02, -.32998100E+03, -.22859000E+02, -.14098500E+03, 0.15661700E+03, -.81000100E+02, 0.45471200E+02, -.77396300E+02, 0.18683100E+03, -.10117500E+03, 0.18701600E+03, 0.26641800E+03, -.54270800E+02, -.18041100E+03, -.56822100E+03, 0.72515700E+03, -.36048500E+03, -.34395200E+03, -.36260000E+03, 0.26458900E+03, 0.16698700E+03, -.39024700E+03, 0.27093500E+02, -.22135600E+03, 0.13329900E+03, -.40646300E+03, 0.23269500E+03, -.11579200E+03, -.10569900E+03, -.11646500E+03, 0.70880600E+02, 0.35528600E+02, -.16679000E+03, -.22487600E+02, -.10389800E+03, 0.37919300E+02, -.25205700E+03, -.41992200E+03, 0.20981900E+03, 0.49830300E+03, 0.20921000E+03, -.24688800E+03, -.24462500E+03, 0.23220300E+03, 0.29269900E+02, 0.37337200E+01, -.18492500E+03, -.24067800E+03, -.60672400E+03, 0.30871100E+03, -.38110800E+02, 0.30302500E+03, 0.17859700E+03, 0.15462700E+02, 0.10304100E+02, -.29872900E+03, 0.19068200E+03, 0.43007300E+02, 0.28353700E+03, -.67263900E+02, 0.33170500E+02, 0.93563100E+02, 0.33539400E+02, 0.27585600E+03, 0.18946400E+03, -.91821200E+02, -.64603800E+02, -.43370300E+02, 0.16813500E+03, -.79762100E+02, -.25197900E+03, 0.12269300E+03, 0.42773800E+02, 0.12615200E+03, -.72679500E+02, -.11827700E+03, 0.30332800E+03, 0.12253900E+03, 0.14345800E+03, -.14804100E+03, -.14595700E+02, 0.38058500E+02, 0.11988500E+02, 0.22557700E+01, -.26658200E+02, -.84970000E+01, -.70390700E+01, 0.14845100E+01, -.93880800E+01, 0.78528300E+02, -.33371300E+02, 0.44132300E+02, 0.16221800E+01, 0.22141200E+02, 0.76136800E+02, -.47776000E+02, -.66556400E+02, 0.31641700E+02, 0.49787100E+02, 0.24981300E+02, -.13828300E+01, 0.37561700E+01, 0.13938800E+02, 0.65994700E+01, 0.75715100E+02, 0.27034500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54678200E+01, 0.61780300E+00, 0.13164800E+01, 0.58940400E+00, 0.59540000E+00, -.15323300E+01, 0.14578600E+01, 0.19336800E+00, -.18110500E+00, 0.16799400E+01, 0.13275200E+01, 0.98695500E+00, 0.22685800E+01, 0.34066600E+01, -.10583500E+01, 0.17524200E+01, 0.29169800E+01, 0.94731500E+00, -.45693000E+00, 0.78110700E+00, -.13809300E+01, -.69273000E+00, 0.15820400E+00, 0.34065800E+01, 0.21628300E+00, -.21212300E+00, -.60220500E+00, -.24787100E+00, 0.49493100E+00, -.14089400E+00, -.29990400E-01, -.10819500E+00, -.11280500E+01, -.83822100E+00, 0.21885700E+00, -.98466500E-01, 0.78831800E-01, -.16800600E+00, -.30651600E+00, 0.56511100E+00, -.57797900E+00, 0.35240500E+00, 0.24352700E+01, -.36527900E+00, 0.12265700E+01, 0.27233200E+00, 0.11425600E+01, -.18446200E+01, -.10305300E+00, -.11072800E+00, -.12491500E+01, 0.37699700E+00, -.40109200E+00, -.16835200E+01, 0.44710600E-01, 0.12309800E+01, 0.29365300E+00, -.43715900E+00, 0.18758400E-02, 0.13247300E+01, -.23034100E+00, -.27679200E+00, 0.24153600E+00, -.74448500E-01, -.16631700E+00, 0.31281700E+00, -.61722400E-01, 0.23730000E+00, -.30835800E+00, 0.42339600E-02, -.30295700E+00, 0.33748600E+00, -.99463600E+00, -.44842900E-01, 0.53012800E+00, 0.44385200E+00, -.58102400E+00, 0.43250800E+00, 0.18333600E+00, 0.10429800E+00, -.14095600E-01, -.46645800E+00, -.18994900E+00, 0.19748000E+00, -.22366300E+00, 0.30899200E-02, -.26272900E+00, -.56730900E+00, 0.46121500E+00, 0.12462900E+00, 0.10069100E+01, -.10728100E-01, 0.25737900E+00, -.77538400E-01, -.46197600E+00, 0.62079900E-01, 0.89378900E+00, -.30445800E+00, 0.13145700E+00, -.35196600E+00, 0.89743500E+00, 0.23866500E+00, 0.22737700E-01, 0.22799600E+00, 0.11611200E+00, 0.90636900E-01, -.94599500E-01, 0.64618800E-01, -.29159900E-01, 0.39264500E+00, -.52110700E+00, 0.77515400E-01, 0.93532300E+00, -.68866000E-02, -.24817300E+00, -.54678000E-02, 0.92745300E-01, -.38763200E+00, -.10598200E+00, 0.47763700E+00, 0.19410500E+00, 0.38864800E+00, -.41917800E-01, -.19989700E+00, 0.96542200E-02, 0.19488900E+00, -.99364900E+00, 0.24149700E+00, -.84355900E-02, -.13558800E+00, 0.16452200E+00, 0.46982400E+00, -.16552500E+00, 0.10424900E-02, 0.69982300E-01, -.26608100E-02, 0.12019400E+01, -.20040900E+00, 0.32494100E+00, -.25618900E-01, 0.41840600E+00, 0.92169200E-01, 0.12485600E+03, 0.17805300E+02, -.87397100E+01, 0.16413500E+03, -.88421800E+01, 0.88719500E+02, 0.71460600E+01, -.91828100E+02, -.13218000E+03, -.31451500E+02, -.34199000E+02, -.25706700E+03, 0.18754200E+03, -.95047600E+02, 0.69395500E+02, -.93683400E+02, 0.93615200E+02, 0.14139900E+03, -.82844400E+02, -.19536200E+02, -.11469100E+03, 0.16499000E+03, -.12902300E+03, -.64153200E+02, 0.30794500E+02, -.41203000E+03, 0.32049900E+02, -.26924000E+03, -.20185200E+03, 0.21473100E+03, 0.17709700E+03, 0.24003500E+03, -.18263500E+03, -.81443400E+01, 0.42843600E+03, -.21396000E+03, -.30651400E+03, -.21430500E+03, -.28226200E+02, -.14507600E+03, 0.13728700E+02, 0.31704300E+03, 0.32744400E+02, -.66912200E+02, -.10713300E+03, 0.32806700E+03, -.16368100E+03, -.28096500E+03, -.16429000E+03, -.19586400E+03, -.19919600E+03, 0.99896300E+02, 0.19584700E+03, 0.51674100E+02, -.16538600E+03, 0.81718600E+02, -.33402100E+03, 0.16702400E+03, -.25940700E+03, 0.16702200E+03, 0.29124200E+03, 0.42429700E+02, 0.14930700E+03, 0.10536200E+03, 0.24009100E+03, -.31478900E+02, -.65190800E+02, -.34644000E+03, 0.17222900E+03, -.13734700E+03, 0.17329600E+03, -.84046200E+01, -.17450000E+02, 0.13461300E+03, 0.59401700E+02, 0.20509200E+03, -.57538400E+02, 0.97944000E+02, -.58102900E+03, 0.28819400E+03, 0.16206200E+03, 0.29062200E+03, 0.27527200E+03, -.66757400E+02, 0.72534200E+01, -.14105100E+03, 0.12107700E+03, -.51302400E+02, -.14178100E+03, -.57306900E+03, 0.29013400E+03, 0.37144400E+03, 0.28690500E+03, 0.15495100E+03, 0.59169000E+02, -.20801100E+02, -.62540100E+02, -.22903300E+02, 0.88928900E+02, 0.34015900E+03, -.52064100E+02, 0.30939300E+02, -.44933300E+02, 0.26263900E+02, -.17273400E+03, -.11051900E+03, 0.11093000E+03, -.27016100E+02, 0.16484400E+03, -.13355300E+03, 0.27666100E+03, 0.31790900E+03, -.15820000E+03, 0.25539700E+03, -.15908400E+03, -.52732500E+02, -.28460500E+02, -.18771600E+03, -.10999500E+03, -.24412000E+03, -.33267300E+02, 0.23303200E+02, 0.25726000E+02, -.10484600E+02, 0.23837600E+02, -.14594300E+02, -.60832400E+02, -.59415400E+01, 0.81386900E+01, -.58887800E+02, 0.10728700E+01, 0.23055200E+02, -.13767700E+01, 0.41823400E+01, -.12735400E+02, -.22557400E+01, -.44605800E+02, -.25405100E+01, -.16180400E+02, -.19795700E+02, 0.44979400E+00, -.86451500E+02, 0.36810000E+02, -.66564000E+00, -.15496600E+02, -.37976600E+02, -.33270300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20118800E+01, -.16240500E+00, 0.32051600E-01, -.53967700E+00, -.84793700E+00, 0.54918600E+00, 0.19763700E+00, 0.15429700E-01, 0.67949700E+00, -.10540100E+00, 0.20748300E+00, -.11673100E+00, 0.59302600E-01, 0.95658000E+00, 0.52521000E-01, -.17121200E+00, 0.15406200E+00, 0.10087600E+01, -.35651900E+00, -.46880100E-01, -.24968700E-01, 0.25807000E-01, -.11050600E+00, -.20507000E+00, 0.22317400E-02, -.58213600E-02, -.16193800E+00, 0.14006200E+00, -.28479000E+00, -.30977500E-01, 0.97752300E-01, -.12413300E+00, -.56708500E+00, 0.26045000E-01, -.19018000E-01, 0.14047700E+00, -.13056800E-01, -.30078800E-01, -.36406400E-01, -.48446500E+00, -.19298500E+00, -.11534400E+00, -.47198300E+00, 0.10216700E+00, -.21183900E+00, 0.71975000E-02, -.31219300E+00, 0.78209600E+00, 0.90345700E-01, -.13557100E-01, 0.85008000E+00, -.41950300E+00, -.20788800E+00, 0.28795800E+00, -.84281800E-02, -.51331600E+00, 0.69330400E-02, 0.21245300E-01, 0.71517500E-03, -.24298000E+00, 0.88017800E+00, 0.92385800E-01, -.92118500E-01, 0.32437300E+00, 0.18024700E+00, -.14151100E+00, -.78651400E-02, -.59200100E+00, 0.83481600E-01, -.21135700E-02, -.99164800E-01, -.53569600E-02, -.14172500E+00, -.47338400E+00, 0.12655700E+00, 0.83051400E+00, -.15240700E+00, -.63974100E+00, 0.18042700E+00, -.16568600E+00, 0.19911100E-01, 0.64592800E+00, 0.95288600E-01, -.57928300E-01, 0.29184000E+00, -.13601400E-01, 0.17752100E+00, 0.43874400E+00, 0.28567300E+00, -.21339900E+00, -.80603400E+00, -.82017100E-02, -.22013400E+00, 0.54146800E-01, 0.74501500E+00, 0.45095000E-01, -.79539400E+00, 0.32161000E+00, -.71095400E-02, 0.43644200E+00, -.36009500E+00, 0.79388500E-01, 0.24146500E-02, 0.86253900E-01, -.87625400E-01, -.11830600E+00, 0.47756000E-02, -.33857100E-01, -.13295400E+00, 0.44500300E+00, 0.21165400E+00, -.29689800E-01, -.28178500E+00, -.14122300E-02, 0.85352200E-01, 0.24373800E-01, 0.11938000E+00, 0.27646300E+00, 0.41562500E+00, -.64753000E+00, -.27603200E-01, -.12725100E+00, -.43549700E-01, -.36859300E-01, 0.14450800E-01, -.23002300E+00, -.25979500E-01, -.13429300E-01, 0.50928900E-01, -.17359000E+00, -.21754700E+00, 0.18594100E+00, 0.24575600E+00, 0.40412100E+00, 0.11826300E+00, 0.39920400E-01, 0.15250400E+00, 0.14969900E+00, -.64467700E+00, 0.38665800E+00, 0.37745700E-02, -.20395000E+00, 0.51271100E-01, -.46056500E+03, 0.22798100E+03, 0.85515000E+02, 0.23018000E+03, 0.46849100E+02, -.88250300E+02, 0.16608600E+03, 0.57057100E+02, 0.24521900E+03, -.10357100E+03, 0.23298800E+03, 0.20034500E+03, -.95150500E+02, -.56283100E+02, -.99954300E+02, -.42354500E+02, 0.10687000E+03, -.89432700E+02, 0.23052100E+02, -.12023000E+03, 0.13511200E+03, -.58526000E+02, -.10354100E+03, 0.50150000E+02, -.74361600E+01, 0.51558700E+02, -.80501100E+02, -.15247700E+02, 0.28372100E+01, 0.14628700E+02, 0.60271200E+02, -.39820400E+02, 0.37386100E+02, 0.29552300E+02, -.15234100E+02, 0.79441700E+02, -.15033800E+02, -.31750000E+02, 0.20608900E+02, -.63183800E+02, -.10410500E+02, -.10552200E+02, 0.16990600E+02, -.82827700E+02, -.15134200E+02, 0.65446900E+01, 0.28810400E+02, 0.69906600E+01, 0.86974600E+02, -.75417700E+01, 0.32835500E+02, 0.53974500E+02, -.53110100E+02, -.32681100E+01, -.88136500E+02, -.41568700E+02, 0.21190900E+02, -.17629100E+01, 0.20800600E+02, 0.11669700E+03, -.75641900E+02, 0.29779800E+02, 0.27372400E+02, -.43582700E+02, -.53004300E+02, 0.12624000E+03, -.19296100E+02, 0.93335000E+01, 0.49731000E+02, 0.97401000E+01, 0.35515800E+02, 0.13468400E+02, 0.18543100E+02, 0.47297700E+02, -.42040400E+02, 0.10616800E+02, 0.10986800E+02, 0.15812900E+03, -.77654400E+02, -.42914000E+02, -.78399400E+02, -.49309100E+02, -.45592600E+02, 0.21341300E+02, 0.10454600E+03, -.11062700E+03, -.35053700E+02, -.20832200E+03, -.45375200E+02, 0.25405400E+02, -.89923100E+02, 0.23040400E+02, 0.57509700E+00, 0.11696600E+02, -.32313500E+02, -.10671400E+03, 0.77651900E+02, -.11087500E+02, 0.13727100E+02, -.73380800E+01, 0.30492800E+01, 0.16073000E+02, 0.36245500E+01, 0.10950000E+03, 0.66924500E+02, 0.42635200E+01, 0.81485700E+01, -.40456600E+02, 0.47583900E+02, -.85020300E+02, -.96629200E+02, 0.48087300E+02, 0.17389500E+02, 0.48176700E+02, 0.67349700E+02, 0.60967700E+02, 0.65675500E+02, 0.42999400E+02, 0.46847300E+02, 0.64238800E+02, -.93357800E+02, 0.21549800E+02, 0.38606500E+01, -.24835600E+02, -.14557400E+02, 0.29629900E+02, 0.11163000E+02, -.99032300E+01, 0.28777400E+02, -.73988400E+01, -.63018400E+01, 0.13523800E+02, 0.94206300E-01, 0.75677200E+01, -.89092300E+01, 0.44080200E-01, -.19527200E+02, 0.31732800E+02, 0.25813500E+01, -.97961800E+01, 0.12423300E+02, -.21124200E+02, 0.57508300E+01, 0.12888600E+02, 0.36253200E+02, -.15135400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10913500E+02, -.28961900E+00, 0.77133600E+01, 0.52154200E+01, -.14325100E+01, 0.12062700E+00, -.17755100E+00, -.62795200E+00, 0.54480800E-01, -.99751700E+00, -.26684200E+00, -.16402400E+00, -.28240200E+01, 0.18791800E+01, 0.18809200E+01, -.12106100E+01, -.15671700E+01, 0.24078800E+01, 0.29807000E+01, -.45214600E+00, -.24083600E+00, 0.70773100E+00, -.21484000E+00, 0.39050300E+00, 0.11702800E+00, 0.12479100E+00, -.13416500E+01, 0.78577200E+01, -.51725100E+00, -.13952000E+00, 0.70803300E+00, 0.14233400E+01, -.40996900E+01, 0.82045600E-01, 0.54646600E-01, -.41461600E+00, -.12951000E+00, -.10164800E+01, 0.23290300E+01, -.10512800E+01, -.32351300E+00, 0.13645400E-01, 0.27990300E+00, -.26457200E+00, -.19549000E+01, -.51678100E+00, -.91537600E+00, 0.28574100E+01, 0.13966700E+01, -.31102000E-01, 0.33456900E+01, -.49786800E+00, 0.94655700E+00, 0.50988400E+00, -.48028500E+00, -.22013900E+01, -.69115400E+00, 0.18198800E+01, -.21201400E-01, -.45669300E+01, 0.32411100E+01, 0.18689000E+01, -.22374800E+00, 0.21232400E+01, 0.28471000E+01, -.35829800E+00, 0.11772500E+01, 0.27014100E+00, -.40839700E+00, 0.23479000E-01, 0.12264600E+00, -.62239200E+00, 0.14007800E+01, 0.31375900E+00, 0.36886500E-01, -.18791700E+01, 0.29369400E+00, 0.11397700E+00, -.14768500E+01, -.76856700E+00, 0.15079500E-01, 0.26573900E+00, -.80663200E-01, 0.31812000E+00, 0.83991100E-02, -.97252600E-01, 0.18621600E+01, 0.50170400E+00, 0.89508100E-01, -.55250900E+00, -.34800500E+01, 0.36352500E-01, 0.97611500E+00, -.64350000E+00, -.24085100E+01, 0.86926900E+00, -.24803900E+01, 0.11099400E+01, -.27841000E+00, 0.12453300E+01, -.71056700E-01, -.11465200E+01, 0.14844900E-01, 0.49909600E+00, -.12233000E+01, 0.47415900E+00, 0.14093800E+00, -.18105000E+00, -.68136200E+00, -.12957400E+01, -.29520100E+00, 0.12753900E+00, 0.27872300E+00, -.20586600E-01, 0.21325800E+00, -.11178400E+00, 0.16015900E-01, -.62612500E+00, -.75924700E+00, 0.48836700E+00, -.29648600E+00, 0.12281900E+00, 0.60445800E-01, 0.21647600E+00, 0.13265600E-01, 0.30276900E+00, -.52371400E-01, 0.15764000E+00, -.83122700E-01, -.38364100E-01, 0.55770800E+00, -.96574500E-01, 0.55815600E+00, 0.27041000E+01, 0.35321800E+00, 0.50705100E-01, 0.20231700E+01, -.18490400E+01, 0.28919400E+00, 0.46577200E+00, 0.11703700E+01, -.37383100E+00, 0.45848700E+00, 0.14793800E+01, -.18415600E+02, -.20168200E+03, 0.69283100E+00, 0.87669200E+02, 0.20122200E+03, -.16766900E+03, -.24117800E+03, -.22899000E+03, 0.24241200E+03, 0.52352100E+02, -.11025900E+03, 0.87189400E+02, -.84687900E+02, 0.53379200E+02, 0.19702400E+03, -.59330000E+02, 0.11661900E+03, 0.25059900E+03, 0.24306000E+03, -.17993900E+03, -.11265400E+03, -.62036800E+02, 0.26167100E+02, 0.19240500E+03, 0.30773600E+02, 0.39179700E+02, -.56450100E+01, 0.95912500E+02, -.41173000E+02, -.14896800E+03, 0.84760700E+02, -.25939600E+03, 0.13119600E+03, -.67175300E+02, -.16890400E+03, -.63538500E+02, -.11552800E+03, -.93675400E+02, 0.11738500E+03, 0.15564900E+03, 0.59551300E+02, -.13547300E+03, 0.93048400E+02, -.49258600E+02, 0.22821700E+02, 0.76809500E+01, 0.29576700E+02, -.57057500E+02, 0.12023200E+03, 0.53446000E+02, -.68053000E+02, 0.45861600E+02, 0.75725400E+02, -.35212400E+02, 0.97650400E+03, -.48866700E+03, -.19851800E+03, -.48839500E+03, 0.14988400E+03, 0.43192200E+03, -.28933400E+03, 0.56867900E+02, -.22828300E+03, 0.34838800E+03, -.57262600E+03, 0.14401300E+03, -.70011700E+02, -.18500100E+03, -.72830300E+02, -.16605300E+03, -.36626600E+02, 0.36538000E+02, 0.12224600E+02, 0.87384300E+02, -.41575700E+02, -.28643700E+02, -.28768500E+03, 0.17673800E+03, -.12246000E+03, 0.13842800E+03, -.12023200E+03, -.54035500E+02, 0.16790600E+03, -.95026800E+02, 0.82080300E+02, 0.39476600E+01, 0.48401100E+03, -.77424700E+03, 0.34089600E+03, 0.72298500E+03, 0.38338900E+03, 0.20199400E+03, -.93108400E+02, 0.25485100E+03, 0.12031200E+03, 0.10389000E+03, -.87212800E+02, 0.42664600E+03, -.50284400E+02, -.66018600E+01, -.97749300E+02, 0.25342700E+02, -.67014300E+02, -.10293600E+03, 0.40846900E+02, -.23533100E+02, 0.22683300E+03, -.70837800E+02, 0.14424800E+03, 0.23224700E+03, -.11701100E+03, -.11074300E+03, -.11488100E+03, -.19038900E+03, -.20107900E+03, -.12668300E+03, -.41692800E+02, 0.37622200E+02, -.32851300E+03, 0.34250100E+03, -.48159800E+02, -.65372700E+01, 0.67629500E+02, 0.72574000E+01, -.10602900E+03, -.20959000E+02, 0.21137600E+02, -.10483900E+03, 0.50702400E+02, -.28602100E+01, -.33776400E+02, -.15815500E+02, -.14786200E+02, 0.50974500E+02, -.29917200E+02, 0.11912100E+02, -.22444100E+02, -.39585300E+01, 0.18806800E+02, -.41072000E+01, 0.60359000E+02, 0.43638500E+01, -.46804400E+02, -.64450700E+02, 0.28948600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22882200E+01, -.31315600E+00, 0.30793800E+00, -.13053400E+01, -.55309300E+00, 0.13020200E+01, -.92362300E+00, -.65451900E-02, 0.21598900E+00, -.10646200E+01, 0.24805800E-01, -.27902000E+00, 0.97919500E-01, 0.55050800E+00, -.12344500E+00, -.90820700E+00, -.18797800E+00, 0.51226900E+00, -.98575500E-01, 0.59028500E+00, -.24700100E+00, 0.12402300E+00, 0.89241000E-01, 0.73117500E+00, 0.22882800E-02, -.20657200E+00, -.63805500E+00, 0.10556000E+01, 0.33573300E+00, -.46129000E+00, 0.10963400E+00, -.62735800E-02, -.56722600E+00, -.91299600E-01, -.12504300E-01, -.73237000E+00, 0.17575600E-01, -.82978800E-01, -.22097000E+00, 0.31805200E+00, -.30605200E+00, 0.59465300E+00, 0.10590700E+01, -.21916600E+00, 0.58559500E+00, 0.22219300E-01, -.16677200E+00, -.15937200E+00, -.45474900E+00, -.94982400E-02, -.61024000E+00, -.65824800E-01, 0.66163000E-01, 0.49061800E+00, 0.69870000E+00, -.36777200E+00, 0.51025300E-01, -.27759600E+00, -.20397700E-03, -.39076100E+00, 0.15451500E+00, -.19747800E+00, 0.13781900E+00, 0.10340400E+00, 0.41448500E+00, 0.24410200E+00, -.75624100E-01, -.20782900E+00, 0.72643400E-01, -.86447900E-04, -.37940200E-01, -.27294600E-01, 0.42027200E-01, -.20604200E+00, 0.30428200E+00, -.39050700E+00, 0.18837000E-01, 0.28104900E+00, -.52771800E-01, 0.25202300E-01, 0.36795600E-02, 0.17994700E-01, 0.23776500E-01, -.13486600E-01, -.12612400E-01, -.29486500E-01, 0.26939800E+00, -.16640300E+00, 0.58775400E+00, 0.56577500E-01, 0.75705100E+00, -.25811200E-01, -.21410400E+00, 0.12818100E+00, 0.41901400E+00, -.13254300E+00, -.22392700E+00, -.14320300E+00, 0.20145700E-01, 0.21609100E+00, -.27095500E+00, -.19821100E+00, -.16951000E-01, -.83051400E-01, -.16064600E-01, -.59722400E-01, -.63514300E-01, -.67047600E-01, 0.25276800E+00, -.84046700E+00, 0.18436700E+00, -.23811600E-01, -.19095400E-01, 0.22152200E-01, -.12574900E+00, 0.48403500E-01, 0.15160400E+00, -.27157900E+00, 0.24519100E+00, -.30130700E+00, -.42486500E-01, 0.17709700E-01, 0.84669800E-02, 0.12284900E+00, -.30955900E-01, 0.10485900E+00, 0.18922300E+00, 0.15273600E-01, -.38436900E-01, -.27115700E-01, -.87765600E-01, 0.43416500E+00, 0.20362800E-01, 0.29658800E+00, 0.52789300E-01, -.53970800E-02, 0.13820000E+00, -.95301600E-01, 0.48858700E+00, 0.43053800E-01, -.17309400E+00, -.13617000E+00, -.73137600E-01, 0.40740400E+00, -.27855300E-01, -.12970800E+03, 0.91318500E-01, -.51260900E+02, 0.84233900E+01, 0.18824300E+02, 0.29456700E+02, -.10342500E+02, 0.36599600E+02, 0.10625800E+03, -.90814900E+02, 0.48018700E+02, 0.31456000E+02, 0.45087100E+02, 0.59526100E+00, -.48357500E+02, 0.72564300E+02, 0.64944800E+02, 0.65313100E+02, -.10668000E+03, -.11982700E+02, -.14817900E+03, 0.75569600E+02, 0.34339100E+03, 0.74049300E+02, 0.11719800E+03, 0.14480000E+03, 0.44951100E+01, -.24501800E+02, -.40426100E+02, 0.13323800E+03, -.77813600E+01, 0.45214700E+02, -.22371000E+02, -.10169200E+03, -.22268600E+02, -.18427900E+02, -.10268700E+02, 0.11255400E+02, 0.32390700E+02, 0.83741200E+01, -.50371100E+02, 0.44578800E+01, -.11321200E+03, 0.55910800E+02, 0.64774800E+02, 0.57474700E+02, 0.55925400E+02, 0.96249400E+02, 0.94947000E+01, -.16057200E+02, 0.17458000E+02, 0.76787200E+02, -.78926100E+01, 0.25977800E+03, -.12887100E+03, 0.94364700E+02, -.12991700E+03, -.89716800E+02, 0.75743100E+02, -.76612500E+02, -.44733400E+02, -.14138700E+03, 0.78844700E+02, -.13621200E+03, -.11765300E+02, 0.70809600E+01, 0.89430600E+02, 0.57136900E+01, -.16267700E+02, 0.10571200E+01, 0.17475600E+02, -.15883200E+02, -.75776900E+01, 0.11636800E+02, 0.76863500E+01, 0.57395300E+02, -.26047000E+02, -.43716600E+02, -.29624400E+02, -.69770100E+02, 0.41150200E+02, 0.33480800E+02, 0.56319700E+02, 0.62634700E+01, 0.19992600E+02, 0.85075600E+02, -.14905700E+02, 0.50903000E+01, -.65410000E+02, 0.66573600E+01, 0.24841100E+02, -.11228300E+02, 0.63456600E-01, -.23322600E+02, -.28100600E+02, -.26358900E+01, 0.29980000E+01, 0.70835400E+01, -.63162400E+01, -.36333700E+02, -.35931400E+01, -.17792900E+01, -.26104900E+02, 0.33264200E+01, 0.22424200E+02, 0.60735800E+02, -.30213000E+01, 0.13474600E+02, -.91696400E+01, 0.20110000E+01, -.11911300E+03, 0.48505000E+01, -.20779400E+02, -.12206100E+03, -.95839900E+01, 0.14612300E+01, 0.75249500E+02, -.97772200E+02, 0.65158000E+02, -.16118600E+02, 0.34722900E+01, -.65575100E+01, 0.32005800E+01, -.88883800E+01, 0.11366100E+01, -.31591200E+01, -.91443800E+01, 0.11057100E+02, -.13573200E+02, -.10522600E+02, -.39902700E+01, 0.71450900E+01, 0.11507700E+02, 0.18960500E+02, 0.64334800E+01, -.74187400E+01, -.42043400E+01, 0.36402900E+00, 0.45465300E+02, -.49155900E+01, 0.54029200E+01, -.40066000E+00, -.12802700E+02, 0.31197400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12858900E+02, -.13845900E+01, -.36517500E+01, -.45265800E+00, 0.55683400E+00, 0.12725300E+01, -.16727300E+01, -.32415700E+00, 0.19240700E+00, -.30404500E+01, -.40702100E+00, -.30450700E+01, -.20501800E+01, -.18931800E+01, -.48858900E+00, -.22692600E+01, -.43816600E+01, -.22823700E+01, 0.90173600E+00, -.12022600E+01, 0.49726500E+00, 0.28626900E+00, -.32046300E+00, -.99324800E+00, -.47222600E+00, -.47688600E+00, 0.33839800E+00, 0.30983900E+00, 0.41875300E+00, -.60090700E-01, 0.11715200E+00, -.16917800E+01, -.12752000E+01, -.91721800E+00, -.13166600E+00, -.29381900E-01, -.27378000E-01, 0.12023200E+00, -.23568400E+00, 0.59510000E+00, -.41661400E-01, -.27350500E-03, -.23329100E+01, 0.51522600E+00, 0.56374300E+00, 0.17694600E+00, -.87601300E+00, 0.14397200E+01, -.87225800E+00, -.35835000E+00, 0.70341800E-01, 0.72695000E+00, -.38390100E-01, 0.25730100E+00, -.29821900E+00, -.65672600E+00, -.57282800E+00, 0.22859200E+00, 0.10446500E-01, 0.66795400E+00, 0.16615700E+01, 0.18426800E+01, -.27923000E-01, 0.77694300E+00, -.36651100E+00, 0.16671400E+01, 0.24718400E+00, 0.49640300E+01, -.41863800E+00, -.17975800E-01, -.55385900E+00, 0.59918300E+00, 0.28842400E+01, -.99453800E+00, 0.10791500E+00, 0.78951300E+00, 0.21838600E+00, -.58632800E+00, -.41286000E+00, -.65706500E+00, 0.76634100E-01, -.28020200E+00, -.66706500E+00, -.31624800E+00, -.25030600E+00, 0.46179500E-01, 0.78570700E+00, 0.58417900E+00, -.17982200E+00, 0.28782200E+00, -.19459700E+01, -.41449300E-01, -.68579700E+00, 0.39330700E+00, 0.10966900E+01, 0.17075100E+00, -.67908300E+00, -.51223400E-01, -.28817900E+00, 0.38815100E+00, 0.17743800E+00, -.10325300E+01, -.22552200E-01, -.24609800E+00, -.27756100E+00, 0.20784200E+00, -.10887200E+00, -.18925700E+00, 0.39502200E+00, -.22096000E+01, 0.44329700E-02, -.89052600E-01, -.50880700E+00, 0.24260000E-01, -.30739400E+00, 0.50117100E-01, 0.51420100E+00, 0.30578900E+00, -.50190800E-01, -.14549900E+00, 0.40760900E+00, -.19073500E+00, -.12608500E+00, -.34351200E+00, 0.44323200E-01, -.36817200E+00, 0.42741500E+00, -.16677600E+00, -.35382500E-01, 0.20839500E+00, 0.54468400E+00, -.52720300E+00, 0.19991400E+00, -.55325800E+00, -.32437800E-01, 0.26863900E-01, 0.14593000E+00, -.12060000E-01, 0.25188700E+00, -.72924800E-01, 0.23134400E+00, 0.15053800E+00, 0.11726800E+00, 0.10656000E+01, -.18775000E+00, -.43058800E+00, 0.35330700E+01, -.75245200E+01, 0.94966200E+02, -.55818000E+02, -.98843900E+02, -.95101900E+02, 0.90871400E+02, -.30712400E+03, -.34131800E+03, 0.16890500E+03, 0.72866800E+02, 0.16999200E+03, 0.17809300E+03, -.11242400E+03, 0.13018300E+03, 0.13585700E+03, 0.25571600E+03, -.91176400E+02, 0.59462400E+02, 0.20069900E+03, -.99695600E+02, -.75619900E+02, -.10056500E+03, -.10017800E+03, -.58027900E+02, 0.97260400E+02, 0.12187300E+03, -.11937200E+03, -.57519700E+02, -.11921200E+03, 0.99261700E+02, -.49402300E+02, -.16909700E+03, -.48842600E+02, 0.14588100E+03, 0.62755700E+02, -.29161300E+02, 0.98348900E+02, 0.12946100E+02, 0.12310300E+03, -.11920200E+03, 0.66122200E+02, -.32594900E+02, -.69023800E+02, -.31341200E+02, -.13295300E+03, 0.96389800E+01, 0.10761700E+01, -.94856400E+01, 0.21558800E+02, 0.32816600E+02, 0.18325300E+03, 0.63035300E+03, -.31547400E+03, -.99115200E+02, -.31522600E+03, 0.72626900E+01, 0.18848700E+03, -.19707800E+03, -.11645800E+03, -.25172000E+03, 0.14831100E+03, -.47876100E+03, 0.90109000E+02, -.44816100E+02, -.14413000E+03, -.45334600E+02, -.35755300E+02, 0.25284200E+00, 0.27814500E+01, 0.45091700E+01, 0.31345100E+02, 0.10671100E+02, -.15217700E+03, -.52941700E+03, 0.26618100E+03, 0.16380400E+03, 0.26275400E+03, 0.26960500E+03, 0.11717400E+03, 0.11717400E+03, 0.22202000E+02, 0.12023400E+03, 0.13568400E+03, -.19804000E+03, -.11230600E+03, 0.47848400E+02, 0.34957000E+03, 0.55147500E+02, 0.14592400E+02, -.16327100E+02, -.12271900E+01, -.20683900E+02, -.12040000E+03, 0.24428700E+02, 0.73998400E+02, 0.35880300E+02, -.19051500E+02, -.83153000E+02, -.17875200E+02, -.19738500E+03, -.13329200E+03, 0.76729500E+02, -.83914300E+01, 0.14751400E+03, -.13157000E+03, 0.19111400E+03, 0.15436700E+03, -.76687600E+02, -.14549500E+03, -.76760900E+02, 0.59816900E+02, 0.71958000E+01, -.18781800E+03, -.13667300E+03, 0.32974900E+02, -.29405300E+02, 0.21550400E+02, -.18597000E+02, -.81328600E+01, 0.26755900E+02, 0.24080500E+02, -.18317800E+01, -.15687800E+02, 0.19723800E+02, 0.12568300E+00, -.34915800E+01, 0.13423300E+02, -.14870400E+02, -.39504700E+01, -.10520100E+02, -.19666200E+01, -.20767100E+02, 0.26826500E+02, 0.16668100E+02, -.47340200E+02, 0.10333600E+00, 0.19838700E+02, 0.29379600E+02, 0.23681000E+02, 0.47256800E+01, -.52900400E+02, 0.50743700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21303700E+02, -.46923400E+00, 0.14514400E+02, 0.34372500E+01, -.87294000E+01, 0.23289800E+01, 0.55971400E+00, -.14443400E+01, 0.10462400E+01, -.26789200E+01, -.36937700E+00, 0.66719400E+00, -.49758200E+01, 0.26923600E+01, 0.19975300E+01, 0.15958100E+00, -.15402800E-01, 0.52941000E+01, 0.29352900E+01, 0.74195700E+00, 0.40969600E+01, 0.17129000E+01, 0.44255200E+00, -.17681100E+01, -.53132800E+00, -.17235900E+01, -.45522300E+01, 0.93868200E+01, 0.20468200E+01, -.27251900E+01, 0.10042800E+01, -.20582000E+00, -.10223000E+02, 0.44326000E+00, 0.27968000E+00, 0.88339100E+00, -.72536200E-01, -.10936300E+01, 0.18289500E+01, 0.49278500E+01, 0.95303500E+00, 0.12220700E+01, 0.70475000E+01, -.71984800E+00, 0.88430000E+00, 0.66896200E+00, -.74538300E+00, 0.17257800E+01, -.88386200E+00, -.26787500E+00, -.22465400E+01, -.27933800E+00, -.54671100E+00, -.17092300E+00, -.13787100E-01, -.44630800E+01, -.74334300E+00, 0.13838800E+01, -.17387600E-01, -.23537100E+01, 0.49222000E+01, 0.18239600E+01, -.29696300E+00, 0.92253600E+00, 0.21544200E+01, 0.61799300E+00, 0.30364200E+00, 0.92916600E+01, 0.14920300E+00, 0.59656000E-02, 0.36791200E+00, -.17910300E+00, -.93889200E+00, 0.95728600E+00, -.29091000E+01, 0.87230700E+00, -.52607900E+00, -.73664300E+00, -.77538100E+00, -.20727200E+00, -.21730500E-01, 0.15284600E+01, -.12683900E+01, 0.11406500E+01, 0.65467300E+00, -.11557000E+00, -.11095500E+01, -.80526100E+00, 0.40363300E+01, -.23235300E+01, 0.35806000E+01, 0.27154700E-01, 0.23295100E+00, -.40042400E+00, -.27277700E+01, 0.15433000E+00, 0.59954300E+01, -.19297300E+01, 0.42106300E-01, -.15644400E+01, 0.22598000E+01, -.13056900E+01, 0.42379400E-01, 0.55997900E+00, 0.59334500E+00, -.82847900E+00, -.34983800E+00, 0.12997200E+01, 0.40384400E+00, -.14844700E+01, 0.76723500E+00, 0.76869700E+00, 0.16089900E+01, 0.52638100E-01, -.94914300E+00, 0.10671300E+00, 0.45376300E-01, -.62838500E+00, -.38762600E+01, 0.30701200E+01, -.20576400E+00, 0.13740500E+01, 0.44783100E+00, 0.19620000E+00, -.10160800E+00, 0.52018300E+00, -.11799400E+01, 0.51888600E+00, -.37261700E+00, 0.15428900E+00, -.29811000E+01, 0.51855400E+00, -.12474900E+01, 0.25302400E+01, -.69764900E-01, 0.22681500E+00, -.11458100E+01, 0.97513700E+00, -.30250100E+01, 0.77134600E+00, 0.19467400E+00, -.19470400E+01, 0.15974200E+01, 0.40660800E+01, 0.66945200E-01, 0.36294800E+01, 0.29133000E+00, 0.62434800E+03, 0.43682100E+03, -.42963800E+03, -.60529700E+03, -.28446300E+03, 0.62668100E+03, 0.68373800E+03, 0.11061400E+03, -.86518000E+02, -.27674600E+02, -.57814000E+02, -.21810000E+03, 0.15726100E+03, -.17822900E+01, -.16951700E+03, 0.80075900E+02, 0.15594900E+02, -.45564900E+03, 0.11926000E+04, -.60064700E+03, -.11657200E+04, -.60009000E+03, -.54544400E+02, -.37914000E+03, -.70548500E+03, -.79003400E+03, -.79303000E+03, -.68671600E+02, -.18569700E+03, -.18027700E+04, 0.90629800E+03, 0.16544300E+04, 0.90580500E+03, -.10618100E+04, -.18241700E+03, 0.70393600E+03, -.11205200E+04, -.15481000E+03, -.29135200E+03, 0.11960000E+04, 0.54624700E+03, -.24182400E+03, -.22375400E+03, -.26488900E+03, -.20911600E+03, -.25715500E+03, 0.12722200E+03, -.38865200E+02, 0.10747100E+03, -.35389500E+03, -.65988100E+03, -.14598200E+04, 0.69923200E+03, -.91263000E+03, 0.72974700E+03, 0.44795400E+03, 0.31349000E+02, -.38769200E+03, -.60709100E+02, 0.14243600E+04, 0.94155800E+02, 0.14629200E+04, 0.12560600E+04, -.63680400E+03, -.92235000E+03, -.62888900E+03, -.30699700E+03, -.15359600E+03, -.80688200E+03, -.47549800E+03, -.33566600E+03, -.14516500E+03, -.59859200E+02, 0.14020500E+04, -.70164300E+03, -.39453100E+03, -.70812400E+03, -.14249400E+04, -.81106900E+03, -.41107400E+03, -.95087400E+03, -.70364500E+03, -.36964000E+03, 0.15308300E+04, -.73171200E+03, 0.37823700E+03, 0.76114300E+03, 0.36468000E+03, 0.36230200E+03, -.60773900E+03, 0.12358700E+04, 0.14020500E+04, 0.11655100E+04, -.79508100E+03, 0.29632600E+03, -.74065300E+03, 0.38051900E+03, 0.27497300E+03, 0.37003600E+03, 0.88248600E+03, 0.61106500E+03, -.50914500E+03, -.36568900E+03, -.49988300E+03, 0.54025000E+03, -.11090300E+03, -.17901000E+03, 0.13266500E+03, 0.92645700E+03, 0.90577700E+02, -.45736000E+03, 0.15234900E+03, 0.65575400E+03, 0.28825400E+02, -.61244700E+03, -.64173300E+02, -.23465800E+03, -.93291200E+02, 0.25493100E+02, 0.14683900E+03, -.69388300E+02, -.36078700E+03, -.37303200E+02, 0.56101800E+01, -.36143200E+03, 0.26548200E+03, -.11357100E+02, 0.18864800E+02, 0.49603000E+01, -.44379500E+02, 0.26261200E+03, -.75173200E+02, -.48649900E+02, -.67203000E+02, 0.33389300E+03, 0.53829900E+02, -.37538600E+03, 0.42667500E+02, -.99792800E+02, -.27360100E+03, 0.10517500E+03, -.89392500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39670000E+01, -.48127700E+00, -.11922800E+01, -.44994600E+00, -.10835900E+01, -.16516700E+00, 0.92921300E-02, -.18819900E+00, -.35136000E+00, -.56388000E+00, -.33074000E+00, -.86288500E+00, -.89353700E+00, -.12618400E+01, 0.14342200E-01, -.22047000E+00, -.13495900E+01, -.12654500E-01, -.37225700E+00, -.56119100E+00, 0.28555600E+00, -.33192300E-01, 0.40060700E-01, -.40422300E+00, -.67206500E-01, 0.37805900E+00, 0.19210700E+01, -.33165000E+00, 0.24955200E+00, 0.29146700E+00, 0.30652700E-01, -.53296500E+00, -.91281900E+00, -.12212700E+00, 0.11169700E-01, 0.10294000E+01, 0.13547600E-01, -.38303500E-01, 0.21937300E+00, -.34098700E+00, -.13989400E+00, -.47393600E+00, 0.23472600E+00, -.20212500E-01, 0.10180500E+00, -.46295800E-01, -.65745400E+00, 0.13163700E+00, 0.60677000E+00, -.33142400E-01, 0.20029100E+00, -.25383500E+00, -.27520500E+00, 0.26333900E+00, 0.61174000E-01, -.38959100E+00, -.12432800E+00, 0.59306600E+00, -.24686000E-02, -.78616700E+00, 0.11451500E+01, 0.50209500E+00, -.37601300E-01, 0.46213800E+00, 0.55513800E+00, -.29206400E+00, 0.20874100E+00, 0.88261600E+00, -.21393400E+00, 0.99041200E-03, -.34854900E-01, 0.20016600E+00, -.21465500E-01, -.65651500E+00, -.42617400E-01, 0.46956400E+00, 0.56440400E-01, -.19715100E+00, -.10467400E+00, -.21688000E+00, 0.22525200E-01, -.34240400E+00, -.50547300E-01, 0.17586000E+00, 0.54739700E-01, -.24355100E-01, 0.38453100E+00, -.54646000E-01, 0.44566900E+00, 0.10662200E+00, 0.11953800E+01, -.28734000E-01, -.35486400E+00, 0.21443800E+00, -.11552700E-01, 0.39398000E-01, 0.48452800E+00, -.37790500E+00, -.34026100E-01, -.30076800E-01, 0.55388400E+00, 0.51584000E-01, 0.62665800E-03, -.24060300E-01, 0.72505900E-01, 0.25790200E+00, 0.21519000E+00, -.99777400E-01, -.32935400E+00, -.31464900E+00, -.40986300E+00, 0.11501100E+00, 0.45724500E-01, -.15216800E-01, 0.21817400E-01, -.80867500E-01, 0.10469900E-02, -.36790700E+00, -.78718800E-01, 0.49330400E+00, 0.11783700E-01, 0.74365900E-01, 0.19692700E-01, 0.11420800E-01, 0.22178500E-01, -.66305300E-01, -.25236200E+00, -.17078400E-01, -.39367300E-01, 0.88696100E-01, 0.57882500E+00, -.52323100E+00, 0.80862700E-01, -.18244400E+00, -.45934900E-01, -.20565300E-02, 0.27693500E+00, 0.18744900E-02, 0.48736800E+00, -.14111800E+00, 0.16265200E+00, 0.52309000E-01, 0.76707100E-02, 0.24319900E+00, -.11802500E+00, -.63231500E+00, 0.51345200E-01, -.39326300E-01, 0.87769500E+02, -.23965000E+02, -.70824700E+02, -.90106800E+02, 0.11524500E+03, -.28708700E+02, -.24752100E+03, 0.12305400E+03, -.28076800E+01, 0.12332800E+03, 0.85436600E+02, -.80814400E+02, 0.86007700E+02, 0.79671800E+02, 0.21125700E+03, -.83332200E+02, 0.18935700E+02, 0.15123900E+03, -.74141400E+02, 0.85526800E+01, -.75514600E+02, -.27081900E+02, 0.52627600E+01, 0.40027300E+02, 0.53796300E+02, -.10820800E+03, 0.61223300E+01, -.95924300E+02, 0.23524300E+02, -.11229900E+02, -.59321100E+02, -.11167500E+02, 0.25880900E+02, 0.65679400E+01, 0.94497300E+01, 0.53813600E+02, 0.53742000E+02, -.34186700E+01, -.22489200E+01, 0.40761100E+02, -.19038500E+02, -.39141200E+02, -.19144800E+02, -.61987200E+02, 0.24663800E+01, 0.22503400E+02, 0.18039700E+01, 0.61549500E+02, -.47802100E+01, 0.52412500E+02, 0.35687000E+03, -.17906000E+03, -.10222000E+03, -.17846500E+03, -.66935500E+01, 0.14406700E+03, -.11895400E+03, -.68814300E+02, -.11157200E+03, 0.10393600E+03, -.28217200E+03, 0.15918300E+02, -.73802900E+01, -.72640400E+02, -.81260700E+01, -.45422900E+02, -.20352100E+02, 0.19115800E+02, -.46526900E+01, 0.38684300E+02, -.10199900E+02, 0.16107000E+01, -.14969700E+03, 0.76282100E+02, 0.75825800E+02, 0.73532200E+02, 0.10626800E+03, 0.65471900E+02, 0.15285900E+02, -.50583100E+02, -.33396400E+02, 0.86074700E+02, 0.15622900E+01, -.20986100E+03, 0.98017400E+02, 0.22774400E+03, 0.10440000E+03, 0.75755200E+02, 0.57178200E+02, 0.82629300E+01, 0.25312400E+02, -.42337900E+02, 0.53646900E+02, 0.84224900E+02, -.65252500E+02, 0.32135600E+02, -.19344900E+02, 0.32706800E+02, -.77034800E+02, -.66816300E+02, 0.47736500E+02, -.23682900E+02, 0.11763700E+03, -.60788700E+02, 0.16874400E+03, 0.51588300E+02, -.25764500E+02, -.34473200E+02, -.25558200E+02, 0.15505500E+02, -.39792900E+02, -.10861500E+03, -.87677800E+02, 0.20708200E+02, -.57245400E+02, 0.55122100E+02, -.23067700E+02, -.75145200E+01, 0.26197400E+02, 0.13256200E+02, -.25860500E+02, -.15763600E+02, 0.16979500E+02, -.24757500E+02, 0.23229500E+01, 0.11526300E+02, -.19878900E+02, -.71109300E+01, -.11813600E+02, 0.26786000E+01, -.10698200E+02, 0.12987900E+02, -.22882900E+01, -.23478200E+02, 0.12139100E+02, -.14660400E+01, 0.25513600E+02, 0.12543400E+02, -.10388000E+02, -.43333600E+02, -.82816300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21518100E+01, -.27787500E+00, 0.34093600E+00, -.11987600E+01, -.60572300E+00, 0.11136700E+01, -.72355100E+00, 0.11487600E-02, 0.20164600E+00, -.35325400E+00, 0.51738500E-01, -.18102900E+00, 0.20061500E+00, 0.43578900E+00, -.16825400E+00, -.77017600E+00, -.91758100E-01, 0.51870900E+00, -.25770500E+00, 0.56057200E+00, -.92425900E+00, -.55219900E-02, 0.22989700E+00, 0.17397700E+01, -.28003200E-01, -.90477600E-01, -.65003900E+00, -.64656000E+00, 0.94283300E-01, -.21259000E+00, 0.14712400E-01, -.14275800E+00, -.30884700E+00, 0.12335100E+00, -.43429200E-01, -.67892900E+00, 0.42002900E-03, -.41961200E-01, -.18152500E+00, -.37285300E+00, -.22145000E+00, 0.28703500E+00, -.42627400E+00, -.49613100E-01, 0.42210100E+00, -.21945800E-03, -.42536200E-01, 0.12182000E+00, -.32928900E+00, -.42220100E-01, -.38771500E+00, 0.78607800E-01, 0.13628100E-01, 0.71390100E+00, 0.44770100E+00, -.10002400E+00, 0.10069800E+00, -.14266800E+00, -.11455800E-03, -.26788100E+00, 0.64740100E-01, -.17743100E-01, 0.96823200E-01, 0.17170800E+00, 0.43073100E+00, 0.16600600E+00, -.59818800E-02, 0.51924400E+00, 0.19706100E-02, -.34063400E-03, 0.70774300E-01, 0.14984800E-01, -.69952700E-01, -.31001300E+00, 0.32282100E+00, -.33453000E+00, 0.12996900E+00, 0.37215400E+00, -.14892000E+00, 0.95366400E-01, 0.74089500E-02, -.21145200E+00, -.38502400E+00, -.12068800E+00, -.15205200E+00, 0.22986900E-01, 0.45233500E+00, -.17968900E+00, -.77135200E-01, 0.40695600E+00, -.10323200E+01, -.22193700E-01, -.22800700E+00, 0.10379400E+00, 0.35920600E+00, -.13762800E+00, 0.26730100E+00, -.11046300E+00, 0.11775100E+00, 0.12310500E+00, -.10676800E+00, -.11933100E+00, -.97884200E-02, -.23999000E-01, -.59757800E-01, -.47499400E-01, 0.17263700E+00, -.16460900E-01, 0.23195700E+00, -.23006500E+00, 0.67004300E-01, -.44213000E-01, 0.32145600E-01, 0.68304300E-02, -.77374000E-01, 0.16269100E-01, -.43394600E-01, -.13144900E+00, 0.48094300E+00, -.27599600E+00, -.10982100E+00, -.10195200E+00, 0.32704600E-02, 0.15589600E+00, -.17817000E-01, 0.18263500E+00, 0.86728400E-01, 0.10260000E+00, -.31729400E-01, -.21776100E-01, 0.33249000E+00, 0.13910100E+00, -.30118900E+00, 0.31603800E+00, 0.36271300E-01, -.83982200E-02, 0.91302600E-01, -.31246700E+00, 0.55210000E+00, 0.10258500E+00, -.27216000E+00, -.45700600E-02, -.13336800E+00, -.38462800E+00, 0.16571200E+00, 0.70110500E+00, -.46561300E-01, 0.41938000E-02, -.56485300E+00, 0.36278400E+02, 0.42542500E+02, 0.53876100E+01, 0.88128800E+00, 0.34280900E+02, -.17265900E+03, 0.88723900E+02, -.17832000E+02, 0.86394900E+02, -.38863300E+02, -.69145400E+02, 0.31872400E+02, -.33532800E+02, 0.74719900E+02, -.48419400E+02, 0.18313000E+02, 0.10990100E+03, -.54720200E+02, 0.78574400E+02, -.55032600E+02, -.27818300E+01, 0.82343200E+02, -.28994200E+02, 0.39183300E+02, -.41499400E+02, 0.61512900E+02, -.29627100E+02, -.11633500E+01, 0.11892800E+01, -.11217200E+01, 0.51447800E+00, 0.34800700E+02, 0.55391100E+02, -.44215600E+02, 0.12468100E+02, 0.32996800E+02, 0.24474100E+02, -.29985800E+02, -.34617600E+02, 0.17304300E+02, -.26757200E+01, 0.17122100E+02, 0.30182700E+02, 0.16141900E+02, 0.36222700E+01, 0.34251400E+02, 0.22704700E+02, 0.14590000E+02, 0.48680500E+02, -.18674000E+03, 0.93476900E+02, 0.56797700E+02, 0.93375400E+02, -.36749400E+02, -.32283500E+02, 0.10087200E+03, 0.51676900E+02, 0.49087800E+02, -.35751700E+02, 0.12599900E+03, -.10050100E+03, 0.50579000E+02, 0.93363300E+02, 0.50280700E+02, 0.16762400E+02, 0.56927900E+01, 0.63616200E+02, 0.57081700E+02, 0.37199000E+02, 0.21408900E+01, 0.87687300E+02, 0.11925700E+03, -.57693200E+02, 0.12689000E+02, -.59385000E+02, 0.31521600E+02, 0.33963600E+02, 0.46431700E+01, 0.58528600E+02, -.74888300E+02, 0.10394700E+02, -.72980800E+02, 0.42764600E+02, -.17968300E+02, -.78109300E+02, -.21205300E+02, 0.77989400E+01, 0.71321200E+02, -.47204800E+02, -.20818800E+02, -.20706200E+02, 0.51244100E+02, -.52601400E+02, -.23912700E+02, 0.10120400E+02, -.56690800E+01, 0.11902700E+02, 0.87794100E+01, -.12352100E+02, 0.27060100E+02, 0.22156400E+02, 0.48859900E+02, -.13415700E+02, 0.31264100E+02, -.78107100E+01, 0.29398700E+01, 0.14310500E+02, 0.38604200E+01, 0.57784100E+02, -.16644500E+02, -.22530800E+02, 0.79988200E+01, 0.27270000E+02, 0.49598700E+00, -.61095500E+02, -.29758100E+01, -.56875100E+00, -.94202500E+01, 0.43526600E+00, 0.13346200E+02, 0.32762000E+01, -.31793600E+01, 0.13397100E+02, -.59585500E+01, 0.53237500E+01, -.10530900E+02, -.27745300E+01, -.89955800E+00, -.63855600E+01, 0.79417900E+01, 0.31721300E+00, -.21836400E+01, -.20917900E+02, -.56959300E+00, 0.38832600E+01, 0.69251700E+00, 0.56126800E+01, 0.46484600E+01, -.90686700E+01, -.15167200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42541100E+01, 0.34356000E+00, -.13377300E+01, 0.11615400E+01, -.10847600E+01, -.22558800E+01, 0.20704200E+01, -.93909300E-02, -.37571900E+00, -.21096900E+00, -.12537900E+00, -.55466300E+00, -.14246000E+01, -.10389900E+01, 0.29636400E-01, 0.12512600E+01, -.24822600E+00, -.14494100E+01, 0.27675500E+00, -.76843000E+00, 0.75612200E+00, -.16980000E+00, 0.21553500E+00, -.93730600E+00, 0.24798900E+00, 0.96348100E-01, 0.21225800E+01, 0.13785100E+01, -.11770600E+01, -.81286800E-01, 0.25362400E+00, -.74770300E+00, -.19171100E+00, -.50135200E+00, 0.63587500E-01, 0.60064500E-01, 0.35464000E-01, -.11142400E+00, -.87322000E-01, 0.32276000E+00, -.23670300E+00, 0.11473500E+00, 0.35559600E+00, -.70298800E-01, 0.50154400E+00, 0.16847200E-01, -.25660300E+00, -.35631900E+00, -.13363300E+00, 0.14466400E-01, -.67886000E+00, 0.11682200E+00, -.14098100E+00, -.61268600E+00, 0.13510800E+00, 0.34171600E+00, 0.13759800E+00, -.44218600E-01, -.79265500E-02, 0.24158400E+00, -.80767800E+00, -.33967300E+00, -.35793300E-01, -.10506200E+00, 0.48330200E+00, 0.58405600E-01, -.65008100E-02, -.16583400E+01, 0.17512200E+00, 0.66976900E-02, -.54957500E+00, -.24096500E-01, -.59856900E+00, 0.36046600E-01, -.18166900E+00, -.12247500E-01, 0.41705700E-01, -.14031900E+00, 0.12820400E+00, 0.41352400E+00, -.41901100E-01, -.26292500E+00, -.45199500E-01, -.26802100E+00, -.22960000E-01, 0.22084000E-01, -.42682100E+00, -.13898000E+00, -.57133000E+00, 0.16622800E+00, 0.15243400E+01, 0.17282900E-01, 0.83370700E-01, -.34394300E-01, -.51036600E+00, -.27306400E+00, 0.67599700E+00, -.15116400E+00, -.11081300E-01, -.15242400E+00, -.15009100E+00, 0.32367200E+00, -.29372800E-02, -.10655500E+00, 0.21706700E+00, 0.18312800E+00, -.40395700E+00, -.26445800E+00, -.53678000E+00, 0.11751000E-01, 0.28256900E+00, -.82230000E-01, -.24946300E+00, 0.46148500E-03, -.37390000E-01, 0.11462800E+00, 0.62086600E+00, -.29678200E+00, -.35517400E+00, -.34175800E+00, -.27399200E-01, -.22287600E+00, 0.67200700E-01, 0.11857400E+00, -.58193300E-01, 0.19960900E+00, -.49893300E+00, 0.53385200E-01, 0.31020200E-01, -.22259900E-01, -.65830500E+00, 0.16471600E+00, 0.39486900E+00, 0.82012300E-02, 0.36950100E-01, -.13106600E-02, 0.52859100E+00, -.20409000E-01, 0.10170700E+01, 0.49955300E-02, 0.50864600E-02, 0.69242500E-01, 0.18975600E+00, 0.18780900E+00, -.30995300E-01, 0.40996200E+00, 0.17664600E-01, 0.10778100E+00, -.46845900E+00, -.48717700E+00, -.89558000E+02, -.53475400E+02, -.43245500E+02, -.17472800E+03, -.92461000E+02, 0.48384600E+02, -.84323300E+02, 0.46217500E+02, 0.87973700E+02, -.93190600E+02, 0.43422300E+01, 0.84939300E+02, 0.10046500E+03, -.55010600E+02, 0.17874000E+02, -.19330900E+03, 0.97720500E+02, 0.13037600E+03, 0.96858000E+02, -.10551900E+03, 0.39478200E+02, 0.17209500E+03, 0.13163600E+03, 0.52607900E+02, -.39232100E+01, 0.13401600E+03, 0.27538400E+03, -.13818600E+03, -.23337100E+03, -.13778300E+03, 0.18863800E+03, 0.57634200E+02, -.11916100E+03, 0.23671000E+03, 0.85395900E+02, 0.72505200E+02, -.20363500E+03, 0.82282200E+02, -.44034200E+02, -.89810800E+02, -.41251000E+02, -.15288300E+02, -.52909000E+01, -.72457200E+01, 0.52035200E+02, 0.19841000E+02, 0.52947300E+01, 0.11100300E+03, 0.14976400E+03, -.71852700E+02, 0.16770400E+03, -.74883500E+02, 0.41605400E+02, 0.10306900E+03, 0.12403500E+03, 0.14173000E+03, -.14250000E+03, 0.36276800E+02, -.24722100E+03, -.28420000E+03, 0.14318200E+03, 0.10134400E+03, 0.14208700E+03, -.13696300E+02, -.57597000E+01, 0.20145600E+03, 0.14055800E+03, 0.15602900E+03, -.62528100E+01, 0.10073800E+03, -.47563300E+03, 0.23785300E+03, 0.14154200E+03, 0.23774800E+03, 0.29288300E+03, 0.10759000E+03, 0.12634700E+03, 0.50840600E+02, 0.14510700E+03, 0.54452100E+02, -.11160500E+03, -.20578800E+03, 0.98030000E+02, 0.17816700E+03, 0.10273200E+03, 0.24714600E+02, 0.17170600E+03, -.13077000E+03, -.14239000E+03, -.13980600E+03, 0.19829000E+03, 0.75514500E+02, 0.82643000E+02, -.42211600E+02, -.93835200E+02, -.41252400E+02, -.18427200E+03, -.14459700E+03, 0.12968100E+03, 0.61085700E+02, 0.19951200E+03, -.13318400E+03, 0.11817100E+03, 0.60784400E+02, -.34580200E+02, -.11753700E+03, -.30357200E+02, 0.64941200E+02, -.11622300E+03, -.17250800E+03, -.71015900E+02, 0.15681300E+03, -.86453900E+02, -.32364800E+02, -.26450500E+01, -.14405100E+02, -.32032500E+01, 0.11561800E+02, 0.36846200E+02, -.64826700E+01, 0.10158400E+02, 0.37917000E+02, -.47781400E+02, 0.15103100E+02, -.28023200E+02, -.83539000E+01, -.22779400E+01, -.48264500E+02, -.20250900E+02, 0.62992700E+01, 0.12914700E+02, -.84526700E+02, 0.42050700E+01, 0.43826300E+02, 0.27249900E+02, 0.21963500E+02, 0.32828000E+02, -.54750400E+02, 0.14793600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22994600E+02, 0.28384400E+01, 0.86633100E+01, 0.11854100E+02, 0.93618900E+01, -.87559100E+01, 0.46000200E+01, 0.84507600E+00, -.23459900E+01, 0.83226600E+01, 0.32911500E+01, 0.40960200E+01, 0.48179800E+01, 0.93208400E+01, -.14936600E+00, 0.51676300E+01, 0.10265600E+02, 0.42106600E+01, 0.39008500E+01, 0.14632300E+01, -.76371200E+01, -.15756200E+01, 0.41879800E+00, 0.74125800E+01, 0.97548600E+00, -.13742400E+01, -.13663600E+01, -.28201000E+01, -.30381400E+01, -.56368400E+00, 0.95921600E-01, 0.23662100E+01, 0.29363300E+01, -.35912900E+01, 0.10082000E+01, 0.42144000E+00, 0.15915300E+00, 0.10984400E+00, 0.88926600E+00, -.12079700E+01, 0.10579300E+01, 0.53311000E+00, -.13027500E+01, -.11114200E+01, 0.60123800E+00, -.73043700E+00, 0.40682200E+01, -.80007800E+01, 0.38164100E+01, 0.87480600E+00, 0.92947300E+00, -.18028800E+01, 0.16022700E+00, -.41398800E+01, 0.23873100E+01, 0.64029200E+01, 0.18762700E+01, -.29724400E+01, 0.18681800E-01, 0.55070600E+01, -.12253700E+02, -.52405600E+01, 0.13906500E+01, -.36072700E+01, -.97103300E+00, -.40457400E+00, -.11657200E+01, -.18647200E+02, 0.11618900E+01, 0.56329700E-02, -.36009700E+00, 0.16856300E-01, -.16657900E+01, 0.16887500E+01, 0.31938000E+01, -.18050800E+01, -.45314300E+00, 0.29282800E+01, 0.30941400E+01, 0.78115500E+00, -.11556400E+00, 0.88680000E+00, 0.15709600E+01, -.19360900E+01, -.98565300E+00, 0.51983700E+00, -.25623100E+01, 0.93401500E+00, -.28359800E+01, -.13666900E+00, -.50301500E+01, 0.75013900E-01, 0.66468400E+00, -.93305000E+00, 0.39600600E+01, -.73860900E+00, -.80771000E+01, 0.36954800E+01, -.93792800E+00, 0.74111200E+00, -.42577800E+01, -.10617800E+01, -.22559000E+00, -.15774500E+01, 0.95255200E+00, -.30629300E+01, -.29256900E+01, 0.63504400E+00, 0.10045600E+01, 0.44119600E+01, 0.12294900E+01, -.51452000E+00, -.23147200E+00, 0.58856300E-01, 0.57362100E+00, 0.43244900E+00, 0.18349800E+01, 0.12926300E+01, 0.59949900E+01, -.41207500E+01, -.19519600E+00, -.23871700E+01, 0.34428500E+00, 0.49074700E+00, -.25595700E+00, 0.83853100E+00, 0.48978300E+00, -.17121600E+00, -.29429000E+00, 0.38260800E-01, -.53702400E+01, 0.27097000E+01, 0.32211400E+01, 0.43897900E+01, 0.33229100E+00, 0.25236700E+00, -.24102300E+01, 0.20033000E+01, -.82506100E+01, 0.27102500E+01, -.15580700E+01, -.13247300E+00, -.22040300E+01, -.25069300E+01, 0.61364200E+00, 0.22574300E+01, -.36287100E+00, -.49241300E+00, -.25258100E+01, 0.12730700E+01, 0.13804700E+01, 0.47039000E+03, 0.15516100E+03, 0.12079900E+04, 0.91242800E+03, -.47577600E+03, 0.25032700E+03, -.45586100E+03, -.32103400E+03, 0.61053600E+03, -.73976800E+03, -.13719700E+04, -.10323600E+04, 0.70062600E+03, -.58357200E+03, 0.53094800E+03, -.27843900E+03, -.77601200E+03, -.26890700E+03, 0.19282900E+02, -.73251800E+02, -.77979600E+03, -.66957600E+03, -.74279900E+02, 0.63919600E+02, -.42385100E+03, -.14150300E+04, 0.71308500E+03, 0.99174600E+03, 0.70813900E+03, -.11749400E+04, -.73004800E+03, 0.66213400E+03, -.86423700E+03, 0.20201100E+03, -.86705100E+03, 0.14330700E+04, 0.11264600E+03, -.28002100E+02, -.27313500E+03, -.56583600E+02, 0.10368400E+03, -.30378100E+03, 0.32070000E+03, 0.29384000E+03, 0.53141800E+02, -.33127800E+03, -.73709800E+03, -.27291000E+04, 0.13435900E+04, -.61226900E+03, 0.13646100E+04, 0.39559200E+03, -.11402900E+04, 0.49315100E+03, 0.12330500E+03, 0.11262300E+04, -.73254900E+03, 0.23285400E+04, 0.17172200E+03, -.97877100E+02, -.28489800E+03, -.85460200E+02, -.23544100E+03, -.26664800E+03, -.52530300E+03, -.62447800E+03, -.69780400E+03, -.15709800E+03, 0.43649400E+03, 0.21422800E+04, -.10708300E+04, -.94120000E+03, -.10694800E+04, -.15067700E+04, -.11571600E+04, -.60883000E+03, -.65674300E+03, -.12185300E+04, -.67698800E+03, 0.21428100E+04, -.14850500E+04, 0.78495900E+03, -.38821900E+02, 0.74644200E+03, 0.52775200E+03, -.17933000E+03, 0.66110000E+03, 0.80602700E+03, 0.14954900E+04, -.54698800E+03, 0.88673600E+03, -.86773500E+03, 0.46616100E+03, 0.29820100E+03, 0.43334200E+03, 0.11803200E+04, 0.92401900E+03, -.45123700E+03, -.33880200E+03, -.91377300E+03, 0.81691500E+03, -.78958700E+03, -.14582700E+03, 0.10637800E+03, 0.70917900E+03, 0.72157800E+02, -.24057400E+03, 0.60657700E+03, 0.57593300E+03, 0.17376000E+03, -.58370900E+03, 0.39603900E+03, -.16237200E+03, 0.95843700E+02, 0.22012400E+02, 0.13281400E+03, -.13885300E+03, -.42580400E+03, 0.33254100E+01, -.21885500E+02, -.43024700E+03, 0.35384800E+03, -.66436600E+01, 0.11561600E+03, -.25959300E+01, -.16649300E+01, 0.34655500E+03, 0.55424800E+02, -.83606700E+02, -.98245900E+02, 0.43719600E+03, -.17923800E+02, -.31643200E+03, -.21589800E+03, -.73292100E+02, -.30945800E+03, 0.29905600E+03, -.14018900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.88779100E+01, -.10268100E+01, -.19453000E+01, -.22590700E+01, -.24002700E+01, 0.29419300E+01, -.19866400E+01, -.31559200E+00, 0.54592100E+00, -.24557800E+01, -.15519100E+01, -.12820800E+01, -.30848300E+01, -.37537400E+01, 0.15145800E+00, -.15682400E+01, -.40581700E+01, -.18177200E+01, -.15992800E+00, -.13467300E+01, 0.25754100E+01, 0.69297500E+00, -.19503300E+00, -.54367300E+01, -.49826000E+00, 0.27976900E+00, 0.11027700E+01, 0.21672600E+00, 0.12184100E+01, 0.52231700E+00, -.39450400E+00, -.83557900E+00, 0.18750400E+01, 0.37863600E+01, -.48313300E+00, -.26691500E+00, 0.14449700E-01, 0.37192200E+00, -.84488700E+00, -.12489900E-01, 0.44102100E+00, 0.11907500E+00, -.45704800E+01, 0.71744200E+00, -.11381200E+01, 0.27961300E+00, -.19981900E+01, 0.31485400E+01, -.28696600E+00, 0.21541100E+00, 0.13853300E+01, 0.82375500E-01, -.11741500E+00, 0.98132700E+00, 0.93881100E+00, -.27208600E+01, -.73160300E+00, 0.18920400E+01, -.16494400E-01, -.55021400E+01, 0.41011000E+01, 0.13282600E+01, -.61068700E+00, 0.34255900E+00, 0.70951800E+00, 0.11890700E+00, 0.11350400E+00, 0.28332400E+01, 0.24642500E-01, 0.17468500E-01, 0.78237800E+00, -.13577800E-01, -.13587600E+01, -.16943400E+01, -.20736500E+00, 0.82863100E-01, 0.82991300E+00, -.10726000E+01, -.13925600E+01, 0.59098500E+00, 0.12528400E-01, -.43022900E+00, -.74773900E+00, 0.15451300E+00, -.28520600E+00, 0.36913100E-01, -.22161300E+00, -.11911700E+01, 0.83800200E+00, 0.42348700E+00, 0.44032200E+01, -.60815400E-01, 0.83509000E+00, -.48067700E-01, -.23990100E+01, -.21953800E+00, 0.33996600E+01, -.15796600E+01, 0.77837800E+00, -.36605100E+00, 0.82029400E+00, 0.70131500E+00, 0.47002200E-01, 0.67001100E+00, -.14725500E+00, 0.34053100E+00, 0.13244600E+01, 0.57607700E-01, -.10053400E+01, 0.66736100E+00, -.23880900E-01, 0.34129000E+00, -.14372400E+00, -.71663100E-01, 0.36894600E+00, -.40205900E-01, -.75792500E+00, -.12561200E+00, -.19228200E+01, 0.89586700E+00, -.31459700E+00, 0.38579800E+00, 0.12517200E+00, -.60980900E-01, -.91645800E-02, -.67762300E-01, 0.11243700E+01, 0.33965300E-01, 0.28583300E+00, -.18973600E+00, 0.12370800E+01, -.12149200E+01, -.23608400E+00, -.12098200E+01, -.29065900E+00, -.17345900E+00, 0.11211400E+01, -.11499200E+01, 0.40673700E+01, -.82030400E+00, 0.10157700E+00, 0.15354500E+00, 0.99365200E+00, 0.98072600E+00, 0.35424100E-01, 0.30924700E+01, 0.99265200E-01, 0.31243500E+00, 0.94459000E+00, 0.13853300E+01, -.13296300E+01, -.75109700E-01, -.15167600E+03, -.51031700E+03, 0.11406200E+02, -.45683600E+01, -.16142400E+03, -.51417300E+01, 0.45463300E+02, -.25732400E+03, 0.12052000E+03, 0.36942900E+03, 0.76464800E+02, -.15046000E+03, 0.28388400E+03, -.43799600E+03, 0.22131300E+03, -.65777100E+02, 0.22059100E+03, -.16789600E+02, -.22192400E+03, 0.29906900E+03, 0.15334800E+03, 0.27586700E+03, -.26301600E+03, 0.28252900E+03, 0.73991500E+03, -.37642700E+03, -.25351800E+03, -.37110000E+03, 0.71448100E+03, 0.19359200E+03, -.29664100E+03, 0.40886800E+03, -.79360900E+02, 0.31565200E+03, -.65015500E+03, 0.40830900E+02, -.34728300E+02, 0.19679100E+03, -.22498600E+02, 0.30598500E+02, 0.70059600E+02, -.18846600E+03, -.15674400E+03, -.37167500E+03, 0.11301000E+03, 0.17398900E+03, 0.10701600E+04, -.52268400E+03, 0.49837700E+03, -.53504200E+03, 0.91654900E+01, 0.10687600E+03, 0.73825500E+02, 0.32616900E+03, -.53559600E+03, 0.14219500E+01, -.85536000E+03, -.51035000E+02, 0.28472400E+02, 0.16698800E+03, 0.25729100E+02, 0.12046200E+03, 0.78701800E+02, 0.23124200E+03, 0.34212700E+03, 0.16751500E+03, 0.13275000E+02, -.20083300E+03, -.15282700E+04, 0.75443900E+03, 0.55508200E+03, 0.76552800E+03, 0.78595000E+03, 0.23830500E+03, 0.31298000E+03, 0.12386200E+03, 0.81210000E+03, 0.61844700E+02, 0.52550100E+02, 0.91352000E+03, -.46871700E+03, 0.70758300E+02, -.45660700E+03, -.50177700E+03, -.24058100E+03, -.15166000E+03, -.19705700E+03, -.46047500E+03, -.85981500E+02, -.41127700E+03, 0.57381000E+03, -.29199200E+03, -.67910500E+02, -.28651500E+03, -.52590400E+03, -.23109600E+03, 0.12938500E+03, 0.16373800E+03, 0.25165000E+02, -.21796000E+03, -.20579100E+03, -.52132300E+02, 0.13470000E+02, -.45016900E+03, 0.25806100E+02, 0.15995000E+02, 0.10079400E+03, -.13616400E+03, 0.75314000E+02, 0.31015900E+03, 0.88652900E+02, 0.65863500E+02, 0.26107700E+02, -.14803800E+02, -.37838900E+02, 0.32591900E+02, 0.23404200E+03, -.27228300E+00, 0.11776300E+02, 0.23427600E+03, -.18851900E+03, 0.77167500E+01, -.56351100E+00, 0.62611500E+01, 0.21164500E+02, -.18620600E+03, -.25187000E+02, -.84091800E+00, 0.47577200E+02, -.17522700E+03, -.15858600E+02, 0.11375300E+03, 0.56851700E+02, 0.35770600E+02, 0.14391700E+03, -.41561600E+02, 0.19332500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16408600E+02, -.19089200E+01, -.55098800E+01, -.91848400E+01, -.71828800E+01, 0.63679100E+01, -.32175100E+01, -.63895100E+00, 0.15161200E+01, -.58172800E+01, -.30527900E+01, -.25061000E+01, -.36489800E+01, -.78136300E+01, -.73994100E-01, -.32399000E+01, -.72093500E+01, -.44268200E+01, -.32261900E+01, -.11944900E+01, 0.61838600E+01, 0.10031700E+01, 0.12916800E+00, -.58647300E+01, -.11174400E+01, -.33312300E+00, 0.16124600E+01, -.24726500E+01, 0.12070300E+01, 0.11915600E+01, -.39411800E+00, -.64365900E+00, -.40525000E+01, 0.35759300E+00, -.17831400E+00, 0.17222700E+01, -.26049400E-01, -.96303500E-01, 0.80474000E-01, -.14964900E+00, -.10824200E+00, -.21521200E+00, -.21224200E+01, 0.22353400E+00, 0.26069500E+01, 0.23582900E+00, -.73925500E+00, 0.46049900E+00, 0.61313200E-01, -.29739400E+00, -.21278600E+01, -.80710300E+00, -.77012900E-03, 0.59015700E+00, -.20522500E+01, -.30490300E+01, -.95782100E+00, 0.68021500E+00, -.11113800E-01, 0.59915500E+00, 0.56058600E+01, 0.25516100E+01, -.18167000E+00, 0.17822300E+01, -.57702900E-01, 0.10945600E+01, 0.16016000E+00, 0.70328300E+01, -.25158800E+00, 0.24228500E-03, -.11242600E+01, 0.36659900E+00, -.51743000E+00, -.67827200E+00, -.13165500E+01, -.81354000E+00, 0.53300300E+00, 0.12199600E+01, -.77855100E+00, -.34432700E+00, 0.22260500E-01, -.17105600E+01, -.18157700E+01, 0.26182700E+00, -.27667800E+00, 0.35150000E+00, 0.60791700E-01, -.12263200E+01, 0.24548900E+01, -.10035100E+01, 0.61353700E+01, -.83374000E-01, 0.27854700E+00, -.20648700E+00, -.29149500E+01, -.23819300E+00, 0.53237500E+01, -.19978800E+01, 0.67724400E+00, -.13936800E+01, 0.26079100E+01, 0.81178600E+00, 0.65659300E-02, 0.30808500E+00, 0.26190800E+00, 0.84799700E+00, -.44889600E+00, -.30986100E+00, -.46334700E+00, 0.21985800E+01, 0.44242800E+00, 0.16801800E-01, -.63489400E+00, -.16662500E+00, -.39501500E+00, 0.75334400E-01, 0.36355000E+00, 0.33094000E+00, -.93689900E+00, 0.16571700E+00, 0.10871100E+01, 0.41892100E+00, -.42651800E-01, 0.13214200E+00, 0.20020200E+00, -.21679300E+00, 0.69379300E+00, 0.29006800E+00, -.93749400E-01, -.21634400E+00, -.11003300E+01, -.11881200E+01, 0.82638800E+00, -.29256900E+00, 0.35439200E+00, -.88093800E-01, -.55658900E+00, 0.23400400E+01, 0.11296000E+01, 0.17515900E+00, -.98654100E+00, -.10157600E+01, 0.22877600E-01, -.83637200E+00, -.61765500E+00, 0.12071000E+01, -.13388200E+00, 0.19680900E+00, -.17223700E+01, 0.18426100E+01, 0.24100200E+00, -.89183300E-01, -.57872200E+00, -.78339900E+03, 0.33898200E+03, -.18014300E+03, -.57698500E+02, -.16855200E+03, -.11462500E+03, 0.71008700E+01, -.15419200E+03, -.70265400E+02, -.16281200E+03, 0.11168400E+03, 0.63204800E+03, -.16500800E+03, 0.86829800E+02, -.43720300E+03, 0.86070200E+02, -.18211500E+03, -.34086400E+03, 0.10166900E+03, -.37799400E+02, 0.94975100E+00, -.31573000E+03, 0.30470900E+03, -.10849700E+03, 0.46791900E+02, 0.49271800E+03, 0.52617000E+02, 0.28801600E+03, 0.21328900E+03, -.13788600E+03, -.16866600E+03, -.37054800E+03, 0.41064900E+03, -.40375500E+03, 0.79893100E+03, -.41021400E+03, -.87139700E+02, -.40217900E+03, -.24745600E+03, -.30405000E+03, -.72586300E+02, -.64869600E+02, -.49730100E+03, -.15233300E+03, -.34973500E+03, 0.70091700E+03, -.34231900E+03, 0.21407700E+03, -.35040200E+03, -.15449500E+03, -.24879900E+02, -.23571800E+03, -.11582000E+03, -.37088300E+03, 0.88529900E+01, -.33616700E+03, 0.92012200E+03, -.45731100E+03, -.34166700E+03, -.45976000E+03, -.35213900E+02, 0.92037800E+02, -.29488700E+03, 0.46781800E+02, -.28090900E+03, 0.10075200E+03, -.68484400E+03, -.78380300E+03, 0.37397400E+03, 0.43972300E+03, 0.39404100E+03, 0.28486800E+03, 0.10151300E+03, 0.38749300E+02, -.99601500E+02, 0.15127500E+03, 0.27938800E+03, -.54003500E+03, 0.31915200E+02, -.51332300E+02, 0.31929800E+03, -.16262500E+02, -.25066400E+03, -.40601200E+03, 0.42432200E+03, 0.22256800E+03, 0.20066700E+03, -.33476200E+03, -.12706900E+03, 0.49932400E+03, -.24661900E+03, -.13760700E+03, -.24913700E+03, -.16495400E+03, -.59564100E+02, -.54829700E+02, 0.79443500E+02, -.11413000E+03, -.12951500E+03, -.26770100E+03, -.32941700E+03, 0.15824000E+03, -.37029900E+03, 0.16431200E+03, 0.30618400E+03, 0.20934400E+03, 0.14146500E+03, 0.53292300E+02, 0.25591200E+03, 0.13752900E+03, -.15598800E+03, 0.10021700E+03, -.48926800E-01, -.29320600E+02, -.13187900E+02, 0.76134500E+01, 0.85311300E+01, -.32339100E+01, 0.87864000E+01, -.72143200E+02, 0.13464300E+02, 0.10901700E+03, 0.29462900E+02, 0.21095900E+02, -.70065400E+02, -.12982700E+02, -.51356000E+02, 0.77456100E+02, 0.22841200E+02, -.60135800E+02, 0.64002700E+02, -.37353800E+00, 0.88422700E+01, -.27979500E+02, 0.10578000E+03, -.10514700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.51912100E+01, -.56728800E+00, -.31948200E+00, 0.20188900E+00, -.90665000E+00, -.31893100E+00, -.11407300E+00, -.26746300E+00, -.52093200E+00, -.35851400E+00, -.10461400E+00, -.58840900E+00, -.50945400E+00, -.19211700E+01, -.11086400E+00, -.11321200E+00, -.24724700E+01, -.24515600E+01, -.32579800E+00, -.15025500E+01, 0.10119800E+01, -.16285400E-01, -.31202200E+00, -.18153200E+01, -.22191300E+00, 0.56920700E+00, 0.52856400E+00, 0.33335600E+01, 0.11795900E+00, 0.85457300E+00, 0.52570000E-01, -.84390300E-01, -.18546000E+01, 0.25911900E+00, -.14491200E+00, 0.20665700E+00, 0.25058600E-01, -.25584600E+00, -.35958000E+00, 0.78022800E+00, -.79314500E+00, -.70639400E+00, 0.31020600E+00, -.58418700E-01, 0.91762400E+00, -.10352900E+00, -.10785800E+01, -.14678700E+00, 0.39873800E+00, 0.18330500E-01, 0.19121400E+01, -.64588700E+00, -.38814700E+00, -.26238000E-01, -.28461500E+00, 0.18234900E+00, -.14628300E+00, 0.89867300E+00, 0.45566000E-02, -.26465500E+00, 0.57867900E+00, 0.13017200E+01, -.12979200E+00, -.29525100E-01, -.60194700E-01, -.37018300E+00, 0.92010200E-01, 0.26352000E+00, -.80848400E-01, -.55304800E-03, 0.24409800E+00, -.13629500E-01, -.13257000E+00, 0.78110200E-01, -.45158800E-01, 0.84693300E-01, -.21894300E-01, -.35474900E+00, -.16548200E+00, -.13511200E+00, 0.21379700E-01, -.24349700E+00, 0.40617400E+00, 0.50898300E+00, 0.37129700E-01, -.17295400E+00, -.57102300E-01, -.95094500E-01, 0.33690700E+00, 0.35334900E-01, 0.86723000E+00, 0.71647100E-02, 0.24652200E+00, 0.41900800E-01, 0.19757700E+00, 0.47719400E+00, 0.32424400E+00, -.18784300E+00, -.18917000E+00, -.16247700E+00, 0.83668000E+00, -.43021500E-01, 0.47131400E-01, 0.73967200E-01, 0.29755100E+00, 0.13173300E+00, -.23797100E+00, 0.21136200E+00, 0.86602400E-01, -.23748600E+00, 0.10099200E+00, 0.75280700E-01, 0.12852800E+00, 0.23648700E-01, -.28377900E-01, 0.21962600E-01, -.37118200E+00, -.14383900E+00, 0.70087600E+00, -.48797400E-01, 0.11398300E+00, 0.30997300E+00, 0.16824100E-01, -.10853900E+00, -.37274700E-01, 0.58586500E-01, 0.29765500E-01, 0.57003000E-01, -.95537300E-01, -.37799000E-01, -.76475600E+00, 0.11281000E+01, 0.84335700E-01, 0.42827800E+00, -.11035700E+00, -.16215200E-01, 0.13737300E-01, -.58981000E-01, -.35011400E+00, -.18590900E+00, 0.47780700E-01, -.14219000E+00, -.25162200E+00, 0.62589100E+00, -.10594800E+00, -.22537700E+00, 0.53049100E-01, -.80829700E-01, 0.30496700E+00, -.10655800E+01, -.16441600E+00, -.98180000E-01, -.13301000E+00, -.80048800E-01, 0.35437500E+03, -.17775000E+03, -.75758700E+02, -.17732800E+03, -.72569600E+01, 0.10791200E+03, -.17527400E+03, -.78252300E+02, -.14300400E+03, 0.12877100E+03, 0.41331800E+02, -.23277000E+03, 0.11619100E+03, -.11188200E+03, 0.11621000E+03, -.45109200E+01, -.11001600E+03, 0.26137100E+02, -.10675500E+03, 0.74939500E+02, -.43472900E+02, 0.28868700E+02, 0.44659200E+00, 0.20453300E+00, 0.80323600E+02, 0.61962400E-01, -.16809600E+02, -.89251100E+02, 0.39232000E+01, 0.14320700E+01, 0.68882600E+01, -.64326500E+02, 0.68147600E+02, 0.15541500E+03, -.75628800E+02, -.46665700E+02, -.77319300E+02, -.53159600E+01, -.79000800E+02, -.45406600E+02, -.45269300E+02, -.99703700E+02, -.35418500E+02, -.13322000E+03, 0.61314200E+02, -.31050100E+02, -.10201400E+03, -.30660800E+02, 0.10485400E+03, 0.66885700E+01, 0.12900300E+02, 0.14712400E+03, 0.29135400E+02, -.35813700E+02, -.94920100E+02, 0.16513900E+03, -.83033700E+02, -.12371600E+03, -.82581000E+02, -.70627900E+02, -.39193200E+02, -.39532200E+02, -.10482200E+02, -.65626400E+02, -.46500800E+02, -.36858300E+02, -.54248400E+02, 0.27873800E+02, -.65446600E+02, 0.26754100E+02, -.59493800E+02, -.14123800E+03, -.11090800E+03, -.14992200E+03, -.13746500E+02, -.10048300E+03, 0.17623700E+03, -.22194900E+03, 0.11354900E+03, 0.90769600E+02, 0.11129000E+03, 0.49765600E+02, 0.26153900E+02, 0.25803100E+02, 0.54562600E+02, 0.10007200E+03, -.85153600E+01, 0.12856600E+03, 0.74974400E+02, -.34306400E+02, 0.28383000E+02, -.37449700E+02, 0.66765700E+01, 0.26615000E+02, 0.32406300E+01, -.30633200E+02, -.69855400E+02, 0.21144000E+02, -.60315100E+02, -.15084300E+03, 0.76708200E+02, 0.80940600E+02, 0.75417600E+02, -.71773000E+02, 0.21711000E+02, 0.11311400E+03, 0.51986600E+02, 0.54674600E+02, -.86968200E+01, 0.22271400E+03, 0.29095100E+02, -.81987100E+01, 0.29930400E+02, -.14437700E+02, -.50354800E+02, -.11039600E+02, 0.13050000E+02, -.50618300E+02, 0.33824800E+02, 0.70611500E+01, 0.29592900E+02, 0.17999200E+01, 0.32842200E+01, 0.33286400E+02, -.13332600E+02, -.24092900E+02, -.68640300E+01, 0.32024100E+02, -.10345000E+00, -.36674800E+02, 0.73612000E+01, -.61538400E+01, -.35628700E+02, 0.32576300E+02, -.18978600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12674500E+02, -.23117300E+00, 0.74140800E+01, 0.39679200E+01, -.46763400E+01, 0.31864300E-01, 0.80635400E+00, -.10603200E+01, 0.11986900E+00, -.14159700E+01, -.21243600E+00, -.81092100E+00, -.25478300E+01, -.17831200E+01, 0.34325600E+00, -.68255000E+00, -.25187400E+01, 0.30991500E-01, 0.19579200E+01, -.12959600E+00, 0.88801100E+00, 0.44583100E+00, 0.43971000E+00, -.10358900E+01, -.37097100E+00, -.67777800E+00, -.13279300E+01, 0.83031700E+00, 0.73434700E+00, -.63607400E+00, 0.18161500E+00, -.13472300E+01, -.27952800E+01, -.13375100E+00, -.14591900E+00, 0.19349300E+00, -.82215000E-01, 0.14960100E+00, 0.13824300E+00, 0.16218900E+01, 0.95897800E+00, 0.99135600E-01, -.10369400E+01, 0.35925300E+00, 0.31391500E+00, 0.43927100E+00, -.10308300E+01, 0.23209900E+01, -.83441900E-01, -.18881100E+00, -.73987600E-01, 0.59650900E+00, 0.27840400E+00, 0.76877700E+00, 0.93923600E-01, -.10183700E+01, -.66303700E+00, 0.47166600E+00, 0.19976400E-02, 0.94771200E-01, 0.17389900E+01, 0.15996700E+01, -.13527100E+00, 0.73426900E+00, -.12636000E+00, 0.12063700E+01, 0.38919100E+00, 0.90996600E+01, -.32915700E+00, -.79869500E-02, 0.10836200E+00, -.21246300E+00, 0.34741400E+01, 0.40336800E+00, -.19898600E+00, -.72108900E+00, -.14661800E+00, -.64257000E-01, -.82925800E+00, -.40793200E+00, 0.45969100E-02, -.88823200E+00, -.10822200E+01, 0.17332600E+00, -.59611300E+00, -.23868700E+00, 0.25417200E+00, 0.40312200E+00, 0.51585300E+00, 0.72814600E+00, -.18583100E+01, -.82515000E-02, 0.11608300E+00, 0.10903700E+00, 0.24060700E+00, 0.24793200E+00, 0.41957500E+00, -.79151300E+00, -.32710800E+00, 0.10629500E+00, 0.46524100E+00, -.15451300E+01, 0.19874200E-01, 0.67112700E-01, -.14171500E+00, -.37016400E+00, -.55488000E+00, 0.40105800E+00, 0.76131900E+00, -.28525000E+00, 0.44004400E+00, 0.29629300E+00, 0.42323900E+00, 0.57395900E-01, -.73470900E+00, 0.13976600E+00, 0.65967900E-01, 0.46490500E+00, 0.66803500E+00, 0.63146200E-01, 0.29035200E+00, 0.25243500E+00, -.33144800E+00, -.16727500E+00, 0.25481900E-02, -.34443300E+00, 0.31097500E+00, -.46738700E-01, 0.86123700E-02, 0.16475000E+00, 0.41388000E+00, 0.12485400E+00, -.86068100E+00, -.35886600E+00, -.84669400E-01, 0.53158700E-02, 0.29494400E+00, -.58525700E+00, 0.15607400E+00, -.24146900E+00, 0.40808100E+00, -.21996100E-01, 0.48458800E+00, 0.79218400E+00, -.63759600E+00, 0.48244100E+00, 0.22647900E+00, 0.25706200E+00, 0.11975600E+01, -.21516700E+01, -.26535400E+00, -.95000300E-01, 0.27907700E+00, -.14711400E+00, -.45535800E+00, 0.32307000E+02, -.11539400E+03, -.53352600E+00, 0.55840600E+01, 0.53785400E+02, -.19112100E+03, -.32816100E+03, -.61332400E+02, 0.12996200E+03, -.17445300E+02, 0.17638500E+03, -.93353000E+02, 0.74313500E+02, -.88580900E+02, -.15158800E+03, 0.14132200E+03, -.62517200E+02, 0.79899100E+02, -.30631600E+02, 0.11861400E+03, -.14092600E+03, 0.26385300E+03, -.13228900E+03, -.19658500E+03, -.13131800E+03, -.10889200E+03, -.47387600E+02, -.85907100E+02, 0.19950000E+03, 0.12909400E+03, -.82110600E+02, -.71688600E+02, 0.21579400E+03, -.11091800E+03, -.28486000E+03, -.10635100E+03, -.13087200E+02, -.10774600E+03, 0.80590400E+02, 0.19506500E+03, 0.33400700E+02, -.69238700E+02, 0.58970600E+01, -.58941400E+03, 0.29600900E+03, -.21233100E+03, 0.29466000E+03, 0.15674900E+03, -.40781700E+02, 0.37721100E+03, 0.29387200E+03, 0.16706700E+03, -.54821400E+02, 0.32883900E+03, -.25667700E+03, 0.12926700E+03, 0.81953700E+02, 0.12806600E+03, -.49993400E+02, 0.40868400E+01, 0.16862900E+03, 0.11108800E+03, 0.43685900E+02, 0.55796200E+01, 0.24495300E+03, 0.24581300E+03, -.95039200E+02, -.20959000E+03, -.12455600E+03, -.53255000E+02, -.10835200E+03, -.67834500E+00, 0.14180000E+03, -.32791400E+03, -.39523700E+02, -.24918500E+02, -.82978300E+03, 0.40041900E+03, 0.13033500E+03, 0.41354000E+03, 0.24977000E+03, 0.24099600E+03, -.21793200E+01, -.68245900E+02, 0.22814600E+03, 0.13425100E+03, 0.34383000E+03, -.54405800E+02, -.29698800E+01, -.74188100E+02, 0.27214500E+02, 0.98435900E+02, -.12117300E+02, 0.11443100E+03, 0.28437600E+02, 0.15212800E+03, -.39100200E+02, 0.61381800E+02, 0.66181100E+02, -.35449500E+02, 0.18569100E+03, -.32674000E+02, 0.12534200E+03, -.52383800E+02, -.64695700E+02, -.58227800E+01, 0.26203800E+02, -.81606700E+02, -.31813300E+02, 0.44156400E+02, -.63301300E+01, 0.95112900E+01, -.23247100E+02, -.75400600E+02, 0.10802700E+02, -.23317100E+01, -.74792800E+02, 0.38448200E+02, 0.25010300E+02, 0.11251500E+02, -.69794000E+01, -.74073900E+01, 0.36089100E+02, 0.10536700E+01, -.19995300E+02, -.33602900E+00, -.76343700E+00, -.23827900E+02, -.48402800E+02, -.11698500E+02, 0.17090900E+02, -.48176900E+02, 0.21893400E+02, -.27054700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26942500E+02, 0.10923000E+01, -.15591500E+02, -.54971500E+01, 0.89650200E+01, -.22804400E+01, -.54254000E+00, 0.16252900E+01, -.15094400E+01, 0.15061900E+01, -.10940100E+01, 0.21480500E+01, 0.72055200E+01, -.87915500E+01, -.17003700E+01, 0.58851700E+00, 0.45019600E+01, -.57753700E+01, -.57656900E+01, 0.61222000E+00, -.13194900E+01, -.17727500E+01, 0.45696100E+00, 0.19989900E+01, 0.10369200E+01, 0.22160400E+01, 0.81458800E+01, -.10128300E+02, -.25957500E+01, 0.25881700E+01, -.12726600E+01, 0.17542800E+01, 0.10491300E+02, 0.15507900E+01, -.23948700E+00, 0.27059000E+01, 0.12371700E+00, 0.50985800E+00, -.79021700E+00, 0.22036600E+01, -.13223300E+01, 0.61362400E+00, 0.29678300E+01, -.92919100E-01, 0.44035200E+01, 0.84521900E+00, 0.11572100E+01, -.29274400E+01, -.56941000E+00, 0.15864500E+00, -.33232700E+01, -.23768800E+00, 0.10288300E+01, 0.45738400E+01, 0.10177800E+01, 0.26701600E+01, 0.36596700E+00, -.35721600E+01, 0.22096800E-01, 0.28185200E+01, -.59638500E+01, -.24326700E+01, 0.72779100E+00, -.35698200E+01, -.47429200E+01, 0.25742200E+01, -.14397800E+01, -.11073600E+02, 0.53275400E-01, 0.39617800E-02, -.26625400E+00, 0.55465600E+00, -.12410800E+00, 0.20310800E+01, 0.19529700E+01, -.35491100E+01, 0.25853200E+00, 0.38863300E+01, 0.15662600E+00, -.35588300E+00, -.22148100E-01, -.20002600E+01, 0.57555200E+00, -.71321300E-02, -.38893000E+00, 0.19477100E+00, 0.15310800E+01, -.64338300E+00, -.52173400E+01, 0.27608100E+01, 0.35212600E+01, -.15338400E-01, 0.55501300E+00, 0.31253100E+00, -.20763000E+01, 0.40605300E+00, -.84029900E+00, 0.12190200E+01, -.12764500E+00, 0.31589500E+00, 0.50228300E+00, 0.20491600E+01, -.35902400E-01, -.18019300E+01, -.26104800E+00, 0.25361600E+01, -.41664900E+00, -.24124000E+01, -.14933300E+01, 0.11464600E+01, -.55906300E+00, -.13294800E+01, -.25855600E+01, -.62756800E-01, 0.16469400E+01, 0.32166800E+00, 0.13554700E+01, 0.95089500E+00, 0.60227100E+00, -.31000800E+01, 0.86250100E+00, -.68215600E+00, 0.10945700E+01, 0.67015700E-02, -.85751800E-01, 0.11571600E+01, 0.10228900E+01, -.60238300E-02, -.11940400E+00, -.34064100E+00, -.93448200E+00, 0.14269400E+01, 0.18115700E+01, 0.35107700E+01, 0.27158700E+00, 0.23620600E-01, -.12170000E+01, 0.45547700E-02, -.26876300E+01, 0.96722400E+00, 0.75670200E+00, -.35866900E+00, -.18466500E+00, 0.32231500E+01, 0.17511600E+00, 0.55405200E+00, 0.11724100E+00, -.11424400E+00, -.20270500E+01, 0.25719000E+01, 0.11626500E+01, -.19627500E+00, -.80796200E+00, 0.65471700E+00, 0.28951600E+01, 0.53025700E+00, 0.91300200E+03, -.17611100E+01, 0.16966200E+03, 0.21060800E+03, 0.44887100E+03, 0.59765700E+03, -.83078200E+02, -.49375600E+02, -.40728100E+03, -.79292100E+03, 0.42055000E+03, -.12665200E+03, 0.39589900E+03, 0.62001900E+03, -.35951200E+03, 0.32387200E+03, -.18393700E+02, 0.46593100E+03, -.27170200E+03, 0.25141200E+03, -.47467300E+03, 0.22895300E+03, -.55928000E+03, 0.23920500E+03, -.14988100E+03, -.41164300E+03, 0.47320800E+03, -.28217500E+03, -.23689500E+02, -.18179000E+03, 0.43234400E+03, -.10778200E+04, 0.51943500E+03, 0.44200100E+03, 0.54355000E+03, -.90966700E+02, 0.41080600E+03, -.23428900E+03, -.53679300E+03, 0.14399300E+03, 0.25724100E+03, 0.69488000E+03, 0.20507300E+04, -.10118800E+04, -.22725000E+03, -.10255100E+04, -.44543000E+03, 0.26892400E+03, -.12410300E+04, -.10202800E+04, -.60581400E+03, 0.32477900E+03, -.12001700E+04, -.15398800E+03, 0.84435500E+02, -.26678400E+03, 0.76133200E+02, 0.44291500E+02, -.11893400E+03, -.28485300E+03, -.53407100E+03, 0.53171000E+02, -.76478700E+02, -.22528100E+03, -.34465600E+03, 0.11276700E+03, -.12123800E+03, 0.16706200E+03, -.32623000E+03, 0.55405500E+02, 0.18433900E+03, -.13013500E+03, 0.85298900E+03, -.91073200E+02, 0.68875500E+03, 0.83675700E+03, -.40528600E+03, -.20380300E+03, -.42229900E+03, -.36776500E+03, -.88929500E+03, 0.13962200E+03, -.58762000E+02, -.23445500E+03, -.51495400E+03, -.23194700E+03, -.79147200E+02, 0.92097700E+02, 0.75247600E+02, 0.39635500E+02, -.15995100E+03, -.29705200E+02, -.28257900E+03, -.13335700E+03, -.34405000E+03, 0.35200800E+02, -.11757100E+03, 0.11820400E+04, -.61626600E+03, -.63336000E+03, -.58967800E+03, -.50757100E+03, 0.10394300E+03, -.29198900E+03, -.74529500E+02, -.72915600E+03, 0.81041800E+02, 0.66362600E+02, -.13154700E+03, 0.29029800E+02, 0.58556300E+02, 0.49037100E+02, -.60219300E+02, -.32391600E+02, 0.15333900E+02, -.63239500E+02, 0.11257600E+03, -.72682700E+02, -.17896400E+02, 0.10191900E+02, 0.17202400E+02, 0.11983500E+03, -.16281200E+02, 0.10056600E+03, -.79472500E+02, 0.82411300E+02, 0.54909400E+02, 0.64528300E+02, -.10672000E+02, -.66723500E+02, 0.33093900E+01, -.50488200E+02, 0.77196800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.87649200E+01, 0.12175500E+01, 0.47194300E+01, 0.14892900E+01, 0.16354900E+01, -.30468300E+00, -.31240300E+00, 0.18428100E+00, -.17950800E+00, 0.19196700E+01, 0.26820200E-01, 0.29190000E+01, 0.20285900E+01, -.45196100E+00, 0.56432400E+00, 0.64356200E+00, 0.18539300E+01, 0.15272600E+01, 0.29294500E+00, 0.10308900E+01, -.11176800E+01, -.21908300E+00, 0.37087000E+00, 0.13878400E+01, 0.41264100E+00, 0.51891900E+00, -.94745800E+00, -.13367000E+01, -.19172200E+00, -.11575500E+00, -.36609000E-01, 0.89047700E+00, 0.79628900E+00, 0.76582200E+00, 0.26082200E-01, -.60033500E+00, -.49042200E-01, -.33639000E-01, -.19031500E+00, -.54937200E+00, 0.13746500E+00, 0.23754500E+00, 0.91501100E+00, -.16914500E+00, -.80376700E-01, 0.20288000E-02, -.15874800E+00, 0.82884200E+00, 0.82450900E+00, 0.57969500E-01, -.13587700E+00, -.15614200E+00, 0.39862100E+00, 0.49863400E+00, 0.16798300E+00, 0.75794900E-01, -.10858200E+00, -.16935500E+00, -.10152800E-01, -.52509100E+00, 0.10444100E+00, -.79070800E+00, -.10737400E+00, -.20870900E+00, -.70362600E+00, -.26570300E+00, -.22398900E+00, 0.18334600E+00, 0.94148200E-01, 0.19991000E-01, 0.57976900E-01, -.45425200E+00, 0.19354200E+00, 0.12751500E+01, -.13515100E+00, -.22034500E+01, -.15314400E+00, 0.11543200E+01, 0.11272700E+00, -.35072800E+00, -.76674700E-01, -.12123200E+01, 0.22688100E-01, 0.16492900E+00, -.22048500E+00, 0.54439300E-01, -.33350300E+00, -.20928500E+00, -.64624300E-03, 0.27958800E+00, 0.88967600E+00, 0.10460700E-01, 0.22957100E+00, -.15505900E+00, -.11125800E+01, 0.60359500E-01, 0.82118300E+00, -.37448900E+00, 0.25826900E+00, -.22721400E+00, 0.37468900E+00, 0.40536700E+00, 0.10859500E-01, 0.76108000E-01, 0.64593000E-01, 0.28977000E+00, -.19117700E+00, -.89668800E-01, -.40680900E+00, 0.95338600E+00, -.26840800E+00, -.12005900E-01, 0.28303900E+00, -.29123900E-01, 0.14283300E+00, 0.36011100E-02, 0.20046500E-02, 0.20387400E+00, -.24396000E+00, -.64409800E-01, 0.62790000E-01, 0.97647000E-01, 0.16521100E-01, -.79653000E-01, -.23946500E-02, 0.49095700E+00, -.33170300E+00, 0.13109900E+00, 0.43401700E-01, -.87975600E-01, -.40683700E-01, 0.32257300E+00, -.25537800E+00, 0.66795200E+00, 0.57296300E-01, -.53731000E-01, -.16432400E+00, 0.27847000E-01, -.36465500E+00, -.10333500E+00, 0.34415500E+00, -.22164600E+00, 0.19855000E+00, -.22977500E-01, -.31792600E-01, 0.17007700E+00, -.38398400E-02, 0.68295500E-01, -.11433000E+00, -.16257000E+00, 0.66882100E-01, -.53357200E-01, -.18328400E+00, -.55912700E-01, 0.29512300E+00, 0.25683700E-01, 0.44368600E-01, 0.37986400E+01, -.29383500E+02, 0.16707600E+02, -.22371500E+02, -.66103500E+02, -.21728000E+02, 0.31623300E+02, 0.21608100E+02, -.82929700E+02, 0.42827500E+02, 0.35328900E+02, 0.42570900E+02, 0.41454000E+01, 0.60024300E+01, 0.13397000E+02, 0.17805900E+02, 0.50646100E+02, -.16856600E+02, 0.92972600E+02, 0.14870300E+03, -.76697200E+02, -.74450300E+02, -.75207000E+02, -.15328400E+02, -.26271400E+02, -.14942400E+02, 0.66827900E+02, -.43628200E+01, -.20139100E+02, -.76767600E+02, 0.66642300E+02, -.37933500E+02, -.65986600E+02, -.34806400E+02, -.19579100E+02, -.38346300E+02, 0.31430800E+01, 0.29835000E+02, -.31605200E+02, -.38531900E+02, 0.34852200E+01, -.18199300E+02, 0.12642000E+02, -.66509200E+02, 0.91357400E+01, -.26340300E+02, 0.17834300E+02, 0.26739900E+02, 0.61840100E+01, -.20278300E+02, 0.20884100E+02, 0.22864000E+02, -.58480400E+02, 0.30591000E+02, 0.38924900E+02, 0.29439200E+02, 0.12196200E+02, 0.16913100E+02, 0.27777700E+02, 0.27213500E+02, 0.11585300E+02, 0.20668400E+02, 0.38946900E+02, -.62255800E+01, -.12865900E+01, -.23703000E+02, 0.44019100E+01, -.98656900E+00, 0.66386100E+01, 0.26404700E+02, 0.59089900E+02, -.10320800E+02, 0.17490500E+02, 0.11584100E+03, -.12625500E+03, 0.55019500E+02, -.50614700E+02, 0.63178300E+02, -.10373800E+02, -.38430100E+02, 0.49569000E+02, -.21589400E+02, 0.54634200E+02, -.38494700E+02, 0.24711700E+02, 0.28833300E+02, -.15622600E+02, -.12847300E+02, -.14130900E+02, 0.10641700E+02, -.41779000E+01, 0.54135500E+00, 0.18972400E+02, -.38809100E+01, -.10171100E+02, -.61203300E+02, 0.69628000E+02, -.38725300E+02, -.32667900E+02, -.35098300E+02, 0.37528500E+02, -.11464200E+02, -.48757900E+01, 0.28976800E+02, -.15461600E+02, -.11384800E+02, -.88166000E+02, 0.13608000E+02, 0.14736300E+01, -.29909200E+01, -.28771500E+01, -.39366600E+01, 0.41861600E+01, -.25590800E+01, -.43077700E+01, -.15566800E+02, 0.29558000E+01, 0.10632100E+02, 0.11899600E+01, 0.18785900E+01, -.15673700E+02, 0.28506700E+01, -.38759700E+01, 0.53736200E+01, 0.19253200E+01, -.83548900E+01, 0.26045200E+01, -.39751600E+01, 0.38113300E+01, -.20075600E+01, 0.14415000E+02, -.40791500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15746600E+02, 0.37502500E+00, -.11958300E+02, -.51244600E+01, 0.54640700E+01, -.14735700E+01, -.29091700E+00, 0.97818600E+00, -.71623100E+00, 0.81157100E+00, -.49700100E+00, -.52002000E+00, 0.30693900E+01, -.33218500E+01, 0.77461400E-01, -.72927200E+00, -.78084800E+00, -.28729200E+01, -.30591000E+01, 0.25811100E+00, -.10594500E+01, -.80679800E+00, -.38940000E+00, -.26123700E+01, 0.41516400E+00, 0.77321700E+00, 0.44821800E+01, -.60635100E+01, 0.60141300E+00, 0.45870200E-01, -.69813500E+00, 0.55851400E+00, 0.55494500E+01, -.32511100E+01, 0.10563000E+01, -.20192000E-02, 0.35326400E+00, -.33371300E+00, 0.14888600E+01, -.64501900E+01, 0.38117400E-01, -.25444300E+01, -.98055800E+00, 0.71171400E+00, 0.50400700E-01, 0.94640900E+00, 0.98063800E-01, -.13506600E+01, -.23176800E+01, 0.61160500E+00, 0.11968000E+00, -.17730900E+00, -.16162000E+00, 0.25631500E+01, 0.25432700E+01, -.17204700E+01, 0.66225500E-01, -.99189600E+00, 0.19715300E-01, 0.77142200E+00, -.60817000E+00, -.31244700E+00, 0.38185800E-01, -.62068400E+00, -.27655800E+01, 0.15943000E+01, -.51226600E+00, 0.65191100E+01, -.39767100E+00, -.19374800E-01, 0.10845700E-01, 0.20030300E+00, 0.22930700E+01, 0.58478400E+00, -.23659600E-01, 0.23158800E-01, -.46538800E+00, 0.12929100E+00, 0.63292200E+00, -.27168800E+00, -.84921000E-02, -.36207100E+00, -.28304000E+01, -.31048900E+00, -.69348300E+00, -.93611300E-01, -.21337700E+01, 0.91552000E-01, 0.37704800E+00, 0.24396300E+00, -.23617400E+01, 0.35231300E-01, 0.22815100E+01, -.35597200E+00, -.32666500E+00, -.11515200E+00, 0.24151500E+01, -.13387400E+01, 0.92743200E-01, -.21863800E+00, -.53882600E+00, 0.28255200E+00, 0.10885100E+00, 0.14508500E+01, -.50571600E+00, -.13389800E+01, -.33187000E+00, 0.30688300E+00, 0.20095800E+01, 0.48144500E+01, 0.19397600E+01, -.36163400E+00, -.86322100E+00, 0.45783900E-01, -.98699200E+00, 0.28805200E+00, -.19014500E-01, 0.98695700E+00, 0.44767900E+01, -.19152800E+01, 0.10724500E+01, -.21399100E+00, -.36737100E+00, 0.50564000E+00, 0.85311400E-01, -.13830000E+01, 0.16699800E+01, -.94675700E+00, 0.19963400E+00, 0.16242600E+00, -.22701600E+01, 0.21791200E+01, -.73956900E-01, 0.17301100E+01, -.93912400E+00, 0.50248800E-01, -.45229600E+00, -.82986200E+00, -.50498700E+00, -.14845900E+00, 0.17949000E-01, 0.27970700E+00, 0.68926700E+00, -.24636700E+01, 0.46199900E+00, 0.32709000E-01, -.14204500E+00, 0.10993200E+00, -.79598500E+00, 0.17669800E+01, 0.31021200E+00, 0.27488900E+00, 0.95051200E+00, 0.31604300E+00, 0.11215100E+00, 0.25819500E+00, 0.22900100E-01, 0.11270000E+00, 0.33813300E+03, 0.10531000E+03, 0.34808200E+01, 0.21307500E+03, 0.14031100E+03, -.49701100E+02, -.37712500E+03, 0.52996400E+02, -.34976100E+02, 0.21798100E+03, -.29904200E+02, -.21793000E+03, 0.58375800E+02, 0.10935800E+03, 0.17487300E+03, -.91309200E+02, 0.60817200E+02, -.93957000E+02, -.34836400E+03, 0.18246500E+03, -.53277300E+02, 0.17436800E+03, -.19550800E+03, 0.26515300E+02, -.54862400E+02, -.12675800E+03, 0.14714200E+03, -.48695900E+02, 0.22747600E+03, -.26561100E+03, 0.14409000E+03, -.41506400E+01, 0.13170100E+03, 0.11417600E+03, 0.19053300E+03, 0.11322300E+02, -.30024200E+02, 0.25339600E+03, 0.19201200E+03, -.12426400E+02, 0.40623900E+03, -.21444900E+03, -.20863500E+03, -.20305900E+03, 0.34534600E+02, 0.24232000E+03, -.15192800E+03, -.24059400E+03, -.34371300E+03, 0.27719200E+03, -.18306200E+03, 0.67508000E+02, -.39332500E+02, -.20653600E+02, -.33370400E+02, -.58344800E+02, 0.18224000E+01, 0.30433000E+01, -.12067600E+03, -.13071700E+03, 0.50313500E+02, -.55615700E+02, 0.98104500E+03, -.47873100E+03, -.76148000E+03, -.48852200E+03, -.23290500E+03, 0.53202500E+02, 0.25597200E+02, 0.45264500E+03, -.33255500E+03, 0.56634100E+02, -.85594700E+03, -.10294800E+03, 0.96236700E+02, 0.14361400E+03, 0.55510000E+02, 0.16523600E+03, 0.16963700E+03, -.27615800E+03, -.24101000E+03, -.53364500E+02, 0.14286500E+03, 0.16207600E+03, -.24435800E+03, 0.12968900E+03, -.80718300E+01, 0.12156000E+03, 0.17961200E+03, 0.53282400E+02, 0.20639400E+02, -.86383100E+02, 0.10052100E+03, 0.83466900E+02, 0.28694600E+03, 0.61609900E+02, -.18867500E+02, -.94835500E+02, -.31459400E+02, 0.20382500E+03, -.97407600E+02, -.17309100E+03, -.11362000E+03, 0.16489800E+03, -.99738000E+02, -.48317100E+02, -.42614200E+02, 0.68845400E+01, -.32890600E+02, 0.53391600E+01, 0.24047200E+02, 0.55151800E+01, -.21784500E+01, 0.28073100E+02, 0.10177400E+03, -.12084300E+02, -.53652000E+02, -.14609500E+02, -.16781700E+02, 0.10114300E+03, -.70153900E+01, 0.29111200E+02, 0.86831200E+02, -.15446600E+02, 0.41555600E+01, 0.85927700E+02, -.41824800E+02, 0.14578200E+02, 0.45922200E+02, -.42002600E+02, 0.37922000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.63595300E+01, 0.71483300E+00, -.24215800E+00, 0.39020800E+01, 0.30115600E+01, -.28746100E+01, 0.93787000E+00, 0.15741500E-02, -.77439400E+00, 0.16032700E+01, -.15007100E+00, 0.44313200E+00, -.63995700E+00, -.20565600E+01, 0.39772300E+00, 0.69757500E+00, -.31529700E-01, -.13230400E+01, 0.18554000E+01, -.91087800E+00, -.12104200E+01, -.31389100E+00, 0.23127700E+00, 0.12853300E+01, 0.24122400E+00, 0.42899300E+00, 0.48593500E+00, 0.98768400E+00, -.13611500E+01, 0.58986100E+00, 0.96571800E-01, 0.64767000E-01, 0.15366000E+00, -.37042500E+00, 0.20408500E+00, -.35219200E-01, -.25547500E-01, -.19459400E+00, 0.37231400E+00, 0.80393600E+00, 0.51049700E+00, -.44826900E+00, 0.16698800E+00, 0.10259900E+00, -.10732900E+01, -.16008600E+00, -.54976900E-01, 0.14726200E+00, 0.75790200E+00, -.14619500E+00, 0.17873800E+00, -.10166200E+00, -.99822600E+00, -.80832600E+00, -.19466900E+00, 0.15933100E+01, 0.48784700E-01, -.54850200E+00, 0.37553000E-02, 0.93528200E+00, -.15609500E+01, -.10030600E+01, 0.33136400E-01, -.16588700E+00, -.12148600E+01, 0.70765500E+00, -.35150000E+00, -.31456100E+01, 0.58896700E-01, 0.50616500E-02, -.65416100E+00, 0.76937800E+00, 0.89411700E+00, -.85416300E-01, 0.92445600E+00, -.30266700E+00, 0.15444300E+00, 0.93929900E+00, 0.83441100E+00, -.41470200E+00, -.17214100E-01, -.94050300E+00, 0.21251000E+00, -.59598600E+00, -.17212700E+00, 0.37470500E+00, 0.28282400E+00, 0.27060100E+00, 0.43356000E+00, -.75556900E-01, -.32953300E+00, -.64785200E-01, -.78781500E+00, -.27775600E+00, 0.32129000E+00, -.14495500E+00, -.53726200E+00, 0.30824500E+00, 0.93693300E+00, -.32973700E+00, -.20287700E-02, 0.71969500E+00, -.74508200E-01, 0.46839900E-01, 0.42594600E-01, -.68898400E+00, -.17127300E-01, 0.85441100E-01, -.45450000E+00, 0.10745800E+00, -.20050100E+00, -.14008500E+00, 0.75523900E-01, -.46112700E-01, 0.32149700E-01, 0.21810300E-01, 0.41783500E+00, 0.66304600E+00, -.26024200E+00, -.61234300E-02, 0.28000000E-01, -.30373400E+00, -.11078900E+00, -.31661800E+00, 0.40299200E-01, 0.76863800E+00, -.70758900E+00, 0.24715700E+00, -.10791200E+00, -.13750900E+00, 0.11704600E+00, -.23794400E-01, 0.26917100E+00, 0.15045100E+01, 0.19891800E+00, 0.49246900E-01, -.68960900E+00, 0.56357200E+00, -.13469600E+01, 0.83432200E-01, 0.47264700E+00, -.56679000E+00, -.13846300E+00, 0.99931800E+00, -.32149000E+00, 0.29800100E+00, 0.76770400E-01, 0.34963800E-01, -.34034600E-01, -.11006900E+01, 0.50005800E+00, -.25546000E-01, -.17938700E+00, -.20137600E-01, 0.29880700E+00, -.60343700E-01, 0.96843000E-01, -.52727100E-01, -.52269000E-01, 0.50962200E+02, -.63577200E+02, -.10442100E+03, -.73847300E+01, 0.87036500E+02, 0.25288000E+02, 0.11676300E+03, -.61545500E+02, -.55929600E+02, -.57926000E+02, -.14805200E+02, 0.86057600E+01, -.69378700E+02, -.22957300E+02, -.53433900E+02, 0.16185600E+02, 0.37625400E+02, 0.13006900E+03, -.63630500E+02, -.33526400E+02, -.64975500E+02, -.33547600E+02, 0.23510500E+02, -.12331600E+02, 0.88342500E+02, -.22050500E+02, 0.21656600E+02, -.37152700E+02, 0.24930300E+03, -.12296400E+03, -.15214500E+03, -.12424200E+03, -.12637800E+03, -.12749700E+03, 0.59379700E+01, 0.79910600E+02, -.53125400E+01, -.11743200E+03, 0.19881000E+02, -.18363900E+03, 0.90653300E+02, -.16218200E+03, 0.91801000E+02, 0.10583200E+02, 0.45011500E+02, 0.34779900E+02, 0.40351500E+02, 0.10292200E+03, 0.19968800E+02, 0.78110800E+02, 0.39245100E+01, -.30567900E+01, -.27710700E+02, -.20781200E+01, 0.20043200E+02, 0.20166100E+02, 0.20580000E+01, 0.20128600E+02, 0.21920300E+02, 0.16017800E+02, 0.47286100E+02, -.11571300E+01, 0.73759500E+01, 0.47316100E+02, 0.34331800E-01, 0.88389700E+01, 0.22618900E+02, -.34743000E+02, -.12893900E+02, -.52389500E+02, 0.21245000E+02, -.42088000E+01, -.37633100E+03, 0.17983800E+03, -.25189200E+02, 0.18732000E+03, 0.11993800E+03, 0.98424600E+02, 0.27086400E+02, -.31268500E+02, 0.81260400E+02, 0.74250000E+02, 0.11284200E+03, 0.32592700E+02, -.21516600E+02, -.21533500E+02, -.16261700E+02, -.14680400E+02, -.50852400E+02, 0.37700900E+02, 0.10656200E+02, 0.32683100E+02, -.54257200E+02, 0.51420400E+02, 0.98815000E+02, -.46949600E+02, 0.51425700E+02, -.49213400E+02, 0.99763600E+01, -.11406500E+02, 0.34193700E+02, 0.54701400E+02, -.43179000E+02, -.48829200E+02, -.35969300E+02, 0.23822200E+02, -.31923200E+01, 0.20593600E+02, -.10405300E+01, -.63878000E+02, -.23871700E+01, 0.66904400E+01, -.63946700E+02, 0.38888000E+02, 0.12399400E+02, 0.15962800E+02, 0.31329400E+01, -.34643900E+01, 0.38901500E+02, -.53634700E+01, -.35595900E+01, -.13138700E+02, 0.13695900E+02, -.74458200E+01, -.31622200E+02, 0.13520200E+02, -.60567000E+01, -.40547600E+02, 0.10092600E+02, -.13197800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32467800E+01, -.14965300E+00, 0.64293400E+00, -.25180000E+01, -.18413200E+01, 0.11080500E+01, -.12573600E+00, -.65169600E-01, 0.43376200E+00, -.12648000E+01, -.56967300E+00, -.18503000E+00, -.70916800E+00, 0.76888200E+00, 0.98180100E-01, -.12575100E+00, -.25255700E+00, 0.18528300E+00, -.15795500E+00, 0.25162200E+00, 0.36575500E+00, 0.13502300E+00, 0.26754100E+00, -.40163300E+00, -.14211800E+00, -.73740600E+00, 0.30700700E+00, -.82781100E+00, -.82872500E-01, -.24634700E+00, 0.41652200E-01, -.62403100E+00, -.38331400E+00, -.17672700E+00, -.70413400E-01, -.24101300E+00, -.26426900E-01, 0.20719800E-01, -.32202500E+00, 0.32766500E+00, -.24292100E+00, 0.49757300E+00, -.48869400E+00, -.54192100E-01, 0.95286700E-01, -.77421300E-01, -.16485200E+00, 0.46108900E+00, 0.93991200E-01, -.66725700E-01, -.52634100E+00, 0.33600600E+00, 0.78746800E-01, 0.61745200E+00, 0.21073400E+00, 0.52471900E+00, 0.59873100E-01, -.27166400E+00, 0.93525600E-03, 0.24669600E+00, -.82952300E+00, -.29834100E+00, -.11096700E-02, -.77313600E-01, 0.14189600E+00, 0.18598100E+00, -.58777700E-01, 0.24160300E+00, 0.52775400E-01, -.27493300E-02, -.50680900E-02, -.12771200E+00, 0.87186300E-01, 0.55970500E+00, -.74403300E-01, -.13823800E+00, -.86514100E-01, 0.25402900E+00, -.59876600E-01, 0.25566600E-01, -.86048700E-02, -.24337500E+00, -.32288300E-01, 0.13880200E+00, 0.75704200E-01, -.44878200E-02, -.12934400E-01, -.51560800E-01, -.33352900E+00, 0.32074400E-01, 0.55343900E+00, 0.12634200E-01, 0.13090500E+00, 0.34355000E-01, -.50464200E+00, -.96990600E-02, 0.23683000E+00, -.13409000E+00, -.48510300E-01, -.16698700E+00, 0.24550400E+00, 0.31350800E+00, 0.14151000E-01, 0.29978600E-02, -.75440100E-02, 0.20379800E+00, 0.43395000E-02, -.90111100E-01, -.30440900E+00, 0.52528400E+00, -.10282800E+00, -.13835100E-01, -.23110800E+00, -.18311100E-01, 0.19399700E+00, 0.30366400E-01, 0.59080600E-01, 0.12146000E-01, -.58653600E+00, -.59330900E-01, -.65388900E-01, 0.72390200E-01, 0.71060800E-01, 0.45038300E-01, -.13251100E-01, -.41842600E-01, -.73554800E-01, 0.79305700E-01, -.53339500E-01, -.87215800E-01, -.58616400E+00, 0.54468400E+00, -.10519700E+00, 0.15125300E+00, 0.38636700E-01, -.34455000E-01, 0.41896700E+00, -.79795400E-01, 0.43781600E+00, -.14834000E-01, -.85635300E-01, -.61883800E-01, 0.80983500E-01, 0.13628000E+00, 0.70675600E-01, -.52441400E-01, 0.12263000E-01, -.25583600E-01, -.17605900E+00, -.15618200E+00, 0.33620300E+00, 0.99090800E-02, -.15205300E+00, -.39809600E-01, 0.14861300E+00, -.20303200E-02, 0.65106400E-02, -.26976400E-01, -.13965900E+00, -.98149700E-01, 0.34490800E+02, 0.55148600E+02, 0.26169600E+02, -.25406500E+02, -.33225300E+02, 0.81802100E+02, -.40073900E+02, -.88904600E+01, -.41475200E+02, 0.13050600E+02, -.19741400E+02, -.99229400E+01, 0.66950800E+01, -.15670500E+02, -.24941000E+02, -.14806700E+01, 0.59102300E+01, -.37359300E+01, 0.44645500E+02, -.28638000E+01, -.25061900E+02, 0.33737600E+02, 0.58240500E+01, -.17582600E+02, -.51839400E+02, 0.23039200E+02, -.26247600E+02, -.13764300E+02, 0.57121300E+01, 0.38763900E+02, 0.70635500E+01, 0.52824700E+01, 0.20447700E+02, -.69001000E+01, -.12623600E+01, -.31905000E+01, 0.55161900E+01, 0.31498800E+02, 0.25798800E+02, -.12329200E+02, -.22967800E+02, -.12903100E+02, -.48753700E+02, 0.44884200E+02, -.54493000E+02, -.43803100E+02, 0.27895600E+00, 0.54199300E+02, 0.37523700E+02, 0.31799500E+02, -.15340900E+02, 0.13470000E+02, -.15919300E+02, 0.43001300E+02, 0.26506000E+02, -.32162100E+02, -.49995800E+01, 0.67597700E+00, 0.27167500E+02, -.50615600E+01, 0.25932500E+02, -.14114500E+02, 0.52137300E+02, -.13118600E+02, -.41031000E+02, 0.43338200E+02, 0.15568100E+02, 0.24574400E+02, 0.23446900E+02, 0.25165500E+02, -.78236700E+01, 0.11994500E+03, -.58597200E+02, -.92216500E+02, -.60006400E+02, -.45010400E+02, -.42632000E+02, 0.20082000E+02, 0.99423800E+01, -.10299700E+01, -.32917600E+02, -.95444400E+02, -.16698800E+02, 0.62412200E+01, 0.25167600E+02, 0.83452300E+01, 0.25964500E+02, 0.50020700E+01, -.22473000E+02, 0.31139600E+01, -.12040600E+02, 0.99794100E+01, 0.34811400E+02, 0.34860600E+00, -.79697400E+00, -.62443900E+01, -.14960900E+00, -.41794100E+02, -.90937100E+01, 0.28251800E+02, 0.15265700E+02, -.17178100E+01, -.61375800E+01, 0.56503000E+02, -.88678800E+01, 0.22204600E+01, -.10910500E+02, 0.24426700E+01, 0.26091100E+02, -.51258600E-01, -.10093400E+01, 0.26939300E+02, -.18652000E+02, -.50888400E+01, -.88329500E+01, 0.17182400E+01, -.20458100E+01, -.18069400E+02, 0.10725600E+01, 0.26412400E+01, 0.53818700E+01, -.26789800E+01, 0.18508300E+01, 0.78409100E+01, 0.42212300E+01, -.19164400E+01, 0.21002300E+02, -.68282600E+01, 0.48243200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11539700E+02, -.12061300E+01, -.57762400E+01, -.54234900E+01, -.43523600E+01, 0.35522700E+01, -.23570600E+01, -.57030200E+00, 0.77509600E+00, -.43431000E+01, -.29524100E+01, -.81026800E-01, -.26925100E+01, -.12944900E+02, 0.10390400E+01, -.15141500E+01, -.67907400E+01, -.73787200E+01, -.17498400E+01, -.25804200E+01, 0.82867900E+01, 0.10996600E+01, 0.11443100E+00, -.81124300E+01, -.10815800E+01, 0.80188000E+00, 0.18309500E+01, 0.57517000E+01, -.19869800E+01, -.65651700E-01, 0.36374900E+00, 0.47880000E+00, -.57776200E+01, 0.17539800E+01, -.58710400E+00, 0.12412600E+01, 0.91406300E-01, -.34672900E+00, -.25923700E+00, 0.92434400E+00, -.17785100E+01, -.24523300E+00, 0.40666300E+01, 0.25632800E-02, 0.25885900E+01, 0.71697800E+00, -.32758500E+01, 0.23972600E+01, -.18812700E+01, -.26653200E+00, -.33419700E+00, -.14626700E+01, -.49455700E+00, 0.26958600E+01, -.34772500E+00, -.43412600E+01, -.12610700E+01, -.35521600E+00, 0.18993700E-02, 0.80542300E+00, 0.20058200E+01, 0.17702300E+01, -.31362400E+00, 0.13544100E+01, -.73721800E+00, 0.15612600E+01, -.28344800E+00, 0.33381600E+01, 0.26602300E+00, -.87733500E-02, -.99028800E+00, -.70459200E+00, -.16913700E+01, 0.11804800E+01, -.17215800E+01, -.10891100E+01, -.20034200E+00, 0.76894500E+00, -.46607700E+00, 0.77315000E+00, -.38840300E-01, 0.10309800E+01, 0.54785200E-01, 0.81533900E+00, 0.16347600E+00, -.66531000E+00, -.51537300E+00, -.16005000E+01, 0.21664000E+01, 0.72985000E+00, 0.90151500E+01, -.27360300E-01, 0.15174000E+01, -.29530800E+00, -.30464500E+01, -.42494600E-01, 0.32363900E+01, -.19797000E+01, -.13118900E+00, -.37081700E+00, 0.16472800E+01, 0.14048200E+01, 0.10862700E+00, 0.80758500E+00, -.10208700E+00, 0.63706000E-01, 0.10616700E+01, 0.44164200E+00, -.30777500E+00, 0.26138600E+01, -.13920800E+01, -.12497200E+00, -.11665400E+01, -.75417900E-01, 0.65200500E+00, -.39298000E-01, -.23166700E+00, 0.72966400E+00, 0.22240200E+01, 0.15115400E+01, -.46862000E+00, 0.50683600E+00, -.15664700E-01, 0.69419300E+00, -.74659800E-02, -.83124100E+00, -.14927400E+01, 0.34215400E+00, -.26393000E+00, 0.37339200E+00, 0.17804300E+00, 0.11441200E+01, -.17586200E+01, 0.17653500E+01, -.37781100E+00, -.31186000E-01, 0.21346700E+01, -.21730400E+01, 0.30860900E+01, -.28577500E+00, 0.29479200E+00, 0.40488200E+00, 0.22907900E+00, -.16571500E+01, 0.98748400E+00, -.39087000E+01, 0.38774000E-02, -.39859700E+00, -.53577700E+00, 0.57345600E+00, 0.14871500E+01, 0.56532700E-01, -.82524300E+00, -.41563300E+00, -.16935700E+01, -.38921900E-01, 0.74976000E-01, -.15875000E+00, -.38339000E+00, 0.80816900E+00, 0.34364300E+01, 0.26525900E+03, 0.15561800E+03, -.21292100E+02, -.16829400E+03, 0.88710100E+03, -.44376300E+03, -.44764500E+03, -.44419300E+03, 0.18619300E+02, -.17838800E+03, -.23677700E+03, 0.44095500E+02, -.23557800E+03, -.12440700E+03, -.58836000E+03, 0.77954800E+02, -.38525300E+02, 0.22117900E+03, -.38142600E+02, 0.23302400E+03, 0.18186100E+03, -.24511000E+03, -.16673100E+02, 0.32923100E+02, 0.20361900E+03, -.61072900E+02, -.11802300E+03, 0.64313400E+02, 0.35149200E+03, 0.59297800E+02, 0.16241600E+03, 0.16849100E+03, -.41122300E+03, -.39439100E+03, -.39640300E+03, 0.32827900E+03, 0.23280000E+03, 0.10212300E+04, -.51240800E+03, -.10273000E+03, -.51057800E+03, 0.12327500E+03, 0.21542500E+02, -.39357600E+02, 0.26800600E+03, -.37087100E+03, -.42045700E+02, -.45393500E+03, 0.58247700E+03, -.29237800E+03, -.75176700E+02, -.29096800E+03, 0.46788700E+02, 0.56815800E+02, -.32701500E+02, 0.14521800E+03, -.16397200E+03, -.17797000E+02, -.21209900E+03, -.30613700E+02, 0.18757700E+02, -.19672700E+03, 0.15438700E+02, 0.12130300E+03, -.18942300E+02, -.20192000E+03, -.15425000E+02, -.47769800E+00, -.93536200E+01, 0.35623600E+03, -.86584700E+02, 0.58868800E+02, -.85107100E+01, 0.46572600E+02, -.10793700E+03, -.62442400E+02, 0.83549100E+02, 0.12752200E+03, 0.16221400E+03, -.11215300E+03, 0.62663300E+02, 0.30847200E+03, -.14958800E+03, 0.52955500E+02, -.15415900E+03, -.98770000E+02, -.96512800E+02, 0.11368000E+03, 0.42981600E+02, -.47963900E+02, -.10708300E+03, -.18647300E+03, -.11781800E+04, 0.59332900E+03, 0.24835900E+03, 0.58855400E+03, 0.11099400E+03, 0.26878900E+03, 0.34210300E+03, 0.10610000E+03, 0.41537900E+03, 0.24360900E+03, 0.10327300E+04, 0.47707400E+02, -.16996600E+02, -.23216400E+02, -.22101300E+02, 0.67214000E+01, -.10019900E+02, 0.18317200E+02, 0.77452200E+01, -.57855300E+02, 0.15840500E+02, 0.48649000E+02, 0.11372700E+02, 0.72165200E+01, -.58845800E+02, -.58755800E+01, -.29906000E+02, 0.15216700E+02, -.19914700E+02, -.42750900E+02, -.14613300E+02, 0.35235200E+02, 0.81030000E+01, 0.12597300E+02, 0.46203500E+02, -.57483800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.67334400E+01, 0.38968700E+00, -.21256700E+01, 0.35740600E+01, 0.18851700E+01, -.22670000E+01, 0.56094000E+00, 0.12878300E+00, -.88180500E+00, 0.16025200E+01, 0.11825900E+01, -.65734600E+00, 0.62022300E+00, -.14258200E+00, -.43208900E+00, 0.80703900E+00, 0.28539400E+00, -.48874400E+00, 0.11247100E+00, -.58301400E+00, -.16417000E+01, -.56762200E+00, -.22572500E-01, 0.18455400E+01, 0.48719000E+00, 0.14886100E+01, 0.14902800E+01, 0.13154900E+01, -.84553900E+00, 0.52276000E+00, 0.66273100E-01, 0.11570900E+01, 0.57807500E+00, -.42653300E+00, 0.97550900E-01, -.38002700E+00, 0.58291800E-01, -.22941500E+00, 0.45145400E-01, -.22622900E+01, -.42217300E+00, -.51832400E+00, -.11447700E+01, 0.86139300E-01, -.25168500E-01, -.16563600E+00, 0.15067400E+00, -.60833300E+00, 0.48793900E+00, -.25978400E-01, 0.43265900E+00, 0.72213500E-01, -.31686900E+00, -.61064300E-01, 0.92280000E+00, 0.39256900E+00, 0.90629800E-01, 0.48756600E-01, 0.12808400E-02, -.11076400E+00, -.40617000E+00, -.30441800E-01, 0.70274800E-01, 0.74713700E-01, 0.82172700E-01, 0.30077300E+00, -.13678500E+00, -.18758600E+01, -.12388600E+00, 0.73254200E-03, -.24261900E+00, 0.34380200E+00, -.61738300E+00, -.12088600E+00, -.37517900E-01, -.90373300E+00, 0.13275100E+00, 0.30968500E+00, 0.25156600E-01, -.21471900E-01, 0.79222600E-02, -.12333200E+01, 0.22693800E+00, 0.22211700E-01, -.20302500E+00, 0.33966700E-01, 0.23226900E+00, -.11710700E+00, -.96299200E-01, 0.60469000E+00, 0.23542800E+01, -.43117800E-01, 0.43640400E+00, -.99893400E-02, -.62453800E+00, -.18049900E+00, -.12762100E+00, -.69014100E-01, 0.40231400E+00, -.14264600E+00, -.44216800E+00, 0.37552400E+00, -.46373600E-01, -.29165600E+00, 0.19445100E+00, 0.14916600E+00, 0.21191500E+00, 0.97265400E-01, -.44098000E+00, -.77887800E+00, -.36471000E+00, -.13052300E+00, -.69374500E-01, -.56533200E-01, 0.38134800E+00, -.19969500E+00, 0.53159300E+00, 0.10418000E+00, -.15868900E+01, 0.18418700E+00, -.17794000E+00, -.34744900E+00, -.52675500E-01, -.44319300E+00, 0.10311900E+00, 0.22722500E+00, 0.86665500E+00, -.13411700E+00, 0.11196300E-01, 0.37214500E+00, 0.12003900E+01, -.97216600E+00, 0.65584200E-01, -.29997500E+00, -.13000500E+00, -.38810400E-01, 0.36856200E+00, -.10137900E+01, 0.10069100E+01, -.68773300E+00, 0.67674400E+00, 0.37464500E+00, 0.29000100E+00, 0.58926200E+00, -.43716300E-01, -.46049800E+00, 0.10543400E-01, -.67294700E-01, 0.10092000E+01, -.15162800E+01, -.15314300E+00, -.14165300E+00, 0.22716000E-01, -.19270000E+00, -.74319500E-01, -.28117800E-02, 0.43065600E-01, 0.20193700E+00, -.17767900E+00, -.19233800E+00, -.10663100E+01, -.80092400E-01, 0.64444100E+02, 0.18102000E+02, 0.40120400E+02, 0.42283100E+03, -.21469700E+03, -.10813700E+03, -.21168600E+03, -.83220600E+02, 0.57658400E+01, -.14580100E+03, -.10380900E+02, -.23561700E+03, 0.97141800E+01, -.53175200E+01, -.58811800E+02, 0.31701800E+02, 0.19749900E+03, 0.28842400E+02, -.62528000E+02, 0.91258200E+02, -.12862600E+02, -.11196700E+03, -.13518800E+03, 0.55111300E+02, 0.29809300E+01, 0.21031300E+03, -.98801500E+02, -.66423600E+01, -.10692300E+03, 0.48207600E+02, -.37956700E+02, 0.18829500E+02, 0.60407900E+02, -.11131800E+03, -.19548900E+02, -.70700800E+02, -.50497800E+02, 0.20607200E+02, -.56680700E+02, 0.25310100E+02, -.42541500E+02, -.11471000E+02, 0.14583200E+02, 0.56229800E+02, 0.48585800E+02, 0.17708600E+01, 0.34267800E+02, 0.29307900E+03, -.14860500E+03, -.41375700E+02, -.14617400E+03, 0.13754900E+02, 0.28277700E+02, -.10649200E+03, 0.21383500E+02, -.11018600E+03, 0.29387200E+02, -.12871800E+03, 0.27034700E+03, -.12721500E+03, -.11473400E+02, -.13310200E+03, -.11785900E+03, 0.17829200E+02, -.65223700E+02, 0.94155600E+02, -.16056500E+03, 0.39790600E+01, -.63539100E+02, 0.22980700E+03, -.97988000E+02, -.22838300E+03, -.11267300E+03, -.49476600E+02, -.68624400E+02, 0.93821300E+02, 0.12160400E+03, 0.86032400E+02, -.10451100E+03, -.14722700E+03, 0.34261000E+02, -.19592200E+02, 0.15648600E+02, -.17228100E+02, 0.84343600E+02, 0.49912500E+02, -.43261700E+02, 0.13481300E+02, -.38718300E+02, 0.49118800E+02, 0.29482100E+02, -.26997200E+03, 0.14188500E+03, 0.30207800E+02, 0.13440600E+03, 0.93823800E+02, 0.20227000E+02, 0.11638800E+03, -.38304400E+02, 0.12567500E+03, -.10407100E+01, 0.37434200E+01, 0.66336800E+01, 0.60100000E+01, -.20555600E+02, -.27823700E+01, 0.29543000E+02, 0.15935000E+01, -.23430300E+01, 0.31354100E+02, -.16833900E+02, -.81951200E+01, 0.14805400E+02, 0.28778800E+01, -.46527100E+00, -.16811400E+02, 0.16337300E+01, -.88523100E+01, 0.20468900E+02, 0.28230400E+02, -.15707000E+02, -.10932300E+02, -.53443600E+01, 0.78817100E+01, 0.15036000E+02, 0.28500200E+02, 0.48964400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.72509300E+00, 0.77243300E-01, 0.98865100E+00, 0.10359200E+00, 0.13118600E+01, 0.11752300E+01, -.18253500E+01, -.56675600E-01, -.11401500E-03, -.74999000E+00, 0.38545800E+00, 0.39183000E+00, 0.99214200E+00, 0.97934600E-01, -.21816100E+00, -.64541300E+00, -.33939500E+00, -.69987100E-01, 0.28777800E+00, 0.34303100E+00, -.44601700E+00, 0.74902900E-01, -.80189300E-01, 0.69149400E+00, 0.80055000E-01, 0.69896000E-01, -.70569400E+00, 0.22153800E+01, -.17175500E-01, 0.10342400E+00, 0.13507700E-01, 0.10770400E+01, -.16598300E+00, -.20890400E+00, 0.17632500E-01, -.16922700E-01, 0.70604300E-02, 0.11804900E-01, -.22233000E+00, 0.11825100E+00, -.10384100E+00, 0.12656800E+00, 0.55232000E+00, -.79007800E-01, 0.16032400E+00, -.77834900E-03, -.17406700E+00, -.41928700E-01, 0.14710900E+00, -.12543000E-01, 0.59747600E-01, -.49067700E-01, 0.66862400E-01, -.55372600E+00, 0.17469200E+00, -.19219200E+00, -.82958700E-01, 0.39746000E-01, -.37111900E-03, -.39593600E-01, 0.43868000E+00, 0.10479400E+00, -.39288300E-01, -.77713900E-01, 0.24138900E-01, 0.40783000E-01, 0.30701200E-01, 0.38260900E+00, 0.83408700E-01, -.77931000E-03, -.49357400E-01, -.13365500E+00, 0.49620800E-01, 0.50263500E-01, -.86582900E-02, -.22018300E+00, -.32476200E-01, -.11927400E+00, -.12612900E+00, -.49121600E-01, 0.80702200E-02, 0.50312600E-01, 0.84828100E-01, 0.55807600E-01, 0.38382000E-01, -.17491500E-01, 0.94520900E-01, 0.70243900E-01, 0.75196300E-01, -.94190900E-01, -.11273200E+00, 0.14259000E-02, -.11695200E+00, 0.58672600E-01, 0.11228900E-01, 0.62927700E-01, -.30905600E+00, 0.15504200E+00, -.81611100E-01, 0.11494200E+00, -.15746700E+00, 0.14331900E+00, -.82360400E-02, -.25876400E-01, -.11413200E-01, 0.36007100E-02, 0.10381900E+00, -.52947500E-01, 0.17804300E+00, -.32308500E+00, -.37403300E-01, -.15222000E-01, -.15687300E+00, 0.42425100E-02, 0.33534800E-01, 0.19217100E-02, 0.96978500E-01, -.12791100E+00, 0.76851600E-01, 0.13080700E+00, -.66133200E-01, 0.73872600E-01, 0.19707700E-01, 0.10522700E+00, -.14454900E-01, -.80612400E-01, 0.33144400E-01, 0.16626600E-01, -.33388900E-01, -.45508600E-01, 0.19515100E-03, -.15916000E-01, 0.17480000E+00, 0.21254300E+00, 0.21959100E-01, 0.52610400E-02, 0.73615900E-02, 0.61500200E-01, 0.76004600E-01, 0.89032500E-01, -.11425800E+00, -.28551300E-01, -.67716200E-02, 0.18277900E-01, 0.18618700E-01, 0.17161900E+00, -.12437500E-01, 0.18031400E-01, -.61155700E-01, 0.30414900E+00, -.14040200E-01, 0.88701300E-04, 0.10402800E+00, -.42117700E-01, 0.21035400E+00, -.29662700E-01, 0.24319800E-01, 0.30742700E-01, -.60951300E-01, 0.35179400E+00, 0.34461200E+00, -.16756300E-01, -.14237200E+00, -.14039000E+02, -.15247300E+02, 0.61170300E+02, -.31645200E+02, 0.20214000E+02, -.30671200E+02, -.36360000E+02, 0.32868000E+02, -.27693000E+02, 0.53277500E+01, -.59710300E+02, 0.25348600E+02, -.36464200E+01, -.14856000E+03, 0.75098600E+02, 0.69262500E+02, 0.74051200E+02, -.47088900E+02, 0.45135100E+01, 0.31086700E+01, -.91695800E+02, 0.89222600E+01, -.56233100E+01, 0.52986600E+02, -.20822300E+02, 0.12424700E+02, 0.88036700E+01, 0.96601600E+01, 0.47475900E+02, 0.23622000E+02, 0.14033000E+02, -.10727000E+01, 0.17809700E+02, 0.31644500E+02, -.45633900E+02, -.61523000E+02, 0.28957600E+02, 0.46831700E+02, 0.30788100E+02, -.27616100E+02, -.39788100E+02, 0.22762300E+02, -.30342400E+02, -.81526800E+01, -.11752400E+02, 0.65305500E+02, 0.59479300E+02, -.30462300E+02, -.44180800E+01, -.29580600E+02, -.28741200E+02, -.19922600E+01, -.28998500E+02, -.34203600E+02, -.55572900E+02, 0.10019600E+02, -.31989100E+02, 0.21213400E+03, -.10437100E+03, -.11307900E+03, -.10510900E+03, -.80849700E+02, -.24438000E+02, -.60205000E+01, 0.49954000E+02, -.94267200E+02, -.39023700E+01, -.11426900E+03, 0.71421400E+02, -.29645700E+02, 0.60700500E+00, -.34725800E+02, 0.20825600E+01, -.69561900E+01, 0.14533900E+02, 0.34067800E+02, 0.26905100E+02, -.16301400E+02, -.24041900E+02, -.32157000E+02, 0.16869100E+02, -.10291100E+02, 0.15979000E+02, 0.67754200E+02, 0.42011600E+02, -.25248900E+02, -.53922000E+01, -.76052300E+01, 0.39268600E+02, -.42792600E+01, -.10382500E+03, 0.53916100E+02, 0.17434200E+02, 0.51658600E+02, 0.78577800E+02, -.35147900E+01, 0.64733400E+01, -.41663700E+02, 0.48363600E+02, 0.11041300E+02, -.56064700E+02, -.53535100E+01, 0.37221800E+01, -.16541300E+02, -.44730900E+01, 0.85963400E+01, 0.52315100E+01, -.64374200E+01, 0.87111200E+01, 0.25219100E+01, -.45656300E+01, -.10341700E+01, -.12325700E+01, 0.17130600E+01, 0.21282800E+01, 0.30444200E+01, -.24384200E+01, 0.15691000E+02, 0.97708100E+01, -.39083600E+01, 0.11709000E+02, -.17357600E+02, 0.19001500E+01, 0.17142400E+01, 0.90394400E+01, 0.64307600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.66393600E+01, 0.56729800E+00, 0.15662200E+01, 0.57360200E+00, 0.77496200E+00, -.40663300E+00, 0.71174200E+00, 0.38050500E+00, 0.13945100E+00, 0.23188400E+01, -.49478700E-01, 0.10770800E+01, 0.67404200E+00, 0.30383800E+01, 0.60226300E+00, 0.48311200E+00, 0.33322600E+01, 0.32608400E+01, -.30286300E+00, 0.11476700E+01, -.22822900E+01, -.13942400E+00, 0.20627300E+00, 0.25637400E+01, 0.19572700E+00, -.35982400E+00, -.15681000E+01, -.16901400E+01, 0.74903600E+00, -.69767000E+00, 0.15769400E+00, 0.46050400E+00, 0.11419000E+01, -.93683500E+00, 0.47324600E+00, -.72378900E+00, 0.11277800E-01, -.62187400E-01, 0.58197200E+00, -.33410400E+01, 0.17095300E+00, -.10314200E+01, 0.16492600E+00, -.13493300E+00, -.28216300E+01, -.55955800E+00, 0.62380300E+00, -.47645100E+00, 0.14690000E+01, 0.35043700E+00, 0.20032400E+01, -.50962800E+00, -.37815800E+00, -.77250800E+00, 0.40606600E+00, 0.35501400E+00, 0.55744300E+00, 0.15991500E+01, -.62793600E-02, -.25357700E+01, 0.18815900E+00, -.42495200E+00, 0.75592600E-01, 0.42231100E+00, 0.19616500E+01, -.31748600E+01, 0.45444100E+00, -.16862400E+01, -.39929600E+00, 0.59887700E-02, 0.10164900E+01, 0.18634500E+00, -.66518000E+00, -.13955700E+01, -.18808100E+00, 0.17902700E+01, 0.20237500E+00, -.12733400E+01, 0.58038400E+00, -.13605300E+00, 0.20887000E-01, 0.53664700E+00, 0.59970300E+00, -.26825100E+00, 0.43740400E+00, 0.19169100E+00, -.20015700E+00, 0.56577700E-01, -.32857600E+00, -.48271800E+00, -.42555800E+00, -.19118800E-02, -.66204900E+00, 0.23349500E+00, 0.83432500E+00, -.11068800E+00, -.84263800E+00, 0.74050300E+00, -.14090300E+00, 0.23381700E+00, -.47255500E+00, 0.10556800E+00, -.41805700E-01, -.10773600E+00, 0.29837200E+00, -.36001100E-01, -.70744100E+00, -.43476300E+00, 0.31841400E+00, -.22192300E+00, 0.38252700E+00, 0.46547300E+00, -.67005300E-02, 0.36134400E-02, 0.11845200E-02, -.94663600E-01, -.16809000E+00, -.11833600E+01, -.21143300E+00, 0.10214700E+00, -.28054700E+00, 0.65059400E+00, -.23974800E-01, 0.14880300E+00, -.58629300E-03, -.21902600E+00, 0.53573100E+00, -.28910500E+00, 0.58213300E-01, -.31426200E+00, 0.10931000E+01, -.25686100E+00, 0.76010300E+00, -.28652400E+00, -.10297400E+00, -.55326400E-01, 0.78666600E+00, 0.66531300E-02, 0.15985700E+01, -.41142100E+00, -.62026100E-01, -.12897200E+00, -.21804500E+00, -.91366100E-01, -.29297700E+00, -.62081200E+00, 0.54644400E-01, 0.27891100E-01, 0.92807800E+00, 0.18121300E+00, -.35197600E+00, -.23073800E+00, 0.42652500E-01, -.23211400E+00, 0.11962900E+01, -.96818100E-01, -.13636900E+00, 0.82649300E-01, -.94797800E-02, -.12070400E+00, 0.15497400E+01, -.25467900E+00, -.35300600E+00, -.93741300E+00, 0.18827400E+03, 0.20040300E+03, -.10296400E+03, 0.22566400E+02, -.99293300E+02, -.36934100E+02, 0.56488100E+02, -.69971400E+02, 0.42991400E+01, -.18771000E+03, 0.40561300E+02, -.13710000E+03, 0.53606400E+02, -.25018600E+02, 0.80845000E+01, -.27648300E+02, -.27461300E+02, -.52832300E+02, 0.10865200E+01, -.44777700E+02, -.64416700E+02, -.34516800E+02, -.40042600E+01, -.10026800E+02, 0.10004900E+02, 0.57886800E+02, 0.27165500E+01, 0.10034400E+03, 0.30246600E+02, 0.18675100E+02, -.21775100E+02, -.10622900E+03, 0.72613200E+02, -.11464000E+03, 0.11374700E+02, -.10582000E+02, 0.55535900E+02, -.56145800E+01, -.63275100E+02, -.11893300E+03, 0.52049900E+02, 0.38993800E+02, -.22995900E+01, -.62921600E+02, -.97464600E+02, 0.24042500E+03, -.12276400E+03, -.36530400E+02, -.11978400E+03, -.57536500E+02, 0.19330700E+02, -.86616800E+02, -.41592700E+02, -.15792200E+03, 0.37780100E+02, -.20536700E+03, -.30094600E+02, 0.19185100E+02, -.46052900E+02, 0.17567300E+02, -.61951200E+02, -.65840900E+02, 0.20402900E+02, 0.15094500E+03, -.67600300E+02, 0.18989100E+02, 0.56393600E+02, 0.13454800E+03, -.65181700E+02, -.27953400E+02, -.64974000E+02, -.21882200E+02, -.10396400E+03, 0.46867900E+02, 0.15068300E+02, 0.96271100E+01, -.10060200E+03, -.16930900E+02, 0.82788700E+02, -.33528500E+02, -.26152200E+02, -.41439800E+02, 0.27398600E+02, 0.60433400E+02, -.24488200E+02, 0.21011100E+02, -.40555100E+02, 0.50732200E+02, -.12182400E+03, -.12956100E+03, 0.70814000E+02, -.39938900E+02, 0.64115300E+02, 0.23752500E+03, 0.50694700E+02, -.78069400E+01, -.90933400E+02, 0.52230100E+02, 0.45329400E+02, -.29190500E+02, 0.20065600E+02, 0.12151200E+02, -.34865800E+02, -.31126800E+00, 0.29089700E+01, 0.15073200E+02, -.20081300E+02, 0.25050600E+01, 0.25850200E+01, -.14726900E+02, 0.31719800E+02, 0.27203000E+01, 0.16420700E+02, 0.19854900E+01, 0.36879100E+01, -.81948800E+01, 0.38259900E+02, 0.32225400E+02, -.25127400E+02, 0.56012000E+01, -.38080700E+02, 0.22970600E+02, -.66173300E+01, 0.46300000E+02, 0.14835900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.55381700E+01, 0.28188400E+00, -.23573300E+01, 0.33302500E+01, 0.18023000E+01, -.18278100E+01, 0.46256400E+00, 0.68221500E-01, -.68139700E+00, 0.13741000E+01, 0.11093600E+01, -.53444000E+00, 0.42111700E+00, 0.41569300E-01, -.67940400E+00, 0.80527000E+00, 0.44428700E+00, -.69690100E+00, -.19835200E+00, -.27726500E+00, -.12223100E+01, -.39162300E+00, 0.50027000E-01, 0.17181300E+01, 0.44117200E+00, 0.99315100E+00, 0.20061000E+01, 0.12566900E+01, -.10075900E+01, 0.61600200E+00, 0.29215800E-01, 0.10329700E+01, 0.80195400E+00, -.58160900E+00, 0.12458300E+00, -.56533500E+00, 0.10158900E+00, -.27480900E+00, -.32777400E+00, -.12745000E+01, -.41423100E+00, 0.11843300E+00, -.25728000E+01, -.22916200E-01, 0.45380800E+00, -.16683700E+00, -.19023100E-02, -.10936800E+01, -.22911500E+00, 0.10794300E+00, -.45855000E+00, 0.38151400E+00, 0.16082600E+00, -.12660500E-01, 0.11501300E+01, 0.31503700E+00, 0.10069700E+00, -.33706800E+00, -.96712100E-02, 0.51138600E+00, -.41506200E+00, 0.13356900E+00, 0.14279700E+00, 0.14996300E+00, 0.12231500E+00, 0.44154400E-01, 0.23258300E+00, 0.55266200E+00, -.80967900E-01, 0.19784100E-01, -.12284000E+00, 0.65203600E-01, -.69708700E+00, -.64520700E+00, 0.75813900E+00, 0.17208200E+00, 0.10666900E+00, -.21235900E+00, 0.89399500E-01, 0.28809000E+00, -.42957300E-01, 0.33789700E+00, 0.15486500E+00, -.32599800E+00, 0.80401400E-01, 0.70418200E-02, 0.63099900E+00, 0.86507300E-01, -.66325900E+00, 0.26563500E+00, 0.32933800E+00, 0.57964100E-02, 0.80975300E+00, -.43988000E-01, 0.32971300E+00, -.92399900E-01, -.19846000E+01, 0.83576100E+00, -.25153500E+00, 0.70412300E+00, -.13186600E+01, -.59902100E+00, -.43810400E-01, -.16319100E+00, -.12879100E+00, -.48415700E+00, -.54663800E+00, -.59056300E-01, 0.54292500E+00, -.57283300E-01, 0.66807200E+00, 0.22934900E+00, -.21996500E+00, 0.33770000E-01, 0.88078200E-01, 0.53410800E-01, -.30124900E+00, 0.46716000E-01, 0.50429500E+00, -.12648000E+00, -.17626500E+00, -.10621300E+00, 0.60997000E-01, 0.25743600E+00, -.73778000E-01, -.80353700E+00, 0.18153900E+00, -.10452800E+00, -.22506600E-01, 0.25601200E-01, -.37094700E+00, -.35308000E+00, 0.30232200E+00, -.21203100E+00, -.55159600E-01, -.42056300E-02, 0.62190800E+00, -.12744800E+00, 0.27305300E+00, 0.26594700E+00, -.21454600E+00, 0.75023500E-01, 0.10856600E+00, -.12495800E+00, 0.23819600E+00, -.49474100E+00, 0.45422600E-01, -.16931900E+00, 0.44491400E-01, 0.79712500E+00, -.35562100E+00, -.54562200E-01, -.37167200E+00, -.19242900E+00, 0.52763800E+00, -.23274400E+00, -.67085300E-01, -.15463100E+00, -.26305100E+00, -.40800500E+00, 0.32544700E+00, -.11492800E+00, -.48025000E+00, -.85853200E+00, -.20736400E+00, 0.51061900E+03, -.26106300E+03, -.20743400E+03, -.25651500E+03, -.16071100E+03, -.62504800E+01, -.14440100E+03, 0.81749800E+02, -.21731800E+03, -.41442300E+02, -.56238100E+01, -.18674500E+03, 0.93964600E+02, 0.28174800E+03, 0.93584500E+02, -.94084800E+02, 0.60050900E+02, -.24032600E+02, -.20407300E+03, -.50278800E+02, 0.44391300E+02, -.26407900E+02, 0.65945800E+02, -.27542700E+02, 0.10715600E+03, -.33487000E+02, 0.14118600E+03, 0.13307300E+02, 0.43974100E+01, -.47387900E+02, -.16392300E+03, 0.54786400E+02, -.11916200E+03, -.29178500E+02, 0.94317700E+01, 0.10095500E+03, 0.14633300E+02, -.61172300E+02, -.15894300E+03, 0.23241400E+02, -.65744300E+02, -.64804000E+02, -.68258400E+02, 0.18066500E+03, 0.29659300E+03, -.15184700E+03, -.69731700E+01, -.14800800E+03, -.35600500E+02, 0.37942700E+02, -.11230200E+03, -.20096400E+02, -.17331500E+03, 0.50876700E+02, -.13596200E+03, 0.58075000E+03, -.28335900E+03, -.26832200E+03, -.28938100E+03, -.17784300E+03, 0.47046200E+00, -.29744500E+02, 0.24117100E+03, -.26559300E+03, 0.85896100E+02, -.16710000E+03, 0.33965200E+03, -.15480300E+03, -.11660500E+03, -.16728700E+03, -.16760100E+03, -.29391300E+03, 0.23305700E+03, 0.19565200E+03, 0.18093000E+03, -.32326900E+03, -.17027600E+03, 0.48827900E+02, -.27967300E+02, 0.13863100E+01, -.24468900E+02, 0.15401900E+03, 0.99544800E+02, -.65094900E+02, 0.39635500E+02, -.69852100E+02, 0.72853900E+02, -.16857500E+03, -.43175600E+03, 0.22544800E+03, 0.17268100E+02, 0.21535800E+03, 0.36321800E+03, 0.10433000E+03, 0.12110900E+03, -.52449300E+02, 0.14995200E+03, 0.10464200E+03, -.26308600E+03, 0.14632300E+02, 0.16479000E+02, -.69893300E+02, -.14261600E+02, 0.66065600E+02, 0.24900900E+02, -.29115700E+02, 0.67299100E+02, -.59040600E+02, -.13798800E+02, 0.23814200E+02, 0.53975700E+01, 0.64966900E+01, -.59962300E+02, 0.16477200E+02, -.14876200E+02, 0.62267200E+02, 0.31615400E+02, -.36648600E+02, 0.26272600E+02, -.45340100E+02, 0.10676800E+02, 0.32643000E+02, 0.59169100E+02, 0.87653400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.91476100E+01, -.24714500E+00, 0.77622000E+01, 0.79746700E+00, -.60072300E+01, 0.16246700E+01, 0.20372700E+00, -.68736400E+00, 0.47059800E+00, -.78119300E+00, 0.55021900E+00, -.80543500E+00, -.46267700E+01, 0.62536400E+01, 0.12543900E+01, 0.91954400E+00, 0.39998900E-01, 0.54280700E+01, 0.23373900E+01, 0.11140800E+01, 0.82995800E+00, 0.95889000E+00, 0.69519000E+00, -.19316400E+00, -.41935200E+00, -.19557900E+01, -.22923800E+01, 0.38453900E+01, 0.13050900E+01, -.16640900E+01, 0.48736800E+00, -.77661100E+00, -.43085600E+01, -.13610600E+01, 0.47320400E+00, 0.25118900E+00, -.68801800E-01, -.39765300E+00, 0.18413200E+01, 0.13159000E+01, 0.16049300E+01, -.24087300E+00, 0.34418000E+01, -.35744500E+00, -.16632400E+01, -.92421500E-01, 0.34512200E+00, 0.11078800E-01, -.37451200E+00, -.12511800E-01, -.66298300E+00, 0.47101600E+00, -.55589700E+00, 0.84523500E+00, 0.96500800E+00, -.41853400E+00, -.48423000E-01, 0.31657600E+00, 0.17479300E-02, -.32424100E+00, -.70778400E+00, -.30536500E+00, 0.19206800E+00, 0.61425700E+00, 0.12448900E+01, 0.96464300E+00, 0.14804200E+00, 0.48864500E+01, 0.63844800E-01, -.51749500E-02, 0.84910300E+00, -.28194200E+00, 0.82321800E+00, 0.72498000E+00, 0.16520400E+00, -.68425100E+00, -.28307800E+00, 0.70988000E+00, -.78389800E+00, 0.47924400E+00, -.13210200E-01, 0.69470500E-01, -.55314300E+00, 0.45145300E+00, -.11471700E+00, -.35675400E+00, 0.57206900E+00, -.65800000E-01, 0.24179700E+01, 0.44468400E-01, 0.26076200E+01, -.38426400E-01, -.69503900E-01, -.78323500E-01, -.98942700E+00, -.23618000E+00, 0.10670500E+01, -.12351300E+01, 0.33207400E+00, 0.86040900E-01, -.13856400E+00, -.71905200E+00, -.25288600E-03, 0.20851300E+00, 0.79140200E-01, -.59018200E+00, 0.29240200E-01, 0.46502700E+00, 0.33440100E+00, -.11054700E+01, 0.19246000E+00, 0.54402100E+00, 0.64317800E+00, 0.54096300E-01, -.31168700E+00, -.47084900E-01, -.25667400E+00, -.28170600E+00, -.30838800E+00, 0.82690300E+00, -.29208900E+00, 0.40051000E-01, -.19359800E+00, -.30188900E-03, -.30736500E-01, 0.17870100E+00, -.11588100E+00, 0.79267900E-01, -.59685200E-01, 0.21529500E+00, 0.20412900E+00, -.75511500E-01, -.82280900E+00, -.12578000E+00, -.81049500E-01, 0.43175400E-01, -.49347400E+00, -.24800800E+00, -.73319500E-01, -.38968100E+00, 0.70973400E-01, 0.10430400E-01, -.26256600E+00, -.49636000E+00, -.17740400E+00, 0.47513200E+00, 0.61004300E-01, 0.53430000E-01, 0.26982300E+00, -.13174000E+01, -.87071100E-01, 0.82523300E-02, -.17771600E-02, -.19099500E+00, -.28010900E+00, 0.26261400E-01, -.12993200E+00, -.61878800E-01, -.13428300E+00, 0.36745500E+00, -.24625200E+00, 0.19880200E-01, 0.13070500E+00, 0.27403000E+00, 0.42290400E-03, -.15858000E+00, 0.14449000E+02, 0.13185300E+02, -.13396200E+01, -.15604500E+02, 0.34696700E+01, -.85975500E+00, 0.27797600E+02, 0.13215400E+02, -.97186100E+01, 0.48699200E+01, 0.43586800E+02, -.23399600E+02, -.44796900E+02, -.21327800E+02, -.27566000E+02, -.68841200E+01, -.20817300E+02, 0.12777300E+02, 0.39821000E+02, -.13476400E+02, -.35881200E+02, 0.58693300E+01, -.67339500E+01, -.19003200E+02, -.22006000E+01, 0.17045700E+02, 0.69289700E+01, -.29704900E+01, -.10830100E+02, -.16858300E+02, 0.54470900E+01, -.24397900E+01, 0.39152900E+02, -.18131800E+02, -.40738600E+02, -.19586600E+02, 0.15371500E+02, 0.19648200E+02, 0.31845000E+02, 0.17481500E+02, -.27243500E+02, 0.12869000E+02, -.30841300E+02, -.27168300E+02, 0.14915400E+02, 0.22508700E+02, 0.13538300E+02, 0.61364400E+01, 0.65052400E+01, 0.29723500E+02, 0.25533500E+02, 0.45973700E+01, 0.50921100E+01, 0.10525500E+02, 0.14760400E+03, -.76993700E+02, -.11361400E+03, -.74406800E+02, -.25618100E+02, 0.21851300E+02, 0.10491300E+01, 0.60569200E+02, -.42910500E+02, 0.18434600E+02, -.21906900E+02, -.50486300E+01, 0.51984900E+01, -.37974800E+02, 0.27894700E+01, -.80546700E+01, -.43729700E+02, 0.25967600E+02, -.64748500E+01, 0.36791500E+02, -.42403600E+02, -.17454400E+02, -.27302400E+02, 0.12627700E+02, 0.12239900E+02, 0.13640500E+02, 0.37398900E+02, 0.96118500E+01, 0.89931400E+01, 0.13647800E+01, -.30690000E+01, 0.35033800E+01, -.54897800E+01, 0.56492400E+02, -.30853100E+02, -.24829300E+02, -.28208800E+02, 0.32972500E+02, 0.91568900E+01, -.33944100E+02, 0.57158900E+01, -.14692200E+02, 0.28471900E+01, -.40216100E+02, 0.16308100E+00, 0.89274200E+00, -.95243200E+01, -.15116900E+01, 0.45509000E+01, 0.44811200E+01, -.17856400E+01, 0.46129300E+01, -.25110800E+01, 0.11780000E+01, -.78217700E+00, -.36264100E+00, -.17860900E+01, -.26727200E+01, 0.28684200E+01, -.19937900E+01, 0.10714100E+02, -.41236400E+01, -.46811600E+01, 0.37087000E+01, -.47926500E+01, -.98367600E+00, 0.31941900E+01, 0.50111700E+01, -.15522100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22561700E+02, 0.22902000E+01, 0.13823100E+01, -.62334500E+01, -.10076900E+02, -.73477400E+00, 0.39828400E+01, -.25003700E+00, -.63699700E-01, 0.38191200E+01, 0.36571400E+01, -.10113400E+01, -.18546600E+01, -.81009000E+00, 0.55281000E+00, 0.42475300E+01, 0.51482900E+01, 0.44644700E+01, -.20912400E+01, 0.46212700E+01, 0.12924200E+01, -.18995900E+00, 0.29077800E+01, 0.70637300E+01, 0.71401400E+00, 0.21195700E+01, -.18283700E+01, 0.52261400E+01, 0.10396400E+01, -.73352200E+00, 0.55445100E-01, 0.39054600E+01, -.30484500E+01, 0.42072200E+01, -.67506200E+00, 0.86404900E-02, 0.15909300E+00, -.36662900E+00, 0.13902000E-01, 0.87305100E+00, 0.35736100E+00, 0.23427000E+01, -.31641500E+01, -.62040100E+00, 0.10942100E+01, -.49920100E-01, 0.20170100E+01, 0.41730900E+01, 0.40195000E+01, 0.20119500E+00, -.71880100E+00, -.99013200E+00, 0.22001200E+01, 0.65472800E+00, -.34907800E+01, 0.34603000E-01, 0.88805000E+00, 0.45037300E+00, 0.10127300E+01, 0.13340400E+01, -.13703200E+01, -.19379800E+01, 0.57311700E+00, 0.57866800E+00, 0.26768600E+01, -.31341800E+01, -.42236900E+00, -.14495100E+02, 0.43836500E+00, -.10755500E+01, 0.36716000E+00, -.19130800E+00, -.28581700E+01, -.19019300E+01, 0.28167600E+01, -.30956700E+01, 0.10080300E+00, 0.28003600E+01, 0.77832000E+00, -.28235900E+00, 0.17231200E+01, -.38492300E+00, 0.99922000E+00, 0.27860300E+01, 0.16045100E+00, -.35464000E+00, -.19430500E+01, -.16440800E+01, 0.38548600E+01, -.56722700E+00, 0.19008700E+01, -.45010900E+00, -.11951100E+01, 0.21049100E+00, -.30776000E+01, 0.82850600E-01, -.20372900E+01, -.73524500E+00, 0.12484200E+01, -.26822600E+00, 0.13078100E+00, 0.31577100E+01, -.51622300E+00, 0.38417700E+00, -.62175300E-01, 0.18147400E+01, 0.12023600E+01, -.93206000E+00, -.15387300E+01, 0.11941200E+01, -.30118000E+01, -.92832300E+00, 0.54104500E+00, -.81344100E+00, 0.79055100E+00, -.70073100E+00, 0.99649700E+00, -.22470300E+01, 0.13902800E+01, 0.85610100E+00, -.45473000E+00, 0.81207800E+00, 0.24710100E+00, 0.77540900E+00, 0.82819900E+00, 0.98525600E+00, 0.80670200E+00, -.23510700E+00, 0.31902100E+00, 0.18625700E+00, 0.42888600E+01, -.16023600E+01, -.18242300E+01, 0.14876300E+01, -.20944000E+00, 0.16317700E+00, -.19962900E+01, -.28184400E+01, -.11569000E+01, -.12596900E+01, 0.45538300E+00, 0.62780700E+00, -.78959700E+00, -.63266300E+01, 0.12401900E+01, 0.75337000E+00, -.12758700E+00, -.48130100E+00, -.10729700E+01, 0.71557600E+00, -.21337000E+01, 0.29747700E+00, -.46011400E-01, 0.51249000E-01, -.15360300E+01, 0.55661800E+00, -.23707000E+00, -.30170800E+00, 0.39170100E-01, -.72295100E+00, 0.19851900E+01, 0.34299900E+00, 0.49458600E+00, -.31871200E+00, -.16849500E+01, -.22817400E+01, -.73395500E+00, -.54287100E+03, 0.16221800E+02, -.49851400E+03, -.15179700E+03, -.13358500E+03, 0.13411300E+03, -.25450600E+03, -.23596800E+03, 0.76302300E+03, -.35925800E+03, 0.18748900E+03, 0.31913400E+03, 0.17757800E+03, 0.36000200E+02, 0.86924100E+02, -.64079800E+02, -.39011900E+03, 0.20417400E+03, 0.44568300E+02, 0.13340800E+03, 0.15803100E+03, -.66434800E+02, -.72939900E+02, -.84483900E+02, 0.24325400E+03, -.86164400E+00, -.22063900E+03, -.38289500E+03, -.36133900E+03, 0.11650000E+03, -.10469900E+03, -.81464800E+03, 0.39389800E+03, 0.35408300E+03, 0.40740800E+03, -.22611000E+03, -.39653700E+03, 0.28282600E+03, -.28002400E+03, 0.13057300E+03, -.28207300E+03, 0.58248900E+03, 0.86274100E+03, -.44123700E+03, 0.43758800E+02, -.43086300E+03, -.27702700E+03, 0.62091800E+02, -.13067200E+03, 0.44810200E+02, -.50208800E+03, 0.93593000E+02, -.39970200E+03, 0.18807400E+04, -.94894300E+03, -.15137500E+04, -.93980200E+03, -.89642400E+02, 0.12399600E+03, -.17121500E+03, 0.64383300E+03, -.63821400E+03, 0.22751500E+03, 0.51946200E+01, 0.16506300E+04, -.76445200E+03, -.26110200E+03, -.81598400E+03, -.47452900E+03, -.61423500E+03, 0.33798800E+03, 0.39129100E+03, 0.29965300E+02, -.64221100E+03, -.68253200E+03, 0.27910600E+03, -.91806600E+02, -.41172100E+02, -.14319000E+03, 0.12442200E+03, 0.17207400E+03, -.13065600E+03, 0.78724500E+02, -.27608400E+03, 0.12924800E+03, -.58252900E+03, 0.13702400E+03, -.52221600E+02, -.47635300E+03, -.69000800E+02, 0.11194800E+04, 0.36379800E+03, -.77290500E+02, -.93507800E+02, 0.61870800E+02, 0.35329500E+03, -.13155200E+04, 0.63445600E+02, 0.38040600E+02, -.12252000E+03, -.16732200E+02, 0.15428600E+03, 0.64109300E+02, -.65500800E+02, 0.15091500E+03, -.23311500E+02, -.39133200E+01, 0.84556500E+02, 0.14282900E+02, 0.29689700E+02, -.26763200E+02, 0.32428600E+02, -.21514300E+02, 0.20306100E+03, 0.75083600E+02, -.10155500E+03, 0.98245000E+02, -.12698700E+03, 0.33782300E+01, 0.28558500E+01, 0.15214900E+03, 0.28801000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23933500E+01, -.17252700E+00, 0.12441300E+01, 0.38654000E+00, 0.10303400E+01, 0.96340000E+00, -.11798000E+01, 0.91570700E-02, 0.59436700E-01, 0.56412600E-01, -.23076100E-01, 0.47494700E+00, 0.45844300E+00, 0.44675800E+00, 0.10929800E+00, -.72368100E+00, 0.24305000E+00, 0.71021100E+00, 0.30433000E+00, -.11370100E+00, -.11941700E+01, -.39545200E-01, -.60255200E-01, 0.22160000E+00, -.15539900E-01, 0.15835900E+00, -.43588500E+00, -.15360000E+01, 0.42557000E+00, -.16205200E+00, -.53587500E-01, -.17510900E+00, -.33870900E+00, 0.42616900E-01, -.21593000E+00, 0.15735100E+00, -.11174900E-01, 0.18607000E+00, -.52718400E-01, 0.10485100E+01, 0.19156100E+00, 0.64419300E+00, -.22840800E+01, 0.14779700E+00, 0.56838300E+00, 0.72984800E-01, 0.37521800E+00, -.18210200E+00, 0.52086300E+00, 0.16315800E+00, 0.12588700E+00, -.39428700E+00, 0.22442400E+00, -.75007500E+00, -.88742600E+00, 0.33065300E+00, -.37940400E-01, 0.14892300E+00, -.18427500E-02, 0.12670100E+01, 0.95546300E+00, 0.25497900E+00, 0.38095700E-01, 0.28537300E+00, 0.99661600E-01, -.30835000E+00, 0.14438000E+00, 0.38178300E+00, -.90953100E-01, 0.12014700E-02, 0.26421000E-01, -.20371200E+00, -.52910600E+00, -.23363100E+00, 0.39577600E+00, -.38700800E+00, -.18532800E-01, 0.43710200E+00, -.21873100E+00, 0.91793900E-01, 0.96977900E-02, 0.69332100E-01, -.23478000E+00, 0.13181400E+00, -.10857300E+00, -.86137300E-03, 0.54689900E+00, -.22104300E-02, 0.83047600E+00, -.39773900E+00, 0.19715100E+00, -.13648300E-01, 0.32915100E+00, -.12567400E+00, -.27495100E+00, 0.19142700E-01, -.58132100E+00, -.11636400E+00, -.94638200E-01, -.92701200E-02, -.15636400E+00, 0.26290800E+00, -.17444900E-01, 0.21432300E+00, -.23630300E+00, -.18127800E+00, 0.37726600E+00, -.38355100E-01, 0.25340700E-01, -.26171600E+00, -.14485500E+00, 0.10786100E+00, 0.39052200E+00, 0.61720100E-02, -.85327100E-01, -.42755800E-01, 0.31934400E-01, -.41865100E+00, -.33375800E+00, 0.40923700E+00, 0.50067800E-01, 0.19996600E+00, -.29301000E-02, -.32383400E-01, 0.58834700E-02, -.10182900E+00, -.42808000E+00, 0.48271200E-01, 0.28925000E-01, -.68858200E-01, 0.33116800E+00, 0.60410000E-01, -.27848600E+00, -.43765400E+00, 0.55345500E-01, -.17328500E-01, 0.29170300E+00, -.22623800E+00, 0.44982900E+00, -.51138400E-01, 0.10485300E-01, 0.24274000E+00, 0.20865500E+00, -.66196000E+00, 0.70066000E-01, -.56961400E+00, -.40488200E-01, -.95285400E-01, 0.18619000E+00, 0.10331300E+00, -.23073300E+00, -.27857100E-01, -.21691900E-02, 0.53462500E-01, -.39322500E+00, 0.18657800E-01, -.19502500E-01, -.20390500E-01, -.62909200E-01, -.22204900E-01, -.51333100E+00, 0.57297700E-01, 0.34107100E+00, 0.11388200E+01, -.31543400E+00, -.20386200E+00, -.62020400E-02, 0.10982200E+00, -.25541100E+01, 0.35805200E+02, -.34417100E+02, 0.15331700E+02, -.41573200E+02, -.17325800E+02, -.13135600E+02, -.45478000E+02, 0.11995700E+03, -.60926800E+02, -.53734000E+02, -.59396400E+02, -.24404000E+02, -.53137300E+02, 0.31650800E+02, 0.53103700E+02, -.14045600E+02, -.31437900E+02, -.24201500E+02, 0.74457500E+02, -.37336100E+02, -.35151200E+02, -.35792700E+02, -.66286300E+02, -.45269300E+02, 0.52964600E+02, 0.51870600E+02, -.16321900E+02, -.40570600E+02, -.33842800E+02, 0.68641100E+02, -.35007700E+02, -.26791400E+02, -.34355100E+02, 0.34449100E+02, 0.12172800E+02, -.53327100E+02, 0.21900200E+02, 0.51279500E+01, 0.19110600E+02, -.34061500E+02, 0.26385400E+02, -.12757700E+02, -.44309000E+02, -.13395400E+02, 0.21310300E+01, -.16977900E+02, -.24329700E+02, -.19928000E+02, -.15043000E+02, -.12116700E+02, -.13426800E+02, -.21808500E+03, 0.11070700E+03, 0.10519400E+03, 0.10812300E+03, 0.19888000E+00, -.90067900E+02, 0.31210900E+02, -.52258600E+02, 0.69138400E+02, -.59108400E+02, 0.12047300E+03, -.93356700E+02, 0.40306500E+02, 0.57650800E+02, 0.45040100E+02, 0.14721500E+02, 0.14437000E+02, 0.76968400E+01, -.17793600E+02, 0.46055900E+01, 0.20838000E+02, 0.46114200E+02, 0.14514300E+02, -.11145800E+02, 0.73767100E+01, -.69091500E+01, -.98240600E+01, 0.13761900E+02, -.43643300E+00, -.80875700E+01, -.31181700E+02, 0.12506700E+02, -.77394800E+01, -.62917200E+00, 0.16327500E+01, 0.71708600E+01, 0.59394500E+00, -.90057200E+02, 0.18521700E+02, 0.23455800E+02, 0.82395200E+01, -.87641800E+01, 0.68548300E+01, 0.75244200E+02, 0.35498000E-03, -.39843800E+01, 0.13437900E+02, -.12028100E+01, -.91324700E+01, -.89406500E+01, 0.54827700E+01, -.92677500E+01, 0.66532100E+01, 0.95992600E+00, -.79404000E+00, -.84116200E+00, 0.23372400E+01, 0.67717400E+01, -.60524000E+01, -.95465000E+00, -.32641000E+01, 0.59292200E+01, 0.75760000E+01, -.15073400E+02, 0.63361000E+01, 0.72927900E+01, -.32669800E+01, -.11037000E+01, -.60304300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.56501600E+01, 0.62744800E+00, 0.44771400E+00, 0.35520200E+01, 0.29999700E+01, -.27248500E+01, 0.72186200E+00, -.13599600E+00, -.13492500E+01, 0.11614700E+01, -.38491700E+00, 0.41375600E+00, -.38803500E+00, -.30686400E+01, 0.29456200E+00, 0.40104700E+00, 0.55107700E+00, -.23824200E+01, 0.18727900E+01, -.10534600E+01, -.97043500E+00, -.23023300E+00, 0.12201000E+00, 0.14638900E+01, 0.89416500E-01, 0.42581700E+00, -.11600200E+01, -.68446700E+00, -.11406800E+01, 0.54429800E+00, 0.78221900E-01, -.57652900E-01, -.19088300E+00, 0.25927300E+00, 0.36002200E-02, 0.14864800E-01, -.36808800E-01, -.10743300E-01, -.26138000E+00, 0.42471000E+00, 0.18754600E-01, -.18444100E+00, -.12760300E+01, 0.18701800E+00, 0.33833800E-01, -.14701100E+00, 0.18396600E+00, -.56532000E-01, 0.12458200E+01, 0.39301500E-01, 0.12189900E+01, -.20169600E+00, -.32160100E+00, -.12265400E+01, -.92416700E+00, 0.15628000E+01, -.19149300E+00, 0.53933400E+00, 0.53728700E-02, 0.64052600E+00, 0.38256900E+00, 0.29331600E+00, -.17994400E-01, -.12421800E+00, -.93023600E+00, -.24433600E+00, -.11270700E+00, -.28549200E+01, -.41797600E-01, 0.32201100E-02, -.28073900E+00, 0.15554100E+00, -.65370900E+00, -.31710900E+00, 0.85518500E+00, 0.13879900E+00, -.17187200E-01, 0.35696600E+00, 0.36098300E+00, -.64300000E-01, 0.12966500E-01, -.52929400E+00, 0.16250600E+00, 0.32961000E+00, 0.88583000E-01, 0.11575400E+00, 0.91221600E-01, -.54651400E-01, -.12042300E+01, 0.37257900E+00, -.23032100E+00, 0.63958800E-02, 0.15267700E+00, -.53620500E-01, 0.13878200E+00, -.31291400E+00, -.11687700E+01, 0.72046200E+00, 0.10376300E+00, 0.16042900E+00, -.71229200E+00, -.28856200E+00, -.38475400E-01, -.34495800E+00, 0.75683800E-01, -.46060500E-01, -.72963300E+00, -.70148600E-01, 0.44415200E-01, 0.50359700E+00, 0.31327400E+00, 0.25768400E-01, 0.13005000E+00, -.22125000E-01, -.12674000E+00, -.67752300E-01, -.16930800E+00, -.36483200E+00, 0.26649100E+00, -.14943200E+00, -.21767500E+00, -.17444900E+00, -.26881200E-01, 0.56211300E+00, 0.45612800E-01, -.36932100E+00, 0.37700800E+00, -.17690100E+00, 0.57985600E-02, 0.17194200E+00, -.18046400E+00, -.45416100E+00, 0.44171100E-01, -.12540500E+00, 0.11757200E+00, -.10558300E-02, 0.30901100E+00, -.12408500E+00, -.27223700E-01, 0.16732600E+00, 0.18527200E+00, -.12303900E+00, 0.71577800E-01, -.32949300E+00, 0.22852300E+00, -.96529800E+00, 0.10956200E-01, -.88966200E-01, 0.38241900E+00, 0.10965900E+01, -.20779900E+00, 0.13419500E+00, -.29317900E-01, -.62358100E-01, -.25300800E-01, -.17642300E-01, -.60693800E-01, -.11429000E+00, -.16233000E+00, -.40921400E+00, 0.74420200E+00, -.42077700E-01, -.25212800E+00, 0.22409300E+00, 0.54420100E+00, -.64898300E+00, -.17643100E+00, -.10757300E+00, -.30164000E+00, -.13036300E+03, 0.28307700E+02, -.37956200E+02, 0.42045700E+02, -.10366500E+03, -.38453300E+02, 0.39396800E+03, -.83215500E+02, 0.40835100E+02, 0.20522000E+03, 0.42436000E+02, -.65654000E+02, 0.51537800E+02, -.52787200E+02, -.11725300E+03, -.93752600E+00, 0.53222100E+02, -.15390500E+03, 0.24061900E+03, -.12028900E+03, -.30352200E+02, -.11877200E+03, 0.43601800E+02, -.58644900E+02, -.45169000E+01, -.84836600E+01, -.13378400E+03, -.30095300E+02, -.16692000E+03, 0.82623100E+02, -.42110000E+02, 0.41933500E+02, -.41349600E+02, -.10244800E+03, -.62105200E+02, -.87031300E+02, -.21303000E+03, -.16573400E+03, 0.11635700E+02, 0.10752000E+03, 0.14184600E+03, -.72621500E+02, 0.24402600E+02, -.71127600E+02, 0.28193600E+01, 0.36126900E+02, -.75416900E+02, -.44005500E+02, -.11619000E+03, 0.69004300E+02, -.47656300E+02, 0.43832300E+03, -.22062300E+03, -.19113300E+03, -.22099800E+03, -.12539200E+03, 0.49071000E+02, 0.12536600E+02, 0.24214800E+03, -.17368600E+03, 0.12956900E+03, -.30050000E+03, 0.35265600E+03, -.15783500E+03, -.18227500E+03, -.17623300E+03, -.18648800E+03, -.30909200E+03, 0.23506300E+03, 0.13821100E+03, 0.14338600E+03, -.30904700E+03, -.26388100E+03, 0.92169000E+02, -.47149700E+02, -.32225500E+02, -.46349700E+02, 0.11490200E+03, 0.66192900E+02, -.51210900E+02, 0.49958400E+02, -.70162900E+02, 0.46732800E+02, -.14132800E+03, -.35405900E+03, 0.18025100E+03, -.43608800E+02, 0.17732500E+03, 0.33247400E+03, 0.16912800E+02, 0.12047900E+03, -.55159700E+02, 0.14525700E+03, 0.74050400E+02, -.45924400E+03, 0.84315400E+01, 0.14022000E+02, -.65053500E+02, -.63870100E+01, 0.65635700E+02, 0.21540500E+02, -.21839800E+02, 0.66041200E+02, -.59291300E+02, -.93850000E+01, 0.17751000E+02, 0.40816200E+01, 0.70058100E+01, -.59184700E+02, 0.16850600E+02, -.77083900E+01, 0.72266400E+02, 0.50869700E+01, -.29745600E+02, 0.52140900E+02, -.41125200E+02, 0.11750400E+02, 0.28278400E+02, 0.48826800E+02, 0.17308200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22617000E+02, 0.50096100E+00, -.16197800E+02, -.40314400E+01, 0.97514100E+01, -.20026500E+01, -.10181500E+01, 0.14732000E+01, -.85435400E+00, 0.19433700E+01, 0.89740800E+00, -.15632000E+01, 0.47024300E+01, -.26130900E+01, -.24922000E+01, -.14474300E+00, 0.21123500E+01, -.33958200E+01, -.35274900E+01, 0.16790900E+00, -.39921000E+01, -.16158400E+01, -.25918400E-01, 0.20626900E+01, 0.68478000E+00, 0.84775400E+00, 0.66646000E+01, -.75029300E+01, -.20572400E+01, 0.14117100E+01, -.77325100E+00, 0.30933200E+00, 0.94325800E+01, 0.30453800E+00, -.64289000E+00, 0.16109600E+01, 0.44894000E-01, 0.16583600E+01, -.21549800E+01, -.16400600E+01, 0.32166100E+00, 0.15041000E+01, -.14601100E+02, 0.11281400E+01, 0.22429800E+01, 0.49339600E+00, 0.14296900E+01, -.24182200E+00, 0.14842200E+01, 0.57821900E+00, 0.11030300E+00, 0.58139600E-01, 0.19112800E+01, -.13231900E+01, -.13445200E+00, 0.86921200E+00, 0.40402400E+00, -.16523200E+00, -.14587600E-02, 0.18635400E+01, -.14304200E+01, -.84063600E+00, 0.35275800E+00, -.52145100E+00, 0.10266300E+01, -.21436700E+01, 0.19388000E+00, -.78991900E+01, 0.60134000E-01, 0.57603100E-02, -.19004300E+00, -.94972100E+00, -.51295600E+00, -.67151300E+00, 0.11995100E+01, 0.88352200E-01, -.10491600E+00, -.44198700E+00, 0.45440300E+00, 0.32161800E+00, -.16671700E-02, -.13442500E+01, 0.67262000E+00, -.16659500E+00, -.23477600E+00, 0.21629300E+00, -.73062300E+00, 0.43570300E+00, -.14421200E+01, 0.65846700E+00, -.18337300E+01, -.12322000E-02, 0.11678400E+01, 0.22511100E+00, 0.12590700E+01, -.14103700E+00, -.46018800E+01, 0.13645900E+01, -.77288900E+00, 0.61092300E+00, -.40591100E+00, 0.13768800E+01, -.14350800E-01, -.46952900E+00, -.57576600E+00, 0.55300000E+00, 0.71943500E+00, -.75914300E+00, -.11172500E+01, 0.70603900E+01, -.67579800E+00, -.97631600E+00, -.19330700E+01, -.17139400E+00, 0.98046100E+00, 0.20240000E+00, 0.12343100E+01, 0.58734900E+00, 0.31166600E+01, -.20434900E+01, -.43616700E-01, 0.32748900E+00, 0.49068300E+00, 0.10229900E+01, 0.54192200E-01, -.74436000E+00, 0.21338800E+01, -.37333900E+00, 0.82955200E-01, -.25714500E+00, -.13963200E+01, 0.11312700E+01, -.92406100E-01, 0.13452900E+01, 0.13204500E+00, -.66255200E-01, 0.22202200E+00, -.13454800E+01, -.23567700E+01, 0.87673000E+00, -.62158600E-01, -.28127800E+00, 0.73069900E+00, 0.22549500E+01, 0.13348700E+01, -.29499000E+00, -.10391500E+00, -.25387000E+00, -.17958000E+01, 0.28354900E+01, -.57576600E+00, -.95295800E-02, -.64495300E+00, 0.36613800E+00, 0.17794300E+00, -.14934200E+00, 0.18199200E+00, -.22541400E+00, -.13088900E+00, -.11729000E+01, 0.95502500E+00, -.10622100E+00, 0.68919400E+00, -.22241100E+01, -.13056700E+01, -.15682200E+00, -.16181200E+00, 0.96075800E-01, 0.16064800E+00, 0.27721600E+00, 0.12108700E+03, -.15470900E+03, -.10869900E+03, -.24522200E+03, 0.97829000E+02, 0.18193900E+03, 0.30106700E+02, -.16694300E+02, -.12203100E+03, -.15243600E+02, -.19959700E+02, -.14675500E+03, 0.26614500E+02, 0.12570100E+02, 0.12784500E+03, -.86801500E+02, 0.11566200E+03, 0.21981000E+03, -.10162300E+03, -.17027300E+03, -.11125000E+03, 0.44061000E+02, -.22721300E+02, -.10055100E+03, -.75218100E+02, -.25574900E+02, 0.65809800E+02, 0.44532300E+02, -.24708000E+03, 0.11760800E+03, 0.11651000E+03, 0.12360600E+03, -.26060300E+02, -.20259900E+03, 0.12253900E+03, 0.88799700E+01, 0.77964200E+02, -.19249200E+03, -.14101500E+03, 0.33899100E+03, -.17010800E+03, -.74639100E+02, -.16909500E+03, -.14335600E+03, -.41004200E+01, -.13670800E+03, -.20589000E+03, -.26311200E+03, 0.19715600E+02, -.14246300E+03, -.88933400E+01, 0.77977700E+01, -.22332700E+03, 0.67800900E+01, 0.65232400E+00, -.14568800E+03, -.11691100E+03, 0.55095600E+02, -.11128000E+03, -.29372000E+02, 0.82290100E+02, 0.10867100E+03, -.26600500E+02, 0.47789000E+02, -.52029300E+02, 0.11881100E+03, 0.10215000E+03, -.14192400E+03, 0.16727500E+02, -.78531800E+02, 0.93408100E+02, 0.22140200E+02, 0.21122300E+03, -.11620900E+03, -.87576200E+02, -.10550400E+03, -.58793900E+02, 0.23392100E+02, 0.22171000E+02, 0.98412800E+00, -.22414200E+02, 0.19616700E+02, -.93218900E+00, -.19603900E+03, 0.10379600E+03, 0.74264900E+02, 0.97335400E+02, 0.29080600E+03, 0.16958900E+02, 0.16044000E+01, -.22795500E+03, 0.84991100E+02, 0.10423400E+03, -.10278500E+03, 0.27671300E+02, 0.50376100E+01, -.66095000E+01, -.14943300E+02, -.55588400E+02, 0.17214800E+01, -.55079800E+01, -.57493200E+02, 0.10080900E+03, 0.27201500E+01, 0.39420500E+02, 0.54085600E+01, 0.29272000E+02, 0.10009600E+03, -.12482600E+02, -.16304900E+02, 0.31439800E+02, 0.44237800E+02, -.32494500E+02, -.28418300E+01, -.45844000E+02, 0.21449000E+02, -.58623700E+02, 0.41315300E+02, 0.35044200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.69609500E+01, 0.70044800E+00, -.19990500E+00, 0.20220500E+01, -.12528900E+01, -.26382700E+01, 0.21413200E+01, -.42359100E-01, -.57154100E+00, 0.98916700E+00, 0.47762100E+00, -.27115800E+00, -.13478900E+01, -.62326900E+00, 0.22742500E+00, 0.16468000E+01, -.10786400E+01, -.16541900E+01, 0.62590500E+00, -.89604700E+00, 0.11366900E+01, -.20528600E+00, 0.16295000E+00, -.19411300E+01, 0.19825500E+00, 0.14724500E+00, 0.19459000E+01, 0.34356300E+01, -.10783300E+01, -.13059000E+00, 0.30934900E+00, -.11243300E+01, -.10074800E+01, 0.16674300E+00, -.10151200E+00, -.10256800E+01, 0.33590000E-01, -.31755600E+00, 0.34135800E-01, 0.10331900E+01, -.41023300E+00, 0.30541500E+00, 0.53804900E+00, -.77048000E-01, 0.57243600E+00, 0.63699300E-02, 0.29080700E-01, -.51096100E+00, -.11540000E+01, -.15978200E+00, -.15932100E+01, 0.59148300E+00, -.43087000E+00, 0.19366800E-01, 0.63335500E+00, 0.22174600E+00, 0.18706400E+00, -.57292100E+00, -.87416900E-02, 0.37047000E-01, -.19960900E+01, -.10240400E+01, 0.43683400E-01, -.33015300E+00, 0.49171700E+00, 0.99384400E+00, -.44661600E+00, -.33043700E+01, 0.42999800E+00, 0.11349600E-01, -.59579400E+00, 0.22832100E+00, -.47911900E+00, 0.17904700E+00, -.27237600E+00, -.63370600E+00, 0.41865100E-01, -.14735500E+00, 0.32856600E+00, 0.38183100E+00, -.69396900E-01, -.12487800E+00, 0.42163000E+00, -.65425500E+00, -.56448900E-01, 0.14931300E+00, -.78182600E+00, 0.11347300E+00, -.53510000E+00, -.66225500E-01, 0.80659200E+00, 0.16264900E-01, -.42965100E+00, -.65097500E-01, -.16143800E+00, -.42852100E+00, -.56503300E-01, 0.27749700E+00, 0.38810800E+00, -.30642100E-01, -.95948700E+00, 0.38716100E+00, -.39361400E-01, -.14821200E+00, 0.15191900E+00, -.48299900E-01, 0.29630400E+00, -.33775200E-01, -.10461300E+01, -.18841200E+00, -.96970900E-01, -.13289500E+00, -.15905900E+00, -.33502500E-01, 0.37978600E+00, -.10648800E+00, 0.35702100E+00, 0.17150000E+00, -.13887100E+01, -.25171600E+00, -.19729700E+00, -.59316000E+00, 0.27821600E-01, -.26805000E+00, 0.36668100E-01, 0.15125600E+00, 0.61701400E+00, -.12778100E+00, 0.27452000E-01, 0.26589200E+00, 0.23078100E+00, -.69910200E+00, 0.32556300E+00, -.49280100E+00, -.13929800E+00, -.37107400E-01, 0.12968200E+00, -.10718500E+00, 0.16340100E+01, -.84759900E+00, 0.15264500E+00, 0.46818400E-01, 0.13307500E+00, -.49518600E+00, -.22986500E+00, 0.82270400E+00, -.40042800E-01, 0.12771500E+00, 0.33260300E+00, -.92022800E+00, -.20393100E-01, 0.46858400E-01, 0.37883900E+00, -.12400400E+00, -.50124800E+00, -.73469500E-02, -.77922100E-01, 0.19871800E+00, 0.97096600E-01, 0.37254500E+00, -.16034100E+00, 0.31575800E-01, 0.19368900E+00, 0.48013700E+00, 0.17159600E+00, -.41416900E+00, 0.17497100E+00, 0.11135200E+00, 0.72613200E+00, 0.34005300E+00, 0.17841800E-01, 0.98722800E+02, 0.11072000E+03, 0.14435800E+03, 0.22985400E+01, -.18537100E+03, -.12600000E+03, 0.62149900E+02, 0.68853000E+02, 0.62122500E+02, 0.17491200E+02, 0.80325000E+02, -.46243700E+00, -.23502300E+02, -.64233700E+02, 0.63410300E+02, 0.26811300E+02, -.39799300E+03, 0.19550500E+03, 0.20261500E+03, 0.19702000E+03, 0.85331600E+02, 0.15779300E+03, -.24662000E+02, -.81801800E+02, 0.10666800E+03, 0.14005100E+03, 0.17859000E+03, -.85726600E+02, 0.46793500E+02, -.16312100E+02, 0.42927800E+02, 0.39855400E+02, 0.86380600E+02, -.65571200E+01, -.17028800E+02, 0.66177100E+02, 0.50877100E+02, 0.17986100E+02, -.22913400E+03, 0.11635400E+03, 0.49062700E+02, 0.11494200E+03, 0.62783000E+02, 0.10083200E+02, 0.67033100E+02, 0.67111600E+02, 0.16583400E+03, -.12704300E+02, 0.74790300E+02, -.96675700E+02, 0.41441600E+02, 0.18350600E+03, 0.50629200E+02, 0.64792200E+02, 0.16028100E+03, -.39224100E+02, -.85100400E+02, 0.14140000E+02, 0.99388800E+02, -.16012900E+03, -.17535700E+03, 0.73305400E+02, 0.79725200E+01, 0.88750400E+02, 0.53550600E+02, 0.12808800E+03, -.11682900E+03, -.75941400E+02, -.52922900E+02, 0.12096600E+03, 0.91492800E+02, -.14765100E+03, 0.77891100E+02, 0.34193200E+02, 0.74205400E+02, -.13699500E+02, -.49424400E+02, 0.22926000E+02, -.15643000E+02, 0.12816500E+03, -.45146600E+02, 0.13553000E+03, 0.61303800E+02, -.36654500E+02, 0.88380300E+02, -.31245000E+02, -.10266200E+03, -.83586300E+02, -.29496700E+02, 0.39664600E+02, -.63137600E+02, -.59393200E+02, 0.18156600E+03, -.22973600E+02, 0.59705400E+00, 0.13002500E+01, 0.97128700E+01, 0.22125200E+01, 0.57419200E+01, -.51706100E+01, 0.30920000E+01, -.42090100E+02, -.33431100E+01, -.27236600E+02, -.14643900E+01, -.13713500E+02, -.41650500E+02, 0.97992100E+01, 0.12579500E+02, -.31174600E+02, -.23889900E+02, 0.73871500E+01, 0.51442200E+01, 0.20097900E+02, -.85129200E+01, 0.22049800E+02, -.43989100E+02, 0.38461800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14628500E+02, -.17916500E+01, 0.69670600E+01, -.33285000E+00, -.28116700E+01, 0.27490200E+01, -.93757100E+00, -.19813200E+00, 0.82054000E+00, 0.58768400E+00, 0.48540700E+00, -.33410800E-01, 0.93565900E+00, 0.90133200E+01, 0.10929500E+00, -.15505900E+01, 0.18781600E+01, 0.66494600E+01, 0.27623400E+00, 0.13731500E+01, -.18748000E+01, 0.74017200E+00, -.10014700E+01, 0.74767100E+00, -.34627500E+00, -.14714900E+01, -.29883600E+01, -.10805400E+01, 0.32563600E+01, -.26349500E+01, 0.13535700E+00, -.31721700E+00, -.11575900E+01, 0.24948500E+00, -.21766700E+00, 0.14148100E+01, -.13619700E+00, 0.69188300E+00, 0.10046100E+01, 0.88330700E+00, 0.13133100E+01, 0.77406300E+00, 0.89121100E+00, 0.25077500E+00, 0.66457900E-01, 0.80332800E+00, -.13996500E+00, 0.30069000E+01, -.32628300E+00, -.36172700E-01, 0.44039800E+00, -.11311300E+01, 0.42643500E+00, -.13637700E+01, -.64249200E+00, -.56431200E+01, -.73652300E+00, 0.24101800E+01, -.94306800E-02, -.28326200E+01, 0.66104400E+01, 0.22189700E+01, -.33823400E+00, 0.11982900E+01, 0.30087700E+01, -.10901500E+01, 0.89210900E+00, 0.81896600E+01, -.22087300E+00, -.10607000E-01, 0.10438000E+01, -.10551600E+01, 0.82333800E+00, 0.92977700E+00, -.25774800E+01, 0.22055900E+01, -.46970000E+00, -.13405200E+01, -.10900200E+01, -.12686300E+01, 0.90533700E-01, 0.16957300E+01, -.16704100E+01, 0.86945200E+00, 0.59977200E+00, 0.79471800E-01, -.55756400E+00, -.14828900E+00, 0.28029900E+01, -.15935200E+01, 0.55682900E+00, -.28594200E-01, -.23848100E+00, 0.27645400E+00, -.81649700E+00, -.20381600E+00, 0.27713000E+01, -.10803500E+01, 0.77770100E-01, -.32116600E+00, 0.11245100E+01, -.76313200E+00, 0.30527600E-01, 0.10634900E+00, -.35352400E+00, 0.49961700E+00, 0.41433300E+00, -.94036900E-03, 0.35468600E+00, 0.66205600E+00, 0.67488900E+00, 0.60733300E-01, 0.29135700E+00, -.29910800E-01, -.42229100E+00, -.16183800E+00, -.28289200E+00, -.51669300E-02, -.31680100E+01, 0.11744500E+01, -.28379700E+00, 0.80224100E+00, -.41860300E+00, -.95238200E+00, 0.12861800E+00, -.93586000E-01, 0.64131600E+00, 0.15931500E+00, 0.18758500E+00, 0.47647200E+00, 0.13186100E+01, -.78899600E+00, -.20143000E+01, -.23201200E+01, -.50849100E-01, -.50670400E-01, -.42670400E+00, -.11780800E+01, 0.40659700E+00, -.10364100E+01, 0.93554200E+00, 0.86461000E+00, 0.53182900E+00, -.27891700E+00, 0.95425300E-01, -.22401900E+01, 0.58307900E-01, 0.30824600E-01, 0.89517100E+00, 0.44068200E+00, -.12887700E+01, 0.79278300E-01, 0.57461100E+00, 0.47656600E-01, -.15801900E+01, 0.10110300E+00, -.95013900E-02, -.21171900E+00, 0.53927700E+00, 0.55617500E+00, -.16510400E+01, -.62053000E-01, -.10524600E+00, -.34692500E+01, 0.35560200E+00, 0.11462100E+01, 0.88631400E+00, -.56296000E+00, -.43806400E+01, 0.48089400E+00, -.11787800E+00, 0.70408500E+00, -.15619700E+03, -.32794000E+03, 0.37659800E+02, -.36900100E+02, 0.93361600E+03, -.46887800E+03, -.57382500E+03, -.46568600E+03, 0.37037400E+01, -.31510900E+03, 0.90468400E+02, 0.36351700E+03, -.44690600E+02, -.22515900E+03, -.16389400E+03, 0.57184900E+03, -.28022100E+03, -.35854000E+03, -.28174500E+03, -.23065700E+03, -.29608200E+03, 0.20855700E+03, 0.28560800E+03, -.22612100E+03, -.21114800E+03, -.25158000E+03, -.68405400E+03, 0.33489300E+03, 0.85644600E+02, 0.34184700E+03, 0.19858000E+03, -.28398600E+03, 0.94206000E+02, 0.17451800E+03, 0.46612600E+03, -.24944900E+03, 0.19218300E+03, 0.23928200E+03, -.11780000E+03, -.14694700E+03, -.12074100E+03, -.16819700E+03, -.12199900E+03, -.86917200E+02, -.96197800E+02, -.18892700E+03, -.85799800E+02, -.17692400E+03, -.92196400E+03, 0.46156800E+03, 0.40280300E+02, 0.45577900E+03, 0.11420900E+03, -.61081900E+03, 0.75354000E+02, -.33498300E+02, 0.28063900E+03, -.44961500E+03, 0.78751800E+03, 0.40961200E+03, -.20428000E+03, 0.16606100E+03, -.21102100E+03, -.43358200E+02, 0.15376300E+03, -.68211100E+02, -.44930200E+02, -.32357200E+03, 0.14945100E+03, -.54703400E+02, 0.34234700E+03, -.16624900E+03, -.49425200E+02, -.17180500E+03, -.19559200E+03, 0.31787000E+02, 0.41949400E+02, 0.27070000E+02, -.15374200E+03, 0.50202000E+02, -.14388200E+03, -.18641800E+02, 0.17527100E+02, 0.27079800E+03, 0.11159100E+02, -.23692200E+03, 0.38123200E+02, 0.64713100E+02, -.23715500E+03, -.13679400E+03, 0.16259900E+03, 0.33760400E+02, 0.26198000E+02, -.16506000E+02, 0.44649400E+02, -.58875400E+01, 0.39922700E+02, -.28634100E+02, 0.43837900E+01, 0.34670300E+02, 0.40148900E+02, 0.38858200E+01, 0.41461700E+02, -.35471600E+01, 0.40482100E+02, 0.38463000E+02, -.23157600E+02, -.51640500E+01, -.15337400E+01, 0.47699900E+02, 0.17794200E+02, -.11674400E+03, -.12901400E+02, 0.68777100E+02, -.19209200E+02, 0.41814700E+02, -.23184200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.56949100E+01, 0.79177400E+00, 0.34973500E+01, 0.13799700E+01, 0.17323100E+01, -.49222100E-01, -.40842300E+00, 0.24248100E+00, 0.25199000E-01, 0.18050900E+01, -.10544800E+00, 0.23692900E+01, 0.24246700E+01, 0.38169300E+00, 0.15681300E+00, 0.94298600E-01, 0.13318700E+01, 0.14876200E+01, -.34552900E+00, 0.11357300E+01, -.14066500E+01, -.25181000E+00, 0.13094100E+00, 0.15542700E+01, 0.38119800E+00, 0.16119700E+00, -.14842900E+00, -.82360100E+00, -.44882200E+00, -.57178300E-01, 0.11851000E+00, 0.63592200E+00, 0.34793600E+00, 0.17984700E+00, 0.11858900E+00, 0.41012900E-01, -.57426700E-03, -.15205500E-02, -.46947900E+00, -.11049500E+01, -.39076000E+00, 0.44185200E+00, -.16227900E+00, -.40960000E-01, 0.14141400E+00, 0.55416600E-01, -.21388400E+00, 0.80085500E+00, 0.36806300E+00, 0.20123600E+00, -.90798400E+00, 0.19467000E+00, 0.48743500E+00, 0.89459500E+00, 0.71280200E+00, -.10659200E+01, 0.15124800E-01, 0.66019900E+00, -.79089600E-02, -.24023100E+01, 0.58032300E+00, -.67842300E+00, -.12663600E-01, -.34780900E+00, 0.10427600E+01, -.13546500E+01, 0.25695000E-01, -.25997700E+00, 0.73243600E-01, 0.70885600E-02, 0.49054000E+00, -.51421300E+00, -.11685600E+01, 0.27508400E+00, -.76583700E+00, -.18140500E+00, -.37770300E+00, -.38703700E+00, 0.31104700E+00, -.68998700E-01, -.25035200E-01, 0.95868600E+00, 0.13628400E+00, 0.41195200E-01, 0.40179400E+00, -.15376900E+00, -.31055500E+00, 0.27787500E+00, 0.84294200E+00, -.44803600E+00, 0.17710000E+01, 0.14675300E-01, 0.56450000E+00, -.20292700E+00, 0.57230100E-01, -.27566400E+00, 0.43244000E+00, -.34867200E+00, -.30182400E+00, -.10056300E+00, 0.23094400E-01, -.73838900E+00, 0.12978800E-01, -.97551800E-01, 0.28926000E+00, -.15950000E+00, -.10528900E+01, 0.16580900E+00, -.19180300E+00, 0.88489600E+00, 0.51839100E+00, -.36353700E-01, 0.47063900E-01, 0.41977800E-02, -.92579100E-01, 0.91744100E-01, 0.20117400E+00, -.12900900E+00, 0.60365400E+00, -.46970000E+00, 0.12659300E+00, -.10989300E+00, 0.51762300E-01, 0.40559700E+00, -.20573300E-01, 0.33799700E-01, 0.12387800E+00, -.10831900E+00, 0.27187000E-02, -.14476000E+00, -.11991500E+01, 0.37268900E+00, 0.65752600E+00, 0.65715100E+00, 0.68218700E-01, 0.27405300E-01, 0.11141000E+00, 0.44153300E+00, -.84343800E+00, 0.49109300E+00, -.12141900E+00, -.15342600E+00, 0.15342800E+00, 0.26699700E+00, 0.69660700E-01, 0.40749300E-01, -.39551300E-02, -.23786100E-02, 0.37739200E-01, 0.10058200E+01, -.42197700E+00, -.85618800E-02, -.11094400E+00, 0.25956900E-01, 0.64172900E+00, -.68456700E-01, -.81423400E-01, -.26400900E-01, 0.84565100E-01, -.13079600E+00, 0.12984600E+01, -.18035300E+00, -.44556400E-01, 0.28900500E+00, -.26885300E+00, -.21922100E+00, -.95771300E-02, -.43489300E-01, -.59094600E+00, -.23272200E+00, -.32489400E-01, -.36474500E+00, -.18652900E+00, -.10704600E+03, -.14084700E+02, -.85170100E+02, 0.30478800E+03, -.15585900E+03, -.15231500E+03, -.15218200E+03, 0.29379600E+02, -.12949000E+03, 0.14938600E+02, 0.89019200E+02, 0.19640800E+02, -.73869900E+02, -.10064000E+03, -.11305900E+03, 0.54834600E+02, 0.11736500E+03, 0.57089900E+02, 0.87460300E+02, 0.80894200E+02, -.41499300E+02, -.10854100E+03, -.22379900E+03, 0.14502500E+03, 0.13374700E+02, 0.40699100E+03, -.20229000E+03, 0.79049500E+02, -.20351200E+03, 0.18570300E+01, -.14579700E+03, -.58072100E+02, 0.97562400E+01, -.20297600E+03, -.90186300E+02, -.17372100E+03, 0.18990400E+03, -.95051800E+02, -.14361400E+02, -.95049900E+02, -.84436300E+02, -.21193900E+02, -.49592300E+02, -.46322400E+02, -.15661200E+03, -.76651300E+01, -.14077900E+03, -.28446200E+03, 0.13554700E+03, -.86675900E+02, 0.14157100E+03, 0.15786700E+02, -.17599300E+03, 0.82531100E+02, 0.11989400E+03, 0.36620000E+02, -.47838200E+02, 0.42867200E+03, 0.13950300E+03, -.76539900E+02, 0.16110400E+03, -.70406600E+02, -.14657600E+03, -.22642700E+03, 0.17014600E+03, 0.88007000E+02, 0.27897300E+02, -.22226000E+03, 0.24824100E+02, 0.20896200E+03, -.97053000E+02, -.53265900E+02, -.10433900E+03, -.77421900E+02, 0.19136500E+02, -.38317000E+01, 0.50078300E+02, -.56782600E+02, 0.97291300E+01, -.26725800E+03, -.19772200E+03, 0.99484400E+02, -.95326600E+02, 0.99009900E+02, 0.16907900E+03, 0.81181800E+02, -.57862100E+01, -.12301300E+03, 0.91963000E+02, 0.10412600E+03, 0.38201200E+02, 0.21322600E+02, 0.69287300E+01, -.13085900E+02, -.78663300E+01, 0.26552800E+02, 0.72061500E+01, -.13075900E+02, 0.25434600E+02, -.38839700E+02, -.11266200E+02, 0.34661200E+02, 0.66289800E+00, 0.20515600E+02, -.39465600E+02, 0.39656300E+01, -.60493400E+01, 0.29779900E+02, 0.18103100E+02, -.29690200E+02, 0.16972300E+02, -.34847000E+02, 0.35125000E+02, 0.31277500E+01, 0.43154700E+02, 0.12598500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.78698600E+01, -.96180200E+00, 0.18491200E+01, -.33689400E+01, -.29545100E+01, 0.30135300E+01, -.90061200E+00, 0.30058300E-01, 0.87562400E+00, -.97180400E+00, 0.35980600E+00, -.40978100E+00, 0.94699900E+00, 0.35771200E+01, -.44030000E+00, -.11082900E+01, -.11224700E+00, 0.19946900E+01, -.18285100E+01, 0.12912900E+01, 0.62584600E+00, 0.38821700E+00, -.31405800E+00, -.95700700E+00, -.21662000E+00, -.65738300E+00, -.54298400E+00, -.12048900E+01, 0.18023200E+01, -.10019300E+01, -.16572600E+00, -.13808500E+00, 0.65906800E+00, 0.31881100E+00, -.21714100E+00, -.68382900E+00, 0.15089700E-01, 0.19940400E+00, -.39858200E-01, -.64115900E+00, 0.17516200E-01, 0.27276400E+00, -.17056600E+01, -.69846900E-01, -.46805900E+00, -.24814200E-01, 0.10134500E+00, 0.12021700E+00, -.11891500E+00, 0.15627500E+00, 0.84604400E+00, -.19200000E+00, 0.71443500E+00, -.13093400E+01, -.11250700E-01, -.16375100E+01, -.95960200E-01, 0.76192100E+00, -.31923900E-02, 0.12508200E+00, 0.20212700E+01, 0.89104900E+00, -.31038100E+00, 0.55291500E+00, 0.11506400E+01, -.11475800E+01, 0.68707700E+00, 0.32112300E+01, -.47142400E-02, -.11831000E-01, 0.19563500E+00, -.92306600E+00, -.73715200E+00, 0.33434500E+00, -.13564500E+01, 0.11786600E+01, -.26871200E+00, -.16732100E+01, -.65862100E+00, 0.82446800E-01, 0.50528100E-01, 0.11852200E+01, 0.29313600E+00, 0.81043400E+00, 0.53828000E+00, -.56168300E+00, 0.46407400E+00, -.59794500E-01, 0.48689300E+00, -.17251700E+00, 0.23200800E+01, 0.43571700E-01, 0.69395300E+00, 0.24176500E+00, -.77084700E+00, 0.15158000E+00, -.42067100E+00, -.11142400E+00, -.65229200E+00, 0.14077000E+00, -.22743800E+00, 0.10768000E+01, 0.60846900E-01, 0.13038300E+00, 0.30403300E+00, 0.41378400E+00, -.83500000E+00, -.20940500E+00, 0.11578400E+01, -.62375700E+00, 0.74559100E+00, 0.27854300E+00, -.56881600E+00, 0.50599500E-01, -.17296400E+00, 0.16838200E-01, -.23256300E+00, -.13957300E+01, 0.79404800E+00, -.16726600E+00, -.11858200E+00, 0.50338700E+00, 0.10188000E+00, 0.71311000E+00, -.66374900E-01, -.12632800E+01, 0.67951700E+00, -.41464900E+00, -.36400300E-01, 0.31884700E-01, -.20490500E+01, 0.13102200E+01, 0.49374100E+00, -.10600000E+01, -.23366000E+00, -.56816600E-01, 0.50170800E+00, 0.14920800E+00, 0.16249700E+01, -.67098100E+00, -.36048600E+00, -.45081600E+00, -.31203900E+00, 0.73681300E+00, -.30857900E+00, -.29420500E+00, 0.89935000E-01, -.50579000E-01, 0.58958300E+00, -.78219500E+00, 0.60035900E+00, -.11470200E-01, -.21415400E+00, -.12583200E+00, 0.11493100E+01, -.90551600E-01, -.56865300E-01, -.32466800E-01, -.12217300E+00, -.41686300E+00, 0.19552100E+01, -.53067300E-01, -.56940600E+00, -.23139600E+00, 0.87836200E+00, 0.85033900E-02, -.13628900E+00, -.10230400E+00, -.53439900E+00, -.26446500E-01, -.14898200E+00, -.65116600E+00, 0.43360300E-01, -.74876500E-01, 0.34537000E+02, -.42554100E+01, -.30482600E+03, 0.15192300E+03, 0.18928000E+03, 0.15237000E+03, -.27045900E+01, 0.50754900E+02, 0.18189600E+02, -.12612900E+03, 0.11033800E+02, 0.46563500E+02, 0.62164200E+02, -.20865700E+03, 0.10397700E+03, 0.17401000E+03, 0.10396200E+03, 0.64115300E+02, 0.10525900E+03, -.47551900E+02, -.12402500E+03, 0.22718800E+02, 0.12345900E+03, 0.36400800E+02, 0.20229900E+03, -.10109400E+03, 0.64969300E+02, -.10112800E+03, -.14662000E+02, 0.29271700E+02, -.81576200E+02, -.10213200E+03, -.11558200E+03, 0.41373600E+02, -.95483600E+02, 0.37708900E+02, -.18543700E+02, -.43061500E+02, -.18719200E+02, -.70029600E+01, -.12539100E+02, -.18080600E+02, -.10558300E+02, 0.22572600E+01, -.14931100E+02, -.35201700E+02, 0.12846300E+03, -.63927900E+02, 0.33180600E+02, -.63701100E+02, 0.40829400E+01, 0.10346000E+03, -.56481700E+02, -.69705000E+02, -.74416600E+02, 0.97851700E+02, -.20574300E+03, -.11959300E+02, 0.23159300E+01, 0.11330500E+03, 0.67919000E+01, -.10336200E+02, -.58101500E+02, 0.52917500E+02, 0.77670700E+02, 0.49394400E+02, -.57331200E+02, 0.30229400E+01, -.81871500E+02, 0.35055600E+02, 0.19409800E+02, 0.41036800E+02, 0.24551500E+02, 0.76129800E+01, -.12091000E+02, -.17549900E+02, 0.25378100E+02, -.19387600E+01, 0.65959800E+01, -.29710700E+02, 0.14297200E+02, -.94164200E+02, 0.14618500E+02, 0.66727800E+02, 0.17412100E+02, -.25214100E+02, 0.14095700E+02, 0.25683300E+02, -.21979200E+02, -.86626900E+02, -.18038300E+02, 0.44577100E+01, -.13560700E+01, 0.43687500E+01, -.87731700E+01, 0.46704300E+01, -.21684100E+01, -.83272400E+01, -.11443800E+02, -.64630300E+01, -.10314600E+02, -.11957100E+01, -.64658800E+01, -.10774600E+02, 0.71543600E+01, 0.56708900E+01, -.28662100E+01, -.58022200E+01, -.47093300E+01, 0.29728700E+02, -.41535300E+01, -.82688600E+01, -.49279600E+01, -.12030600E+02, 0.11453100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14388000E+01, -.28049800E+00, -.20705900E+01, -.84916000E+00, -.12581900E+01, -.50698600E+00, 0.12754000E+01, -.20287800E-01, 0.14167000E+00, -.13402700E+01, -.58005100E+00, -.11313300E+01, -.14961200E+01, 0.17974300E+00, 0.15772700E+00, -.24288500E-01, 0.37028800E+00, 0.12271500E+00, -.11120800E+00, 0.88909700E-02, 0.16161800E-01, 0.19030100E-01, 0.12791500E+00, 0.21913600E+00, -.65649700E-01, -.93688400E-01, 0.20214100E+00, -.16228300E+01, 0.28294500E+00, -.15165200E+00, 0.79922100E-02, 0.12433800E-01, 0.36613700E+00, -.39859300E+00, 0.11419200E+00, 0.99718100E+00, -.22798600E-01, 0.18930100E+00, 0.38631900E+00, -.18211800E+01, 0.39681200E+00, -.30372300E+00, -.58468700E+00, 0.53876300E-01, -.70141700E+00, -.17397800E+00, 0.19207000E+00, 0.46543800E-01, 0.16306600E+00, 0.10089100E-01, 0.26276400E+00, 0.59674700E-01, 0.12532800E+00, 0.25680200E+00, -.20073300E+00, 0.27584900E-01, 0.15917000E-01, 0.37671500E-01, 0.78121900E-03, 0.23441100E+00, 0.17732900E-01, 0.22342000E+00, 0.12333400E+00, 0.36444300E+00, 0.85397400E-01, 0.10074700E+00, 0.62135600E-01, 0.10623400E+01, -.83822500E-01, -.17339000E-02, 0.18484700E+00, 0.94234000E-01, 0.84676500E+00, -.51023100E+00, 0.21810200E+00, 0.23666100E+00, 0.19573600E+00, -.57676600E-01, -.14792300E+00, -.77458300E-01, 0.10448000E-01, -.78847900E+00, 0.67229200E-01, -.24804000E-01, -.19529500E+00, -.12381200E-01, 0.33605200E+00, -.52767500E-01, 0.22989600E-01, 0.15825700E+00, -.18486800E+00, -.10778200E-01, 0.74482200E-01, 0.79676800E-01, 0.16319700E-01, -.26973500E-01, -.41929400E+00, -.61587900E-01, -.74115700E-01, 0.77400100E-01, -.99634000E-01, -.19850700E-01, -.83700400E-02, 0.92831500E-04, -.65860800E-01, 0.72061800E-02, -.79097400E-01, -.84800300E-01, 0.14997800E+00, -.63229600E+00, -.60988100E-01, 0.20354800E-01, -.74674500E-01, 0.87664000E-02, -.35750200E-01, 0.24484400E-01, 0.16562900E-01, -.72118800E-01, -.16693700E+00, 0.21903600E+00, 0.84135800E-01, 0.97052000E-01, 0.27548300E-01, -.35545000E-02, -.16868300E-01, -.16711800E+00, -.12761800E+00, -.38049800E-01, 0.18157000E-01, -.41367600E-01, -.56985800E+00, 0.34997900E+00, 0.18869700E+00, -.67085800E-01, 0.20156300E-01, -.94825800E-02, 0.32796400E+00, 0.68271000E-01, 0.11506000E+00, -.48391700E-02, 0.49537100E-01, 0.72626300E-01, 0.24050900E-01, 0.25321400E+00, -.62321500E-01, -.25022100E+00, 0.36243100E-01, -.45230800E-01, 0.42044100E+00, -.54026300E+00, 0.43737100E-01, 0.30120200E-01, 0.14417800E+00, -.30242300E-01, -.53849400E-01, -.80199600E-02, 0.98778200E-02, -.55749500E-01, -.48580700E-02, 0.30668600E+00, -.52307700E+00, -.89129900E-02, 0.12948100E+00, 0.40645600E+00, -.35704300E+00, 0.36906600E-01, 0.75411200E-01, -.57654700E-01, -.29082000E+00, 0.20666200E+00, -.81055400E-01, 0.21579900E-01, 0.16277200E+00, 0.15122200E+00, 0.25381000E+00, -.78487800E+02, -.88977800E+02, 0.45728000E+02, 0.33215900E+02, 0.44290800E+02, -.50149900E+02, -.79717000E+01, 0.21671800E+02, -.47872100E+02, 0.16732800E+02, -.14371400E+02, 0.83859800E+02, -.99577400E+02, 0.51803700E+02, 0.25112100E+02, 0.49064400E+02, 0.30944600E+02, 0.46145700E+02, -.11367200E+02, -.34366600E+02, 0.66364500E+02, 0.36439400E+02, 0.66025300E+02, -.51536700E+02, 0.23756000E+02, 0.12511400E+02, 0.25797300E+02, -.36643100E+02, -.61004400E+00, 0.99813900E+01, -.14222000E+01, 0.34056700E+02, 0.12993500E+01, 0.39271700E+02, 0.42305100E+02, -.21781400E+02, -.90183600E+01, -.20976800E+02, -.25172200E+01, 0.12663000E+02, -.23204900E+02, -.21496500E+02, -.24314900E+02, 0.15833400E+02, 0.72758600E+00, 0.16792200E+03, -.83269100E+02, -.63163200E+02, -.83052400E+02, -.50421800E+02, 0.34994900E+02, -.30980400E+02, 0.24361600E+01, -.72158800E+02, 0.33793200E+02, -.66375900E+02, -.20767300E+02, 0.12613600E+02, -.88685800E+01, 0.11456700E+02, 0.47652400E+02, 0.45287400E+02, -.51277000E+02, -.19993400E+02, 0.27284100E+01, 0.38038600E+02, 0.14981600E+02, -.64631000E+02, 0.35725500E+02, 0.84904700E+01, 0.32315400E+02, 0.44828500E+02, 0.24389100E+02, -.16370000E+02, -.23387100E+02, 0.28269000E+01, 0.22928700E+02, 0.59091100E+02, 0.67008200E+02, -.32010300E+02, -.26575400E+02, -.33792700E+02, 0.28058300E+02, 0.16117600E+02, -.25392700E+02, 0.37432100E+01, -.53305500E+01, 0.34961600E+01, 0.10198100E+03, -.29605300E+01, 0.20801500E+01, -.14721200E+01, -.19259500E+01, -.13795900E+02, 0.59071200E+00, -.75648900E+00, -.13093900E+02, 0.18000700E+02, -.45080000E+00, -.56646100E+01, 0.72934600E+00, -.35902400E+01, 0.17976200E+02, -.21745500E+01, -.17278600E+01, 0.74535700E+01, 0.10099400E+02, -.16038000E+01, 0.54705800E+01, -.36040900E+01, -.70901200E+01, -.59303200E+01, -.39424300E+01, 0.18805000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.79272300E+01, 0.59601900E+00, 0.10815500E+01, -.24965300E+01, -.12022000E+01, 0.10302500E+01, 0.30768500E+00, 0.47562100E+00, 0.90001900E-01, 0.15409200E+01, -.32050700E+00, 0.15185600E+01, 0.16492200E+01, 0.11182100E+01, 0.29761900E+00, 0.60703700E+00, 0.36501800E+01, 0.23543400E+01, -.12492200E+01, 0.22982800E+01, -.14183800E+01, -.18312000E+00, 0.57990800E+00, 0.25872300E+01, 0.17747200E+00, -.41691100E+00, -.66400600E+00, -.27622500E+01, 0.54532800E+00, -.39599200E+00, -.12412000E+00, 0.11347800E+01, 0.22027400E+01, 0.47329800E-01, 0.25487000E+00, 0.31120200E+00, 0.13074700E-01, 0.86220000E-01, 0.26921100E-01, -.83409100E+00, 0.49552000E+00, -.48292900E-01, 0.88297100E+00, -.21135500E+00, -.10789100E+01, -.10498300E+00, 0.48855700E+00, -.53664900E+00, 0.62630700E+00, 0.36793500E+00, -.43424200E+00, -.66662900E-02, 0.40667000E+00, 0.21644000E+01, 0.15848100E+01, 0.95489300E-01, 0.42995900E+00, -.36562800E+00, 0.75203000E-02, -.96933200E+00, -.27393800E+01, -.21112300E+01, 0.31255000E+00, -.76737800E+00, 0.30664400E+00, -.85209500E+00, -.28219500E+00, -.11861200E+01, 0.12994000E-01, -.10270200E-01, 0.96113200E+00, -.10120900E+00, -.26486100E+00, 0.65338200E+00, -.10405300E+00, -.33663000E+00, -.48882300E+00, 0.65798000E+00, 0.53781700E+00, -.14582800E+00, -.17021200E-02, 0.31960700E-01, 0.20984600E+00, 0.43891900E-01, 0.23248600E+00, -.67599400E-01, -.52476200E+00, 0.22635800E+00, 0.15988600E+01, -.58070800E+00, 0.26223700E+01, -.22537100E-01, 0.59780000E+00, -.45486900E+00, -.10668600E+01, -.31702500E+00, 0.76048100E+00, -.11316400E+01, 0.44640600E+00, -.21654800E+00, 0.18262300E+00, 0.51375600E+00, 0.43728200E-01, 0.50602800E+00, 0.13342000E-01, -.22080900E+00, 0.57124600E+00, 0.14856500E+00, -.72295000E+00, 0.15219300E+01, -.80341600E+00, -.26955500E+00, -.54046300E-01, -.32369600E-01, 0.33010700E+00, 0.85865100E-01, 0.30046600E+00, 0.69253400E+00, 0.82492200E+00, 0.76053400E+00, -.12230700E+00, 0.35639500E+00, 0.34318700E-01, 0.32211500E+00, -.17366400E-01, 0.38175100E+00, -.35096500E+00, 0.44351900E-01, 0.13700200E+00, -.21033500E+00, -.93234100E+00, 0.77310200E+00, -.38807700E+00, 0.65468400E+00, -.86440900E-01, 0.46532700E-01, -.22173800E-01, -.27897600E+00, -.90668100E+00, 0.52899200E+00, -.14261300E+00, 0.25324400E+00, -.81475300E-01, 0.26098900E+00, 0.34868700E+00, -.54367300E+00, -.32212200E-01, -.57082500E-01, -.45357800E+00, 0.60815500E+00, 0.13127500E-02, 0.63647000E-01, -.11080500E+00, 0.74164600E-01, 0.58745400E-01, 0.77100900E-01, 0.27094100E-01, -.14658400E-01, 0.39669300E-01, -.39795900E+00, 0.11518400E+01, 0.11001400E-02, 0.84495800E-01, -.19860800E+00, 0.38635900E+00, -.21607200E+00, 0.34508600E-01, -.30094800E+00, -.19562800E+01, -.21603800E+00, -.78459300E-01, -.79430400E+00, -.47298900E-01, 0.25848400E+00, 0.36589600E+00, -.43324800E+00, 0.48960800E+03, -.24485100E+03, -.35418900E+03, -.24448100E+03, -.63091500E+02, -.10215500E+03, 0.80680300E+01, 0.24715500E+03, 0.54577900E+02, -.11518500E+03, -.11871000E+03, 0.13707200E+03, -.67860800E+02, -.12581700E+03, -.68048700E+02, -.54040200E+02, -.47222500E+02, 0.38651300E+02, 0.39786700E+02, -.99483900E+02, -.44361000E+02, 0.49252300E+02, -.22538100E+03, 0.11297800E+03, -.63995700E+02, 0.11267700E+03, -.13903900E+01, -.62713500E+02, 0.81832600E+02, 0.35640400E+02, 0.14071900E+03, -.75972100E+02, 0.25085500E+02, -.65584500E+02, 0.32408400E+02, 0.41510800E+02, 0.32720300E+02, -.71527800E+02, -.34957800E+02, 0.49989700E+02, -.16516600E+02, -.34736100E+02, -.21126300E+02, 0.64501300E+02, 0.11499200E+03, -.59666400E+02, -.24708800E+03, -.58259600E+02, -.53651700E+02, -.74091000E+02, -.62220900E+02, 0.92394700E+02, 0.16034800E+02, -.76637600E+02, 0.63118100E+02, 0.34675000E+02, -.10562100E+02, -.84556600E+02, -.16910300E+02, 0.10721500E+02, 0.49661200E+02, -.63964500E+02, -.38838500E+02, -.75954900E+02, 0.43117100E+02, 0.14633100E+02, 0.76961000E+02, -.33110200E+02, 0.34207900E+02, -.38728000E+02, -.60208100E+02, -.28572900E+02, 0.82739000E+02, 0.63436300E+01, -.70948000E+02, -.12610100E+02, 0.72310600E+02, 0.17365700E+03, -.85862600E+02, 0.76462600E+02, -.86716000E+02, 0.13960900E+02, -.49020800E+01, -.16188800E+02, -.38155300E+01, -.16075000E+03, 0.21250100E+02, 0.64862100E+01, 0.10038900E+02, -.55346200E+01, -.49634400E+01, -.31155400E+01, -.76284100E+01, 0.83622900E+00, -.10793600E+01, -.11232600E+02, 0.13731000E+02, 0.64375700E+01, 0.11400200E+02, -.21425500E+01, 0.11679000E+02, 0.13196100E+02, -.46480500E+01, -.34345900E+01, 0.10329000E+01, 0.13917300E+02, -.29381000E+01, -.35689400E+02, -.16995200E+02, 0.66538700E+01, -.11338600E+02, 0.14843100E+02, -.15110500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12077700E+02, 0.14127600E+00, -.10023500E+02, -.14701900E+01, 0.76827700E+01, -.20331200E+01, -.85206800E+00, 0.80512600E+00, -.99068400E+00, 0.10054900E+01, 0.52788800E+00, -.15740300E+01, 0.39697000E+01, -.23059700E+01, -.25748200E+01, -.97084700E+00, -.10958500E+01, -.59031000E+01, -.19255800E+01, -.85683900E+00, -.33797400E+01, -.13085200E+01, -.39490500E+00, 0.20087300E+01, 0.35957900E+00, 0.14317400E+01, 0.27184200E+01, -.61625700E+01, -.10348400E+01, 0.11719900E+01, -.74704000E+00, -.35588400E+00, 0.67912500E+01, 0.12627000E+01, -.92233000E+00, -.28374600E+00, -.32129900E-01, 0.14840600E+01, -.16275100E+01, -.20065500E+01, 0.60121300E+00, 0.52715400E+00, -.12862000E+02, 0.11508900E+01, 0.95636500E+00, 0.83328500E-01, 0.11274000E+01, 0.12846400E+00, 0.51222200E+00, 0.11634400E+00, 0.60595100E+00, 0.46788200E+00, 0.14459300E+01, -.13816500E+01, -.65994200E+00, 0.67108500E+00, -.52297200E-01, 0.88531300E-01, -.36253100E-02, 0.85534400E+00, -.95958300E+00, 0.85705100E-01, 0.17475600E+00, -.20827100E+00, 0.48152200E+00, -.65927800E-01, 0.23324900E+00, -.23104000E+01, 0.12952200E+00, 0.56569900E-02, -.39747800E-01, -.64767000E+00, 0.28209200E+01, -.55638100E+00, 0.10318800E+01, -.11239100E+01, 0.50993100E+00, -.36417900E+00, -.51455500E-01, -.25207100E+00, -.50167700E-02, -.18480400E+01, 0.11954300E+01, -.10704500E+01, -.76740700E+00, 0.27304400E+00, -.10582700E+00, 0.65175100E+00, -.19791300E+01, 0.37907500E+00, -.62481200E+01, 0.25012500E-01, -.52041700E+00, -.71378000E-01, 0.22287800E+01, -.34272700E+00, -.30459400E+01, 0.98846500E+00, -.24755300E+00, 0.21237900E+00, -.13081200E+01, 0.26947600E+00, -.48824300E-01, 0.14617600E-01, -.69616300E+00, -.46234700E+00, 0.64579100E+00, -.22342800E+00, 0.71651900E+00, -.15531600E+00, 0.90008800E-01, -.62516700E+00, -.34851500E+00, 0.29786600E-01, -.14172900E+00, -.15799300E-01, -.15974700E+00, 0.27739400E-01, 0.57444000E+00, -.79356500E+00, -.11920100E+00, 0.22142800E+00, -.58314500E-02, 0.23329400E+00, 0.27363800E-01, -.35917100E+00, 0.13919600E+01, -.29936400E+00, 0.13151700E+00, 0.88772100E-01, 0.39170200E+00, 0.69621200E+00, -.10432200E+01, -.11859900E+01, -.11800800E+00, -.77153100E-01, 0.80498400E+00, -.15781500E+01, 0.11814500E+01, -.21340900E+00, -.23779200E+00, 0.89883200E+00, 0.28682900E+00, -.72448800E+00, 0.57238800E+00, -.80563500E+00, -.12073300E+00, -.14311300E+00, -.41953900E+00, 0.16500100E+01, -.36661000E+00, -.28346300E-01, 0.13497100E+00, 0.14245400E-01, -.33084300E+00, 0.46002800E-01, 0.20759200E-01, 0.40411700E-01, 0.24053300E-01, -.41353000E+00, 0.28513800E+00, -.25428400E-01, 0.70792900E-01, -.61834300E-01, -.29421000E+00, -.81783500E-01, -.29413600E+00, 0.78572400E-01, 0.67957800E+00, 0.36135600E+00, 0.11826800E+00, 0.83737200E-01, 0.88159800E-02, -.94849900E-01, 0.23063400E+00, 0.11419900E+01, 0.14729800E+00, 0.13092500E+02, -.59707600E+02, -.31701500E+00, 0.58504100E+02, -.68787300E+01, -.17490500E+02, 0.28975600E+02, -.15903200E+02, 0.47076000E+01, -.68178300E+01, 0.75728800E+02, -.34236500E+02, -.67818500E+02, -.38392400E+02, 0.65278100E+00, -.29912200E+02, 0.15047300E+01, 0.39534100E+02, -.42786200E+02, -.13812300E+02, -.48351400E+02, 0.66393100E+02, -.34291700E+02, -.43140900E+02, -.33187300E+02, 0.77398100E+02, -.73139800E+01, 0.11058600E+02, 0.52867400E+02, -.35277400E+02, -.15049600E+02, -.88155700E+02, -.19442200E+02, 0.91439700E+01, -.13364700E+02, 0.97650600E+01, -.55740700E+01, -.16727200E+02, 0.13093400E+02, 0.78982000E+01, 0.24203800E+01, -.15456300E+02, -.19225600E+02, -.30866700E+03, 0.16440000E+03, 0.44389100E+02, 0.15492700E+03, 0.60430100E+02, -.61352300E+02, 0.37560100E+02, -.25678100E+02, 0.72087500E+02, -.56578300E+02, 0.18869300E+03, -.30028300E+02, 0.14868100E+02, 0.56636200E+02, 0.14807000E+02, 0.24971600E+01, 0.19237900E+02, -.19252000E+02, -.24980900E+01, -.13976300E+02, 0.16871000E+02, 0.25060600E+02, 0.70980300E+02, -.46230600E+02, -.19389300E+02, -.35476900E+02, -.42198000E+02, -.19154900E+02, 0.95244400E+01, 0.82074100E+01, 0.20687700E+02, -.13230400E+02, -.26271300E+02, -.65007300E+02, 0.34110500E+02, 0.51158200E+02, 0.32454000E+02, -.75159100E+02, -.15980500E+02, 0.12228800E+02, -.38991500E+02, 0.37522400E+02, -.57863700E+01, 0.57170000E+02, 0.39615400E+01, -.39729600E+01, 0.13326600E+02, -.38993200E-01, 0.45627300E+01, -.63158400E+01, 0.52435500E+01, 0.42716800E+01, 0.84222300E+01, 0.33268900E+01, 0.49781400E+01, -.22986700E+01, 0.23368300E+01, 0.83016400E+01, -.32060400E+01, -.56746600E+00, -.12381600E+02, -.74826200E+01, 0.39156400E+01, -.13215200E+02, 0.22661700E+01, 0.14206400E+02, -.21013900E+00, -.68879100E+00, -.46849500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54675900E+01, 0.50966100E+00, -.97613100E+00, 0.17894800E+01, -.21065300E+01, -.30223500E+01, 0.32408800E+01, -.61069700E-01, -.46353700E+00, 0.14497700E+00, -.19389400E+00, -.68853300E+00, -.23220800E+01, -.73986300E+00, 0.30785400E+00, 0.18111600E+01, -.11867600E+01, -.17695400E+01, 0.10826800E+01, -.10413400E+01, 0.12529100E+01, -.12354300E+00, 0.16538600E+00, -.21290100E+01, 0.16096100E+00, -.18061400E+00, 0.20579800E+01, 0.71511200E+00, -.17720600E+01, 0.49449300E+00, 0.23023800E+00, -.63543600E+00, 0.20407700E+00, -.14683100E+01, 0.31445800E+00, -.66943400E-01, 0.46987400E-01, -.65144000E-01, -.29357400E+00, -.92836900E+00, -.19546700E+00, -.46429900E+00, 0.25951600E+01, -.13269500E+00, -.77755300E+00, -.36406200E+00, -.39969200E+00, -.92769400E+00, -.85357900E+00, -.12057300E+00, -.10130300E+01, 0.10625600E+01, -.75986600E+00, -.17099100E+01, 0.10769700E+00, 0.18300800E+01, 0.19570700E+00, -.51929100E+00, -.49208000E-03, 0.15462200E+01, -.34921800E+01, -.10147500E+01, -.17736600E+00, -.83783900E+00, -.95429900E+00, 0.12525800E+01, -.46315500E+00, -.26500100E+01, 0.35042000E+00, -.96680800E-03, -.11121600E+01, 0.38277200E+00, 0.52065200E+00, 0.94682100E+00, -.51022600E+00, -.83289500E+00, 0.25176600E+00, 0.58053200E+00, 0.47854200E+00, 0.47228000E+00, -.70920400E-01, -.11390100E+01, -.93307600E-01, -.64857600E+00, -.27061900E+00, 0.87332000E-01, -.72375100E-01, -.24038900E+00, -.13245600E+01, 0.79514300E+00, 0.25816000E+00, 0.94893400E-02, 0.13573200E+00, -.47746100E+00, -.62884200E+00, -.57431600E+00, 0.15782000E+01, -.31401200E+00, 0.73710900E+00, -.25343400E+00, -.20074400E+00, 0.29448000E+00, 0.16861600E-01, -.64166300E-01, 0.15167800E+00, -.38367900E-01, -.53329600E+00, -.25992900E+00, -.57359300E+00, 0.63529700E+00, 0.41229900E+00, -.14959300E+00, -.53610200E+00, 0.17595800E-01, 0.26500700E+00, 0.21060100E+00, 0.97435700E-02, 0.93078400E+00, 0.43136800E+00, -.47054500E+00, -.64869200E-01, -.64254100E+00, 0.11357900E+00, 0.22082100E+00, -.10863300E+00, 0.22995300E+00, -.63856100E+00, 0.86616600E-01, 0.98498400E-01, -.45008400E-01, -.12832900E+01, 0.78732700E+00, -.10890800E+00, 0.81886500E+00, -.10419400E+00, 0.12932400E-01, 0.22073000E-01, 0.39339200E+00, 0.86236600E+00, -.10291500E+00, -.33950700E-01, -.41754500E+00, -.26974500E+00, 0.51340200E+00, -.12397800E+00, 0.66226700E+00, 0.12812900E+00, 0.25706400E+00, -.74643000E+00, -.61785500E+00, 0.11482400E+01, 0.67812400E-02, -.10111600E+00, -.11170400E+00, 0.19098700E+00, -.43934700E-03, -.11148200E-02, -.87499400E-01, 0.25244400E-01, 0.51993000E+00, 0.12359800E+00, 0.19307700E-01, -.90142700E+00, -.21522300E+01, 0.37335100E+00, 0.68539000E+00, 0.35380100E+00, -.21571700E+00, -.15597700E+01, 0.47118100E+00, -.26307400E+00, 0.35562300E+00, 0.12588100E+00, 0.15038500E+00, -.10272000E+00, -.57144000E-01, -.39556600E+00, -.77977800E-03, -.16146500E+03, -.43628400E+00, -.91271100E+02, -.82123900E+02, 0.20889800E+02, 0.41140400E+02, 0.11711900E+03, -.78655300E+02, 0.96010600E+02, 0.56994700E+02, -.26755200E+02, -.13858700E+03, -.29959000E+02, -.15447700E+02, 0.13607200E+02, -.22712100E+02, -.44719300E+02, 0.63292800E+02, 0.25206100E+02, 0.64387800E+02, -.49910900E+02, 0.24474500E+02, -.59560700E+02, 0.25002400E+02, -.54556800E+02, -.53941600E+01, 0.59191900E+02, -.72297400E+01, 0.25550000E+02, -.25398900E+02, -.14199900E+03, 0.52318500E+02, -.25125300E+02, -.16180700E+02, -.25879200E+02, -.59986100E+02, -.69128000E+01, -.13323800E+02, -.69094600E+02, -.90382000E+02, 0.16045700E+02, 0.14184700E+01, 0.19721100E+03, -.10278600E+03, -.24199500E+03, -.96973600E+02, -.41462100E+02, 0.76349900E+02, -.10922300E+03, 0.12120700E+02, -.13101500E+03, 0.94608000E+02, -.37238000E+02, -.11465400E+03, 0.75316500E+02, -.37251300E+02, 0.59327800E+02, 0.13652200E+03, 0.15671800E+03, -.17491200E+03, -.72673100E+02, -.20855300E+02, 0.15213500E+03, 0.47354200E+02, -.61775200E+02, 0.34791700E+02, 0.35227100E+02, 0.30644300E+02, 0.22166700E+02, 0.19389200E+02, 0.28935500E+02, -.54118300E+02, -.21724800E+02, 0.18886100E+02, 0.14059500E+03, 0.18581900E+03, -.94623100E+02, -.83208900E+01, -.93342600E+02, 0.37137500E+02, 0.28242200E+02, -.10426900E+03, -.57195000E+02, -.61498700E+02, 0.33800200E+02, 0.72804100E+02, -.33777500E+01, -.13027200E+01, -.27669200E+01, -.18045100E+01, -.50747400E+02, -.31596100E+01, 0.62721000E+01, -.50827400E+02, 0.64642100E+02, 0.82513600E+01, -.52712300E+01, -.12453100E+01, 0.10068500E+01, 0.64458400E+02, -.74124300E+01, -.39926700E+01, 0.18375800E+02, 0.12395000E+02, -.37394200E+01, -.12741900E+01, -.21781500E+02, 0.22798200E+01, -.31081800E+02, -.71782100E+01, -.97256700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12005400E+02, 0.13359300E+01, 0.17574100E+01, -.37183800E+01, -.65761900E+01, -.93192700E+00, 0.26168700E+01, -.39669500E+00, -.38230800E+00, 0.22285800E+01, 0.25672500E+01, -.14584000E+01, -.18624200E+01, -.75052600E+00, 0.30014400E-01, 0.24495400E+01, 0.10392700E+01, 0.22147100E+00, -.37907400E+00, 0.22753800E+01, 0.10076500E+01, -.85731400E-01, 0.17959800E+01, 0.45939800E+01, 0.23993100E+00, 0.14036800E+01, -.27186500E+01, 0.35654500E+01, 0.91288100E+00, -.49122700E+00, -.47162000E-01, 0.18844400E+01, -.29539400E+01, 0.31215800E+01, -.72260000E+00, -.12259900E+01, 0.12370300E+00, -.13432000E+00, 0.39173900E-01, 0.39452300E+00, 0.60145200E+00, 0.13357300E+01, -.47136100E+01, -.16569500E+00, 0.55089300E+00, -.18686900E+00, 0.14977200E+01, -.29670300E+01, -.39979500E+00, 0.32999200E+00, -.21504100E+01, 0.12160700E+01, 0.37344800E+00, -.43144100E+00, 0.19267900E+01, 0.18402300E+01, 0.27630400E+00, -.50654500E+00, 0.14491300E-01, -.19674400E+00, -.29276500E+01, -.12170900E+01, 0.59537300E+00, -.10109000E+00, 0.97869700E+00, 0.78897200E+00, 0.26268100E+00, -.81008900E+00, 0.57383600E-01, -.15302700E-01, 0.32838400E+00, 0.79746700E-01, 0.48967600E+00, -.16974100E+01, 0.30006200E+01, -.32718600E+00, 0.37040900E+00, 0.75433000E+00, -.56215100E-01, 0.91589300E+00, 0.63774900E-01, 0.92222400E+00, 0.34927200E+00, -.83784600E+00, -.50151200E+00, -.58250300E-01, 0.80920500E+00, 0.13378800E+00, 0.11877700E+00, 0.41322000E+00, -.29850000E+01, -.50253000E-01, -.40201500E+00, -.32531000E+00, 0.12386900E+01, -.72958500E+00, -.27554200E+01, 0.39055700E+00, 0.49380600E+00, 0.51823200E+00, -.21373200E+01, -.48532000E+00, -.76083200E-01, 0.21241100E+00, -.69804400E+00, -.14110600E+01, 0.30878200E+00, -.12286300E-01, 0.11272700E+01, -.21037000E+01, 0.66255300E+00, 0.12879700E-02, 0.27699200E+00, 0.10121100E+00, -.58902500E+00, 0.15512500E-01, -.40540800E+00, -.54315200E+00, 0.51727800E+00, 0.41825300E-01, -.22856800E+00, 0.15442900E+00, -.11816200E+00, 0.34056800E+00, -.62373400E-02, -.24839500E+00, 0.10109500E+01, -.32226500E+00, 0.13773700E+00, 0.19460200E+00, 0.65762500E+00, -.21757100E+00, -.88079300E+00, -.11096700E+01, -.18806500E+00, 0.11671800E+00, 0.20751700E+00, -.12097600E+01, 0.73991500E+00, -.21350100E+00, -.39929200E+00, 0.87015400E+00, 0.11824600E+00, -.20875600E+01, 0.52918900E+00, 0.84320600E-02, -.11070300E+00, -.67929700E-01, 0.30512300E+00, 0.22292100E+01, -.96043300E+00, 0.14804300E+00, 0.72365500E+00, 0.38882700E-01, -.91837800E+00, 0.84807500E-01, -.11912500E+00, -.11257900E+00, 0.35586000E+00, -.16645600E+00, 0.18876400E+00, 0.41838500E-01, -.28217300E+00, 0.38064900E+00, -.19284900E+00, -.41175400E+00, -.17839000E+00, 0.40104800E+00, 0.21615500E+01, 0.26593500E+00, 0.11093400E+00, 0.41223900E+00, 0.10007000E+00, -.76551800E+00, 0.24552600E+00, 0.21081300E+01, 0.10698300E+00, -.31277300E+00, -.37134900E-01, 0.39372300E+01, 0.16115200E+03, 0.22256200E+02, -.25561800E+02, 0.17956400E+02, -.10583200E+03, 0.43205800E+02, -.10738400E+03, -.22152300E+02, 0.71829900E+01, 0.80652100E+02, 0.12720100E+02, 0.83182500E+02, 0.17838300E+02, -.34350800E+02, 0.10607800E+02, -.20487200E+03, 0.40227000E+02, -.10015400E+03, 0.49690500E+03, -.24292200E+03, -.19976300E+02, -.24849400E+03, 0.80516400E+02, -.84105000E+02, -.13351000E+03, -.36998700E+01, -.26469500E+03, -.52211500E+02, -.16739300E+03, -.67075600E+02, 0.34842700E+02, -.35504300E+01, 0.33290500E+02, -.59273400E+01, -.43543700E+02, 0.81792900E+01, 0.11247200E+02, 0.20431300E+02, -.38246900E+02, -.47668400E+02, -.65826800E+03, 0.33232800E+03, 0.21606500E+03, 0.32839900E+03, 0.68478700E+02, -.12306100E+03, 0.15323900E+03, -.14731100E+02, 0.20916300E+03, -.10953000E+03, 0.35648000E+03, 0.20714400E+03, -.11144900E+03, 0.12150300E+03, -.10564300E+03, -.17730300E+03, -.18591000E+03, 0.16904800E+03, 0.12118700E+03, 0.10303200E+02, -.19147300E+03, -.57472800E+02, 0.20757100E+03, -.11752000E+03, -.60822600E+02, -.10348800E+03, -.10490700E+03, -.48362900E+02, -.12073100E+02, 0.63136300E+02, 0.12387000E+02, -.30988900E+02, -.20441800E+03, -.34442800E+03, 0.16931500E+03, 0.54987900E+02, 0.17256200E+03, -.11342100E+03, -.21833800E+02, 0.10460500E+03, -.71315900E+02, 0.13089300E+03, -.30144500E+01, 0.10016000E+03, 0.24536500E+01, -.23876800E+01, 0.20581400E+02, 0.38536400E+01, 0.57677400E+02, -.60080000E+01, 0.35753800E+01, 0.57056400E+02, -.50380500E+02, -.49140300E+01, 0.16841300E+02, -.50936900E+01, 0.46032600E+01, -.50214800E+02, 0.45549000E+01, 0.52975900E+01, -.33257900E+02, -.19479700E+02, 0.35979300E+01, -.49767900E+01, -.22768500E+01, 0.27230900E+02, 0.22040300E+02, 0.11976100E+02, 0.33923200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24502500E+01, 0.26350900E+00, 0.54815400E+00, 0.18023000E+00, 0.87115700E+00, 0.94498700E-01, -.14816100E+00, 0.11620600E+00, 0.96047200E-01, 0.12123700E+00, 0.55998800E-01, 0.47216500E+00, 0.40848000E+00, 0.33118800E+00, 0.23710400E-03, 0.14039000E+00, 0.10095100E+01, 0.31237100E-01, 0.23650400E-01, 0.45570100E+00, -.32851700E+00, -.21940000E-01, 0.15568100E+00, 0.65015100E+00, -.20144900E-01, -.35104700E+00, -.12629000E+01, -.77993900E+00, 0.67810200E-01, -.34618500E+00, 0.11098400E-01, -.17374500E+00, 0.11882700E+00, 0.13275700E+00, 0.64638400E-03, -.36939200E+00, -.10782300E-01, 0.20607600E-01, -.59505200E-01, -.47686700E+00, -.74370000E-01, 0.52955100E-01, -.97423500E+00, 0.52379500E-01, 0.11883300E+00, 0.13271100E-01, 0.24780500E+00, 0.12786100E+00, 0.12045900E+00, 0.73502500E-01, 0.57173700E+00, 0.10025400E+00, 0.40717300E+00, 0.45848100E+00, 0.23327900E+00, 0.13581500E+00, 0.66873500E-01, -.11579900E+00, 0.49549700E-03, 0.11962000E+00, -.37374600E+00, -.16422200E+00, 0.46491300E-01, 0.17557200E-01, -.77372000E-02, 0.81547800E-02, -.34220300E-01, -.12500100E+00, -.14114600E-01, 0.13377400E-02, 0.89114300E-01, -.57331100E-01, -.88312600E-01, -.95169700E-01, 0.36123900E+00, -.28166000E+00, 0.30183100E-01, 0.14719600E+00, -.69239300E-01, 0.67170400E-01, -.12797400E-02, -.27897500E-01, -.89578100E-01, -.10361600E+00, -.77811600E-01, 0.36417600E-01, 0.13841400E+00, 0.14431100E+00, -.45057700E+00, 0.13700000E+00, -.13188600E+01, 0.58100500E-02, -.43426100E-01, 0.76787700E-02, 0.17252700E+00, 0.11799300E+00, -.66626000E+00, 0.33967600E+00, 0.53990000E-01, 0.10401700E+00, -.25606600E+00, 0.16682400E+00, -.66140200E-02, -.25226500E-01, -.12478100E+00, 0.28155400E-01, 0.10435100E+00, -.87361100E-01, 0.11468300E+00, -.59549100E+00, 0.36403100E-02, -.56060100E-01, 0.93327700E-01, 0.17348800E-01, -.82418300E-01, 0.30928900E-01, 0.25695700E+00, 0.72373700E-01, -.28848700E+00, -.35216400E+00, 0.48490400E-01, -.41038100E-01, -.47522800E-01, -.22042000E+00, 0.20404100E-02, 0.29602300E-01, -.10066800E-01, 0.10592400E-02, 0.43400900E-01, 0.34267200E-01, 0.59181400E+00, -.16583300E+00, -.10310300E+00, -.39614100E+00, 0.26480800E-02, 0.86919900E-02, 0.15295300E+00, -.21524500E+00, 0.25532000E+00, -.14642400E+00, 0.16247600E+00, 0.57351000E-01, 0.19015400E+00, 0.40115300E+00, -.43983800E-01, 0.60958200E-01, 0.97345700E-02, 0.40148000E-01, 0.80306600E-01, -.43000200E+00, 0.12598800E+00, -.45400300E-01, 0.71032400E-01, -.34471000E-01, -.37515700E-01, 0.20657800E-01, 0.24753400E-01, 0.40857700E-01, 0.13630600E-01, 0.22917000E+00, 0.15688700E+00, 0.13423700E-01, 0.74925100E-01, 0.26971800E+00, -.47304000E-02, 0.92107200E-01, 0.41974700E-01, -.10521900E-01, -.14484000E+00, -.14925100E+00, -.13677300E-01, -.15735700E+00, 0.79411200E-01, -.19268600E+00, 0.13423600E+00, 0.39683500E+00, 0.12871700E+00, -.77166000E-01, -.14142300E+00, -.42194700E-01, 0.72756700E+02, 0.89408700E+01, -.16477200E+02, 0.10007700E+01, -.27819100E+02, 0.18518300E+02, -.18046800E+02, -.44102300E+02, 0.20580500E+02, 0.26799400E+02, 0.21825500E+02, 0.24953500E+02, 0.24969800E+02, -.22897000E+02, -.10834100E+02, -.37555500E+02, 0.37719900E+02, -.15244600E+02, 0.11510800E+03, -.56053900E+02, -.13210000E+02, -.57549000E+02, 0.33667900E+02, 0.63686200E+01, -.69218900E+01, 0.28317700E+02, -.67027600E+02, 0.11528300E+02, -.70891300E+02, 0.63665500E+01, -.27428900E+01, 0.66128600E+01, -.31585400E+01, 0.17935300E+01, 0.16908100E+01, 0.12280000E+02, 0.23707700E+02, -.92086500E+00, -.29466400E+01, -.36164400E+02, -.23964200E+03, 0.11716200E+03, 0.68678700E+02, 0.12012000E+03, 0.57105300E+02, -.28555000E+02, 0.62697900E+02, 0.25978600E+01, 0.54352200E+02, -.15819700E+02, 0.18272300E+03, 0.44216000E+02, -.24776000E+02, 0.43200500E+02, -.22273000E+02, -.46544500E+02, -.52042900E+02, 0.33677400E+02, 0.19469300E+02, -.15525700E+01, -.47528200E+02, 0.25623200E+01, 0.49558600E+02, -.23714500E+02, -.18585100E+02, -.24694400E+02, -.36166000E+02, -.51004300E+01, -.10617000E+02, 0.12966300E+02, 0.11996500E+02, -.68996300E+01, -.87158500E+02, -.45688100E+02, 0.21111300E+02, -.26352400E+02, 0.22810000E+02, -.75110800E+01, 0.27809100E+01, -.59514600E+01, -.22364200E+02, 0.42882000E+02, -.47094900E+01, -.12207300E+02, 0.41885600E+01, 0.19702900E+01, 0.42958100E+01, 0.16708000E+01, 0.13718500E+02, 0.45179500E+00, -.56833600E+00, 0.13882500E+02, -.12838200E+02, -.37605900E+01, 0.59939100E+01, -.48242800E+00, 0.26752100E+01, -.12994900E+02, 0.20842300E+01, 0.19019900E+01, -.30445400E+01, -.85218300E+01, -.37327700E+01, 0.43407100E+01, 0.47187200E+00, 0.10909100E+02, 0.56179700E+01, 0.26016300E+01, 0.50857000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25263300E+01, -.22519700E+00, -.36297100E+00, -.16592300E+01, -.40982800E+00, 0.15779000E+01, -.12743800E+01, 0.18836900E-01, 0.28752200E+00, -.24097700E+00, 0.72608300E-01, 0.10109500E+00, 0.84725100E+00, 0.85725300E+00, -.16444200E+00, -.70749200E+00, 0.18552100E+00, 0.89338000E+00, -.55253100E+00, 0.57799900E+00, -.74232000E+00, -.16114500E-01, 0.84250500E-01, 0.12322300E+01, -.56959500E-02, 0.37327100E-01, -.13639100E+00, -.20911800E+01, -.21940600E+00, 0.28669800E+00, -.93369600E-01, 0.47468200E-01, 0.95984900E+00, 0.22078700E+00, -.32872300E-01, -.35233600E-01, -.30009000E-01, 0.12038800E+00, -.27398700E+00, -.90298400E+00, -.50708800E-02, 0.26304500E+00, -.10914900E+01, 0.90160900E-01, -.24476800E+00, -.69753500E-01, 0.11587600E+00, 0.55829300E+00, -.51960800E+00, -.39426300E-01, -.44425300E+00, 0.59975500E+00, 0.18686300E+00, 0.35054600E+00, -.54492500E-01, 0.51241200E-01, 0.28756700E-01, -.12540400E+00, 0.26027600E-02, -.63183200E-01, 0.10968400E+00, 0.14870000E-01, 0.54959100E-02, -.11187200E+00, -.16523900E+00, 0.70999100E-01, -.37496700E-01, 0.52941700E+00, 0.48138600E-01, -.20986100E-02, 0.13911400E+00, -.10573400E+00, 0.13464300E+00, -.72547900E-01, 0.24390000E+00, -.29308300E+00, 0.31659700E-01, -.11073200E-01, -.18278100E+00, -.14252500E+00, 0.20442200E-01, -.40496200E+00, -.15672200E-01, 0.16358200E+00, -.84438200E-01, -.15828200E-01, 0.11555700E+00, -.23515400E-01, -.92349400E-01, 0.46541400E-01, -.13276900E+01, 0.47993800E-02, 0.11690100E+00, -.31738700E-01, 0.24392500E-01, 0.14085200E+00, -.34947800E+00, 0.12733100E+00, -.45108500E-01, 0.78872700E-01, 0.71593200E-02, 0.17458300E+00, 0.10754200E-01, 0.13983100E+00, -.14697600E+00, 0.54182400E-02, 0.18552000E+00, -.49002300E-01, 0.20492500E+00, -.10260400E-01, -.31706900E-01, -.48106600E-01, -.50206900E-01, 0.75508000E-02, 0.46699200E-01, -.17778900E-01, -.12994300E+00, -.12154000E+00, 0.30094000E+00, 0.17909600E-01, -.70563100E-01, 0.14892200E+00, 0.17752700E-01, 0.15080100E+00, -.18220200E-02, -.99482800E-02, 0.47177800E-01, 0.35090700E-01, -.65216000E-02, -.12636600E+00, -.23422100E-01, 0.34675700E+00, -.22766900E+00, 0.32565500E+00, 0.17008200E-01, 0.10925600E-01, 0.55686300E-01, -.20676600E+00, 0.21490400E+00, 0.15627800E+00, -.32995200E+00, 0.40274300E-01, -.15268100E+00, -.43469300E+00, 0.18343400E+00, -.15415600E+00, -.70299400E-01, -.36496700E-01, -.26887200E+00, 0.10580400E+01, -.22956300E+00, -.43794300E-01, -.33229300E-01, -.24821800E-01, 0.37777300E+00, -.10002900E-01, 0.60160900E-02, 0.79446700E-01, -.44101300E-01, -.40775200E-01, 0.36199000E+00, -.64557200E-01, 0.43141000E-01, 0.91957200E+00, 0.60264500E-02, -.92601800E-01, -.48307300E-01, 0.49937800E-02, 0.12294600E+00, -.16024700E+00, -.88652600E-01, -.29961400E+00, -.75796900E-01, 0.20659900E+00, -.74429200E-01, 0.66997900E-01, -.23731700E-01, -.26354200E-01, 0.90387000E-01, -.30707200E-01, 0.46274600E+00, 0.25672700E+02, 0.98206900E+01, 0.96372700E+01, -.18729500E+02, 0.11479800E+02, 0.24813300E+01, -.27061500E+02, 0.13716800E+02, 0.81900500E+01, 0.13386400E+02, -.45641500E+01, 0.34043000E+01, -.50150900E+01, -.66996200E+01, 0.98395000E+01, -.10798600E+02, 0.35446900E+02, -.72055600E+02, 0.35807000E+02, 0.57140000E+00, 0.36033000E+02, 0.88150500E+01, 0.29363200E+02, -.92997600E+01, 0.24555400E+01, 0.31275800E+02, 0.21945800E+02, 0.72962200E+02, -.31354300E+02, 0.15675100E+02, 0.41656800E+01, 0.15708900E+02, 0.17473900E+02, -.24663300E+01, 0.24786900E+01, 0.25865200E+01, 0.24753600E+02, -.10689900E+01, 0.30787300E+02, -.20204400E+02, 0.12432100E+02, -.98557800E+01, 0.10270300E+02, 0.10469900E+01, 0.23991800E+02, -.35538200E+01, -.24469600E+02, 0.28105400E+02, 0.27899500E+01, -.12949300E+02, -.15904800E+02, 0.77821200E+01, -.25067200E+01, 0.82121800E+01, 0.95576200E+01, 0.24018700E+02, -.10095900E+02, 0.20568100E+01, -.10325000E+02, 0.25131400E+02, 0.18932600E+01, 0.23187700E+02, -.15832200E+02, -.75808400E+01, -.11652200E+02, -.14624700E+02, -.31616800E+02, 0.84090100E+01, 0.51766100E+01, 0.10378100E+02, -.24219500E+02, 0.28517900E+02, 0.84022000E+02, -.41466800E+02, -.63884400E+01, -.42061300E+02, -.28209300E+02, -.44099300E+02, 0.50058600E+01, 0.20284200E+02, -.48062900E+01, -.59756300E+02, 0.10229100E+02, -.21560600E+01, -.15108200E+01, 0.73425600E+01, 0.29234200E+01, -.25695000E+01, -.12072100E+01, 0.13381100E+01, -.26486500E+01, 0.84325900E+01, 0.53581600E+00, -.31887600E+01, -.54166500E+00, -.33337300E+01, 0.90066600E+01, -.34874100E+00, 0.27840400E+01, -.91176900E+01, 0.12175700E+01, 0.36528800E+01, 0.89565900E+00, 0.49655800E+01, -.50677700E+01, -.30995400E+00, -.66961200E+01, 0.60171700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39665000E+01, 0.61244600E+00, 0.26916100E+01, 0.13628900E+01, 0.15250700E+01, 0.32112800E-01, -.33425200E+00, 0.16166000E+00, 0.23565900E+00, 0.11230000E+01, 0.22559700E+00, 0.15375400E+01, 0.15027200E+01, 0.24788900E+00, 0.11450100E-01, 0.72036600E-01, 0.56433300E+00, 0.10579300E+01, 0.42839900E+00, 0.60838400E+00, -.60454900E+00, -.11055300E+00, 0.27060400E-01, 0.35975200E+00, 0.21228800E+00, -.20719600E+00, -.27881800E+00, -.68340500E+00, -.56751900E+00, -.52777400E+00, -.85641500E-02, 0.52622400E-01, 0.10995900E+00, 0.26908700E+00, -.55827200E-01, -.79612500E+00, -.14674900E-02, -.53070100E-01, -.31617400E-01, 0.10872300E+01, 0.10839400E-01, 0.55154100E+00, 0.37089800E+00, 0.63342300E-01, 0.41496400E+00, 0.33701100E+00, 0.30875100E-01, 0.67431900E+00, -.52862300E+00, -.44946400E-01, -.60681200E+00, 0.19287600E+00, 0.58643000E-01, -.87130000E-02, 0.44689900E+00, -.14613100E+00, -.60204300E-01, -.20421900E+00, 0.52400800E-03, -.13682200E+00, -.31179600E+00, -.31443900E+00, -.39764900E-01, -.32827200E+00, -.15673000E+00, 0.27168000E+00, -.28864400E-01, 0.71970700E+00, 0.38605900E-01, -.95351000E-03, 0.11968400E+00, -.21472400E+00, 0.53683800E+00, 0.81474500E+00, -.15888500E+00, -.51567600E+00, -.17849000E+00, 0.91623900E-01, 0.28545100E-02, -.67719400E-01, -.15053400E-01, 0.52634700E+00, -.15962100E+00, -.19080200E+00, 0.66131200E-01, -.56530800E-01, 0.17563700E+00, 0.36180900E+00, -.33255800E+00, 0.17865200E+00, -.60315700E+00, 0.91508300E-02, -.86321900E-02, -.36300800E-01, -.65889300E-02, -.43070900E-01, 0.20455800E-01, 0.95232700E-01, -.80096400E-01, 0.15851000E+00, -.22715100E+00, -.39849800E+00, -.51034600E-02, -.11408100E+00, -.48187400E-01, -.96507400E-02, -.47838300E+00, -.12637000E+00, 0.17984700E+00, 0.31808100E+00, 0.31460900E+00, -.33173100E-01, 0.44872900E-01, 0.13362000E-01, -.17316100E+00, 0.92585900E-01, 0.10186000E-01, 0.28704400E+00, 0.49774800E+00, -.37145300E+00, 0.14275900E+00, 0.10216700E-01, -.37985600E-01, 0.15399400E-01, -.13709600E-01, -.78055500E-01, 0.73800900E-01, -.15116200E-01, 0.10177200E+00, -.65493600E-01, 0.13720700E+00, -.92163700E-01, 0.70810200E-01, 0.18703700E+00, 0.47519900E-01, 0.96342700E-02, -.18137100E+00, 0.17863800E+00, -.20528100E+00, 0.18695600E+00, -.47684400E-01, -.16332900E+00, 0.13245500E+00, -.14797200E+00, 0.55339400E-01, 0.64243600E+00, -.28609800E-01, 0.92969300E-01, -.39665400E+00, 0.57950900E+00, -.23373300E+00, 0.19219900E-01, 0.85047800E-01, 0.59632700E-01, -.78360500E-01, 0.95351200E-02, -.25356100E-01, 0.12795800E-01, 0.99044400E-01, 0.10205300E+00, 0.59287400E+00, -.13625800E+00, -.16021100E+00, -.50286400E+00, -.13113100E+00, 0.22786400E+00, 0.45767100E-01, 0.15716900E-02, -.33003800E+00, -.16369600E+00, -.41923100E-02, 0.54900500E-01, -.10521500E+00, 0.50564900E+00, 0.18015600E+00, -.18624800E+00, 0.27730000E-01, 0.12394200E+00, 0.22927400E+00, 0.90044400E-02, 0.48734300E+00, 0.22144400E+00, -.29518400E+02, -.23498100E+01, 0.31774000E+02, -.21610500E+01, 0.20841200E+02, 0.12007700E+03, -.58170200E+02, -.83285800E+02, -.59654200E+02, -.45446900E+02, -.75666900E+02, 0.33493100E+02, 0.78564300E+02, 0.50576200E+02, -.81791900E+02, -.50111000E+02, -.19365500E+03, 0.94675700E+02, 0.17644900E+02, 0.96811000E+02, 0.23632800E+02, -.10727900E+02, 0.72954600E+02, 0.62912300E+02, 0.10275200E+03, -.23459400E+02, 0.97434100E+02, -.40117900E+02, 0.19471300E+02, 0.42591700E+01, 0.19958200E+02, 0.32196100E+01, -.68420700E+01, 0.28373900E+02, 0.17963400E+02, 0.27062300E+02, -.11151600E+02, 0.43111300E+02, 0.11841000E+03, -.56909200E+02, -.48689700E+02, -.59634000E+02, -.14137700E+02, -.73311400E+02, -.24860100E+02, -.22845400E+01, 0.69372000E+01, -.90371900E+02, -.11153800E+03, -.47350800E+02, 0.26369800E+02, -.48134400E+02, 0.23095700E+02, 0.57929900E+02, 0.12000400E+03, -.84206200E+02, -.62854700E+02, -.32276900E+02, 0.11457000E+03, 0.11988900E+02, -.29450400E+02, 0.18824800E+02, 0.60479400E+01, 0.14668000E+02, 0.26931100E+02, 0.11091300E+02, 0.17186900E+02, -.78390100E+01, -.11206000E+02, 0.13862200E+02, 0.46140600E+02, -.95496100E+02, 0.49560600E+02, 0.10035900E+03, 0.47915800E+02, -.44007600E+02, 0.59888100E+01, 0.44803300E+02, 0.27141200E+02, 0.65425500E+01, 0.32980500E+02, 0.38165100E+02, 0.32800700E+01, -.70350100E+01, 0.14876500E+00, -.39067300E+01, -.71450300E+01, -.51190800E+01, 0.41539300E+01, -.76852600E+01, 0.11891600E+02, 0.74994300E+01, -.21694100E+01, -.10387200E+00, 0.52187300E+00, 0.11317200E+02, -.42809000E+01, -.45624300E+01, -.81390200E+00, -.20614300E+01, 0.11362800E+02, -.19033200E+02, 0.10557600E+02, -.61601300E+01, -.34230100E+01, 0.16917300E+01, -.14647600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42569200E+01, 0.44338500E+00, -.25622300E+00, -.25096300E+00, -.62356300E+00, -.11196200E+01, 0.72459900E+00, -.20240500E+00, -.77953600E+00, 0.50580200E+00, 0.26337200E+00, -.43748500E+00, -.21179600E+00, -.23700600E+01, -.11317500E+01, 0.11940300E+01, 0.47460200E+00, -.14064300E+01, 0.11016800E+00, 0.71737000E+00, 0.63847000E+00, -.15254700E+00, 0.72468100E+00, 0.31839200E+01, 0.88817100E-02, -.23055600E+00, -.47574700E+00, -.10970300E+01, 0.41833300E+00, -.26951800E+00, -.73496800E-01, -.18260100E+00, -.13181100E+00, -.10727700E+01, 0.18681000E+00, 0.96723100E-01, 0.34506600E-01, 0.13602900E-01, -.53024900E+00, 0.18229900E+01, -.14013700E+00, 0.47903100E+00, 0.22739800E+01, -.18625100E+00, 0.89734600E+00, 0.34680400E+00, -.45397900E-01, -.33341300E+00, 0.87871500E+00, -.10298100E+00, -.42134300E+00, 0.57782600E+00, 0.37545200E-01, -.17362600E+01, 0.62728100E+00, 0.12055200E+01, 0.78704600E-01, 0.17500400E+00, -.23812200E-02, -.15770900E+00, -.50233100E+00, 0.68818400E-01, -.55241300E-01, -.48461800E+00, -.20033400E+00, -.49775400E+00, 0.21805000E+00, 0.17103400E+01, -.18248100E+00, 0.39994600E-02, -.46695700E-02, 0.15961600E+00, 0.69979700E-02, -.18277900E+00, 0.67169900E+00, -.14122000E+00, 0.11182000E+00, 0.29956300E+00, -.33329400E+00, 0.36725000E+00, -.13147000E-01, -.48624900E+00, -.93067800E-01, -.56896200E+00, -.11588700E+01, -.89966200E-01, 0.36942400E+00, 0.40065700E+00, 0.21826000E+00, 0.22801600E+00, -.65878300E+00, -.74516300E-02, 0.11004700E+00, 0.16665900E-01, 0.44773600E+00, 0.86958200E-01, -.88640600E+00, 0.21297400E+00, 0.29298900E-01, 0.32388000E+00, -.34455100E+00, -.39099600E+00, -.53520800E-02, -.85820900E-02, -.14416600E+00, -.17230900E+00, 0.36173000E+00, 0.12062000E+00, 0.50595300E-01, -.13193500E+00, -.55435100E-01, -.70222400E-01, 0.26009500E-01, 0.11029600E-01, -.67454500E-01, -.15673800E-01, -.39405400E-01, 0.40388400E+00, 0.93444400E+00, -.77593300E-01, -.28107100E-01, -.13827600E+00, -.83904800E-01, 0.28996600E-01, 0.23538500E-01, -.59698900E-01, 0.21094800E+00, 0.67526100E-01, 0.83636000E-01, 0.45872700E-01, 0.77807700E+00, -.68615300E+00, 0.45465600E-01, 0.30523100E+00, 0.13472000E+00, 0.74139800E-01, -.70312400E+00, -.22924000E+00, -.38664700E+00, -.43945800E+00, 0.52730400E+00, -.22284700E-01, -.18535000E+00, -.68645700E+00, -.56933800E-01, -.22620200E+00, -.24590600E-01, 0.27215500E-01, -.29139300E-01, -.32879500E+00, 0.28516500E+00, 0.22448400E-01, 0.11111300E-02, 0.13343900E-01, -.27837500E+00, -.12225000E-01, -.46943200E-01, 0.14333100E-02, 0.10597100E+00, 0.12722100E+00, 0.80639200E+00, 0.11324000E+00, -.14120300E+00, -.11500000E+01, -.96296400E-01, 0.25065200E+00, 0.95729800E-02, 0.13623100E-01, -.14401100E+00, -.12068400E+00, 0.18431900E+00, 0.16869900E+00, 0.37892900E-03, -.16781500E-01, 0.32127400E-01, -.80186700E+00, -.35438700E+00, 0.16733900E+00, 0.37217400E+00, -.40282600E-01, -.60311800E+00, -.20634400E-01, 0.11130200E+00, -.50102800E+02, -.21263700E+02, -.21273600E+02, 0.15823300E+02, -.11259100E+03, 0.55475300E+02, 0.57979700E+02, 0.56111600E+02, 0.43650900E+02, 0.26805400E+02, 0.23705500E+02, -.50338400E+01, 0.13032400E+02, 0.33326900E+01, -.28068700E+02, -.46109400E+02, 0.22175200E+02, 0.55982800E+02, 0.23049300E+02, -.47086900E+02, -.45010300E+02, 0.25139300E+02, 0.21346800E+01, 0.19144300E+02, -.23787400E+02, 0.70052000E+02, -.32271400E+02, 0.15141600E+02, 0.42370100E+02, 0.16090400E+02, -.18691100E+02, -.14508200E+02, 0.21415400E+02, 0.22551100E+02, 0.49065100E+01, -.92480400E+01, -.14463500E+01, 0.23585700E+03, -.11948200E+03, -.14901700E+03, -.11773700E+03, -.41938400E+02, -.14886900E+02, 0.10606200E+02, 0.10069000E+03, -.37488100E+01, -.48858700E+02, 0.32423400E+02, 0.23249100E+03, -.12480200E+03, -.42386600E+02, -.11687500E+03, -.84382500E+02, -.42095700E+02, 0.23648800E+01, -.48914900E+02, -.63960800E+02, -.45567000E+02, -.60199900E+02, -.36190700E+02, 0.27418900E+02, 0.22723400E+02, 0.17967900E+02, 0.45348500E+02, 0.43520300E+02, -.35057900E+02, -.70477200E+01, -.63735000E+02, 0.52375500E+02, -.84707200E+02, 0.87087100E+01, -.32847300E+01, -.45445600E+02, -.42549000E+01, 0.44874100E+02, 0.33291200E+02, -.93215400E+01, 0.16394000E+02, -.16574900E+02, 0.21568700E+02, -.13867600E+03, -.95710600E+01, 0.42866600E+01, -.15797800E+01, 0.58919000E+01, 0.50859200E+02, 0.40555600E+01, -.48004300E+01, 0.49528500E+02, -.21885600E+02, -.68285700E+01, -.10277800E+01, -.13961000E+01, 0.23954900E+00, -.22521500E+02, 0.61075400E+01, 0.65462000E+01, 0.41434300E+01, 0.37097000E+01, 0.45006000E+01, 0.24584500E+01, -.78914800E+01, -.12662300E+01, 0.23384200E+02, 0.10352500E+02, 0.57361800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.66491200E+01, 0.66935400E+00, 0.22200000E+01, 0.18118700E+01, 0.19642800E+01, -.15103300E+01, 0.76994600E+00, 0.35868200E+00, -.50447500E+00, 0.20744100E+01, 0.11012900E+01, 0.13415800E+01, 0.22011000E+01, 0.36472600E+01, -.29923000E+00, 0.14475000E+01, 0.29989500E+01, 0.22324800E+01, -.74010100E+00, 0.98014900E+00, -.22505600E+01, -.56522400E+00, -.17755800E-01, 0.18381800E+01, 0.49512600E+00, -.59818200E-02, 0.10167200E+01, -.28309500E+01, 0.51313400E+00, 0.39293600E+00, -.38116000E+00, 0.11511400E+01, 0.27474800E+01, -.96722200E+00, 0.38721700E+00, 0.19347700E+00, 0.51214800E-01, -.24780500E-01, -.57105400E-02, -.12329800E+01, 0.13285600E+00, -.37376500E+00, 0.76807100E+00, -.30048900E+00, -.43536700E+00, -.15320800E+00, 0.50014000E+00, -.13469700E+01, 0.18335500E+01, 0.31553700E+00, 0.17933100E+01, -.10053700E+01, 0.72273500E-01, 0.66344000E+00, 0.23299700E+01, 0.80699200E+00, 0.70093300E+00, -.51510300E+00, 0.29206000E-02, -.10628900E+01, -.20079900E+01, -.13257400E+01, 0.11013900E+00, -.10716400E+01, -.13392300E+00, -.27658600E+00, -.15905800E+00, -.15763900E+01, 0.24375500E+00, 0.50729600E-02, 0.55441600E+00, -.36990100E+00, -.14010700E+01, 0.12813000E+01, 0.66925900E+00, -.12543500E+01, -.20803000E+00, 0.98867300E+00, 0.78172700E-01, 0.83930600E-01, -.12057500E-01, -.28550200E+00, 0.16908700E+00, 0.34606200E+00, -.32532500E-01, -.63710900E-01, -.37375500E+00, -.10580400E+00, -.88026400E+00, 0.28071300E+00, 0.95492600E+00, 0.33149500E-01, 0.44471000E+00, 0.19164000E-01, -.61324200E+00, 0.13129200E+00, -.11078100E+01, 0.70543600E+00, -.17931700E+00, -.71871800E-01, -.38248300E+00, 0.29409700E+00, -.22252700E-01, -.55251900E+00, 0.38217100E+00, 0.57146400E-01, -.12371600E+01, -.77647900E-01, -.34462700E+00, 0.65605300E+00, 0.63989900E+00, -.12311100E+00, -.81097600E-01, -.46830900E-02, -.82609700E-01, 0.38019800E-01, 0.56057900E+00, -.36075900E+00, -.46283800E+00, -.61887400E+00, -.19060400E+00, -.35928100E+00, -.22394700E-01, -.35757900E-01, -.19921500E-01, 0.68628400E-01, 0.69104400E-02, 0.60882400E-01, -.13817800E+00, 0.10557600E-01, -.90818000E+00, 0.10249400E+01, 0.14303700E+00, 0.12666300E+01, 0.75876000E-01, -.13153800E-01, 0.38779900E+00, -.78875600E+00, -.71038300E-01, 0.15827900E-01, 0.36578900E+00, -.14846500E+00, 0.29883700E+00, 0.13887600E+01, 0.14574400E+00, 0.60642700E+00, 0.62400400E-01, -.32919500E-01, 0.71293700E+00, 0.78293500E+00, -.13402200E+00, -.10511200E+00, 0.76712700E-01, -.17330100E+00, 0.10771200E+01, -.15172900E+00, 0.17788100E+00, 0.34869100E-01, -.15520700E+00, 0.60739900E+00, -.11828600E+01, -.12303000E+00, 0.36802200E+00, 0.19586600E+01, -.63523700E+00, -.71178000E-01, -.36028800E+00, 0.11490100E+00, 0.10783100E+01, 0.13782900E+00, -.16756000E+00, -.16206300E+00, -.55155400E-01, 0.25245700E+00, -.60016500E+00, 0.55150300E+00, -.42118900E+00, -.11462300E+00, -.24818200E+00, -.10238900E+00, -.25826300E+00, -.90231400E-01, -.36659600E+00, -.88214200E+00, -.67146100E+02, -.11205000E+02, 0.12468400E+01, -.95457800E+02, 0.48329400E+02, 0.53948200E+02, 0.46600000E+02, 0.56275300E+02, 0.38417800E+02, -.11629800E+01, -.26644600E+02, 0.12515600E+02, 0.39355100E+02, 0.38928100E+02, 0.65976400E+02, -.34300100E+02, 0.23160400E+01, -.32960400E+02, -.25743400E+02, -.33594900E+02, -.88756000E+01, -.23533100E+02, -.32923600E+02, -.11344600E+02, 0.53192000E+02, -.32724400E+02, 0.15202400E+02, 0.15425200E+02, 0.16513900E+02, -.89740600E+01, -.13229700E+01, 0.90832200E+00, -.62669700E+01, -.14066100E+01, 0.70541900E+01, 0.12143500E+03, -.15614100E+02, 0.13675500E+02, -.21704700E+01, 0.92006000E+01, -.60467500E+01, 0.17065500E+02, 0.51164200E+01, 0.65409600E+02, -.19909500E+02, 0.11617700E+02, 0.24233000E+01, 0.11640800E+01, -.63431900E+01, 0.16850100E+02, -.18425800E+00, 0.79345100E+01, 0.44281700E+02, -.61918100E+02, -.71099000E+02, -.54907900E+02, 0.32220100E+02, -.10074300E+02, -.35119000E+02, 0.11546500E+02, 0.11194900E+02, 0.17451700E+02, 0.30454300E+02, 0.20691700E+02, -.53357500E+01, -.27616000E+02, -.24496400E+01, 0.26165700E+02, 0.38826100E+02, 0.78983500E+00, 0.26739500E+01, -.32371400E+02, -.61033200E+00, 0.33823900E+02, 0.16546300E+02, -.14750800E+02, -.13774000E+02, 0.57436600E+01, -.88735700E+01, 0.23234200E+02, -.23993200E+01, 0.43993100E+01, -.24659200E+01, 0.71579900E+00, 0.13745500E+02, 0.44351000E+01, -.33432000E+01, 0.12982600E+02, 0.50498200E+01, -.46688400E+01, 0.36182600E+01, -.70653200E+00, -.34418300E+01, 0.50082100E+01, 0.36814600E+01, 0.56193300E+00, 0.24282300E+01, 0.63612000E+01, -.67467600E+01, 0.35133000E+01, -.81865900E+01, 0.58234100E+01, 0.63957800E+01, 0.50489800E+01, 0.59123000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.58576400E+01, 0.48850000E+00, -.22730700E+00, -.35230500E+00, 0.26306700E+01, 0.23404600E+00, -.15476500E+00, 0.30113600E+00, 0.20803100E+00, -.59821100E+00, -.11013100E+00, 0.39483200E+00, 0.29799800E+00, -.67748000E+00, -.30814800E+00, 0.20912100E-01, 0.24340300E+01, -.14091300E+01, 0.40593700E-01, 0.13253600E+01, 0.65971800E+00, 0.18007000E+00, 0.53255800E+00, 0.90479000E+00, 0.14785700E-02, -.92480400E+00, -.32822200E+01, 0.13543800E+01, 0.51426500E+00, -.15800600E+01, -.42191800E-01, -.22980600E+00, 0.64940700E+00, 0.11997100E+01, -.26910200E+00, -.12016100E+01, -.26957400E-01, -.35315400E-01, 0.28335300E+00, 0.32824000E+01, 0.30365900E+00, 0.13120600E+01, -.70904300E-01, 0.10007900E+00, 0.14110300E+01, 0.69170300E+00, 0.42780300E+00, 0.83817300E+00, -.20971100E+01, 0.31953500E-01, 0.65384800E+00, 0.64004600E+00, 0.87151000E+00, -.50114600E+00, 0.10125000E+00, -.49045800E+00, -.13502200E+00, -.33655000E+00, 0.42825000E-02, 0.79604500E+00, -.12567600E+01, -.11951700E+00, 0.18841800E+00, -.28925900E+00, -.14562000E+00, 0.16446100E+01, -.29864200E+00, 0.12676000E+01, 0.13261100E+00, -.42816800E-03, 0.32753400E+00, -.35386700E+00, 0.11998900E+01, 0.58667200E+00, 0.11898900E+00, -.32857100E+00, -.59363400E-01, 0.28955900E+00, -.47452400E+00, 0.29138300E+00, -.26602200E-01, 0.74632600E+00, -.44055200E+00, -.24382100E+00, -.16900900E+00, 0.19676900E-01, 0.19253000E+00, 0.46948700E+00, -.14027500E+01, 0.30278300E+00, -.46114400E+01, 0.48571100E-01, -.59107200E-01, -.26239800E+00, -.10576000E+00, 0.29609500E+00, -.66825800E+00, 0.89838300E+00, -.13302300E+00, 0.29319400E+00, -.34531300E+00, -.42737300E+00, -.63204400E-02, -.24917800E+00, -.37648800E+00, 0.12036900E+00, -.20189800E+00, -.31609100E+00, 0.12505000E+01, -.26840300E+01, 0.23333100E+00, -.21043300E+00, 0.24508100E+00, 0.11591100E+00, -.37631700E+00, 0.18061000E+00, 0.50623200E+00, -.89527200E-01, -.84038700E-01, -.10210600E+01, 0.19162900E+00, -.42021600E-02, -.26081200E-01, -.30693000E+00, -.91056700E-01, 0.97349300E-01, 0.45217500E+00, -.11861800E+00, -.76100700E-02, -.65620300E-01, 0.93662900E+00, 0.36643500E+00, -.36636900E+00, -.50569800E+00, -.18437400E+00, 0.82713400E-02, -.10698500E+00, -.47360800E+00, 0.90837100E+00, -.74917900E+00, 0.20431000E+00, -.10973200E+00, 0.16934600E+00, 0.71254100E+00, -.18086500E+00, 0.71350200E+00, 0.89572200E-01, 0.21306000E+00, -.73736300E+00, -.72243300E+00, 0.47527500E+00, -.15931500E+00, -.36671200E-01, -.77019700E-01, 0.11302800E+01, 0.52421600E-01, 0.13118000E+00, 0.49188000E-01, 0.40293600E-01, 0.24089100E+00, 0.96640400E+00, -.19449100E+00, 0.16137800E+00, -.12881800E+00, 0.15293100E-01, 0.14768200E+00, -.57199000E-01, -.42808700E-01, -.47256700E+00, -.30962600E+00, 0.32632300E-01, 0.21326300E+00, -.26284600E-01, 0.33194300E+00, -.26855600E+00, 0.95736100E-01, -.54510300E-01, 0.73264900E-01, -.15146900E+00, 0.15311500E+00, 0.13269800E+00, 0.10380100E+01, 0.11032800E+01, 0.40261100E+00, -.37479400E+00, 0.37075600E+02, -.14044200E+02, -.95957000E+02, 0.47205800E+02, 0.40461800E+02, 0.48075000E+02, 0.28737000E+02, 0.10729600E+03, -.80335100E+02, -.13082100E+03, -.17018100E+02, 0.15219000E+03, 0.13625000E+03, 0.12178700E+03, -.60954000E+02, -.68187400E+02, -.60879800E+02, 0.10199800E+02, 0.97945900E+02, 0.40496800E+02, 0.22683400E+01, -.62155200E+02, 0.99977000E+02, -.21137400E+03, 0.17078300E+03, -.85174600E+02, -.20299500E+02, -.85288700E+02, 0.10687900E+02, 0.63498100E+02, -.44201400E+02, 0.90709600E+01, -.69710000E+02, 0.54926600E+02, -.92705900E+02, -.16186300E+03, 0.83395300E+02, 0.12422600E+03, 0.80781200E+02, 0.81449200E+02, 0.12315500E+03, -.37051500E+01, 0.11068100E+01, -.68272600E+02, 0.18945700E+03, 0.13145500E+03, -.92849000E+02, 0.45866800E+02, 0.91992600E+02, 0.48031300E+02, 0.20663700E+02, -.86512800E+02, 0.49733700E+02, 0.28338500E+02, 0.36368500E+02, -.59622800E+02, -.20307600E+02, -.50487700E+02, 0.15679500E+02, 0.17284100E+02, 0.25111700E+02, -.69018300E+01, 0.16650300E+02, -.14387400E+00, -.16994700E+02, 0.38485700E+02, -.14657200E+02, 0.19589200E+02, 0.23394900E+03, -.11758800E+03, -.20474600E+03, -.11717400E+03, 0.12933500E+03, 0.64182300E+02, -.17221400E+03, -.53743800E+02, -.50750800E+02, 0.29675500E+02, -.24506500E+02, 0.51955100E+01, 0.12057300E+02, -.22688900E+02, -.24505900E-01, -.23979100E+02, 0.13033800E+02, -.88112100E+01, -.22985800E+02, 0.69062700E+01, -.92110100E+01, 0.56758800E+01, 0.54321000E+01, 0.41865000E+01, 0.73987600E+01, 0.48400100E+01, -.46663400E+00, 0.29496300E+02, 0.56287000E-01, -.33357300E+02, 0.28626400E+02, -.11607900E+02, 0.11063700E+02, -.16361900E+02, -.75684900E+00, 0.12610200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14894800E+02, -.14706500E+01, -.13052600E+00, 0.78471100E+00, -.21093300E+00, 0.21641500E+01, -.24108500E+01, -.35112500E+00, 0.32146800E+00, -.32584600E+01, 0.56126900E+00, -.38466300E+01, -.36759600E+01, 0.22090900E+01, 0.10807700E+01, -.31184600E+01, -.45520900E+01, 0.12472800E+01, 0.19241400E+01, -.76902000E+00, -.21683600E+00, 0.77489100E+00, -.42430500E+00, -.53068800E+01, -.49673800E+00, -.77504000E+00, 0.15745100E+00, 0.19194900E+01, 0.10505900E+01, -.65794400E+00, 0.33937300E-01, -.67725100E+00, -.99398800E+00, 0.14648500E+01, -.88940700E+00, 0.13269400E+01, -.25738000E+00, 0.73288100E+00, 0.24024600E+01, -.75261700E+00, 0.19466400E+01, 0.20923300E+00, -.89864800E+01, 0.89188800E+00, -.15311200E+01, -.59401800E+00, 0.15748900E+00, 0.23214300E+01, -.91758900E+00, -.63937900E-01, 0.12042900E+01, -.50632800E+00, 0.11720200E+01, 0.19059700E+01, -.21862900E+01, -.20986000E+01, -.60852200E+00, 0.47348400E+00, -.36330200E-02, -.15443200E+00, 0.21022800E+01, 0.13475200E+01, 0.10322500E-03, 0.12121400E+01, 0.12995200E+01, 0.49793000E+00, 0.70238100E+00, -.82462200E+00, 0.11753200E+00, -.10719500E-01, -.45463500E-01, -.72836000E+00, 0.44196900E+01, -.12430000E+00, 0.31764700E-01, 0.12997900E+00, 0.73672200E-01, -.92098800E+00, -.25545500E+00, -.11173900E+01, 0.49004100E-01, 0.13249100E+01, -.42799700E+00, -.49154100E+00, 0.34090100E+00, -.13177500E+00, 0.12733800E+01, 0.88901000E+00, -.34402300E+00, 0.79722600E+00, -.53594500E+01, -.33091500E-01, -.21071900E+00, 0.14227000E+00, 0.21702700E+01, -.11804800E+00, -.19608500E+01, 0.46257600E-01, -.22568000E+00, 0.10314400E+01, -.25512100E+01, -.17814900E+01, -.71977800E-01, 0.43148400E-01, -.36422800E+00, -.13101300E+01, -.77165500E+00, 0.35922700E+00, 0.25529300E+01, -.12087400E+01, 0.20302200E+01, -.45834600E+00, -.10908400E+01, 0.68352700E-01, -.67874000E+00, 0.19373400E+00, -.82814500E+00, 0.11754800E+01, 0.51058300E+01, -.23682800E+01, 0.13868700E+00, -.82784800E+00, -.24265200E+00, 0.58385400E+00, -.47285500E-01, -.90324900E+00, 0.21704700E+01, -.54658100E+00, 0.37351300E+00, 0.33287500E+00, 0.24304100E+00, -.25506700E+00, -.77828200E+00, 0.93128100E+00, -.52730400E+00, 0.31949600E+00, -.33554300E+01, -.12547400E+01, -.24554400E+01, 0.59081700E+00, -.11989300E+01, 0.13530300E+00, -.10461200E+01, -.37869900E+01, 0.12284300E+01, 0.14005600E+01, -.37319200E+00, -.23665700E+00, 0.45700000E-01, 0.62076700E+01, -.19684400E+01, 0.43764800E+00, 0.10555900E+01, 0.24963000E+00, 0.60277600E+00, -.54085900E-02, -.27252100E+00, 0.93413300E-01, 0.77681800E+00, 0.23489300E+00, 0.40175700E+01, 0.13116600E-01, -.14752700E+01, -.12554500E+01, -.14037900E+00, 0.39931600E+00, -.45649600E+00, 0.34803100E+00, 0.11977600E+01, -.87104400E+00, 0.68567300E+00, -.81011900E+00, -.30956900E+00, -.56904300E-02, -.30166800E+00, -.18280200E+01, -.16578700E+01, 0.23855600E+00, 0.10356200E+01, -.20880400E+00, 0.11469100E+01, 0.34144400E+01, 0.83882700E+00, 0.29598100E+01, 0.62869600E+00, 0.16774800E+01, -.20215200E+03, 0.75637800E+02, -.36933800E+02, 0.25914400E+01, -.36950300E+02, 0.13844800E+02, -.99321300E+02, 0.15327200E+03, 0.17227600E+03, -.17137500E+03, -.14343200E+03, -.21916000E+03, 0.77008100E+02, -.34046500E+02, -.75790300E+02, -.38530900E+02, 0.93456200E+02, -.23797300E+03, -.29046400E+03, -.20793700E+03, 0.70491600E+01, -.19400500E+03, 0.17616400E+03, -.34708900E+03, 0.17360300E+03, 0.47790200E+01, 0.17337200E+03, -.32780900E+02, -.15940100E+03, 0.18895400E+02, -.10897600E+03, 0.97789700E+02, -.11570300E+03, 0.49355300E+02, 0.60614100E+02, -.44639600E+02, -.76637400E+02, -.31117600E+02, -.35171600E+03, -.41168500E+03, 0.93090900E+02, 0.28630400E+02, 0.24022700E+03, -.44443000E+03, -.59790600E+03, 0.63468100E+03, -.28795900E+03, -.20033200E+03, -.32044300E+03, -.14951900E+03, -.59217200E+02, 0.13364000E+03, 0.26288500E+03, 0.11189400E+02, -.92137100E+02, -.28043600E+03, 0.10693000E+03, -.28094700E+02, 0.17873300E+02, -.52367800E+02, 0.22079600E+02, 0.16973200E+02, 0.28434900E+02, 0.61866900E+02, -.14004000E+03, 0.66948200E+02, 0.10819900E+01, -.66361100E+03, 0.33034300E+03, 0.55174200E+03, 0.33205600E+03, -.37029700E+03, -.46549400E+02, 0.41161100E+03, 0.73339600E+01, -.69023900E+02, 0.14042100E+03, 0.10660900E+03, -.36060000E+02, -.19072700E+02, 0.57576000E+01, 0.56315500E+01, 0.42743200E+02, -.14925700E+02, 0.46427100E+01, 0.38507900E+02, -.43905900E+02, 0.65173200E+01, -.90459500E+01, -.13063800E+02, 0.22421500E+01, -.44389300E+02, 0.50481600E+01, 0.10471600E+02, -.44345000E+02, -.15685000E+02, 0.59364300E+02, -.74939200E+02, -.10387900E+02, -.51230600E+01, -.36502500E+01, 0.18296500E+02, -.47025100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10610200E+02, -.13125300E+01, -.45670500E+01, -.65682600E+01, -.49824600E+01, 0.44396400E+01, -.26760400E+01, -.37074400E+00, 0.80950600E+00, -.41720200E+01, -.26932400E+01, -.82060300E+00, -.20844900E+01, -.74952900E+01, 0.10587300E+00, -.14453600E+01, -.53177200E+01, -.43004100E+01, -.31780100E+01, -.80572200E+00, 0.57230600E+01, 0.97932700E+00, 0.58320400E-01, -.51102500E+01, -.62703300E+00, 0.37253700E+00, 0.20885800E+01, 0.45412800E+00, -.21176300E+00, 0.35712500E+00, -.24067400E+00, 0.32474800E+00, -.13794400E+01, 0.81775000E+00, -.24777100E+00, 0.51935600E-01, 0.60230200E-01, -.22009300E+00, -.55487800E+00, 0.18388400E+01, -.88374500E+00, -.92887000E-01, 0.38202300E+01, -.14588900E+00, 0.13631200E+01, 0.47479800E+00, -.21826500E+01, 0.13301900E+01, -.52198100E+00, -.51169700E-01, 0.54779200E+00, -.19658200E+01, -.86329300E-01, 0.18862600E+01, 0.49626400E+00, -.27893700E+01, -.53933700E+00, -.98275000E+00, 0.18560300E-02, 0.90728400E+00, 0.15115200E+01, 0.12437300E+01, -.21160200E+00, 0.48163900E+00, -.79844400E+00, 0.12787600E+01, -.33267800E+00, 0.17222900E+01, 0.60498500E+00, -.63755900E-02, -.73387600E+00, -.31893000E+00, -.64529500E+00, 0.10135800E+01, -.95716200E+00, -.66813500E+00, -.21289900E+00, 0.55978400E+00, 0.10425800E+00, 0.34457400E+00, -.34286300E-01, 0.84580900E+00, -.88522300E-01, 0.69384200E-01, 0.79398700E-02, -.22226800E+00, -.15176200E+01, -.13346800E+01, 0.16830300E+01, 0.57566100E-03, 0.63711300E+01, -.22109500E-01, 0.45537600E+00, -.32028300E+00, -.18757300E+01, -.36566100E+00, 0.38310300E+01, -.15941200E+01, -.21418000E-01, 0.87783400E-01, 0.72579000E+00, 0.68128000E+00, 0.64487200E-01, 0.76077800E+00, -.15473800E+00, -.26571100E+00, 0.86265200E+00, 0.16673700E+00, -.51273000E+00, 0.25119500E+01, -.25203200E+00, 0.23260000E+00, -.16544300E+01, -.50515600E-01, 0.71980300E+00, -.79263300E-01, -.41360400E+00, 0.60581500E+00, 0.15006300E+01, 0.45557200E+00, -.10871600E+00, -.27813200E+00, 0.93871600E-01, 0.14939600E+00, -.78459000E-02, -.10330800E+00, -.13443500E+00, 0.53329700E-01, -.11173300E+00, -.50348700E-01, 0.38315000E+00, -.38990900E+00, -.51863100E+00, 0.50002500E+00, -.37902800E+00, -.27290400E-01, 0.65193400E+00, -.10111200E+01, 0.17161400E+01, -.25112100E-01, -.42625500E+00, 0.38394900E+00, -.54184900E+00, -.89490100E+00, 0.38736900E+00, -.92600700E+00, -.24747500E-01, -.10059000E+00, -.16427200E+01, -.70309000E+00, 0.87146000E+00, -.14540900E-01, -.38387400E+00, 0.11074200E+00, -.15033700E+01, 0.20463700E+00, 0.69828900E-01, -.87690700E-01, 0.21887900E+00, -.31034000E+00, -.38202100E+00, 0.32287100E+00, 0.70720500E-01, -.23665700E+01, 0.57691600E-01, 0.96899800E+00, 0.51841100E+00, -.19034300E+00, -.17809300E+01, -.12309500E+01, 0.15561600E+00, 0.78745900E-01, 0.43389100E-01, 0.34573600E+00, -.41570200E+00, -.14372900E+01, 0.23419100E+00, 0.27610400E+00, -.97489400E+00, 0.20979000E+00, -.34891700E+01, 0.46761200E+00, 0.83056800E+00, -.87803800E+00, -.38993300E+00, -.25486200E+00, 0.10941600E+00, -.39612200E+03, 0.19724500E+03, 0.18995100E+03, 0.19673800E+03, 0.13429800E+03, 0.25712400E+03, -.14374800E+03, -.22699900E+03, 0.64368400E+02, 0.30274500E+03, 0.19329700E+03, 0.53471200E+01, -.31192000E+01, -.91698900E+01, -.26192700E+01, -.89204900E+02, 0.95835900E+02, 0.64403800E+02, -.89505200E+01, -.44019400E+02, 0.10488300E+03, -.20460000E+03, 0.15495900E+03, -.75750600E+02, 0.23618200E+02, -.77139200E+02, -.87203900E+00, 0.66829300E+02, -.93229800E+01, 0.43871100E+02, -.98018200E+02, 0.68039600E+02, -.58630300E+02, -.55353400E+02, 0.19170300E+02, 0.82278100E+02, 0.29117700E+02, 0.17337800E+03, 0.30583300E+03, -.64247900E+02, 0.67093800E+02, -.20898700E+03, 0.34238600E+03, 0.15087400E+03, 0.14332300E+03, -.62860800E+02, -.73078100E+01, -.68537000E+02, -.48970300E+02, -.52025300E+02, -.81724700E+02, -.77646800E+02, -.79771200E+02, -.34135600E+02, -.54027400E+02, -.13820900E+03, 0.75431600E+02, 0.51072500E+02, 0.68658100E+02, 0.55698400E+01, 0.60503400E+02, -.37114400E+02, -.71638500E+02, 0.28008400E+02, 0.34241500E+02, 0.43326200E+02, 0.32704200E+03, -.16711900E+03, -.29770400E+03, -.16407500E+03, 0.20529700E+03, 0.97753800E+02, -.21968400E+03, -.86977900E+02, -.65402900E+01, 0.53970200E+02, -.20448100E+03, -.11051100E+02, 0.21976900E+02, -.14021400E+02, 0.13477200E+02, 0.35805000E+02, 0.17185400E+02, -.11462700E+02, 0.37104500E+02, -.18427600E+02, -.18268600E+02, -.10489800E+02, 0.34668500E+01, 0.38002800E+00, -.18081500E+02, 0.15410900E+02, 0.13710600E+02, 0.42746400E+02, -.17161800E+02, -.37153600E+02, 0.54796300E+02, -.25578600E+02, 0.27772500E+02, 0.24025500E+02, -.20397700E+02, 0.27930800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22209700E+02, 0.54444400E+00, -.15191900E+02, -.30736000E+01, 0.74059900E+01, -.37226700E+01, 0.90695800E+00, 0.13394400E+01, -.13538900E+01, 0.25299600E+01, 0.12604400E+01, -.18653400E+01, 0.68691600E+01, -.22102000E+01, -.27881600E+01, -.61877400E+00, -.69883300E+00, -.67035500E+01, -.44765600E+01, -.10499500E+01, -.48638700E+01, -.22830700E+01, -.85106200E+00, 0.18032500E+01, 0.88276600E+00, 0.29781100E+01, 0.68364800E+01, -.10320600E+02, -.11020800E+01, 0.23527800E+01, -.11224200E+01, 0.62995100E+00, 0.11145700E+02, 0.14099200E+01, -.97935900E+00, -.33055100E+00, 0.27987000E-01, 0.16009300E+01, -.19883000E+01, -.75470300E+01, -.10048800E+01, 0.12609600E+00, -.14537600E+02, 0.13180900E+01, 0.82700300E+00, -.40912600E+00, 0.18367000E+01, -.75992300E+00, 0.34495900E+00, -.17898800E-01, 0.50874900E+00, 0.98714200E+00, 0.13233300E+01, -.14559500E+01, -.74654400E+00, 0.21239300E+01, 0.38966900E+00, -.38543000E+00, -.19295100E-02, 0.97537900E+00, -.18315800E+01, -.77864100E+00, 0.36080000E+00, -.15686000E+00, -.38429200E+00, -.16058200E+00, -.39944200E+00, -.97488700E+01, -.25226200E+00, 0.12649200E-01, -.66259800E+00, 0.54939000E+00, 0.18592700E+01, -.77114600E+00, 0.79265600E+00, -.22069200E+01, 0.11781800E+01, 0.84058000E+00, 0.48642400E+00, -.75578000E+00, 0.10756600E-02, -.34235900E+01, 0.11756400E+01, -.15068200E+01, -.70293300E+00, 0.72283300E+00, 0.14403600E+01, 0.17921200E+00, -.34744200E+01, 0.15900300E+01, -.19918100E+01, -.84991900E-01, -.10454900E+01, 0.59251300E+00, 0.13436500E+01, -.80296800E+00, -.26796300E+01, 0.11999000E+01, 0.65970200E+00, 0.22720200E+00, -.14997900E+01, 0.16332400E+01, -.14809900E+00, -.93278200E+00, -.54994300E+00, 0.13704600E+01, 0.90350800E+00, -.13168300E+01, -.64933800E+00, -.25216900E+01, -.10156200E+01, -.12677800E+01, -.12159300E+01, -.12747900E+00, 0.90357700E+00, -.25305700E+00, 0.11033200E+01, -.21619900E-01, -.22167800E+01, -.17499000E+01, 0.20752600E+00, -.60967600E+00, 0.35130300E+00, -.62604700E+00, 0.18620000E+00, 0.38173300E+00, 0.20967000E+01, -.47106900E+00, 0.22244900E+00, 0.27378700E+00, 0.21428500E+01, -.85091400E+00, 0.64757700E+00, -.13049500E+01, -.16527100E-01, -.20665700E+00, 0.69843800E+00, -.15129300E+01, 0.27110300E+01, -.15000400E+01, 0.10460900E+01, 0.74750400E+00, 0.55916700E-02, 0.26770500E+00, -.17953000E+00, -.97712100E+00, -.78151900E-01, -.31799200E+00, 0.12293600E+01, -.12936800E+00, -.81530000E+00, -.29340200E+00, 0.15695300E+00, 0.51964100E-01, 0.50372400E+00, 0.51543700E-01, 0.18838700E+00, 0.28823700E+00, -.21178600E-01, 0.67840000E+00, 0.31579300E+00, -.86630200E-01, 0.39662400E+00, -.19637900E+00, 0.30646900E-04, -.57321100E+00, -.29092600E+00, 0.17781600E+00, 0.11749200E+01, 0.81149600E+00, 0.21668000E+00, 0.79392200E+00, 0.25881000E+00, -.65481500E+00, 0.54588800E+00, 0.33065500E+01, 0.56476500E+00, 0.18804000E-01, -.39643400E-01, -.17831700E+00, 0.32586400E+01, -.16539200E+01, -.67570000E+00, 0.36025300E+00, 0.71156300E-01, -.14291300E+00, 0.14962900E+00, -.26115000E+00, 0.20148600E+02, 0.35941000E+02, -.33230800E+00, -.24790300E+01, -.34347000E+02, 0.21215600E+02, -.13858700E+01, -.31071000E+02, -.35784000E+02, -.72537700E+02, 0.14049000E+03, -.74407600E+02, 0.71933400E+02, -.70229200E+02, 0.11627200E+03, 0.19192600E+02, 0.34953900E+02, 0.95537400E+02, -.10006200E+03, 0.10652600E+02, -.61415900E+02, -.31571300E+02, 0.14543100E+02, -.21160800E+02, 0.15887300E+02, 0.11591700E+01, -.33190000E+02, 0.86185800E+01, 0.14768800E+02, 0.27141700E+02, -.41534400E+02, 0.77537000E+01, -.11610100E+03, 0.76937400E+02, -.56471000E+01, 0.58436700E+02, 0.37621100E+02, -.25317500E+02, -.13205300E+02, -.78535400E+02, 0.57716300E+02, -.37396000E+02, 0.11473500E+03, -.25263900E+03, 0.13029400E+03, 0.19090700E+03, 0.12737300E+03, 0.48189000E+02, 0.46403100E+01, 0.31233100E+02, -.19112000E+02, 0.21078000E+02, 0.20142600E+02, 0.14197300E+03, -.87445900E+01, -.10235300E+02, 0.91466100E+01, 0.42204300E+01, -.15786000E+02, -.35275200E+02, 0.29691100E+02, -.79384800E+01, 0.25078000E+02, -.31400700E+02, -.41440500E+02, 0.11978000E+02, 0.52761000E+00, -.59553500E+02, -.61583600E+01, -.29451800E+02, -.46570000E+02, -.42189700E+02, -.21550400E+02, 0.60848400E+02, -.71427400E+02, -.10213400E+03, -.22046700E+01, -.56253000E+01, 0.15991300E+02, 0.17760400E+01, -.18125000E+02, -.41360100E+01, 0.44315800E+01, -.17911000E+02, 0.20546300E+02, 0.44749100E+00, 0.18181500E+01, -.33724000E+01, -.66365600E-01, 0.20911100E+02, -.12341000E+00, 0.15178800E+01, -.19881800E+02, 0.40797000E+01, 0.80204200E+01, 0.40977500E+01, 0.67409700E+01, -.14315400E+00, -.29701700E+01, -.36213300E+01, 0.10173600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.26365800E+01, -.20301600E+00, -.41162200E+00, -.18302400E+01, -.47803800E+00, 0.18401700E+01, -.15401200E+01, -.19739300E-01, 0.30068300E+00, -.16335900E+01, -.11524000E-01, 0.19388000E-01, 0.84679800E+00, 0.90661300E+00, -.13348200E+00, -.86096600E+00, 0.15440000E+00, 0.83910500E+00, -.63757000E+00, 0.65627700E+00, -.87403400E-01, 0.93824100E-01, 0.52553600E-02, 0.30370100E+00, 0.18516500E-01, -.79600600E-01, 0.64993000E-01, -.93008200E+00, -.26361700E-01, -.33146900E-01, -.59775500E-01, 0.23819900E+00, 0.82594100E+00, 0.71268600E-03, -.16302700E-01, 0.31048900E+00, -.23131600E-01, 0.12489700E+00, 0.25534000E-01, -.23627100E-01, 0.93464700E-01, 0.32577700E+00, 0.90916700E+00, 0.45015800E-02, -.21736500E+00, 0.90853000E-01, -.27040900E-01, 0.59722300E+00, -.70943500E+00, -.30571800E-01, -.48485900E+00, 0.29785500E+00, 0.18998900E+00, 0.11182300E+01, 0.25374600E+00, -.57200900E+00, -.63555000E-01, -.19458900E+00, 0.28721600E-02, -.73291300E+00, 0.34753600E+00, 0.15023900E+00, 0.36555700E-01, -.78936200E-01, 0.14490900E+00, 0.28956500E+00, -.39170300E-01, 0.42777500E+00, 0.87577100E-01, -.28265700E-02, 0.25729100E+00, -.21872500E+00, 0.23226600E+00, 0.17680100E+00, 0.11293000E+00, 0.15028500E-01, -.12666400E+00, -.13181600E+00, -.15139800E+00, -.12622200E+00, 0.14946200E-01, -.44660000E-02, 0.18544800E+00, 0.30222800E+00, 0.11587800E+00, -.78774100E-01, -.15196700E+00, -.37528100E-01, -.39901600E+00, 0.19986000E+00, -.70175800E+00, 0.16322700E-01, -.32953500E-01, 0.57262800E-01, -.96359600E-01, 0.11895600E+00, 0.38795500E+00, 0.20492600E+00, -.17249000E+00, 0.17063100E+00, 0.23965500E-01, -.96763300E-02, 0.12668500E-01, 0.99538700E-02, -.63002700E-01, 0.77863000E-01, -.10430700E+00, -.87738200E-01, 0.33404100E+00, -.36726700E+00, 0.16949600E+00, 0.15492200E-01, -.17795700E+00, 0.24665700E-01, -.23262900E-01, 0.27743200E-01, -.91050300E-01, -.96695700E-01, 0.37669700E+00, -.33442100E+00, 0.31236300E-01, 0.19305900E+00, 0.61103600E-02, 0.62541500E-01, -.13391200E-01, -.58945300E-01, 0.39371300E+00, -.66749000E-01, -.27492500E-01, -.97959600E-01, 0.69220300E-01, 0.28850400E+00, 0.12922700E+00, 0.14996700E+00, -.16986400E-01, 0.40667000E-02, 0.33251600E-01, -.35667200E-01, 0.18432500E+00, 0.10462200E+00, -.25271600E+00, -.11708700E+00, -.10183700E+00, 0.26150000E+00, 0.12241100E-01, 0.45636100E+00, -.24997200E-01, 0.17509600E-01, -.74087900E-01, 0.47474400E+00, -.24338900E+00, -.52532400E-01, -.97725500E-02, 0.18578300E-01, 0.54369000E+00, 0.20692400E-01, 0.76513900E-02, 0.78254400E-01, 0.35931800E-01, -.43987100E+00, 0.28957900E+00, -.88221800E-01, 0.11132800E+00, 0.16884700E+00, 0.77945700E-01, -.91182900E-01, -.10602400E+00, -.17646600E-01, -.16919900E+00, -.16690800E+00, -.13630700E-02, -.66521500E-01, -.13499400E+00, 0.45168700E+00, -.81996900E-01, -.99733600E+00, -.95807100E-01, 0.18379200E+00, 0.15766700E+00, 0.35449700E-01, -.83740700E+00, 0.10350500E+01, 0.77914100E-01, 0.19633300E+00, 0.11014600E+00, 0.36359000E+00, -.13613500E+00, -.26359200E+00, 0.48212400E-01, -.27724700E+02, -.33459900E-01, -.12397100E+02, 0.99624500E+00, 0.30296700E+01, 0.37422100E+02, 0.45465300E+02, -.88580100E+01, -.44950900E+01, -.13676800E+03, 0.67972600E+02, -.29113300E+02, 0.68385800E+02, -.21864500E+02, 0.61316700E+01, -.20929900E+02, -.24855600E+02, 0.66576000E+02, -.22139400E+01, 0.47749700E+02, -.22201800E+02, 0.11343600E+02, 0.77249300E+00, 0.11109700E+02, 0.59748600E+01, 0.24333300E+01, 0.44473300E+01, -.65183300E+01, 0.41743900E+01, 0.61984400E+01, -.68615700E+01, 0.10129800E+02, -.11564000E+02, 0.56528600E+02, -.50111500E+01, -.24165200E+02, -.22788700E+02, 0.22929800E+02, 0.10104700E+02, 0.54593700E+01, -.28998500E+02, -.80310800E+02, 0.11434300E+03, -.51754300E+02, -.11367900E+03, -.57304400E+02, 0.96890900E+00, 0.55609300E+02, -.53134300E+02, -.21766900E+02, -.35225000E+02, 0.49429400E+02, -.42045500E+02, -.35900800E+02, 0.30879700E+02, -.36844900E+01, 0.18059400E+02, 0.17507900E+02, 0.26880200E+02, -.19308000E+02, -.94851700E+01, -.12295800E+02, 0.31334800E+02, 0.41732200E+02, -.24598300E+02, 0.11287700E+02, 0.74223200E+02, 0.12282500E+02, -.54384700E+02, -.17375500E+02, 0.45466800E+02, -.26396900E+01, -.25372000E+01, 0.27173800E+02, 0.10370300E+02, -.40350200E+01, -.47566100E+00, 0.57353900E+01, 0.15819600E+01, 0.73144900E+01, -.25225800E+01, 0.12770400E+01, 0.73881500E+01, -.70529400E+00, 0.19075600E+01, -.75042700E+01, -.65192400E+00, 0.26330500E+00, -.10167200E+01, -.97775600E+00, 0.23166100E+01, -.45247100E+00, -.72896600E+01, 0.81497900E+01, -.47915800E+01, 0.20779600E+01, 0.29524500E+00, 0.33209300E+01, -.55976900E+01, -.49428200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22127700E+02, 0.22440700E+01, 0.15432800E+01, -.60786100E+01, -.12620500E+02, -.22520100E+01, 0.58487800E+01, -.35468300E+00, -.50789900E+00, 0.43203500E+01, 0.40787300E+01, -.16156000E+01, -.22991400E+01, 0.15631800E+00, 0.28150500E+00, 0.50931700E+01, 0.26071800E+01, 0.19325000E+01, -.21002300E+01, 0.34407200E+01, 0.19624600E+01, -.50145300E+00, 0.25772300E+01, 0.45567800E+01, 0.54485800E+00, 0.22287200E+01, -.58536300E+00, 0.32033800E+01, 0.17248100E+01, -.22037500E+00, -.20239000E+00, 0.30224000E+01, -.30666600E+01, 0.39847200E+01, -.87662400E+00, -.68635200E+00, 0.16601200E+00, -.16756800E+00, 0.12196100E-02, -.21565500E+01, -.20712100E+00, 0.18040500E+01, -.44482500E+01, -.42200100E+00, 0.90945800E+00, -.35104300E+00, 0.23301900E+01, -.39218600E+01, -.25825200E+00, 0.43221300E+00, -.34239000E+01, 0.19275100E+01, 0.50761900E+00, -.63401700E+00, 0.21529600E+01, 0.32575000E+01, 0.88206000E+00, -.58147700E+00, 0.14294800E-03, -.99154600E-01, -.38428800E+01, -.17648000E+01, 0.79604800E+00, 0.10334800E+00, 0.18260100E+01, -.55676400E+00, 0.34843300E+00, -.29792700E+01, -.25757500E+00, 0.54781000E-02, 0.65541200E+00, 0.47754900E+00, -.35475700E+00, -.14601700E+01, 0.28430700E+01, -.84374900E+00, 0.68773100E+00, 0.12759700E+01, -.28494500E+00, 0.13566100E+01, -.51250800E-02, -.60135500E+00, -.11668900E+00, -.57196200E+00, -.53460400E+00, -.10471600E+00, 0.24321400E+01, -.59782800E+00, -.32545500E+00, 0.17001700E+01, 0.51420900E+00, -.92759600E-01, 0.15111600E-01, 0.20880800E+00, 0.39268800E+00, -.11849500E+01, -.19971700E+01, 0.34442000E-01, 0.91244900E+00, 0.23426100E+00, -.25311600E+01, -.53403600E+00, -.13376600E+00, -.34283200E+00, -.50889000E+00, -.10521000E+01, 0.23855700E+00, 0.58422500E-02, 0.88785500E+00, -.28149400E+01, 0.72785300E+00, -.19129900E+00, 0.61925800E+00, 0.49450300E-01, -.65932100E+00, -.13805300E-01, 0.10939300E+00, -.66934500E+00, -.12590600E+01, -.15805100E-01, -.20684100E+00, 0.10109800E+00, -.12068400E+00, -.87954000E-01, 0.41322800E-01, -.12701700E+00, 0.16838500E+01, -.35954200E+00, 0.23443800E+00, 0.31356300E+00, 0.20404400E+01, -.13723700E+01, -.42809000E+00, -.17222700E+01, -.15366700E+00, 0.18589400E-01, 0.66907700E+00, -.15037300E+01, 0.25856200E+01, -.14263600E+01, 0.46976800E+00, 0.46802800E+00, 0.43931400E+00, -.16138000E+01, 0.15230200E+00, -.24252300E+00, 0.25397300E-01, -.50119000E-01, 0.16359500E+01, 0.66661600E+00, -.16382300E+01, -.92406400E-02, 0.81192700E+00, -.11806700E+00, -.69848000E+00, 0.51246800E-01, -.20760900E+00, -.19070100E+00, 0.28647100E+00, 0.43413600E+00, 0.11123800E+01, -.47943700E-01, -.14193000E+00, -.59063600E+00, 0.46682900E-01, -.73820100E+00, -.45550500E-01, 0.36889600E+00, 0.14576500E+01, 0.97514200E+00, 0.18184900E+00, 0.94359400E+00, 0.29013100E+00, -.10336600E+01, 0.49181300E+00, 0.33143200E+01, 0.58291500E+00, -.42838000E+00, -.59276200E-01, 0.24011900E+00, 0.32008700E+01, -.19728200E+01, -.92904900E+00, 0.39448900E+00, 0.10718100E+00, -.16241500E+00, 0.13194500E+00, -.20639300E+00, 0.77861000E-01, -.67665900E+00, 0.60689400E+01, -.11875000E+02, -.33036500E+02, 0.18607000E+02, 0.23964400E+02, 0.11462000E+02, -.45254600E+02, -.46424500E+02, -.44589700E+02, 0.21972800E+02, 0.53792700E+02, 0.22228400E+02, 0.66906600E+02, 0.19380100E+02, 0.11858900E+02, 0.34856600E+02, -.17027000E+02, 0.11896600E+02, 0.28597900E+02, -.28551000E+02, 0.14745700E+02, -.21520000E+02, 0.13898000E+02, -.61869500E+00, -.28995100E+02, 0.19683500E+01, -.93987500E+01, 0.15074900E+02, -.27717200E+02, 0.46198400E+01, -.87120000E+02, 0.49784800E+02, 0.11756600E+02, 0.41528300E+02, -.41198500E+00, -.66459800E+02, 0.60022000E+00, -.75751000E+02, 0.74021500E+02, -.83895200E+02, 0.94260800E+01, -.67552600E+02, 0.37877200E+02, 0.94653500E+02, 0.32103300E+02, 0.45038900E+02, 0.80484400E+02, -.23686900E+02, -.13469500E+02, -.35894700E+02, 0.88648400E+02, 0.47549500E+02, -.31161100E+01, -.43887200E+01, -.10230800E+02, 0.15847400E+01, -.36075600E+01, -.21387600E+02, 0.15133800E+02, -.31521300E+01, 0.59761800E+01, -.11127400E+02, 0.84375300E+01, -.34023600E+02, 0.17331200E+02, 0.21228900E+02, 0.17533800E+02, -.69471700E+02, -.61603700E+02, 0.22710800E+02, -.41356900E+01, 0.53973600E+02, -.46088000E+02, -.45543400E+02, -.57582300E+01, -.72299500E+01, 0.15957800E+02, 0.29003500E+01, -.66960400E+01, -.58308800E+01, 0.46153100E+01, -.72906900E+01, 0.19930000E+02, 0.27506700E+01, -.29329900E+01, -.39562000E+01, 0.11495000E+01, 0.20206200E+02, -.15894300E+01, 0.30664500E+01, -.16890100E+02, 0.71868000E+00, 0.15539700E+02, 0.26439300E+01, 0.51596900E+01, -.23818400E+01, -.53013500E+01, -.49857300E+01, 0.47501700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45032900E+01, 0.39155000E+00, -.89802400E+00, 0.18973100E+01, -.13679200E+01, -.26904300E+01, 0.26668000E+01, -.72947400E-01, -.37081900E+00, 0.18490800E+01, 0.65902600E+00, -.96022000E+00, -.15935300E+01, 0.15401500E+00, -.25649000E+00, 0.16686200E+01, -.17296000E+00, -.83438900E+00, 0.68306400E-01, -.38641800E+00, -.14212300E+00, -.24996100E+00, 0.50837600E+00, 0.91352300E+00, 0.21109000E+00, 0.87726500E-02, 0.25180000E+01, 0.12242200E+01, -.12648100E+01, 0.36257200E+00, 0.15452600E+00, -.41611300E+00, -.76610200E+00, -.24977900E+00, 0.45253900E-01, 0.63610500E+00, 0.39127700E-01, -.23590000E+00, -.12752600E+00, 0.26480500E+00, -.25832200E+00, 0.32727300E+00, -.39854600E+01, 0.21095300E-02, 0.90197800E+00, -.48855300E-01, 0.33964200E-01, -.44548600E+00, 0.85766400E+00, 0.15430900E+00, -.39056500E+00, -.32887300E-01, 0.25777000E+00, 0.12018300E+00, 0.48359200E-01, 0.78711600E+00, 0.18499100E+00, -.10322800E+00, -.88414600E-02, 0.67550300E+00, -.87747500E+00, -.25216600E+00, 0.31134000E-02, 0.23156900E+00, 0.67676500E+00, -.56598900E+00, 0.14805100E+00, -.21871200E+01, -.33081400E-01, 0.11646600E-01, -.46005100E+00, 0.53764000E-01, -.13395000E+01, -.48346900E+00, 0.37669700E+00, 0.63974900E-01, 0.81533000E-01, 0.13191700E+00, 0.12388800E+00, 0.35815900E+00, -.30257000E-01, -.44039300E+00, -.80653400E-01, -.70866300E-02, -.65837400E-01, 0.10907300E+00, -.21502200E+00, -.23866900E+00, -.64452200E+00, 0.11372300E+00, 0.77205300E+00, 0.12551200E-01, 0.26174100E+00, 0.47369700E-01, -.54820400E+00, -.51950000E-01, -.93096900E+00, 0.35361700E+00, -.50176200E-01, -.79261100E-01, -.43573100E+00, 0.28872200E+00, -.35480300E-01, -.28291300E+00, 0.12961200E+00, 0.35412100E-01, -.41946400E+00, -.25338900E+00, -.29981500E+00, 0.98897500E+00, 0.19370400E+00, 0.69464700E-01, -.15141100E+00, -.28225900E-01, 0.14151300E+00, -.52340100E-01, -.55681800E-01, -.14278500E+00, -.25472900E+00, 0.27581500E+00, -.17689900E+00, -.15420800E+00, 0.41250700E-01, 0.28293400E+00, 0.90092900E-02, -.10834300E-01, 0.20142600E+00, -.39357500E-01, 0.21749800E-01, -.56893900E-02, 0.43005000E+00, -.80470500E+00, 0.27835200E+00, 0.30003700E+00, 0.30742700E-01, -.17630800E-01, 0.23859400E+00, -.42341800E+00, 0.24200100E+00, 0.19774800E-01, 0.22314000E+00, 0.93387500E-01, 0.23236600E+00, -.55567600E+00, 0.24898200E+00, -.52314500E+00, -.55808600E-04, 0.90000500E-02, -.57635200E+00, 0.57937600E+00, 0.30235800E+00, -.29422300E-01, -.13088000E+00, 0.40513700E-01, -.38750800E+00, 0.27179500E-01, 0.32571000E-01, -.79463100E-01, -.82030000E-01, 0.15013200E+00, -.20194900E+00, 0.25558500E-01, 0.10320300E+00, -.53878700E+00, -.30493000E+00, 0.35031300E+00, 0.96685400E-01, -.33432300E-01, -.28973800E+00, -.19914000E-01, -.28790800E-01, -.17687600E+00, 0.45640500E-01, 0.97832100E-01, -.51603200E-01, 0.44417600E+00, -.16385700E+00, -.49391200E-02, 0.22621400E+00, 0.74999600E-02, 0.44106100E+00, -.21278100E+00, -.82321200E-01, -.15089300E+00, -.22937400E+00, -.35850200E+00, -.12352400E-02, 0.18988800E+00, 0.49141300E-02, -.24353200E+00, 0.40482300E-01, -.25490300E+02, -.30052400E+01, 0.12984900E+02, 0.12141900E+01, 0.35132700E+01, 0.62514700E+01, 0.13484900E+02, -.62300300E+02, 0.30608800E+02, -.12469600E+02, 0.31144500E+02, -.28801100E+01, 0.10623500E+01, 0.54814000E+01, -.23212700E+02, 0.44354600E+02, 0.79547500E+01, 0.42541300E+02, -.54445700E+01, 0.21387300E+01, -.12611200E+01, 0.26879900E+01, -.14146600E+02, 0.87947000E+00, 0.18268300E+01, 0.86069400E+00, 0.11192400E+02, -.21281000E+01, 0.30240700E+02, 0.33032400E+02, -.15634100E+02, -.17076900E+00, -.16715600E+02, -.50664300E+01, -.34493800E+02, -.84126000E+01, -.67626300E+01, -.36550800E+01, -.32366400E+02, -.38315600E+02, 0.22286000E+02, -.11521200E+02, 0.87037500E+01, -.11380200E+02, 0.11178200E+02, 0.11116000E+02, -.29166100E+01, 0.56015500E+01, -.17477400E+02, 0.77778400E+01, -.22080000E+02, -.86552800E+01, 0.45605000E+01, 0.10839600E+02, 0.43234900E+01, -.33362000E+01, 0.65940700E+01, 0.52812300E+01, -.22955000E+01, -.68066800E+01, 0.53592300E+01, 0.17264900E+02, -.82516900E+01, 0.50162700E+01, 0.26666200E+02, 0.41828400E+01, -.12427600E+02, 0.13985700E+02, 0.10812400E+02, 0.13040200E+02, -.37012000E+02, 0.19224300E+02, 0.12628300E+02, -.56904400E+00, 0.48270400E+00, -.47246500E+01, 0.14180900E+00, -.94260900E+01, 0.21837000E+01, -.21419000E+01, -.10382300E+02, 0.81751500E+01, -.38757800E+00, 0.17923300E+01, 0.40167600E+00, 0.12673100E+01, 0.80863700E+01, -.28714000E+00, 0.25496800E+00, 0.24343800E+01, 0.29986200E+01, -.22129400E+01, -.70289800E+01, 0.16185100E+01, -.21802300E+01, -.11058500E+02, 0.21675500E+01, -.44596400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30007400E+01, 0.34119300E+00, -.29535800E+00, 0.14503600E+01, -.55046300E+00, -.16585300E+01, 0.15167000E+01, -.85076500E-01, -.19383100E+00, 0.35655900E+00, 0.32313200E+00, -.64547300E+00, -.11559900E+01, 0.34217200E+00, -.17752500E+00, 0.79475100E+00, -.49841000E+00, -.53417900E+00, 0.32545500E+00, 0.61509800E-01, 0.22432500E+00, -.82440000E-01, 0.31005700E+00, 0.16674800E+00, 0.10861700E+00, -.40299100E-01, 0.52244200E+00, 0.18864900E+01, -.72506100E+00, -.16589700E+00, 0.22501900E+00, -.45017200E+00, -.35530900E+00, -.29570200E-01, -.13205200E-01, -.29668600E+00, 0.12142400E-01, -.34654100E-01, -.37882600E+00, 0.47888900E+00, 0.59684000E-01, 0.56392400E+00, -.14305200E+01, -.12559200E-01, -.12340800E+00, -.82478400E-01, -.20529400E+00, 0.13221900E+00, -.62683500E+00, 0.37207000E-01, -.63543500E+00, 0.69975700E+00, 0.14155400E+00, 0.53247200E+00, 0.69902300E+00, 0.12680900E+00, 0.99631200E-01, -.18420500E+00, -.37068000E-02, -.63765900E+00, -.13631800E+01, -.58683300E+00, 0.27206900E-01, -.12919800E+00, 0.64450100E+00, 0.24092000E+00, -.10947500E+00, -.12283800E+01, 0.26086000E+00, 0.55916400E-02, 0.17081900E-02, -.46597500E-01, 0.15353800E+00, -.58114000E+00, 0.43498900E+00, 0.21747900E+00, 0.56525200E-01, -.54531100E+00, 0.15490200E+00, 0.28405400E+00, -.25212200E-01, -.14526800E+00, 0.68714100E+00, -.20399900E+00, 0.49480700E-01, 0.14715500E-01, -.42567100E+00, 0.17170000E+00, -.34151500E+00, -.16328800E+00, -.91021800E+00, 0.26722900E-01, -.12706800E+00, -.76321100E-03, 0.53125500E+00, -.13747300E+00, -.60715000E+00, 0.66064100E-01, -.17190000E+00, 0.19466500E+00, -.47429700E+00, -.31494300E+00, 0.81451600E-02, 0.13137700E+00, -.11983100E+00, -.17886400E+00, 0.13141500E+00, -.62901000E-01, -.44134900E+00, -.52866100E+00, 0.21804500E-01, 0.17318600E+00, 0.24622500E+00, 0.45763200E-01, 0.31645200E-01, -.37465500E-01, -.49236800E+00, -.15458400E-01, -.19353000E+00, 0.19145700E+00, -.81282400E-01, 0.19363700E+00, -.18605300E-01, 0.56536900E-01, -.12759600E-01, -.36445900E+00, 0.34130100E+00, -.19414100E+00, 0.90940200E-01, 0.57406700E-01, -.51533600E+00, 0.31226500E+00, -.94211900E-01, -.90092300E+00, -.35026600E-01, 0.86810900E-02, 0.11094900E-01, -.41465600E-02, 0.72003700E-01, -.56780000E-01, -.13721400E+00, 0.11467700E+00, -.14271000E+00, 0.13008500E-01, -.26563700E-01, -.12897900E+00, -.16561600E-01, -.22834900E-01, 0.87766700E-01, -.43255400E+00, 0.33341900E-01, 0.19318200E-01, -.59395400E-02, 0.59965000E-01, -.36663500E+00, 0.26730900E-01, -.14990100E-01, 0.16544300E-01, 0.17811200E-01, -.28323100E-01, -.28557400E+00, 0.19699500E-01, 0.54464700E-01, -.15045600E+00, 0.16682900E+00, -.49870200E-02, 0.45546500E-01, 0.34697500E-01, 0.46928000E+00, -.80337200E-01, 0.50346500E-01, 0.22318900E+00, 0.19488200E-01, -.47981300E+00, -.25836300E+00, 0.31366600E+00, 0.12538600E+00, -.12592800E+00, -.21672700E+00, 0.52311600E-01, 0.15441600E+00, -.99276100E+00, -.18349600E+00, 0.79524900E-01, -.14749100E+00, 0.42544300E+00, 0.11680100E+00, 0.29562600E-01, 0.40045800E-01, -.53711600E+00, -.14838400E-01, -.19407100E+00, -.28322100E+02, 0.57990200E+01, 0.16770500E+02, 0.20478700E+02, -.35927500E+02, -.13045100E+02, -.11940100E+03, 0.58772600E+02, 0.31019800E+02, 0.59696400E+02, -.79852800E+01, -.37377800E+02, -.30364500E+02, -.22056600E+02, 0.48113500E+02, -.38043600E+02, 0.13951500E+03, -.56434100E+02, 0.28128900E+02, -.34532700E+01, 0.28189900E+02, -.10297600E+01, -.24950600E+02, -.19471400E+01, -.27513700E+02, 0.10897400E+02, -.15355100E+02, 0.53497100E+02, 0.29528400E+02, -.15054100E+02, -.68023500E+02, -.14831600E+02, -.13150800E+02, -.40385800E+02, -.27478300E+02, -.74164300E+00, 0.37712800E+02, -.52795400E+02, -.58855600E+02, 0.60468300E+02, -.23959100E+02, -.69309100E+02, -.30176600E+02, -.12139400E+02, 0.56814000E+02, -.57039500E+02, -.21464300E+02, -.42170900E+02, 0.47884700E+02, -.79543600E+01, 0.17939800E+02, -.78642700E+01, 0.98267100E+01, -.91643400E+01, 0.32496600E+01, -.27599200E+00, 0.26638500E+01, -.94836000E+01, -.34037200E+02, 0.10994300E+02, 0.54031400E+01, -.10619900E+03, 0.54208300E+02, 0.10592900E+03, 0.53156700E+02, -.33665600E+02, -.48213700E+02, 0.87766000E+02, 0.76145300E+01, 0.29098100E+02, -.14281500E+02, 0.11151100E+02, -.23248900E+01, -.39531000E+01, 0.72829900E+01, 0.16375200E+01, 0.14842300E+02, -.44995200E+01, 0.16224000E+01, 0.14277600E+02, -.13079500E+01, 0.23534100E+01, -.24694800E+01, -.88714400E+00, -.12688200E+01, -.11232200E+01, -.10389100E+01, 0.15322300E+01, -.83826300E+01, 0.19694800E+00, 0.10745400E+02, -.71697600E+01, -.26883500E+00, -.14484600E+01, 0.11879500E+02, -.21629600E+00, -.17784200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.55756300E+01, 0.49085800E+00, 0.41281200E+00, -.80097100E+00, 0.54179200E+00, 0.33557400E+00, -.43538600E-03, 0.29746300E+00, 0.16779300E+00, 0.72558200E+00, -.11100500E+00, 0.84457900E+00, 0.55424600E+00, 0.15686400E+01, 0.37660200E+00, 0.45809300E+00, 0.34747600E+01, 0.21546900E+01, -.59556900E+00, 0.17615400E+01, -.12012500E+01, -.62314600E-02, 0.60592000E+00, 0.24728000E+01, 0.95135300E-01, -.68651300E+00, -.17131500E+01, -.64869100E+00, 0.67138400E+00, -.72370700E+00, 0.69441500E-01, 0.41120000E+00, 0.12946000E+01, -.40936900E+00, 0.31934200E+00, 0.72573900E+00, -.24356900E-01, 0.56118600E-01, 0.61300200E+00, 0.39997500E+00, 0.36167800E+00, 0.47730300E-01, 0.24017300E+01, -.14402600E+00, -.65309800E+00, 0.12991100E+00, 0.38627400E+00, 0.15296700E+00, 0.69523600E+00, 0.19845700E+00, 0.54892900E+00, -.41870200E+00, 0.88443700E-01, -.13179800E+00, 0.52828500E+00, -.13445000E+01, -.45212000E-01, 0.80000300E+00, 0.10182900E-02, -.24093000E+01, 0.70394000E+00, -.73901300E+00, 0.19270000E+00, -.60239100E+00, 0.86363600E+00, -.76566100E+00, -.25548800E+00, -.15049700E+01, 0.17448700E+00, 0.10651000E-02, 0.63144300E+00, -.20289600E+00, -.51887700E+00, -.85421100E+00, -.14381700E+00, 0.11406000E+01, -.29316300E+00, -.10259000E+01, 0.26179100E+00, -.28843300E+00, 0.28072400E-01, 0.11641000E+01, 0.42616000E+00, 0.22695200E+00, 0.48417200E+00, 0.32879400E-01, -.90623300E+00, 0.35588300E+00, 0.99060700E+00, -.11969200E+01, -.95792700E+00, 0.24333600E-01, -.12186400E+00, -.16676200E+00, 0.59145700E-01, 0.15709300E+00, -.20049700E+01, 0.87491000E+00, -.28843100E+00, 0.36686300E+00, -.35304500E+00, 0.10752400E-01, -.15172900E-01, -.10335800E+00, 0.10576200E+00, 0.11523100E+00, -.10479400E+01, -.42957400E+00, -.65088700E-01, 0.10935400E+01, 0.17495400E+00, -.21354100E+00, 0.16650100E-01, -.20282300E-01, -.14251900E+00, 0.17245900E-01, 0.31522000E+00, -.65434900E+00, 0.13959100E+01, -.17690700E+00, 0.10381700E+00, 0.31295200E+00, 0.52808100E-01, 0.65634000E+00, 0.25151800E-01, -.21761200E+00, -.12533000E-01, -.17452900E+00, 0.10712600E+00, -.37148500E+00, -.55004100E-01, 0.11346100E+00, 0.23212300E+00, 0.62348600E+00, 0.11767800E-01, 0.17731000E-01, 0.99484200E-01, -.22686500E-01, -.11057900E+00, 0.59776900E-01, -.69283700E-01, -.19842200E+00, 0.13892700E+00, -.31292600E+00, 0.17508600E+00, -.10135100E+00, -.76152900E-01, -.27334600E-01, 0.16886900E+00, 0.11939900E+01, -.74243900E+00, 0.49214200E-01, 0.16549600E+00, 0.12063400E+00, 0.33092600E-01, 0.15068400E-01, -.10025000E+00, 0.22947000E-01, 0.21686700E+00, -.20188600E+00, 0.10027200E+01, -.35087400E-01, -.39178900E+00, -.38075400E+00, -.39055800E+00, -.21652700E+00, -.80158900E-01, 0.10105700E+00, 0.36140500E+00, 0.25846200E+00, 0.13866600E+00, 0.47951200E-01, 0.91633300E-01, 0.10173300E-01, 0.56382100E+00, 0.16150000E+01, 0.22177200E+00, -.41218900E-01, 0.21743800E+00, -.15495500E+00, 0.19065000E+01, 0.77139500E+00, -.69233800E-01, -.16492600E-02, -.12638100E+00, -.11482800E+00, 0.10954900E+00, -.22950400E+00, -.55296100E-01, -.13807700E+01, -.11741500E+00, 0.43130300E+00, -.93692900E+00, -.33546200E+02, 0.17115100E+02, 0.38562900E+02, -.14891100E+02, -.20157300E+02, -.44040800E+02, 0.21975700E+02, -.18682300E+02, 0.22032600E+02, -.95303000E+02, -.25749800E+02, -.67310900E+02, -.60586100E+02, 0.10694700E+01, -.41760000E+02, 0.94145700E+02, -.36692600E+02, 0.18450500E+02, 0.20221900E+01, 0.18411300E+02, -.60272200E+01, -.59529300E+01, -.68394600E+01, -.31097000E+02, -.95297600E+01, 0.33596900E+01, 0.48691700E+02, 0.31750600E+02, -.19464300E+02, 0.85168900E+02, -.15073200E+02, 0.11519100E+02, 0.23755200E+02, -.14675500E+02, -.10909300E+02, -.10352200E+02, 0.25571200E+01, -.26292200E+02, 0.12238600E+03, -.55476300E+02, -.14849900E+03, -.61030000E+02, -.35563300E+02, 0.73819000E+02, -.38376100E+02, -.38405100E+02, -.59898100E+02, 0.58707500E+02, -.41330600E+02, -.37843800E+02, 0.34370300E+02, -.61224600E+01, 0.18841500E+02, 0.41448100E+01, 0.22118700E+02, -.35566200E+02, -.21149200E+02, -.25969300E+02, 0.37030500E+02, 0.31581800E+02, -.11120000E+03, 0.54641900E+02, 0.97142800E+02, 0.55504500E+02, -.61355400E+02, -.52387100E+02, 0.73497100E+02, -.41415400E+02, 0.54552500E+02, 0.32660100E+02, 0.42802700E+02, -.56922900E+01, -.10770700E+01, 0.12714400E+02, 0.52734200E+01, 0.27155200E+02, -.44846600E+01, 0.46742300E+01, 0.27762800E+02, -.19836800E+02, 0.28463900E+01, -.79816200E+01, -.10866800E+01, -.99373200E+00, -.20040200E+02, -.18304500E+00, 0.54512100E+01, -.71395300E+01, -.97492400E+01, 0.11181300E+02, 0.31687500E+01, -.17533400E+01, 0.18597700E+01, 0.19203500E+02, -.91132700E+01, -.10780600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10681500E+02, -.10017000E+01, 0.19586800E+01, -.30023600E+01, -.40966900E+01, 0.33858700E+01, -.41002300E+00, 0.48634900E-01, 0.21792300E+01, -.83006800E+00, 0.10115200E+01, -.61921200E+00, 0.16332900E+00, 0.66655500E+01, 0.98958700E-03, -.47781000E+00, 0.10442900E+01, 0.46326200E+01, -.24495700E+01, 0.71479500E+00, 0.61197000E-02, 0.46260800E+00, -.48641900E+00, -.71690700E+00, -.22491900E+00, -.73792000E+00, -.23659500E+01, 0.34637500E+01, 0.14916600E+01, -.17396500E+01, 0.40515000E+00, 0.49066400E-01, -.26618900E+01, 0.26073000E+00, -.71507900E-01, -.63440500E+00, 0.12942000E-01, -.17264800E+00, 0.35065200E+00, -.32471500E+01, -.67631700E+00, 0.62849000E-02, -.23332100E+01, 0.38044300E+00, -.16878900E+01, 0.18108100E+00, -.62911500E+00, 0.30761000E+01, -.12033100E+01, 0.19665500E-01, 0.35771500E+01, -.14358700E+01, -.91761200E+00, -.14273700E+01, 0.99330000E-01, -.35525500E+01, -.13834100E+00, 0.12703000E+01, -.43772400E-03, -.10622000E+01, 0.42140800E+01, 0.91554300E+00, -.58616300E+00, 0.25310400E+01, 0.21310700E+01, -.10883300E+01, 0.40883200E+00, 0.14402600E+01, 0.93033300E-01, -.16875800E-01, 0.57886400E-01, -.64377500E+00, -.15313400E+01, -.11783800E+01, -.88602800E+00, 0.31025100E+01, -.56748000E+00, -.20954000E+01, -.18844300E+00, 0.12423400E+00, 0.76302300E-01, 0.23531200E+01, -.76305200E+00, 0.34063800E+00, 0.92888700E+00, -.30595700E+00, 0.54189800E+00, 0.82667300E+00, 0.14448600E+01, -.32266100E+00, -.21166200E+01, -.16266000E-01, 0.48360100E-01, 0.66559000E-01, 0.61285900E+00, 0.87683200E-02, -.39098600E+00, -.18136700E+00, -.12732800E+00, 0.80815600E+00, 0.77281200E-01, 0.64667100E+00, 0.80579900E-01, 0.58544200E+00, -.52375600E+00, 0.19712300E+00, 0.11266100E+01, 0.25206400E-01, -.12155100E+00, 0.16986300E+01, -.55372700E+00, -.54422300E-01, -.57475000E+00, -.18298200E-01, 0.51384500E+00, -.15683800E+00, -.72864800E+00, 0.35943600E+00, 0.17354300E+01, -.27010100E+00, -.34883800E+00, -.32253400E+00, 0.18805200E-01, 0.72353000E+00, 0.63603100E-01, -.97009400E+00, -.32239400E+00, -.92811300E-01, 0.67063700E-01, -.21377000E+00, 0.35496800E+00, -.39460400E+00, -.58434200E+00, -.19021200E-01, 0.32204700E-01, 0.61085400E-01, 0.76631900E+00, -.78017800E+00, 0.18635800E+00, 0.41281300E+00, -.36879500E-01, -.84752700E-01, 0.99313000E-01, -.34532800E+00, 0.66895100E+00, -.23612400E+01, -.84479900E-01, -.34566400E-01, -.45187300E+00, 0.18787800E+01, -.21970000E+00, 0.14169500E+00, 0.23119200E+00, -.18915200E+00, -.57293200E-01, 0.14713700E+00, -.12776100E+00, -.17853100E-01, 0.59750700E-01, -.64463200E+00, 0.16527400E+01, 0.18265000E-01, -.73614800E+00, -.32901700E+00, 0.77275200E+00, -.32968700E+00, 0.22194400E+00, -.36197300E+00, -.24804100E+01, 0.10615200E+01, 0.77958000E-01, -.43372100E+00, 0.99811900E-01, -.94537900E-01, 0.37526400E+00, -.17008800E+00, 0.25731100E+00, 0.29924500E-01, 0.14668600E+00, -.15724900E+00, 0.53965400E+00, 0.73747500E+00, -.26539600E+00, 0.27773200E+00, 0.35257700E+00, 0.73450000E+00, -.34005900E+00, -.65473600E+00, -.47165600E-01, 0.78428400E-01, -.89678500E-01, 0.59214000E+00, -.11373500E+00, -.10522500E+01, 0.13070700E+03, 0.63223500E+02, -.49157200E+02, -.10790400E+03, -.18038000E+03, 0.93491600E+02, 0.38332000E+02, 0.90205500E+02, -.20814400E+02, -.72412400E+02, -.12866700E+03, 0.11361100E+02, 0.38766800E+02, -.82864400E+02, 0.70801500E+02, -.15202100E+03, 0.79727700E+02, -.21406900E+02, 0.76074400E+02, -.12925100E+02, -.86379300E+02, -.99928900E+01, -.84230000E+02, -.48486700E+01, -.50261400E+02, -.19415900E+02, -.35933500E+02, -.28077200E+01, 0.13265500E+03, 0.19479800E+02, -.32759500E+02, -.10669800E+03, -.53826000E+02, -.95139000E+02, 0.78205600E+02, -.16795700E+03, -.12435800E+03, 0.32574600E+03, -.14646800E+03, -.12900100E+03, -.16397800E+03, -.66451900E+02, 0.23340400E+03, -.11745400E+03, -.37766100E+02, -.17405100E+03, 0.22215700E+03, -.45541400E+02, -.35079500E+02, 0.62624500E+02, -.68268200E+01, 0.17748000E+02, -.19614100E+02, 0.37885500E+02, -.57619600E+02, -.36336300E+02, -.75197300E+02, 0.91939400E+02, 0.95248300E+02, -.31673800E+03, 0.14996700E+03, 0.24506700E+03, 0.15829300E+03, -.28547300E+03, -.11815700E+03, 0.23200100E+03, -.71454800E+02, 0.15122100E+03, 0.72527000E+02, 0.29304600E+02, -.31549900E+02, -.13699100E+02, 0.52024600E+02, 0.14951200E+02, 0.72451600E+02, -.26522200E+02, 0.19123200E+02, 0.71731900E+02, -.52242800E+02, 0.59283200E+01, -.29265400E+02, -.10192600E+02, 0.46468600E+01, -.52796800E+02, -.34482500E+01, 0.18127900E+02, -.41364300E+02, -.26848900E+02, 0.51241700E+02, -.16195800E+02, -.16037700E+01, 0.13547600E+02, 0.44737800E+02, -.30646700E+02, -.70148500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42755600E+00, -.14644800E-01, -.53748100E+00, -.64402900E-01, -.91756200E+00, -.49737000E+00, 0.88824300E+00, 0.13720600E-01, -.78969500E-03, -.13460900E+00, -.47954100E-01, -.19500900E+00, -.18866300E+00, 0.19849400E+00, 0.33397300E-01, 0.32682400E+00, 0.55287200E-01, 0.91573200E-02, -.21092300E+00, -.15068100E+00, 0.37874300E+00, -.24927600E-01, -.90414900E-01, -.59762200E+00, 0.27860300E-01, 0.11675200E+00, 0.67811700E+00, -.10326200E+01, -.20346000E+00, 0.21165700E+00, -.50200100E-01, -.41455600E-01, 0.78383800E+00, -.10252600E+00, 0.21154200E-01, -.10741100E+00, 0.75774800E-02, -.36139000E-02, -.18992900E+00, -.14286700E+00, -.11468800E+00, 0.15877600E+00, 0.23485000E+00, -.49064800E-01, -.31148300E-01, -.48376000E-01, -.39639200E-01, -.67413700E-01, -.10310800E+00, -.11747900E-01, -.42836200E-02, 0.18145100E+00, 0.16735100E-01, -.69369300E+00, 0.21294700E-01, 0.50081800E-01, 0.54039600E-02, 0.43710200E-01, -.46706300E-03, 0.38060400E-01, -.27827900E-01, 0.47647900E-02, -.37979100E-01, -.13225200E+00, -.81501200E-01, 0.21547100E-02, -.41116400E-01, -.26476300E+00, 0.60961400E-01, 0.68131700E-03, -.96946900E-01, -.29444600E-01, -.14514000E+00, 0.13162800E+00, -.18776700E+00, -.23259000E+00, 0.41088800E-01, -.54389000E-01, 0.35992800E-02, 0.22163700E-01, -.29724700E-02, -.15955700E+00, 0.96861900E-01, 0.44817800E-01, -.17351500E-01, -.57195900E-02, -.90899400E-01, -.95019300E-01, -.45800500E-01, -.59594400E-01, 0.12964900E+00, 0.82444200E-02, 0.12180500E+00, -.38802100E-01, -.41439100E-01, 0.23362600E-01, -.80016600E-01, 0.13089000E+00, -.59834300E-01, -.63742700E-01, -.26119300E-02, -.13125700E-01, -.26739700E-02, -.69702600E-01, 0.95644500E-01, -.43124300E-01, -.26639800E+00, 0.15377200E-01, 0.15311300E+00, -.36276800E-01, 0.14122900E+00, -.93087200E-02, -.83315900E-02, 0.66948600E-02, -.22173600E-01, 0.27519700E-01, 0.28417400E-01, -.12105100E-01, 0.16662000E+00, 0.62906400E-01, -.22321500E-01, 0.20636400E-01, 0.23403700E-02, 0.93412600E-01, -.19823200E-01, 0.57951000E-01, -.10224900E+00, 0.23701400E-01, -.19271200E-01, -.33569500E-02, -.21893400E+00, 0.26416100E+00, 0.24555400E-01, 0.22432200E+00, -.20566500E-03, -.25824500E-02, 0.10356800E+00, -.42434700E-01, 0.15076100E+00, -.32112900E-01, 0.10218900E-01, -.71648100E-02, -.45164700E-01, 0.19358100E-01, -.99496000E-02, 0.53097100E-01, 0.14473400E-01, -.17177800E-02, 0.39058400E-01, -.50697600E-01, 0.97165900E-01, -.16597100E-01, -.23645100E-01, -.87131100E-02, 0.17824500E+00, -.12109800E-01, -.34394700E-02, -.12802700E-01, 0.16926500E-02, 0.13498200E+00, 0.14759700E+00, -.12661700E-01, -.16612000E+00, 0.21767600E-01, -.67399500E-01, 0.17536900E+00, 0.23658400E-01, 0.74299300E-02, -.14427200E-02, -.60252100E-01, -.14128700E-02, -.40379100E-01, 0.77887100E-02, 0.39520400E-01, 0.26408000E-01, -.36896300E-02, -.49591400E-01, 0.16491500E-01, 0.14313800E+00, -.14986100E-01, 0.29477400E+00, 0.35382300E+00, 0.11358200E+00, 0.30308200E-01, 0.41372000E-01, 0.83076100E-01, 0.33820500E-01, -.42843700E-01, -.54050600E-02, 0.51559800E-02, -.41483100E-03, -.20109100E+00, -.26078500E+00, 0.13123900E+00, 0.29527100E-01, 0.11238300E+02, 0.11007800E+01, 0.12514200E+02, -.86541200E+01, 0.37258200E+01, 0.11787500E+02, 0.43222600E+01, -.73430100E+01, -.47632500E+01, 0.40278600E+01, -.35259000E+01, 0.78586900E+01, 0.48910400E+00, 0.15046100E+02, -.24015900E+01, 0.89573900E+00, 0.44482200E+01, 0.11728300E+01, 0.37677200E+01, 0.50807500E+01, -.30551700E+01, 0.10396900E+01, 0.31687500E+01, 0.80649900E+01, 0.12270800E+02, 0.35274200E+01, -.12380700E+01, -.33909900E+01, -.19949600E+01, 0.79079600E+01, 0.34697800E+01, 0.14151300E+01, 0.10761600E+02, 0.57954200E+01, 0.37401600E+01, -.13740100E+02, 0.51511000E+00, -.30932600E+00, -.29552800E+01, -.31617900E+00, 0.54513900E+00, -.22606700E+01, -.86396700E+01, -.11386600E+02, -.58564000E+01, -.36326500E+01, -.68482700E+01, -.81946800E+01, 0.27282700E+01, 0.76852100E+01, 0.40576800E+01, 0.32757500E+01, 0.45685700E+01, -.36619300E+00, -.42754100E+01, -.37525700E+01, 0.38625400E+01, 0.98900100E+01, 0.10134800E+01, 0.29393700E+00, -.35213600E+01, -.45851400E+00, 0.94713300E+01, 0.89211600E+01, -.38439100E+01, 0.52142000E+01, -.21665900E+00, 0.28336500E+00, 0.10488700E+02, 0.52479900E+00, 0.12181100E+01, -.13642600E+01, -.13414500E+00, 0.89971600E+00, 0.58584000E+00, -.82487200E+00, 0.92146400E+00, 0.10017200E+01, -.35887100E+00, -.56944400E+00, 0.10636400E+01, -.11771500E+01, 0.10669700E+01, 0.11539500E+00, -.17678400E+00, 0.17992400E+01, -.48053500E+00, -.21827400E+01, 0.62200700E+00, -.12231200E+00, -.93799800E+00, 0.11595000E+01, -.24011000E+00, 0.12338500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19137600E+01, -.16939700E+00, 0.37501700E+00, 0.27552800E+00, 0.90095000E+00, 0.88116300E+00, -.11932000E+01, 0.81982300E-02, 0.43041800E-01, 0.14419700E-01, 0.12820800E+00, 0.18228800E+00, 0.24252200E+00, 0.91030300E+00, 0.45576500E+00, -.10538200E+01, -.50669400E+00, 0.50801400E+00, 0.60997500E+00, -.49935400E-01, -.14542900E+01, -.41233700E-02, -.13932200E+00, 0.13076300E-01, 0.17523800E-01, 0.16031300E+00, -.42458200E-01, 0.93681500E-04, -.37131200E-01, 0.13769200E+00, -.53744600E-02, 0.24726800E+00, 0.32950400E-01, -.82721300E-01, -.62066100E-02, -.15837400E+00, 0.30206300E-02, -.44025000E-01, 0.16455400E+00, -.97238200E+00, -.58272300E-01, -.19702400E+00, -.87507900E+00, 0.12285800E+00, -.32340500E+00, -.91653700E-01, 0.14640100E-01, 0.15773000E+00, -.22648200E+00, -.74923900E-01, 0.31122600E-01, 0.27313800E+00, -.12045300E+00, -.23810300E+00, 0.15898400E+00, -.13468000E+00, -.10451200E+00, 0.18048500E+00, -.83577800E-03, 0.35439300E-01, 0.32220700E+00, 0.24368300E+00, 0.23523400E-01, 0.16238300E+00, 0.12669600E+00, 0.48868300E+00, 0.68980500E-01, 0.12381500E+01, -.29401000E-01, 0.22077300E-02, 0.10954700E+00, -.94393700E-01, -.22123900E-01, 0.74073100E-01, 0.52700100E-01, -.33871000E+00, 0.11700700E+00, 0.25430300E+00, -.89016300E-01, -.51009900E-01, 0.27130000E-02, -.35583400E+00, 0.13644000E+00, 0.45147000E-01, 0.71446900E-02, -.20724200E-01, 0.72185800E+00, -.47403300E-01, 0.29307500E-01, -.10334400E-01, -.43577100E-01, -.39924500E-02, 0.56353900E-01, -.24066700E-01, -.45632200E-01, -.25586700E-01, 0.44805300E-01, -.38739900E-01, 0.29365400E-01, -.35881800E-01, 0.42855500E-01, 0.10307000E-01, -.82694100E-03, 0.27627800E-01, -.22333000E-01, 0.44303500E-03, -.26871100E-02, -.84964800E-02, 0.35244500E-01, 0.14895400E+00, -.17155800E-02, 0.44392900E-02, 0.29137600E-01, -.60929700E-02, -.34511700E-01, 0.84008900E-02, -.48640600E-01, -.48826300E-02, 0.11784200E+00, -.13600700E-01, 0.28521600E-01, 0.32601400E-01, 0.32217500E-02, 0.26415800E-01, 0.21911300E-02, -.83927000E-01, 0.40446700E-02, -.97584500E-03, 0.11405700E-01, -.30442400E-02, 0.18620200E-01, 0.38602500E-02, -.84042800E-01, -.11922600E+00, -.19486300E-01, -.15276700E-01, 0.13883100E-01, -.14572300E-01, 0.25326500E+00, -.65078100E-01, 0.80615000E-02, 0.20520600E+00, 0.37103600E-01, -.77236300E+00, 0.18439600E-01, -.14778700E-01, -.20886400E-01, -.46585900E-01, -.16244700E+00, -.11137700E+00, -.84258100E-01, 0.43055500E-01, 0.69670800E-01, -.16363100E-01, -.33761200E+00, -.63145700E-02, -.39828100E-01, -.45676900E-01, 0.22025600E-01, 0.23732300E+00, -.17988600E+00, 0.64650700E-01, -.40730100E-01, 0.41345600E+00, -.33725900E+00, 0.76515800E-01, 0.13758200E+00, 0.51683000E-01, 0.21610800E+00, 0.66550400E-01, -.60133400E-01, 0.20394800E+00, 0.10170500E+00, 0.13574200E+00, 0.19956200E+00, 0.22469800E+00, -.46614300E-01, 0.39427300E-01, 0.16833600E+00, -.75413800E-02, 0.28908900E+00, 0.36447700E+00, 0.40142300E+00, -.85592600E-01, -.20320200E+00, -.60808100E-01, 0.62456100E-01, 0.12637000E+00, -.16151800E-01, -.50043800E+00, -.28428900E-01, 0.20739300E+00, -.15263200E+00, 0.38695700E+00, -.69000900E-01, -.46747800E-01, -.72257600E+01, 0.23335200E+02, -.11956000E+02, 0.58739500E+01, 0.19645500E+02, 0.59788200E+01, 0.25805000E+01, -.49824400E+01, 0.44218300E+01, 0.72627500E+01, 0.16890600E+02, -.38970100E+01, 0.51409300E+01, -.44803300E+01, 0.21944000E+01, -.26023300E+01, 0.22432400E+01, 0.19547500E+01, 0.74917000E+00, 0.13420000E+01, 0.37673700E+01, 0.92025700E+01, -.12579500E+01, 0.16455200E+02, 0.30282100E+02, -.16368200E+02, 0.89219000E+01, -.15093700E+02, -.26760700E+02, 0.79157400E+01, -.49316700E+01, 0.94660700E+01, 0.46709500E+01, 0.11718800E+01, -.44553600E+02, 0.37961300E+02, -.23588400E+02, -.14872100E+02, -.19325900E+02, -.55285200E+01, -.31360100E+02, -.61157600E+01, 0.25165300E+01, 0.44666100E+01, -.32586100E+02, -.26585200E+02, -.21768100E+01, 0.22573400E+01, -.49270900E+01, 0.12939500E+01, 0.34494500E+01, 0.15417500E+01, 0.11840400E+01, 0.22061600E+01, -.65297900E+01, 0.92415400E+00, 0.14565000E+02, 0.65434200E+02, -.32727800E+02, -.31543600E+02, -.32726800E+02, 0.47481900E+01, 0.13571600E+02, -.19277800E+02, 0.89370500E+01, -.26248500E+02, -.84014800E+00, -.93850200E+01, -.74115700E+00, 0.10213000E+01, -.30880100E+00, -.87165200E+00, -.42457500E+01, 0.61767500E+00, -.63949700E+00, -.43957800E+01, -.72343000E+00, -.78817900E+00, 0.58131500E+00, 0.22490200E+00, 0.41780000E-01, -.68149200E+00, -.11563000E+00, -.29839000E+00, 0.11487100E+01, 0.38920600E+00, -.11739900E+01, -.10404800E+01, 0.18436900E+01, -.39139600E+01, -.42458500E+01, 0.19483000E+01, 0.10124800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.68855800E+01, -.90958000E+00, -.22383700E+01, -.63815500E+01, -.50776800E+01, 0.39042600E+01, -.13167300E+01, -.17688100E+00, 0.91273400E+00, -.26626800E+01, -.14077100E+01, -.12267400E+01, -.95881400E+00, -.25063900E+01, -.65538800E+00, -.14157200E+01, -.37327500E+01, -.16136800E+01, -.34574000E+01, 0.56340800E+00, 0.30764400E+01, 0.24488600E+00, 0.91005000E-01, -.31535000E+01, -.46943500E+00, -.39290500E+00, 0.19586400E+01, -.33078000E+01, 0.27003600E+01, 0.78177800E+00, -.84207000E+00, 0.26406900E+00, 0.97298200E+00, -.30092000E+00, 0.17756300E+00, -.18934600E+00, 0.76406600E-01, -.22285200E+00, -.17258000E+00, -.67153700E+00, -.61729400E+00, -.12848600E+00, 0.13700400E+01, 0.10159500E+00, -.39834600E+00, 0.23045400E+00, -.98251700E+00, 0.10714400E+01, -.49872800E+00, 0.12692000E+00, 0.79277800E+00, 0.34569900E-01, 0.26800500E-01, 0.10351500E+01, 0.98530700E+00, -.14368200E+01, -.83854700E-01, 0.68099000E+00, -.54492900E-02, -.25000900E+01, 0.18187600E+01, 0.52211900E+00, -.32924100E+00, 0.24873900E+00, 0.59437800E+00, -.54866500E+00, 0.17471300E+00, 0.13852300E+01, -.37194000E-01, 0.37530300E-02, 0.23669700E+00, -.27933500E+00, -.23670300E+01, -.29742700E-01, -.70548500E+00, 0.10586600E+01, -.22449500E+00, -.79560100E+00, -.19116300E+00, 0.59038600E+00, -.73693700E-02, 0.16563700E+01, -.18602900E+00, 0.75458600E+00, 0.58465100E+00, -.36588800E+00, -.51038900E+00, -.43104200E+00, 0.61431200E+00, -.90152200E-01, 0.36993100E+01, 0.32155200E-01, 0.88521700E+00, 0.13090100E+00, -.80367600E+00, 0.23876200E-01, 0.70869500E+00, -.25913700E+00, -.21965600E+00, 0.82620000E-01, 0.17673200E+00, -.30060700E+00, 0.64004700E-01, -.18180100E+00, 0.36496900E+00, 0.79813200E+00, -.11844300E+01, -.17375900E+00, -.30139400E+00, -.10269700E+01, 0.60944300E+00, 0.12546500E+00, -.56454600E-02, 0.30518000E-01, -.32048400E-01, -.85199800E-01, 0.90797100E-01, -.71664300E+00, -.11026200E+01, -.27503700E+00, -.13031900E+00, -.17414700E-01, -.69254900E-01, -.49302800E-02, 0.25920300E-01, -.81750300E+00, 0.50901500E+00, -.21473500E+00, -.83731100E-01, 0.18385800E+00, -.10951700E+01, 0.11394200E+01, -.19358700E+00, -.14569600E+00, -.15316100E+00, -.26928700E-01, 0.45888700E+00, -.74628700E+00, 0.13571200E+01, -.64708400E+00, 0.43004100E+00, -.19037000E+00, 0.43720500E+00, 0.11602700E+01, -.13535400E+00, -.28297600E+00, 0.77222000E-01, -.94070000E-01, 0.11206800E+01, -.22695000E-01, -.31766800E+00, -.13930800E+00, -.77374500E-01, -.13420500E+00, 0.90589900E+00, -.10186100E+00, 0.11093900E+00, 0.48552100E-01, -.37110500E-01, 0.23236200E+00, 0.12106300E-01, -.72453800E-01, 0.47910100E+00, -.24063500E+00, -.65671700E-01, 0.10734800E+00, -.15927400E+00, -.24555100E-02, -.10760200E+00, 0.40308100E-01, -.15441500E-01, -.34254900E+00, 0.23136500E+00, -.65041800E+00, -.41333500E+00, 0.10756400E+01, -.47262100E+00, -.31622900E+00, -.90943100E-01, -.27745500E-01, 0.14986800E+01, 0.99619200E-01, 0.20011800E+00, -.13148700E+00, 0.16779200E+00, 0.11097400E+01, 0.41524900E+00, -.56201200E-01, -.81718500E-01, -.21092200E+01, -.10408500E+00, 0.11669600E+01, 0.66404300E+00, -.33193300E+00, 0.25046600E+00, 0.29453800E+01, 0.20116900E+01, -.15303300E+03, 0.10001500E+03, -.48639000E+02, -.21250900E+02, -.49973900E+02, -.26947000E+02, 0.47453300E+02, -.58145900E+02, -.33434900E+02, -.11469800E+03, -.10017000E+02, -.11700900E+03, 0.11199300E+03, -.54995300E+02, -.11585800E+02, -.55790700E+02, -.93047300E+01, -.70514900E+00, 0.10568200E+01, -.79308000E+01, -.71009400E+02, -.11325600E+02, -.16803400E+03, -.85752100E+02, 0.40844800E+02, 0.50220600E+01, 0.44214700E+02, 0.63153400E+02, 0.58123400E+02, 0.45956500E+02, -.76360800E+01, -.15167000E+02, 0.86056200E+02, 0.65990600E+02, -.24256400E+03, 0.10872200E+03, -.16123200E+02, 0.12280400E+03, 0.14605000E+01, 0.72759300E+02, 0.49642700E+02, -.41715000E+02, 0.40782000E+02, 0.77601800E+02, 0.19407200E+03, -.39988500E+02, 0.31282000E+02, -.45954800E+02, 0.19805700E+02, 0.81168900E+01, -.77655000E+01, -.14914900E+02, -.10589400E+02, 0.43652700E+02, -.54229700E+01, -.21074800E+02, -.16975400E+03, 0.82465100E+02, 0.36473800E+02, 0.84529800E+02, 0.75517800E+02, -.12088600E+03, 0.57834800E+02, -.42710100E+02, 0.15508600E+03, -.37209400E+02, -.15704800E+03, 0.20529700E+01, -.25303200E+01, 0.96498100E+01, 0.10797200E+01, 0.20613000E+02, -.51864900E+00, 0.72070600E+00, 0.22232500E+02, -.39388700E+02, 0.41077600E+01, -.49852600E+01, -.28564300E+01, 0.18617300E+01, -.40409300E+02, 0.46720500E+01, 0.15482800E+01, -.44928800E+00, -.70948400E+01, 0.10265200E+02, 0.33410400E+02, -.57378700E+01, 0.10669200E+02, 0.28266900E+02, -.92870000E+01, 0.12084600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.82683900E+01, -.87125500E+00, 0.24355100E+01, -.22519500E+01, -.32659300E+01, 0.27490900E+01, -.15581300E+01, -.24856700E+00, 0.54174900E+00, -.15366800E+01, 0.84246900E+00, -.15852100E+01, -.83682800E+00, 0.45022100E+01, -.47787400E+00, -.11119700E+01, -.17626200E+01, 0.23581400E+01, -.42835100E+00, 0.10652600E+01, -.76820600E+00, 0.26121800E+00, 0.47125800E-01, 0.96652800E+00, -.81124000E-01, -.76094200E+00, -.88212600E+00, 0.46060200E+00, 0.98269300E+00, -.11416600E+01, 0.13281900E+00, -.39235800E+00, -.48200200E+00, -.42485600E+00, -.47377500E-01, -.18233200E+01, -.20775700E-02, 0.67844800E-01, -.63644700E+00, -.35815400E+00, -.32195200E+00, 0.14404500E+01, -.37482400E+00, -.22039400E+00, 0.11625700E+01, 0.93240400E-02, -.14147900E+00, 0.20903100E+00, -.12336500E+01, -.74683000E-01, -.10100600E+01, 0.42334700E+00, 0.45757300E+00, 0.78788700E+00, 0.86808400E+00, -.59609400E+00, -.11759100E+00, -.41217800E+00, 0.52705300E-02, -.36711800E+00, 0.13462100E+01, 0.19482900E+00, 0.28273400E+00, 0.71754200E+00, 0.45588200E+00, 0.78568500E+00, 0.20615600E-01, 0.12395300E+01, 0.56410000E-02, -.82728500E-02, -.21191900E+00, -.14858500E+00, 0.81382800E+00, -.84048100E+00, 0.12832800E+01, -.11035200E+01, 0.19672900E+00, 0.83882100E+00, -.43610700E+00, 0.19526400E-01, 0.47385400E-01, -.23314500E+00, -.23110300E+00, 0.36735200E-01, -.31570200E+00, -.48964500E-02, 0.61007900E+00, -.34079500E+00, 0.51789900E+00, 0.29920000E+00, -.96935800E+00, -.45454900E-01, -.75480600E+00, 0.45648800E+00, 0.79129900E+00, 0.46628700E-01, -.55042400E+00, -.99779800E-02, -.24798500E+00, 0.52995700E+00, -.30849700E+00, -.52050300E+00, -.42246900E-01, -.25702800E+00, -.35331800E+00, -.11220200E+00, 0.11383800E+00, -.22526200E+00, 0.97142100E+00, -.24346400E+01, 0.81009900E-01, -.20654700E+00, -.29465300E+00, 0.64416100E-01, -.14058100E+00, 0.13064400E+00, 0.49796000E+00, -.28735000E+00, -.19695700E+00, -.83179400E+00, 0.16729200E+00, -.19454100E+00, 0.11421000E+00, -.30948900E+00, -.83679900E-01, 0.48680500E+00, 0.27443300E-01, 0.16334100E+00, -.15025800E+00, -.12258800E+00, -.23429300E+00, 0.11470100E+01, -.28005200E-01, 0.11210200E+01, 0.12159000E+00, 0.23060100E-01, 0.17165400E+00, -.35375400E+00, 0.12142400E+00, 0.46651400E+00, -.43551700E+00, -.17804000E+00, -.17102300E+00, 0.91082200E+00, 0.14894800E+00, 0.20590500E+01, -.31864400E-01, -.18020500E-01, -.69929100E+00, 0.19821300E+00, 0.25614300E+00, -.22914300E-01, -.52250800E-01, 0.92625500E-01, -.63584200E-01, 0.90720900E-01, 0.47198600E-01, -.26010400E-01, 0.18987100E-01, -.11243200E+00, -.19838100E-01, 0.12563700E-01, 0.52385800E+00, 0.98839800E+00, -.34902300E+00, -.57139700E+00, -.14121200E+00, 0.15233800E-01, 0.39388300E+00, -.32663500E-01, -.13437700E+00, -.60650600E+00, -.14881100E+00, 0.29419700E+00, 0.41551600E+00, 0.16944700E+01, 0.64407700E+00, -.10399800E+00, -.29447700E+00, 0.29811400E-02, 0.12761000E+01, 0.16763500E+00, 0.14451700E+00, -.32578400E+00, 0.20875700E+00, 0.11571200E+00, -.14085600E+00, -.36620700E+00, 0.19152600E-01, -.41041300E+00, 0.42201800E-01, 0.10257200E+00, 0.12109600E+00, -.28251500E+00, 0.25136000E+00, 0.18164500E+01, -.18177900E+01, -.29405100E-01, -.20394700E+03, 0.10360800E+03, -.18547000E+01, 0.10198100E+03, 0.28101700E+02, -.15720600E+02, 0.47116800E+02, 0.24693000E+02, 0.13642800E+03, -.55821600E+02, -.29598800E+02, -.65295700E+01, 0.44329200E+01, -.23578700E+02, 0.33081800E+01, -.71906700E+01, -.40794900E+01, 0.15639500E+02, 0.26278300E+02, 0.34827900E+02, -.27025100E+02, -.35214100E+02, 0.95381600E+02, -.55253900E+02, 0.88234800E+02, -.47477300E+02, -.93993600E+01, 0.70127800E+02, -.57883000E+02, 0.39619300E+00, -.61655900E+02, 0.49069400E+02, -.10019900E+03, 0.13534900E+03, -.69780400E+02, -.13688200E+03, -.68015900E+02, 0.10893200E+01, -.97985300E+01, -.68169600E+02, -.25410300E+02, -.30823600E+02, -.16692200E+02, -.44256600E+02, -.50630000E+02, 0.35774700E+02, -.11431500E+01, 0.25716100E+02, 0.28433800E+01, 0.10284300E+02, 0.50579200E+00, -.32209900E+01, 0.21107600E+02, 0.61728700E+01, 0.37154500E+02, 0.15633400E+03, -.81857800E+02, 0.19741800E+02, -.78258400E+02, -.33894200E+02, 0.13453200E+02, -.40915600E+02, -.23274600E+02, -.11720600E+03, 0.52485500E+02, -.12169400E+03, -.61032500E+01, -.90005500E-01, 0.55946500E+01, 0.11728100E+01, -.72806500E+00, 0.13013400E+01, -.52845800E+00, -.11004400E+01, -.30034600E+01, 0.21218200E+01, -.25230600E+01, -.91963900E+00, 0.23977900E+01, -.36075500E+01, 0.19391700E+01, 0.27180300E+01, -.20090200E+01, -.47759500E+01, 0.33734200E+01, -.19473600E+02, 0.89022000E+01, -.74936400E+00, -.13170400E+01, -.40252700E+01, -.79215400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.88640100E+01, 0.37214600E+00, -.17244100E+01, -.13593000E+01, 0.19922100E+01, 0.93006000E-01, -.26824500E-01, 0.63773400E+00, 0.54451900E-01, 0.16580100E+01, 0.16078700E+00, 0.26018800E+00, -.48085600E+00, 0.38778400E+01, 0.70201400E+00, 0.68565200E+00, 0.35560200E+01, 0.38564600E+01, -.18901800E+00, 0.10965900E+01, -.18699800E+01, -.51016900E-02, 0.27885800E+00, 0.21170300E+01, 0.15671200E-01, -.64083700E+00, -.23747000E+01, -.22619100E+01, 0.14261900E+01, -.10454500E+01, 0.12270400E+00, -.11721100E+00, 0.11807700E+01, -.10427600E+01, 0.44580000E+00, -.13613400E+01, -.54100600E-02, 0.20094600E-02, 0.69017000E+00, -.29241200E+01, 0.50890800E+00, -.10185700E+01, 0.27484300E+00, -.19827500E+00, -.30066700E+01, -.69704000E+00, 0.11040900E+01, -.12109700E+01, 0.15199900E+01, 0.26623000E+00, 0.22258500E+01, -.71181900E+00, -.49948200E+00, -.14164200E+01, 0.11686900E+00, 0.74772300E+00, 0.40314200E+00, 0.11399800E+01, -.16727900E-02, -.87565600E+00, 0.40878400E+00, -.39766200E+00, 0.44516500E-01, 0.93069300E+00, 0.11861900E+01, -.21961100E+01, 0.47115200E+00, -.13751300E+01, -.39581100E+00, 0.68788200E-03, 0.54296100E+00, 0.48193200E-01, -.70958300E+00, -.14726300E+01, 0.83997000E+00, 0.11471500E+01, 0.12727100E+00, -.13149500E+00, 0.23510300E+00, -.11846700E+00, 0.44235000E-01, 0.23985500E+00, -.84603200E-01, -.33721000E+00, 0.27796600E+00, 0.38446400E+00, -.80478600E-01, 0.19414800E+00, -.18044400E+00, -.56771800E+00, -.14511300E+01, -.29544000E-01, -.11570800E+01, 0.18650400E+00, 0.30343800E+00, 0.13593500E+00, -.24465900E+00, 0.46717800E+00, 0.60151400E+00, 0.16600500E+00, 0.59996600E-01, 0.92867100E+00, -.15636600E-01, 0.97031900E-01, -.25287400E+00, 0.17739900E+00, 0.13146300E+01, -.31457900E+00, -.62210300E+00, 0.98767400E-01, -.61173000E+00, 0.73562900E-01, -.73689600E+00, -.45891500E-01, 0.71736800E+00, -.18779900E+00, -.79023400E-01, -.21364800E+00, -.83394000E+00, 0.87302100E-01, -.35201300E+00, -.93182100E-01, 0.10372700E+00, -.25789400E+00, 0.48990800E-01, 0.37010500E+00, 0.30822200E+00, -.62757400E-01, -.92522100E-01, -.43934200E-01, 0.39766000E+00, 0.91924300E-02, 0.49707200E-01, 0.64273200E+00, -.34231900E-01, 0.24852300E-01, -.42575600E+00, 0.13067500E-01, -.63376000E+00, -.17612400E+00, 0.11946900E+00, -.52825200E-01, -.61762600E+00, 0.49564500E+00, -.16450800E+00, -.94365700E+00, 0.52811900E-01, -.65699600E-01, 0.41569100E+00, -.52518800E-01, 0.20040600E+00, -.13380600E+00, -.28730200E+00, -.65482700E-01, 0.60089600E+00, -.25742700E-01, 0.21280900E-01, 0.50771700E-02, -.15280100E-01, 0.22172900E+00, 0.81980200E+00, -.31880200E-01, -.42844400E+00, -.13430600E+01, 0.11945000E+01, -.10013700E+00, 0.20092200E+00, 0.52131100E-01, 0.84378000E+00, 0.12291900E+00, 0.11519800E+00, -.40525200E-01, 0.67875300E-01, -.11995800E+01, -.11008300E-01, 0.85233800E+00, 0.38703600E+00, -.42507400E+00, -.14532600E+00, -.56106600E-01, 0.15067000E+01, -.10821900E+01, -.10131800E+01, 0.28384100E+00, 0.10411900E+00, 0.43875100E+00, 0.99052600E-01, -.34143100E+00, -.13003600E+00, -.11350300E+01, -.83219100E-02, -.21784400E+00, 0.87594200E+00, 0.29227000E+00, 0.15542500E+00, -.22133500E+01, -.23579900E+01, -.41061500E+00, 0.70791800E+00, 0.12547800E+02, 0.10353800E+03, -.76613800E-02, 0.58480200E+02, 0.35777100E+02, -.17795300E+02, 0.18257800E+02, -.56727500E+02, 0.45465800E+02, -.41804200E+02, 0.53188700E+02, -.25428900E+02, -.69535500E+01, -.26634800E+02, 0.17916800E+02, 0.57417000E+01, -.15104300E+02, 0.48328700E+01, -.18013400E+02, 0.14823700E+02, -.46832600E+02, -.10820200E+03, 0.53809000E+02, -.54891200E+02, 0.53480600E+02, -.88529500E+01, -.26916800E+02, 0.52228200E+02, 0.16172600E+02, 0.96061900E+02, -.91491900E+01, -.34004500E+02, -.14439500E+03, 0.62699200E+02, 0.78547900E+02, 0.72195600E+02, 0.92784700E+01, -.39416300E+02, 0.18127700E+02, -.19976200E+02, 0.42904000E+02, -.37157200E+02, 0.85020500E+02, 0.57044100E+01, -.67107200E+01, -.81858800E+01, -.28157100E+01, 0.49334900E+01, -.14060100E+02, 0.10199500E+02, -.66343400E+01, -.28072000E+01, -.10203000E+02, 0.30429400E+02, -.25407300E+02, 0.10664100E+02, -.57248900E+02, 0.12769600E+02, 0.47374100E+02, -.38450400E+02, 0.30494200E+02, 0.41385800E+02, 0.11181300E+03, -.68194900E+02, -.29073100E+02, 0.27263200E+01, 0.62344300E+00, 0.88861500E+01, -.17541300E+01, -.61819800E+01, -.17515400E+01, -.20390600E+01, -.56734700E+01, -.30209600E+01, -.40901700E+00, -.14202400E+01, 0.93746600E+00, 0.11273100E+00, -.26867600E+01, -.11223800E+00, -.90223500E+00, 0.33786900E+00, -.60746700E-01, -.11016100E+01, 0.28338200E+02, 0.90108600E+00, -.18743400E+01, 0.30325200E+01, -.11334800E+01, 0.13738500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.70249300E+01, -.10305500E+01, 0.41313800E+01, 0.25869500E+01, -.80675100E-01, -.31723400E+00, 0.27867600E+00, -.13901500E+00, -.12848600E+00, 0.19490400E+01, -.15038700E-01, -.13804300E+00, 0.20368600E+00, 0.56125800E+01, 0.17920000E+00, -.24195800E+00, 0.16176800E+01, 0.41253000E+01, 0.18551800E+01, 0.80619800E+00, -.33723700E+01, 0.13374700E+00, -.24844200E+00, 0.34593800E+01, -.19298800E+00, -.91219600E+00, -.20687000E+01, -.30447300E+01, 0.18342800E+01, -.10085700E+01, -.50465800E-02, -.80433400E+00, 0.82293900E+00, -.90849000E+00, 0.23952700E+00, -.65323600E-01, -.71167300E-01, 0.22891200E+00, 0.65279400E+00, -.15873600E+00, 0.77147800E+00, -.61511500E+00, 0.13812900E+01, 0.32628800E-01, -.15783300E+01, -.12175400E+00, -.26327400E+00, 0.84427100E+00, 0.14043700E+01, -.10071700E+00, 0.50829900E+00, -.19120400E+00, -.31964500E+00, -.44462100E+00, 0.51525800E+00, -.12275400E+01, -.24001200E+00, 0.14786200E+01, -.38393500E-02, -.29696500E+01, 0.25665500E+01, 0.45662200E+00, 0.32897700E-01, 0.27821800E+00, 0.13629100E+01, -.90325400E+00, 0.40726200E+00, 0.30372400E+01, -.44156600E+00, -.17737400E-03, 0.61668700E+00, 0.28098200E+00, 0.81105100E+00, -.11453000E+01, -.32787500E+00, 0.19660900E+01, 0.43771100E-01, -.83010100E+00, -.26094800E-01, -.82478500E+00, 0.58434300E-01, 0.11273000E+01, -.57348800E+00, -.12903200E+00, 0.21773400E+00, 0.27891900E+00, -.23334400E+00, 0.23082100E+00, 0.11016400E+01, -.92212800E+00, -.11707100E+01, -.40405900E-01, -.11993100E+01, 0.27448700E+00, 0.94555800E+00, -.88674000E-01, 0.73212200E+00, -.26125700E+00, 0.90753100E-01, 0.26160900E-02, 0.63588000E+00, -.60941200E+00, -.14915600E-01, 0.32135600E-02, 0.77211000E-01, 0.19846300E+00, 0.17596600E+00, -.36360500E-01, 0.16277700E+00, -.13988600E+01, -.30231400E+00, 0.55208100E-01, 0.44834000E+00, -.33315200E-02, -.35468500E+00, -.16191600E+00, -.13208100E+00, -.78407300E+00, -.70645600E+00, 0.72040200E+00, 0.38614100E-01, 0.34127500E-02, -.86974600E-01, -.26021800E+00, 0.47708900E-01, -.86161800E-01, -.91473600E-01, 0.19032400E-01, -.59863100E-01, 0.21676400E+00, 0.89587500E+00, -.61943700E+00, -.40806600E+00, -.78296200E+00, -.18251600E+00, -.40788900E-01, 0.13004900E+00, -.39762500E+00, 0.95551800E+00, -.83608800E+00, 0.39280600E+00, 0.25415600E+00, 0.11133200E+00, -.22275100E+00, -.19522500E+00, -.13516900E+01, 0.82522600E-01, -.10563600E+00, 0.14006000E+01, -.12007300E+01, -.62052000E+00, -.45767600E-01, -.77842200E-01, -.47195900E-01, -.76375000E+00, -.37709300E-02, -.91685400E-01, -.99283500E-01, -.56522000E-02, -.86584300E+00, -.10895000E+01, 0.10229200E+00, 0.27438000E+00, -.32867200E+00, -.80812600E-01, -.39605500E+00, -.19805400E+00, 0.27120000E-01, 0.61450600E+00, 0.37839800E+00, -.14941300E-01, 0.28843300E+00, 0.25628600E-01, 0.14206500E+00, 0.30253200E+00, -.63089500E+00, 0.15780200E+00, 0.24445700E+00, -.88481200E-01, 0.26528600E-01, -.48185600E+00, 0.21886800E+01, 0.89440800E+00, 0.12685500E+00, -.26523500E-01, 0.68954800E-03, -.22931800E+00, -.11932700E+00, 0.27295700E-01, -.43285000E+00, -.33620300E-01, 0.14143900E+00, -.11766500E+01, 0.36674600E+00, 0.60336700E-01, -.37782200E+01, -.13852200E+01, -.51869100E+00, 0.39675900E+00, -.19830800E+00, 0.15941800E+03, -.78819700E-03, -.90793200E+02, -.78158900E+02, -.68470100E+02, -.88921500E+02, -.33921400E+02, -.59042400E+02, 0.71349400E+02, 0.51320000E+02, -.27363200E+02, 0.56807000E+02, -.25652900E+02, -.14868700E+02, 0.19167600E+02, -.16915600E+02, -.10304800E+02, -.31052500E+02, 0.35338900E+02, -.15003300E+02, 0.38293300E+02, -.24795100E+02, -.12343600E+03, -.19727800E+02, -.64660300E+02, 0.33684200E+01, 0.75607300E+02, 0.11863100E+03, 0.58656300E+02, 0.35029800E+02, -.49733100E+02, 0.11407700E+02, -.37913300E+01, -.10390600E+03, -.50246400E+01, -.35615800E+02, -.99205500E+02, 0.54805300E+02, 0.23398700E+02, 0.69151800E+02, -.11990500E+03, 0.49230900E+01, -.21643300E+02, 0.20078000E+02, 0.29274000E+01, 0.10825700E+02, 0.29450800E+02, 0.28538100E+02, -.21651700E+02, -.53731100E+01, -.27546600E+02, 0.29981900E+02, -.17065200E+01, -.13953200E+03, 0.72830800E+02, 0.49696400E+01, 0.69749700E+02, 0.94547100E+02, -.57780900E+01, 0.81544100E+02, 0.53187500E+02, 0.91862100E+02, 0.82409100E+01, -.14142600E+02, 0.10362300E+02, 0.92023700E+01, -.82264800E+01, -.40839700E+01, -.65597000E+01, 0.57098500E+01, -.10713400E+02, -.51842300E+01, -.65416000E+01, -.26502900E+01, 0.13770100E+01, 0.50734900E+01, 0.16176500E+00, -.69162400E+01, 0.33276500E+01, -.35253600E+01, 0.14466500E+02, 0.33336400E+00, -.10597400E+02, 0.32906200E+02, -.92174700E+01, -.56661000E+01, 0.17626200E+01, 0.85501800E+01, 0.91965800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.89457100E+01, 0.73918300E+00, 0.17689600E+01, 0.52633900E+00, 0.96010500E+00, -.45008400E+00, 0.66923100E+00, 0.43545700E+00, -.19381400E-01, 0.21818000E+01, 0.10702000E+00, 0.11280100E+01, 0.64472100E+00, 0.36106200E+01, 0.69039900E+00, 0.62625400E+00, 0.39966300E+01, 0.39649800E+01, -.35853400E+00, 0.13297700E+01, -.25114000E+01, -.16570700E+00, 0.28522200E+00, 0.28702000E+01, 0.18862800E+00, -.50186400E+00, -.21035000E+01, -.30647700E+01, 0.11208900E+01, -.92061900E+00, 0.94717100E-01, 0.17496000E+00, 0.19731300E+01, -.10971200E+01, 0.54610300E+00, -.17231400E+01, 0.18773500E-01, -.87713800E-01, 0.41549100E+00, -.33021600E+01, 0.15139900E+00, -.79612200E+00, 0.60279000E+00, -.30777600E+00, -.27257500E+01, -.64309100E+00, 0.93461100E+00, -.10865800E+01, 0.18584700E+01, 0.34173300E+00, 0.23367500E+01, -.82840600E+00, -.25440600E+00, -.13620000E+01, 0.32137200E+00, 0.75355400E+00, 0.55328700E+00, 0.11547200E+01, -.37563600E-02, -.19351000E+01, 0.57587800E+00, -.38127200E+00, 0.12885500E-01, 0.77646000E+00, 0.13939800E+01, -.29549400E+01, 0.44297300E+00, -.18017800E+01, -.40221500E+00, 0.39344800E-02, 0.80314700E+00, 0.14220000E+00, -.74674700E+00, -.14402100E+01, 0.39711100E+00, 0.10749000E+01, 0.24368600E+00, -.51800900E+00, 0.50861200E+00, -.99751600E-01, 0.29716300E-01, 0.28238900E+00, 0.14879500E+00, -.38229100E+00, 0.17687600E+00, 0.40477900E+00, -.77846000E+00, -.11014200E+00, -.39258900E+00, -.58356100E+00, -.27834100E+01, -.66249400E-02, -.98382300E+00, 0.38233400E-01, 0.70811300E+00, 0.47085200E-01, -.13917600E+00, 0.66414000E+00, 0.44482300E+00, -.72926300E-02, -.15350100E+00, 0.43230000E+00, -.25236600E-01, 0.20745100E+00, -.91663200E-01, -.19119400E+00, 0.71177600E+00, -.19985200E-01, 0.14557800E+00, -.18277200E+00, -.32879500E+00, 0.28663100E+00, 0.33190000E+00, -.15819800E-01, 0.17583700E+00, -.21169200E+00, -.48141100E+00, -.72871700E+00, -.30546100E+00, 0.36744500E+00, -.41993100E+00, 0.33086200E+00, -.49280700E-01, -.14321600E+00, 0.38761400E-01, 0.19303400E+00, 0.12169100E+00, -.84569800E-01, 0.12789100E-01, -.99090400E-01, 0.13479000E+01, -.30936000E+00, -.38735600E+00, -.23989300E+00, -.13623900E+00, -.19175900E-01, -.75182200E-01, -.31269900E+00, 0.33558700E+00, -.54386900E+00, 0.62086800E-01, 0.14079000E+00, -.50237800E+00, -.74589400E+00, -.13467000E+00, -.13012400E+01, 0.16911900E-01, -.55457200E-01, 0.69215500E+00, -.65382300E-01, -.45796300E+00, -.15466700E+00, -.15094400E+00, -.21438200E+00, 0.56243000E+00, 0.19793200E-01, -.14081400E+00, 0.66442400E-01, -.14128900E-01, -.14635100E+00, 0.11054600E+01, -.78963400E-01, -.64905400E+00, -.14867000E+01, 0.12028900E+01, -.86111400E-01, 0.76818900E-01, 0.16146800E-01, 0.53862100E+00, 0.40745800E+00, 0.63977800E-01, 0.71737000E-01, 0.47020500E-01, -.10593000E+01, -.62445500E-01, 0.85410700E+00, 0.51633900E+00, -.24599400E+00, -.27852800E-02, -.15142900E+00, 0.23102100E+01, -.51241600E+00, -.84747400E+00, 0.29356600E+00, -.35243800E-01, 0.22930700E+00, -.30375500E-01, -.34166900E+00, 0.52507800E-01, -.11258700E+01, -.57277200E-01, -.34083600E+00, 0.54553300E+00, 0.26894400E+00, 0.16509100E+00, -.15562600E+01, -.19723900E+01, -.46336100E+00, 0.96037300E+00, -.16413700E+00, 0.73007500E+00, 0.32352700E+01, 0.77755700E+02, 0.80018700E+02, 0.59451000E+01, 0.31841600E+02, -.48673600E+02, 0.87078800E+02, -.37842200E+02, 0.25462600E+02, -.12000100E+02, -.35363400E+02, -.12758900E+02, 0.16307700E+02, -.13018900E+02, -.95770900E+01, -.73166500E+01, -.12573700E+02, -.77506400E+01, -.24084400E+02, -.94915700E+02, 0.54668400E+02, 0.40708400E+01, 0.47593200E+02, 0.39078400E+02, -.64551400E+02, -.45846400E+01, -.75631100E+02, 0.58656900E+02, -.68118700E+02, -.52031700E+02, -.14898600E+03, 0.64859100E+02, 0.16754900E+03, 0.73953700E+02, 0.31524700E+02, 0.76210400E+02, 0.83699600E+01, -.53771300E+01, -.16246700E+02, 0.92245900E+02, 0.66646400E+02, 0.31087100E+02, -.25521600E+02, -.19388800E+02, -.15555000E+02, -.18450400E+02, -.33626500E+02, 0.22694000E+02, -.27514900E+00, 0.97995800E+01, -.26690900E+02, 0.47964500E+02, -.78253700E+01, 0.43673400E+01, -.39655000E+02, 0.39704500E+01, -.24727200E+02, -.41857500E+02, 0.31098400E+01, 0.85124600E+01, 0.66466900E+02, -.54328600E+02, 0.36571000E+02, -.38416800E+01, -.74144800E+01, 0.10008200E+02, 0.14753300E+01, 0.26651800E+01, -.64177600E+01, 0.58021300E+01, 0.21064500E+01, -.48716700E+01, 0.20736700E+01, -.19958800E+01, -.25920100E+01, 0.86664100E-01, -.43884400E+01, -.25462600E+01, 0.15325600E+01, -.81862900E+01, 0.15503900E+01, 0.82406900E+01, 0.11282300E+02, 0.35254600E+01, 0.10190400E+01, 0.12957900E+01, -.60530200E+01, 0.59853100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32080800E+02, -.32796100E+01, -.12942100E+00, -.41632200E+01, -.54419900E+01, 0.74548300E+01, -.44436300E+01, -.63453600E+00, 0.20519400E+01, -.57311800E+01, 0.18729800E+01, -.52567300E+01, -.48517500E+01, 0.66395800E+01, -.29880500E+01, -.20602200E+01, -.37869900E+01, -.60178200E-01, 0.16925600E+01, -.18064000E+01, 0.20459700E+01, 0.12354600E+01, -.46082100E+00, -.89656700E+01, -.20121600E+01, -.25490200E+01, -.43242800E+01, -.27833600E+01, 0.24151000E+01, -.42442900E+00, -.52766600E+00, -.51308300E+01, -.63947600E+00, 0.91268300E+01, -.30398700E+01, 0.18143700E+01, -.41662400E+00, 0.35428100E+01, -.20883500E+01, 0.43088200E+01, 0.35880000E+01, 0.15112900E+01, -.16944500E+02, 0.14308900E+01, -.80856200E-01, 0.70182700E-01, -.18615000E+00, 0.36925000E+01, 0.69994100E+00, -.10626800E+00, 0.26953000E+01, -.61766900E+00, 0.15203700E+01, -.21032600E+01, -.28753100E+01, -.25162100E+01, -.17257400E+01, 0.11138400E+01, 0.15312200E-01, 0.17524700E+01, 0.55934400E+01, 0.21686800E+01, 0.74656300E-01, 0.18945400E+01, 0.57063300E+00, 0.30008200E+01, 0.46932100E+00, 0.20500000E+01, 0.80139200E-01, 0.15394100E+00, -.15742000E+01, -.12650700E+01, 0.60604100E+01, -.22319900E+01, 0.36104800E+01, -.75886900E+00, 0.29965800E+00, 0.77578000E+00, -.39843000E+00, -.97113000E+00, 0.22498300E+00, -.60943200E+00, -.49138000E-01, -.20896900E+01, -.82062900E+00, 0.50824600E+00, 0.16275400E+01, 0.19256800E+01, -.28873200E+01, -.66870300E+00, -.10521300E+02, 0.96293200E-01, -.12520100E+01, -.21239800E-01, 0.40820100E+01, -.33891200E-01, -.53284500E+01, 0.17855700E+01, -.14344800E+01, 0.19703000E+01, -.27258400E+01, -.13511300E+01, -.84262400E-01, -.56617800E+00, -.12870000E+01, -.11446800E+01, -.13603300E+01, -.98021200E+00, 0.38524800E+01, -.55771200E+01, 0.28277700E+01, -.79996700E+00, -.20564900E+01, 0.39793900E+00, -.81530300E+00, 0.68008100E+00, 0.62504100E+00, -.53735400E+00, -.48107600E+00, -.38034800E+01, 0.47701800E+00, -.43742900E+00, 0.30254400E+00, 0.31552300E+00, -.42070100E+00, -.12312900E+01, 0.10419100E+01, -.64225000E+00, -.50118000E+00, 0.12842900E+00, -.55872100E+01, 0.49028600E+01, -.43785400E+00, 0.13917700E+00, -.45603700E+00, -.13792500E-01, -.75330500E+00, -.26448700E+00, -.10489800E+00, 0.34452300E+00, -.17680000E+01, -.29240000E+00, -.11904500E+01, 0.52461100E+00, 0.32847700E+00, 0.42507200E+00, 0.11507800E+00, -.42565400E+00, -.34433700E+00, 0.69306100E+01, -.28558700E+00, 0.15920200E+00, -.15821100E+00, 0.25974600E+00, 0.21669600E+01, -.26509800E+00, 0.11434400E+00, -.62346500E+00, -.12508900E+00, 0.19693400E+01, 0.51844900E+01, -.89387800E-01, -.17403400E+01, -.90556000E+00, 0.10148400E+01, -.99714100E-01, -.49900300E+00, -.92210700E-01, 0.63636600E+00, 0.10501600E+00, 0.36365900E+00, -.20880400E+01, -.21172000E+00, -.14054100E+01, -.15891600E+00, 0.30582100E+01, 0.50771200E-01, -.53335100E+00, -.42167400E+00, 0.24606400E+00, 0.89382800E-02, -.77948700E+01, -.32757400E+01, 0.18175200E+01, 0.25293500E+01, 0.24806000E+01, 0.66105000E+00, -.77331300E+00, 0.39430600E+00, 0.34836500E+01, 0.37358500E+00, 0.65819000E+00, 0.59358800E+01, -.31487000E+00, -.65972500E+00, -.92822500E+01, -.30069300E+01, 0.42975900E+00, -.11376100E+00, 0.31667900E+00, 0.28560600E+00, -.72700300E-02, 0.51746300E+03, 0.25368200E+03, 0.19664000E+03, 0.36996100E+03, 0.59234600E+02, 0.24618700E+03, -.33694500E+03, -.50432800E+02, 0.29382300E+02, -.91389700E+02, 0.25127600E+02, 0.14321300E+03, 0.95335500E+00, -.27830100E+02, 0.82716500E+02, 0.14402000E+03, -.13440400E+02, -.21845900E+03, -.73652200E+03, 0.36569200E+03, 0.17124700E+03, 0.36546200E+03, 0.18823100E+03, 0.19206600E+02, -.12449600E+03, -.43474400E+03, 0.30655800E+03, -.41617100E+02, 0.36544300E+03, -.64585400E+03, 0.29543700E+03, 0.61966200E+03, 0.32403800E+03, 0.25289800E+03, 0.61832900E+01, 0.70196200E+02, 0.39254500E+01, 0.10331600E+03, 0.72595400E+02, 0.31344700E+03, 0.69502500E+02, -.48891300E+02, 0.51477600E+02, -.34393200E+02, -.11160000E+03, -.13487600E+03, 0.65369800E+02, 0.16729100E+02, 0.88746300E+02, -.13466800E+03, -.51887000E+02, 0.50095000E+03, -.25736600E+03, -.20539700E+03, -.25041400E+03, -.20088600E+03, -.39796400E+02, -.20202700E+03, 0.98360900E+02, -.38188500E+02, -.30004600E+03, -.14856600E+03, -.16849800E+02, -.66727500E+01, 0.37371800E+02, 0.84208700E+01, -.11988800E+03, -.82219600E+01, 0.10433200E+02, -.11829700E+03, 0.80101400E+02, -.40360900E+01, -.25893800E+01, 0.69484400E+00, -.43817700E+01, 0.83831500E+02, 0.55819400E+00, 0.95863900E+01, -.42331700E+02, -.34009900E+01, 0.34792000E+01, -.28889400E+02, 0.35152300E+02, -.12337600E+02, -.70904600E+02, -.29942600E+02, 0.19109900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12187000E+01, -.34288100E-01, 0.47811400E+00, -.13988900E+01, 0.36869700E+00, 0.12766700E+01, -.93986000E+00, 0.57449800E-01, 0.35849800E+00, -.81486300E+00, -.46632000E-01, 0.37505100E+00, 0.49629400E+00, 0.19146400E+00, -.20816500E-01, -.87750600E+00, 0.29854800E+00, 0.20211800E+00, -.27413200E-01, 0.54476800E+00, -.34118600E+00, -.51766600E-02, 0.18203400E+00, 0.60708400E+00, -.11096600E+00, -.31767700E+00, -.92933800E+00, 0.40396100E+00, 0.44818500E+00, -.19151900E+00, -.45939700E-01, 0.11833600E+00, -.95623300E-01, 0.15751900E+00, -.84087500E-02, 0.30402400E-01, -.18786900E-01, 0.10209100E-01, 0.95670000E-01, 0.38422600E+00, 0.10763200E+00, 0.18271200E+00, 0.76831900E+00, -.68540500E-01, 0.74621400E-01, 0.72369900E-01, 0.10081400E-01, 0.22832100E+00, -.19243400E+00, 0.64085100E-02, -.22574200E+00, -.91591400E-01, 0.12625800E+00, 0.50034300E+00, 0.62111900E-01, -.36972300E+00, -.28431800E-01, -.16793100E+00, 0.15501900E-02, -.14444700E+00, 0.12071000E+00, -.98217200E-01, 0.21680000E-01, -.11035300E+00, -.45657700E-02, 0.15925800E+00, -.59641400E-01, 0.38821100E+00, 0.97337200E-01, -.19860600E-02, 0.17578900E+00, -.99086900E-01, 0.34015800E+00, 0.32258300E+00, -.11386800E+00, -.57634800E-01, -.61037600E-01, 0.61934700E-01, -.66809400E-01, -.10493000E+00, 0.41477300E-02, 0.85827100E-01, -.32895600E-01, 0.86569600E-01, 0.35788100E-01, -.25812600E-01, 0.17640700E-01, -.22388000E-01, 0.39322700E+00, -.10575400E+00, 0.78167500E-01, -.47628600E-02, -.77746500E-01, -.23048100E-01, -.11396300E+00, -.24118400E-01, -.12358100E+00, -.65453600E-01, 0.25904500E-01, 0.19924600E-01, -.11731400E-01, 0.20563800E-01, -.31193800E-02, 0.91796500E-02, -.61684700E-01, 0.11069600E-01, 0.34078300E-01, -.32122700E-01, 0.26831700E-01, -.14473300E+00, -.60816400E-01, -.12357000E-02, 0.27893200E-02, 0.28719600E-03, -.24407200E-01, -.74256500E-02, -.90727500E-02, -.15388200E+00, 0.11222100E+00, 0.50118800E-01, -.10519000E-02, 0.88484400E-02, 0.22315200E-01, 0.34049400E-01, -.46665000E-02, 0.10442000E-01, -.46467200E-01, 0.54970600E-02, 0.15014900E-01, -.47555200E-01, 0.25558300E+00, -.16202200E+00, -.57854600E-01, -.86726000E-01, -.19202900E-01, -.36605400E-02, -.47115500E-02, -.41170300E-01, -.66878600E-01, -.12801300E-01, -.54570700E-01, 0.61357100E-01, 0.38170800E-02, -.20821600E+00, 0.53653800E-01, -.54770200E-01, -.79998900E-02, 0.94749000E-02, 0.28709400E-01, 0.44946000E+00, -.28529500E+00, 0.46942500E-02, 0.10973200E+00, 0.74710300E-02, 0.49464700E-01, 0.17439700E-01, -.12295800E-01, -.84749100E-02, 0.90651500E-01, 0.14631900E+00, 0.83338100E-01, -.24434400E-01, -.10085800E+00, 0.35397700E+00, -.21194400E+00, -.10087300E+00, 0.36566700E-01, 0.76832300E-02, -.28119600E-01, 0.26157100E-01, 0.68384800E-02, -.14042700E-02, 0.36255800E-01, 0.14357300E+00, -.27834400E-01, 0.55489800E+00, 0.65479900E-01, -.41357200E-01, -.10977100E+00, -.41744600E-01, 0.50358600E+00, 0.50933300E+00, 0.14942400E+00, -.11997600E+00, 0.17068200E+00, 0.99540000E-01, 0.78402100E-01, 0.35773200E-03, -.35155300E-01, -.21474200E+00, -.17308800E-01, -.32433100E+00, -.34944600E+00, -.66199000E-01, 0.87341000E-01, 0.21187600E+00, -.28840600E+00, -.13865800E-01, 0.10760700E+00, -.34359100E-01, 0.79333200E-01, -.20620500E-03, -.26867000E-01, 0.15399300E+02, 0.63777000E+01, 0.39112400E+01, -.97899400E+00, 0.15966200E+02, -.14168800E+02, 0.64242200E+01, -.31377300E+01, -.12225400E+02, -.32191000E+01, 0.41411100E+01, 0.26773300E+01, -.65263200E+00, 0.75480200E+01, 0.32668900E+01, 0.94881500E+00, -.13667900E+02, -.22330000E+02, 0.12160500E+02, 0.25002400E+02, 0.11096800E+02, 0.16492400E+02, 0.12432900E+02, -.23571600E+01, -.14211700E+02, 0.78551900E+01, 0.68964300E+01, 0.22558500E+02, -.28372800E+02, 0.10593500E+02, 0.23599100E+02, 0.14244200E+02, -.37573500E+00, -.63695300E+01, 0.16437600E+00, -.15232000E+02, -.32629300E+00, -.42992000E+01, 0.17397700E+02, -.46572400E+01, 0.96212100E+00, 0.25511400E+01, 0.22918600E+01, -.28278100E+01, -.27046400E+01, 0.13558100E+01, -.48275100E+00, 0.11168700E+01, -.26581400E+01, -.69048300E+01, 0.28118000E+02, -.14077500E+02, -.21984000E+02, -.14046900E+02, -.67465100E+00, -.27745100E+01, -.12146000E+02, 0.61837100E+01, 0.15705000E+01, -.17082800E+02, -.26259400E+01, -.11463600E+01, -.55389400E+00, 0.62925300E+01, 0.71397300E+00, 0.12787100E+01, -.72612800E+00, 0.88142100E+00, 0.12981100E+01, -.10031000E+01, 0.67605400E+00, -.90267400E+00, -.71089300E+00, -.49050200E+00, -.76853100E+00, -.75730100E+00, 0.72483200E+00, -.27492700E+01, -.15104000E+01, 0.31000200E+00, 0.11428400E+01, 0.20250600E+01, 0.17575100E+00, 0.22052300E+01, -.16481000E+01, 0.13979600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.63590700E+01, 0.34415600E+00, 0.56016400E+00, -.27319000E+01, -.21633100E+01, 0.35592800E+00, 0.10955500E+01, 0.44968300E+00, -.29642800E+00, 0.13680800E+01, -.51144600E+00, 0.12781500E+01, 0.20214700E+01, 0.11177600E+01, -.38248200E-02, 0.76805200E+00, 0.16450400E+01, 0.46091300E+00, -.20930500E+01, 0.13917100E+01, -.83535400E+00, -.38784900E+00, 0.83223200E-01, 0.89184000E+00, 0.14698900E+00, 0.13968500E+00, 0.94957800E+00, -.53942700E+01, 0.14798500E+01, 0.31453700E+00, -.60914200E+00, 0.12337700E+01, 0.40531600E+01, -.23414900E+00, 0.25311200E+00, -.55821400E+00, 0.72079600E-01, 0.60848700E-01, 0.12897600E-01, -.23169600E+01, -.16481100E+00, -.21178100E+00, 0.14744900E+01, -.26038600E+00, -.96187100E+00, -.17728600E+00, 0.63923400E+00, -.12268700E+01, 0.71836200E+00, 0.32255500E+00, 0.75977800E+00, -.19469100E+00, 0.32973200E+00, -.76701200E-01, 0.10230500E+01, 0.14609900E+01, 0.55318600E+00, -.35376800E+00, 0.64998100E-02, -.82610900E-01, -.19986200E+01, -.77510300E+00, 0.66143600E-01, -.37776800E+00, -.49556700E+00, -.10117900E+01, 0.25391800E+00, 0.12865600E+01, -.28375600E+00, -.45215400E-02, 0.11283300E+01, -.38229100E-01, 0.63109400E+00, 0.11252600E+01, 0.26198500E+00, -.11090800E+01, 0.29427300E+00, 0.87547300E+00, -.42169000E+00, 0.24668900E+00, 0.53758000E-02, -.84662500E+00, -.62742000E-01, 0.14805400E+00, -.29464200E+00, -.16084500E+00, 0.56536000E+00, -.76214500E+00, -.11257700E+00, 0.64856400E+00, 0.22157600E+01, -.15102500E-01, 0.62051700E+00, -.21582500E+00, -.11112400E+01, -.38143400E+00, 0.10338000E+01, -.53793700E+00, 0.22690300E+00, -.23454400E+00, 0.59571400E-01, 0.12843700E-02, 0.72349300E-02, -.59356100E-01, -.77352100E-01, 0.99057200E-01, -.53639500E+00, -.27530300E+00, 0.28804000E+00, -.35873700E+00, 0.37223700E+00, 0.95165700E-03, 0.23866400E-01, 0.28125000E-01, -.81930900E-01, -.40364500E-01, -.15277800E+00, -.41676700E+00, -.10973200E+01, 0.31414800E+00, 0.46591800E-02, 0.18036100E+00, -.78493900E-02, -.14246100E+00, 0.82529600E-02, 0.23070500E+00, 0.25713300E+00, 0.27181100E-01, 0.43126400E-01, 0.11173800E+00, -.51145400E+00, 0.81841200E+00, -.90285600E+00, -.12973800E+00, -.66583500E-01, 0.13123800E-01, 0.60327000E+00, -.10747800E+01, 0.64593500E+00, -.16541200E+00, 0.15690600E+00, 0.63870900E+00, 0.91816400E-01, -.11763000E+01, 0.44483800E+00, -.18396400E+01, -.31655400E-01, -.18716500E+00, -.91623000E-01, 0.16516200E+00, 0.48660500E-01, 0.14890900E+00, 0.12815900E+00, 0.16833300E-01, -.74059300E+00, 0.18566700E+00, 0.35657500E-01, -.13421600E+00, 0.88845900E-01, -.14056400E+00, 0.18584000E+00, 0.16161800E+00, -.25075000E+00, 0.11681300E+01, 0.37042800E+00, -.98621700E-01, 0.31830800E+00, -.16691000E+00, -.80539900E+00, 0.11542500E+00, -.18979300E+00, -.35687100E+00, 0.19044500E+00, -.39705100E+00, 0.43346300E+00, 0.27202700E+00, 0.71255200E+00, -.19970300E+00, -.27978200E+00, 0.24382300E-01, 0.72613400E+00, -.18717500E+00, -.39277800E+00, 0.45108300E-01, -.34163800E+00, -.26702800E+00, -.10370600E+00, 0.14374700E+00, 0.51964700E-01, 0.53211800E+00, 0.10289600E+00, -.79706700E+00, -.46413200E+00, -.16767300E-01, -.36953500E-01, 0.32087900E+01, 0.76088200E+00, 0.19399900E+00, 0.19897700E+00, 0.38892300E-01, -.30869700E+00, -.43582800E-02, 0.16481100E-01, -.33113200E+01, -.71528700E+02, -.55915300E+02, -.14537000E+02, 0.18589600E+02, 0.29366900E+02, 0.31625800E+00, 0.79739300E+00, -.20320900E+02, -.26998200E+00, -.15316400E+02, -.29950100E+02, -.37101900E+02, -.40342100E+02, -.21052900E+02, -.17056400E+02, 0.23556000E+02, -.26131100E+02, 0.20057700E+02, -.87975800E+02, 0.12593100E+02, -.68901500E+00, -.48403200E+02, -.53496800E+02, -.45631000E+02, 0.36990700E+02, -.66166500E+02, 0.31690100E+02, 0.69316300E+02, -.30154100E+02, 0.76328700E+02, -.35080500E+02, -.56221200E+02, -.36141800E+02, 0.60041700E+02, 0.69871000E+02, -.40190600E+01, -.41615500E+02, -.26214600E+02, 0.71252000E+02, -.49722700E+02, 0.22993000E+02, -.35869700E+02, -.37246500E+02, -.13665800E+02, -.43979400E+01, -.32623900E+01, -.36886100E+02, 0.51489100E+01, -.38852000E+01, -.19392400E+03, 0.98460100E+02, 0.63946900E+02, 0.97160200E+02, -.65234600E+02, -.48203500E+02, 0.11665700E+03, 0.83319000E+01, 0.73295600E+02, -.26051200E+02, 0.14396100E+03, -.64179000E+01, -.26075500E+01, 0.17166200E+02, 0.56936800E+01, 0.16076600E+02, -.72340700E+01, 0.29809200E+01, 0.15920500E+02, -.11648300E+02, -.13488600E+01, -.81580900E+00, -.18629300E+01, 0.65243500E+00, -.10513400E+02, -.24877500E+01, 0.54419000E+01, -.11734000E+02, 0.26611000E+01, 0.62950600E+01, 0.13819300E+01, -.34657700E+01, 0.35711900E+01, 0.48979900E+01, -.31259600E+01, 0.24399500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19399300E+02, 0.21532800E+01, 0.92265700E+00, 0.99741700E+01, 0.72341700E+01, -.73422700E+01, 0.24848500E+01, 0.78259300E-01, -.22169200E+01, 0.48856300E+01, -.56666400E+00, 0.26341300E+01, -.65232100E+00, -.58714400E+01, 0.12500900E+01, 0.26113200E+01, 0.14984600E+01, -.23789600E+01, 0.45234200E+01, -.25415500E+01, -.28123000E+01, -.92318400E+00, 0.51105000E+00, 0.28520700E+01, 0.82146400E+00, 0.11899100E+01, 0.26176800E+01, 0.24228400E+01, -.37941200E+01, 0.18324200E+01, 0.30230100E+00, 0.81378700E+00, 0.60108700E+00, -.18201200E+01, 0.95806300E+00, 0.57084600E+00, 0.44647400E-01, -.75132900E+00, 0.87780100E+00, 0.28835900E+00, 0.34780900E+00, -.14116800E+01, 0.32418800E+01, -.15119500E+00, -.11336500E+01, -.38896000E+00, 0.29107300E+00, -.17998200E+01, 0.18644700E+01, -.99828600E-01, -.13293300E+01, 0.71180800E-01, -.18972700E+01, -.22941300E+00, -.39047300E-01, 0.44036100E+01, 0.32925500E+00, -.98287800E+00, 0.23294300E-02, 0.87557400E+00, -.54217900E+01, -.22003000E+01, 0.16643000E+00, -.12466400E+01, -.27092800E+01, 0.90526400E+00, -.88084200E+00, -.57925000E+01, -.19458400E-01, 0.23548400E-01, -.51917900E+00, 0.17369700E+01, 0.59080000E+00, 0.93272400E+00, 0.14684000E+01, -.28442500E+01, 0.55091500E+00, 0.29781200E+01, 0.13182800E+01, -.36318400E+00, -.10220400E+00, -.37975000E+01, 0.75067200E+00, -.63031200E+00, -.70651100E+00, 0.66131300E+00, -.89464000E-02, -.60313100E+00, 0.23550100E+00, 0.37555200E+00, 0.22606100E+01, -.90423000E-01, -.47110200E+00, -.65826700E+00, -.10680800E+01, -.19430200E+00, 0.20067100E+01, -.63674800E+00, 0.16807200E+01, -.19334000E+01, 0.16801400E+01, 0.15657100E+01, 0.27492300E+00, 0.36616900E+00, 0.38048300E+00, -.10033500E+01, 0.91219700E+00, 0.47136300E+00, -.18581400E+01, -.62748200E-01, -.15424100E+01, -.11991400E+00, 0.12870500E+01, -.14130000E+00, -.10098100E+00, -.27860800E-01, 0.94480000E+00, 0.85223100E+00, -.30401200E+01, 0.23076700E+01, 0.61281700E-01, 0.56208700E+00, -.27868700E+00, -.81830200E+00, 0.12015800E+00, 0.28455200E+01, -.25423800E+01, 0.79293700E+00, -.23022300E+00, -.57219400E+00, 0.73412900E+00, -.23435300E+00, 0.91827800E+00, 0.33301100E+01, 0.71631200E+00, 0.91519300E-01, -.14674300E+01, 0.18819400E+01, -.31705000E+01, 0.33770500E+00, 0.11651500E+01, -.84347400E+00, 0.10417400E+00, 0.17729000E+01, -.10906000E+01, 0.17435000E+01, 0.12719500E+00, 0.19267800E+00, 0.46908800E+00, -.46623900E+01, 0.20954900E+01, -.12399800E+00, -.42157500E+00, 0.46141000E-01, -.50376000E-01, -.13156900E+00, 0.25756500E+00, 0.12188200E+00, -.35343100E+00, 0.15907500E+01, -.14386700E+01, 0.85327500E-01, 0.12651700E+01, 0.26174800E+01, -.56311300E+00, -.56450500E+00, -.52778100E+00, 0.41608300E+00, 0.28047900E+01, -.11151100E+01, 0.15600900E+00, -.16874200E+00, -.51790000E+00, 0.61487100E+00, -.62305900E-01, -.20561800E+01, -.27458200E+00, 0.32221600E+00, -.10308100E+01, 0.55201300E-02, -.31762500E+01, 0.11823000E+01, 0.66964600E+00, 0.25017500E+00, 0.58968800E+00, -.49107700E+00, -.40431900E+00, -.14971500E+00, -.10439500E+00, 0.14716200E+01, -.41984500E-02, -.54469600E+00, -.22356600E+01, 0.20792300E+01, -.66407100E+00, -.73639700E+01, -.35574200E+01, -.11168000E+01, 0.19944200E+00, -.27413700E-01, 0.56057000E+00, -.46814900E-02, 0.57991800E-01, -.41583900E+01, 0.35410000E+00, 0.88599700E+02, 0.36366100E+02, 0.28734200E+02, -.67673700E+02, 0.45621700E+02, -.20570900E+02, -.72450200E+02, -.22888000E+02, 0.51781500E+02, -.61479900E+00, -.22990100E+02, 0.31105800E+02, -.20666600E+02, 0.21165800E+02, -.13829600E+03, -.10139700E+03, 0.40502000E+02, -.40591400E+02, 0.50074400E+02, 0.20890000E+02, 0.11097500E+03, -.43203800E+02, 0.16811200E+02, 0.27343400E+02, 0.11629500E+03, -.96225100E+02, 0.69169700E+02, -.43202800E+02, -.35074300E+02, -.35026900E+02, -.33333600E+02, -.28328300E+02, -.16832500E+03, -.11786400E+03, -.27028300E+02, -.26558000E+02, 0.29907600E+02, 0.51608800E+02, -.32801700E+02, 0.28659300E+02, -.25750700E+02, -.55778000E+01, -.77318600E+01, 0.17118300E+02, -.20253300E+02, -.64995600E+02, -.63020900E+01, 0.10045400E+02, 0.13181800E+03, -.69109100E+02, -.35963200E+02, -.65773300E+02, 0.36324400E+02, 0.26086400E+02, -.14055200E+02, 0.36125000E+02, 0.18062600E+02, -.84455800E+02, -.34029000E+02, -.42939700E+01, -.25246600E+01, 0.26448600E+02, 0.12442100E+01, 0.26878500E+02, -.99593500E+01, 0.73654100E+01, 0.26623300E+02, -.71653900E+01, 0.35857200E+01, -.76282500E+01, -.16324100E+01, -.67635400E+01, -.59563900E+01, -.31126500E+01, 0.22069300E+01, -.93597600E+01, -.76074100E+01, 0.41844600E+01, -.13795800E+02, -.45683700E+00, 0.78141900E+01, 0.28044700E+02, -.57143200E+01, 0.18839300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17905900E+02, -.14792200E+01, -.35287800E+01, -.14626100E+01, -.24385000E+01, 0.10484900E+01, -.12949800E+01, -.89616600E+00, 0.78822500E-01, -.43997700E+01, -.10128400E+00, -.23864600E+01, -.13919600E+01, -.71804400E+01, -.12870600E+01, -.12674200E+01, -.80352100E+01, -.77961900E+01, 0.64632300E+00, -.25474900E+01, 0.51378600E+01, 0.36460800E+00, -.53140200E+00, -.56956700E+01, -.38068000E+00, 0.11479800E+01, 0.39260000E+01, 0.63458500E+01, -.20517000E+01, 0.17879300E+01, -.19114800E+00, -.21296500E+00, -.41526700E+01, 0.24260700E+01, -.11520800E+01, 0.34156500E+01, -.44281300E-01, 0.17493000E+00, -.72064000E+00, 0.64096700E+01, -.24246900E+00, 0.15053800E+01, -.11831800E+01, 0.63432800E+00, 0.52607500E+01, 0.12552400E+01, -.18578200E+01, 0.22511600E+01, -.37487800E+01, -.70714400E+00, -.45551800E+01, 0.16787600E+01, 0.47193100E+00, 0.27790800E+01, -.60891300E+00, -.15821000E+01, -.11378700E+01, -.22825600E+01, 0.74370800E-02, 0.38010400E+01, -.11281700E+01, 0.74911600E+00, -.15992000E-01, -.14739300E+01, -.27850300E+01, 0.60821000E+01, -.91386700E+00, 0.37524100E+01, 0.79719500E+00, -.70064400E-02, -.15993000E+01, -.27200100E+00, 0.16606100E+01, 0.29313900E+01, -.81007100E+00, -.22787300E+01, -.48388300E+00, 0.11248000E+01, -.10382000E+01, 0.14759900E+00, -.61918200E-01, -.60796100E+00, -.28965100E+00, 0.73656500E+00, -.36890300E+00, -.79615600E+00, 0.15715900E+01, 0.25273900E+00, 0.88398600E+00, 0.11504000E+01, 0.57397500E+01, 0.86894500E-02, 0.18768900E+01, -.73526300E-01, -.14831200E+01, -.10300200E+00, 0.32274100E+00, -.13695000E+01, -.84418900E+00, 0.51445400E-01, 0.31285000E+00, -.84400200E+00, 0.47751000E-01, -.42323700E+00, 0.17722100E+00, 0.44236300E+00, -.14092900E+01, 0.11703600E-02, -.31867600E+00, 0.11580300E+00, 0.59259800E+00, -.60156100E+00, -.70961800E+00, 0.30228900E-01, -.31821200E+00, 0.40630800E+00, 0.10037500E+01, 0.14856900E+01, 0.51837600E+00, -.72513800E+00, 0.84427100E+00, -.71953400E+00, 0.97994500E-01, 0.24961500E+00, -.72251300E-01, -.33080200E+00, -.23364500E+00, 0.16775800E+00, -.32972000E-01, 0.22683900E+00, -.26880400E+01, 0.61108900E+00, 0.75839000E+00, 0.54902200E+00, 0.26458100E+00, 0.37107600E-01, 0.98957700E-01, 0.60165200E+00, -.69540300E+00, 0.10576000E+01, -.81189100E-01, -.27793100E+00, 0.97593500E+00, 0.15683300E+01, 0.24837700E+00, 0.26350000E+01, -.35135100E-01, 0.10802300E+00, -.13826800E+01, -.14505700E-01, 0.95499700E+00, 0.29927400E+00, 0.27482500E+00, 0.42874600E+00, -.11326200E+01, -.39469800E-01, 0.29037700E+00, -.11064200E+00, 0.10816200E-01, 0.34251300E+00, -.22727500E+01, 0.16434500E+00, 0.13465300E+01, 0.30247000E+01, -.24203900E+01, 0.15244500E+00, -.16254000E+00, -.33166100E-01, -.11316100E+01, -.83807900E+00, -.14322500E+00, -.16300600E+00, -.90183000E-01, 0.21439700E+01, 0.14157500E+00, -.16863300E+01, -.10267400E+01, 0.49864400E+00, 0.18609100E-01, 0.30219400E+00, -.46660200E+01, 0.10288600E+01, 0.17301000E+01, -.58871500E+00, 0.64275500E-01, -.42962700E+00, 0.69844000E-01, 0.67687400E+00, -.10180700E+00, 0.22713300E+01, 0.95113300E-01, 0.70355200E+00, -.10474100E+01, -.58484100E+00, -.31677600E+00, 0.32234400E+01, 0.39255100E+01, 0.95162100E+00, -.19713100E+01, 0.43425900E+00, -.15494800E+01, 0.40329400E+00, -.37572700E+00, -.68253200E+01, -.14535600E+01, 0.62744200E-01, 0.11606100E+03, 0.68707900E+01, -.82543600E+02, -.42963800E+02, 0.22767100E+02, -.53475900E+02, 0.21348700E+02, 0.15683200E+02, 0.84111700E+01, -.41784000E+02, 0.42644700E+02, 0.80956600E+02, -.60553500E+01, -.69576200E+02, -.22040700E+03, 0.10904900E+03, 0.10604400E+03, 0.10789900E+03, 0.83605000E+02, 0.17987900E+03, -.12560900E+03, -.13675100E+03, 0.70172900E+02, 0.10140000E+03, 0.47628600E+03, 0.33605200E+02, -.20282700E+02, 0.82325800E+02, -.15096700E+02, -.66397100E+02, -.28714500E+03, 0.10560200E+03, 0.19214200E+02, 0.75114500E+02, -.29668700E+03, 0.28867200E+02, 0.12100600E+02, -.15657300E+02, 0.11663200E+03, -.64283700E+01, -.67674000E+02, -.29512400E+01, -.31467000E+02, -.19343500E+00, -.30670500E+02, 0.67350000E+01, -.19301300E+03, 0.11903000E+03, -.60530700E+02, -.35729700E+02, -.59341300E+02, -.11628400E+03, 0.11347200E+00, -.53065500E+00, 0.66056000E+02, -.68430500E+02, -.12374100E+03, 0.40490700E+02, -.13571400E+02, 0.89251600E+01, 0.55425500E+02, 0.12552900E+02, -.21809900E+02, -.16167900E+01, -.85972500E+00, -.19804600E+02, 0.19106300E+02, -.43314000E+01, -.29509200E+01, -.66592000E+00, -.38644200E+01, 0.22433900E+02, -.19002700E+01, 0.12513700E+02, -.30483900E+02, -.11464200E+02, -.86084400E+01, -.28521800E+02, 0.13773000E+02, -.12975100E+01, -.95018700E+01, -.11738600E+02, 0.51821200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18258000E+02, -.16067900E+01, 0.31382800E+00, -.20386400E+01, -.72533600E+01, 0.13280800E+01, 0.48281400E+00, -.93966900E+00, 0.37048000E+00, -.11471200E+01, 0.98501800E+00, -.38547400E+01, -.27978300E+01, -.15990400E+01, -.61668600E+00, -.17378500E+01, -.10069800E+02, -.46944100E+01, 0.62329400E+00, -.19175800E+01, 0.26567600E+01, 0.47965300E+00, -.83284600E+00, -.39691300E+01, -.63970000E+00, 0.13646000E+01, 0.57527400E-02, 0.22973400E+01, 0.91110000E+00, 0.95345700E+00, -.10539500E+00, -.54444500E+00, -.50422400E+01, 0.20932000E+01, -.12153500E+01, -.22350300E+01, -.14027400E-01, 0.28758200E+00, -.15015600E+01, -.45018800E+01, -.77732300E+00, -.11630400E+01, -.69076300E+01, 0.68648900E+00, -.21085500E+01, -.98691800E+00, -.13743600E+01, 0.13065100E+01, -.22454800E+01, -.48865900E+00, -.45944000E+00, 0.28884400E+01, 0.53209300E-01, 0.60388200E+00, -.56055000E+00, 0.32897800E+01, 0.18558900E+00, -.92044300E+00, 0.19117200E+00, 0.47672200E+01, -.33235300E+01, 0.11403800E+01, -.23229300E+00, 0.10748400E+01, -.17298700E+01, 0.20360700E+01, 0.70965900E+00, 0.73933600E+01, -.71828500E+00, 0.39156200E+00, -.13144700E+01, 0.60157700E+00, 0.55784300E+01, 0.24855300E+01, -.92882700E+00, -.21993200E+01, 0.82001100E+00, 0.66176000E+00, -.61863300E+00, 0.19848500E-01, -.89617800E-01, -.25367300E+01, -.67542200E+00, -.17232200E+01, -.11729700E+01, -.25358500E+00, 0.31407200E+01, 0.51806400E+00, -.13056400E+01, 0.22530100E+01, 0.44342000E+01, -.76106600E-01, 0.45588700E+00, 0.38316900E+00, 0.14278400E+01, -.11443200E+01, 0.26106400E+00, -.10459500E+01, 0.21747500E+00, 0.58199800E+00, -.19088300E+01, -.17798500E+01, -.67934700E-01, -.49887000E+00, -.33229400E+00, -.12694800E+01, -.22941300E+00, 0.45221300E+00, 0.58997600E+00, -.25228500E+01, 0.20891400E+01, 0.30283500E-01, -.20470000E+01, 0.10709900E+00, 0.31411700E+00, 0.31149100E+00, 0.17208300E+00, 0.29069000E+01, -.21363800E+01, -.12215300E+01, -.11137000E-01, -.21533700E+01, -.86577400E-01, -.10489400E+01, -.14857700E+00, -.52167600E+00, 0.93627500E+00, 0.14125900E+00, -.25657900E+00, 0.73325200E+00, -.44105700E+01, 0.18975400E+01, 0.21530500E+00, 0.43073300E-01, 0.11351200E+00, 0.22536500E-01, 0.14021700E+00, 0.27722600E+00, -.60997200E+00, 0.81349500E+00, -.95990700E-01, 0.30804200E+00, -.47773000E+00, 0.31546300E+01, -.35155200E+00, 0.30377700E+00, 0.35734300E+00, -.96211900E-01, -.19250100E+01, -.18344400E+01, 0.30127600E+01, -.25612300E-01, -.89197900E+00, -.86375600E-03, 0.11047700E+00, -.13211200E+00, 0.35195900E+00, -.69576800E+00, -.43980200E+00, 0.10772100E+01, -.19446700E+01, -.67920100E-02, 0.96986400E+00, -.75488300E+00, 0.14690200E+00, 0.89664000E+00, 0.33460900E+00, -.47074200E+00, -.25021700E+01, -.48464300E+00, -.54490400E+00, -.49678400E+00, 0.61545400E-02, 0.14852500E+01, -.15097600E+00, -.13488500E+01, -.33123000E+00, 0.23787400E+00, 0.46111700E+00, 0.89179700E+00, -.63883500E+01, -.15034800E+01, 0.14006100E+01, -.19586400E+00, -.32745700E+00, 0.79351700E+00, 0.33807800E+00, 0.57842900E+00, 0.51823700E-01, 0.34047400E+01, 0.56734900E+00, -.21358600E+00, 0.10867900E+01, -.27940800E+01, -.85352600E-01, 0.10561400E+02, 0.28436700E+01, 0.15875900E+01, -.11292100E+01, 0.37922100E+00, -.16158300E+01, -.72432000E-02, -.26427800E-01, -.33148200E+01, 0.21434800E+00, 0.46739000E+00, -.84055700E-01, -.67988200E+02, -.85856400E+02, -.65185800E+02, 0.31543000E+02, 0.19523700E+02, 0.32486100E+02, -.25602900E+02, 0.36144000E+02, 0.44512700E+02, 0.46223800E+02, 0.68038000E+02, -.20365900E+02, 0.10932900E+03, 0.45034400E+02, -.22530600E+02, 0.14654700E+03, -.23849500E+02, -.15359000E+02, 0.12346300E+03, 0.21750700E+02, 0.26837100E+02, -.11267700E+03, 0.80666600E+02, 0.41850200E+03, 0.14196800E+02, -.47652600E+01, -.13289900E+03, -.64560400E+01, -.40893000E+02, -.22726800E+03, 0.87487400E+02, -.11265000E+02, 0.80905700E+02, -.25121800E+03, -.61648000E+00, -.12576100E+03, 0.73769600E+02, 0.24515300E+02, 0.62685700E+02, 0.22988100E+02, 0.41879600E+02, -.63092300E+02, -.47374900E+01, 0.84966800E+02, 0.31732500E+02, -.13030300E+03, 0.14729100E+03, -.73853500E+02, -.43903100E+02, -.73485700E+02, -.53830400E+02, -.30387400E+02, -.31455800E+02, -.17339100E+02, -.22097800E+02, -.14339300E+02, -.12024400E+03, 0.44239700E+00, 0.13050200E+02, 0.25327900E+02, 0.14756100E+01, -.18514200E+02, 0.93962500E+01, -.71877800E+01, -.15652000E+02, 0.14556500E+02, -.38573400E+01, -.12599600E+00, 0.14526500E+00, 0.36243000E+01, 0.14527700E+02, 0.28278500E-01, 0.15445300E+01, -.42685900E+01, -.10576600E+02, -.12922800E+02, 0.95400500E+01, 0.16361800E+02, -.44868400E+00, -.29142100E+01, -.67381200E+01, 0.89308500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.74377800E+01, 0.65587100E+00, 0.96352900E+00, -.23610200E+01, -.13772400E+01, 0.79944700E+00, 0.38179700E+00, 0.43053500E+00, 0.22762700E-01, 0.16608000E+01, -.31737200E+00, 0.17907700E+01, 0.22449200E+01, 0.83143500E+00, 0.30065700E+00, 0.62207200E+00, 0.23209200E+01, 0.12781400E+01, -.16584800E+01, 0.18563800E+01, -.97893700E+00, -.22763700E+00, 0.31025600E+00, 0.16150600E+01, 0.19449400E+00, 0.13032900E+00, -.21218000E+00, -.31147200E+01, 0.79399800E+00, 0.67768000E-02, -.30802400E+00, 0.12325500E+01, 0.25221500E+01, 0.52535800E+00, 0.16312300E+00, -.74306000E+00, 0.57708000E-01, -.84602000E-01, 0.20435300E+00, -.26007800E+01, -.70813800E-01, -.49121800E+00, 0.11908500E+01, -.12219900E+00, -.17149900E+01, -.24218400E+00, 0.54060000E+00, -.65272700E+00, -.53699400E+00, 0.24884400E+00, -.31215700E+00, 0.82148400E+00, -.51057100E-01, 0.79898300E+00, 0.16137200E+01, 0.68645500E+00, 0.52696700E+00, 0.16876500E+00, 0.28809900E-02, -.12268600E+01, -.30534000E+01, -.14827700E+01, 0.14819000E+00, -.74725700E+00, 0.39715200E+00, -.69806200E+00, -.21422300E+00, -.11083500E+01, -.32496900E-01, -.15243500E-02, 0.10854200E+01, 0.25787200E+00, 0.68379100E+00, 0.64704400E+00, -.58317300E+00, -.26387300E+00, 0.17093900E+00, -.41391400E-01, 0.19839400E+00, 0.10722500E+00, -.23607100E-01, -.35770700E+00, 0.18198800E+00, -.56255700E+00, -.29003500E-01, 0.39970100E-01, 0.31182300E+00, 0.10126100E+00, 0.40254000E-01, 0.28045500E+00, 0.58463400E+00, -.27663700E-01, 0.47523500E-01, -.13988600E+00, 0.11285600E-01, -.60619200E+00, 0.27663100E+00, -.29681700E+00, 0.40419100E+00, -.15645100E+00, -.39370500E+00, 0.13997900E+00, -.21739000E-01, 0.40464800E-01, -.12455900E+00, -.18389800E+00, 0.38733000E+00, -.10632000E+00, -.43636600E+00, 0.66284600E+00, -.57578800E+00, -.71469700E-01, 0.99355900E-01, -.27988000E-01, 0.31596200E+00, -.85143900E-01, -.29749500E+00, 0.15312000E+00, -.19273500E+00, 0.74236900E+00, 0.12679100E-01, -.13130300E+00, 0.13970000E+00, 0.68125700E-01, 0.19156900E-01, 0.14427600E+00, -.27376000E+00, 0.24446400E-01, 0.21878700E+00, 0.76254000E-01, 0.65569300E+00, -.59057000E+00, -.57089600E+00, -.79141400E+00, -.12191800E+00, -.16437700E-01, 0.78213100E+00, -.51713000E+00, 0.10872300E+01, -.59106900E-01, -.20706800E+00, 0.67543500E+00, 0.25799800E+00, -.15608900E+01, 0.38405400E+00, -.11235800E+01, -.88945000E-01, -.45581900E-01, -.11927300E+00, 0.93559700E+00, -.54367900E-01, 0.14504300E+00, 0.33709500E+00, 0.18094000E-01, -.10445900E+01, 0.16825600E+00, -.15263600E+00, -.40575500E-01, 0.14994200E+00, -.77715300E+00, 0.11681000E+01, 0.98278900E-01, 0.19587700E+00, 0.10497900E+01, -.23578500E-01, -.59866700E+00, 0.30409300E+00, -.70125500E-03, -.18765300E+00, -.20914600E+00, -.54371300E-01, -.84598200E-01, 0.90113200E-02, 0.70775500E+00, 0.20955200E+00, -.11648200E+01, -.21457500E-01, 0.16636800E+00, -.11886900E+00, 0.69529800E-01, -.19343300E+01, 0.19715500E+01, 0.75634000E+00, -.16319400E+00, -.64315900E-02, -.47852600E+00, -.31094700E-01, 0.23252600E+00, -.15598100E+00, -.72324600E+00, -.15015100E-01, 0.17273700E+00, -.24705500E+01, 0.72613300E-02, 0.22014300E+00, 0.10149600E+01, 0.11266400E+01, 0.32182600E+00, -.19541300E+00, 0.73877000E-01, -.13124000E+00, -.53236400E-03, -.22451600E+00, -.34218900E+01, 0.21733300E+00, -.37221600E-01, -.10462100E+00, -.45322500E+00, -.12230400E+03, -.40320700E+02, 0.21026700E+02, -.48017400E+02, 0.20077300E+02, -.20844200E+01, 0.69962000E+01, -.82451500E+01, 0.46299000E+01, 0.21651100E+02, -.36227300E-01, -.31839900E+02, -.22468200E+02, -.52453600E+00, 0.71838300E+02, 0.91943600E+01, -.24858800E+02, 0.11972000E+03, -.38975800E+02, -.17270300E+02, -.45153200E+02, 0.70215800E+02, 0.27563000E+03, 0.42465000E+02, -.17445100E+02, -.58384500E+02, -.19383400E+02, -.22991100E+02, -.16086300E+03, -.45991700E+02, -.59368700E+02, 0.20043800E+02, -.17875800E+03, 0.44694500E+02, -.70738200E+02, 0.48177800E+02, 0.92945000E+02, 0.35047200E+02, -.66925600E+01, 0.35454700E+02, -.51236600E+02, -.31630300E+02, -.84242900E+01, 0.43038100E+02, -.11065700E+03, 0.11801000E+03, -.63152900E+02, -.26994800E+02, -.58906700E+02, -.29274500E+02, -.16270300E+02, -.12449800E+02, 0.11164300E+02, -.29311900E+01, -.86030100E+02, -.56218700E+02, -.32321000E+01, 0.67670800E+01, 0.40571200E+02, 0.30823500E+01, -.21669500E+02, -.34458500E+00, 0.68994000E+00, -.20808500E+02, 0.28627200E+02, -.15690100E+01, 0.10876900E+01, -.24157100E+01, 0.25237000E+01, 0.30217700E+02, -.49101300E+01, 0.37776000E+01, -.17415800E+02, -.65693200E+01, -.68323400E+01, -.31226100E+01, 0.14974200E+01, 0.20505100E+01, -.35748600E+01, -.53330200E+01, 0.72941600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18272600E+02, 0.20152000E+01, 0.39721600E+01, 0.89197100E+01, 0.60146000E+01, -.72829700E+01, 0.43943800E+01, 0.61612800E+00, -.15982000E+01, 0.62546200E+01, 0.30643200E+01, 0.24470700E+01, 0.29926000E+01, 0.67154100E+01, 0.91064900E+00, 0.37256900E+01, 0.75561900E+01, 0.43599300E+01, 0.31879800E+01, 0.58028800E+00, -.48726800E+01, -.99354700E+00, 0.32186300E-01, 0.44499800E+01, 0.84796200E+00, 0.82515500E+00, -.20225600E+01, 0.42501000E+00, -.12721100E+01, -.15928500E+01, 0.54779100E+00, 0.70546700E+00, 0.45654900E+01, 0.68692800E+00, -.92585900E-01, -.18741500E+01, -.53886400E-01, 0.41471200E+00, -.55864100E+00, -.15842400E+01, 0.94471900E+00, 0.83430000E+00, -.33507600E+01, -.18181600E+00, -.14085500E+01, -.43235100E+00, 0.12223800E+01, -.50190000E+00, 0.17674000E+01, 0.35755400E+00, 0.17854500E+01, 0.37957800E+00, 0.10311500E+01, -.11114900E+01, 0.27906400E+01, 0.10532700E+01, 0.54303900E+00, 0.22340200E+00, 0.15818400E-02, -.19319700E+01, -.41278400E+01, -.20497400E+01, 0.32240400E+00, -.12202100E+01, 0.12183500E+01, -.63624800E+00, -.45085200E+00, -.50317500E+01, 0.75380600E+00, 0.99047900E-02, 0.11710100E+01, -.70733500E+00, 0.12122600E+01, 0.11600200E+01, 0.75556300E+00, -.27156000E+01, 0.44166400E+00, 0.22098400E+00, 0.30858800E+00, 0.97953600E-01, -.41670100E-01, -.22279400E+01, 0.15773400E+01, -.85486500E+00, -.71744700E+00, 0.39663500E+00, -.19701900E+01, -.19426000E+00, -.23240400E+01, 0.36333000E+00, -.32784700E+01, 0.45185300E-01, -.81022800E+00, 0.36593900E+00, 0.12220200E+01, -.38500800E+00, -.27166800E+01, 0.13920900E+01, -.39838700E+00, 0.33164200E+00, -.19259200E+01, -.24831200E+00, -.10675000E+00, -.59769500E+00, -.18638300E+00, -.52663400E+00, 0.99977800E+00, 0.17198900E+00, -.75432800E+00, -.15938200E+01, -.95092600E+00, 0.32184700E-01, -.12875100E+00, 0.20043600E-02, 0.11913400E+01, -.33233200E+00, 0.14364900E+00, 0.21512000E+00, -.29265700E+01, 0.17205300E+00, -.69899300E+00, -.86774800E+00, 0.16041900E+00, -.93647500E+00, 0.35008300E-02, 0.31562700E+00, 0.79819700E+00, -.25325000E+00, -.34701900E-01, 0.47955500E+00, 0.79893100E+00, -.11274000E+01, 0.60722300E+00, -.12444400E+01, -.16432800E+00, -.99669400E-02, -.14344600E+00, -.10263600E+01, -.50796100E-02, -.11400200E+01, 0.10253300E+01, 0.82092600E+00, -.62792000E+00, -.24579900E+00, -.16130400E+00, -.46430700E+00, 0.18949000E-01, -.26519200E+00, 0.59076500E+00, -.46342100E+01, 0.68261300E+00, 0.15795000E+00, -.13645700E+00, -.21851300E+00, -.13815300E+01, 0.10523700E+00, 0.35683100E-02, 0.85180500E-01, -.13803600E+00, 0.82427500E+00, -.23939200E+01, 0.37331900E-01, 0.10019100E+01, -.14790600E+01, -.14496300E+00, 0.44707000E+00, 0.69259200E+00, -.15575000E+00, -.11145200E+01, -.12518300E+00, -.32568700E-01, 0.96624700E+00, 0.37612800E+00, -.69192000E-01, -.52129300E+00, -.21086300E+00, 0.23876000E+00, 0.10211700E+00, -.65320300E+00, 0.67532800E-01, -.10712000E+01, -.15092700E+01, 0.48747900E+00, -.28206300E-01, -.53901400E+00, 0.35550300E+00, 0.99604700E-01, 0.95677900E+00, 0.14935000E+00, -.65497100E+00, -.16283400E+00, -.23181600E+00, 0.27463000E+01, 0.67972400E-01, -.14599500E+00, -.18649600E+01, 0.32258800E+01, -.74570900E+00, -.54906600E+00, 0.21969000E+00, -.23989500E+00, 0.18409700E-01, -.89715900E-01, 0.24001600E+01, 0.15341400E+00, -.17454700E+00, 0.88522600E-01, 0.10332200E+01, 0.33231600E-02, 0.14863900E+03, -.73053900E+02, 0.69299400E+01, -.73807400E+02, 0.21221900E+02, -.14925700E+02, -.47986800E+02, -.46305800E+02, -.78374900E+02, 0.20850000E+02, -.26907500E+03, 0.47383000E+02, -.35580100E+02, -.97315700E+02, -.20408600E+02, 0.40630900E+02, -.10181300E+03, 0.30631200E+02, 0.14556400E+02, 0.10965200E+03, -.44417800E+02, -.64278500E+03, -.17367300E+03, 0.99971500E+02, 0.49000300E+02, 0.88610900E+02, 0.96278300E+02, 0.33327700E+03, -.51121500E+02, 0.20752000E+02, -.61286600E+02, 0.36857100E+03, 0.76881700E+02, 0.78264700E+02, -.27257800E+02, -.66045900E+02, -.38622500E+02, -.13615100E+02, -.54376400E+02, 0.59357400E+02, 0.14302000E+02, -.89268800E+01, -.49863100E+02, 0.19182200E+03, -.20830400E+03, 0.10015800E+03, 0.11835900E+03, 0.10327100E+03, 0.81404700E+02, -.31962500E+02, 0.49515100E+02, 0.78294900E+01, 0.36534500E+02, 0.53432000E+02, 0.60426300E+02, 0.61861000E+01, -.13980800E+02, -.41289000E+02, -.59429000E+01, 0.74094900E+01, -.61964300E+01, 0.42763200E+01, 0.63397000E+01, -.17163000E+02, 0.10399600E+02, -.34349000E+01, 0.38527300E+01, -.23861900E+01, -.18818700E+02, 0.31791800E+01, -.43195100E+01, 0.10652200E+02, 0.85121900E+01, 0.16199300E+02, 0.20118900E+01, -.12122100E+02, -.61530900E+01, 0.72223100E+01, -.10787600E+01, -.12049300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.81728500E+01, 0.29466200E+00, -.32924000E+01, -.16829100E+01, 0.26149800E+01, -.16971300E+00, -.50484800E+00, 0.60302400E+00, -.36359600E+00, 0.11268200E+01, -.53084500E-01, 0.11328900E+01, 0.13825400E+01, 0.33358600E+00, 0.12761800E+00, 0.94459400E+00, 0.24829200E+01, 0.89502100E+00, -.14407400E+01, 0.63691300E+00, -.72356700E+00, -.30420800E+00, 0.19263400E+00, 0.66051200E+00, 0.11408600E+00, 0.49918900E-01, 0.97921100E+00, -.31729600E+01, -.47251700E-01, 0.24797300E+00, -.21043800E+00, 0.61932600E+00, 0.17699500E+01, -.87924100E-01, 0.18111400E+00, 0.81397800E+00, 0.29363700E-01, 0.72335000E-01, 0.18547700E+00, -.21045100E+01, -.11132900E+00, -.64207200E+00, -.39328900E+00, -.11575000E+00, -.21272900E+00, -.18580400E+00, 0.43774500E+00, -.96742700E+00, 0.11765700E+01, 0.22114100E+00, 0.59964100E+00, -.65798400E+00, -.68930800E-02, 0.95213000E+00, 0.88496300E+00, 0.37324900E+00, 0.22030500E+00, -.11481400E+00, 0.36595300E-02, 0.89989600E-01, -.62882000E+00, -.10350800E+01, 0.11834500E+00, 0.51802900E-01, -.10532200E+00, -.56884400E+00, -.43168500E-01, -.26970800E+01, -.15510600E+00, -.33706000E-03, 0.13661800E+00, -.15370700E+00, -.16263100E+01, -.26215200E+00, 0.11230400E+01, -.68482200E+00, -.43398500E-01, 0.12728800E+01, -.97481100E-01, 0.63822300E-01, 0.30146400E-01, -.53150700E+00, -.25483200E+00, 0.19886000E+00, 0.54654200E-01, 0.10336800E+00, 0.77229100E+00, -.60390200E-01, -.86322800E+00, 0.62796100E+00, 0.12764200E+01, -.35421400E-01, -.46397700E-01, 0.17307200E+00, -.94032500E+00, 0.20463000E+00, -.17801000E+00, 0.95716900E-01, 0.42139100E+00, 0.70086500E-01, 0.38809400E+00, 0.16304000E+01, 0.73739200E-02, -.23764400E+00, -.17863700E+00, 0.92340200E+00, 0.83454700E+00, -.73551800E+00, -.91291200E+00, 0.85659000E+00, -.64650100E+00, -.12766700E+00, -.10557000E+01, -.61346900E-01, 0.82920500E+00, -.49190000E-01, 0.25767200E+00, 0.11166600E+00, -.23634000E+00, -.66414200E+00, 0.64957900E-02, -.35670700E+00, 0.25835100E+00, -.66607100E-01, 0.28833500E-01, 0.29328900E+00, 0.32088400E+00, -.15733000E-01, -.61607500E-01, 0.59873600E-01, -.54131200E-02, 0.24143600E+00, 0.29366900E+00, 0.51093200E+00, 0.61115600E-01, -.16993500E-01, -.21010800E+00, -.12993800E+00, -.22617000E+00, -.57633000E-01, 0.22275700E+00, 0.58905000E-01, -.30942600E+00, 0.58665500E+00, -.45066700E-01, -.38983700E+00, 0.24372400E-01, -.10619500E+00, 0.80025000E-01, 0.22987800E+00, 0.40390800E+00, -.16007800E-01, -.18561700E-01, 0.86499500E-01, 0.40740100E+00, 0.75057600E-01, 0.23340900E+00, 0.21730600E-02, 0.18039300E-01, 0.41326600E+00, -.38098400E+00, 0.59910100E-01, -.13514000E+00, 0.58865800E+00, 0.40629900E+00, -.15032600E+00, 0.20377900E+00, 0.19342600E-01, 0.40223300E+00, 0.11531900E+00, -.17234100E-02, -.38270300E-01, 0.89574300E-01, -.56606400E+00, 0.11469700E+00, 0.24783900E+00, 0.59009400E-01, -.27062900E+00, -.26200400E+00, -.46876400E-01, 0.29185300E+00, -.59917000E+00, -.75871500E+00, -.13471600E+00, 0.41303000E+00, 0.27322900E-01, -.44459000E-01, -.14972000E+00, -.32557600E-01, 0.11885000E+00, 0.53560600E-01, -.62888800E+00, 0.25542100E-01, 0.24205100E+00, 0.11669300E+00, -.18744100E+01, -.17121800E+01, -.49345900E+00, 0.19734900E+00, 0.70282300E-01, 0.26048400E+00, -.27753200E-02, 0.94310400E-01, 0.75189600E+00, 0.23655800E+00, -.87027800E-02, 0.10114400E-01, 0.14331400E+00, -.14962400E+00, 0.19849600E-01, 0.12603200E+02, -.44031500E+01, -.19597200E-01, 0.23034200E+01, -.43786300E+01, 0.63002700E+01, -.44569100E+01, -.93856900E+01, 0.88837600E-01, -.19145300E+02, 0.37094200E+02, -.20514700E+02, -.38454300E+02, -.18680100E+02, -.21984000E+02, -.80428000E+00, 0.56814900E+01, 0.33078300E+02, -.61888600E+01, 0.92665100E+01, -.98042400E+02, 0.36108400E+01, -.83266400E+01, -.49062900E+02, -.21196000E+01, -.26178900E+01, 0.15240100E+02, -.46295500E+02, -.27076800E+02, -.63081500E+01, 0.14071600E+02, 0.99301700E+01, 0.56542800E+01, -.29681600E+01, -.96719600E+01, -.27471000E+01, 0.11796900E+02, -.95173100E+00, 0.12823700E+02, -.18993000E+00, -.72416900E+01, -.35826000E+01, 0.26173700E+02, -.19834200E+02, 0.79026400E+01, 0.98509500E+01, 0.99484000E+01, 0.49184700E+02, 0.36686800E+01, 0.54707400E+01, 0.12448700E+01, -.83079800E+00, 0.53760800E+00, -.12411300E+02, 0.17082300E+01, -.14808300E+01, -.59684100E+01, -.33410100E+01, 0.67783100E+01, -.24252900E+00, -.10096700E+00, 0.60558000E+01, -.88146900E+01, 0.10442000E+01, 0.24002900E+00, -.14296500E+00, -.25132200E+00, -.92431800E+01, -.18323000E-01, -.26806900E+01, 0.33853700E+01, 0.15272000E+01, 0.67861700E+00, -.26323900E+00, -.30148600E+01, -.32906200E+00, 0.65359600E+01, 0.32364700E+01, -.14610300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20423700E+02, 0.19775900E+01, 0.97896800E+00, 0.52326900E+01, 0.85420400E+01, -.59734800E+01, 0.28421300E+01, 0.11411400E+01, -.15549000E+01, 0.53272700E+01, 0.36055400E+01, 0.30948700E+01, 0.60470600E+01, 0.65835000E+01, -.80688100E+00, 0.35200300E+01, 0.87594100E+01, 0.29835200E+01, -.33222800E+00, 0.14995100E+01, -.58633900E+01, -.25646000E+01, 0.10603600E+01, 0.47405100E+01, 0.59564500E+00, -.91472100E+00, 0.26137100E+01, -.10443500E+02, -.33321900E+00, 0.14673400E+01, -.11244800E+01, 0.97991600E+00, 0.74313000E+01, -.25684100E+01, 0.67876500E+00, 0.80030600E+00, 0.24003400E-01, 0.22260200E+00, 0.24884900E+00, 0.37170700E+01, 0.15652000E+01, 0.10394800E+00, 0.44888900E+01, -.10351100E+01, 0.18685700E+01, -.97567100E-01, 0.22106300E+01, -.56245800E+01, 0.34856300E+01, 0.62882500E+00, -.46324600E+00, -.14504500E+01, 0.13819600E+01, 0.42552500E+01, 0.65750000E+01, 0.19464700E+01, 0.98341500E+00, -.26779100E+01, 0.20560900E-01, -.20893500E+01, -.92553100E+01, -.40718100E+01, 0.12187400E+01, -.48746300E+01, -.55875800E+00, 0.23007700E+01, -.13017000E+01, -.65309200E+01, 0.16081000E+01, 0.56709800E-02, 0.21732400E+01, -.25702900E+00, 0.24053000E+01, 0.36890400E+01, 0.29127300E+01, -.36143500E+01, 0.32615200E+00, 0.28953700E+01, 0.49363700E+00, 0.24110700E+00, -.69126000E-01, -.19365700E+01, 0.13027400E+01, -.10371100E+01, -.78643200E+00, 0.14195900E+00, -.81082400E+00, -.88465800E+00, -.46762500E+01, 0.20950600E+01, 0.90642800E+00, 0.46299200E-01, -.38294600E+00, -.17132500E-01, 0.10776700E+00, -.34901500E+00, -.33139900E+01, 0.21623600E+01, -.93243000E-01, 0.12419600E+01, -.30828300E+01, -.10868500E+01, -.13367000E+00, -.13502000E+01, -.15191200E+00, -.10452200E+01, -.12158600E+01, -.37261500E+00, -.48947600E+00, -.56401400E+00, 0.27546700E+01, 0.60494200E+00, -.14034900E+01, 0.11629400E+00, 0.80116500E+00, 0.55518400E-01, -.61381000E+00, -.36941900E+00, -.96815700E+00, -.20215700E+01, -.89942300E+00, -.11172900E+01, 0.28241100E+00, -.30334500E-01, -.19490200E+00, 0.55562600E+00, 0.27703900E+01, -.24985300E+00, -.19809600E+00, -.36991700E+00, -.12524000E+01, 0.59662700E+00, 0.79718000E+00, 0.54226200E+00, 0.11955100E+00, 0.23623100E-01, -.36120000E+00, -.16327100E+01, -.15147700E+01, 0.38507600E+00, -.35800100E+00, 0.36488400E+00, -.14938000E+01, 0.43673000E+01, 0.77988000E-01, 0.16730200E+01, 0.31471200E+00, -.65624000E-01, -.12741900E+01, 0.39583900E+00, -.49282400E+00, -.49051700E+00, -.72245900E+00, 0.30159100E+00, 0.33430100E+01, 0.23172800E+00, 0.41947800E+00, -.45316900E+00, -.31171800E+00, -.64601900E+00, -.53565200E+01, -.78453200E+00, 0.76481200E+00, 0.11299200E+01, 0.74355900E+00, -.50712900E+00, -.71492600E-01, -.42829600E-01, 0.25422900E+01, 0.81850500E+00, -.25103500E+00, 0.22704400E+00, -.48593100E+00, 0.23982400E+00, -.20181200E+01, 0.69891000E+00, 0.12175600E+01, -.32279900E+00, -.72082500E+00, 0.57070600E+00, -.12024800E+01, 0.27813800E+01, 0.16528200E+01, -.15686100E+01, 0.71200100E+00, 0.12334400E+01, 0.24678700E+00, 0.45276200E+00, -.69701100E-02, -.23326000E+01, 0.51406500E+00, -.22789500E+01, -.93604300E+00, 0.17806000E+01, 0.26497200E+00, 0.39656800E+01, -.43702700E+01, -.73949400E+00, 0.91330500E+00, -.82694100E-01, 0.10731700E+01, -.22410400E-01, 0.30558400E+00, 0.10953800E+01, 0.26962400E+00, -.60524800E+00, 0.50682900E+00, 0.30772100E+00, -.12968200E+01, 0.11255000E+01, 0.32833500E+00, -.18068300E+03, -.98473400E+00, -.26626900E+02, 0.28901500E+00, 0.71437800E+02, 0.61471600E+02, 0.10337300E+02, -.58520500E+02, 0.12051700E+03, 0.31395200E+03, -.16138800E+03, 0.15519200E+03, -.16427400E+03, -.11045500E+03, 0.23170700E+03, -.72533100E+02, 0.10749600E+03, -.38975200E+03, 0.16457500E+03, 0.16781600E+03, 0.30245400E+03, -.17255500E+03, -.18829100E+03, -.15450900E+03, -.15051900E+03, -.31164000E+03, -.30750100E+03, -.21903600E+03, -.20720000E+02, -.37631400E+03, -.73525600E+02, -.20014500E+03, 0.82432300E+02, 0.99599200E+02, 0.99428400E+02, 0.75910000E+02, 0.10153800E+03, -.60492100E+02, -.72424800E+02, 0.44685900E+02, 0.72563300E+02, -.11192800E+03, 0.53511300E+03, -.27170800E+03, -.27490900E+03, -.26589200E+03, 0.93410100E+00, 0.10877200E+03, -.15576100E+03, 0.34090800E+02, -.13305500E+03, -.67808800E+02, -.58977100E+02, 0.10585300E+01, 0.32166500E+01, 0.70814300E+02, -.11527000E+02, 0.38963300E+02, -.85176300E+01, 0.97002000E+01, 0.38618500E+02, -.44270300E+01, 0.28240800E+01, 0.19106100E+01, -.11859900E+02, -.52173000E+01, -.27076800E+01, -.19990200E+02, -.10563400E+02, -.20623700E+02, -.93006900E+01, -.66352000E+01, -.69735200E+01, 0.16075500E+02, 0.11225100E+02, 0.44314300E+02, -.17884800E+01, 0.31153200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.82395700E+01, 0.76377200E+00, 0.12182300E+01, -.43015100E+00, -.19715700E+00, -.46944900E+00, 0.54796600E+00, 0.27114600E+00, -.34215300E+00, 0.17307000E+01, 0.18143800E+00, 0.18760100E+01, 0.15809500E+01, 0.30329400E+00, 0.70276900E+00, 0.12152800E+01, 0.30913000E+01, 0.19227800E+01, -.13166600E+01, 0.12256200E+01, -.72774400E+00, -.25640900E+00, 0.43391000E+00, 0.15300800E+01, 0.25091000E+00, 0.42730500E+00, 0.62440100E-01, -.24853000E+01, 0.14649000E+00, 0.10757000E+00, -.14253100E+00, 0.13050000E+01, 0.10628500E+01, 0.38976500E+00, 0.19983400E+00, 0.42989100E+00, 0.30477600E-01, -.17414100E+00, 0.44534700E+00, -.24856000E+01, -.19788800E+00, -.69493900E+00, 0.10681400E+01, -.28635600E+00, -.58955100E+00, -.22881200E+00, 0.28306100E+00, -.71293900E+00, 0.15108500E+01, 0.22338600E+00, 0.95279500E+00, -.71887800E+00, -.54028600E-02, 0.12561400E+01, 0.12818100E+01, 0.25803600E+00, 0.31235200E+00, 0.20664700E-02, 0.99923900E-03, -.12545200E+01, -.63217000E+00, -.11049400E+01, 0.11918400E+00, 0.10008100E+00, 0.21371200E+00, -.84646600E+00, -.15244200E+00, -.14369700E+01, -.12387900E+00, 0.59558400E-02, 0.65887800E+00, -.85392300E-01, -.12860900E+01, 0.12443600E+00, 0.43236400E+00, -.11054400E+01, 0.67765800E-03, 0.10511000E+01, -.14054400E-01, 0.16725300E+00, -.53561400E-02, -.42365300E+00, -.25711800E-04, 0.29579100E+00, -.10707800E+00, 0.63850300E-01, -.21674400E+00, -.39448700E+00, -.38309900E+00, 0.19471500E+00, 0.56749000E+00, 0.39147000E-02, 0.93765500E-01, -.14419400E+00, -.12420800E+01, 0.19172300E+00, 0.56039300E+00, -.12062600E-01, 0.32117700E+00, -.12990000E+00, 0.23297200E+00, 0.73681300E+00, 0.78107100E-02, 0.27473400E-01, 0.45739200E-01, 0.37571900E+00, 0.85890500E-01, -.21277700E+00, -.60108900E-01, -.19093400E+00, -.36779700E+00, 0.28841600E-01, 0.25606100E+00, -.87643700E-02, 0.10987900E+00, -.71159600E-01, -.26648100E+00, -.46739000E-01, 0.15957700E+00, 0.24912900E+00, -.76117500E-01, -.29197400E-02, 0.74756900E-02, 0.13371100E-01, 0.11147600E-02, 0.21017700E+00, -.14977200E+00, 0.40977400E-01, 0.33289300E-01, 0.86910100E-01, 0.59096000E+00, -.13086000E+00, -.43963700E+00, 0.12917100E+00, -.12535600E+00, -.33592600E-01, -.23292500E-01, -.37845800E+00, 0.46962200E+00, -.36451700E+00, 0.21625500E+00, -.12492600E-02, -.39599800E-01, -.14633200E+00, 0.14612100E-01, -.73542500E-01, 0.12352100E-01, 0.42189200E-01, 0.84007500E-01, -.52141000E+00, 0.69544000E-01, -.23009100E-01, 0.24527200E-01, -.89821000E-01, 0.34580400E-01, 0.61481500E-01, 0.47663500E-01, 0.10736000E+00, -.53865900E-01, 0.14132900E+00, -.35365000E+00, 0.57067400E-01, -.11626800E+00, 0.61419600E+00, 0.21412000E+00, -.78894400E-01, 0.43477000E-01, -.41021600E-01, -.25033100E+00, 0.18793200E+00, -.10828000E+00, 0.64704600E-01, -.50791800E-02, -.89002500E-01, 0.41100700E-01, -.33864700E+00, 0.16882900E+00, 0.26388700E-02, 0.38428600E-01, -.70634400E-01, 0.28871200E+00, 0.25859200E+00, -.87647400E-01, -.13147000E+00, 0.94341700E-01, -.10134100E+00, -.15487100E+00, -.69483600E-01, 0.27994500E-01, 0.48659600E+00, -.43053100E-01, -.53635700E+00, -.23548600E-01, -.19768200E+00, 0.12433300E+00, 0.15744000E+00, -.60980300E+00, -.22604000E+00, 0.21442400E+00, -.71384700E-01, 0.95100500E-01, 0.43976600E-02, 0.16964300E-01, 0.93139200E+00, 0.18577300E+00, -.98252700E-01, -.85557200E-02, 0.27345100E-01, -.14850800E+00, -.36210800E-01, 0.14954300E-02, 0.15101800E-02, 0.33555500E+01, 0.17638500E+01, -.12383600E+01, 0.23336000E+01, 0.84893100E-02, -.59468900E+01, 0.13864500E+01, -.12459100E+02, 0.24643100E+02, -.13391400E+02, -.22038800E+02, -.11826300E+02, -.14381200E+01, 0.78954100E+01, -.21087600E+01, 0.95161700E+01, -.15550300E+02, 0.97632400E+01, -.41990800E+02, -.15562300E+01, 0.10517900E+01, -.19838000E+02, 0.12754900E+01, -.34643900E+00, 0.43264800E+01, -.10163900E+02, 0.87108400E-01, 0.19528200E+01, 0.52782200E+01, -.43908900E+00, -.43451700E+01, 0.17461600E+01, -.49117300E+00, 0.23909500E+01, 0.33936700E+01, 0.10429100E+01, 0.17831100E+01, -.29764100E+01, 0.30831700E+01, -.13317100E+01, 0.17377000E+02, 0.15362400E+02, -.76715300E+01, -.53575900E+01, -.78951300E+01, 0.12365100E+02, 0.69349300E+01, -.90686800E+01, -.25939300E+01, -.57430100E+01, 0.39078800E+01, -.67676800E+01, 0.98098500E+00, -.24109700E+00, -.29440900E+01, -.12618600E+01, 0.10189200E+01, -.42909600E+00, 0.35820800E+00, 0.10981200E+01, -.29421100E+01, -.43325900E-02, -.50842800E+00, 0.32559000E+00, -.59180100E+00, -.31699000E+01, -.11447300E+00, -.10901900E+01, 0.13596800E+01, 0.12414600E+00, 0.68232000E-01, 0.32830400E+00, -.16744900E+01, 0.15784500E+00, 0.22737900E+01, -.62439800E+00, -.35947900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.94907500E+01, 0.12802900E+01, 0.29978800E+01, 0.28245700E+01, 0.39423700E+01, -.78567500E+00, -.10907800E+01, 0.15024300E+00, -.73496700E+00, 0.20623200E+01, -.14125500E+01, 0.36014900E+01, 0.19594700E+01, -.53529400E+01, 0.51923500E+00, 0.76765800E-01, 0.10084600E+01, -.11162600E+01, 0.53235400E+00, -.13917900E+00, -.38076200E+00, -.90776800E-01, 0.49355600E+00, 0.11595600E+01, 0.43597800E+00, -.67925100E-01, 0.27267500E+01, -.64748100E+01, -.31927700E+01, 0.11762900E+01, -.66123400E-01, -.45058600E+00, 0.29243400E+01, -.73247800E+00, 0.47892500E+00, 0.20474600E+00, 0.12605600E+00, -.65087700E-01, -.12596400E+01, -.41278300E+00, -.52754500E+00, 0.31733400E+00, -.63328500E+00, -.30728500E+00, 0.13035300E+01, -.17531800E+00, -.97043100E+00, 0.11598200E+01, 0.28166500E+01, 0.21665200E+00, 0.69172600E+00, -.10833200E+01, 0.97948100E+00, 0.92754200E+00, -.13567800E+01, 0.62888800E+00, 0.65410500E-01, -.17480900E+00, 0.40303400E+00, 0.28336700E+00, 0.99624900E+00, 0.21255100E+00, 0.12410600E-01, 0.38554500E+00, -.17114400E+01, -.75481000E+00, -.41308200E+00, -.16690600E+01, 0.56732800E-01, 0.45328500E-02, -.75953800E+00, 0.11058200E+00, -.20503600E+01, -.13525300E+01, 0.13214900E+01, -.18619900E+01, 0.55925900E+00, 0.18630300E+01, 0.25133000E+00, 0.37340200E+00, 0.65685700E-02, -.23240300E+01, -.20164300E+00, 0.42583400E+00, -.91196300E+00, 0.29040000E+00, -.17403000E+01, -.18481900E+01, -.15083500E+01, 0.70784400E+00, 0.53156300E-01, 0.16183700E-01, 0.65665900E+00, -.23632700E+00, -.15133400E+01, 0.35039200E+00, 0.11477200E+01, 0.13248300E+00, 0.45142800E+00, -.61515800E+00, 0.76164200E+00, 0.13187300E+01, 0.28935000E-01, 0.27934300E+00, 0.14883400E+00, 0.13496300E+00, 0.25809100E+00, 0.67091100E-01, -.47859000E+00, 0.29579600E+01, -.36159300E+00, 0.60243700E-01, -.20594100E+00, -.94699400E-01, 0.57426400E+00, -.25363900E-01, -.85618900E-01, 0.33741500E+00, -.35542100E+00, -.44954600E+00, -.79637000E-01, -.11713800E+00, 0.82032100E-01, -.23906600E+00, 0.30290800E-01, 0.36057500E+00, -.69470500E-01, 0.24522800E+00, -.12687000E+00, -.12586400E+00, -.12440000E+01, 0.12176300E+01, -.35141500E+00, 0.14139700E+01, -.28848400E-01, -.59982200E-01, 0.23778100E+00, -.22346300E+00, 0.35977800E+00, -.95803900E-01, -.75180700E-01, -.33136700E+00, 0.43124800E-01, -.76106200E+00, 0.20623300E+00, 0.11892800E+00, -.61842800E-01, -.55621600E-01, -.89395500E+00, 0.19957200E+00, 0.86512400E+00, 0.92959400E-01, -.30330700E+00, 0.30238500E-02, -.52904800E-01, 0.93419300E-01, 0.15788300E+00, 0.10916400E+00, -.25072500E+00, -.26843000E+00, -.11041200E+01, 0.14175500E+00, 0.95593700E+00, 0.77962800E+00, -.14098600E-01, -.81508700E+00, -.17686400E+00, 0.20314800E+00, 0.21045300E+01, 0.61849700E+00, 0.48368700E-01, 0.61651900E+00, -.29678300E+00, -.38882800E+00, -.10788900E+01, 0.19212900E+00, -.33171900E-01, -.22719000E+00, -.47411500E+00, 0.31630700E-02, -.59635400E+00, -.13064100E+01, -.32673300E+00, -.58815500E+00, -.18219700E+00, -.50407300E+00, 0.11632100E+00, 0.47386300E+00, -.98778800E-01, -.74966600E+00, -.16825900E-01, 0.96371900E+00, 0.10655900E+01, 0.13300900E+01, -.67088700E+00, -.24624500E+01, 0.11624900E+01, 0.28812900E+00, 0.10891100E-04, 0.93069500E-01, 0.36060700E+00, -.62297200E-02, 0.23287400E+00, -.41485000E+00, -.76502900E+00, 0.55256000E-03, -.17220700E+00, -.48977900E+00, 0.77665200E+00, 0.11666000E+00, 0.17811900E+00, -.18461900E-01, -.84797400E-01, -.40368900E+02, -.16807400E+02, -.74284000E+01, -.12588600E+02, -.28651300E+01, -.26799200E+02, 0.60954900E+02, 0.68257300E+02, -.10680000E+02, -.33283200E+02, -.34285400E+02, 0.50746900E+02, -.29387900E+02, -.59693400E+02, -.38619500E+02, -.52969900E+02, -.49251700E+02, 0.11015200E+03, 0.16112300E+03, -.79759700E+02, 0.16316600E+03, -.83435200E+02, -.71726800E+02, -.28935400E+02, 0.77583100E+02, 0.78695100E+02, -.58887500E+02, -.22029300E+02, -.11455100E+03, 0.72277200E+02, -.75664700E+02, -.28690100E+01, -.36413300E+02, -.40578900E+02, -.22003000E+02, 0.13037400E+01, 0.27893400E+02, 0.23845700E+02, -.18667400E+02, -.52633200E+02, -.19577400E+02, 0.12551300E+02, -.36751700E+02, 0.10305400E+02, -.91172100E+02, 0.12583000E+02, 0.14299900E+02, 0.68656800E+01, -.20470800E+02, 0.47834800E+02, 0.79715300E+02, -.71859200E+01, -.26694000E+01, 0.10555400E+02, 0.53728200E+01, 0.41317700E+02, -.49021500E+01, 0.22928000E+01, 0.40606300E+02, -.13383600E+02, -.93568600E+00, -.28231600E+01, -.19425000E+01, 0.14462400E+01, -.12792900E+02, -.32911200E+01, 0.38933800E+01, -.62289700E+01, 0.40575600E+00, 0.63953100E+01, -.15075200E+01, 0.20536200E+01, 0.63441300E+01, 0.99960800E+01, -.62019900E+01, -.20940200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.99011300E+01, 0.12110100E+01, 0.30847000E+01, 0.66739300E+01, 0.62564800E+01, -.44680500E+01, 0.16810400E+01, 0.29213000E+00, -.11259700E+01, 0.32194900E+01, 0.15104500E+01, 0.14496600E+01, 0.16022700E+01, 0.31013900E+01, -.78260000E-01, 0.18577000E+01, 0.42862500E+01, 0.70316700E+00, 0.31174200E+01, -.15816900E-01, -.34501800E+01, -.49531900E+00, 0.15138500E+00, 0.43564500E+01, 0.41531500E+00, 0.21853700E+00, -.29902000E+01, 0.17300800E+01, -.23069200E+01, -.90874500E+00, 0.62455800E+00, -.41946100E+00, -.26478100E+00, 0.10178200E+01, -.30849800E+00, -.65101600E+00, -.66722200E-01, 0.31832500E+00, -.25374600E+00, 0.84846700E+00, 0.10039500E+01, 0.81069900E+00, -.55825600E+01, -.83593700E-01, 0.12932500E+01, -.24504700E+00, 0.17031700E+01, -.19198600E+01, 0.81907400E+00, 0.11524500E+00, -.84397900E+00, -.37289500E-01, 0.97310100E+00, -.50092200E+00, -.11126900E+01, 0.15866100E+01, 0.40122100E-02, -.67718200E+00, 0.67579300E-03, 0.24731700E+01, -.14994600E+01, -.36337400E+00, 0.48461400E+00, -.13641500E+00, -.49390300E+00, 0.54925500E+00, -.11010200E+00, -.21389800E+01, 0.18636800E+00, 0.40285900E-02, -.29258900E+00, -.30664100E+00, 0.21600000E+01, -.11236500E+01, 0.17966700E+01, -.19387800E+01, 0.54344600E+00, 0.78713600E+00, -.13412200E+00, -.25058600E-01, -.43395900E-02, -.25714100E+01, 0.89812200E+00, -.77008800E+00, -.10601700E+01, 0.26386000E+00, -.49742700E-01, 0.23004500E+00, -.86514700E+00, 0.45107300E-01, -.44152200E+01, 0.74475200E-02, -.15699600E+00, -.36008800E+00, 0.10470400E+01, -.30878000E+00, -.25724400E+01, 0.38391700E+00, -.49232300E-01, -.53646800E-01, -.10847900E+01, 0.29005300E+00, -.55356700E-01, 0.14104900E+00, -.60787300E+00, -.80172400E+00, 0.53603400E+00, -.11326300E+00, 0.69800000E+00, -.14213100E+01, -.20435000E+00, -.21915100E+00, 0.38398000E+00, 0.80097300E-01, -.16852700E+00, 0.65963700E-01, 0.25111300E+00, 0.21411900E-01, -.10424900E+01, -.26085900E+00, 0.23394100E+00, 0.11632000E+00, 0.37329500E-01, -.33537500E+00, -.31241000E-01, 0.11954200E+00, 0.28189000E+00, -.11336600E+00, 0.88610300E-01, 0.35483700E-01, 0.33480200E+00, 0.68499300E-01, -.41899700E+00, -.17245600E+01, -.84507900E-01, 0.12658700E-01, -.27009800E+00, -.44130300E+00, -.86132500E-01, -.32156700E+00, 0.61445700E-01, 0.67057200E+00, 0.28178300E+00, -.81711700E+00, 0.63069800E-01, 0.55108400E+00, -.84794000E-01, -.38677700E-01, -.38705500E+00, -.13797900E+01, 0.22171700E+00, 0.13938900E+00, 0.12717700E+00, 0.57394200E-01, -.97536800E+00, 0.13015500E+00, -.16387900E-01, 0.61260900E-01, 0.36324600E-01, -.35125900E+00, -.28390600E+00, 0.14397100E+00, 0.34049700E+00, -.92766600E+00, 0.75183500E-01, -.24568800E-01, 0.25688800E-01, 0.80075900E-02, 0.25358000E-01, 0.10130400E+00, 0.87885600E-01, -.55186900E-01, 0.22984300E+00, -.10570400E+01, 0.54684800E+00, 0.71157900E+00, 0.48163700E+00, -.16712600E+00, 0.88783900E-01, -.73643100E-01, 0.26093800E+01, -.12405000E+01, -.38965700E+00, 0.38909700E+00, -.61413300E+00, -.40432400E+00, -.36789300E+00, -.19522700E+00, 0.63030700E-01, -.42924600E+00, -.30946400E-01, -.21143700E+00, 0.10618500E+01, -.10269300E+01, 0.27202400E+00, -.24525800E+01, -.76228600E+00, -.47231800E+00, 0.17094300E+00, -.13485200E+00, -.83599600E-01, 0.84078200E-02, -.18923300E+00, 0.46588900E+00, 0.63289300E+00, -.34037300E+00, 0.24219200E+00, 0.10574800E+00, -.48790700E+00, 0.18390700E+00, -.92833100E-01, -.87838700E-03, 0.32587600E-01, -.90780400E+00, 0.28908100E+02, -.43498700E+01, 0.20224100E+02, 0.12450800E+02, 0.21277800E+02, 0.69075500E+02, -.31259500E+02, 0.28961500E+02, 0.11182600E+03, 0.14900000E+02, 0.34331800E+01, 0.44707900E+02, 0.15385600E+02, 0.19138300E+02, -.11850500E+01, 0.48713600E+02, 0.78671400E+02, 0.15710200E+03, -.93781600E+02, 0.19268800E+02, -.79967500E+02, -.60527200E+02, -.13341300E+03, 0.47723400E+02, 0.85771600E+01, -.41047700E+01, -.14006500E+03, -.10370700E+03, -.25014600E+02, -.74413800E+01, 0.11749300E+02, 0.12621000E+02, 0.10251800E+02, 0.15438800E+02, -.12939900E+02, 0.89026500E+01, 0.18575100E+01, 0.10862400E+02, -.36857300E+02, 0.13217800E+03, -.64333100E+02, -.62117800E+02, -.65845800E+02, -.14063100E+02, 0.21230100E+02, -.38236600E+02, 0.18079600E+02, -.23871400E+02, 0.85766600E+01, -.65218200E+02, -.80538500E+00, 0.73681700E+01, 0.44045300E+01, 0.22385200E+01, 0.19732200E+02, 0.57443700E+01, -.61171000E+01, 0.19882700E+02, -.10111900E+02, -.29664300E+01, -.12405100E+01, 0.13274100E+01, -.10536300E+01, -.94253000E+01, 0.14425300E+01, 0.17438100E+01, 0.81278900E+01, -.52188700E+01, -.72004700E+01, 0.80405700E+01, 0.11891900E+01, -.57210700E+00, 0.21474400E+01, 0.10757800E+01, 0.50564200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30518700E+01, -.18060100E+00, 0.15787400E+01, -.25840600E+01, -.24126400E+01, 0.15612000E+01, -.12378800E+00, -.11671800E+00, 0.47378800E+00, -.60209400E+00, 0.19353900E+00, -.84802200E-01, -.54376400E+00, 0.81119900E+00, 0.30206800E+00, 0.32375200E-01, 0.29102900E+00, 0.10331900E+01, -.26423700E+00, 0.64122100E+00, 0.11946200E+01, 0.38432000E+00, 0.12933200E+00, -.12786900E+01, -.27227700E+00, -.10427200E+01, -.29007700E+00, -.43436700E+00, 0.50510500E+00, -.44284900E+00, -.33086100E-01, -.40430700E+00, 0.32860200E-01, 0.30907300E+00, -.17642800E+00, -.29556500E+00, -.23443600E-01, 0.15469000E+00, -.39861300E+00, 0.13704100E+01, 0.19691800E+00, 0.66637200E+00, -.66595900E+00, -.52022500E-01, 0.20323200E+00, 0.11042800E+00, -.72724600E-01, 0.40552500E+00, 0.40294800E-01, -.12705200E-02, 0.25717100E+00, 0.22911400E+00, 0.36290000E+00, -.37918100E+00, 0.32128000E+00, -.10786300E+00, 0.50611000E-01, -.10245800E+00, 0.76007300E-03, 0.56331600E+00, -.53875800E+00, -.10543600E+00, -.69864100E-01, -.21755900E+00, 0.13386400E+00, -.10993800E+00, 0.40351900E-02, -.26636900E+00, 0.15029700E+00, -.23719400E-02, -.90591100E-01, -.21903600E+00, -.66497900E-01, 0.48490500E+00, -.40883000E+00, -.17333100E-01, -.49907000E-01, -.17027500E+00, -.47404600E-02, 0.46029300E-01, -.11916100E-02, 0.97496000E-01, 0.75871900E-01, 0.99505600E-01, -.42183500E-02, -.60114200E-01, -.20994300E+00, -.32147400E-01, -.86604000E-01, 0.20339900E-01, 0.41414700E+00, 0.12044600E-01, 0.28457500E-01, 0.13205100E+00, -.21083400E-01, 0.45137900E-01, -.40360700E+00, 0.14163000E+00, -.14358300E+00, 0.12622500E+00, -.21852200E+00, 0.70754700E-01, 0.14678600E-02, -.61760700E-01, 0.86609400E-01, -.10191300E+00, -.35547900E-02, 0.66878000E-01, -.27486500E-01, 0.35250800E+00, -.58860800E-01, 0.69198500E-01, -.84318500E-01, 0.40945800E-02, 0.19018200E+00, 0.74729500E-02, 0.15450000E+00, -.61874900E-01, -.11545800E+00, -.15424800E+00, -.87925000E-01, -.10537500E+00, 0.49324900E-01, -.13200600E+00, -.29349800E-01, -.24226000E+00, 0.19597700E+00, 0.15945900E-01, -.70612400E-01, 0.12649400E+00, -.29987800E+00, 0.34734800E+00, -.16807400E+00, -.16585200E+00, -.15998500E+00, -.22532400E-01, 0.44047000E+00, -.33695700E+00, 0.73815200E+00, -.13246100E+00, -.72083400E-01, 0.14818300E+00, 0.15846000E+00, 0.26566700E+00, 0.71683300E-01, -.33149100E+00, 0.37438300E-01, -.89627900E-02, 0.24513200E+00, 0.38502600E-01, 0.12608100E+00, -.28027600E-01, -.40721600E-01, -.14458100E+00, 0.22975000E+00, -.10719100E-01, 0.18450400E-01, 0.21204700E-01, -.13431200E+00, -.20978400E+00, 0.34670700E-01, -.34965100E-01, 0.48389500E-01, -.16553900E+00, 0.23650000E+00, 0.44901200E-01, 0.73563000E-03, -.56559200E-01, -.19134000E+00, 0.21432400E+00, -.52801400E-01, -.20681000E-01, -.33068800E-02, -.17026200E+00, -.11097200E+00, 0.34982900E-01, 0.57506100E-01, -.78505600E-01, 0.77430700E-02, 0.45592900E-03, 0.19838500E+00, -.65643300E+00, -.24915600E+00, -.10602200E+00, 0.93641500E-02, -.21028500E+00, -.25867800E-01, 0.26147100E-01, 0.11356000E-01, 0.27662500E+00, 0.10248800E-02, -.37937200E+00, 0.46361800E+00, -.45631800E+00, -.73408600E-01, 0.10658300E+01, -.43441300E-02, 0.10599100E+00, 0.12807200E+00, 0.18370300E-01, -.78123200E-01, 0.33833100E-02, -.18489100E-01, 0.81229500E-01, 0.36951000E-01, -.21953400E-02, -.11127300E+00, -.58038100E-01, 0.35992300E-01, -.97491400E-01, 0.32539700E-01, -.56946900E-02, 0.28608200E-01, 0.19465600E+00, -.47378500E-01, -.10735200E+02, -.76598500E+01, 0.85296100E+00, 0.39947500E+01, -.13472900E+02, -.22016500E+02, 0.84774200E+01, 0.31816200E+02, 0.11446600E+02, -.68637700E+01, 0.46996500E+01, -.14846700E+02, -.25051700E+02, 0.29895500E+02, 0.53362800E+00, -.63337200E+01, -.49870400E+01, 0.16767700E+01, -.98614800E+01, 0.37476000E+01, 0.18972600E+02, 0.14056600E+02, 0.70377200E+01, 0.55172500E+01, -.18275600E+01, 0.14215500E+02, -.50518400E+01, -.31997800E+02, 0.23378900E+02, 0.91645300E+01, 0.16019700E+02, 0.12764700E+02, 0.83331800E+01, -.65463300E+01, -.10755500E+02, -.87542500E+01, 0.12149100E+02, 0.25252200E+02, -.45112700E+01, 0.12151900E+01, 0.82951100E+01, 0.20013900E+01, -.78122000E+01, -.11680000E+02, 0.85267200E+00, 0.52753200E+00, 0.85538000E+01, -.53874200E+01, -.93078900E+01, -.15953300E+01, 0.78369200E+00, 0.41714600E+00, 0.11550700E+01, -.92746500E+01, 0.95777600E+00, -.36337100E+00, -.91163200E+01, 0.80167500E+01, -.11979000E+00, -.62503100E+00, 0.22926900E+00, 0.59431300E-01, 0.81103600E+01, 0.11448300E+01, 0.15339100E+01, -.13375000E+01, -.73610100E+00, -.50111300E+00, 0.78907700E+00, -.17595900E+01, -.27233400E+01, -.72395000E+01, -.32868500E+00, 0.14398100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12005500E+02, -.14588400E+01, 0.47143700E+01, 0.35688200E+00, -.97632700E+00, 0.20522100E+01, -.87733900E+00, -.84104500E-01, 0.68386300E+00, 0.65700400E+00, 0.35161200E+00, -.17112500E+00, 0.47334200E+00, 0.88050600E+01, -.14434900E+01, 0.13718700E+00, 0.28098200E+01, 0.39215600E+01, 0.93453000E+00, 0.70255800E+00, -.25270400E+01, 0.39978200E+00, -.59938000E+00, 0.10695500E+01, -.61150200E+00, -.20329500E+01, -.40921900E+01, -.25404500E+01, 0.10565800E+01, -.10278700E+01, -.17516700E-01, -.70260800E+00, 0.99834300E+00, 0.10805400E+01, -.44109500E+00, -.16410900E+01, -.15395100E+00, 0.95784800E+00, -.18678700E+01, 0.83253100E+00, 0.21397300E+00, 0.91481500E+00, -.67141900E+00, -.29785500E+00, -.72733200E+00, -.28423200E+00, -.18629000E+00, 0.12304900E+01, 0.14377800E+01, 0.97448100E-01, 0.16998200E+01, -.62488000E+00, 0.79413700E+00, -.20390800E+01, -.98356500E+00, -.22055200E+00, -.33021200E+00, 0.64558000E+00, 0.75636800E-02, 0.19082000E+01, 0.14443900E+01, 0.98453500E+00, -.56760700E-01, 0.80958100E+00, 0.24963600E+00, -.11655700E+01, 0.45007100E+00, 0.27543000E+01, -.34878100E+00, -.25985100E-01, -.19648400E+00, -.54648100E+00, 0.14147600E+01, -.34428700E+00, 0.74872700E+00, 0.31649400E+00, -.26269300E+00, 0.44847800E+00, 0.31535200E-01, -.43258600E-01, 0.43242900E-01, -.50688900E+00, -.60060800E+00, -.58603900E+00, -.51325100E+00, -.10115000E+00, 0.36229500E+00, 0.27262600E+00, -.82913500E+00, 0.68449000E+00, -.37849900E+01, -.50809400E-03, 0.10731200E+01, -.61641000E+00, 0.12224200E+01, 0.19751700E+00, -.60688300E+00, 0.15495600E+00, -.67314000E-01, 0.63124100E+00, 0.58302000E+00, -.36959800E+00, 0.10593200E+00, 0.75076800E+00, -.67097800E+00, -.44079800E+00, 0.79690300E+00, 0.47012800E+00, 0.35392800E+00, -.31975400E+00, 0.32549200E+00, -.48727300E+00, 0.84517000E-01, 0.96476900E-01, -.31164800E+00, 0.88795000E-01, 0.19864600E+00, 0.22895400E+00, -.15765200E+01, -.96079900E+00, -.71753100E-01, -.90834900E-01, -.10472400E+00, -.31585500E+00, -.23354500E-02, 0.12983600E+00, 0.52452800E+00, 0.15212300E+00, -.38529900E+00, 0.85605200E-02, -.89599200E+00, 0.18105900E+01, -.15700800E+01, -.24503200E+00, 0.48662700E-01, 0.62558700E-01, -.10139800E+00, -.79241300E+00, -.38182700E+00, -.73128400E+00, -.80906100E-01, 0.38189600E+00, -.21026400E+00, -.16087700E+01, 0.32729900E+00, -.12974000E+01, -.47601700E-01, -.13342200E+00, -.42103200E+00, 0.10756200E+01, -.34172900E+00, 0.15944600E+00, 0.75353900E-01, 0.17033700E+00, 0.27041900E-01, 0.72517700E-01, -.10500000E-01, -.21943300E+00, 0.34584500E+00, 0.12305400E+01, 0.26398300E+01, -.41844100E-01, -.13494900E+01, -.23583000E+01, -.31788800E+00, 0.10662200E+01, 0.21213500E+00, -.18395100E+00, -.13392700E+01, 0.15134400E+00, 0.50010900E+00, 0.43193900E-01, 0.40423600E+00, -.44688000E+00, 0.51409800E+00, 0.10973900E+01, -.89710300E-01, 0.14764300E+00, 0.90090900E-01, -.19471200E+00, 0.10798500E+01, -.33296000E+00, 0.11661000E+01, 0.11969400E+01, 0.62486800E+00, 0.87441400E+00, 0.37337300E+00, 0.28759300E+00, 0.17147900E-01, -.15145900E+01, -.11842900E+00, 0.58181200E+00, -.62384300E-01, -.53327600E+00, 0.71482900E+00, -.22173100E+01, 0.10955500E+01, 0.23413000E+00, -.12234300E+01, -.62012700E-02, 0.41787400E-01, -.11192300E-02, 0.11384900E+00, -.55548000E+00, -.62454700E+00, 0.35534200E-01, 0.28569800E+00, 0.47076400E+00, 0.80507800E-01, 0.53130600E+00, -.65042100E-01, 0.11269500E+00, -.39829700E-01, -.56973700E+00, -.82267900E+00, 0.15191700E+00, 0.44600000E+02, 0.25458600E+02, -.24171200E+02, 0.14143200E+03, -.12794700E+03, 0.10198900E+03, 0.12343500E+03, 0.63040700E+02, 0.68938200E+02, -.29291900E+02, -.14807400E+02, -.83155600E+02, -.23994800E+02, -.53912600E+02, 0.24362500E+03, 0.20143000E+03, -.10893700E+03, 0.45619200E+03, -.10460000E+03, -.10408100E+03, -.11734500E+03, 0.97843400E+02, 0.11023100E+03, -.27405000E+02, -.13942200E+03, -.17484300E+03, 0.53997400E+02, -.81142300E+02, -.12631100E+02, -.27421200E+02, -.22426200E+02, -.96081400E+01, -.12996900E+02, 0.25599900E+02, 0.17480500E+02, -.53036100E+01, -.74700300E+02, 0.20397100E+01, 0.66995900E+01, -.47917700E+02, -.22872600E+00, -.12091400E+03, 0.22240000E+02, -.23460900E+02, -.30529300E+02, 0.60784400E+01, 0.53208200E+02, 0.12480200E+03, -.99687200E+01, 0.10744600E+01, 0.15163400E+02, 0.91891900E+01, 0.64472900E+02, -.27736200E+01, 0.63555400E+00, 0.64064400E+02, -.33245100E+02, -.33431700E+01, -.44395600E+01, -.14786900E+01, -.95214700E+00, -.31256600E+02, -.13594600E+00, 0.79454400E+01, -.24033900E+01, -.58732700E+01, 0.20433700E+01, 0.37422800E+01, 0.13667300E+02, 0.78192500E+01, 0.14404400E+02, -.55884900E+01, 0.20081900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45460000E+01, 0.42868800E+00, -.20184000E+01, 0.55902200E+00, -.21794100E+01, -.24499500E+01, 0.28478400E+01, 0.51289400E-01, -.30202000E+00, 0.21079100E+01, -.22127400E-02, 0.86384400E-01, -.69964400E-01, -.45510800E+00, 0.14124400E+00, 0.20526500E+01, -.52817000E-01, -.13740500E+01, -.42705300E+00, -.13035800E+01, 0.48613000E+00, -.39439800E+00, -.36961600E+00, -.13793900E+01, 0.23196900E-01, 0.88674800E+00, 0.21101500E+01, -.17199600E+01, -.99806300E+00, 0.16729500E+01, -.14807100E+00, 0.13283000E+00, 0.88857500E+00, 0.64182900E-01, 0.47884500E-01, 0.41278000E+00, 0.48690400E-01, -.18994500E+00, -.51510300E+00, -.23045300E+01, -.11377900E+01, -.81307700E+00, -.24097700E-01, 0.27914700E-01, 0.53276500E-01, -.32794500E+00, 0.33979600E+00, -.10467200E+01, 0.13795600E+00, 0.38880200E-01, 0.39708800E+00, 0.45815200E+00, -.15235900E+00, 0.18794200E+01, 0.34173800E+00, 0.21057000E+01, 0.45475500E+00, -.62148700E+00, 0.41655100E-02, 0.66907000E+00, -.32118500E+01, -.43749300E+00, 0.65381400E-02, -.82378700E+00, -.13919000E+01, -.12772100E+00, -.35332000E+00, -.19676600E+01, 0.20261200E-02, 0.50285600E-02, 0.43968200E+00, 0.58484700E+00, 0.37614200E+00, 0.90994700E+00, -.35691500E+00, -.13381300E+01, 0.41178300E+00, 0.14638600E+00, -.63842700E-01, 0.50540100E+00, -.52429100E-01, -.14819400E+01, 0.82046700E+00, 0.26193600E-01, -.28561700E+00, -.17636500E+00, 0.37469500E-01, -.57333000E+00, -.10104800E+01, 0.57449000E+00, 0.13195500E+01, 0.42945200E-01, 0.70724000E+00, -.14123400E+00, -.16793700E+00, -.37201600E-01, -.65009400E-01, 0.12846300E+00, -.40832600E+00, -.29971300E+00, 0.11118800E+00, -.32612100E+00, 0.10067400E-01, -.11236600E+00, 0.12263600E+00, -.67198000E-01, -.48302900E+00, 0.16023900E+00, -.27457200E+00, 0.76133200E+00, 0.25043300E+00, 0.14960300E+00, 0.22366600E+00, 0.37425700E-02, -.92969200E-02, -.56626500E-01, -.38408200E+00, -.27826200E+00, -.90549300E-03, 0.37144400E+00, 0.86359800E-01, 0.32354100E+00, 0.57409700E-01, 0.14302700E+00, 0.15283200E-01, -.23654900E+00, -.18348200E-01, -.11666900E+00, 0.98392800E-02, -.22090200E-01, 0.13335100E+00, -.16430800E+00, 0.65358500E-01, -.74203600E+00, 0.97791600E-02, -.20194900E-01, 0.60075800E-01, 0.18627000E+00, 0.15999400E-01, -.26823000E-01, -.41959200E-01, 0.32147000E-01, -.16835100E+00, -.18576000E+00, -.10552300E+00, -.53143100E+00, 0.97744400E-02, -.46565700E-01, 0.95136400E-01, -.15349100E+00, 0.22236500E+00, -.24216700E-01, -.83519300E-01, -.15831100E-01, 0.33785700E+00, 0.14685300E-01, 0.63131600E-01, 0.30745100E-01, -.14422600E+00, -.15215500E+00, -.48667400E+00, 0.36618500E-01, 0.59432500E+00, 0.40835200E+00, 0.18838500E+00, -.57764300E+00, -.19506300E+00, -.23465800E-01, 0.32907900E+00, 0.43455100E+00, 0.57635200E-01, 0.16400100E+00, -.51402800E-01, -.13303800E+00, -.83357600E-02, 0.59700500E+00, 0.83489100E-01, -.32402300E-01, -.74400900E-01, 0.10022200E+00, -.29067800E+00, -.96139200E+00, -.67277700E+00, 0.23834800E+00, -.23154600E+00, -.10609200E+00, -.11251200E+00, -.20215800E+00, 0.57219600E-01, 0.39697000E+00, 0.10181200E+00, 0.25086500E+00, 0.48602600E+00, -.15014200E-01, -.42374600E-01, 0.10161700E+01, 0.99351200E+00, 0.36270500E+00, -.26363100E+00, -.34041000E-01, -.16530800E+00, -.55828100E-02, 0.12493300E+00, -.42399200E+00, -.32259700E+00, 0.10682700E+00, 0.10333500E+00, 0.23387800E+00, -.55940500E+00, 0.25303300E+00, 0.10865400E-01, 0.22566300E+00, -.11357000E-01, 0.44686500E+00, -.10410900E+00, 0.39806300E+00, 0.41783300E+00, -.14882100E+02, 0.17041000E+02, -.17609500E+02, 0.72737300E+02, -.55267300E+02, -.98967900E+02, -.36600300E+02, -.55320100E+02, 0.95188100E+01, 0.27795100E+02, 0.59793500E+02, 0.63008000E+01, 0.15172200E+02, -.29071600E+02, -.78149800E+02, 0.51781900E+02, -.22522700E+03, 0.41972800E+02, 0.51847500E+02, 0.13734000E+02, -.24635400E+02, -.34852900E+02, 0.28636600E+02, 0.22510100E+02, 0.73524800E+02, -.39842900E+02, 0.51468300E+02, 0.32393900E+02, 0.19851100E+02, 0.16960900E+02, 0.23438600E+02, -.71863700E+01, -.26882600E+02, -.39529900E+02, 0.23689000E+02, 0.89252700E+01, 0.30179600E+02, -.16799600E+02, 0.79395800E+01, -.15459200E+02, 0.51345200E+02, -.13906300E+01, -.19903500E+00, -.22254400E+01, 0.78548200E+01, -.42173800E+02, -.93000800E+02, 0.54002100E+01, 0.29721500E+01, -.22057800E+01, -.30459900E+01, -.46327200E+02, 0.25662300E+01, -.46243800E+00, -.46212700E+02, 0.35053900E+02, -.12351700E+01, 0.48576100E+01, 0.10130800E+01, 0.15722900E+01, 0.34465900E+02, 0.14426300E+00, -.29551500E+01, 0.29177800E+00, 0.41088700E+01, -.53589700E+01, -.24129900E+01, -.67842600E+01, -.34087600E+01, -.18616200E+02, 0.65397400E+01, 0.23104700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.75053700E+01, -.96017200E+00, 0.76771500E+01, 0.39640300E+01, -.34539500E+01, -.14867200E+01, 0.24016400E+01, -.28710300E+00, -.10640400E+00, 0.43378500E+01, 0.10243500E+01, 0.29459100E+00, 0.42236900E+00, 0.93352000E+01, 0.48140700E+00, 0.12346100E+01, 0.48176100E+00, 0.31393900E+01, 0.17092900E+01, -.12429500E+01, -.23467100E+01, 0.16481100E+00, -.15893800E+01, -.52966600E+00, -.43655400E+00, -.56496700E+00, -.26668800E+01, 0.14537000E+01, 0.18656200E+01, -.22044700E+00, 0.13930200E+00, -.55870600E+00, -.85725200E+00, -.88017900E+00, 0.10145900E+00, 0.31502800E+00, -.60619600E-01, 0.12862700E-01, 0.62544600E+00, -.49801100E+00, -.30034800E+00, -.15777000E+01, 0.34156000E+01, 0.20404000E+00, -.25744200E+01, -.77131200E-01, -.30629700E+00, 0.15610400E+01, 0.94590900E+00, -.95435700E-01, 0.37260900E+01, -.76989800E+00, -.94227300E+00, -.50095400E+00, 0.60429700E+00, -.12617100E+01, 0.54190700E-01, 0.19107200E+01, 0.23838800E-03, -.27846300E+01, 0.41396800E+00, 0.11819600E+01, -.32231300E+00, -.31907100E+00, 0.14201200E+01, -.10769500E+01, 0.24720900E+00, 0.31828100E+01, -.16430400E+00, -.20510100E-02, 0.14277000E+01, 0.21568600E+00, 0.16534900E+01, 0.60514600E+00, -.17294600E+01, 0.18147500E+01, -.51190400E-01, -.20998200E+01, -.27436300E+00, -.67894200E+00, 0.23044100E-01, 0.72227800E+00, 0.24984100E+00, 0.26886400E+00, 0.29030600E+00, -.39570900E+00, 0.68864400E+00, 0.51719300E+00, 0.87279800E+00, 0.83971600E-01, -.56507400E+00, 0.59882000E-02, -.16526200E+00, 0.42708600E+00, 0.23982400E+01, 0.92947200E-01, -.21643400E+00, -.32667800E+00, -.74892600E+00, 0.29591700E+00, 0.48237800E+00, -.14628600E+01, 0.54911700E-01, -.23493000E+00, 0.60814200E+00, 0.19882300E+00, -.10355200E+01, 0.42569700E+00, 0.33654000E+00, -.24568100E+00, 0.62703200E+00, 0.24013600E+00, 0.39056900E+00, 0.48095800E-01, -.24075900E+00, -.16267500E+00, -.48371000E+00, -.37521000E+00, 0.87683500E+00, -.15126500E+00, -.15414900E+00, 0.18614600E+00, -.25378200E+00, 0.62196000E-02, 0.47350600E-01, -.59939900E+00, 0.60621500E+00, -.20509300E+00, -.21686700E-01, 0.32282400E+00, 0.49132000E+00, 0.18619100E+00, -.23030000E+00, -.70797100E+00, -.12196100E+00, -.66336000E-02, 0.86281600E-01, -.37223200E+00, -.62659200E-02, -.64917700E+00, 0.66287300E+00, -.13500500E-01, -.13240400E+00, 0.24897000E+00, -.16104800E+00, -.20861600E+01, 0.58487100E-01, -.16230300E+00, 0.14192900E+01, -.24158500E+01, -.57504300E+00, -.45902400E-02, 0.24696600E-01, -.26384300E+00, -.40084300E-01, 0.14424700E-01, -.17721900E+00, -.29819400E-02, 0.20826400E-01, 0.62591700E-01, 0.23649900E+00, 0.67022700E-01, -.94639000E+00, -.20650900E+01, 0.97958000E+00, 0.10966600E+01, 0.52733700E+00, -.16009000E+00, -.15864300E+01, 0.42769600E-01, -.64852700E-01, 0.48524500E+00, 0.40466300E+00, -.61732200E+00, 0.21393700E+00, -.29995200E+01, -.97445100E+00, 0.25698400E+00, 0.10875900E+01, 0.41660200E-01, -.14529000E+01, -.69118800E+00, -.88308700E+00, 0.70472000E+00, -.93253500E+00, -.71693300E+00, -.19993800E+00, 0.20038300E+00, 0.17199800E+00, 0.69690200E+00, -.51626000E-01, 0.59969600E+00, 0.74705900E-02, 0.33487300E-01, -.38583300E-01, 0.19446800E+01, 0.97742100E+00, -.34944700E+00, -.29240000E+00, -.43587300E-01, -.15442200E-01, 0.13713600E-01, -.14784900E-01, -.11370700E+01, 0.34471900E+00, -.63947400E-01, -.32785300E+00, 0.52640800E-01, -.35115500E+00, -.38455700E+00, 0.27506300E-01, -.56543300E-01, 0.11135100E+00, -.45055800E+00, -.39714000E+00, 0.26962000E+01, -.33396500E+00, 0.54630300E+00, -.27515800E+02, 0.81624200E+02, -.16871600E+03, 0.11790300E+03, 0.72103900E+02, 0.83626300E+02, 0.77841200E+02, -.28032200E+02, -.86010000E+01, -.70818400E+02, -.31537400E+02, -.33676400E+02, 0.22802900E+03, 0.14353700E+03, -.78594000E+02, 0.39699300E+03, -.76618300E+02, -.14039400E+03, -.12178400E+03, 0.91308900E+02, 0.10893200E+03, -.88391900E+01, -.13040300E+03, -.99576400E+02, 0.15461000E+03, -.14229300E+03, -.18590400E+02, -.77394600E+02, -.79337800E+02, -.48421300E+02, 0.14931100E+02, 0.57098100E+02, 0.40374900E+02, -.48974900E+02, -.12101500E+03, -.11178100E+03, 0.61039600E+02, 0.50217100E+02, 0.56699200E+02, -.75273100E+02, -.13165200E+02, 0.37948600E+02, -.24176400E+01, 0.20443500E+02, 0.19425800E+02, 0.20036700E+03, -.54131900E+01, -.27732400E+01, 0.17006500E+02, 0.35041000E+01, 0.75103900E+02, -.65330700E+01, 0.38221700E+00, 0.74978300E+02, -.63985100E+02, 0.20325000E+01, -.49303400E+01, -.21469400E+01, 0.58636500E+00, -.61993700E+02, -.47058700E+01, 0.24486900E+01, -.15056800E+01, -.39196500E+01, 0.67423300E+01, 0.11434100E+01, 0.98942300E+01, 0.11835200E+02, 0.33294900E+02, -.99237500E+01, -.46477500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.45897100E+01, -.39842100E+00, 0.10511200E+01, -.13793300E+01, 0.12547000E+01, 0.23110600E+01, -.21549800E+01, 0.44224400E-01, 0.47331000E+00, 0.34360700E-01, 0.16157400E+00, 0.78983700E+00, 0.17294000E+01, 0.78415600E+00, -.14026900E+00, -.11367500E+01, 0.88399300E+00, 0.18295300E+01, -.49877400E+00, 0.88445800E+00, -.36743800E+00, 0.22223600E+00, -.19210500E+00, 0.77540500E+00, -.11785800E+00, -.76297400E-01, -.16024400E+01, -.11964700E+01, 0.65387700E+00, -.28889900E-01, -.19370600E+00, 0.85162100E+00, 0.63605200E+00, 0.77699700E+00, -.13021700E+00, 0.24800800E+00, -.43388900E-01, 0.19180400E+00, -.23125000E+00, 0.35821700E+00, 0.26403200E+00, 0.46913100E+00, -.23849200E+01, 0.33108700E-01, 0.94196200E+00, 0.13022100E+00, 0.39973000E+00, 0.14363000E+00, 0.96824500E+00, 0.14973500E+00, 0.93503600E+00, -.82581900E+00, 0.72940100E+00, -.65334800E+00, -.13852000E+01, -.25134500E+00, -.21092800E+00, 0.29903300E+00, 0.69144000E-02, 0.82794400E+00, 0.27915700E+01, 0.11439900E+01, -.56102900E-01, 0.49498100E+00, -.48073200E+00, -.94628800E+00, 0.29948600E+00, 0.17273200E+01, -.18122900E+00, -.96764500E-02, 0.25663100E+00, -.47645900E+00, -.10402400E+01, -.12586100E+00, 0.18485200E+00, -.19674000E+00, 0.58122200E-01, 0.34057100E+00, -.47413300E+00, 0.11160900E-01, 0.68574300E-01, -.24748400E+00, -.31763600E+00, 0.93656700E+00, -.31327300E-01, 0.13463200E-02, -.17823300E+00, -.79503300E+00, 0.82437900E-01, -.26453700E+00, 0.11220400E+01, 0.58675600E-02, 0.64117800E+00, 0.10428500E+00, -.13667600E+01, 0.29449300E+00, 0.12599000E+01, -.35717600E+00, -.22375500E-01, -.24531100E+00, 0.51050200E+00, 0.25998600E+00, 0.34631600E-01, 0.19351300E+00, -.19058400E-01, 0.34565700E+00, 0.23180400E+00, 0.33539300E-01, 0.58888600E+00, 0.41721400E+00, -.58957300E-01, 0.61486400E-01, -.40291900E-01, -.28253800E-01, 0.59082200E-01, -.48681800E-01, -.38822400E+00, -.15053300E+00, -.94174800E+00, 0.89111400E+00, -.62630000E-01, 0.70816700E+00, 0.16911600E-02, -.40110300E-01, 0.23648000E-01, 0.70973500E-01, 0.61030800E-01, 0.88350200E-01, -.41323600E-01, -.74066300E-01, -.11011000E+01, 0.10275700E+01, -.35580800E+00, 0.87187400E+00, 0.45444700E-01, -.16840000E-01, 0.14628800E-01, -.60751400E-01, -.27853400E+00, 0.48759500E-01, 0.99840500E-01, -.26950800E+00, 0.25135300E-01, 0.66536300E+00, -.36674000E-03, -.70047800E-01, 0.41071300E-01, -.15359100E-01, -.45071600E+00, -.37053400E+00, 0.48228600E+00, -.29944400E-01, -.24979200E+00, 0.26727200E-02, 0.92986400E-01, 0.14057900E-01, 0.86007100E-01, -.60945200E-01, -.14122700E+00, 0.37134600E-01, -.45118100E+00, -.28275900E-01, 0.12291700E+00, -.44950800E+00, 0.47048800E-01, 0.57475200E-01, -.21088900E-02, -.15335400E-01, 0.54585100E-01, 0.54916300E-01, -.11298800E+00, -.18766600E+00, -.56998400E-01, 0.12718300E+00, -.90672500E-02, 0.41542600E+00, -.15335900E+00, -.22703200E-01, -.74036500E-02, 0.52000500E-01, -.90365400E+00, -.17462300E+00, -.57760400E-02, -.54581600E-01, -.21319500E-01, -.14118400E+00, -.12012200E-01, 0.93317100E-01, -.70191500E-02, -.10477800E+00, 0.19106100E-01, 0.35737200E+00, -.21481000E+00, 0.26364400E-01, -.11121500E+00, -.12560800E+01, -.18988500E+01, -.24623800E+00, 0.43532500E+00, 0.97037900E-02, 0.14851000E+00, 0.12278500E-02, 0.60743200E-01, -.31455700E-02, 0.63344800E+00, 0.91580800E-01, -.14925700E+00, 0.14331100E+00, -.65304900E-01, -.20373800E+00, 0.64335100E-01, -.31715500E-01, 0.49760200E-01, -.32965300E+00, -.41082300E+00, 0.29969700E+00, -.29469500E+00, 0.17403200E-01, 0.66633800E-01, 0.30702100E+02, 0.71791100E+01, 0.12352800E+02, 0.41605700E+02, -.33459500E+01, 0.40044100E+02, 0.12877700E+02, -.34986300E+02, -.23505500E+02, -.22658800E+02, 0.11039800E+02, -.28802400E+01, 0.13715000E+03, -.78223200E+02, 0.13680500E+03, -.70853200E+02, -.61998600E+02, -.32140200E+02, 0.19750000E+02, 0.40312600E+02, -.41399400E+02, -.35968200E+02, -.97848000E+02, 0.44502300E+02, -.50725100E+02, -.19199700E+02, -.22147400E+02, -.15061500E+02, -.13345400E+02, 0.44547300E+01, 0.23040800E+02, 0.11818400E+02, -.13703800E+02, -.18196400E+02, 0.34876900E+02, -.15939900E+02, -.29090200E+02, -.17187800E+02, -.34714700E+02, 0.15993200E+02, -.20615800E+02, -.31798000E+01, -.22341700E+02, 0.43480300E+02, 0.23039100E+02, -.42403700E+01, -.11959300E+01, 0.20892300E+01, 0.27663400E+01, 0.43214300E+02, -.17162200E+01, 0.44923300E+00, 0.42605800E+02, -.30168100E+02, 0.29364600E+00, -.36706900E+01, -.57489400E+00, -.10184100E+01, -.29681900E+02, 0.23349300E+00, 0.24826600E+01, 0.28305600E+01, -.33253900E+01, 0.29234600E+01, 0.26073800E+01, 0.72938400E+00, 0.37208100E+01, 0.16370100E+02, -.31773600E+01, -.14615000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.86327300E+01, -.91292600E+00, 0.45002700E+00, -.45833000E+01, -.37419300E+01, 0.38712200E+01, -.80068400E+00, 0.14710500E+00, 0.19956900E+01, -.10984900E+01, 0.44431000E+00, -.90855700E-01, 0.98450900E+00, 0.37576500E+01, 0.49922500E-01, -.10640300E+01, 0.28327800E+00, 0.40404000E+01, -.23110800E+01, 0.11268400E+01, 0.12255000E+01, 0.41796800E+00, -.40617100E+00, -.19757200E+01, -.16364100E+00, -.42600900E+00, 0.19349200E+00, 0.16467200E-02, 0.18022400E+01, -.67205400E+00, -.12618700E+00, 0.25258900E+00, -.13980900E+00, 0.41052800E+00, -.73293600E-01, -.30061500E-01, 0.13448900E-01, -.82228000E-01, 0.41618600E+00, -.26095800E+00, -.56902300E-02, 0.18427500E+00, 0.10436600E+01, 0.19287000E-01, -.58887200E+00, 0.24512700E+00, -.27424100E+00, 0.10928400E+01, -.13421800E+01, -.13904100E-01, -.40182500E+00, -.32848400E+00, -.67667100E-01, 0.12395800E+01, 0.84895400E+00, -.28470000E+01, -.14011700E+00, 0.27664700E+00, -.67100900E-03, -.15392800E+01, 0.16599100E+01, 0.18710200E+00, -.22471400E+00, 0.27206300E+00, 0.11342900E+01, -.11872200E+00, 0.20869600E+00, 0.36497500E+01, 0.13072900E+00, -.10979200E-01, 0.56050300E+00, -.61245300E+00, -.13731100E+01, 0.96250300E+00, -.15619300E+01, 0.95957900E+00, -.65520200E+00, -.85791800E+00, -.37356200E+00, -.12483300E+00, 0.31737800E-01, 0.19816000E+01, -.85381900E-01, 0.72965800E+00, 0.79083200E+00, -.42089100E+00, -.87899100E-01, 0.54359500E-01, 0.15548000E+01, -.67643800E+00, 0.34851900E+01, 0.18132100E-01, 0.35299400E+00, 0.86987600E-01, -.13642800E+01, 0.80378400E-01, 0.20147500E+01, -.95613900E+00, -.41492500E+00, -.11419700E+00, 0.81344800E+00, 0.32802600E+00, 0.73378000E-01, 0.28504900E+00, 0.23649100E+00, 0.33192500E+00, 0.16065900E+00, 0.14992100E+00, -.39243500E+00, 0.83688000E+00, -.71738700E-01, 0.24690300E+00, -.33511200E+00, -.13837000E-01, 0.16467300E+00, -.84548700E-01, -.43269700E+00, -.56697200E+00, -.38033300E+00, 0.96776300E+00, -.57506600E-01, 0.24695800E+00, 0.11600500E+00, 0.31775300E+00, -.63638700E-02, -.14224200E+00, 0.57538700E-01, -.63118800E-01, -.11216600E+00, -.20010700E+00, -.47464400E+00, 0.15376900E+00, 0.56808900E-01, -.13651800E+00, -.18474800E+00, -.50593300E-01, 0.46515400E+00, -.22194900E+00, 0.12043000E+01, -.34576000E+00, -.19177500E+00, -.78359900E-01, 0.15033000E+00, 0.36389400E+00, -.62367600E-01, 0.45623600E+00, 0.56716400E-01, 0.12680400E+00, 0.43479100E+00, 0.57185200E+00, -.40438200E+00, -.95414000E-01, 0.29992700E+00, -.42331300E-01, 0.72805700E+00, -.16778900E-01, 0.22530700E-01, 0.33827400E-01, 0.17125300E+00, -.48801900E+00, -.65790900E+00, -.18788800E+00, 0.17955800E-01, 0.28248200E-01, -.19699400E+00, -.23972300E+00, -.15116500E+00, 0.98118100E-01, 0.70658800E+00, 0.69842400E-01, 0.89657000E-02, 0.33515600E+00, -.16029600E+00, 0.80665800E+00, -.99484500E-01, -.44094100E+00, -.45158500E+00, 0.19844400E+00, -.11888200E+00, 0.48149200E-01, -.25261400E+01, 0.13817200E+01, 0.49372900E+00, -.30487600E+00, 0.57711700E+00, -.27127900E-01, -.14273000E+00, -.83449500E-01, -.70010600E-01, -.10586600E+00, -.11401800E-01, -.40632800E+00, -.13420100E+01, -.49942500E-01, 0.32145200E+00, -.34632300E+01, -.32975300E+01, -.80797500E+00, 0.23507500E+00, -.13344300E+00, 0.46911700E+00, 0.21188500E-02, -.10115400E+00, 0.14972000E+01, 0.98733100E-01, -.15977400E+00, 0.62036200E-01, -.62105700E-01, 0.31292000E+00, -.89611600E-02, 0.43968200E-01, -.35668600E-01, 0.13249100E-01, -.62386200E+00, -.36957600E+00, -.25979700E+01, -.57683500E-01, 0.94869300E-01, -.14484000E+00, 0.70277300E+00, -.11319900E+03, 0.67543700E+02, 0.12564400E+03, 0.57388400E+02, -.13329400E+02, 0.51510400E+01, -.33978300E+02, -.75180800E+02, 0.59351600E+02, 0.10152500E+02, -.15827800E+02, 0.98498100E+02, -.70386000E+02, 0.22020100E+02, -.48355400E+02, -.57257300E+01, -.77190000E+01, 0.41508600E+02, 0.40690600E+02, 0.10365000E+00, -.50947500E+01, -.94237600E+02, -.40258700E+02, 0.48639100E+01, -.12778800E+02, 0.20256000E+02, 0.36440000E+02, 0.81359700E+01, 0.26708900E+01, -.11350400E+01, -.14140800E+02, 0.90554100E+01, 0.74287800E+02, 0.74267900E+01, -.36706100E+01, 0.15633300E+00, -.40183100E+01, -.70878900E+00, -.93850600E+01, -.49187000E+01, 0.17979800E+02, 0.39571100E+01, 0.52254700E+01, 0.51195000E+01, -.45687200E+01, -.39456500E+00, -.49391900E+01, 0.83069000E+00, 0.76442300E+01, 0.17872200E+01, -.13050400E+01, 0.72568000E+01, -.10812300E+02, 0.71531100E+00, -.32027700E+01, -.11885900E+01, -.24953200E+00, -.10721800E+02, 0.32321900E+01, 0.18172500E+01, 0.28901900E+01, -.29086000E+01, 0.92678700E+00, 0.47308300E+01, -.23513900E+01, -.36598500E+01, -.90811200E+01, 0.15953000E+01, 0.11318000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11557400E+02, -.28390100E+00, 0.85758800E+01, 0.43854500E+01, -.33711900E+01, 0.89016300E+00, 0.14754100E+00, -.68332400E+00, 0.53890600E+00, -.73338400E+00, 0.38610300E+00, 0.29840400E+00, -.22492700E+01, 0.28108200E+01, 0.72929100E+00, -.87674900E-01, 0.32813800E-01, 0.25130900E+01, 0.23227800E+01, -.33744100E+00, 0.42821700E+00, 0.63486400E+00, 0.63227100E-02, 0.14368600E+01, -.13901900E+00, 0.28284000E-01, -.32191500E+01, 0.60604200E+01, -.26696900E+00, -.12751800E+00, 0.60278000E+00, 0.17310700E+00, -.43884700E+01, 0.32452600E+01, -.10953600E+01, 0.24160400E+00, -.33141400E+00, 0.35596000E+00, -.69346800E+00, 0.35036700E+01, 0.33678200E+00, 0.22362400E+01, -.40219400E+01, -.20050000E+00, 0.63441500E-01, -.80589100E+00, -.43061000E-01, 0.21903300E+01, 0.20826800E+01, -.48505500E+00, 0.20989000E+00, -.24123500E+00, 0.70240600E+00, -.13928600E+01, -.20209200E+01, -.80989400E+00, -.46977200E+00, 0.18361000E+01, -.32932900E-01, -.29227500E+01, 0.32990900E+01, 0.11650700E+01, -.16376500E-01, 0.15786800E+01, 0.39832800E+01, -.11220100E+01, 0.11733100E+01, -.81464200E+00, 0.15922400E+00, 0.34740400E-01, 0.51230300E+00, -.15680600E+01, -.34268900E+01, -.46415400E+00, 0.38190900E+00, -.16839600E+01, 0.33747900E+00, 0.68763100E-01, -.14666000E+01, 0.22595400E-01, 0.14122000E-01, -.75773600E-02, 0.24332100E+01, 0.41835800E+00, 0.58953300E+00, -.24417500E+00, 0.30084700E+01, 0.15968500E+00, -.10846500E+01, 0.66048900E+00, 0.32430700E+01, -.20481100E-01, -.89894300E+00, 0.21793500E+00, -.31381200E+00, 0.33193500E+00, -.98562700E-01, 0.67736200E+00, -.25661400E+00, 0.24503400E+00, 0.41727200E+00, -.54098300E+00, -.56422500E-01, -.10095100E+01, 0.87083300E+00, 0.75492400E+00, -.76160000E+00, 0.10846200E+00, -.79404800E+00, -.25227100E+01, -.33898900E+00, 0.10624800E+00, 0.22209900E+00, -.36837200E-01, 0.29319000E+00, -.16448500E+00, -.37636700E+00, -.13228500E+00, -.97967300E+00, 0.72678600E+00, -.84391600E+00, -.13217500E-01, 0.15057200E-01, 0.65372900E-01, -.39874600E-01, 0.84753400E+00, 0.56604500E+00, 0.42749800E+00, -.73128600E-01, 0.32608500E-01, 0.11815300E+01, -.94173800E+00, 0.18438300E+00, 0.21943100E+00, 0.44864200E+00, -.11058000E+00, 0.18535200E+01, -.82421700E-01, 0.15860600E+01, 0.29343100E+00, 0.95814200E-02, -.11386000E+00, 0.12262300E+00, 0.11600400E+01, 0.25622200E+00, -.12481900E+01, 0.96073500E-01, -.92715500E-01, 0.89270000E+00, -.42636800E+00, -.81839900E+00, -.12278500E+00, -.14527400E+00, -.35652100E+00, 0.75967700E-01, -.11069100E+00, -.34221600E-01, -.64987500E-01, -.39609200E+00, -.81767900E+00, -.77881100E+00, -.25003900E+00, -.56255700E-01, -.41873700E+00, 0.56747300E-01, 0.73782700E+00, 0.39202900E+00, -.29693200E+00, -.20746400E+01, 0.10214100E+00, -.20584500E+00, -.18233600E+00, -.50723400E-01, 0.11431100E+01, 0.53898500E-01, -.27426000E+01, -.44542200E+00, 0.30627400E+00, 0.37704900E-01, -.19392700E-01, -.30367800E+01, 0.19926800E+01, 0.70131200E+00, -.24803000E+00, 0.30527200E+00, 0.15456100E+00, -.46771500E+00, 0.31264900E-01, 0.60468600E-01, 0.13192100E+01, -.58203400E-01, -.10006600E+00, -.89106400E+00, 0.10731100E+00, 0.54208100E-01, -.31851600E+01, -.31835400E+01, -.83540100E+00, 0.31000000E+00, 0.93526700E-01, 0.28378200E+00, 0.46024500E-02, -.20605000E+00, -.12431400E+01, 0.37255900E+00, 0.13989500E+00, 0.35856300E+00, 0.76883400E-01, -.32668000E-01, -.26915900E-01, -.83661700E-02, -.11670400E+00, 0.15574300E-01, -.52737800E+00, -.47265000E+00, -.32854800E+01, -.21818300E+00, -.12579000E+01, -.67530800E+00, 0.13042000E+01, 0.12039600E+01, -.40045700E+02, -.95587400E+02, -.67180300E+00, 0.83168400E+01, -.41609100E+02, 0.67526700E+02, 0.47677300E+02, -.27766200E+02, -.46157200E+02, 0.10610100E+03, -.32682300E+02, 0.47688600E+02, -.74188700E+02, 0.17979600E+02, 0.34614800E+02, 0.29256700E+02, -.34348100E+02, 0.10568200E+01, 0.61521400E+00, 0.21121200E+02, 0.55193400E+02, -.46037200E+02, 0.86767600E+02, 0.39335500E+02, 0.23240400E+02, -.19232900E+02, 0.14151900E+02, -.83819100E+01, -.25700900E+02, 0.59640400E+01, 0.13019700E+02, -.51883700E+02, -.63971100E+02, 0.28612000E+02, 0.44003600E+02, 0.31738200E+02, 0.63271500E+01, 0.74293100E+01, 0.35475200E+02, 0.54168000E+01, 0.28857300E+02, -.40572300E+02, 0.39428900E+01, 0.31979000E+01, 0.88703200E+00, 0.71781500E+01, -.25726100E+01, -.29310800E+02, -.64588100E+00, 0.56278400E+00, -.29971600E+02, 0.88247000E+01, 0.96755100E+00, 0.27492300E+01, 0.76982400E+00, 0.11280300E+01, 0.85068000E+01, -.21020800E+01, -.31272000E+01, -.50673100E+01, 0.95846000E+00, -.10266200E+01, -.60460400E+01, 0.24805600E+01, 0.28642200E+01, -.11771200E+02, -.28647000E+01, -.31908900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16335800E+02, 0.19088100E+01, -.74949500E+01, 0.46748700E+00, 0.39978700E+01, -.28484700E+01, 0.84713200E+00, 0.24812200E+00, -.68402800E+00, -.80695200E+00, -.38797200E+00, -.25529000E+00, -.12259200E+01, -.81805900E+01, -.24558900E+00, 0.20276500E+01, 0.10747100E+01, -.35777500E+01, -.48192100E+00, -.36734300E+00, 0.19559900E+01, -.54811400E+00, 0.13955900E+01, 0.77999600E+00, 0.66373600E+00, 0.75871800E+00, 0.44177500E+01, 0.50423600E+01, -.33266300E+01, 0.64949300E+00, 0.25816200E+00, 0.10697000E+01, -.10590100E+01, 0.49119700E+00, 0.16572800E+00, -.22199000E+01, 0.26218300E+00, -.11596400E+01, -.84316300E+00, 0.17697900E+01, -.11772800E+01, 0.15290500E+01, -.42819000E+01, -.51716800E+00, 0.15910500E+01, -.36730800E+00, 0.88153400E+00, -.41286000E+01, -.46467600E+00, 0.32879500E+00, -.28733600E+01, 0.16784700E+01, -.29783800E+00, -.25489500E+01, 0.12517200E+01, 0.48496700E+01, 0.92237800E+00, -.13387000E+01, -.12178400E-01, 0.36902600E+01, -.56340500E+01, -.21738600E+01, 0.54442800E+00, -.76663900E+00, -.37279300E-01, -.56482800E+00, -.38564200E+00, -.10810300E+02, 0.22357400E+00, 0.32487300E-01, -.10244500E+01, 0.89454500E+00, -.37427100E+01, -.10880700E+01, 0.13957000E+01, -.11220800E+01, 0.33283100E+00, 0.99370100E+00, 0.10486800E+01, 0.16682600E+01, -.12587600E+00, -.10820800E+01, 0.12693000E+01, -.41094600E+00, 0.47969500E-02, 0.31645200E+00, -.49593700E-02, -.48474100E+00, -.76149000E+00, -.32307300E+00, 0.45711500E+01, 0.12438500E-01, 0.57902300E+00, -.83856000E-01, -.10782500E+01, -.74821100E+00, -.26550200E+01, 0.11059000E+01, -.20600900E+00, 0.56069200E-01, -.22920900E+01, -.17011800E-01, -.17505200E+00, -.94988700E+00, 0.52240400E+00, -.64125000E+00, -.16539500E+01, -.54772400E+00, -.23059500E-01, 0.22650100E+00, 0.65280400E+00, 0.29095800E+00, -.22517300E+00, -.20555200E-01, -.82232200E-01, 0.85950100E-01, 0.69472400E+00, -.54475100E+00, 0.41297200E+00, 0.96882800E+00, -.20263100E+00, 0.46554600E+00, 0.67364500E-01, 0.80796900E+00, -.55669600E-01, -.71994800E+00, 0.11365900E+01, -.48217200E+00, 0.82904100E-01, 0.97682200E-01, 0.42392700E+00, -.10653300E+01, 0.12653300E+01, -.53929900E+00, -.31489200E-01, -.11580800E+00, 0.33456300E+00, 0.96610000E-01, 0.11153900E+01, -.10787900E+00, 0.10840500E+00, -.66545900E-01, 0.46983200E+00, 0.78788100E+00, -.32467800E+00, 0.10269600E+01, 0.15726000E+00, 0.79817100E-01, -.18673100E+00, -.13558300E+01, 0.20014500E+00, -.20703100E+00, -.12217900E+00, -.91263700E-01, -.49042900E+00, -.22368800E-01, -.32149600E-01, -.23724500E+00, -.26516600E+00, -.53989800E+00, -.11647300E+01, -.62271000E-01, 0.99975000E+00, -.13660300E+01, -.12830700E+00, -.27295600E+00, -.49054700E-01, 0.11687900E+00, 0.77164000E+00, 0.14155700E+00, 0.31684000E+00, 0.21731400E+00, -.37355200E-01, -.17646900E+00, -.10615300E+00, -.46000200E+00, -.35463600E+00, 0.12115800E+00, 0.17798100E+00, 0.38527300E+00, -.22723700E+01, -.15489100E+01, -.29113500E+00, -.27984100E+00, -.65007200E+00, -.90274700E+00, -.27250800E+00, 0.26778100E+00, -.74823700E-01, 0.25706100E+00, 0.31003900E+00, 0.79118800E+00, 0.22440600E-01, -.49011500E+00, -.16849700E+00, -.31747100E+01, -.23748600E+00, -.15818500E+00, -.32130800E+00, 0.51629200E-01, 0.18789600E-03, -.51576300E-02, 0.57958000E-02, -.30105800E+01, -.29819100E+00, -.17471800E+00, -.18375800E-01, 0.39245100E-01, -.35470500E+00, -.17138300E+00, 0.34805300E-01, 0.33394300E+00, 0.69689900E-01, -.59392900E+00, -.46961000E+00, 0.33962900E+01, 0.45145300E+00, 0.57131000E+00, -.75748400E-01, 0.52180600E-01, 0.16296800E+00, -.41367300E+00, -.15794900E+03, -.11491700E+01, 0.93267400E+02, -.59562300E+02, 0.59629400E+02, 0.46755900E+02, 0.67556100E+01, -.42281700E+02, 0.98529800E+02, -.12961700E+03, 0.55993300E+02, 0.15316600E+03, 0.60086100E+02, -.93835400E+02, -.18114700E+02, 0.10095800E+03, 0.18200400E+02, 0.11743700E+02, -.57244600E+01, 0.10145500E+03, 0.14928200E+03, -.80783200E+02, -.27959500E+02, -.74274700E+02, -.94909600E+02, -.66153200E+02, 0.40943200E+02, 0.56841000E+02, 0.33154700E+02, -.64262800E+02, -.11285900E+03, -.17881700E+03, 0.90680400E+02, 0.79087100E+02, 0.90118400E+02, -.25670900E+02, -.37302600E+02, 0.78820600E+02, 0.19783000E+02, 0.52396300E+02, -.38847600E+02, 0.12186700E+03, -.64503600E+00, -.56517800E+01, 0.16377100E+02, 0.59627000E+00, 0.50005100E+02, -.61738000E+01, 0.19265900E+01, 0.49353000E+02, -.74477000E+02, 0.62559900E+01, -.38333400E+01, -.13945900E+01, -.24911300E+01, -.74751700E+02, -.32768000E+01, -.10009300E+01, -.65048200E+01, -.10499700E+01, 0.76596400E+01, -.44938900E+01, 0.56506500E+01, 0.90136800E+01, 0.38178000E+02, -.83500900E+01, -.68876200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.73915300E+01, -.71583900E+00, -.24207300E+01, -.59387300E+00, -.87242100E+00, 0.42168000E+00, -.59977600E+00, -.41555700E+00, 0.27796500E-01, -.23751800E+01, 0.30276700E+00, -.24815000E+01, -.25827400E+01, -.24099800E+01, -.46147300E+00, -.63840500E+00, -.29653800E+01, -.15712200E+01, 0.98780100E+00, -.15018300E+01, 0.16184100E+01, 0.19162700E+00, 0.63318500E-01, -.17961400E+01, -.24662800E+00, -.15278000E+00, 0.14470200E+01, 0.21311000E+01, -.24734400E+00, -.23123900E+00, 0.19249700E+00, -.18682300E+01, -.23962400E+01, 0.22703200E+00, -.33589400E+00, 0.12806800E+00, -.12277500E-01, -.10818400E-01, -.22458200E+00, 0.24497000E+01, 0.20655500E+00, 0.71069500E+00, -.37496000E+01, 0.34853400E+00, 0.23631300E+01, 0.41546900E+00, -.34718000E+00, 0.44278500E+00, -.41891900E+00, -.27771000E+00, -.85427900E+00, -.11285400E-01, -.73250200E-01, 0.68330300E+00, -.24392600E+00, -.53691100E+00, -.56992600E+00, -.45070000E+00, 0.33437400E-02, 0.15935600E+01, 0.14347900E+01, 0.13210100E+01, -.66481800E-01, 0.79225000E+00, -.64911400E+00, 0.20007800E+01, -.11047400E-01, 0.22004500E+01, -.39544900E-01, -.51865100E-02, -.93570300E+00, 0.33712200E+00, 0.11616700E+01, -.53792100E+00, 0.60479500E+00, -.17019500E+00, 0.79246500E-01, 0.45329400E+00, -.42907800E+00, -.13944300E+00, 0.22438800E-01, -.90072000E+00, -.53639000E+00, 0.19352200E+00, -.30252100E+00, 0.91820000E-01, 0.13522200E+00, -.78332300E-01, -.20828000E+00, 0.31521200E+00, -.10159700E+01, -.16883800E-01, -.61354700E+00, 0.33133900E+00, -.17230500E+00, 0.32319300E+00, 0.11061500E+01, -.72365000E+00, -.79367900E-02, -.26140100E+00, 0.10099300E+01, 0.50156300E-01, 0.21221800E-01, 0.13479000E+00, -.27154400E+00, 0.43798900E+00, 0.11505900E+01, -.11451800E-01, -.16539400E+00, -.15364400E+01, -.82209000E+00, 0.10004400E+00, 0.25668500E+00, 0.11850500E-01, -.26109700E+00, -.39884100E-01, 0.78466600E-01, -.27010600E+00, -.84291000E+00, 0.58967000E+00, 0.22949400E+00, 0.40105300E+00, -.81147400E-01, -.47347800E+00, 0.29844100E-01, 0.12988900E+00, 0.81131300E-01, -.52315000E-01, -.45197900E-01, 0.22649400E+00, 0.10933400E+01, -.59411500E+00, -.16979600E+00, -.11696900E+01, -.97604500E-01, -.19014300E-01, -.41496200E+00, 0.27868500E+00, 0.35144200E+00, -.57342400E+00, 0.21029600E+00, 0.14364000E+00, 0.62361200E-01, 0.43242100E+00, -.43930800E+00, 0.63549600E+00, 0.54341800E-01, 0.11408500E+00, 0.10932300E+01, -.19010600E+01, -.84116800E-01, 0.99472700E-01, 0.49442100E+00, 0.11873700E+00, -.91860800E+00, 0.15299800E+00, 0.90746700E-01, 0.75159100E-01, 0.19695100E+00, 0.58259200E+00, -.15502900E+01, 0.12242200E+00, 0.68049200E+00, 0.10694300E+01, -.85527000E-01, -.67626700E+00, 0.83031400E-01, 0.11394100E+00, 0.10560600E+01, 0.10378600E+00, 0.20959800E+00, 0.10906700E+01, 0.51203700E-01, -.42772300E+00, -.14744000E+00, -.25977700E+00, 0.17452100E+00, 0.10174600E-01, -.44258900E+00, 0.17326600E+00, -.41141700E+00, -.11831100E+01, -.87090100E-01, -.67191400E-02, -.41110400E+00, -.42195300E+00, -.16191000E+00, 0.27076500E+00, 0.38725200E-01, 0.37456200E+00, 0.15396600E+00, -.87055400E+00, 0.10366800E+01, 0.70603800E+00, -.41520400E+00, -.34232200E+01, 0.33801400E+00, -.75729500E+00, -.52599400E-01, -.10348300E-01, 0.13765000E+00, -.34024700E-02, -.60732900E-02, 0.23251200E+01, -.14764700E+00, 0.21178700E+00, 0.83044500E-01, 0.28427900E+00, -.62164800E+00, 0.81272100E-01, -.40468400E-02, -.82595000E-01, -.52091700E-01, 0.52475000E+00, 0.27872400E+00, -.67265700E+00, -.28707000E+00, -.32807800E+00, -.23897500E+00, 0.15405200E+00, 0.25212700E+00, 0.30422900E+00, 0.91694900E-01, -.19159600E+01, -.66163400E+02, -.24316900E-01, 0.16303700E+02, -.57136700E+01, 0.21911000E+01, 0.19345300E+01, 0.15357500E+02, -.86486200E+02, 0.43587000E+02, 0.47545700E+02, 0.45283200E+02, 0.21413700E+02, -.28883700E+02, 0.15624400E+02, 0.19402500E+02, 0.44013200E+02, -.34967900E+02, 0.38569700E+02, -.49266300E+02, 0.27531000E+02, 0.31526900E+02, 0.24102100E+02, 0.21560100E+02, 0.17536300E+02, -.18406400E+02, -.21030100E+02, -.81499200E+00, 0.19956400E+02, 0.28943100E+02, 0.65355100E+01, -.31447800E+01, 0.25278600E+01, -.31701100E+01, 0.42946100E+02, -.15015100E+02, -.10893200E+02, -.15662900E+02, 0.10294100E+02, -.26010300E+02, -.67452100E+01, 0.42369500E+01, 0.29777100E+01, -.44633700E+01, -.31576300E+01, -.22717100E+02, 0.19123900E+01, -.11954400E+01, -.22021600E+02, 0.15560700E+02, -.24586300E+01, 0.36674500E+01, 0.84840200E+00, 0.15368900E+01, 0.15853000E+02, -.86610100E+00, -.22942700E+01, 0.75188600E+00, 0.27298200E+01, -.47605400E+01, 0.11203300E+01, -.74897600E+00, -.47844700E+01, -.11313200E+02, 0.28457100E+01, 0.50807400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18624400E+02, 0.18759900E+01, -.23998800E+01, 0.62703500E+01, 0.90042800E+01, -.58316000E+01, 0.24998900E+01, 0.65566600E+00, -.12665100E+01, 0.39526200E+01, -.16948200E+01, 0.50933800E+01, 0.29785600E+01, -.11314100E+02, 0.10696100E+01, 0.21561200E+01, 0.33123300E+01, -.50741000E+01, 0.10759400E+01, -.20337400E+01, 0.10991000E+01, -.78029200E+00, -.17477200E+00, -.20629100E+01, 0.50224000E+00, 0.18151600E+01, 0.47293900E+00, -.67686200E+00, -.28429200E+01, 0.19866300E+01, -.10379200E+00, 0.10465500E+01, 0.40977800E+00, 0.16666600E+01, 0.72797900E-02, 0.61488100E+00, 0.58279500E-01, -.45295400E+00, -.91524500E+00, 0.20457300E+01, -.10147300E+01, -.76225900E+00, 0.23646800E+01, -.90766700E-01, 0.15897600E+01, 0.23786500E+00, -.87853200E+00, -.40058600E+00, 0.15525400E+01, 0.69142000E-01, 0.51497900E+00, -.13574100E+01, -.35227200E+00, 0.10842300E+00, -.96826300E+00, 0.11191000E+01, 0.19081300E+00, -.58503000E+00, -.47772500E-02, 0.67942100E+00, -.11800500E+01, -.32524300E+00, -.41263300E+00, -.17816700E+01, -.25473400E+01, -.11537300E+01, -.73511300E+00, -.45595900E+01, 0.29980700E+00, 0.17560600E-01, -.58780700E+00, 0.34043200E+00, -.33833600E+01, 0.72875500E+00, -.14276800E+01, -.87521200E-01, -.12690300E+00, -.22470300E+00, 0.13071400E+01, 0.11848000E+00, -.84532000E-01, -.25255000E+00, 0.65343600E+00, 0.29322400E+00, 0.13262500E+00, 0.13777400E+00, -.20826000E+01, -.58679300E+00, -.20737600E+01, -.32865800E+00, -.54088000E+00, 0.12264400E+00, 0.18078100E+01, -.80498600E+00, -.91967700E+00, 0.59611200E+00, 0.18101600E+01, 0.46554700E+00, -.28554700E+00, -.11710800E+01, 0.13116700E+01, 0.37611300E+00, 0.90648800E-01, 0.30606800E+00, 0.82050600E+00, -.13907300E+00, -.92935500E+00, 0.60597200E+00, -.10688000E+01, 0.46587900E+01, 0.10916600E+00, 0.68340400E+00, 0.10235300E+01, -.44963100E-01, 0.29228100E+00, 0.14680400E+00, -.69835400E+00, 0.51719900E+00, 0.55695100E+00, 0.43979600E+00, 0.14019700E+00, 0.59172100E+00, 0.73547600E-01, 0.26713100E+00, -.64588100E-01, -.62354800E-01, -.11926600E+01, 0.15317800E+00, 0.90192100E-01, -.47280300E+00, -.91514200E+00, 0.32531500E+00, 0.77071600E+00, 0.60249200E-01, 0.69648300E-01, -.66676700E-01, 0.47041900E+00, 0.14429700E+01, -.62863100E+00, 0.69478200E+00, -.87003900E-01, -.35029100E+00, 0.56583600E+00, 0.60799400E+00, -.27940200E+00, 0.23597800E+00, 0.96835500E-01, 0.22355700E+00, -.33306600E+00, -.95807100E+00, 0.71688800E+00, 0.14462200E-01, -.61612300E-01, -.98285800E-01, 0.68807300E+00, -.58456500E-01, 0.75361800E-01, 0.40922500E-01, -.84232900E-01, -.76436500E+00, -.11637100E+01, -.16995900E+00, 0.10476100E+00, -.10386500E+00, 0.93081400E-01, 0.83058400E+00, 0.37107000E+00, -.24981800E+00, -.30768900E+01, -.10383800E+01, -.60498800E+00, -.57312700E+00, 0.17514800E+00, 0.12269100E+01, -.94918500E+00, -.56554300E+01, -.19363700E+01, 0.36616300E+00, -.13827400E-01, 0.61149800E-01, -.74629700E+01, 0.16769500E-01, -.45140700E+00, -.98430200E+00, 0.16178400E+00, -.77805500E+00, -.59326600E+00, 0.12072800E+01, -.90603900E-02, 0.23913100E+01, -.13425500E+00, -.11293500E+01, 0.81215100E-01, -.16301900E+01, 0.94658600E-01, -.61485700E+01, 0.90268500E+00, -.11606000E+01, -.11805700E+01, 0.42474500E-01, -.46858900E+00, 0.22661100E-01, -.51287600E+00, -.10043800E+01, 0.13305400E+01, -.72573500E-02, 0.41936500E+00, 0.87359200E+00, -.48524100E+00, 0.54425400E+00, -.19626800E+00, -.61521900E-01, 0.91421300E-01, -.80573700E+00, 0.27711500E+00, -.98251600E+00, -.83455800E+00, -.12933200E+01, -.62419600E+00, 0.18345800E+01, 0.67864400E+00, 0.39169200E+00, 0.10079600E+01, -.82206000E-01, -.20727100E+03, -.31319100E+02, -.32533600E+02, -.37019600E+02, 0.35794900E+02, -.63732200E+02, -.73822700E+02, -.19149700E+03, 0.86672500E+02, -.11026600E+03, 0.10088500E+03, 0.20080300E+03, 0.83369000E+02, -.17224600E+03, -.10081500E+03, 0.56503400E+02, 0.46856300E+02, 0.11530900E+03, -.10591000E+03, 0.65202400E+02, 0.46720900E+02, 0.52817400E+02, 0.91316700E+02, 0.67622300E+02, -.36703100E+02, -.60694000E+02, -.65894600E+02, 0.77654900E+02, 0.69014500E+02, -.21154600E+02, 0.13681900E+02, 0.37569200E+02, 0.99131700E+01, 0.10839700E+03, -.16253800E+00, 0.12124900E+01, -.80602000E+01, 0.14320700E+02, -.43144900E+02, -.53878100E+02, 0.10604200E+02, 0.59798300E+01, -.14588400E+02, -.84331000E+01, -.11380600E+03, 0.90177500E+01, -.33021500E+01, -.11466200E+03, 0.10350000E+03, -.49081000E+01, 0.17872500E+02, 0.25660700E+01, 0.92385300E+01, 0.10404100E+03, 0.43310200E+00, -.56527700E+01, 0.21964600E+01, 0.14131000E+02, -.12848800E+02, -.28754000E+01, -.38172300E+01, -.18819500E+02, -.68248800E+02, 0.24315800E+02, 0.57941100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.23541900E+02, 0.23971200E+01, 0.23515200E+00, 0.16497900E+01, 0.27573300E+01, -.50248800E+01, 0.33235200E+01, 0.40836600E+00, -.15281700E+01, 0.44324600E+01, -.13760800E+01, 0.39489300E+01, 0.39791700E+01, -.56738400E+01, 0.43757400E+00, 0.25706300E+01, 0.37559400E+01, -.10256700E+01, -.16979800E+01, 0.16498100E+01, -.10080600E+01, -.10635000E+01, 0.84680800E+00, 0.79388300E+01, 0.11954100E+01, 0.82323600E+00, 0.31903200E+01, -.14438100E+01, -.21209000E+01, 0.54564100E+00, 0.17271700E+00, 0.27148100E+01, 0.14425500E+01, -.83260200E+01, 0.19711800E+01, -.36158800E+00, 0.76771100E-01, -.16308900E+01, 0.28946000E-01, 0.41753800E+00, -.23738600E+01, -.12670100E+01, 0.17655600E+02, -.10430800E+01, -.87085800E+00, 0.27772700E+00, -.28275500E+00, -.11676700E+01, 0.66764800E+00, -.15196800E+00, -.48756600E+00, 0.15886500E+01, -.10361000E+01, -.13834600E+01, 0.80876700E+00, 0.47219000E+01, 0.11972400E+01, -.10654200E+01, -.44326700E-01, 0.42111000E+01, -.76157500E+01, -.21579700E+01, -.56045400E+00, -.19256400E+01, -.20177800E+01, -.27070300E+01, -.55416700E+00, -.58805000E+01, -.96182900E-01, 0.21157800E+00, -.50682400E+00, 0.13829900E+01, 0.52337700E+00, 0.50098200E+01, -.38500300E+01, 0.65200900E+00, -.66063800E+00, 0.48248900E+00, 0.21017400E+01, -.66927800E-01, 0.12132900E+00, -.13932100E+01, 0.10050000E+01, 0.14738200E+01, 0.93378200E+00, -.60800900E+00, 0.76521400E+00, -.52055400E+00, 0.14852700E+01, 0.29933800E+00, 0.43529900E+01, 0.10058800E+00, 0.12020200E+00, 0.11586400E+00, -.72473400E+00, -.49278900E+00, 0.17115500E+00, -.74324200E+00, 0.95827000E+00, -.13632700E+01, 0.48001300E+00, 0.71226100E+00, 0.83356900E-01, -.22961000E-01, 0.64809000E-01, 0.81890700E+00, 0.94587700E+00, 0.16443900E+00, -.24880400E+01, 0.37695200E+00, -.13562400E+01, 0.21218500E+00, 0.47797000E+00, -.26830400E-01, 0.87352500E+00, -.42370300E+00, 0.18018600E+00, 0.55900300E+00, -.32198300E+01, 0.19366800E+01, -.51036200E+00, 0.14807100E+00, -.19134000E+00, -.32050100E+00, 0.20250500E+00, 0.57072000E+00, -.71789100E+00, 0.41336300E+00, -.13690100E+00, -.10601300E+00, 0.17906500E+01, -.17571100E+01, -.14172600E+00, -.85184300E+00, 0.70397500E+00, 0.20934600E+00, -.29012300E+00, 0.11994900E+01, -.28771100E+01, 0.72419600E+00, 0.96607100E+00, 0.46777900E+00, 0.45918200E+00, 0.19968100E+01, -.40881800E+00, -.34990200E+01, 0.40442900E-01, 0.66133800E-01, -.94157200E+00, -.60494100E+01, 0.21966900E+01, -.15412400E+00, -.14123200E+01, -.19717100E+00, -.13080200E+01, 0.22358000E+00, 0.20218000E+00, 0.26167800E+00, -.27058600E+00, -.20168700E+01, -.38063100E+01, -.13077200E-01, 0.15222600E+01, -.19366100E+01, 0.86852100E-01, 0.51472500E+00, 0.63947600E+00, -.54271200E+00, -.42013000E+01, 0.17888500E+00, -.59426900E+00, -.42691900E+00, 0.32659600E+00, 0.11310100E+01, 0.88097300E+00, -.25042800E+01, 0.58790100E+00, 0.21855600E+00, 0.25691300E+00, -.27713800E+00, -.81709900E+00, 0.50186400E+01, 0.27209200E+01, -.79320800E+00, -.96839500E+00, 0.47459800E+00, -.41926500E-01, 0.19676100E+00, -.42540700E+00, -.19743100E+00, -.57604700E+00, -.96496900E-01, -.21427300E+01, 0.14776200E+01, -.27924300E+00, -.32496500E+00, 0.11719000E+00, -.84669200E+00, 0.17528200E+00, 0.21578700E+00, 0.80354600E+00, 0.15910700E-01, -.24417700E+00, 0.28046200E+01, -.27910700E-01, 0.25400500E+00, -.40443000E+00, 0.56064400E+00, 0.63386500E+00, 0.54605100E+00, 0.38636400E+00, 0.13863900E+00, 0.56390600E-01, -.87188100E-01, -.10098400E+01, 0.35504200E+01, 0.16504700E+00, 0.37667900E+00, 0.74782500E+00, 0.33246300E+01, 0.76473900E+00, 0.10302900E+01, 0.74015000E+00, -.14283700E+01, 0.10926000E+01, 0.10568000E+03, 0.65189100E+02, 0.47063400E+02, -.13182400E+02, 0.14497100E+03, 0.26538300E+03, -.21625800E+03, 0.94757600E+02, -.26576100E+03, 0.10881000E+03, -.80521300E+02, -.94372700E+02, 0.15525800E+03, -.51749200E+02, 0.10279700E+03, -.39731200E+02, 0.12480200E+03, 0.46316400E+02, -.30784700E+02, -.73010100E+02, -.24337200E+02, 0.70696600E+01, -.47023100E+02, -.21779700E+02, 0.29996100E+02, 0.80731700E+02, -.55993600E+02, 0.30784700E+02, 0.74143500E+02, -.42326200E+02, -.11340800E+03, -.36717500E+02, 0.62556400E+02, -.18826600E+02, -.10126000E+02, -.32673200E+02, 0.29668600E+02, -.55789300E+02, -.16887400E+03, -.16950900E+00, 0.27387100E+01, -.14668200E+02, 0.41637400E+01, 0.26406400E+02, -.77034800E+00, 0.18237600E+01, 0.31040800E+02, -.58863100E-01, -.85651600E+01, -.33769600E+01, -.20236200E+01, -.47438300E+01, -.23261600E+01, 0.16621200E+01, 0.19654700E+01, -.45404600E+01, -.30696200E+01, -.49241300E+01, 0.24630900E+01, -.10174600E+01, 0.71950700E+01, 0.41403300E+02, -.75486500E+01, 0.17952400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.90164200E+01, 0.94965400E+00, -.10564300E+00, 0.49545100E+01, 0.38048500E+01, -.40977000E+01, 0.11119000E+01, -.94334100E-01, -.18781700E+01, 0.16395400E+01, -.61513600E+00, 0.44901800E+00, -.78184800E+00, -.40926200E+01, 0.13348600E+00, 0.10392500E+01, -.69973300E+00, -.35073100E+01, 0.19408600E+01, -.16403500E+01, -.13840000E+01, -.61237600E+00, 0.28955800E+00, 0.14714100E+01, 0.40474900E+00, 0.80616800E+00, 0.21360200E+01, 0.11743500E+01, -.21062600E+01, 0.95995300E+00, 0.10072100E+00, -.26661700E+00, -.13418700E+00, -.46919900E+00, 0.25601200E+00, 0.63622600E-01, 0.44754000E-01, -.39661200E+00, 0.38800700E+00, 0.29226800E+00, -.56571700E-02, -.35169600E+00, -.19138900E+01, 0.55058000E-01, -.15261300E+00, -.20162500E+00, 0.98150300E-01, -.82888800E+00, 0.13223200E+01, -.95775800E-02, 0.78226700E+00, -.47561400E+00, -.93965100E+00, -.73650300E+00, 0.16238700E-01, 0.18601100E+01, 0.49881600E-01, -.30417300E+00, 0.16400100E-02, 0.10357900E+00, -.12337400E+01, -.85575000E+00, 0.51946500E-01, 0.45982000E+00, -.78357700E+00, 0.45109700E+00, -.37083300E+00, -.59565700E+01, -.13264900E-01, 0.13982600E-01, -.87444400E+00, 0.57480500E+00, -.20560600E+01, -.97820400E+00, 0.14713400E+01, -.50104800E+00, 0.36389400E+00, 0.15731400E+01, 0.86323700E+00, 0.64382600E+00, -.33971300E-01, -.51853800E+00, 0.51088400E+00, -.97334000E-01, -.38822800E+00, 0.10039200E+00, 0.42440000E+00, -.47576600E+00, -.15043900E+01, 0.14593000E+01, -.54937700E+00, -.29315000E-01, 0.30923700E-01, -.22059700E+00, 0.96273000E-01, 0.10275100E+00, 0.92335300E-01, 0.51244500E+00, 0.32044800E+00, -.10469000E+00, 0.32555900E+00, 0.23188400E+00, -.34460200E-01, -.26234900E+00, 0.48131800E+00, 0.26858500E-01, -.80553300E+00, -.10481500E+00, 0.52299700E-01, 0.34288300E-01, -.32198400E+00, 0.26407000E+00, 0.90425300E+00, -.56521900E-02, -.11634500E+00, -.14403300E+00, -.62326500E+00, -.30836000E+00, 0.23825500E+01, -.57687400E+00, 0.58765500E-01, -.42488900E+00, -.48730100E-01, 0.11063900E+00, 0.24919900E-01, 0.10977400E+00, 0.41107900E+00, -.12641200E+00, -.21204100E+00, 0.48817600E+00, 0.39538900E+00, 0.14048300E+00, -.35270000E-01, 0.48896000E+00, -.22567500E+00, -.47599700E-01, -.71298600E+00, 0.27167000E+00, -.37588800E+00, -.61389000E+00, 0.25134700E+00, -.65381300E+00, -.40939400E+00, -.91711900E+00, -.23174700E+00, 0.10425700E+01, -.11240400E-01, 0.60586900E-01, 0.15255900E+00, -.17502500E+01, 0.73078400E-01, 0.15092600E+00, 0.16801800E+00, -.70374500E-01, -.14419300E+00, 0.14399400E+00, 0.30326400E-01, 0.19691300E+00, 0.71319700E-01, -.27392300E+00, -.14616100E+01, 0.29015000E-01, 0.29841900E-01, -.20461500E+01, 0.68788700E+00, -.18906100E+00, -.81355900E-01, 0.19409400E+00, 0.13007600E+01, 0.40096200E+00, 0.31383000E+00, 0.13138500E+01, -.28174800E+00, -.35947500E+00, -.43353500E+00, -.25472300E+01, -.71297000E+00, 0.36964400E+00, -.10078800E+00, 0.83536600E-01, -.27377600E+01, -.11114800E+01, -.26404100E+00, 0.46940100E+00, -.20130600E+00, -.12071200E+00, -.36186700E+00, -.13972400E+00, 0.15104000E+00, 0.16920500E+01, -.91839700E-01, -.53880400E-01, 0.98696900E+00, 0.20690100E+00, -.22274500E+00, -.34357500E+01, -.11565500E+01, -.77960700E+00, 0.56200500E+00, -.92138600E-01, 0.37309300E+00, 0.10224800E-01, 0.77067300E-01, 0.27007200E+01, 0.29120400E+00, -.14973400E+00, -.10127800E+00, -.44002600E-01, -.43220900E+00, 0.33544700E+00, 0.60577700E-01, 0.49969400E-01, 0.22890600E-01, 0.12335600E+00, 0.60959200E+00, -.22543600E+01, 0.10717700E-01, 0.10935400E+01, 0.22613100E+00, -.27513100E+00, 0.47145200E+00, 0.15829200E+00, -.20774600E+00, -.60420300E+00, -.54267300E-01, 0.32996600E+00, -.99808500E+02, -.10987600E+03, 0.18013700E+01, -.36689400E+02, -.11128100E+00, -.84590800E+01, 0.99130900E+01, 0.26585800E+03, 0.70409500E+01, 0.38188300E+02, 0.46822200E+02, -.43269800E+02, 0.50636600E+02, -.23529200E+02, 0.20229700E+02, -.33405500E+02, -.44687200E+02, 0.30974500E+02, 0.47540700E+02, 0.22195100E+02, -.28993500E+01, 0.15072300E+02, -.95290500E+01, -.24997100E+02, -.21517700E+02, 0.26703700E+02, 0.27634100E+02, -.27916400E+02, 0.13380900E+02, 0.30670100E+02, 0.13542300E+02, -.49491100E+02, -.76700900E+01, -.72238600E+01, -.48053700E+01, 0.54427400E+01, 0.69809700E+01, 0.11879700E+03, -.31463100E+01, -.20108000E+01, 0.92586300E+01, 0.90925800E+00, -.96916100E+01, -.14466500E+01, 0.22827800E+01, -.10719800E+02, -.27557400E+01, 0.18711700E+01, 0.15373200E+01, -.59423400E+00, 0.47118200E+01, -.11932100E+01, -.13336100E+01, 0.18871200E+01, -.44061600E+01, 0.13176300E+01, 0.28098800E+01, 0.49040800E-01, 0.95047300E+00, -.36994400E+01, -.13955100E+02, -.17109100E+01, -.28954500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11281300E+02, -.12327500E+01, 0.34055900E-02, -.55258500E+01, -.32979400E+01, 0.47515900E+01, -.19844400E+01, 0.99986900E-01, 0.17142600E+01, -.24020900E+01, -.18927900E+00, -.10338500E+00, 0.12090600E+01, 0.29855500E+01, -.54930200E+00, -.12211500E+01, 0.10227400E+01, 0.35089500E+01, -.30634900E+01, 0.11065100E+01, 0.12156800E+01, 0.51800700E+00, -.37871100E+00, -.13117900E+01, -.20236600E+00, -.89589700E+00, 0.58482700E+00, -.55191800E+00, 0.24440200E+01, -.10270100E+01, -.17623400E+00, -.38421700E+00, 0.97408000E+00, -.13650200E-01, 0.26561100E-01, 0.46215400E+00, 0.48867000E-01, 0.72599300E-01, -.32009100E+00, 0.10419200E+01, -.64676300E+00, 0.38194000E+00, 0.35882000E+01, -.93981900E-01, 0.23256300E+00, 0.65464800E+00, -.10851200E+01, 0.16968100E+01, -.10310400E+01, 0.23292900E+00, 0.65942600E+00, -.60665300E+00, 0.42182400E+00, 0.11956300E+01, 0.11078200E+01, -.29331200E+01, 0.45734300E-01, 0.66591600E+00, -.69856300E-04, -.19621700E+01, 0.25854500E+01, 0.10516000E+01, -.33600800E+00, -.11611100E+00, 0.14602400E+01, -.13599500E+01, 0.61613200E+00, 0.46021200E+01, -.29133100E-01, -.16690000E-01, 0.10242500E+01, -.73124800E+00, -.11383400E+01, 0.42632400E+00, -.15587700E+01, 0.24080500E+01, -.66440200E+00, -.19949400E+01, -.87007700E+00, 0.24451900E+00, 0.59694200E-01, 0.27955600E+01, -.63479600E+00, 0.10890000E+01, 0.86204100E+00, -.60577300E+00, -.32477100E+00, -.17190700E+00, 0.15675400E+01, -.70407600E+00, 0.20890700E+01, 0.49666500E-01, 0.72043600E+00, 0.18395800E+00, -.49803500E+00, 0.21537700E+00, 0.17019700E+01, -.96992400E+00, -.11495900E+01, 0.10078600E+00, 0.11064600E+01, -.42134200E+00, 0.12006600E+00, 0.29977900E+00, -.61655500E-01, 0.40600000E+00, 0.16385200E+00, -.37884900E-01, 0.45077200E+00, 0.62952300E+00, 0.16669900E+00, 0.24694500E+00, -.31188900E+00, 0.74399200E-01, -.18093500E+00, 0.49134600E-01, -.38025700E+00, -.10473700E+01, 0.12282200E+01, 0.44279000E+00, -.82810200E-01, 0.52940500E+00, 0.10017300E+00, 0.58641900E+00, -.88592600E-01, -.51023500E+00, -.53790100E+00, 0.24883000E-03, -.13261700E+00, -.42669700E+00, -.28994900E+00, 0.58410400E+00, -.10964300E+00, -.13396400E+00, -.96052000E-01, 0.63362200E-01, 0.39857400E+00, -.30475000E+00, 0.39239700E+00, 0.41560100E+00, -.54797700E+00, 0.26196700E+00, -.61673400E-01, -.13045800E+00, 0.27878100E+00, -.61335900E+00, 0.13397000E-01, -.21037700E-01, -.79482600E-01, 0.89133800E+00, -.57328000E-01, 0.90850200E-01, 0.13529700E+00, 0.88444200E-01, -.44875900E-04, 0.14910200E+00, -.48245000E-02, -.15224100E+00, 0.29755600E+00, -.10344100E+01, 0.48912800E+00, 0.65476500E-01, -.23871800E+00, -.36878700E+00, 0.22588500E+00, -.85970100E-01, -.46214700E-01, -.16700800E+00, -.11194300E+01, -.20491100E+00, 0.12174400E+00, -.52738500E+00, -.40359200E-01, 0.30159600E-01, 0.21050600E+00, -.82381300E+00, 0.24489700E+00, 0.69673800E-01, -.32133800E+00, 0.93902500E-01, -.39577000E+00, 0.99466200E+00, 0.24636800E+00, -.64730600E-01, 0.11206200E+00, 0.19485900E+00, -.24178300E+00, -.20177300E+00, -.30209100E-01, 0.53297800E+00, 0.13475200E+00, -.10629500E+01, -.82307800E+00, -.15699800E+00, 0.47126800E+00, -.24779900E+01, -.27648200E+01, -.87373000E+00, 0.32009200E+00, -.22392400E+00, 0.56345400E+00, -.71816200E-02, -.48186900E-01, 0.30313800E+01, 0.10281400E+00, -.12418800E+00, 0.24515500E+00, 0.25470900E+00, -.85632900E+00, 0.26868200E+00, -.55197700E-02, 0.11614100E+00, -.46832000E-01, -.90603700E-01, 0.22474500E+00, -.44584400E+00, -.15544300E+00, 0.94169100E+00, 0.42801000E+00, 0.61096800E+00, 0.22505400E+00, 0.21532000E+00, 0.73345700E-01, 0.49874300E+00, 0.10155500E+00, 0.29518200E+00, 0.51449200E+00, 0.44401700E+02, 0.21372800E+02, 0.10675500E+02, -.12419400E+03, 0.34400800E+02, -.36170200E+02, -.10105300E+03, -.19711900E+02, 0.23760300E+02, 0.60457500E+01, -.57926500E+02, -.62529200E+02, -.13415400E+02, 0.10558400E+01, 0.10589200E+02, 0.14987700E+02, -.76447300E+01, -.30298100E+02, -.71553400E+01, 0.20814300E+02, 0.24799800E+01, 0.12586900E+02, 0.40523200E+01, -.27530900E+02, -.14101900E+01, -.27060500E+01, 0.35775500E+02, -.16703900E+02, -.23229300E+02, -.17600000E+02, 0.74217400E+02, 0.28905200E+01, -.61810000E+01, 0.29271300E+02, -.10410400E+02, -.92150600E+01, -.11084600E+03, 0.28352500E+01, 0.23657500E+01, -.12753200E+02, -.19965100E+01, -.61168000E+01, 0.59989300E+01, -.50949500E+01, -.75329800E+01, 0.37937100E+01, -.18116600E+01, 0.38245500E+01, 0.12847300E+01, -.10289000E+01, 0.33659400E+01, 0.34169500E+01, -.11240900E+01, 0.10419000E+02, 0.29534200E+01, -.50226600E+01, 0.43041100E+01, -.42324600E+01, -.30516400E+01, -.66863700E+01, 0.10457900E+02, 0.38767900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15917100E+02, 0.19314400E+01, 0.42081200E+01, 0.80385400E+01, 0.67607400E+01, -.59393200E+01, 0.29284100E+01, 0.61841800E+00, -.12778900E+01, 0.50162400E+01, 0.33682200E+01, 0.20359800E+01, 0.37160300E+01, 0.80031300E+01, -.49395000E+00, 0.35557100E+01, 0.76659800E+01, 0.48456700E+01, 0.24720200E+01, 0.12245900E+01, -.54670100E+01, -.95227600E+00, -.80972800E-01, 0.54852600E+01, 0.12927000E+01, 0.33734400E+00, -.11363100E-01, 0.37999700E+01, -.10643400E+01, -.14660200E+01, 0.40703500E+00, 0.12118600E+01, 0.29460500E+01, 0.22600200E+00, 0.61723800E-01, -.63183800E+00, 0.55391000E-01, 0.16659200E+00, -.59556600E-01, -.66304800E-01, 0.60320000E+00, 0.10391400E+01, -.27789700E+01, -.88950600E-01, -.74211900E+00, 0.18764400E-01, 0.14251300E+01, -.11588100E+01, 0.39498000E+00, 0.53687100E+00, 0.11080400E+01, 0.54185500E+00, 0.36807500E+00, -.26205800E+01, 0.17732100E+01, 0.16765900E+01, 0.84243900E+00, 0.35802900E+00, -.13117700E-02, -.24404700E+00, -.48377000E+01, -.20038700E+01, 0.18788100E+00, -.16136200E+01, 0.17650900E+01, -.16425300E+01, -.43469900E-01, -.89358300E+01, 0.55054800E+00, 0.95275500E-02, 0.87122300E+00, -.35260700E+00, -.56791400E+00, 0.74749400E+00, 0.50969400E+00, 0.50501800E+00, -.13223300E+00, -.10436500E+01, 0.62249000E+00, 0.29085500E+00, -.28199100E-01, -.49255100E+00, 0.14831100E+01, -.37550900E+00, 0.18392300E+00, 0.21152100E+00, -.10307700E+01, 0.42966300E+00, -.12010100E+01, -.21515300E+00, -.29567900E+01, 0.42688900E-01, -.59362400E+00, 0.29854500E+00, 0.20654100E+01, -.20387700E+00, -.30581100E+01, 0.14213300E+01, -.63116100E+00, 0.13586800E+00, -.13355000E+01, -.76823000E-02, -.81854000E-01, -.53934900E+00, 0.25518800E-01, -.70304500E+00, 0.10237200E+01, 0.24324400E+00, -.49075400E+00, -.51246000E+00, -.80944200E+00, -.44623900E-01, 0.11070900E-01, 0.22055200E-01, 0.77892200E+00, -.21469300E+00, 0.37230500E+00, -.10068100E+01, -.73238900E+00, 0.36864000E-01, -.82461600E+00, -.30716100E+00, 0.25142400E+00, -.19124300E+00, -.71483300E-01, 0.32025400E+00, 0.16793400E+00, -.76430600E-01, -.20623400E+00, 0.15605100E+00, 0.10633900E+01, -.77549100E+00, 0.84412900E+00, -.26105500E+00, -.50493300E-01, 0.57950400E-01, -.77940800E+00, -.14386200E+00, -.71816100E+00, -.30299200E+00, 0.79235400E-01, 0.61614800E+00, -.65451400E+00, -.12835600E+01, 0.25482000E-01, -.17519300E+00, -.75595400E-01, -.16493300E+00, 0.23431200E+00, -.11591400E+01, -.30292300E+00, 0.20711300E+00, 0.19943200E+00, -.29624800E+00, -.43905600E+00, 0.53576900E-01, -.12602200E+00, 0.61038500E-01, 0.11943600E+00, -.87906400E-01, -.84383100E+00, 0.29175200E-01, -.27504000E-01, -.16826700E+01, -.44762100E-01, 0.17408700E+00, 0.43689800E+00, -.12577400E+00, -.14462100E+01, 0.11524900E+00, 0.72209500E-02, 0.54965400E+00, 0.30219600E+00, 0.52051600E+00, -.41207900E+00, -.24266100E+01, -.98736400E+00, 0.41075900E+00, 0.17409600E+00, -.11589400E+00, -.20094200E+01, 0.23469200E+01, 0.40548500E+00, 0.12294300E+00, 0.49859600E+00, 0.69215900E-01, -.11470600E+00, 0.29336400E+00, 0.42485500E-01, 0.28769300E+00, -.20428900E+00, -.10672400E+01, -.64462400E+00, -.12486000E+00, 0.18842400E+00, -.16977100E+01, 0.81344100E+00, -.24115900E+00, 0.13075600E+00, -.16036100E-01, 0.34429400E+00, 0.10259500E-01, -.25631400E+00, 0.36157900E+01, -.64816600E+00, -.36807600E+00, 0.31434400E+00, -.27567100E+00, 0.30047000E+00, 0.37412300E+00, -.38266800E-01, -.11828400E+00, -.46823300E-01, 0.62358200E+00, 0.43603200E+00, -.15500000E+01, -.56525300E+00, -.19449000E+00, 0.26716200E+00, 0.10296200E+01, -.47042900E+00, 0.71696900E+00, -.67362100E+00, 0.28049100E+00, 0.29681700E+00, -.49790200E+00, -.10433200E+00, -.84213600E+00, 0.97438500E+02, 0.37561900E+02, -.14185200E+03, -.17715800E+03, 0.52398500E+02, -.19449500E+03, 0.86972700E+02, -.25032700E+02, -.42184700E+02, 0.13293200E+03, -.14632500E+02, 0.91302500E+02, -.91809400E+01, 0.11343700E+03, 0.61740900E+02, -.24051600E+02, -.10233500E+03, -.31130200E+02, 0.17047900E+02, -.49204500E+02, 0.32429900E+02, 0.35536700E+02, 0.45298400E+01, -.52744900E+02, 0.10443600E+03, -.57865900E+02, 0.26257000E+02, -.28728300E+02, 0.29319600E+02, 0.83473600E+02, -.55161500E+02, 0.42606600E+02, 0.42456000E+02, 0.64216200E+02, -.79027300E+02, -.74491100E+02, 0.23994600E+00, -.45519200E+00, -.26951400E+02, 0.42059700E+00, 0.34232100E+01, 0.46098600E+01, -.32047900E+01, 0.52189000E+01, -.19134600E+02, -.36995600E+01, -.97861700E+00, -.25473500E+01, -.62855600E+01, -.20939500E+02, 0.47389700E+01, 0.75535400E+00, 0.65613100E+01, 0.25551200E+01, -.25175300E+01, 0.79982200E+01, -.40957600E+01, -.79673700E+01, 0.13817600E+02, 0.56838100E+01, 0.12643700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57858500E+01, 0.47902100E+00, -.13851200E+01, 0.17406000E+01, -.23908600E+01, -.34846900E+01, 0.38963300E+01, 0.14127800E-01, -.46155800E+00, 0.23614200E+01, -.10789600E+00, -.54816300E+00, -.23533000E+01, -.59873500E+00, 0.32734100E+00, 0.22506500E+01, -.62534600E+00, -.10951200E+01, 0.94826600E+00, -.86519900E+00, 0.35189800E+00, -.28199400E+00, 0.38615900E+00, -.67225300E+00, 0.11434500E+00, -.52812200E-01, 0.19107400E+01, -.22805500E+01, -.20177000E+01, 0.88885400E+00, 0.47623100E-01, -.73843900E+00, 0.89131300E+00, -.12087100E+01, 0.32950700E+00, -.46675600E+00, 0.43199500E-01, -.66084700E-01, -.30074800E+00, -.22835600E+01, -.28861800E+00, -.77702600E+00, -.70692600E+00, 0.24695600E-01, -.81806600E+00, -.52857200E+00, -.11354400E+00, -.10106000E+01, 0.26559600E+00, 0.61364100E-01, -.34170800E+00, 0.74403200E+00, -.61035000E+00, -.18175700E+01, -.62686700E+00, 0.29904100E+01, 0.22935200E+00, -.30139000E+00, 0.17931200E-02, 0.26680700E+01, -.30961400E+01, -.77952200E+00, -.17965300E+00, 0.37851500E-01, -.12193200E+01, 0.35542000E+00, -.11339300E+00, -.21709400E+01, -.12518300E+00, -.20222700E-02, -.10840700E+01, 0.23398400E+00, -.34065800E+00, 0.60453800E+00, 0.42160100E+00, -.16588100E+01, 0.41844800E+00, 0.18402700E+01, 0.25170800E+00, 0.62125400E+00, -.46899300E-01, -.21802100E+01, -.41561300E+00, -.16913900E+00, -.49080300E+00, -.60946700E-02, 0.12439700E+01, -.63111500E+00, -.14103300E+01, 0.15929200E+01, 0.13637800E+01, -.29034100E-01, 0.75238000E+00, -.47324600E+00, -.13816200E+01, -.60542600E+00, 0.19222200E+01, -.10789500E+01, 0.10070800E+01, -.56147000E+00, 0.22878200E+00, 0.97555400E+00, 0.35955600E-01, 0.13021600E+00, 0.91717800E-01, 0.45258200E+00, -.43276800E+00, -.44848100E+00, -.26730600E+00, 0.50530200E-01, 0.50827900E-01, -.77222400E-01, -.33046600E+00, -.11794100E-02, 0.10763800E+00, 0.16528900E+00, -.80813700E-01, 0.56544800E+00, 0.51242600E+00, -.41489900E+00, 0.78825800E-01, -.33894600E+00, 0.86428900E-01, 0.32740300E+00, -.60230800E-01, 0.36087200E-01, -.56538400E+00, 0.26056500E-01, 0.10646200E+00, -.85029300E-01, -.65352200E+00, 0.83404100E+00, -.35405900E+00, 0.33340700E+00, -.11664500E+00, -.53819000E-01, 0.20811100E+00, 0.30644300E+00, 0.15617800E+01, -.49918300E+00, 0.20867700E+00, -.55191900E+00, -.52505300E-01, 0.12260600E+00, -.25497400E+00, 0.62950800E+00, 0.13370600E+00, 0.23861800E+00, -.40849200E+00, -.98009200E+00, 0.12690100E+01, 0.87956500E-02, 0.61594500E-01, -.71199400E-01, -.12228300E+00, 0.47372100E-01, 0.81675700E-01, -.60779600E-01, -.67011100E-01, 0.10722200E+01, 0.13258300E+00, 0.13195700E+00, -.30952300E+00, -.12274300E+01, 0.57416500E+00, 0.17605600E+00, 0.30154200E+00, -.78956500E-01, -.39271800E+00, 0.64021100E+00, -.73183900E-01, 0.64014500E+00, 0.79876700E-01, -.50310700E+00, 0.22977400E+00, 0.53285900E+00, -.12853700E+00, -.15076200E+00, 0.82098700E+00, 0.13751800E+00, 0.42609300E+00, -.26983800E+01, -.93112500E+00, 0.34864600E+00, -.20049400E+00, -.29450400E+00, -.83794400E-01, -.22397500E+00, 0.66930700E-01, 0.88102000E+00, 0.21001100E+00, 0.15160600E+00, 0.67592300E+00, 0.10618800E+00, -.21138800E+00, -.27333200E+00, 0.90427600E+00, 0.12511200E+00, -.20511300E+00, 0.17093700E-01, -.13876400E+00, -.77917800E-02, 0.22657300E+00, -.40116400E+00, 0.86531700E-01, -.27971700E-02, -.94534400E-01, 0.95957900E-01, -.31954800E+00, 0.19963900E+00, 0.20156400E-01, 0.14433200E+00, -.31725200E-01, 0.29187500E+00, 0.98493100E-01, -.18691500E+00, 0.38720500E+00, 0.97451900E+00, 0.61818700E-01, -.51745600E+00, 0.14867500E-01, -.13483800E+00, -.16098100E-01, 0.11841100E-01, -.17281700E+00, 0.28210600E+00, 0.41218000E+00, 0.45636200E+00, -.48049100E-01, -.23024400E+02, 0.40794100E+01, 0.51475900E+02, -.19578700E+02, 0.28410200E+02, -.25658600E+02, -.42078900E+01, 0.18931300E+02, -.37014900E+02, -.10528900E+02, -.31706000E+02, 0.11177300E+02, -.31410500E+02, -.11713900E+02, 0.46353700E+01, 0.12292100E+02, 0.60191400E+01, -.11000100E+00, 0.87003100E+01, -.56534300E-01, -.62963000E+01, -.18169600E+01, 0.12802200E+02, -.47962200E+01, -.39306100E+02, 0.20302500E+02, 0.29287700E+02, 0.19563700E+02, -.22568400E+02, 0.20458800E+01, 0.81568700E+01, -.16084600E+02, 0.10061000E+02, 0.12844000E+02, 0.40166200E+02, -.32982700E+01, -.77691400E+00, 0.10633700E+02, 0.11452000E+01, 0.87247000E+01, -.20374900E+01, 0.15374000E+01, 0.81533700E+01, -.24328100E+01, 0.22829200E+01, -.26513700E+01, -.17996900E+00, 0.28053500E+00, -.21914500E+01, -.62007500E+00, 0.12839400E+01, -.27848500E+01, -.23953700E+01, 0.28652200E+01, -.20845500E+01, 0.13647300E+01, 0.24023900E+00, 0.27888800E+01, -.29739200E+01, -.36539500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13272100E+02, -.14279700E+01, -.47643700E-01, -.57212900E+01, -.48810900E+01, 0.50148100E+01, -.15150300E+01, 0.42211100E-01, 0.23041600E+01, -.26372700E+01, 0.10877800E+01, -.12293300E+01, 0.13750600E+01, 0.58638700E+01, -.24132600E+00, -.19463500E+01, 0.31498000E+00, 0.48325400E+01, -.32279700E+01, 0.21068000E+01, 0.13592100E+01, 0.62996900E+00, -.60116900E+00, -.19104200E+01, -.34156700E+00, -.41162300E-01, -.26221300E+01, -.11746200E+01, 0.37923700E+01, -.12597600E+01, -.24198000E+00, 0.77292300E+00, 0.43714900E+00, 0.40261500E+00, -.30113600E+00, -.20358900E+00, -.27554200E-01, 0.36733400E+00, 0.63034400E-02, -.33353800E+01, -.11104700E+01, -.86596600E+00, 0.73630600E+01, -.34715400E+00, -.19471600E+01, -.21270300E+00, -.11910400E+01, 0.15524500E+01, -.19168500E+01, -.27944300E-01, 0.22451900E+01, 0.28993600E+00, 0.11284800E+01, 0.32348100E+01, 0.94288100E+00, -.32017600E+01, -.16549200E+00, 0.70305800E+00, 0.18462500E-02, -.36143200E+01, 0.26082800E+01, 0.18335400E+01, -.20462700E+00, 0.81693800E+00, 0.14572700E+01, -.67953800E+00, 0.70069400E+00, 0.89673200E+01, -.43346100E+00, -.16891800E-01, 0.19144500E+01, -.70460900E+00, 0.27046200E+01, 0.40151000E+00, -.14401500E+01, 0.17504600E+01, -.51143600E+00, -.29957000E+01, -.15326800E+01, -.54859100E+00, 0.62155500E-01, 0.19678400E+01, -.41361400E-01, 0.36478800E+00, 0.68707600E+00, -.49039900E+00, -.10914800E+01, 0.75022300E+00, -.37397700E+00, -.25573400E+00, -.21238000E+01, 0.86322900E-01, -.68125800E+00, 0.57833000E+00, 0.14350400E+01, 0.61908400E+00, -.79345400E+00, 0.49203600E+00, -.10377300E+01, 0.10208000E+01, 0.25689800E+00, -.75983300E+00, 0.12264200E+00, 0.28619500E+00, -.74439700E+00, 0.92779700E+00, 0.14406700E+01, -.31771700E-02, -.44516200E+00, 0.34318000E+00, -.15051800E+00, 0.83726900E-01, -.21282000E+00, 0.33943700E-01, 0.66677400E-01, -.24291200E+00, -.82745400E+00, 0.11910900E+00, -.19873100E+01, 0.50257600E+00, 0.18393300E-01, 0.40806500E-01, -.10370100E+00, -.29206700E-01, 0.14293800E+00, -.65466900E+00, 0.13680300E+00, -.25816500E+00, 0.19368600E+00, 0.72811400E-01, 0.22892700E+01, -.28099800E+01, -.42073700E+00, -.32157700E+01, 0.84705300E-01, 0.91074900E-01, 0.37715400E+00, -.38834900E+00, 0.28904100E-01, 0.12714600E+00, 0.70468200E-01, 0.98071900E+00, 0.25746400E+00, -.79746300E+00, 0.30943900E+00, -.16514400E+01, -.13997300E+00, -.12389100E-01, 0.65240000E-01, 0.22774000E+00, -.10743700E+00, 0.14487200E+00, 0.15084600E+00, 0.16316200E+00, -.14983600E+01, 0.11384000E+00, -.11229500E+00, 0.10902000E+00, 0.27667000E+00, -.82584000E+00, 0.23390600E+00, 0.17459600E+00, -.19479400E+00, 0.61646600E+00, 0.31096300E+00, -.16533800E+00, 0.17511500E+00, -.16675900E+00, -.13122600E+01, 0.79216700E-01, -.29656300E+00, -.53547900E+00, 0.18495000E+00, -.38083900E+00, 0.10005400E+01, 0.84246900E+00, 0.11436600E+01, -.24225500E+00, 0.41311400E-01, -.18834800E+00, 0.28592100E+01, 0.77913500E+00, -.18840900E+00, 0.14607400E+00, -.14118700E+00, 0.79658600E+00, 0.38562600E-01, -.67796200E+00, -.29548800E-01, -.18366400E+00, -.13004900E+00, -.55241700E+00, -.71758200E+00, 0.10668300E+01, 0.34301800E-01, 0.39491300E+01, 0.72344800E+00, 0.54664400E-01, 0.90488300E+00, -.11250200E+00, 0.26817900E+00, -.33931500E-02, 0.10552300E+00, -.26011500E+01, 0.94804200E+00, -.33866300E-01, -.17691600E+00, -.22278600E+00, 0.55493200E-01, 0.81113800E-01, 0.68546300E-02, 0.21921000E+00, 0.40996100E-01, -.31752700E+00, 0.18563600E+00, 0.22608300E+01, 0.65096500E-01, 0.65783800E-01, 0.38730100E+00, 0.27065100E+00, -.58375300E+00, -.10747700E+00, 0.31354900E+00, -.97553800E+00, 0.16594400E+00, -.97900600E-02, -.57611500E+00, 0.33696600E+00, 0.93163700E-01, 0.54258800E+00, 0.21755900E+03, -.12654200E+03, 0.75493400E+02, 0.14262200E+03, 0.68449200E+02, 0.33209700E+02, 0.25090200E+02, 0.37820700E+02, 0.99744800E+01, 0.88149400E+01, 0.33216200E+02, 0.33871400E+02, -.10627900E+03, 0.58930900E+02, 0.67066000E+02, 0.52071400E+02, 0.27208600E+02, 0.33868300E+02, -.36042700E+02, -.47148700E+02, -.13064400E+02, 0.41312000E+02, 0.35023600E+02, 0.14840900E+02, -.74071600E+01, -.28650700E+02, -.78739500E+01, 0.63573800E+01, -.78409900E+01, -.73908700E+01, -.21725600E+02, 0.24344700E+02, -.27625400E+02, -.75587600E+01, -.24420100E+01, 0.21485700E+01, 0.17996000E+01, 0.27587600E+01, -.15815000E+02, -.65149400E+00, 0.15290200E+01, -.15263500E+02, 0.28903700E+02, -.35398600E+01, -.33026200E+00, -.75608400E-01, 0.26223200E+01, 0.29657300E+02, 0.13573900E+00, 0.22175000E+01, -.55304900E+01, -.27112000E+01, -.24825400E+01, 0.74271500E+00, -.45815800E+00, 0.51414100E+01, -.82428500E+01, -.35589600E+01, 0.65847200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11912600E+02, 0.83359300E+00, -.12923800E+01, -.38879200E+01, -.43081600E+00, 0.49569700E+00, 0.39529400E+00, 0.71477800E+00, -.44314100E+00, 0.12467100E+01, -.10954300E+01, 0.28097200E+01, 0.27296800E+01, -.19466900E+01, 0.46876300E+00, 0.10535500E+01, 0.45796600E+01, 0.56010700E+00, -.43460700E+01, 0.40688900E+01, 0.11895400E-01, -.19770200E+00, 0.14738500E+01, 0.27884000E+01, 0.22657800E+00, -.53846700E-01, 0.35261600E+00, -.49727800E+01, 0.11000200E+01, -.37774600E+00, -.63946900E+00, 0.23308700E+01, 0.32848300E+01, 0.14255100E+01, -.13029800E-01, 0.24109000E+01, -.32605900E-01, 0.22887400E+00, 0.10470000E+01, 0.14903000E+01, 0.43261900E+00, -.12375200E+00, 0.79330600E+01, -.47381400E+00, -.46594400E+00, 0.61800500E+00, -.16296700E+00, 0.86710700E+00, 0.27011400E+00, 0.12313600E+00, -.12398400E+01, -.93273200E+00, 0.42634700E+00, 0.30968000E+01, 0.99055800E+00, -.63024700E+00, 0.28303000E+00, -.15444400E+01, 0.86189900E-02, -.22572300E+00, -.11390300E+01, -.18356600E+01, 0.33613300E+00, -.11052900E+01, -.83831000E+00, 0.39661100E+00, -.32835800E+00, 0.15315000E+01, -.18655700E+00, -.86103000E-02, 0.11589300E+01, -.54286900E+00, 0.14450500E+01, 0.20913200E+01, -.46330300E+00, -.11905600E+01, -.53199700E+00, 0.17361100E+01, -.43946500E+00, -.36493900E+00, -.96486800E-02, 0.55418600E+00, -.10890600E+01, 0.30665600E+00, -.20133800E+00, -.31383900E-01, -.12001900E+00, 0.92386500E-01, -.24338700E+00, 0.10465100E+00, 0.14869000E+01, 0.13038700E-01, 0.43062800E+00, -.46524100E+00, -.28295700E+01, 0.10328800E+00, 0.85018500E+00, -.96883500E-01, 0.39356900E+00, 0.18289400E+00, -.61124400E-01, 0.29088100E+00, 0.27065300E-02, -.49952700E+00, -.16296800E+00, 0.40323300E+00, -.50845100E+00, -.49191300E+00, 0.20202100E+00, 0.83735100E+00, 0.25434200E-01, -.92620300E+00, -.97600100E+00, 0.72256800E-03, 0.40756900E+00, 0.23763900E+00, 0.31320200E+00, 0.16058800E+01, 0.19944700E+01, -.19030300E+00, 0.14268400E-01, -.10367900E+01, 0.22919800E+00, 0.62969600E+00, -.11757200E+00, 0.56399000E+00, -.31079200E+00, 0.42914600E+00, -.94898700E-01, -.17979300E-01, -.19322000E+01, 0.14091200E+01, -.11183500E+01, 0.36602600E+01, -.54378800E-01, 0.60837700E-01, -.98127500E+00, -.11845400E+01, -.14564300E+01, 0.72741300E+00, 0.36922800E-01, -.15202400E+00, -.98029600E-01, 0.75793600E-01, 0.98620300E+00, -.11601000E+00, 0.14877200E-01, -.35291400E-01, -.26379600E+01, 0.42960600E+01, 0.10896100E+00, 0.85752300E-01, -.60038000E+00, 0.30090200E+00, 0.58921800E+00, 0.13475800E+00, 0.27624900E+00, -.34115000E+00, -.11529700E+00, 0.35709600E+00, 0.99026200E+00, 0.71502400E-01, -.89058300E+00, 0.38227700E+00, -.52277600E+00, 0.13744600E+00, -.12585700E+00, -.28638200E+00, -.15175400E+01, 0.60328500E+00, -.13614500E+00, -.66454200E+00, -.16512200E+00, -.28451000E-01, -.29042500E+00, 0.17916700E+01, 0.10410900E+01, -.23611200E+00, 0.75333000E+00, 0.41786200E-01, 0.28333400E+01, -.15384700E+00, 0.60829700E+00, 0.46523800E-02, -.40322300E+00, 0.92948700E+00, 0.35537400E+00, -.16007100E+00, 0.42420200E-01, -.72414100E+00, 0.33784200E-01, 0.59615400E+00, 0.60692900E+00, -.90467200E+00, 0.83262600E-01, -.27852100E+01, -.12556900E+01, 0.47310700E+00, -.44134000E-01, -.25283200E+00, 0.14584800E-01, -.10508600E-01, 0.13065300E+00, -.39523500E+00, 0.33316900E+00, 0.26680400E+00, -.20501700E-01, 0.16145200E-01, -.18869200E+00, 0.26484100E+00, -.15702900E+00, 0.16788300E+00, -.42950300E-01, 0.40159500E-01, 0.82626100E+00, -.45637500E+00, 0.13816700E+00, 0.13427300E+01, 0.34992800E+00, 0.35853700E+00, 0.45646200E+00, 0.13502900E+00, -.11873100E+00, -.31443100E+00, -.22074100E+00, -.18046900E+00, -.47502900E+00, -.75293100E+00, 0.54577000E-01, 0.11252800E+01, 0.36301700E+00, -.42100300E+03, 0.17623600E+03, -.14805300E+02, 0.20836400E+03, 0.10660300E+03, 0.27836400E+02, -.51547100E+02, -.15712400E+03, 0.87373400E+02, 0.40894400E+01, 0.24446400E+03, -.33987700E+02, 0.42170600E+02, -.32455500E+02, 0.17084600E+02, 0.28032800E+02, 0.22717000E+01, -.26915800E+02, -.18604900E+02, 0.18464500E+02, 0.49027800E+01, 0.23055300E+02, 0.56928400E+02, -.26192000E+02, -.53351700E+02, -.28057500E+02, 0.10494300E+03, -.35480600E+02, -.40061800E+02, -.11005800E+02, 0.53259600E+01, -.44711100E+02, -.99287300E+02, 0.11931300E+02, 0.41725400E+01, -.19332800E+02, -.39099200E+01, -.47688500E+02, 0.86341100E+01, -.48982900E+01, -.46768300E+02, 0.17034600E+02, -.61678800E+01, 0.12181300E+02, 0.16579400E+01, 0.30742800E+01, 0.15840300E+02, 0.12583300E+01, -.26338200E+01, 0.38457900E+01, 0.90826000E+01, -.10988100E+02, 0.49259900E+01, -.25654800E+01, -.55435600E+01, -.82654400E+01, 0.10591400E+02, 0.14545600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24688000E+02, -.27120600E+01, -.30865300E+01, -.10928500E+02, -.10070800E+02, 0.85130600E+01, -.32847100E+01, -.33669900E+00, 0.25607300E+01, -.60903400E+01, -.11583900E+00, -.29147000E+01, -.88292500E+00, 0.32945300E+01, 0.32390000E+00, -.35886000E+01, -.33794700E+01, 0.35775400E+01, -.39569500E+01, 0.10649500E+01, 0.38770400E+01, 0.12742100E+01, -.92200400E+00, -.58862000E+01, -.76905200E+00, -.84802400E+00, 0.54487600E+00, 0.18359000E+00, 0.35714500E+01, -.94977600E+00, -.70387000E-01, -.13692300E-01, -.15373200E+01, -.61762200E+00, -.29660300E+00, 0.14330200E+01, -.16091700E-01, 0.36834900E+00, 0.11184000E+00, -.22177200E+01, -.13321400E+01, -.46035000E+00, 0.65963900E+01, 0.76174400E-01, -.97011100E+00, 0.31616400E+00, -.21456000E+01, 0.33137800E+01, -.20850300E+01, -.33874700E+00, 0.13588900E+01, -.14847200E+00, -.36726100E+00, 0.16077900E+00, -.51132700E+00, -.39749300E+01, -.31311900E+00, 0.11755700E+01, 0.80097700E-02, -.10871500E+01, 0.61303300E+01, 0.27737100E+01, -.53656000E+00, 0.16846700E+01, 0.13315600E+01, -.87916500E+00, 0.76680000E+00, 0.82926800E+01, -.65682200E+00, -.36139200E-01, 0.18188300E+00, -.16857400E+00, -.87677200E-02, 0.66814700E+00, -.30638900E+01, 0.36161000E+01, -.60676100E+00, -.21482300E+01, -.10992600E+01, -.50406500E+00, 0.12886800E+00, 0.34193000E+01, -.22688700E+01, 0.12725500E+01, 0.11761900E+01, -.49876600E+00, 0.95722800E+00, 0.67139200E-01, 0.15060100E+01, -.14155300E+00, 0.41542600E+01, -.29957700E-01, -.13294500E+00, 0.12130300E+01, -.41042400E+00, 0.58047500E+00, 0.21502600E+01, -.51653900E+00, -.86373000E+00, 0.79751500E+00, 0.12920000E+01, -.89146400E+00, 0.71748500E-01, -.60433900E+00, 0.29865400E+00, 0.15817200E+01, -.67233200E+00, -.29498400E+00, 0.59110400E+00, -.35877900E+00, 0.30766600E+00, -.32168800E+00, -.15539300E+01, -.44005300E-01, 0.14695400E+00, 0.78959000E-01, 0.93609200E+00, 0.51024000E+00, 0.92535700E+00, -.12036200E+01, 0.32312400E+00, -.86249300E+00, 0.19150500E-01, -.34649500E+00, 0.27109500E-01, -.62280000E+00, 0.18299600E-01, 0.10520700E+00, -.15659200E+00, -.42932300E-01, -.16045800E+00, -.54866300E+00, 0.11077900E+01, 0.13003900E+01, 0.32702700E-01, 0.45025200E-01, 0.17537000E-01, 0.39983600E+00, -.14335700E+00, 0.10086200E+00, 0.22949300E+00, -.10919700E+01, -.37427600E+00, 0.19437700E+01, -.12493800E+00, -.10788300E+01, 0.12389100E+00, -.10570700E+00, 0.11462000E+00, 0.97325800E-02, -.29535700E+00, -.11487600E+00, -.52698700E+00, 0.63435800E-01, 0.86336100E+00, -.96529900E-01, -.88326400E-01, -.26133100E+00, -.34827300E-01, 0.34793200E+00, 0.18791400E+01, -.17887200E-01, -.60400800E+00, -.18569800E+01, 0.51726500E+00, 0.23911700E+00, 0.18923500E+00, -.44896100E+00, -.34320100E+01, 0.32744300E+00, -.26773800E-01, -.61491900E+00, 0.24853500E+00, -.25295200E+00, 0.69707300E-01, 0.54321200E+00, 0.64529000E+00, -.25373100E-01, 0.17958900E+00, 0.41867000E+00, 0.38164500E+00, -.20862100E+01, -.83796700E+00, 0.98447800E+00, -.10275300E+01, 0.62862200E+00, -.12669900E+00, 0.47404800E-01, 0.17975200E+00, 0.13246400E+01, -.10886500E+00, 0.92835700E+00, 0.32224900E+01, -.23609300E+01, 0.20897000E+00, 0.33702000E+00, 0.35424500E+01, 0.10091800E+01, -.13679400E+01, 0.29058900E+00, -.97418500E+00, 0.85052900E-02, -.20701400E-01, -.34858400E+01, -.71084400E+00, -.57269300E+00, 0.14633700E+00, -.62251900E-01, 0.35754300E+00, -.34914500E+00, -.50568000E-01, 0.70879400E-01, 0.91205700E-01, -.22596600E+00, -.43634100E+00, 0.34363300E+01, 0.46431600E+00, -.19074700E+00, -.50156300E+00, 0.33328700E+00, 0.51452700E+00, -.72817200E-02, 0.46656900E+00, -.37642800E+00, -.88136200E-01, -.17953400E+00, -.10659500E+01, -.69627200E+00, -.98126100E-01, -.37037300E+00, -.94926600E+00, 0.87327100E+00, 0.56330300E+02, 0.29938200E+03, 0.61281000E+01, 0.45817100E+02, 0.10322100E+03, -.61851900E+02, 0.64120600E+02, -.66121400E+02, 0.11858900E+03, -.32087900E+02, -.50730900E+02, 0.68234300E+01, 0.10609400E+03, 0.24327700E+02, -.35677300E+02, 0.51680500E+01, 0.26451100E+02, -.37917100E+02, -.28254000E+02, 0.14586000E+02, 0.44327900E+02, 0.54418400E+02, -.28105200E+02, 0.12906600E+02, -.27869700E+02, -.52875800E+02, 0.20750300E+02, -.26671600E+02, -.19115900E+02, -.20274100E+02, -.27722600E+01, 0.94603000E+02, -.84235000E+01, -.42692700E+01, 0.19505200E+02, 0.32332800E+01, -.16731000E+02, -.79716600E+01, 0.64318500E+01, -.17325400E+02, 0.42817100E+02, 0.46634700E+01, -.56517600E+01, -.20038900E+01, 0.25020300E+01, 0.45334700E+02, -.44685600E+01, 0.21869200E+01, -.85463500E+01, -.30193300E+01, 0.87937800E+01, -.56050100E+01, 0.34103600E+01, 0.72625200E+01, -.13830000E+02, -.12138300E+02, -.74870400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.84965600E+01, 0.89336600E+00, 0.59049300E+00, -.48575500E+01, -.97139100E+01, 0.83061600E-01, 0.25101400E+01, -.57530000E+00, 0.12163400E+00, 0.16095800E+01, 0.30024900E+01, -.23325000E+01, -.26605300E+01, -.57297900E+00, 0.11683400E+01, 0.16678300E+01, -.12723500E+00, 0.21991800E+01, -.99687600E+00, 0.19497500E+01, 0.19531900E+01, 0.20203000E+00, 0.14188300E+01, 0.27763800E+01, 0.37114500E+00, 0.26902400E+01, -.23492800E+01, 0.63387100E+01, 0.18051300E+01, -.35789800E+00, 0.12314800E+00, 0.30588300E+01, -.45951600E+01, 0.31260200E+01, -.67517300E+00, -.66987200E-01, -.16940400E-01, -.41269800E+00, 0.14044800E+01, -.27272400E+01, 0.22161300E+00, -.67397600E+00, 0.52146000E+00, -.34107900E-01, -.16060600E+01, -.43486200E+00, 0.34997600E+00, -.18394700E-01, 0.14029600E+00, -.10181400E+00, -.10283500E+00, 0.24106900E+00, -.51747500E+00, 0.87625500E+00, 0.73819500E+00, -.27362000E+00, -.13442500E+00, 0.28324900E+00, -.66082800E-02, -.13801200E+01, 0.16969600E+00, -.58025800E+00, 0.25711100E+00, 0.13280800E+01, 0.13558300E+01, 0.96385600E+00, 0.56187900E-01, -.55427500E+00, -.18269600E+00, 0.14299800E-01, -.58515900E-01, 0.47128500E+00, 0.62592300E+00, -.13418800E+00, 0.12637700E+01, -.13092600E+01, 0.58022500E-01, 0.15192000E+01, -.93864700E-01, -.39156400E+00, -.15373300E-01, -.13146100E+01, 0.51982300E-01, -.12789700E+00, 0.10299600E+00, 0.17109500E+00, 0.13400800E+01, 0.20016600E-01, 0.18770200E+01, 0.26864200E+00, 0.37082900E+01, -.12226800E+00, -.12125800E+01, 0.28710500E+00, -.44690400E+00, -.33232400E+00, -.21940700E+00, -.44422800E+00, 0.80695700E+00, 0.26740900E+00, -.47065800E-01, 0.43918500E+00, -.99567500E-01, -.18320000E+00, -.13481100E+00, 0.35005300E+00, 0.45120200E+00, -.43383200E+00, -.45197700E+00, -.31931600E+01, -.66116900E+00, -.17882400E+00, -.59124700E-01, -.47870100E-01, -.57253100E-01, -.24405300E+00, 0.69675700E+00, -.72823900E+00, -.20350300E+01, 0.75626000E+00, -.11453600E+00, -.23097400E+00, -.86170300E-01, -.40664300E+00, 0.98461800E-01, 0.81941100E+00, -.27877700E-01, 0.10367600E+00, -.22455000E+00, 0.33010000E+00, 0.70201800E+00, -.48036100E+00, -.17270700E+00, 0.58182100E+00, 0.15794000E+00, -.21103100E-01, -.47143400E+00, -.25567100E-01, -.34846400E+00, -.36681400E+00, 0.41712200E+00, 0.79074100E-01, -.23450100E+00, 0.14522800E+00, -.26109600E+00, -.30236600E+00, -.25418600E-02, -.63420600E-01, 0.42733800E+00, -.17668500E+01, 0.37973800E+00, -.34477000E-01, -.24881600E+00, 0.42765700E-01, -.88185600E+00, 0.55256900E-01, 0.43283800E-01, 0.79903600E-01, -.90148700E-01, 0.24085200E+00, -.43106000E+00, 0.16589300E+00, 0.60767500E+00, 0.52625800E+00, -.37246900E-01, -.73886100E+00, -.18139500E+00, 0.19992600E+00, 0.13668500E+00, -.20055800E+00, -.15593300E+00, -.21834000E+00, 0.14667000E+00, -.33736200E+00, 0.40395200E+00, 0.79670900E+00, 0.18723200E+00, -.18146800E+00, -.39088200E+00, 0.74286200E-01, -.12678600E+00, -.30643600E+00, -.18325000E-01, -.11696800E+00, 0.73246900E-01, 0.30398000E+00, 0.47085200E-01, -.15937300E+00, -.53479600E-01, -.58759200E+00, -.15167600E-01, 0.54404800E+00, 0.16049900E-01, 0.50350000E+00, 0.35126600E-01, -.21083100E+01, -.12608000E+01, -.64809800E-01, -.96029800E-01, -.73022500E-03, 0.32920500E+00, 0.61070800E-02, 0.12538500E+00, -.11170600E+01, -.15495000E+00, 0.18222100E+00, -.26225700E-01, 0.54252700E-01, 0.29013900E+00, 0.56029700E-01, 0.47048300E-02, 0.22027200E-01, 0.42923500E-01, -.86264600E-01, -.73774200E-01, -.97927100E-01, 0.50577300E-01, 0.13202800E+00, 0.11713000E+00, 0.49783900E+00, 0.50531500E-01, 0.53110700E-01, -.11739900E-01, -.85627400E+00, 0.36674400E+00, 0.68174600E-01, -.57242900E+00, -.24821500E+00, 0.17187900E+00, -.17738900E+00, 0.68047000E-01, -.55418800E-02, 0.11118200E+00, 0.13678900E+03, -.31966000E+00, -.24849400E+02, -.40135000E+02, -.75701700E+01, 0.24029100E+02, 0.30927000E+01, -.56632800E+02, -.96705400E+01, -.48614200E+02, 0.24961500E+02, 0.30066500E+02, 0.28415800E+02, 0.33878000E+01, 0.13252300E+02, 0.31348900E+00, -.15867900E+02, -.77978900E+01, 0.15550500E+02, -.12206200E+01, -.10906500E+02, 0.64175300E+01, 0.77166600E+01, 0.51947400E+01, 0.21436500E+02, -.79053900E+01, -.12727000E+02, -.13247400E+02, -.36705400E+01, 0.95331400E+01, 0.34296600E+02, 0.36615200E+00, 0.36378300E+00, 0.42383900E+01, -.13583700E+01, 0.13988100E+02, 0.44036800E+00, -.17679700E+01, 0.13432800E+02, -.30030200E+02, 0.89057600E+00, -.67493700E+00, 0.34121300E+00, 0.12479900E+01, -.29663100E+02, -.38049700E+00, -.37765800E+00, 0.19380100E+01, -.96379400E+00, -.83655200E-01, 0.20087900E+01, 0.93030200E-02, 0.82108500E-01, 0.82708300E+01, -.48838400E+00, -.18567700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16408700E+02, -.17296100E+01, -.14392300E+01, 0.31142100E+01, 0.61952900E+01, 0.15688400E+01, -.32258300E+01, 0.77556000E-01, 0.39669400E+00, -.28517700E+01, -.12202700E+01, -.75870700E+00, 0.27405300E-01, 0.12386200E+01, 0.50968400E+00, -.34344500E+01, -.28364900E+01, -.16792200E+01, 0.24376300E+01, -.30954800E+01, -.11566700E+01, 0.48719300E+00, -.19820500E+01, -.47781300E+01, -.48201900E+00, -.19242600E+01, 0.17105000E+01, -.36177200E+00, -.24077200E+01, 0.98843500E+00, 0.34331900E+00, -.13881900E+01, 0.22832300E+01, -.24736800E+01, 0.41336800E+00, -.14725700E+01, 0.13017100E+00, -.24429000E+00, 0.10111700E+00, -.16543700E+01, -.43445300E+00, -.14404100E+01, -.18721800E+01, 0.50860400E+00, -.19196100E+01, -.31444100E+00, -.13519200E+01, 0.92793900E-01, -.13264000E+01, -.21976200E+00, 0.31374400E+01, 0.82643900E+00, -.41623300E+00, -.30728200E+00, 0.15281000E+01, -.83949000E+00, -.10194600E+01, -.10114100E+00, 0.63940400E-01, 0.70415100E+00, 0.17984600E+00, 0.12441900E+01, -.13746900E+00, 0.84888000E+00, -.28727100E+01, 0.44652300E+01, -.45081900E+00, 0.73869700E+01, -.17809100E+00, -.10393700E+00, -.11223600E+01, 0.71037500E+00, 0.26606200E+01, -.70633900E+00, 0.47764500E-01, -.92081400E-01, -.52605100E-01, 0.52658800E+00, 0.10955500E+01, -.24945100E+00, 0.23306800E+00, 0.43030400E+01, -.15851200E+00, -.10169700E+01, -.31944200E+00, -.27759000E+00, -.11077200E+01, 0.90020100E+00, 0.52353900E+00, -.67626200E+00, -.35273600E+01, -.29687400E-01, 0.45432300E+00, -.13733600E+01, -.24918200E+00, 0.24448700E+00, -.36401600E+00, 0.71972300E-01, 0.90117200E+00, 0.83223400E+00, -.84712400E+00, -.88644600E+00, 0.91978300E-01, 0.96344000E+00, -.41786200E+00, -.38428700E+00, -.12188900E+01, 0.43110500E-01, 0.11491400E+01, -.28240700E+01, 0.69098800E+00, -.13534700E+00, -.80074600E+00, 0.65105000E-01, 0.97080800E-01, 0.67194100E-01, -.48266500E-01, 0.16652100E+01, 0.12030200E+01, -.71747200E+00, 0.61299000E+00, -.42444500E+00, -.27347000E+00, 0.12318300E+00, 0.14444000E+00, -.36430900E+00, 0.13972600E+01, -.72057600E+00, 0.91209800E-01, 0.82169000E-01, -.10668600E+01, 0.11285400E+01, -.52801800E+00, 0.84745200E+00, -.75669300E+00, 0.20089700E+00, 0.25535000E+00, -.55973300E+00, -.93337500E+00, 0.21153300E+00, 0.16986900E+00, 0.59181500E+00, 0.74492500E+00, 0.21557400E+00, 0.20779700E+00, -.49588900E+00, -.21746700E-01, 0.11915100E+00, -.20610900E+00, 0.19423000E+00, 0.46432400E+00, 0.77015000E-01, 0.50869700E+00, 0.18000200E+00, 0.19840500E+00, 0.18257800E+00, 0.14582600E+00, 0.17588200E+00, 0.52506500E+00, 0.21289400E+00, -.13005200E+01, -.13911600E+00, 0.24196700E+00, -.11192700E+01, -.15589500E+00, 0.52411500E+00, 0.20753000E+00, -.25413000E+00, -.68561400E+00, 0.54254800E+00, 0.24904700E+00, 0.71433200E+00, 0.26785100E+00, 0.26228500E+00, 0.23087600E+00, 0.32905700E+00, 0.17234000E+00, 0.22776500E+00, 0.63438700E+00, 0.35737200E-03, 0.69657100E+00, 0.12349800E+01, 0.95059400E+00, 0.75616700E-01, -.42910000E+00, -.45807700E+00, 0.15824100E+00, 0.11469400E+00, -.55389700E-01, -.30581000E+00, -.22892400E+00, -.87200600E+00, -.10526300E+01, -.78904400E+00, 0.24069700E+00, 0.60185700E+01, 0.14465700E+01, 0.21751200E+00, -.59503300E+00, 0.61167200E-02, -.49494200E+00, 0.19576700E-01, -.15802000E+00, 0.14748400E+01, -.38608600E+00, 0.13290800E+00, -.10829800E+00, 0.57540400E+00, -.22126000E+00, 0.97937300E-01, 0.65571200E-01, 0.74991600E-01, 0.12900800E+00, 0.29208600E+00, -.56099400E+00, 0.80401800E+00, 0.63262100E+00, 0.64427300E-01, -.28188100E+00, -.11301100E+00, -.10190200E+00, -.14320100E+00, -.16071100E+00, -.37858200E+00, 0.74957900E-01, 0.50667800E-01, -.24970900E+00, -.16667700E+00, -.72170700E-02, 0.46491800E-01, -.25513400E+00, 0.26389600E-01, 0.29135700E-01, 0.46909600E+00, 0.10006200E+02, -.55184800E+01, -.19945900E+00, 0.39358600E+02, 0.20745100E+02, 0.60060300E+01, 0.62550400E+00, -.34004000E+01, 0.34063700E+01, 0.56075700E+01, 0.99056700E+01, -.45448800E+01, -.13809300E+02, -.14426900E+01, -.10739100E+02, -.25300800E+01, 0.29223100E+01, 0.25816300E+01, 0.28180100E+02, -.48545300E+02, 0.22433400E+02, 0.31853400E+02, 0.23614300E+02, 0.62733500E+01, -.24413900E+02, 0.22531300E+02, -.61664300E+00, 0.31911200E+02, -.25806700E+02, 0.39412700E+01, 0.93006700E+00, 0.12739200E+01, 0.25398200E+01, -.16847400E+00, 0.44206200E+00, -.20880400E+00, 0.43589100E+00, -.23041800E+00, 0.46539500E+01, 0.44666500E+00, 0.12308100E+01, 0.78522400E-01, 0.11047000E+01, 0.46532400E+01, -.15648000E+00, -.78660700E-01, -.66112000E+00, 0.72599000E+00, -.13250000E+01, -.11244900E+00, 0.45548700E+00, 0.70747500E+00, -.48676800E+01, -.17713200E+01, 0.11979600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.56563700E+01, -.50139400E+00, -.14863700E+01, 0.97307300E+00, 0.18047900E+00, -.22510100E-01, -.57723200E+00, -.38525600E+00, 0.15260800E+00, -.13363000E+01, 0.95882700E+00, -.21902600E+01, -.23192200E+01, -.62621600E+00, 0.24656700E+00, -.64368900E+00, -.21701300E+01, -.13218500E+01, 0.16095900E+01, -.15865400E+01, 0.97822700E+00, 0.37907900E+00, -.28071200E+00, -.14335200E+01, -.14170700E+00, -.42336500E-01, 0.92587100E-01, 0.44215300E+01, -.15513800E+01, 0.57774900E+00, 0.33673500E+00, 0.15919200E+00, -.14926000E+01, -.16013600E-01, -.72375300E-01, -.16108100E+01, 0.31887800E-01, -.52459500E+00, 0.46862700E-01, -.51075500E+00, 0.13922000E+00, -.43336200E-01, -.55315800E+01, 0.33175600E+00, -.44882800E+00, -.22098700E+00, -.65385800E+00, 0.76064600E+00, -.54801700E+00, -.35258000E-01, 0.13335800E+01, 0.29451500E+00, 0.19384100E+00, -.21930600E-01, 0.65598100E+00, -.13507700E+01, -.68350400E+00, 0.28805700E+00, 0.85518200E-04, -.35922700E+00, 0.16131000E+01, 0.11745300E+01, -.39368200E-01, 0.12857200E+01, 0.38257700E+00, 0.21038600E+01, 0.22384900E+00, 0.18468800E+01, 0.59942500E-01, -.34875100E-02, -.54022100E+00, 0.36106900E-01, 0.13218500E+01, -.12797500E+01, 0.99510700E-01, -.77158800E+00, 0.30709800E+00, -.41400600E+00, -.40535500E+00, 0.10253200E+00, 0.30041200E-01, 0.78077200E+00, 0.42256000E+00, -.56715600E+00, -.37957000E+00, 0.45533000E-01, -.44488800E+00, 0.47359400E+00, 0.11329100E+01, -.62723000E+00, 0.38704400E+00, -.29677300E-01, 0.15107700E+00, -.69581800E+00, -.56828900E+00, -.26893500E+00, -.10784700E+00, -.40334900E+00, 0.48977300E+00, 0.48857400E-02, -.76954100E+00, -.36751000E+00, -.30836100E-01, 0.12063700E+00, -.14717900E+00, -.29503700E+00, -.39375500E+00, -.38207100E-01, 0.46994800E+00, -.14738500E+01, 0.20181900E+00, -.18553400E-01, -.32493400E+00, 0.96909600E-02, -.11122800E+00, -.93705100E-01, -.62000500E-01, -.52622400E-01, 0.56003000E+00, 0.34811700E+00, 0.12444000E+00, -.56680900E-01, -.12899700E+00, 0.28201800E+00, 0.70531900E-01, -.18235100E+00, 0.11048900E+01, -.37647200E+00, -.78245300E-01, 0.44117400E+00, -.13087200E+00, 0.29922600E+00, -.26886600E+00, 0.80474200E+00, -.31038500E+00, 0.11789300E-02, -.54663100E-01, -.60153300E+00, -.74523700E-01, -.82034400E-01, 0.12952100E+00, 0.17547000E+00, 0.35846500E+00, -.37041500E+00, 0.22216500E+00, 0.62005600E+00, -.50297300E-01, 0.84402200E-01, -.40422700E+00, 0.10606200E+00, 0.41741400E+00, 0.12410600E+00, 0.29426800E+00, 0.13219300E+00, -.64007800E+00, 0.17455300E+00, 0.28239700E-01, 0.87985800E-01, 0.18194300E+00, -.22799700E+00, -.37654300E+00, 0.10278300E+00, 0.48433800E+00, -.27724000E+00, -.69803100E-01, -.63916300E-01, 0.88980400E-01, 0.26394000E-01, 0.11695600E-02, -.38050500E+00, -.20949800E-01, -.60244400E-01, -.95196600E-01, 0.49409600E+00, 0.27456800E-01, -.19156600E+01, -.75105700E+00, 0.29997700E+00, 0.74469600E+00, 0.15863900E+00, -.22089700E+01, 0.14271800E+01, 0.54591500E+00, 0.23766100E+00, -.63868700E+00, -.27575400E+00, 0.10438400E-01, 0.28461500E+00, -.43332500E-01, 0.54874600E+00, -.30269600E-01, 0.46846500E+00, -.69184400E+00, -.77672800E+00, 0.73344400E-01, -.46826200E+00, 0.39300400E+00, -.74886400E-01, -.17604000E+00, -.32924300E-01, -.28293900E+00, 0.81317900E-02, -.16793100E+00, -.16761100E+01, 0.54938200E+00, -.15497800E+00, -.49393800E-01, 0.20510200E-02, -.20361000E-01, 0.33414200E-01, -.67301600E-01, 0.56859800E-01, 0.66236300E-01, -.53680100E+00, 0.48178300E+00, -.51328800E+00, 0.12826500E+00, 0.54922300E+00, 0.33511900E-01, -.47444900E+00, 0.22663500E+00, -.26080900E+00, 0.11642700E+00, -.53415300E+00, -.57137300E-03, 0.24564500E+00, 0.37913300E+00, 0.15024100E+00, -.17609200E+00, -.91141800E-01, 0.90857300E-02, 0.33653700E+00, 0.74344400E-01, 0.28708600E+00, 0.10286900E+00, -.45278100E+02, -.12141300E+02, 0.33374000E+01, 0.16795300E+02, 0.48819700E+02, -.12389800E+02, -.87904600E+01, 0.28328700E+02, -.18990200E+02, 0.18945300E+01, -.15078400E+02, -.41889500E+01, -.45892300E+01, 0.45394400E+01, 0.13562100E+02, 0.38798200E+01, -.68494100E+01, -.21722400E+02, -.55198400E+02, 0.26952600E+02, 0.37676700E+02, 0.27550600E+02, -.29481500E+01, -.15785400E+01, 0.34513300E+02, 0.28585800E+02, 0.14259100E+02, -.30645500E+01, 0.49506500E+02, 0.32934100E+00, -.18370000E+01, 0.77822500E+01, -.17695200E+01, 0.25647200E+02, -.34172400E+01, 0.16472900E+01, 0.25728400E+02, -.29293600E+02, 0.44931600E+01, -.24749400E+01, -.72977700E+00, -.20540100E+01, -.29728400E+02, -.22351400E+01, -.21862900E+01, -.23347800E+01, -.93991400E+00, 0.26301000E+01, -.14546400E+01, 0.17302600E+01, 0.17008700E+00, 0.18019600E+02, -.11071400E+01, -.58353400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16580400E+02, -.15335500E+01, -.23724300E+01, -.20009200E+01, -.32231900E+01, 0.19742000E+01, -.79240400E+00, -.71851800E+00, 0.96393700E+00, -.37140900E+01, 0.42357800E+00, -.46621900E+01, -.38776500E+01, -.32243300E+00, -.78457600E+00, -.25174700E+01, -.64705700E+01, -.29294200E+01, 0.21260500E+01, -.16642200E+01, 0.22651000E+01, 0.74111400E+00, -.58725800E+00, -.27367900E+01, -.52693200E+00, 0.55466900E-01, -.19216600E+01, 0.64476600E+01, 0.95912900E+00, -.57451500E+00, 0.27676200E+00, -.16873900E+01, -.35358200E+01, 0.71340900E+00, -.78892000E+00, -.10812500E+01, -.93296500E-01, 0.33101600E+00, -.19416800E+00, 0.37109900E+01, 0.74547600E+00, 0.88568800E+00, -.20188200E+01, 0.68121400E+00, -.43516000E-02, 0.26123200E+00, -.48935500E+00, 0.18149100E+01, -.32920300E+01, -.58599300E+00, -.12341900E+01, 0.16259500E+01, -.22726100E+00, -.21762500E+01, -.22392400E+01, -.97945100E+00, -.81217200E+00, 0.15741900E+00, -.12345000E-02, 0.20193000E+01, 0.13869300E+01, 0.21248300E+01, -.16254900E+00, 0.31331600E+00, -.36207900E+00, 0.28051700E+01, 0.14843100E+00, 0.39501700E+01, 0.18911500E+00, -.82110500E-02, -.12593000E+01, 0.26486200E+00, 0.35812200E+01, 0.40367500E-03, -.90215300E+00, 0.14850800E+01, 0.22832100E-01, -.15566400E+01, -.11070500E+00, -.61584700E+00, 0.14864100E-02, 0.76854100E+00, 0.11596400E-01, -.78138900E+00, 0.12760200E+00, -.59476000E-01, 0.56020000E+00, 0.99292300E+00, 0.14089100E+01, -.48288900E+00, -.96101200E-01, -.38527700E-01, -.75314700E+00, 0.30152100E+00, 0.20986900E+01, -.45621800E+00, -.90437800E+00, -.21650900E+00, -.35047200E+00, 0.53338100E+00, -.50331400E+00, -.14023200E+01, -.33617800E-01, -.10628900E+00, -.14665600E+00, -.41551200E+00, -.11500900E+00, 0.18069100E+00, 0.17971300E-01, -.12680100E+01, 0.38211800E+00, -.23023000E+00, -.81557000E+00, 0.13076200E-01, -.32564600E-01, 0.40441100E-01, 0.78063500E+00, 0.27236100E+00, -.82566200E+00, -.46319900E+00, 0.18020200E+00, -.37317500E+00, -.24875700E-01, -.24385000E+00, 0.30383500E-01, -.10808200E+00, 0.40343300E+00, -.10761000E+00, -.10692700E+00, 0.10356000E-01, -.11160000E+01, 0.18115900E+00, 0.77426300E+00, 0.15651800E+00, 0.18774300E+00, 0.67585900E-01, -.25213200E+00, 0.57263000E+00, -.10637000E+01, 0.54392000E+00, -.17809400E+00, 0.40474800E-01, -.93051700E-01, 0.72546000E+00, -.13865300E+00, 0.32102600E+00, -.33307900E-01, -.10485700E+00, -.14004300E+00, 0.23864800E+00, 0.52346600E-01, -.12064600E-01, -.19126300E+00, 0.18146800E+00, -.13658000E+00, -.12133800E+00, -.48897900E-01, -.88408400E-01, 0.18144300E-01, 0.13355900E-01, 0.35081300E+00, -.75688900E-01, 0.50580600E+00, -.94356400E+00, -.51457400E+00, 0.34672300E-01, -.14111800E+00, 0.81459000E-01, 0.18045800E+00, -.49732300E+00, 0.12683500E+00, -.23612200E+00, 0.44810200E-01, 0.30292600E+00, 0.32655300E-01, 0.90225600E+00, -.28375600E+00, 0.21580700E-01, 0.88596400E-02, 0.14889000E+00, -.75826400E+00, -.49357100E+00, 0.37476600E+00, 0.25607600E+00, -.23430100E+00, 0.38598200E+00, 0.37284200E+00, 0.91098300E-01, -.36345900E-01, -.89176800E+00, -.20905400E-01, 0.11899200E+01, 0.30091500E+00, 0.10071700E+00, -.15706000E+00, 0.43457500E+00, 0.10908000E+01, 0.60164700E+00, -.65614100E+00, 0.14793700E+00, -.31711900E+00, 0.13350000E-02, 0.14933400E-01, -.22306200E+01, -.53230300E+00, 0.26454600E+00, 0.27695600E-01, 0.12960900E+00, 0.28265800E+00, 0.88038400E-01, 0.69486700E-01, 0.45187300E-02, 0.38000400E+00, 0.10287500E+00, 0.10518000E+00, 0.26752100E+00, 0.16032000E+00, -.74648800E+00, -.36957100E+00, 0.95655700E+00, 0.42963000E+00, 0.64256800E+00, 0.31132100E+00, 0.39445500E-02, 0.44015800E+00, 0.25482200E+00, -.28848600E+00, 0.43520900E+00, 0.17137700E+00, 0.56047000E+00, 0.24494700E+00, 0.24614300E-01, 0.52566400E+00, -.11288300E+01, -.22164400E+00, 0.12277100E+01, -.11425500E+03, 0.33004000E+02, 0.46217600E+01, -.92754400E+01, -.13918900E+03, 0.34915600E+02, -.40963300E+02, 0.39497100E+02, 0.22115500E+02, 0.25956400E+02, -.14579500E+02, 0.20711400E+02, -.15203100E+02, -.18502100E+02, -.28427600E+02, 0.24773100E+02, -.50008800E+02, 0.15922700E+02, -.58860000E+01, 0.64060000E+01, -.81170300E+01, -.19093100E+01, -.37688500E+02, -.37816200E+02, -.54691500E+02, -.24862100E+02, 0.19670100E+02, 0.14581200E+01, 0.65693300E+01, 0.41993400E+01, 0.16677200E+01, -.32421700E+00, -.24713700E+02, 0.62748700E+01, -.57962700E+01, -.24499200E+02, -.65980300E+01, -.35819000E+01, 0.69015000E+01, 0.17998700E+01, 0.57770500E+01, -.59256400E+01, 0.10854300E+01, 0.13708800E+01, 0.46486900E+01, 0.33589600E+01, -.59708400E+01, 0.24801300E+01, -.13597600E+01, -.18050100E+01, -.11184900E+02, 0.56647300E+01, 0.49175800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.29488000E+02, 0.32239300E+01, 0.45680800E+01, -.54662500E+01, -.10778500E+02, -.25068500E+01, 0.52900300E+01, -.23084800E+00, -.13659700E+01, 0.64529200E+01, 0.20522400E+01, 0.14069000E+01, -.12117500E+01, -.40954900E+01, 0.15593800E+01, 0.54730300E+01, 0.48983600E+01, 0.17007300E+01, -.16389000E+01, 0.43168900E+01, 0.10531000E+01, -.39393000E+00, 0.31241800E+01, 0.70630900E+01, 0.74260700E+00, 0.37414800E+01, -.43990500E+01, 0.26327000E+01, 0.17117000E+01, -.51126400E+00, -.33258800E+00, 0.48359400E+01, -.22674600E+01, 0.54698600E+01, -.72706300E+00, -.20153700E+00, 0.13657600E-01, -.26907000E+00, 0.18486300E+01, -.34210500E+01, 0.10360300E+01, -.10556800E+01, 0.24103000E+01, -.36044500E+00, -.35262000E+01, -.62454700E+00, 0.26556100E+01, -.24976400E+01, 0.10959000E+01, 0.23222400E+00, -.25957000E-02, 0.14229900E+01, -.10935200E+01, -.17559400E+01, 0.86155900E+00, 0.57220900E+01, 0.11239700E+01, -.99191500E+00, -.69618600E-02, 0.26044200E+01, -.93407000E+01, -.43777300E+01, 0.71305500E+00, -.14893700E+01, -.14269000E+01, 0.53114600E+00, -.15254000E+01, -.13349800E+02, 0.24651700E+00, 0.36923000E-01, 0.30467400E+00, 0.15336300E+01, 0.17020900E+01, 0.18603400E+01, -.15942000E+00, -.32677900E+01, 0.94065800E+00, 0.33772500E+01, 0.13877700E+01, 0.12199300E+01, -.25270300E+00, -.34897400E+01, 0.87511600E+00, -.11260800E+01, -.13023500E+01, 0.32971400E+00, 0.87939900E+00, -.85364000E+00, 0.19093800E+01, 0.11513700E+01, 0.64317600E+01, -.12702600E+00, 0.75192800E+00, -.10066600E+01, -.16872900E+01, -.18192400E+01, 0.37617800E+00, -.12753000E+01, 0.19689700E+01, -.61174200E+00, -.14466800E+01, 0.12603600E+00, -.15535700E+00, -.53987300E+00, 0.41666000E+00, -.47928700E+00, -.81946600E+00, -.16804400E+00, -.10188700E+01, -.29330400E+00, -.10935200E+01, -.67600700E+00, 0.10036500E+01, -.80167900E-01, 0.75239400E+00, -.13309400E+00, 0.70620200E+00, 0.28326800E+00, 0.14585400E+01, -.88433600E+00, -.18712100E+00, -.12049900E+01, 0.29541000E+00, -.29043600E-01, -.22858700E-01, 0.14029700E+01, -.22960800E+00, 0.21464200E+00, 0.52241000E-02, 0.65234600E-01, -.19414800E+01, 0.25164400E+01, -.93544700E+00, 0.32326000E+01, -.51192200E-01, -.78782900E-01, -.14710200E+01, -.69736300E-01, -.77672500E+00, -.30918600E+00, -.12043700E+00, -.44557900E+00, -.11940100E+01, -.79617100E+00, -.11725400E+00, 0.15439000E+01, -.12579400E+00, -.21855800E+00, -.10171400E+01, -.18914700E+01, 0.10264400E+01, 0.90443400E-01, -.52907200E+00, -.15997400E+00, -.16445200E+00, 0.15129400E+00, 0.11370700E+00, 0.30322100E+00, -.59412300E+00, 0.10534800E+01, 0.23926100E+00, 0.16706900E+00, 0.94200400E+00, 0.63819800E+00, -.60283900E-01, -.12089400E+01, -.16645700E+00, 0.28212000E+00, 0.69778100E+00, -.17910600E+00, -.82362800E-01, -.79976600E-01, -.21951400E+00, 0.41643000E+00, -.33033400E+00, -.48511600E+00, -.90071500E+00, 0.15048300E+00, 0.42112100E+00, 0.15820600E+00, -.36770700E+01, -.12722000E+01, 0.49043400E+00, 0.27088700E+00, 0.23048300E+00, 0.35956400E+00, 0.40674200E+00, 0.41043800E+00, 0.19471600E-01, 0.31057800E+00, -.19627600E+00, 0.35282900E+00, 0.14300500E+01, -.92190400E+00, -.75743500E-01, -.49165500E+00, -.13930000E+01, 0.43009000E+00, -.87591100E+00, 0.21257300E+00, -.29690500E+00, 0.28654700E-01, 0.23436500E+00, -.16367700E+00, -.21952900E+00, 0.31873800E+00, -.16058500E-01, 0.62353200E+00, 0.12847100E+00, 0.39870700E-01, 0.41703900E-02, -.11033600E+00, 0.16359600E+00, 0.23306200E+00, -.48249900E+00, -.20979400E+01, 0.16196200E-01, 0.33588000E+00, -.59148800E-01, 0.98733600E+00, 0.97734800E+00, 0.62214300E+00, -.25265800E+00, -.35036600E+01, 0.14948400E+01, 0.81804700E+00, -.30644700E+00, -.36755800E+00, -.18328800E+00, -.11567500E+01, -.12429200E+01, 0.45419300E-02, 0.48668700E+00, 0.35799800E+01, 0.41623900E+00, 0.12112400E+01, 0.43102400E+00, 0.17988900E+03, 0.75948600E+02, -.19624300E+02, 0.43384500E+02, -.31532200E+02, 0.28155900E+01, 0.12203100E+02, -.17769200E+02, -.16113900E+02, 0.14426700E+02, 0.19806400E+00, -.35552800E+02, -.45664000E+01, 0.35359500E+02, -.51102000E+00, 0.93628800E+02, 0.64753500E+02, -.34902900E+02, -.55597000E+02, -.31274100E+02, -.52524800E+02, -.15993200E+02, -.27706500E+02, -.36028100E+02, 0.29834100E+02, -.24936100E+02, -.60334400E+02, -.32686500E+01, 0.52955500E+01, -.17011000E+02, 0.49136400E+01, -.14589900E+02, -.74578700E-01, 0.28529000E+01, -.11298600E+02, 0.46974500E+02, -.87951200E+01, -.38927100E+01, 0.12440600E+01, -.66658300E+01, 0.47304600E+02, 0.24445100E+01, 0.37020300E+01, 0.18839700E+01, -.46291200E+01, -.39198000E+01, 0.43988400E+01, -.19299000E+01, -.36148300E+00, -.13716500E+02, -.89359200E+01, 0.12503700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25880000E+02, 0.27788100E+01, 0.72009300E+01, 0.52682700E+01, 0.44052800E+01, -.41256600E+01, 0.28829900E+01, 0.91698100E+00, -.81142700E+00, 0.64691800E+01, -.37929100E+00, 0.74762200E+01, 0.51961900E+01, 0.33573400E+01, 0.15406000E+01, 0.38848900E+01, 0.89664900E+01, 0.39398600E+01, -.41759400E+00, 0.96282100E+00, -.25191600E+01, -.76925500E+00, -.15087800E+00, 0.97598300E+00, 0.10357100E+01, -.23830000E+00, 0.17029900E+01, -.22634200E+01, -.28218600E+01, 0.72889400E+00, -.64376400E-01, 0.25732300E+01, 0.43961700E+01, -.86873600E+00, 0.10500100E+01, -.39952000E-01, 0.12353400E+00, -.67777400E+00, 0.39616300E+00, -.12257900E+01, -.62287100E+00, -.29846400E+00, 0.58186200E+01, -.11174100E+01, -.75604000E+00, -.36663000E+00, 0.13322700E+01, -.33026600E+01, 0.19982000E+01, 0.72823500E+00, 0.24362100E-02, -.17406000E+01, -.19267500E+00, -.30617800E+00, 0.93743400E+00, 0.15388800E+01, 0.12351700E+01, -.66579300E+00, -.69829600E-03, -.16546100E+01, -.39603500E+01, -.38309000E+01, -.27145100E-01, -.20061900E+01, 0.76013700E-01, -.32629800E+01, -.83696800E+00, -.11296800E+02, 0.88263900E+00, 0.11391200E-01, 0.91458000E+00, -.81726400E+00, -.72991500E+01, 0.20899200E+01, -.70173500E+00, -.15652100E+01, -.43983700E+00, 0.12512400E+01, 0.14130500E+01, 0.14395600E+01, -.80759300E-01, 0.16118700E+01, 0.14387600E+01, 0.67950600E+00, 0.64419900E+00, -.91268400E-01, -.23254400E+01, -.14410600E+01, -.83359200E-01, -.73799300E+00, 0.38912100E+01, 0.88777600E-01, 0.20008100E+01, -.12040800E+01, -.26777500E+01, -.20516700E+00, 0.19049200E+01, 0.34750900E+00, 0.65990300E+00, -.99065600E+00, -.19191900E+00, 0.19763900E+01, 0.62988700E-01, 0.62923800E+00, 0.82116300E+00, -.52330000E+00, -.39576300E+00, 0.53315900E+00, -.99116100E+00, 0.54828800E+01, 0.15295300E+00, 0.48417400E+00, 0.12832200E+01, -.82114900E-01, 0.73955200E+00, -.72972100E-01, -.12853100E+01, -.34048900E+00, 0.50493700E+00, 0.48067600E+00, -.76180900E+00, 0.41609100E+00, 0.24123100E+00, 0.81759000E+00, -.69873900E-01, 0.62139200E+00, -.11328500E+01, 0.28191700E+00, 0.14405300E+00, -.55013000E+00, -.11149400E+01, 0.73987100E+00, -.11995900E+00, 0.11246900E+01, -.11363400E-01, -.45003600E-01, 0.48213200E-01, 0.41692800E+00, -.63051600E+00, 0.40297300E+00, -.46089900E+00, -.32082000E+00, 0.77394700E-01, -.20496500E+01, 0.27447600E+00, 0.71053400E+00, 0.25866800E+00, 0.13215700E+00, -.25370900E+01, 0.16092100E+01, 0.45329300E+00, -.18182700E-03, -.50469000E+00, -.42765800E+00, 0.18453100E+01, -.77305900E-01, -.10907900E+00, 0.22921600E+00, -.24262000E+00, -.18917700E+01, 0.32512000E+01, -.15994300E-01, -.10535900E+01, -.44205800E+01, 0.10784200E+01, 0.59479800E+00, -.37162800E+00, -.17983800E+00, -.19232000E+01, 0.96127500E+00, -.62665200E-01, -.20837800E+00, 0.18972600E+00, 0.59265000E-01, 0.77056400E+00, -.60898700E+00, -.39095800E+00, 0.20503000E+00, 0.10110400E+01, -.52912700E+00, 0.10832700E+01, 0.33843900E+01, 0.26255000E+00, 0.23186000E+00, 0.45864200E+00, -.47705500E+00, -.16436500E+00, -.89066700E+00, -.22923000E+00, -.21660900E+01, -.46642400E+00, 0.24398200E+01, -.32667000E+01, -.12108400E+01, 0.12079400E+01, 0.12752600E+02, 0.23098000E+01, 0.19800300E+01, -.14140400E+00, 0.46770800E-01, -.36286600E+00, 0.16583000E-01, -.19061000E+00, 0.20591400E-01, -.88932500E+00, -.77607500E+00, 0.36294000E-01, -.67900500E+00, 0.10508500E+01, 0.82161500E-01, 0.15836900E+00, 0.14990800E+00, 0.80748500E-01, 0.16243000E+00, -.54036300E+00, -.28203300E+01, 0.10397000E+01, 0.10070000E+00, -.56007400E+00, -.14447300E+01, -.15475800E+00, -.41687800E+00, -.49917600E+00, -.20652300E+01, 0.18291800E+00, 0.32620600E+00, 0.74865700E+00, -.54643000E+00, -.27501300E+00, -.15010700E+01, -.11222500E+01, -.48178300E+00, 0.50835100E-01, -.43614500E-01, 0.28755700E+00, 0.24763100E-01, 0.32444000E+00, 0.35752000E+00, 0.55415400E+02, 0.49770500E+02, -.73439500E+01, 0.23103900E+02, 0.19697000E+02, -.21116000E+02, -.15160600E+02, -.52988100E+01, 0.13794500E+02, 0.16965400E+02, -.25935600E+02, -.28916600E+01, -.27529200E+02, 0.15228900E+02, -.41160300E+02, -.96261900E+02, 0.48596100E+02, 0.82129500E+02, 0.47493100E+02, 0.43413600E+02, -.38664200E+02, 0.34706400E+02, -.65514100E+01, 0.54233400E+02, -.37023500E+02, -.56591600E+02, 0.32160800E+01, 0.32579000E+01, 0.31801100E+01, -.28021700E+01, -.58374200E+01, 0.30407100E+01, -.28197300E+01, -.62427400E+01, -.12716300E+02, 0.90389300E+00, 0.30775300E+01, 0.11321900E+01, 0.44433800E+00, -.12798000E+02, 0.12806500E+01, -.17272900E+01, 0.26423300E+01, 0.29039800E+00, -.48882300E+01, 0.34000100E+00, -.17924800E+01, -.20401400E+01, -.41030700E+01, 0.63182600E+01, 0.13155400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22210000E+02, 0.22149200E+01, 0.11836300E+00, -.11141700E+01, -.76484900E+00, -.31417800E+01, 0.36070600E+01, 0.39082400E+00, -.51348100E+00, 0.46880800E+01, 0.54910100E-01, 0.43739800E+01, 0.42563700E+01, -.34901600E+01, -.17449700E+01, 0.49458300E+01, 0.66821200E+01, -.74657500E+00, -.27873500E+01, 0.17532400E+01, 0.79026700E+00, -.10700500E+01, 0.13261800E+01, 0.72082800E+01, 0.41285300E+00, 0.43374700E-01, -.76004100E+00, -.65549700E+01, -.78751500E+00, 0.73671200E-01, -.24424700E+00, -.60212500E+00, 0.97774400E+00, -.11689700E+01, 0.41313900E+00, 0.35324600E+00, 0.39716800E-01, 0.38584800E+00, -.44584300E+01, 0.68131100E+01, -.89228000E+00, 0.15214800E+01, 0.10268600E+02, -.10452100E+01, 0.34047600E+01, 0.11477300E+01, 0.27555800E+00, -.12161500E+01, 0.32238800E+01, -.32102000E-01, -.19286600E+01, -.52140100E-02, -.50815500E+00, -.29253600E+01, 0.71456200E-01, 0.33565900E+01, 0.83574500E+00, -.24007700E+00, 0.42506300E-02, 0.18589800E+01, -.28942700E+01, -.20025300E+01, -.29727200E+00, -.16853100E+01, -.96923200E+00, -.33881000E+01, -.58460000E+00, -.42696300E+01, -.87349800E-01, 0.61390200E-02, -.30412000E+00, 0.31494600E+00, -.46207700E+01, 0.78966900E+00, -.15180200E+00, 0.11858900E+00, -.55810400E+00, 0.55566200E+00, -.43337100E-01, 0.10979600E+01, -.39719900E+00, -.20988800E+01, 0.10042200E+01, 0.11611700E-01, -.16901000E+00, 0.42487800E+00, -.12458200E+01, -.22132900E-01, -.94461200E+00, -.12198300E+01, 0.55359200E+01, 0.91575900E-01, -.32279000E+00, 0.25551700E-01, -.14559000E+01, 0.18437100E+00, 0.17078300E+01, 0.68675500E+00, -.29255200E+00, -.89236900E+00, 0.20238100E+01, 0.13362200E+01, 0.64726900E-01, -.92974300E+00, 0.68575400E+00, 0.13546000E+01, 0.18293200E+00, -.49401600E+00, -.25356000E+01, 0.11800100E+01, -.16130700E+01, 0.37738700E+00, -.23082300E+00, -.19893000E-01, 0.11179600E+01, -.18066200E+00, 0.12205300E+01, -.45454000E+00, -.59892600E+01, 0.16902100E+01, -.14458400E+00, -.10888100E+00, 0.33449300E+00, -.10010100E+01, 0.23943700E-01, 0.88164800E+00, -.17524700E+01, 0.39511500E+00, -.51114000E+00, -.89628100E-01, -.13807600E+01, -.11678000E+00, 0.12298400E+01, -.67757500E-01, 0.43465900E+00, 0.19065700E+00, -.74955900E+00, 0.29333000E+01, -.42645900E+00, -.22465100E+00, 0.20887200E+00, -.84875000E+00, -.12899700E+00, 0.38679300E+01, -.15675000E+01, -.64720800E-01, 0.26937300E+00, 0.24681300E+00, -.66809700E+00, -.64883100E+01, 0.29074900E+01, -.41869300E+00, -.16778600E+01, -.22439600E+00, -.64044700E+00, -.23082300E+00, 0.26001800E+00, 0.63759100E-01, -.11183700E+01, -.40217500E+00, -.32074700E+01, 0.15821800E+00, 0.21229500E+01, 0.11499800E+01, 0.12273500E-01, -.73881800E-01, 0.23952600E+00, -.20643400E+00, -.71214400E+00, -.99778000E+00, -.56770200E+00, -.76716900E+00, -.28628800E+00, 0.12884300E+01, -.50900700E+00, -.39641400E+01, -.13910300E+01, 0.32122000E+00, -.18747400E+00, 0.31100600E+00, -.76414000E+01, 0.11840300E+01, 0.76159600E+00, -.44920800E+00, -.11906800E+00, 0.12444000E+00, -.70738200E+00, 0.44593500E+00, -.27608800E+00, 0.59279700E+00, -.18433200E+00, 0.26201700E+01, 0.14726100E+00, 0.31790500E+00, 0.32450300E-01, -.10432800E+02, -.22077000E+01, -.60560100E+00, -.33456100E+00, 0.13952000E+00, 0.46726100E+00, 0.80749300E-02, -.31409300E-01, -.35340700E+01, 0.32236000E+00, -.50555400E-01, 0.44191500E+00, 0.14019000E+00, 0.31009100E+00, 0.82719500E+00, -.30922900E-01, 0.13132400E+00, -.37918100E-02, -.71093700E+00, 0.74852500E+00, -.20070200E+01, -.35426100E+00, 0.69515900E+00, 0.34625400E+00, 0.16852900E+01, 0.19700700E+00, 0.50832000E+00, 0.27964300E+00, -.76709200E+00, 0.82929700E+00, 0.32692100E+00, 0.29994300E+00, 0.18517300E+00, 0.50575300E-01, -.10805300E+01, 0.35132600E+00, 0.25872200E+00, -.33030400E+00, 0.93608400E+00, 0.11871400E+00, 0.16534500E+01, -.24867200E+00, -.98818900E-01, 0.66654100E+00, -.10709100E+03, 0.14933400E+02, -.38831700E+01, -.24496700E+02, 0.97800700E+01, 0.15816800E+02, 0.71053100E+01, -.13091800E+02, -.25122600E+01, 0.40275600E+02, -.95682900E+01, -.35843300E+01, -.30205600E+01, 0.27817000E+02, 0.14033500E+03, -.70170100E+02, -.75536200E+02, -.69434500E+02, -.10955700E+03, 0.38576800E+02, -.78702300E+02, -.56504400E+02, -.85239600E+02, 0.66817400E+02, 0.59600800E+02, -.96959400E+01, -.35655900E+01, 0.20205400E+01, 0.66568500E+01, -.76131400E+01, -.37558900E+01, 0.33545600E+01, -.66326300E+01, 0.35686300E+01, -.28931000E+01, -.73019600E+01, -.15041600E+01, -.83404800E+00, 0.42842400E+01, 0.17619100E+00, 0.55038800E+01, -.32607200E+01, -.42916900E+01, 0.81068500E+01, -.30561100E+01, 0.14322200E+01, 0.45403000E+01, 0.58995400E+01, -.88473800E+01, -.25539400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39427900E+01, -.27794500E+00, 0.13423500E+01, -.47080000E+00, 0.10700500E+01, 0.19454700E+01, -.18814200E+01, -.59715400E-01, 0.27620200E+00, -.12399000E+01, 0.27191700E+00, 0.17046000E+00, 0.98814300E+00, 0.12023800E+01, -.71944200E+00, -.99246500E+00, 0.17975700E+00, 0.70764500E+00, -.13833000E+00, 0.46567700E+00, -.74443500E+00, 0.70640500E-01, -.14818000E+00, 0.75057600E+00, 0.71671800E-01, -.58041700E-01, -.32322800E+00, 0.48115100E+00, 0.42553300E+00, -.34961100E+00, 0.22604200E-01, 0.67499100E+00, -.20952000E+00, -.38474900E+00, -.55967900E-01, 0.17343600E+00, 0.10024100E-02, 0.18828500E+00, -.72771000E+00, 0.26587100E+00, -.42923700E+00, 0.19135800E+00, 0.21908900E+01, -.68333300E-01, -.39050200E+00, -.98885200E-01, -.41263000E+00, 0.16736400E+00, -.13546000E+00, -.16649700E+00, 0.17685300E+00, 0.70603400E+00, -.22135800E+00, -.46242400E+00, 0.22376200E+00, 0.63727600E+00, -.90474700E-01, 0.24905300E+00, 0.16546200E-02, 0.95010800E+00, 0.46979700E-01, 0.71280200E+00, -.99416700E-01, -.83415100E-01, -.42299500E+00, -.35501800E+00, 0.30739100E+00, 0.25947900E+01, -.74960200E-01, -.40049700E-02, 0.17848600E+00, -.26401300E+00, -.79294000E+00, 0.46068000E+00, -.49720700E+00, 0.71113900E+00, -.15656000E+00, 0.15335700E-01, 0.62139800E-02, 0.22511500E+00, -.12008900E-02, -.89231200E-01, 0.11591500E+00, 0.80182700E+00, 0.38672200E+00, -.35239400E+00, 0.80821200E+00, -.47035800E+00, -.74117800E+00, 0.44993500E+00, 0.12904200E+01, 0.47226300E-01, 0.37978200E-01, 0.35536400E+00, -.49234600E+00, 0.85646100E-01, 0.67924600E+00, -.21574100E-01, -.21091100E+00, -.48280500E+00, 0.44677400E+00, -.30337600E+00, 0.31604300E-01, -.47579700E+00, 0.47732200E+00, 0.44090100E+00, -.82097900E+00, 0.18155300E+00, -.17735000E+00, 0.32654900E-01, 0.11856900E+00, -.36008300E-01, 0.82246100E-01, -.70814900E-02, -.45822200E-01, -.17987100E-01, 0.82824700E-01, 0.13411900E+00, -.95632800E+00, 0.28102700E+00, -.10978200E+00, 0.21662100E+00, -.81464800E-01, -.67027600E-01, 0.41256000E-01, 0.20624700E+00, 0.46764000E+00, 0.95658400E-01, 0.44673700E-01, -.57218500E-01, 0.70244000E+00, -.39683500E+00, -.16904900E+00, -.26444200E+00, 0.85799600E-01, 0.83451100E-02, 0.46377400E+00, -.36565400E+00, 0.70932600E-02, 0.24832500E+00, 0.27672200E-01, 0.32777200E+00, 0.32452400E+00, -.36499800E+00, 0.27247600E+00, -.71494000E+00, -.36135700E-01, -.67199400E-01, 0.18886200E+00, 0.70786200E+00, -.43914000E+00, -.43365500E-01, 0.65334300E-01, 0.22948700E-01, -.28790200E+00, 0.10529300E-01, -.42304300E-01, -.41253200E-01, 0.15487000E-01, -.37018300E+00, -.11121900E+01, -.56925100E-01, 0.36675400E+00, 0.78481300E+00, -.63263000E+00, 0.77557900E-01, 0.94034500E-01, 0.27579000E-01, 0.26896700E+00, -.96760700E-01, -.53619300E-01, -.14102900E+00, 0.20871700E-01, 0.49458100E+00, -.23074000E+00, -.41070300E+00, -.22922500E+00, 0.63096600E-01, 0.71424500E-01, -.26810900E-01, -.64298100E+00, 0.10722800E+01, 0.10448000E+00, -.27605000E+00, 0.24672500E+00, -.63050200E-02, -.41458100E-01, -.31718800E-02, -.59601600E-01, 0.19999100E+00, -.27791000E-01, 0.14911100E+00, -.64355100E+00, -.44774800E-01, 0.92732200E-01, -.24341900E+00, -.10181300E+01, -.15083300E+00, 0.15254000E-01, 0.14924600E-01, 0.14286000E+00, 0.20577200E-02, -.87306500E-01, 0.20300000E+00, -.58706700E-01, -.29157400E-01, 0.83551700E-01, -.37662800E-01, 0.17404300E+00, 0.28021600E-01, 0.16040000E-01, -.13401800E-01, 0.50053500E-02, -.59171300E-01, -.50170000E-01, -.35037400E+00, -.11836300E+00, -.38007300E+00, -.92883800E-01, 0.45960800E+00, 0.65628100E-01, 0.20964000E+00, -.42783300E-01, -.75810900E-01, 0.13608300E+00, -.94142000E-01, -.24739700E+00, -.20193900E+00, 0.18478900E+00, 0.39544300E-02, 0.73521400E-01, 0.14044700E-01, -.34569300E-01, 0.37546500E+00, 0.33552600E-01, -.17379700E+00, -.17502200E+00, 0.20989700E-01, -.75750300E-01, -.19591700E-01, -.11829500E+02, 0.14079000E+02, 0.11606700E+02, -.64157200E+01, 0.34425800E+01, -.59271700E+01, -.83437600E+01, 0.21289400E+01, -.10531700E+01, 0.17443600E+01, -.11860200E+02, 0.34255700E+01, -.20237800E+02, -.73840300E+01, 0.33449300E+01, 0.14854900E+02, 0.36844300E+01, -.45922300E+01, -.56738200E+01, 0.53624700E+00, -.35522300E+01, -.29034900E+01, 0.42355900E+01, -.18683400E+01, 0.11461700E+01, 0.44281000E+00, 0.24267300E+01, -.35649900E+00, -.23175800E+01, 0.73832200E+00, -.72888900E+00, -.25100000E+01, -.27251800E+01, 0.44933300E+00, 0.14307300E+01, 0.25332200E+00, 0.12071000E+01, -.25421000E+01, 0.11031400E+00, -.47611100E-01, 0.49094900E+00, 0.73173500E+00, -.79102300E+00, -.48576200E+00, -.14538400E+00, -.13020300E+00, -.16329000E+01, 0.17360300E+01, -.10232200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12470600E+02, -.14958200E+01, -.39249000E+01, -.58012800E+01, -.41450600E+01, 0.46865800E+01, -.28898000E+01, -.48333200E+00, 0.86135500E+00, -.39076800E+01, -.23200600E+01, -.19801900E+01, -.32459900E+01, -.68276900E+01, -.17438100E+01, -.17740200E+01, -.60622600E+01, -.51264900E+01, -.19373400E+01, -.14291900E+01, 0.44344700E+01, 0.60420800E+00, 0.20400600E+00, -.49868500E+01, -.81279000E+00, -.51919900E+00, 0.35758800E+01, -.64048100E+00, 0.83642200E-01, 0.16832500E+01, -.55925200E+00, -.16835500E+00, 0.13125100E+01, 0.29075900E+00, -.54298500E-01, -.52445500E+00, 0.32313500E-01, 0.13697700E+00, -.16845900E+01, 0.81946100E-01, -.75619000E+00, 0.24046000E+00, -.17664600E+01, 0.34968600E+00, -.67208700E-01, 0.37369000E+00, -.19668900E+01, 0.28758500E+01, -.18353000E+00, 0.15183100E+00, 0.12705700E+01, 0.94142500E+00, 0.77188900E+00, -.10789700E+00, -.81751400E+00, -.86131800E+00, -.86676000E+00, 0.96874900E+00, -.84281400E-02, 0.62885800E+00, 0.27255400E+01, 0.22350800E+01, -.71836600E+00, 0.12002500E+01, -.66647500E+00, -.32900200E+00, 0.59320700E+00, 0.40695800E+01, -.30726600E+00, -.43031400E-03, -.90983600E+00, 0.16176900E+00, 0.28294400E+01, -.70870200E+00, -.11409500E+00, 0.17958500E+00, 0.78291300E-01, -.65116300E+00, 0.12050200E+00, -.35173300E+00, -.24788600E-01, -.19845900E+01, -.99435000E-03, 0.27597500E+00, -.33549800E+00, -.27146500E+00, 0.63793000E+00, 0.65652700E-01, 0.14766000E+01, 0.34278400E+00, -.16784200E+01, -.12044300E-01, 0.45910400E+00, -.24701300E-01, 0.97179300E+00, 0.53666100E-01, -.11985600E+01, -.45661900E+00, 0.41261800E+00, -.50924200E+00, 0.30327800E+00, 0.37933000E+00, 0.42522800E-01, 0.56861400E+00, -.39090200E+00, -.30823800E-01, 0.42077000E+00, 0.24503200E+00, 0.53920900E+00, 0.51380000E+00, -.20889100E+00, -.41612500E+00, 0.43966100E+00, -.22521600E-01, -.74659000E+00, -.53054500E-01, 0.48999300E+00, 0.76737800E-02, 0.12652000E+01, -.37645000E+00, 0.57399600E+00, 0.83079400E+00, -.39282200E+00, -.81977800E-01, 0.21857600E+00, -.44443500E+00, 0.10027700E+01, -.19758700E+00, -.50936100E-01, -.90318400E-01, 0.11848600E+01, 0.62297000E+00, -.89256900E+00, -.84749900E+00, 0.22112000E-02, 0.25827700E-02, -.27502800E+00, 0.57988000E-01, -.83107300E+00, -.92958500E+00, 0.50100300E+00, -.77977200E-01, 0.52821700E+00, -.12969100E+01, -.25970500E+00, -.21644100E+01, -.81866600E-01, -.37373900E-01, -.12705400E+00, -.27342900E+01, 0.35771400E+00, -.30887500E-01, -.21891100E+00, 0.33537000E+00, -.72061800E+00, 0.34133500E+00, 0.11726600E-01, 0.10160900E+00, 0.49246200E+00, -.12167900E+00, -.80921100E+00, 0.10462900E+00, 0.71932500E+00, -.18507300E+01, -.18209500E+00, -.30269000E+00, 0.16496800E+00, 0.52842500E-01, 0.12615000E+00, 0.65042900E+00, 0.45628000E+00, 0.11276700E+01, 0.33219900E+00, -.11154500E+01, 0.14149700E+00, 0.78131700E+00, 0.42806800E+00, -.81638100E-01, 0.34190300E+00, 0.70754200E-02, 0.31609900E+01, -.76667600E+00, -.30629400E+00, 0.25262500E+00, -.10233300E+01, -.94267200E+00, -.23760400E+00, -.41777300E-01, 0.45916800E-02, -.67473200E+00, 0.12248700E+00, -.28203400E+00, 0.12452200E+00, -.11817000E+01, 0.31297200E+00, 0.15134400E+01, 0.11765400E+00, 0.97218800E-01, -.13588400E+00, -.22336600E+00, -.98899800E-02, -.12375300E-02, -.17050300E+00, 0.13440200E+01, -.40615300E+00, -.30757700E+00, 0.10071500E+00, -.22945900E+00, -.43172100E+00, -.24816000E-01, -.29662100E-01, 0.92797800E-01, -.13300500E-01, 0.26818000E+00, 0.65680900E+00, 0.10526700E+01, 0.20664000E+00, 0.35802800E+00, 0.78404300E-01, 0.72543000E-01, -.41199800E+00, 0.12301100E+00, -.18005100E+00, 0.17315000E+00, -.28189400E-01, -.12274600E+00, -.18056900E+00, 0.46523900E-01, 0.36292800E+00, -.10055100E+00, 0.83816600E-03, 0.24479900E+00, 0.18293000E+00, 0.27805000E+00, 0.12970500E+00, 0.22027800E+00, -.25225900E-01, -.99148800E-01, 0.10916200E+00, 0.26301600E+00, 0.92438900E+00, 0.58727400E+02, -.91513900E+01, 0.14830200E+02, 0.55385900E+00, 0.38072100E+01, -.62773700E+01, 0.42766600E+01, -.99136400E+01, -.74794900E+01, -.58598200E+00, 0.58577700E+01, 0.32184900E+02, -.19446900E+01, 0.78759700E+00, -.12746300E+01, 0.85076400E+00, 0.28542400E+02, -.43266400E+01, -.21351300E+01, -.10976500E+02, 0.14846900E+02, -.61961300E+01, -.54763300E+02, 0.93416800E+00, 0.17151300E+01, -.12378900E+01, -.44808300E+00, 0.44490800E+00, 0.38163700E+00, 0.15052600E+00, -.12106200E+00, 0.52688400E+01, -.82097100E+00, 0.12994300E+01, 0.50123900E+00, -.29052800E+00, 0.49062800E+01, 0.84237800E-01, -.12148500E+00, 0.17691600E+01, -.23334200E+00, -.16528900E+01, 0.32339300E+00, 0.27344600E+00, -.83370700E+00, -.13259000E+01, -.50788900E+00, 0.23169800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.33434800E+01, -.40455900E+00, 0.37124500E-02, -.17472100E+01, 0.43124500E+00, 0.17548000E+01, -.13128600E+01, 0.60266100E-01, 0.26693100E+00, -.11153300E+01, -.17659700E+00, 0.13737300E+00, 0.95493300E+00, 0.27955900E+00, -.11549700E+00, -.81245600E+00, 0.17260600E-01, 0.19893200E+00, -.84777000E+00, 0.26446900E+00, 0.30156000E+00, 0.13813900E+00, -.22635900E+00, -.53364300E+00, -.17709400E+00, -.40691800E-01, -.47686900E+00, -.15544100E+01, 0.13322600E+01, -.21740700E+00, -.24090700E+00, 0.14748700E+00, 0.10335400E+01, 0.37602700E+00, -.12538500E+00, -.30186400E+00, -.84592700E-02, 0.13137700E+00, -.11587800E+00, 0.64498200E-01, 0.16779500E+00, 0.82350100E-01, 0.13302700E+00, -.82477200E-01, 0.92498000E-01, 0.49231100E-01, -.49067900E-01, 0.50954900E-01, 0.89872700E-01, -.57436900E-01, 0.64834500E+00, -.14836200E+00, 0.31799800E+00, -.23692300E-01, 0.14930000E+00, -.42287000E+00, -.60483200E-01, -.15106200E+00, 0.37525400E-02, 0.19730500E+00, 0.58572100E+00, 0.52979200E+00, -.45793600E-01, -.15254000E+00, -.60176400E+00, 0.64004600E-01, 0.21519100E-01, 0.12918400E+01, -.92793900E-02, -.41072700E-02, 0.12497100E+00, -.32916900E-01, 0.64241000E+00, 0.35459700E+00, -.46860200E+00, 0.90763500E-01, 0.75455500E-01, -.26339900E+00, -.11268300E+00, -.17378700E+00, 0.14189600E-01, 0.61136500E+00, -.73820600E-01, -.35765200E-01, -.14779700E+00, -.17028300E-01, -.49546300E+00, -.20877700E+00, -.22221500E+00, -.57806400E-01, -.11842500E+01, 0.18451400E-01, -.17337900E+00, 0.83352200E-01, 0.30779800E+00, 0.14191300E+00, -.61314000E+00, 0.50863700E+00, -.18019100E+00, 0.13472300E+00, -.25591000E+00, -.25079700E-01, -.67683700E-02, -.56995000E-01, -.16742900E+00, -.19040600E+00, 0.20338900E+00, 0.11797500E+00, 0.39273600E+00, 0.68943100E+00, 0.96490400E-01, 0.14217800E+00, 0.13257200E+00, 0.45867100E-02, 0.40497700E-01, -.28322200E-01, -.18102600E+00, 0.14711600E+00, -.14797400E+00, -.24946600E+00, -.10236400E-01, -.23277300E+00, -.17582500E-01, -.16636700E+00, 0.13361600E-01, -.59436300E-01, 0.59102600E-01, -.40910500E-01, 0.58240400E-01, 0.15717800E+00, 0.76998400E+00, -.89057400E+00, -.12997600E+00, -.96864900E+00, -.19959300E-01, 0.13605600E-01, 0.13359300E+00, -.10598600E+00, -.32040800E-01, 0.57994200E-01, -.22509800E-02, 0.24056600E+00, 0.70633000E-01, 0.11982300E+00, 0.45622700E-01, -.37456800E+00, 0.93289200E-02, -.21061700E-01, 0.14272800E+00, -.16263700E+00, -.32705600E-02, 0.18070300E-01, 0.64490200E-02, -.35398100E-01, -.28253400E+00, 0.73568700E-02, 0.28734200E-02, -.15440500E-01, -.96282100E-02, -.18160500E+00, -.46048000E+00, 0.13003900E-01, 0.53363700E-01, -.14893500E+00, 0.58306600E-01, 0.67881500E-02, 0.59138800E-01, -.35179700E-01, -.50237100E-01, 0.14364000E+00, -.81812600E-01, 0.56943500E-02, 0.62484000E-01, -.12284800E+00, 0.97878700E-01, 0.35234700E+00, 0.13774200E+00, -.78022100E-01, -.78884500E-01, -.20275800E-01, 0.23409300E+00, 0.50266000E-01, -.10297600E+00, -.16626000E+00, 0.43410700E-01, -.11161900E-01, 0.22157700E-02, -.24157300E-01, -.38742400E-02, -.24886800E+00, -.14418500E-01, -.15807700E+00, -.13210500E+00, 0.10170000E+00, -.53219500E-02, 0.38522700E+00, -.82848600E+00, -.93485000E-01, 0.31062600E+00, -.27094900E-01, 0.12002600E+00, 0.29420800E-03, -.17450700E-01, 0.17790900E-02, 0.21067000E+00, -.71681600E-02, -.39065000E-02, -.71447000E-01, 0.82664700E-01, -.24935000E-01, 0.15912100E-01, -.70550900E-02, 0.83102100E-02, -.29258100E-01, 0.49132200E-02, -.16312700E+00, -.15981500E+00, -.16834700E+00, 0.42217900E-01, 0.41287600E+00, 0.15528300E+00, 0.15853200E+00, 0.98593100E-02, -.67474600E-01, 0.93051100E-01, -.23129000E-01, -.50270000E-01, -.63652900E-01, 0.19367900E-01, -.18479600E+00, 0.38854900E-01, 0.49651000E-01, 0.33992100E-01, -.19643900E+00, -.82225700E-03, 0.13833400E+00, 0.63417300E-01, 0.21390400E-01, 0.55879000E-01, 0.59387900E-01, -.55356800E-02, -.47040800E-01, -.17210000E+02, 0.10929800E+02, -.22602200E+01, 0.94805500E+01, 0.83555800E+01, 0.77943500E+01, 0.29778600E+00, -.47991300E+01, -.61819000E+00, 0.63286000E+01, 0.76715000E+01, -.67695800E+01, 0.36228700E+01, -.34245000E+01, 0.33196400E+01, 0.10914900E+02, -.22287800E+00, -.91848500E+00, -.72080700E+01, 0.48932900E+01, 0.28312000E+01, -.15898900E+02, 0.34875700E-01, 0.62063700E+00, -.15337600E+01, -.11667300E+00, 0.19566300E+01, 0.62745200E+00, -.52957600E+00, 0.18605700E+01, -.75569600E+00, -.70077900E+00, -.31591600E+00, 0.31106200E+00, 0.81815800E-01, -.92982000E+00, 0.73381200E+00, 0.75812300E-01, 0.14139100E+01, -.20728500E+00, -.81735100E+00, 0.77394200E+00, -.44937800E+00, -.36674000E+00, 0.74484200E+00, 0.62936100E+00, 0.98658000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.29362000E+02, 0.49701300E+00, -.21969800E+02, -.73257600E+01, 0.12688000E+02, -.25529400E+01, -.17242700E+01, 0.20581300E+01, -.20542800E+01, 0.31674600E+01, -.69512400E+00, -.11216500E+01, 0.71682600E+01, -.62456700E+01, -.33849700E+01, -.41424300E+00, 0.22881500E+00, -.90609100E+01, -.52303400E+01, -.65408500E+00, -.50374400E+01, -.22458100E+01, -.36143900E+00, 0.40552600E+01, 0.79982700E+00, 0.20366700E+01, 0.78810100E+01, -.11534100E+02, -.26203000E+01, 0.24899700E+01, -.12670000E+01, 0.10004800E+01, 0.12889500E+02, -.19650800E+00, -.44249900E+00, 0.60435500E+00, 0.17586300E+00, 0.15874600E+01, -.22685600E+01, -.60923200E+01, -.15076100E+01, -.93630200E-01, -.11116200E+02, 0.11146700E+01, 0.31086800E+00, 0.27808000E-01, 0.20453000E+01, -.18636200E+01, 0.94910300E+00, 0.41407700E+00, 0.14934900E+01, 0.11592600E+01, 0.79018000E+00, -.46287200E+01, -.91628200E+00, 0.50767300E+01, 0.10136800E+01, -.63374400E+00, 0.68273000E-02, 0.40044200E+01, -.65577200E+01, -.20049300E+01, 0.32848700E+00, -.17369500E+01, -.15309200E+01, -.15091500E+01, -.65064500E+00, -.18096500E+02, -.21650800E+00, 0.50772300E-02, -.12258100E+01, 0.12138600E+01, 0.14416300E+01, -.22075400E+00, 0.17558300E+00, -.14949100E+00, 0.13469800E+01, 0.82013100E+00, 0.20229800E+01, 0.65956100E+00, -.77483000E-01, -.20051800E+01, 0.11186200E+01, -.21966700E+01, -.10029000E+01, 0.58499400E+00, 0.15005700E+01, 0.13155200E+00, -.34126200E+01, 0.25080700E+01, -.15371600E+01, -.10811200E+00, 0.10935600E+01, -.35137600E+00, 0.27431700E+01, -.15594800E+01, -.40732400E+01, 0.15760700E+01, 0.81480700E+00, 0.82141300E-01, -.20288600E+01, 0.10932400E+01, -.15184700E+00, -.12375700E+01, -.28789100E+00, 0.31549200E+00, -.63260300E+00, -.12078500E+01, -.61387100E+00, 0.37074700E+01, -.33920200E+00, -.16952000E+01, -.17965400E+01, -.16808000E+00, 0.14001700E+01, 0.76928600E-01, 0.14615300E+01, 0.88829400E+00, 0.37752200E+01, -.45497000E+01, 0.19626900E+00, -.14559600E+01, 0.59188300E+00, 0.31333100E+00, 0.90151100E-01, -.55931000E-01, 0.23484500E+01, -.37547200E+00, 0.67539100E-01, -.27969300E+00, -.22030700E+01, 0.34711800E+01, 0.17134200E+00, 0.23409800E+01, 0.57417400E-01, -.15022300E+00, 0.89216200E+00, -.12361100E+01, 0.29686000E+00, 0.51933200E+00, -.57456100E+00, 0.34119500E+00, -.61112800E+00, 0.21856500E+00, 0.73848400E+00, -.24754300E+01, -.16783500E+00, -.69289600E+00, -.14411900E+01, 0.25756000E+01, 0.48285100E+00, 0.35963100E-01, -.50873800E+00, 0.16970600E+00, 0.63599100E+00, 0.86635200E-01, 0.29361300E+00, -.15477600E+00, -.23326800E+00, -.35628100E+00, 0.17438800E+01, -.57315600E-01, 0.33542600E+00, -.17516300E+01, 0.35409200E+00, -.69130600E+00, -.25423900E+00, -.10965900E-02, 0.57215900E+00, 0.91683200E+00, 0.51220900E+00, 0.23658700E-01, 0.79596100E-01, -.51451300E+00, 0.76980600E-01, 0.12293100E+01, -.36639300E+00, 0.19775300E+00, 0.24906100E+00, 0.15469300E+00, -.72599900E+00, -.12465200E+01, -.24334800E+00, 0.47173900E+00, 0.20467600E+00, 0.31979900E+00, 0.33134900E+00, 0.14906500E+00, 0.32375100E+00, -.43651100E+00, 0.13298500E+00, -.31399000E-01, 0.52437700E+00, -.35388200E+00, -.63329100E-01, -.20202300E+01, -.21164900E+01, -.29008200E-01, -.19027100E+00, 0.77488000E-01, 0.32743700E+00, -.29230000E-02, 0.99223200E-01, 0.11361000E+01, 0.18899100E+00, 0.17335700E+00, -.18044100E+00, 0.22624200E+00, 0.25277500E+00, -.18237600E+00, 0.12911500E+00, -.13117300E+00, -.39090900E-02, 0.15544100E+00, -.65375500E+00, -.80946900E+00, -.38056000E+00, -.17044100E+00, 0.17525800E-01, 0.15701900E+01, 0.12914400E+01, 0.30079800E+00, 0.46471900E+00, 0.56302100E+00, 0.40419600E+00, 0.48722200E+00, 0.31616700E+00, 0.11414600E+01, -.43878900E+00, -.52275400E-01, -.57017900E+00, 0.48722100E-01, 0.60042700E+00, -.15653300E+01, -.36450300E-01, 0.15373200E+01, 0.10054900E+01, 0.84316600E-01, 0.32551700E+00, 0.25074900E+00, 0.47225500E-01, -.31330700E+00, 0.53910300E+01, 0.41045800E+02, -.60243900E+01, -.15413800E+01, -.13604300E+02, -.29023500E+02, -.19136900E+02, 0.62919600E+00, 0.34386800E+02, -.23641900E+02, 0.43897300E+02, 0.66709400E+02, -.37514600E+02, -.50272900E+02, -.33321700E+02, -.70424300E+01, 0.26854900E+02, -.15600000E+02, 0.24448900E+02, -.13162000E+02, -.11246800E+02, -.22856000E+01, -.13581100E+01, -.89916700E+00, -.85751800E+01, 0.54428300E+00, -.18644900E+01, -.16675000E+01, 0.26341700E+01, -.82900200E+00, 0.22462000E+01, -.16167500E+01, 0.19549300E+00, -.11973900E+01, -.24977300E+01, 0.19418800E+01, -.15113900E+01, 0.16404000E+00, -.40700500E+01, -.15998900E+01, 0.18099200E+01, -.58924000E+00, 0.14144800E+01, 0.61323600E+00, 0.12557100E+01, -.66416200E+01, 0.21124700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16351400E+02, -.33655000E+00, 0.12126500E+02, 0.43116400E+01, -.54958300E+01, 0.15197800E+01, 0.31611700E+00, -.10778500E+01, 0.72292500E+00, -.11673500E+01, 0.12195300E+00, 0.60035500E+00, -.33858500E+01, 0.21196700E+01, -.35133900E+00, 0.88262900E+00, 0.89190000E-01, 0.19038200E+01, 0.25742200E+01, 0.10221600E-01, 0.20911400E+01, 0.97460500E+00, 0.46488200E+00, 0.12039500E+01, -.35637300E+00, -.13369700E+01, -.28769000E+01, 0.72510800E+01, -.11328600E+01, -.19516700E+00, 0.75137500E+00, 0.77207300E-01, -.51687100E+01, 0.13064700E+00, -.43705300E-01, -.15196300E+01, -.14753500E+00, -.62816300E+00, -.93252100E+00, 0.48161400E+01, -.42319900E+00, 0.17210300E+01, 0.35341500E+01, -.84118200E+00, 0.24718500E-01, -.41665300E+00, -.42672500E+00, 0.85396800E+00, 0.30897500E+00, -.24728400E+00, -.40868900E+00, 0.10172100E+01, 0.49505700E+00, -.15861400E+01, -.12702200E+01, 0.11497200E+01, 0.53603100E-01, 0.27043300E+00, -.17092700E-01, 0.16759100E+01, -.30053000E+00, 0.11718200E+01, -.15628800E+00, 0.29966800E+00, 0.14092200E+01, -.13930300E+01, 0.62995200E+00, -.19884700E+01, 0.29689700E+00, 0.10162000E-01, -.32318300E+00, 0.32209200E+00, 0.80965100E+00, -.44709900E+00, -.93494300E+00, 0.82884300E+00, 0.40696900E+00, -.14614700E+01, -.31616700E+00, 0.21557200E-01, -.21150400E-01, -.13408100E+01, 0.13697900E+01, 0.35422200E+00, 0.29562400E+00, -.19066800E+00, 0.18541100E+01, -.15146100E+00, 0.17775400E+01, -.62681400E+00, -.76409400E-01, -.10887700E-01, -.47776600E+00, -.52305700E-02, 0.45456800E+00, -.21525400E+00, -.21920500E+01, 0.73578700E-01, 0.27027600E+00, -.27791700E+00, -.10383900E+01, -.10995300E+01, -.78606100E-01, -.15894100E+00, -.10809600E+00, -.40427500E+00, 0.51419500E+00, 0.60019700E+00, 0.20115200E+00, -.46573300E+01, -.25736300E+00, 0.27264400E+00, 0.15617000E+01, 0.41107900E-01, -.60151800E+00, -.23414000E+00, -.35289100E+00, -.16495100E+01, -.18774500E+01, 0.20400900E+01, -.60343900E+00, 0.99341200E+00, -.13828200E+00, 0.20104900E+00, 0.19315300E-01, 0.17068900E+00, -.14227500E+00, 0.25902600E+00, -.65684700E-01, -.63019800E-01, 0.25103000E+01, -.14110400E+01, -.32406400E+00, -.89838700E+00, 0.42442800E+00, 0.10290500E-01, 0.24191700E+00, -.42582800E+00, 0.42463300E+00, -.18052800E+00, 0.12313700E+00, 0.27419400E+00, -.31694000E-01, -.10734400E+01, 0.15105100E+00, 0.38221900E+00, -.72220000E-01, 0.97992100E-01, 0.35681800E+00, -.77873300E+00, 0.80186500E-02, 0.20912600E-01, 0.19247500E+00, -.13603300E-01, -.93792600E+00, 0.98566000E-01, -.13075300E+00, 0.74616600E-01, 0.54358800E-01, 0.16973300E+00, -.69321700E+00, 0.10891000E+00, 0.16321900E+00, -.30644500E+00, -.34857100E+00, -.97744300E-02, 0.23884800E-03, 0.20108900E+00, 0.99383500E+00, -.26726700E+00, 0.61078900E-01, 0.42655400E+00, 0.60701300E-01, 0.86500400E-03, -.33427800E+00, -.43933200E+00, -.78545400E+00, 0.12311800E+00, 0.51253600E+00, -.28868100E-01, -.28505600E+00, 0.11466600E+01, 0.46675000E+00, 0.44881900E+00, -.17191300E+00, -.30276300E+00, 0.17793900E+00, 0.30723100E+00, -.60845800E-01, -.13358000E+01, 0.17830500E-01, 0.39279000E+00, -.98273900E+00, -.13572900E+00, 0.27802400E+00, -.15320400E+00, 0.46186000E+00, -.25518300E+00, -.21639400E+00, -.95770200E-01, 0.22504000E-01, -.14638200E-03, -.16886700E+00, 0.14552300E+01, 0.46007700E-01, -.13908600E+00, -.77959700E-02, 0.21985400E+00, -.14423200E+00, 0.43092800E+00, -.93152200E-01, 0.13615900E+00, -.26839100E-01, -.18079000E+00, 0.23882800E+00, 0.70954200E-01, 0.13560400E+00, 0.59146600E+00, 0.20334100E+00, -.11802700E+00, -.14824200E+00, -.41206200E-01, 0.95686400E-01, 0.10568800E-01, 0.18048500E+00, 0.21239200E+00, 0.53095000E+00, 0.35809000E+00, -.25783000E-01, -.21610500E+00, 0.20648300E+00, -.78066200E-01, 0.31281400E+00, -.91766500E+00, -.49811800E+00, 0.18526100E+01, 0.74128800E+00, 0.11271700E+00, -.31508300E+00, 0.53427300E-01, 0.13205700E+01, -.34702200E+00, 0.11189500E+01, -.11945400E+00, -.50636200E+02, 0.27004900E+01, 0.22589300E+02, -.13498000E+02, -.16208900E+02, 0.53153900E+01, 0.31570800E+02, -.12485500E+02, 0.55310300E+02, -.17856700E+02, 0.98728300E+01, -.19672200E+02, 0.87783300E+01, 0.67167600E+02, -.64742500E+01, 0.19643200E+01, -.16707600E+01, 0.28770400E+02, -.24691100E+02, -.81388900E+02, -.77832800E+00, 0.18073700E+01, -.14112300E+02, -.73592400E+00, 0.13601900E+02, 0.32527600E+01, -.19382400E+01, 0.12082400E+02, -.12452500E+02, -.36820300E+01, 0.13604000E+01, 0.54899800E+00, -.15611500E+01, -.13507400E+02, 0.31593200E+01, 0.35756100E-01, 0.37930800E+01, -.17324400E+00, -.31731100E+01, 0.32715300E+01, -.18071200E+01, -.15669800E+01, 0.17230800E+01, 0.12605000E+01, 0.78678700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.43688000E+01, 0.30339600E+00, -.16872700E+01, 0.11250500E+01, -.11712600E+01, -.25395800E+01, 0.24367500E+01, 0.45693500E-01, -.37216400E+00, 0.13951200E+01, -.61489700E-01, -.44652500E+00, -.14270900E+01, -.11600400E+01, 0.35587500E-01, 0.15283500E+01, 0.11070200E+00, -.10896500E+01, 0.22527500E+00, -.70907600E+00, 0.32518800E+00, -.24446100E+00, 0.32763800E+00, -.79430800E-01, 0.24269500E+00, 0.24062400E+00, 0.20891400E+01, -.24561900E+00, -.13945200E+01, 0.18322600E+00, 0.14048200E+00, -.43850900E+00, 0.34404300E+00, -.42388400E+00, 0.11037600E+00, -.77712100E-02, 0.39354000E-01, -.92476900E-01, -.13855900E+00, -.79016500E+00, -.27002300E+00, 0.10273300E+00, -.15709100E+01, 0.13837400E-01, 0.49999600E+00, -.84069500E-01, 0.51157600E-02, -.48231400E+00, 0.32212700E+00, 0.78862900E-01, -.58387300E+00, 0.13598800E+00, -.71011800E-01, -.12060300E+01, -.35234600E+00, 0.87893200E+00, 0.13398000E+00, 0.14592000E+00, -.75861700E-02, 0.67984000E+00, -.52239400E+00, -.27402600E+00, -.36488600E-01, 0.29352700E+00, 0.26961200E+00, -.38723400E+00, 0.10427400E+00, -.17860000E+01, -.48039200E-01, 0.72218500E-02, -.62942900E+00, 0.54179100E-03, -.11421100E+01, -.24617500E+00, 0.15271100E+00, -.34107000E+00, 0.17928800E+00, 0.43091500E+00, 0.12802200E+00, 0.47293200E+00, -.33275100E-01, -.80649300E+00, -.29696400E+00, -.15141800E+00, -.16076400E+00, 0.47740800E-01, 0.52355700E-01, -.34574600E+00, -.26131000E+00, 0.37503300E+00, 0.22060500E+01, -.12080600E-01, 0.56388900E+00, -.17784500E+00, -.81303300E+00, -.38841000E+00, 0.10121400E+01, -.56591900E+00, 0.28408900E+00, -.39725500E+00, 0.14502600E+00, 0.51661900E+00, 0.41755200E-02, -.26945600E-02, 0.24123300E+00, 0.33253500E+00, -.52644500E+00, -.27941600E+00, -.40694500E+00, -.94191900E-01, 0.22368800E+00, -.13787600E+00, 0.79264100E-03, -.14518400E-01, -.16443600E+00, 0.12345100E+00, 0.63043900E+00, -.37518500E+00, -.35658900E+00, -.48741300E+00, 0.11112100E+00, -.10102100E+00, 0.50320800E-01, 0.13824000E+00, -.30480300E-01, 0.85051200E-01, -.43925100E+00, 0.27586800E-01, 0.32783600E-01, -.24618700E-01, -.81090700E+00, 0.52767900E+00, 0.20886300E+00, -.11305100E+00, 0.10149100E-02, -.41017800E-01, 0.43284300E+00, 0.16045000E-01, 0.13529700E+01, -.44034900E+00, 0.23581300E+00, -.21175800E+00, 0.25503100E+00, 0.32507000E+00, -.22223200E+00, 0.53371100E+00, 0.54487600E-01, 0.11784800E+00, -.16789400E+00, -.93526300E+00, 0.10095600E+01, -.42061300E-01, -.23343400E-01, -.56048300E-03, 0.33356000E+00, -.18004600E-01, 0.48187200E-01, 0.20989000E-01, -.43798900E-01, 0.33051200E+00, 0.49280700E+00, -.32286100E-02, 0.11480300E+00, -.23721900E-01, 0.18359800E+00, -.33850900E-01, -.41783200E-01, -.28182100E-02, -.92791500E-01, 0.15757600E-01, 0.34595500E-01, -.78591400E-01, 0.24206600E-01, -.29030700E+00, 0.17816000E+00, 0.32752400E+00, 0.80319500E-01, -.91026200E-01, -.66772200E-01, 0.13643200E-01, 0.79719300E+00, -.82296300E+00, -.31545000E+00, 0.12474000E+00, -.11510200E+00, 0.19830600E-01, -.47948000E-01, -.13144700E+00, 0.35439900E-01, 0.37146200E+00, 0.48796500E-01, 0.13938400E+00, 0.31891000E+00, -.25833600E+00, -.13280900E-01, 0.10033700E+01, 0.31132900E+00, 0.28596000E+00, -.97570400E-01, 0.16889400E-01, -.16033400E+00, -.18521200E-02, 0.54102300E-01, -.12152400E+01, 0.21708300E-01, 0.32934500E-01, 0.91491500E-02, -.99168600E-01, -.15501700E+00, -.10379800E+00, -.11217800E-01, 0.22968100E-01, 0.51358100E-02, 0.79350600E-01, 0.83536500E-01, -.52400900E-01, 0.24815200E+00, 0.18734300E-01, -.17479300E+00, -.61149500E+00, -.90004300E-01, -.10010800E+00, -.15780000E+00, -.81268700E-01, -.17071100E+00, 0.15646000E-01, 0.11237900E+00, 0.63665600E-01, -.87235300E-01, -.11151900E+00, -.80491900E-01, 0.97486600E-01, -.70039000E-03, 0.11817200E+00, 0.27764000E-01, 0.18066600E+00, -.18044400E+00, -.31973400E-02, -.12887400E+00, 0.13596600E+00, 0.39174300E+00, 0.17825500E+00, -.54031100E+00, -.19663300E-01, 0.44249300E-01, 0.25735300E+01, -.31924400E+01, 0.23241900E+01, -.17921100E+01, 0.21375300E+00, -.21034600E+01, 0.28541100E+01, -.19094000E+02, -.46350400E+02, 0.23262300E+02, 0.27905200E+02, 0.22943800E+02, 0.12609600E+02, -.17439900E+02, 0.16879800E+02, -.25626800E+01, 0.23041500E+02, -.16781400E+02, 0.36707600E+01, 0.93604400E+00, 0.57498900E-01, 0.48243600E+01, -.83754300E+00, -.20275400E+01, 0.14641700E+00, -.24529300E+00, -.21455900E+01, -.29470200E+01, 0.13746500E+01, 0.60948200E+00, -.42396900E+00, 0.65168200E+00, -.28619300E+01, -.19443400E+00, -.48782900E+00, -.85558600E+00, 0.19477900E+00, -.42826600E+00, -.24510700E+00, 0.37393100E+00, -.80697800E-01, -.14117500E+01, 0.72866800E+00, 0.38142200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16846100E+02, 0.19508900E+01, 0.49891400E+01, 0.93917300E+01, 0.81259300E+01, -.64425000E+01, 0.31052500E+01, 0.64627400E+00, -.13188500E+01, 0.56007200E+01, 0.44411800E+01, 0.12374400E+01, 0.32862500E+01, 0.10212100E+02, -.62538900E+00, 0.36292200E+01, 0.93648300E+01, 0.70628300E+01, 0.31715300E+01, 0.20328100E+01, -.70231500E+01, -.11441600E+01, 0.34455400E+00, 0.80449500E+01, 0.13044000E+01, -.61374000E+00, -.45308200E+00, 0.42966800E+01, -.10940400E+01, -.15685500E+01, 0.64870800E+00, 0.67161600E-01, 0.33715200E+01, -.36576900E+00, 0.13637800E+00, -.60217300E+00, 0.32166600E-02, 0.15613800E+00, -.86870800E+00, 0.37606900E+01, 0.90667800E+00, 0.26503800E+01, -.48605900E+01, -.28861200E+00, 0.10899400E+01, 0.17986600E+00, 0.19681200E+01, -.16102600E+01, 0.14993700E+01, 0.64177100E+00, 0.59209900E-01, 0.10080400E+00, 0.12310100E+01, -.16573700E+01, 0.15527100E+01, 0.20111200E+01, 0.10143900E+01, -.44864000E+00, -.35171800E-03, 0.34631700E+00, -.30161700E+01, -.16957000E+01, 0.56174000E+00, -.17159000E+01, 0.14548300E+01, -.14081400E+01, -.24091000E+00, -.91597700E+01, 0.73287200E+00, 0.88007700E-02, 0.42729800E+00, -.39599900E+00, -.75559500E+00, -.76486000E+00, 0.13455700E+01, 0.58012600E+00, -.25474500E-01, -.13094000E+01, 0.51739300E+00, 0.79663700E+00, -.16118800E-01, -.12803600E+01, 0.13954600E+01, 0.18727400E+00, -.20265000E+00, 0.49770800E-01, -.18159000E+01, -.11739900E+00, 0.53975300E+00, -.90704300E+00, -.11507800E+01, 0.53873800E-01, 0.12476300E+01, 0.36323700E-01, 0.16429500E+01, -.12236600E+00, -.51329900E+01, 0.12247700E+01, -.12880500E+01, 0.23039500E+00, -.17485200E+01, -.90656800E+00, -.78566800E-01, -.51549600E+00, 0.19455600E-01, -.10703100E+01, -.85388900E+00, 0.18009000E+00, 0.45112100E+00, -.14297000E+01, 0.65389900E+00, 0.80465400E-01, 0.67342700E+00, 0.11717200E+00, -.17635900E+00, 0.17092200E+00, 0.98679200E+00, -.13964600E+01, -.11861900E+01, -.46712200E+00, 0.21672100E+00, 0.34941500E+00, 0.32617100E+00, -.11350700E+00, -.14317900E+00, 0.49151000E-01, 0.10977500E+01, -.47768600E+00, 0.12265100E+00, -.44952200E+00, -.11459700E+01, 0.29962400E+00, 0.14991500E+01, -.26764800E+01, 0.69653700E-02, 0.66051500E-02, -.38236800E+00, -.58953400E+00, -.19816400E+01, 0.36227600E-01, 0.66687500E-01, 0.77481300E+00, 0.38115000E+00, 0.20252300E+01, -.18397000E+00, 0.28115400E+01, 0.33747600E-01, -.12752200E+00, -.32594800E+00, -.38055900E+01, -.20174900E-01, 0.26069000E-01, 0.31146100E+00, 0.27799100E+00, 0.82636000E+00, 0.26702100E+00, 0.10019600E+00, -.12879100E+00, 0.36772200E+00, -.18763200E+01, -.30995200E+01, -.59093200E+00, 0.16953900E+01, -.22182300E+01, -.17543400E+01, 0.97030000E+00, 0.10453500E+00, -.14398000E+00, -.22643700E+01, -.16251300E+01, 0.66023400E+00, -.17282200E+01, 0.71419000E+00, -.85848200E+00, -.93691700E-01, 0.17421100E+01, 0.18468800E+00, -.99305400E-01, -.22655700E+01, -.44888400E-01, 0.72542600E-01, 0.21291800E+01, 0.23164800E+01, -.96309000E+00, -.58070700E+00, 0.79529800E+00, 0.78165300E+00, 0.15637000E+01, -.49890500E+00, -.51154500E+01, -.31925600E+00, 0.24924200E+01, -.20331600E+01, 0.51342200E+00, 0.40318600E+00, -.44522600E+00, 0.41393100E+01, 0.97220500E+00, -.10358400E+01, 0.21267500E+00, -.35395800E+00, 0.63426700E-03, -.35976700E+00, -.32585100E+01, -.21332600E+00, 0.47478700E+00, 0.48424200E+00, 0.45113700E+00, -.27302400E+00, -.20978200E+00, 0.31630100E-01, 0.10094400E+00, 0.80197800E-01, -.10422500E+01, -.96331200E+00, 0.46377600E+01, 0.29446800E+00, -.32049100E+00, -.18594400E+00, -.95504400E-01, -.32926300E+00, -.70685200E+00, 0.64083000E+00, 0.40552000E+00, -.26583200E+00, -.50862900E+00, -.63367100E+00, -.59224200E+00, -.27205900E+00, -.94146300E+00, -.35327600E+00, 0.14453200E+00, -.28377900E-01, -.41433200E+00, -.72813500E-01, -.43008100E+00, -.71604900E+00, -.28140100E+00, -.11090400E+00, 0.94330700E-01, 0.30067500E+00, -.41941300E+00, -.27653500E+01, 0.40518700E+00, 0.83219400E-01, 0.15017500E+01, 0.35633800E+02, 0.33190400E+02, -.13712900E+02, -.22467700E+01, -.25949000E+02, 0.24434000E+02, -.60930000E+02, -.86653000E+02, 0.43492800E+02, 0.20240200E+02, 0.43580000E+02, 0.35127500E+02, -.35607500E+02, 0.76907900E+01, -.26182600E+02, 0.10506300E+02, 0.90544900E+01, 0.10970600E+03, 0.81640800E+01, 0.26398100E+01, -.16582100E+02, -.14527000E+01, 0.10744400E+02, 0.36482100E+01, -.40683000E+01, 0.95396500E+01, 0.11247700E+02, -.52840400E+01, 0.59118700E+01, 0.24288400E+01, 0.40482500E+01, 0.11095200E+02, 0.74305900E+00, -.21459200E+01, 0.80440800E+01, 0.76411700E+01, -.51324700E+01, 0.49609300E+01, -.33795200E+01, -.33140300E+01, 0.33246500E+01, 0.12636400E+02, 0.52232100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.74734400E+01, 0.76417300E+00, 0.25761000E+00, 0.24820700E+01, -.13299500E+01, -.30890800E+01, 0.25889200E+01, -.79274500E-02, -.63865100E+00, 0.26984400E+01, 0.50140100E+00, 0.20514600E+00, -.10443900E+01, -.83510700E+00, 0.31362700E+00, 0.20334000E+01, -.51298600E+00, -.11378900E+01, 0.57805800E+00, -.86277000E+00, 0.35946300E+00, -.31378100E+00, 0.25723600E+00, -.71292200E+00, 0.21002900E+00, 0.40100400E+00, 0.17577000E+01, 0.13845700E+01, -.12263200E+01, 0.12583300E+00, 0.18733100E+00, -.32661000E+00, -.59335400E+00, 0.17381900E+00, 0.19310100E-01, -.73507200E+00, 0.45738600E-01, -.25683800E+00, 0.82249800E-01, -.16112600E+01, -.49743500E+00, 0.13794900E+00, -.25010600E+01, 0.58579000E-01, 0.69491200E+00, -.13418300E+00, 0.40422400E+00, -.67355300E+00, -.16093800E+00, -.35897400E-01, -.11945000E+01, 0.34340200E+00, -.31135500E+00, -.46662400E+00, 0.49130700E-01, 0.85496200E+00, 0.16747400E+00, -.21395100E+00, -.83347300E-02, 0.42950200E+00, -.13828700E+01, -.94455700E+00, 0.65215000E-01, 0.25720500E+00, 0.31431500E+00, 0.31234700E+00, -.28041700E+00, -.32749700E+01, 0.11359500E+00, 0.12476700E-01, -.64668600E+00, 0.16242700E+00, -.13321300E+01, -.23141800E+00, 0.28764100E+00, -.12980300E+01, 0.22656700E+00, 0.75868500E+00, 0.22677700E+00, 0.44890000E+00, -.52393600E-01, -.10527300E+01, 0.29148400E-01, -.38690000E+00, -.23119100E+00, 0.17921300E+00, -.20002000E-01, -.24744900E+00, -.28021900E+00, 0.33476600E+00, 0.19656800E+01, -.24493500E-01, 0.16554700E+00, -.18582900E+00, -.91840100E+00, -.56707200E+00, 0.54336900E+00, -.41373900E+00, 0.77295800E+00, -.44012000E+00, -.44743700E+00, 0.89235400E+00, -.29525100E-01, 0.25329500E-01, 0.12422300E+00, 0.23019200E+00, 0.35934200E+00, -.87921700E-01, -.86020700E+00, -.81705700E+00, -.41415300E+00, -.22273900E+00, 0.81622500E-01, -.53669200E-01, 0.25869800E+00, -.11039400E+00, 0.49700700E+00, 0.17079600E-01, -.19018900E+01, 0.53607300E-01, -.15342300E+00, -.34387200E+00, -.40164000E-02, -.19601000E+00, 0.66209500E-01, 0.22878100E+00, 0.40101500E+00, -.10658900E+00, 0.10389300E-02, 0.22351200E+00, 0.19820400E+00, -.27334400E+00, 0.58933600E-01, -.41067900E+00, -.13004700E+00, -.78304800E-01, 0.17346100E+00, -.21858300E+00, 0.21681000E+01, -.12980200E+01, 0.58191000E+00, -.10489100E+00, 0.22346900E+00, -.24921900E+00, -.42841600E+00, 0.64968900E+00, 0.28609200E-01, 0.13530100E+00, 0.77769900E+00, -.18834500E+01, 0.21942800E+00, -.10308100E-01, 0.32745200E+00, -.16475800E+00, -.43060100E+00, -.84656600E-02, -.11395100E-01, 0.19088100E+00, 0.19259400E-02, 0.74895400E+00, 0.38282200E-01, 0.53280200E-01, 0.38731000E+00, 0.93895600E-01, 0.29393600E+00, -.31288600E+00, 0.14396800E+00, 0.68454200E-01, 0.36586500E+00, 0.32405000E+00, 0.71155300E-01, 0.87067300E+00, 0.63689600E-01, -.22661100E+00, 0.21511600E+00, 0.15295600E+00, 0.14065300E-01, 0.81064800E-02, -.10659200E-01, 0.15809200E-01, 0.43661600E+00, -.52131900E+00, -.16289600E+00, 0.27099400E+00, -.11670300E+00, -.19422100E-01, -.84078500E-01, -.12182400E+00, 0.42961900E-01, 0.49362400E+00, 0.43841500E-01, 0.17163700E+00, -.10515600E+00, -.17732300E+00, 0.60893300E-01, 0.98504900E+00, 0.18930700E+01, 0.45823700E+00, -.19305200E+00, -.17898400E-01, -.22919400E+00, -.46148100E-02, 0.52807200E-01, -.16202500E+01, -.10387700E-01, -.41475300E-01, 0.17342100E-01, -.20046900E+00, -.21866500E+00, -.90200500E-01, -.35473500E-01, 0.65409900E-01, -.67001300E-02, 0.87658500E-02, 0.23040200E+00, 0.39827100E+00, 0.37333100E+00, 0.20824300E+00, -.11318300E+00, -.13878900E+01, -.21761000E+00, -.40772800E+00, 0.10838200E+00, -.80721000E-02, -.31703900E+00, 0.25204000E-01, 0.37024200E+00, 0.21141400E+00, -.30386500E+00, -.21191800E+00, -.28818400E-01, 0.12442400E-01, 0.83126300E-01, -.72907100E+00, -.50250600E-01, 0.46639800E+00, 0.20735100E+00, -.10956000E+00, -.25828500E-01, 0.11705300E+00, 0.16573500E+00, -.69071300E-01, 0.35083300E+00, -.83783800E-01, 0.17810100E+00, 0.10134800E+00, 0.23609600E+00, -.14732600E+02, -.18085700E+01, -.11431600E+00, 0.24334600E+02, -.13103400E+02, 0.31101900E+02, -.21403500E+02, 0.10078700E+02, -.21353300E+01, 0.10621700E+02, 0.20244700E+02, 0.37684200E+01, 0.17141300E+02, 0.17238300E+02, 0.28397700E+02, -.24546800E+02, -.20530000E+02, -.12169800E+01, -.55039400E+00, 0.57812600E+00, -.37368900E+00, -.57342500E+00, -.14817200E+01, 0.15937200E+01, 0.15653100E+00, 0.87900300E+01, 0.89814000E+00, -.21991900E+01, -.70838900E+00, -.28474600E+01, 0.88669700E+01, -.11080800E+01, -.33012000E+00, -.27912700E+01, -.23673900E+01, 0.51853800E+00, -.31236300E+00, 0.91640600E+00, 0.11986100E+00, 0.10538700E+01, -.49198700E+01, 0.11925600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11917900E+02, 0.98078000E+00, 0.18959000E+01, -.25130300E+01, -.86477600E+00, 0.15323800E+00, 0.59752100E+00, 0.64203000E+00, -.66989400E+00, 0.31996300E+01, -.11428000E+01, 0.34772500E+01, 0.43083700E+01, 0.75205400E-01, 0.37169400E+00, 0.10769000E+01, 0.42453300E+01, 0.17841400E+01, -.37939000E+01, 0.29481500E+01, -.15617900E+01, -.45772500E+00, 0.48938300E+00, 0.30906000E+01, 0.47575500E+00, 0.91483300E+00, 0.75874500E+00, -.55142500E+01, 0.96114300E+00, -.21593100E+00, -.42340400E+00, 0.24586100E+01, 0.31947700E+01, 0.93020000E+00, 0.22276800E+00, 0.79213200E+00, 0.11513900E+00, 0.23195200E-01, 0.59898600E+00, -.49014400E+01, -.80101700E+00, -.34261300E+00, 0.25580500E+01, -.35309900E+00, -.45352700E+00, 0.25622700E-01, 0.16330500E+01, -.17705000E+01, 0.33779500E-01, 0.48472100E+00, -.11362600E+01, 0.22329100E+00, 0.21233100E+00, 0.17391800E+01, 0.14821300E+01, 0.94329900E+00, 0.12144600E+01, 0.96691700E-01, -.17308400E-02, -.13612200E+01, -.39368800E+01, -.15048200E+01, 0.32493600E+00, -.13284800E+01, 0.10175800E+01, -.26646100E+01, -.42459900E+00, -.46272500E+01, -.83794000E-01, 0.60619700E-02, 0.20327100E+01, 0.54145100E+00, -.73580100E+00, 0.11328800E+01, -.25832200E+01, 0.54533700E+00, 0.42022100E+00, -.68318400E+00, 0.34986200E+00, 0.92950100E+00, -.80905200E-01, 0.35355500E+00, 0.17818400E+00, -.11087200E+00, -.15724100E+00, -.95224600E-01, -.97017500E+00, -.11197800E+01, 0.91967300E+00, -.19423400E+00, 0.38236300E+01, 0.14920200E-01, 0.15317300E+01, -.37540000E+00, -.69042900E+00, -.12520700E+01, 0.36847100E+01, -.18534300E+01, 0.13062600E+00, -.13597100E+01, 0.15011300E+00, -.56549700E+00, 0.34184400E-01, 0.20654400E+00, 0.26925800E+00, -.25502100E-01, 0.46008600E+00, 0.54741000E+00, -.68334000E+00, 0.24376600E+01, -.52593800E+00, 0.99680000E-01, 0.13726300E+01, -.61386300E-01, 0.20093400E+00, -.79072600E-01, -.25920000E+00, -.36155900E+00, -.68455700E+00, 0.68853700E-01, 0.53026400E-01, 0.20190800E+00, 0.21447500E+00, -.30465600E+00, 0.20757100E-01, 0.98614400E-01, -.25755400E+00, -.40774800E-01, 0.38448500E+00, -.38756600E+00, 0.34443100E+00, -.66654900E-02, -.38966900E+00, -.17636600E+01, -.15113900E+00, -.11701300E+00, 0.20889200E+00, 0.39081800E+00, 0.14421200E+01, -.47713100E+00, -.62634800E+00, 0.33624200E+00, 0.14231300E+00, -.14743000E+01, -.30706500E+00, 0.13529100E+01, -.11432400E+00, 0.84816100E-01, -.80824100E-01, -.11609100E+01, 0.43395700E+00, 0.11882000E+00, 0.49717100E+00, -.47154000E-01, -.93169800E+00, 0.11031400E+00, -.60773600E-01, 0.22416200E+00, 0.70930800E-01, -.67403000E+00, 0.50004500E-01, 0.28191100E-01, 0.10628200E+01, 0.32105700E+00, 0.27699100E+00, -.74528600E+00, -.18877000E-01, 0.34026400E+00, 0.18182800E+01, -.78933500E+00, 0.34027800E+00, 0.55757800E+00, -.19130700E+00, 0.35888200E-01, -.54921600E-01, -.17636300E+01, -.55961600E+00, 0.21813000E+00, -.74970000E+00, 0.21691600E+00, -.42188000E+01, -.32472600E+00, 0.60923600E+00, 0.36219700E+00, 0.32101000E+00, 0.16159500E+00, -.41144900E-01, -.33332800E-01, -.12097500E+00, -.12789100E+00, 0.37536900E-01, -.13103700E+00, -.13613400E+01, 0.31979800E+00, 0.29147300E-01, -.27496700E+01, -.92834500E+00, -.26771400E-01, -.32425700E+00, 0.99764500E-01, 0.16563100E+00, -.32989100E-02, -.17693700E-01, -.15720600E+01, 0.27574300E+00, 0.34374200E+00, -.91283100E-01, -.12642500E-01, 0.30200800E+00, -.18330600E+00, 0.80325900E-01, -.57445600E-01, 0.12256600E-01, -.14593200E+00, -.50357300E+00, -.59923600E+00, -.14020800E+00, -.35970300E-01, -.17870000E+00, 0.99239500E+00, 0.62416600E+00, 0.25872700E+00, 0.34155700E+00, 0.29837300E+00, 0.33459800E+00, 0.47861400E+00, 0.59416800E+00, 0.72193200E+00, 0.28785600E+00, 0.88710300E+00, -.26394200E+00, -.42813700E+00, 0.33516000E+00, -.46203300E+00, -.26627200E+00, 0.30090500E+00, 0.56569300E+00, -.12020400E-01, 0.15432600E+00, -.16923800E+00, 0.18055400E+00, -.45945800E+00, 0.76538200E+00, 0.16180300E+00, -.60961800E-02, -.14269100E+01, -.20480600E+00, -.70215900E+00, -.21324200E+02, 0.83340300E+01, 0.45871400E+02, -.27684700E+01, -.22982800E+02, -.58329400E+02, 0.29322100E+02, 0.25096600E+02, 0.29131800E+02, 0.30586400E+01, -.50705100E+01, 0.98731100E+01, -.13040300E+02, 0.24170400E+02, -.31575700E+01, 0.21659700E+02, 0.43768500E+01, 0.94000800E+00, 0.94462300E-01, -.21704000E+01, 0.14402400E+01, -.13700300E+01, 0.11845300E+01, 0.22284000E+01, 0.10992900E+02, -.16017500E+00, 0.89184900E+00, 0.74395400E+00, -.83492700E+00, 0.10721800E+02, -.19642300E+01, -.23603500E+01, -.19923900E+01, 0.99686800E-02, -.18356400E+01, -.16235800E+01, 0.20850600E+01, -.12365700E+01, 0.12956300E+01, -.25192800E+01, -.15538700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.56802200E+01, -.60771100E+00, 0.39348800E+00, -.46461700E+01, -.36259900E+01, 0.30151100E+01, -.82571000E+00, -.19358800E-01, 0.80288900E+00, -.13829300E+01, 0.14823500E+00, -.18464500E+00, 0.49724200E+00, 0.14898300E+01, -.41671900E+00, -.33763600E+00, 0.46204800E+00, 0.12893100E+01, -.16300200E+01, 0.69485000E+00, 0.12310900E+01, 0.27430700E+00, -.54579300E-01, -.10580000E+01, -.24066200E+00, -.34820300E+00, -.33290200E+00, -.13338900E+01, 0.98079300E+00, -.48646400E+00, -.95682400E-01, -.37554400E+00, -.40126800E+00, 0.11261100E+01, -.38776600E+00, 0.28804800E+00, -.43802900E-01, 0.31902800E+00, -.51319200E+00, 0.28641500E+00, -.14115200E-01, 0.11026000E+01, -.28189200E+01, 0.46960100E-01, 0.18644100E+01, 0.33090700E+00, 0.32605500E+00, 0.57307700E+00, -.28560900E+00, 0.56489200E-01, -.70469800E+00, -.15467700E+00, 0.87991400E+00, 0.36283900E+00, -.25399900E+00, -.17438200E+01, -.30445300E-01, 0.47629800E+00, -.45373100E-02, -.52300400E+00, 0.19546300E+01, 0.79100100E+00, -.24023300E-01, 0.37881200E-01, 0.12932000E+01, -.78151300E+00, 0.21944400E+00, 0.13070700E+01, 0.14996400E+00, -.31349200E-02, 0.43144200E+00, -.75159100E+00, -.62175300E+00, -.28337700E-01, -.84503300E+00, 0.15466400E+00, -.26421900E-01, -.90813400E+00, -.67952300E+00, -.28901000E-01, 0.35032500E-01, -.34224000E-01, -.22067600E+00, 0.42295300E+00, 0.61566700E-01, 0.33713000E-01, -.78396400E+00, -.20655700E+00, -.88678700E-01, -.70593300E+00, -.43511500E+00, 0.43529300E-01, 0.70924600E-01, 0.41222000E+00, -.21724200E+00, 0.26966000E-01, 0.11953200E+01, -.51329900E+00, -.69995200E+00, -.31508800E+00, 0.40438400E+00, -.15086700E-01, 0.33894100E-01, 0.38225700E-01, -.49563700E-01, 0.46486700E+00, 0.72632600E+00, 0.63123500E-02, 0.20089300E+00, 0.29396400E+00, -.31971100E+00, -.84989800E-01, 0.85538300E-02, -.76345400E-02, -.20717500E-01, -.19345900E-02, 0.66723500E-01, -.36488400E+00, -.78321800E+00, 0.25917300E+00, -.96688600E-02, 0.42042200E+00, 0.84034700E-01, -.12641800E+00, -.15162900E-01, -.15783000E+00, 0.79108300E-01, -.16927800E-01, 0.84993100E-01, -.11258600E+00, 0.22786900E+00, -.95956500E-01, 0.37819600E-01, -.92092300E+00, -.62444900E-01, -.62153300E-01, 0.23083500E+00, -.14925000E-01, 0.99304000E+00, -.26080700E+00, -.27068600E+00, 0.19669200E+00, 0.11609200E+00, -.13479700E+00, -.10810200E+00, 0.66638200E+00, -.33433700E-01, 0.75597100E-01, 0.82434800E-01, 0.25131700E-01, -.26223800E-01, -.63451200E-01, 0.88146300E-01, 0.12543700E-01, -.75116400E-01, -.32768800E-01, -.40477100E-01, 0.11036200E+00, -.20900600E-01, -.38894400E+00, 0.32883600E-01, -.33733800E-01, 0.27498600E+00, -.10903000E+00, -.97829300E-01, 0.37357800E-01, -.15387000E+00, 0.60779900E-01, 0.17023400E+00, -.38564400E+00, 0.91236600E-01, -.32257900E-01, -.10679000E+00, 0.23918600E+00, -.10919300E+00, -.69859400E+00, -.24766900E+00, 0.18193100E+00, -.97919800E-01, 0.79905700E-02, -.10209200E+01, 0.16986100E+00, 0.97258800E-01, 0.19532300E+00, 0.19021900E+00, 0.13848800E-01, -.15206300E+00, -.13720700E+00, 0.26298800E-01, 0.76071300E+00, -.11111500E-01, 0.46174200E-02, -.16424300E-01, -.23483300E+00, 0.40499000E-01, -.23003500E+01, -.13038800E+01, -.29207500E+00, -.26718900E-02, -.38761000E-01, 0.74601200E-01, 0.20549900E-02, -.17265500E-01, 0.40395700E+00, -.12592300E+00, 0.29475900E-01, 0.48602700E-01, 0.11771000E-01, -.16412400E+00, -.82629700E-01, -.33779000E-01, -.20359500E-01, 0.14308200E-01, -.10871200E+00, 0.41632300E-01, -.29313200E-01, -.22950300E-01, 0.20105100E+00, -.14596100E-01, -.15189000E+00, 0.32417800E-01, -.11819700E+00, 0.50815600E-02, 0.39789200E-01, -.43139600E-01, 0.52930000E-01, 0.12092300E+00, 0.14297600E+00, -.68181100E-01, -.16638600E+00, -.11674400E+00, 0.56010500E-03, -.12137900E-02, 0.25192700E+00, 0.24070100E-02, 0.68366000E-01, 0.19240800E-01, 0.12721900E-02, 0.65293100E-01, -.97263300E-02, -.10226200E-01, 0.38627000E-01, -.12709300E+01, 0.55653800E-01, 0.12970400E+00, -.17625700E+00, 0.57036400E-01, -.34654300E+00, -.20305500E+00, 0.68871400E+01, 0.17841000E+02, -.18967900E+01, 0.20180200E+01, -.39163200E+02, 0.19724100E+02, 0.11083200E+02, 0.19534900E+02, 0.52037300E+01, 0.17040700E+00, 0.16265600E+02, 0.19213900E+01, 0.23077300E+02, -.96464700E+01, -.12096000E+01, 0.56768300E+00, -.18601100E+00, 0.25046300E+01, -.89356900E+00, -.81083900E+00, -.10825100E+01, 0.81013900E+00, -.26172000E+00, 0.69310300E+01, 0.94145900E+00, -.15319100E+01, -.37393900E+00, -.92519900E+00, 0.69865800E+01, -.80965800E+00, -.86945600E+00, -.17054700E+01, -.11485100E+01, -.17305700E+00, -.87041000E+00, 0.84867200E+00, -.25833300E+00, 0.91149500E+00, -.20038000E+01, -.63615500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17782700E+02, -.18336000E+01, -.68156700E+00, -.11903400E+02, -.79095500E+01, 0.76604800E+01, -.27266900E+01, -.18016100E+00, 0.18705500E+01, -.51383600E+01, -.87246300E-01, -.22033500E+01, -.99555800E-01, 0.32690300E+01, -.13098700E+01, -.20889900E+01, -.13590800E+01, 0.63758700E+00, -.33240600E+01, 0.26249600E+01, 0.29173000E+01, 0.95242000E+00, 0.16602000E+00, -.18592100E+01, -.10616000E+01, -.11982900E+01, -.42462500E+01, -.34572600E+01, 0.42006600E+01, -.18094300E+01, -.51925700E+00, -.10779200E+01, -.15415100E+00, 0.28302100E+01, -.12681500E+01, -.89439900E+00, -.17539400E+00, 0.12141400E+01, -.12290300E+01, 0.18185100E+01, 0.78348500E+00, 0.20088000E+01, -.38322100E+01, 0.21497200E+00, 0.59505200E+00, 0.40775100E+00, 0.32997800E+00, 0.24288900E+01, -.16876700E+01, -.87315000E-01, 0.49261800E+00, 0.92848400E+00, 0.16856900E+01, -.14976700E+01, -.12034800E+01, -.17584100E+01, -.66613700E-01, 0.53854400E+00, 0.66511200E-02, 0.19835900E+01, 0.17617100E+01, 0.18031900E+01, -.78339400E-01, 0.83831800E-01, 0.14201000E+01, -.54352000E+00, 0.60951600E+00, 0.46688200E+01, 0.92175500E-01, -.30214800E-01, 0.72013200E+00, -.13491600E+01, 0.42070800E+01, 0.50171100E+00, -.18711700E+01, 0.11748200E+01, 0.17351200E+00, -.25140800E+01, -.14875800E+01, -.24446600E+00, 0.86233400E-01, 0.55680400E-02, -.49065900E+00, -.86402100E-01, -.34385900E+00, -.17204000E+00, 0.68598600E-01, 0.64295600E+00, -.62123200E+00, -.31559800E+00, -.52652200E+01, 0.56358300E-01, -.31832300E+00, 0.68174400E+00, 0.17125200E+01, -.13349600E+00, -.17278600E+01, 0.15207600E+00, -.11612800E+01, 0.64717200E+00, -.10543300E+01, -.73284600E+00, 0.24959700E-01, -.20598700E+00, -.73737800E+00, 0.11058900E+00, 0.80442800E+00, -.94468300E-01, 0.14248900E+01, 0.51303600E+00, 0.40769700E+00, -.58083000E+00, -.12466700E+01, 0.44675100E-01, 0.83022400E-01, 0.13471400E+00, -.11618500E+00, 0.45385600E+00, 0.17167400E+01, -.14425000E+01, -.90469500E-01, -.23175900E+00, 0.14318100E+00, 0.24421000E+00, -.63854500E-01, -.12123100E+01, 0.12398900E+01, -.24574300E+00, 0.21509500E+00, -.39837600E-01, 0.25302300E+00, 0.21754200E+00, -.70925200E+00, -.14170500E+01, -.22295600E+00, -.60384600E-01, 0.46842300E+00, -.13995000E+01, 0.16673300E+01, -.38008700E+00, -.44779700E+00, 0.26139800E+00, -.19779000E+00, -.26987500E+00, 0.55185100E+00, -.30024600E+00, -.40986300E-01, -.13268000E+00, -.67449000E+00, 0.26516400E+01, -.93104900E+00, -.81816200E-01, 0.25971300E-01, -.33760300E-01, 0.44159100E+00, -.12934500E-01, -.12038100E+00, -.18142900E+00, -.93473800E-02, 0.24830700E+00, 0.14991200E+01, -.44967400E-01, -.71479700E+00, -.83833600E+00, -.79350600E-01, 0.20218500E+00, 0.95901500E-01, -.13751200E+00, -.10588100E+01, 0.58561900E+00, -.25837800E-01, -.16993900E+00, 0.10427800E+00, -.29077300E+00, -.12033700E+00, 0.20740600E+01, 0.38406300E+00, -.15710100E+00, 0.90838900E+00, 0.63051500E-01, 0.22363200E+01, -.19064400E+01, -.90685700E+00, 0.21048800E+00, 0.10953000E+00, 0.56231800E+00, 0.22934900E+00, -.30663900E+00, 0.20124600E+00, 0.72963200E+00, 0.17839200E+00, -.31937700E+00, 0.18814100E+01, -.16948800E+01, 0.26384100E+00, 0.15742500E+01, -.10715100E+00, 0.25627200E+00, -.69072900E-01, -.46243100E-01, -.31930400E+00, -.15104000E-02, 0.12726600E+00, 0.31722500E+01, -.79406600E-01, -.27942300E+00, -.13036900E+00, 0.33683100E+00, -.65572200E+00, -.14368500E+00, -.68200400E-01, 0.58750200E-01, 0.19721600E-01, 0.71084900E-01, -.43381500E-01, 0.18057100E+01, -.28486700E-01, 0.79311300E+00, 0.31003500E+00, -.24150300E+00, -.11816300E-01, -.12038200E+00, -.43316800E-02, 0.19880000E+00, -.23879500E+00, 0.18318800E-01, 0.29731900E-01, 0.64964100E+00, -.31944400E+00, 0.92237100E-01, -.98808300E-02, 0.32863800E+00, 0.37378900E-01, 0.14975700E+00, -.11958100E-01, 0.92982600E+00, 0.16955000E+00, 0.10364200E+00, -.23478500E+00, 0.20894900E+00, -.34581400E-01, 0.38798800E+00, -.41395800E+01, 0.12754100E+00, 0.72286600E+00, 0.24503300E+01, 0.50370300E+00, -.50341300E+00, -.95090700E+00, 0.33684500E+00, 0.38658300E+02, -.28785500E+01, 0.48963500E+02, 0.25143700E+02, -.12644800E+02, -.34537600E+02, -.12566900E+02, -.12341900E+02, 0.42024200E+02, -.97088400E+01, -.18723000E+02, 0.33224600E+01, 0.23870100E+02, -.83364800E+02, -.16778300E+01, 0.13632000E+01, -.29619900E+01, 0.87123800E+00, -.14703000E+01, -.21028600E+01, 0.23782500E+01, 0.59810200E+00, 0.27280400E+02, -.22890400E+01, -.39489600E+01, 0.85591100E+00, -.19247000E+01, 0.27337900E+02, -.70041700E+00, 0.69149600E+00, -.93243800E+00, -.36821800E+01, -.12814700E+01, -.28065900E+01, 0.14202300E+01, 0.10061400E+01, 0.40861300E+01, -.68146400E+01, -.32625200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35504600E+01, 0.36042400E+00, -.33670400E+00, 0.17370500E+01, 0.18587900E+00, -.15627400E+01, 0.84132300E+00, -.23427900E-01, -.31323200E+00, 0.54844500E+00, 0.23556000E+00, -.25542700E+00, -.70556300E+00, -.24858600E+00, -.21059000E-01, 0.55341500E+00, -.41448800E+00, -.63911700E+00, 0.33154400E+00, -.30963400E+00, -.12769900E+00, -.14478500E+00, 0.18338200E+00, 0.25008100E+00, 0.20382400E+00, -.11897200E-01, 0.14327600E+01, 0.25446300E+01, -.10575600E+01, 0.86476500E-01, 0.23912600E+00, -.34607300E+00, -.10993100E+01, -.35270200E+00, 0.96312700E-01, 0.16696300E+00, 0.40282200E-01, -.28777400E+00, 0.20902500E+00, 0.80010200E+00, -.26861400E+00, 0.11367100E+00, 0.30216600E+00, -.45677700E-01, 0.36911400E+00, 0.70344800E-01, -.10933300E+00, -.28413000E+00, -.47129900E+00, -.10568800E-01, -.11223000E+01, -.16912000E-01, -.29087600E+00, 0.13156100E+01, 0.52005400E+00, -.83319700E-01, 0.10256000E+00, -.48575200E+00, -.53430300E-02, -.41114000E+00, -.72481800E+00, -.71733200E+00, 0.48503000E-01, 0.10446500E+00, 0.53787800E+00, 0.40898000E+00, -.77980500E-01, -.14746200E+01, 0.79673500E-01, 0.69962400E-02, -.35058800E+00, 0.20332100E+00, -.88879600E+00, -.30601500E+00, 0.51377600E+00, 0.16758400E+00, -.24695900E+00, 0.18691600E+00, 0.25939900E+00, 0.70493900E-01, -.22775800E-01, 0.12548400E+00, 0.19791000E+00, -.46809600E-02, 0.28104800E+00, -.35012800E-01, 0.23168700E+00, 0.28276200E+00, 0.23581100E+00, 0.55676800E-01, 0.18836100E+01, -.13908700E-01, -.16659100E+00, 0.15516300E-01, -.14629000E+00, -.49761300E-01, -.68757400E-01, -.13178500E+00, 0.87614900E-01, 0.15815300E+00, -.49267400E-01, 0.38766300E-01, -.78444600E-02, -.11001400E+00, 0.17499200E+00, 0.12461800E+00, -.95707100E-01, -.13275900E+00, -.87397900E+00, -.29652200E+00, -.17170700E-01, 0.39120200E-01, -.10173300E+00, -.44453000E-02, 0.81474600E-01, -.48679900E-01, 0.27284500E+00, -.27854900E+00, -.29105900E+00, -.12948100E+00, -.55200700E-01, -.15886300E+00, 0.30601300E-02, -.11277400E+00, 0.98822300E-02, 0.78780900E-01, 0.30974800E+00, -.86654800E-02, -.11112900E+00, 0.77815600E-01, 0.98571800E-01, -.65159700E-01, 0.13491600E+00, 0.12679800E+00, -.46138200E-01, -.23657600E-02, 0.96737600E-01, -.18953100E+00, 0.14073300E+00, -.10485400E+00, 0.31395900E-01, 0.18849000E+00, 0.45531700E-01, -.18750600E+00, 0.26242800E-01, -.25684100E+00, -.93600800E-02, -.28589300E-01, 0.19693700E+00, -.54901900E-01, -.18214700E+00, 0.36346200E-02, 0.79900300E-01, -.30660600E-01, -.10593200E+00, 0.18408400E-01, -.23474300E-02, 0.21676300E-01, 0.43940400E-01, -.37298000E-01, -.20687400E+00, 0.56089400E-02, 0.79457300E-01, -.14356500E+00, 0.79453600E-01, -.64138200E-01, 0.46550000E-01, 0.95696200E-03, 0.77292400E-01, 0.15718500E+00, -.24676300E-03, 0.10965500E+00, 0.53566700E-01, -.11904000E+00, 0.10910500E+00, 0.19260200E+00, 0.66307000E-01, -.40518900E-01, 0.31688800E-01, -.13217700E-01, 0.29922000E+00, -.39748000E-01, -.43479200E-01, 0.24252700E-01, 0.55912400E-01, 0.59089400E-01, 0.16125900E-01, -.10165400E+00, 0.12062800E-02, -.14487600E+00, -.70777600E-02, -.14920400E+00, -.93942400E-01, -.24976200E-01, 0.67839000E-01, 0.66408100E+00, -.27413600E+00, -.54070000E-02, 0.17700200E+00, -.32155700E-01, 0.87989000E-01, 0.51722500E-03, 0.48245100E-02, 0.37192000E+00, 0.79037300E-01, -.72414700E-01, -.35183300E-01, -.45131000E-01, 0.53300800E-01, 0.12692600E-01, 0.23159700E-01, 0.25347400E-01, 0.90070000E-02, -.61675000E-01, -.46863400E-01, 0.10851900E-01, 0.28048000E-01, 0.61513900E-01, 0.49042500E-01, 0.21305200E+00, 0.89649200E-01, 0.51732700E-01, 0.44511700E-02, -.91865100E-01, 0.44038300E-01, 0.11404800E-01, -.23322600E-01, 0.34084600E-02, 0.73831000E-01, 0.10092000E+00, 0.92241100E-01, -.33205900E-01, 0.81564900E-02, -.72649100E-01, -.10783400E-01, 0.30494200E-02, 0.43784700E-01, -.17540600E-01, 0.42702800E-01, 0.18118700E-01, -.19764900E-01, -.24413500E-01, 0.27040200E+00, 0.54619800E-02, -.15328700E-01, -.19758100E+00, -.46708000E-01, -.15858100E+00, 0.67775900E-01, -.93812700E-01, 0.46106400E-01, 0.23392200E+01, -.14814000E+01, -.52728800E+01, 0.26008000E+01, -.16865800E+00, 0.26198800E+01, 0.10759900E+02, -.39292300E+01, 0.29902400E+01, 0.30376000E+01, 0.62610700E+01, -.81193000E+01, -.50339000E+01, 0.28438200E+00, 0.16452600E+00, -.30750200E+00, -.14988200E+00, -.30030500E-01, 0.35738100E+00, -.28321600E+00, -.19389100E+00, -.32160400E+00, -.38412100E-01, 0.35240900E+00, -.15396000E+00, 0.69634200E-01, -.32125800E+00, 0.22574600E+00, -.78593200E-01, 0.26767700E+00, 0.24536600E+00, -.52606700E+00, 0.52862200E+00, -.24771600E+00, -.16542000E+00, -.40273000E+00, 0.49411700E+00, 0.91126900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.29068200E+02, 0.30909500E+01, 0.41876600E+01, 0.92543100E+01, 0.75378400E+01, -.71547200E+01, 0.43745900E+01, 0.59746000E+00, -.16296200E+01, 0.77355800E+01, -.31078500E+00, 0.47620500E+01, 0.22733000E+01, -.15970000E+01, 0.14627200E+01, 0.24912400E+01, 0.84015300E+01, 0.44362500E+01, 0.40012900E+01, 0.11952600E+01, -.49538100E+01, -.97369000E+00, 0.75259100E+00, 0.63488300E+01, 0.10706800E+01, 0.21346200E+00, 0.31852200E+00, -.64379200E+01, -.26651500E+01, 0.12606400E+01, 0.27660400E-01, 0.17166800E+01, 0.57621100E+01, -.20815600E+01, 0.14828700E+01, 0.92096900E+00, 0.66458500E-01, -.22094500E+00, 0.14442500E+00, -.51087400E+01, 0.46698100E+00, -.76009600E+00, -.63258100E+00, -.64810900E+00, -.15011900E+01, -.10303700E+01, 0.15059100E+01, -.35287800E+01, 0.45196400E+01, 0.86573200E+00, 0.11440000E+01, 0.25137200E+00, 0.35535200E+00, -.28808300E+01, -.10794100E+00, 0.46124100E+01, 0.89295000E+00, 0.10594300E+01, -.10670000E-02, -.23236300E+01, -.26920800E+01, -.33024900E+01, 0.22972500E+00, -.32217900E+00, -.84047800E+00, -.38079900E+01, -.26383400E+00, -.82933600E+01, -.58929900E+00, 0.20740600E-01, 0.50222900E+00, 0.62733100E+00, -.34439100E+01, -.23158500E+01, 0.22601300E+01, -.95929500E+00, 0.77490500E+00, 0.16146400E+01, 0.12306600E+01, 0.72885000E+00, -.18355000E-01, -.21630000E+01, 0.33112500E+00, -.77246600E-01, -.65500700E+00, 0.76971500E+00, -.17901000E+01, -.11740000E+01, -.34284300E+01, 0.40861100E+00, -.55444800E+01, 0.44470600E+00, 0.70013300E+00, -.55803300E+00, 0.43313000E+00, 0.17987800E+00, -.26356400E+01, 0.22672500E+01, 0.44701200E+00, -.60697500E+00, -.33897700E+00, -.66871000E+00, -.82642300E-01, -.46695100E+00, 0.15353900E-01, -.58827100E+00, -.39410000E+00, 0.35743300E-01, 0.13902300E+00, 0.50970700E+00, -.24871000E+00, 0.57919200E+00, 0.30228900E+01, 0.39169600E-01, -.26073200E+00, -.73452900E-01, -.11004100E+01, -.14537300E+01, -.72858000E+00, 0.11538400E+00, -.53380600E+00, 0.63247000E+00, 0.10759600E+00, 0.11118700E+00, -.68797800E-01, 0.43086800E+00, -.64942400E+00, 0.16525100E+00, -.94705100E-01, 0.13091300E+00, -.57526100E-01, 0.81812200E+00, -.12623300E+01, -.10659300E+01, 0.13385200E+00, -.89548600E-02, -.77761000E+00, -.71326100E-01, -.17795500E+01, -.49638400E+00, 0.71939500E+00, 0.30544900E+00, -.31512200E+00, -.15709000E+01, 0.17129000E-02, -.19514400E+01, 0.14182200E+00, -.21250200E+00, 0.85593800E+00, -.16438000E+01, -.56372600E+00, 0.96557600E-01, -.36308300E+00, -.42498800E+00, 0.94093100E+00, 0.12066100E+00, -.11908200E+00, -.25762300E+00, -.53905200E+00, -.83999800E+00, -.39152300E+00, -.13512200E+00, 0.46504000E+00, 0.28575800E-01, 0.98799900E+00, -.10148800E+01, 0.18981300E+00, -.34095800E+00, -.12862400E+01, 0.15311500E+01, -.20091500E+00, -.23052500E+00, -.24669700E-01, 0.61007200E+00, -.29751300E+00, -.18058000E+01, -.27898500E+00, 0.10780400E+00, 0.24957600E+00, 0.55509700E-01, -.11617400E+01, 0.92966300E+00, -.29788600E-01, 0.59121700E+00, -.29910900E+00, -.46824500E+00, -.49855200E+00, 0.29901600E+00, -.57672300E-01, 0.95213800E+00, 0.13686100E+00, -.79622000E+00, 0.34485600E+00, 0.10407900E+00, -.21660000E+00, 0.21043800E+01, 0.11483100E+01, -.30395200E+00, -.57154800E-01, 0.38228300E+00, -.53714100E+00, 0.20023000E-02, -.11710200E+00, -.12333800E+01, 0.52375400E+00, -.15400300E+00, 0.44825100E+00, 0.61776500E+00, -.18184400E+00, 0.47746500E+00, 0.83983200E-01, -.97226700E-01, -.47614100E-01, 0.14404000E+00, -.47072900E+00, -.23770500E+01, -.24651300E-01, -.15809800E+01, -.98663900E+00, 0.13250500E+01, -.10869600E+01, 0.57840000E+00, -.10637300E+01, 0.79048300E+00, -.17071900E-01, -.44249900E+00, 0.32144300E-01, -.55170800E+00, 0.89280400E+00, 0.28517500E+00, -.35226200E+00, -.77175000E-01, -.36368000E+00, 0.49136300E+00, 0.16510800E+00, -.34601400E+00, -.11700400E+01, 0.19147400E+00, -.18396500E+00, 0.28152600E+00, 0.13263100E+01, 0.29478600E+00, 0.22767100E+01, -.30822700E+00, -.12330300E+01, 0.42264900E+01, -.32356100E+00, 0.16649200E+01, 0.15125500E+01, -.17095000E+01, -.13889200E+01, 0.13688300E+00, 0.12469500E+03, 0.22045400E+03, -.10998700E+03, -.88160800E+02, -.10980800E+03, -.57399200E+02, 0.68321800E+02, -.73433500E+02, 0.24290200E+02, -.11074200E+03, 0.81179200E+02, -.10273500E+03, -.39059000E+01, 0.17147700E+01, -.13335800E+02, 0.23078500E+01, 0.56416200E+01, 0.13567300E+01, -.11576300E+01, 0.53263500E+01, -.57435700E+01, -.32328200E+01, -.13591000E+01, 0.42830900E+01, 0.27307900E+01, -.60965300E+01, 0.27086400E+01, 0.18442400E+01, 0.69080200E+01, -.84132900E+00, 0.12566400E+00, 0.28885600E+00, -.17159100E+01, 0.14170800E+01, 0.26522800E+01, -.25609000E+01, -.41556600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.40640900E+01, -.19899900E+00, 0.19761800E+01, -.13601800E+01, -.83277700E+00, 0.12073000E+01, -.28494500E+00, -.75104900E-01, 0.47957900E+00, -.63930600E+00, -.21045800E+00, 0.14284100E+00, -.17084400E+00, 0.89606900E+00, -.92301600E+00, -.17929800E-01, -.96432500E-01, 0.51613300E-01, -.34695000E+00, 0.40355700E+00, 0.49537000E+00, 0.14677000E+00, 0.82802900E-01, -.68551800E-01, -.59134400E-01, -.50052900E+00, 0.20988400E+00, 0.47743800E+00, 0.69743000E-01, -.26967800E+00, 0.21730900E-01, -.77512100E-01, -.64214100E-02, -.38661900E+00, 0.12734200E+00, -.47960800E+00, -.31771000E-01, -.12835200E+00, -.30725400E+00, 0.22741300E+00, -.26598500E+00, 0.14010000E+00, 0.88912500E+00, -.11441900E+00, 0.21587400E+00, 0.83192000E-01, -.25839500E+00, 0.80188600E+00, -.39589600E+00, -.29343000E-01, -.26233600E+00, 0.29434600E+00, 0.38872700E+00, 0.91109200E-01, -.33717900E+00, -.34617600E+00, 0.90911100E-02, -.82993100E-01, -.62223000E-02, 0.11193000E+01, 0.26342600E+00, 0.48111600E+00, -.11379000E+00, 0.15780100E-01, 0.16268500E+00, -.59217400E+00, 0.23860300E+00, 0.12873100E+01, 0.13733600E-01, -.43489900E-03, -.15302000E+00, -.53802900E-01, 0.76784800E+00, 0.19793200E+00, -.68332200E+00, 0.41187000E+00, -.72457000E-01, -.82770000E+00, -.10415100E-01, -.24049100E+00, -.12554200E-01, -.13920200E+01, 0.40622100E-01, 0.15933600E+00, 0.11306700E+00, -.10183100E+00, 0.38096500E+00, 0.82707700E-01, 0.46897700E+00, -.11306400E+00, 0.37696300E+00, 0.81434400E-02, 0.38795700E+00, 0.95186200E-01, 0.15557400E+00, -.53877500E-01, -.13600400E+00, -.25633800E+00, -.14759900E+00, -.24215300E+00, -.14775600E-01, -.70748000E-01, 0.49695900E-02, 0.12087500E+00, -.51749900E-01, -.12271500E+00, 0.17484100E+00, 0.20018900E+00, 0.66588800E-01, 0.11335500E+00, 0.10162100E+00, -.15404400E-01, 0.25123400E+00, -.63842900E-03, -.26002300E+00, 0.12083600E-01, 0.11486500E+00, -.23305900E+00, -.61812100E+00, 0.45575600E+00, 0.49497800E-01, 0.42398400E+00, -.61368400E-01, 0.40049900E-01, 0.19821400E-01, -.13760100E+00, 0.28231000E-01, 0.35075600E-01, 0.87915300E-02, -.11657600E+00, 0.35216200E+00, -.11784800E+00, -.19110100E+00, -.68847900E+00, 0.63043600E-01, -.29405400E-01, 0.33257000E+00, 0.76544200E-02, 0.50834200E+00, -.13656800E-03, -.21226400E+00, 0.23274200E+00, 0.29849600E+00, -.61952700E+00, 0.50486000E-01, -.48060700E+00, -.37341400E-01, 0.30366400E-01, -.11306900E+00, 0.54422800E-01, 0.10904100E+00, -.31706200E-01, -.15222400E-01, 0.30744300E-01, -.30689200E+00, 0.44511800E-01, -.55811200E-01, 0.82637900E-02, 0.24899800E-01, -.30802900E+00, 0.84235900E-01, -.22633300E-01, 0.25323000E+00, 0.42471900E+00, -.24350100E+00, -.26635100E-01, 0.20584600E-01, -.51310700E-02, -.12938200E+00, -.20916400E+00, -.16178000E-01, -.35959900E+00, -.25269700E-01, 0.19082700E+00, 0.46193000E-01, -.82379800E-01, 0.25590100E-02, 0.12451800E-01, -.54026100E-01, -.49708700E-01, -.20093800E+00, 0.22574900E+00, 0.25382100E+00, -.94378200E-02, 0.15903700E+00, 0.50851900E-01, -.42771900E-02, 0.51296100E-02, -.79644600E-01, -.10911400E+00, -.10111200E-01, -.34522800E-01, -.44646200E+00, -.11182900E+00, 0.85933300E-01, -.17744300E+01, -.11647500E+01, -.15888900E+00, 0.45539200E-01, -.39006900E-01, 0.17811400E+00, -.29684600E-02, -.12728700E-01, -.82281900E-01, 0.97565700E-01, 0.10575600E+00, -.28095500E-01, 0.24429700E-01, -.37857500E-01, 0.11908200E-01, -.19804700E-01, 0.41985000E-01, -.58600800E-02, -.64538200E-01, -.79215700E-01, 0.10563900E+01, 0.36218500E-02, 0.30116000E+00, 0.17873700E+00, 0.32928000E+00, -.54416200E-01, 0.41782800E-01, 0.68472900E-01, 0.67850600E-01, 0.47313000E-01, -.37135500E-02, -.35351500E-01, 0.20362600E+00, -.45503100E-02, -.60800000E-01, 0.16328700E+00, 0.87608100E-01, -.82914400E-01, 0.10213300E+00, -.10383100E+00, 0.19773400E+00, -.29936200E-01, -.24067600E-01, 0.26110400E-01, 0.11528600E+00, 0.18303600E+00, -.10110000E-01, -.88053500E+00, 0.26647600E-01, 0.13478000E+00, 0.13394500E+00, -.72000000E-01, -.44886400E+00, -.71123600E-01, 0.95971200E-01, 0.18635600E+00, -.50415800E-01, 0.19034200E-01, -.40811800E+02, 0.20013500E+02, 0.13408200E+02, 0.20413400E+02, 0.20308700E+02, -.12663500E+02, 0.15844100E+02, 0.74838400E+00, 0.18624600E+02, -.13669600E+02, 0.18524400E+02, 0.98942800E+00, -.34609500E-01, -.13984900E+01, -.45142300E+00, 0.51749700E+01, -.56924000E-01, -.21947300E+00, 0.48151600E+01, 0.75887300E+00, -.29817900E+00, 0.33294200E+00, -.22031100E+00, 0.15025900E+00, 0.62772200E+00, -.32689900E+00, -.42459900E+00, 0.62888100E-01, 0.87370100E+00, -.27189800E+00, 0.64132100E+00, 0.19939100E-01, -.26532600E+00, 0.22119800E+01, 0.52795100E+00, 0.14358000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15536500E+02, -.47846200E+00, 0.61829800E+01, 0.22377300E+01, -.56651100E+01, 0.50929600E+00, 0.46729400E+00, -.10938400E+01, 0.40619100E+00, -.22827800E+01, 0.21995700E+00, -.43897200E+00, -.65646400E+00, -.41295300E+01, -.35454300E+00, -.45011600E+00, -.59748900E+01, -.53332400E+01, -.31138400E+00, -.21575900E+01, 0.36934500E+01, 0.19212300E+00, -.42504600E+00, -.48559200E+01, -.33792800E+00, 0.51458900E+00, 0.49222200E+00, 0.71665300E+01, -.13259500E+00, 0.53051800E+00, 0.15006700E+00, -.87678800E+00, -.46026000E+01, 0.12454800E+01, -.57553700E+00, -.11433700E+01, 0.45887600E-01, -.64265600E+00, -.76259400E+00, 0.40635900E+01, -.17545600E+01, 0.49977500E+00, 0.21969700E+01, 0.80300800E-01, 0.28891300E+01, 0.72597300E+00, -.16806400E+01, 0.15700100E+01, -.16652400E+01, -.40087200E+00, -.10430600E+00, -.35448400E+00, -.26659300E+00, 0.12782900E+01, 0.30501100E+00, -.16706200E+01, -.43115900E+00, -.66349400E+00, 0.93239200E-03, -.64844900E+00, 0.35430800E+00, 0.13192900E+01, -.42836800E+00, -.12152700E+01, -.10561200E+01, 0.16463900E+01, -.41649200E+00, 0.21123000E+01, 0.48177400E+00, -.16438000E-02, -.41785800E+00, 0.76426000E-01, 0.22132400E+00, 0.21504200E+01, -.22991500E+01, -.26347500E+00, -.17010700E+00, -.13891600E+01, -.31057600E-01, 0.55653800E-01, -.46569600E-01, 0.92817500E+00, 0.76890200E+00, 0.54726000E+00, 0.22160700E+00, -.74513300E+00, -.39764400E-01, -.24600800E+00, 0.92167500E+00, 0.41497700E+00, 0.35242200E+01, 0.49764000E-01, 0.15969300E+01, -.26511800E+00, -.23773100E+00, 0.43159100E+00, 0.70611100E+00, -.39331100E+00, -.83189200E+00, -.40455800E+00, 0.80751900E+00, -.65056700E+00, 0.73172200E-01, 0.13485100E+00, 0.79020500E+00, -.23110100E+00, -.23634700E+01, 0.64855900E+00, 0.87669300E+00, 0.21325000E+00, 0.12690100E+01, 0.32190600E+00, 0.99994300E+00, 0.65935200E-01, -.91552000E+00, 0.22139300E+00, -.40169100E+00, -.37854800E+00, 0.18473000E+01, -.31912900E+00, 0.52275900E+00, 0.77054800E+00, -.15613500E+00, 0.18884700E+00, -.77560400E-01, -.65946500E+00, -.50799100E+00, 0.37260800E-01, 0.91210100E-01, -.30364900E+00, -.84897100E+00, 0.12121400E+01, 0.40394100E+00, -.33333300E+00, -.64136300E-01, -.67160700E-01, 0.12987200E+01, 0.96857100E-02, 0.86286400E+00, -.91052900E-01, -.78169900E-01, -.26566600E+00, 0.56005800E+00, 0.26166500E+00, -.45364800E-01, 0.50722800E-01, 0.25306700E-01, -.23014600E-01, 0.26891000E+00, -.62516100E+00, -.36247900E+00, -.10215400E+00, -.48132600E-03, -.10853700E+00, 0.12664800E+01, 0.28874000E-02, -.55451400E-01, 0.48253100E-01, 0.68282500E-01, -.47504800E+00, 0.11213800E+00, -.37010400E-01, -.97909900E-01, 0.11569100E+01, -.11519700E+01, 0.21067800E+00, -.45467200E+00, 0.98870500E-01, -.67801800E-01, -.22853600E-01, -.10014100E+00, 0.77227200E-01, 0.11288600E+00, 0.74673700E+00, -.13856600E+00, 0.42996900E+00, -.51034300E+00, 0.22179500E+00, -.41378800E+00, -.16649900E+00, -.10777100E+00, 0.16299500E+01, 0.12553000E+01, -.81809100E+00, 0.13206900E+00, -.31714400E+00, 0.15198200E+00, 0.56211800E+00, 0.51222900E-01, -.90806500E+00, -.20183400E+00, 0.77900100E-01, -.17041900E+01, -.37189700E+00, 0.24000300E+00, 0.33083200E+01, 0.21302300E+01, 0.57780400E+00, -.58381500E+00, -.34614500E+00, -.10826400E+00, 0.56982800E-02, -.27653200E+00, 0.29219900E+00, -.37630500E+00, -.85823700E-01, 0.22952400E+00, -.26797500E+00, 0.14366500E+00, -.24552000E+00, -.11949600E+00, -.37003100E-01, 0.39841000E-01, -.43916100E-01, -.11196300E+00, 0.57406900E+00, -.15434300E+00, -.66714200E+00, -.21492800E+00, -.40958200E+00, 0.14893300E+00, -.27264400E+00, 0.52312800E+00, -.30988000E+00, 0.27980600E+00, 0.59004100E-01, 0.82974500E-01, -.45701400E-01, -.27953600E+00, -.85513800E+00, -.32373700E+00, -.28733500E+00, 0.16340400E+00, -.19538200E+00, -.36185100E-01, -.39043200E+00, 0.22596800E+00, -.61613100E-01, 0.24676400E+00, -.17584700E+00, -.27391700E+00, -.25760900E+00, -.37729700E-03, 0.19461200E+00, 0.17249900E+00, -.16583500E+01, 0.14046000E+00, -.43073500E+00, -.14730200E+00, 0.56169400E+00, 0.19097100E+00, -.19140200E+00, -.25329000E+00, 0.30930600E+00, 0.15546600E+02, -.35318000E+01, 0.31289400E-01, -.29508500E+01, 0.45949500E+01, -.18388100E+02, -.35482700E-01, -.88452100E+00, 0.27308000E+01, -.23172900E+02, -.32802100E+00, 0.73964900E+00, -.18964500E+01, -.48163700E-01, -.18853300E+01, 0.61179100E+00, 0.29717600E-01, -.17361700E+01, -.82263300E+00, -.64163000E+00, -.35126200E+00, 0.20951600E+00, -.78563200E+00, -.82027100E+00, 0.35337300E+00, -.39139300E-01, 0.13335500E+01, -.77724800E+00, -.63919500E+00, -.21120900E+00, -.19080500E+00, -.43983500E+00, -.78490000E+00, -.41020900E+00, -.18071800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54538800E+02, -.47679800E+01, 0.66906400E+01, -.36789700E+01, -.12344700E+02, 0.92643900E+01, -.41747200E+01, -.19131200E+01, 0.36435900E+01, -.73304300E+01, 0.32135500E+01, -.10837000E+02, -.79946900E+01, 0.16524900E+02, -.14096600E+01, -.66027500E+01, -.14612900E+02, 0.34278600E+01, 0.39667300E+01, -.19070500E+01, 0.11331600E+00, 0.23172600E+01, -.26076000E+01, -.37437700E+01, -.20397900E+01, -.20172900E+01, -.11114200E+02, 0.10831600E+02, 0.64596100E+01, -.37327500E+01, 0.12522300E+01, -.36963900E+01, -.10454700E+02, -.12465100E+01, -.10765000E+01, -.61310300E+01, -.16337500E+00, 0.11150500E+01, -.14726300E+01, -.10956600E+02, 0.94171200E+00, -.37179200E+00, -.21095900E+02, 0.17754300E+01, -.71094600E+01, -.19227700E+01, -.14101600E+01, 0.23561000E+01, -.29236100E+01, -.29549800E+00, 0.56813900E+01, 0.21697900E+01, -.14851400E+01, -.11426600E+02, -.11236100E+01, -.46291300E+01, -.13117400E+01, 0.58195300E+01, -.53397400E+00, -.21056600E+01, 0.13504900E+02, 0.50780200E+01, -.11621000E+01, 0.74029900E+01, 0.74973600E+01, -.27764800E+01, 0.33130200E+01, 0.12137600E+02, -.86664100E+00, 0.33084700E+00, -.27173200E+01, -.43278800E+00, 0.17986700E+01, -.75603600E+01, -.46601800E-01, 0.99782400E+01, 0.19822200E+00, -.76685600E+01, -.10374500E+00, -.96649500E+00, -.53536700E+00, 0.32295500E+01, -.18904100E+01, -.34154400E+01, 0.13122800E+01, 0.96714300E+00, 0.26945300E+01, 0.38802200E+01, 0.53573400E+01, -.32523800E+01, -.72012300E+01, 0.17365500E+00, -.36705500E+01, 0.16251400E+01, 0.95056400E+01, -.16940800E+01, -.66055600E+01, 0.69441600E+00, 0.44596500E+00, 0.20398900E+01, -.30762700E+01, -.46368400E+00, 0.38546800E+00, 0.11062700E+01, -.16446700E+01, -.22480200E+01, 0.40795700E+01, 0.60597000E+00, 0.11666800E+01, -.52621000E+01, 0.11761700E+00, -.45357000E-01, -.25137800E+01, -.26556700E+00, -.60983900E+00, -.59043000E+00, 0.12170700E+01, -.17465100E+01, -.32481400E+01, 0.10131800E+00, -.81092300E+00, -.15138700E+01, -.43178400E+00, -.58860300E+00, 0.57949200E+00, -.21372200E+01, 0.14152600E+01, -.79376200E+00, -.11704900E+00, 0.10022200E+01, -.46491400E+00, -.22383800E+01, 0.38374900E+00, -.46988700E+01, 0.15702100E+00, 0.48512100E-01, 0.12194600E+01, 0.12884900E+00, 0.19807500E+01, -.81981500E+00, -.11930600E+01, 0.10007900E+01, -.95405300E+00, -.25591500E+01, -.34161900E+00, -.21535600E+01, -.52205500E+00, -.57343000E+00, 0.50242500E+01, 0.15244600E+01, -.21766700E+01, 0.41803500E+00, 0.19088800E+01, 0.36573000E-01, -.51048200E+01, -.28177500E+00, -.10307100E+01, 0.23818600E+00, 0.88394600E+00, 0.11546400E+01, 0.27802900E+01, 0.45017700E+00, -.81043200E+00, -.12055000E+01, 0.12730400E+01, -.17680200E+01, 0.10600600E+00, 0.10274500E+01, 0.72888200E+01, 0.20392400E+00, 0.12809600E+01, 0.48306100E+00, 0.11274800E+01, -.56231900E+01, 0.14684900E+01, 0.94551800E+01, 0.32718500E-01, -.14542600E+01, -.19569200E+01, -.48468500E+00, 0.77127100E+01, -.69490300E+01, -.61001700E+01, 0.41499300E+00, 0.12756300E+01, 0.54606300E+00, 0.13475300E+01, -.12071500E+01, -.75010200E-01, -.76744400E+01, -.16519800E+00, 0.11228000E+01, 0.76679400E+00, 0.25852700E+01, 0.96204900E+00, -.57659500E+01, -.32836600E+01, -.19374100E-01, -.37088500E+00, -.18321800E+00, 0.16701800E+01, -.13919900E-01, 0.85544000E+00, 0.11898700E+01, -.72067700E+00, -.32473500E+00, -.46017200E+00, -.13514200E+00, 0.10512100E+01, 0.30150800E+00, -.29687800E+00, 0.34121400E+00, -.18865700E-01, 0.57860000E+00, -.32463700E+00, -.60197800E+00, 0.19745600E-01, 0.13906300E+01, 0.15394900E+00, 0.15798000E+01, 0.59512900E+00, 0.36085000E+00, 0.41541100E+00, -.90287800E+00, 0.12293700E+01, -.28584000E+00, -.22184300E+01, 0.12896600E+01, 0.13268900E+01, 0.41671600E+00, 0.42405000E+00, -.69521100E+00, 0.12062900E+01, 0.23654100E+01, -.87971300E-01, 0.10277200E+01, 0.31801500E+00, -.53718300E+00, -.18476600E+01, -.19980500E+00, 0.14293800E+01, 0.31174500E+00, -.54773300E+01, 0.95764200E+00, 0.22761400E+01, -.42157700E+01, 0.12352400E+01, -.53146600E+01, 0.58888200E+00, -.42746400E+01, 0.22533900E+01, 0.25090300E+01, -.55099500E+00, 0.13869000E+02, 0.50508800E+00, 0.15562100E+03, -.12852300E+01, -.27270300E+03, 0.28166100E+02, 0.26030400E+02, -.43251000E+02, 0.43511100E+02, 0.65902900E+02, -.28792900E+03, -.18911800E+02, -.37901900E+01, 0.90230100E+02, 0.24644200E+01, -.99840800E+02, -.62711300E+01, 0.73886900E+01, -.88853200E+02, 0.14626200E+01, 0.26521800E+02, -.20177200E+02, -.17214200E+01, -.73557700E+01, 0.57871800E+01, 0.33577300E+00, 0.54075200E+01, -.23913900E+02, -.27515900E+02, 0.94885100E+01, -.17385900E+02, 0.69073300E+01, 0.82201100E+01, -.27490200E+02, -.22709600E+02, -.30837300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15613400E+02, -.14479700E+01, -.32132400E+01, 0.71664500E+00, 0.15431000E+01, 0.72196000E+00, -.18132400E+01, -.33571700E+00, 0.25483000E+00, -.34151200E+01, -.58142000E+00, -.16154800E+01, -.12145000E+01, -.41146300E+01, -.12860500E+01, -.98141300E+00, -.71075700E+01, -.73975500E+01, -.25852400E-01, -.37366100E+01, 0.35545700E+01, 0.10792600E+00, -.10514800E+01, -.70018100E+01, -.63711800E+00, -.41927400E+00, 0.24086400E+01, 0.58457800E+01, -.80164400E+00, 0.88146000E+00, 0.73550500E-01, -.24955800E+01, -.32723100E+01, -.13145000E+00, -.55657400E+00, -.58627700E-01, -.81206800E-03, -.12012000E+00, -.10916900E+01, 0.52542700E+01, -.13514800E+01, 0.33268800E+00, -.21113300E+00, 0.48022900E+00, 0.32797000E+01, 0.83406600E+00, -.15269200E+01, 0.16787100E+01, -.19313600E+01, -.48092800E+00, -.21131300E+00, -.35891500E+00, -.32082300E+00, 0.64532700E+00, -.73764100E+00, -.16210100E+01, -.53718300E+00, -.56059900E+00, 0.17711700E-02, 0.14864500E+01, 0.29465500E+00, 0.18070200E+01, -.50156600E+00, -.13202000E+01, -.11142000E+01, 0.17663400E+01, -.17883600E+00, 0.20007900E+01, 0.54682100E+00, -.95353600E-02, -.78290500E+00, -.25920600E+00, -.36085200E-01, 0.20615400E+01, -.21752200E+01, 0.59217100E+00, -.31149300E+00, -.17079700E+01, -.38644500E+00, 0.11911000E+00, -.18482400E-01, 0.65786700E+00, 0.68244900E+00, 0.72571900E+00, 0.44043400E+00, -.83818400E+00, 0.88256900E+00, 0.16687100E+00, 0.47344900E+00, 0.43984400E+00, 0.39470800E+01, 0.56357700E-01, 0.17321600E+01, -.19606200E-01, -.10974100E+00, 0.62549600E+00, 0.32912100E+00, -.40111900E+00, -.10419500E+01, -.38190400E+00, 0.11427200E+01, -.10394600E+00, 0.10594900E+00, -.26016600E-01, 0.65892400E+00, 0.84915900E-01, -.15922100E+01, 0.48044100E+00, 0.17360700E-01, 0.18061200E+01, 0.11827800E+01, 0.15243900E+00, -.31281500E+00, 0.32821700E-01, -.28278800E+00, 0.31173400E+00, -.91548100E-01, 0.20199100E+00, 0.16088200E+01, -.82456100E+00, 0.53265300E+00, 0.47979700E+00, 0.57760400E-01, 0.24014900E+00, -.89048800E-01, -.79543800E+00, -.12819200E+00, 0.44458400E-01, -.29397600E-01, -.35506200E+00, -.21617200E+01, 0.17882500E+01, 0.10289100E+01, 0.32050700E+00, 0.99502300E-01, -.32135200E-01, 0.12235800E+01, 0.50455300E+00, -.11620900E+00, 0.53224700E+00, -.24953400E+00, -.47271700E+00, 0.48104800E+00, 0.17467500E+01, -.30891200E-01, 0.14825300E+00, 0.92019700E-01, -.45098300E-01, -.13933600E+00, -.28148600E+00, 0.39497100E+00, -.59975200E-01, -.12966700E+00, 0.35560200E-01, 0.14889200E+01, -.13052600E+00, 0.11436400E+00, -.14151800E+00, 0.82607000E-01, -.26398600E+00, -.30757300E+00, -.58271900E-01, 0.16873900E-01, 0.10555700E+01, -.11109600E+01, 0.53335600E+00, -.15379400E+00, 0.29371500E-01, -.12053500E+00, -.37105600E+00, -.33176400E-01, -.14868300E+00, 0.10712500E+00, 0.73905300E+00, -.15693800E+00, -.20251700E+00, -.75697100E+00, 0.87821000E-01, -.58694200E+00, -.39327300E-01, -.16833400E+01, 0.11451600E+01, 0.11082800E+01, -.87271500E+00, 0.33304000E+00, -.72101900E-01, 0.21950900E+00, 0.65211500E+00, -.18168000E+00, -.49512400E+00, -.70095900E-01, 0.12711200E+00, -.14235500E+01, -.25455600E+00, 0.13932700E+00, 0.14615300E+01, 0.15517900E+01, 0.42921500E+00, -.80777300E+00, 0.50134200E-01, -.28131100E+00, -.27274700E-02, -.27763800E+00, -.93678300E+00, -.43680600E+00, 0.37732000E-01, 0.35388900E+00, -.13608200E+00, 0.13620200E+00, -.17105900E+00, 0.32508000E-01, -.25261000E-01, -.97935100E-02, -.13349100E+00, -.11404000E+00, 0.48658000E+00, -.19002200E+00, -.70385700E+00, -.23390200E+00, -.60871800E-01, 0.45543300E+00, -.99606000E-01, 0.74388500E+00, 0.80356200E-01, 0.27603100E+00, 0.13687600E+00, 0.19383400E+00, 0.31842700E+00, -.34068000E+00, -.68124600E+00, -.19830400E+00, -.28369800E+00, 0.20711900E+00, -.77442300E+00, -.16776900E+00, -.12230500E+00, 0.37404400E+00, -.12914800E+00, 0.20363600E+00, -.13593800E+00, -.14471500E+00, -.34556100E+00, 0.38173800E+00, 0.19695800E+00, 0.27908300E+00, -.16410100E+01, 0.14053100E+00, -.38823500E+00, -.95679400E-01, 0.32782400E+00, 0.23782400E+00, -.16682400E+00, -.21034700E+00, 0.94188500E+00, 0.80191100E-02, -.28407500E-01, 0.33001200E+01, -.26137200E+02, 0.10636000E+02, -.20053400E+02, -.87286300E+01, -.16190900E+01, 0.12728900E+02, -.20507800E+02, -.14991600E+01, 0.21947200E+00, 0.27019100E+01, 0.44256000E+00, -.83116100E+01, -.71789200E-01, 0.85974200E+00, -.74244400E+01, 0.17738200E+01, 0.58160400E+00, -.14144000E+01, -.23047900E+00, -.11168000E+01, 0.20346900E+01, 0.11858400E+00, 0.46954800E+00, -.58587200E+00, -.21694500E+01, 0.34153400E+00, -.16116100E+01, 0.32103600E+00, 0.32362400E+00, -.24778500E+01, -.17040800E+01, -.22513700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.93879100E+01, -.10020900E+01, 0.17962000E+00, -.53669900E+01, -.42467400E+01, 0.41559800E+01, -.77650400E+00, 0.23574000E+00, 0.21743900E+01, -.13513800E+01, 0.76024500E-01, 0.19537700E+00, 0.11561500E+01, 0.38201300E+01, 0.12267500E+00, -.10496400E+01, 0.36350500E+00, 0.36171000E+01, -.23231300E+01, 0.66682200E+00, 0.10460600E+01, 0.37435900E+00, -.63084300E+00, -.24416200E+01, -.20376100E+00, -.14872800E+00, -.53421100E+00, -.16157300E+01, 0.19813800E+01, -.88070200E+00, -.10773900E+00, -.65119000E-02, -.27004400E+00, 0.45197600E+00, -.12508900E+00, -.28767400E+00, -.34701000E-02, 0.98371100E-01, 0.51262700E+00, -.22211800E+01, 0.10407800E+00, -.46940100E+00, 0.10198300E+01, 0.12016800E+00, -.25098900E+00, 0.19115200E+00, -.29215300E+00, 0.98322900E+00, -.10581100E+01, -.10711300E+00, 0.73534400E-01, -.79557300E+00, -.14124300E+00, 0.15846400E+01, 0.64364600E+00, -.30087900E+01, -.20793100E+00, 0.15000200E+00, 0.20599500E-02, -.10637600E+01, 0.16552400E+01, 0.17617800E+00, -.20357100E+00, 0.74108400E+00, 0.47327100E+00, 0.85885200E+00, 0.35644300E-01, 0.64751000E+01, 0.89813600E-01, -.18772100E-01, 0.50013800E+00, -.50976000E+00, 0.40195000E+00, 0.14168900E+01, -.17715000E+01, -.85491700E-01, -.27491100E+00, 0.30016600E+00, -.64174200E+00, -.25002200E+00, 0.23771700E-01, 0.94031600E+00, -.11686500E+01, 0.57073600E-01, 0.18080100E+00, -.22440800E+00, 0.19839400E+00, -.10178900E+00, 0.12828000E+01, -.32625200E-01, 0.30663000E+01, -.29486600E-01, -.11359600E+00, 0.13080400E+00, -.18698800E+01, -.29977100E+00, 0.38348800E+01, -.20845600E+01, 0.35488900E+00, -.61399300E+00, 0.13869000E+01, 0.95447000E+00, 0.86196800E-01, 0.57843700E+00, -.16216900E+00, 0.83701700E+00, 0.15360700E+01, 0.35064100E-01, -.82877100E+00, 0.49641900E+00, -.11569000E+01, -.21462300E+00, -.16166200E+00, -.70117800E-01, 0.23559700E+00, -.15964700E+00, 0.20833100E+00, 0.60881300E+00, -.19839100E+01, 0.72630600E+00, 0.73984700E-02, -.29815600E+00, -.99334800E-01, -.46311300E+00, 0.12507000E+00, 0.60643200E+00, -.70414900E+00, 0.21876700E+00, 0.87552900E-01, 0.12792500E+00, 0.92378200E+00, -.10249300E+01, -.86363900E+00, -.77533600E+00, -.25336300E-01, 0.19047300E-01, 0.14054300E-01, -.15987900E+00, 0.73363300E+00, -.24274000E+00, 0.20286000E+00, 0.31871500E+00, 0.10648100E+00, -.11106600E+01, 0.78548600E-01, -.89224300E+00, -.10418400E+00, 0.12194300E+00, 0.62102000E-01, 0.60551300E+00, 0.40504800E+00, 0.92962700E-01, 0.22416000E+00, 0.75344100E-01, -.80125800E+00, 0.58217300E-01, -.12594100E-01, 0.22332900E+00, 0.11541100E+00, 0.23428300E+00, 0.44083300E+00, 0.11748800E+00, -.31977800E+00, 0.45474200E+00, 0.81774900E+00, -.14158000E+00, 0.11806900E+00, -.10709100E+00, -.63083500E+00, -.70378900E-01, -.34120400E+00, -.14545400E+00, -.15241000E-01, 0.28444100E-02, -.70948700E-01, -.94373100E+00, 0.29313000E-01, -.27304700E-01, 0.15893700E+00, -.14981700E+00, 0.31020000E+00, 0.29203000E+00, -.63871900E+00, -.46899800E-01, 0.22894200E+00, -.23640900E+00, -.65191800E-01, -.17191500E+00, 0.14062700E+00, 0.13800300E+01, -.10883100E+00, -.32513900E+00, 0.51707400E+00, -.67700800E+00, 0.13397900E-01, 0.57284700E+00, -.27839500E+01, -.32609900E+00, 0.71842900E+00, -.12884600E+00, 0.25719500E+00, 0.10947800E-01, -.55836300E-01, 0.28477100E+01, 0.18207900E-01, -.47329200E-01, -.14061300E+00, -.36683800E+00, -.66927500E-01, -.21125900E+00, 0.23527400E-01, -.16410000E+00, 0.30275500E-01, 0.34521500E+00, 0.69027900E+00, -.27352700E+00, -.44017200E+00, 0.29692900E+00, 0.59165800E+00, -.27385800E+00, 0.10227300E+00, 0.34356900E+00, -.63454700E+00, -.28353400E+00, -.10508400E+00, 0.19990000E+00, 0.39228300E+00, 0.41880100E+00, -.15580400E+00, -.20253300E+00, -.12116500E+00, 0.31431100E+00, 0.15106200E+00, 0.10449700E+00, 0.32664900E-01, 0.82195400E+00, 0.24171800E+00, 0.17445500E+00, -.10885300E+00, 0.15018400E+00, 0.30656500E+00, 0.27482300E+00, -.68517800E+00, -.21591900E+00, 0.23784300E+00, 0.11475500E+01, -.29325800E+00, -.10406000E+00, -.28653700E+00, 0.32473100E+00, 0.12166200E+00, -.20301600E+00, 0.49029800E-01, 0.15952000E+01, -.68392200E-02, -.15297200E+00, -.62575600E-01, -.56138900E+02, 0.34835600E+02, 0.12199600E+02, 0.11581500E+02, -.10831200E+02, 0.42663800E+02, -.82745200E+01, -.25428500E+01, -.71029200E+00, 0.17822100E+01, 0.89857800E+00, -.22538500E+02, -.17327200E+00, 0.36168100E-01, -.20322600E+02, 0.43067700E+00, 0.18568600E+01, -.15692400E+01, 0.39016700E+00, -.97423600E+00, 0.10648300E+01, 0.12826200E+01, 0.10223000E+01, -.78506000E+00, -.31261700E+01, 0.11274500E+01, -.15516800E+01, -.54827300E-01, 0.64264300E+00, -.75964500E+01, -.18648000E+01, -.63390600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17649000E+02, -.24421800E+01, -.93634900E+01, -.63190700E+01, -.74959200E+01, 0.18188400E+01, 0.97873600E+00, -.57446200E+00, 0.68542100E+00, -.41345700E+01, 0.86542100E+00, -.69011800E+01, -.48937000E+01, 0.12380200E+01, -.91479900E+00, -.11213200E+01, -.39613800E+01, -.22427400E+01, -.13855900E+01, -.10589200E+01, 0.32780300E+01, 0.65375200E+00, -.29121400E+00, -.22215700E+01, -.87219900E+00, 0.60593000E+00, -.11769800E+01, 0.43275700E+01, 0.24049900E+01, -.30705000E+00, -.39664000E-01, -.76464100E+00, -.33027100E+01, 0.12987000E+01, -.80269700E+00, 0.12108700E+01, -.57014800E-01, 0.37176900E+00, 0.12222600E+01, -.10060600E+00, 0.71810700E+00, -.12528100E+01, -.20804400E+01, 0.58446000E+00, -.15493300E+01, -.21730700E+00, 0.57483700E+00, -.12754600E+00, -.15193400E+01, -.36683700E+00, 0.15854900E+01, 0.26957000E+00, -.88316500E+00, -.61579600E+00, -.10425700E+01, -.89963200E+00, -.12232700E+00, 0.70313100E+00, -.77086000E-02, 0.10857600E+01, 0.47926300E+00, 0.15723700E+01, 0.22673900E+00, 0.11250700E+01, 0.14976200E+01, 0.15393900E+01, 0.28263000E+00, 0.35709300E+00, -.16951500E+00, 0.63659500E-02, -.75447800E-01, 0.69623200E+00, 0.19702500E+01, -.16621200E+01, -.10227600E+00, 0.28167800E+01, 0.32598300E+00, -.16284900E+01, -.63453300E+00, -.87157800E-01, 0.86712000E-02, -.18631700E-01, 0.25072100E+00, -.51140600E+00, 0.19202000E+00, 0.14116400E+00, 0.95132500E+00, 0.80027100E+00, 0.77924500E+00, -.68478300E+00, -.76460000E-01, -.33381800E-01, -.14696200E+01, 0.59531100E+00, 0.17718500E+01, -.15047700E+00, -.11922500E+01, 0.21852800E+00, -.28892100E+00, 0.53109100E+00, -.27555600E+00, -.22087500E+00, -.48352600E-01, -.31930200E+00, -.19026100E+00, 0.19599900E+00, 0.10334400E+01, -.17732000E+00, 0.20294100E+00, -.36833600E+01, -.39640400E+00, -.36239800E+00, -.93102300E+00, 0.40516000E-01, 0.58617000E-01, -.18134800E+00, 0.50787400E+00, -.37241400E+00, -.10198600E+01, 0.30880100E+00, -.13280600E+00, -.52081100E+00, 0.17563800E-01, -.28416100E+00, 0.21614700E-01, -.28386400E+00, 0.56116300E+00, -.11813300E+00, -.23513200E+00, 0.42224900E+00, -.20089000E-01, -.30452100E+00, 0.29114500E+00, -.75295300E+00, -.24638500E-01, 0.16864000E-01, -.33999900E+00, -.11843300E+00, 0.46791400E+00, -.17260900E+00, -.26752100E+00, 0.36564400E+00, -.80831300E+00, 0.10294200E+01, -.26573700E+00, 0.19352900E+00, -.95117900E-02, -.17862000E+00, 0.13660900E+00, -.14320300E+01, 0.54210900E+00, -.21033900E-01, -.86583300E-01, 0.11576700E+00, -.51206900E+00, -.24072000E-01, 0.52233800E-01, 0.32395900E+00, -.13929500E+00, -.39779600E+00, -.99857900E+00, 0.17564100E+00, 0.85328800E+00, -.52523000E+00, -.49794900E-01, 0.11834000E+00, -.29037200E+00, -.89151800E-02, -.27759100E-01, -.74102400E+00, 0.28784200E+00, -.30602800E+00, 0.22070300E+00, -.71362000E+00, 0.14694100E+00, 0.55310900E+00, -.34348400E+00, 0.22462800E+00, -.31878300E+00, 0.39346500E+00, -.22228900E+01, 0.89833200E+00, 0.64516000E+00, -.10750000E-01, -.85471900E+00, 0.40357500E+00, 0.36813500E+00, 0.55132400E+00, -.14441500E-01, -.14944700E+01, 0.15127800E+00, 0.26439500E+01, -.41807300E-01, 0.13547300E+00, 0.11520500E+00, 0.22015500E+01, 0.35372200E+01, 0.11654400E+01, -.14414800E+01, 0.18041900E+00, -.73905300E+00, -.91541900E-02, -.21674400E-01, -.58488100E+01, -.64310600E+00, -.72490100E-01, 0.33809700E+00, -.91393200E-01, 0.59630800E+00, -.24169800E+00, -.18023100E+00, -.15983500E-02, -.22613200E-01, -.76182600E+00, -.23406200E+00, -.14885700E+01, 0.26254600E+00, -.58238600E+00, -.53672000E+00, -.59183500E+00, -.21610500E+00, -.53324300E+00, -.63558200E-01, 0.40894800E-01, -.34483900E+00, -.25870200E+00, -.60524700E+00, -.50269400E+00, 0.17565000E+00, -.19458900E+00, 0.12695800E-01, 0.11198900E-01, 0.24911500E-01, 0.95695600E+00, 0.54076900E-01, -.92124500E+00, -.49199700E+00, 0.51002800E-02, -.10547700E+00, -.25683200E+00, 0.57740900E-01, 0.78741800E-02, -.17388400E+01, 0.21191000E+00, -.35241500E-01, -.26263300E+00, 0.42113600E+00, -.48523700E+00, -.77961600E+00, 0.15262300E+01, 0.17489200E+00, -.53368800E+00, -.63018300E+00, -.42400300E+01, 0.72137900E-01, 0.13074600E+00, 0.10726400E+00, -.14795100E+01, 0.39861000E+02, 0.20764400E+02, 0.51125800E+02, -.39514900E+02, 0.62129900E+02, 0.24133000E+02, 0.16853800E+01, -.47732400E+00, -.44412300E+01, -.13442500E+01, 0.32433400E+01, 0.53269200E+00, -.21272200E+01, 0.27581800E+01, -.12578500E+02, 0.16796100E+01, 0.14564700E+01, 0.30751000E+01, 0.21537600E+01, -.13134000E+02, 0.77559200E+00, -.14108400E+01, 0.38421500E+01, 0.12047200E+01, 0.26583500E+00, 0.44802500E+00, -.15240700E+00, -.95292500E+00, -.18325000E+00, 0.19489700E+01, -.77502800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31518400E+02, 0.29132600E+01, 0.62420200E+01, 0.66784200E+01, 0.71704400E+01, -.43798200E+01, 0.27659200E+01, 0.11709000E+01, -.13026200E+01, 0.75484800E+01, -.10621900E+01, 0.58097000E+01, 0.44605400E+01, 0.74282100E+01, 0.14845400E+01, 0.18598100E+01, 0.14928400E+02, 0.12544200E+02, 0.17624800E+01, 0.51359500E+01, -.95341800E+01, -.79542600E+00, 0.11452400E+01, 0.12857300E+02, 0.13692400E+01, -.12138000E+01, -.62958600E+00, -.15515800E+02, -.16163400E+01, -.78400600E+00, -.87509500E-01, 0.27373000E+01, 0.10293300E+02, -.35180100E+01, 0.21457100E+01, 0.63297300E+00, 0.48081800E-01, 0.19899700E+00, 0.89829200E+00, -.80589500E+01, 0.19948200E+01, -.85654400E-01, 0.74197600E+00, -.11350100E+01, -.44004500E+01, -.13083300E+01, 0.27502000E+01, -.38874600E+01, 0.47085100E+01, 0.11798800E+01, -.42033100E+00, 0.72424800E-01, 0.95852800E+00, -.17829300E+01, 0.59394800E+00, 0.41802700E+01, 0.13937400E+01, 0.76283300E+00, -.46319500E-02, -.19823100E+01, -.97527600E+00, -.35435500E+01, 0.77970400E+00, 0.14521700E+01, 0.15432200E+01, -.55596400E+01, 0.42811000E+00, -.68198700E+01, -.92163600E+00, 0.14142900E-01, 0.13357500E+01, 0.41374200E+00, -.21395700E+01, -.42746700E+01, 0.40408300E+01, -.18666000E+00, 0.55551500E+00, 0.25377400E+01, 0.12641900E+01, 0.16143200E+00, 0.40572100E-01, -.14804700E+01, -.11987100E+01, -.10560700E+01, -.72818300E+00, 0.16104500E+01, -.24398200E+01, -.77545700E+00, -.23906300E+01, -.81591200E+00, -.95842900E+01, -.40834700E-01, -.22281300E+01, -.13520600E+00, 0.57671000E+00, -.98754200E+00, -.53532800E+00, 0.12370700E+01, 0.15658200E+01, 0.36672100E-01, -.18487900E+01, 0.26844900E+00, -.16378200E+00, 0.19972600E+00, -.10431600E+01, -.65669200E+00, 0.29639700E+01, -.45505500E+00, -.19559200E+00, 0.24786400E-01, -.18809100E+01, 0.90035800E-01, 0.13306000E+01, -.77906000E-01, 0.36671600E+00, -.44500300E+00, -.33195500E+00, -.58208800E+00, -.24074400E+01, 0.17218500E+01, -.10805300E+01, -.22199200E+00, -.76692900E-01, -.10598900E+00, 0.12094300E+00, 0.11451900E+01, -.20606500E+00, 0.57935200E-02, 0.13465400E+00, 0.32075300E+00, 0.40387400E+01, -.33463200E+01, -.17452200E+01, -.12378200E+01, -.69070600E-01, 0.42346300E-01, -.19328400E+01, -.39737000E+00, 0.25022100E+00, -.64472400E+00, 0.10840300E+00, 0.79701500E+00, -.59660800E+00, -.40189600E+01, 0.15403500E+00, -.47402500E+00, -.15454200E+00, 0.16824200E+00, 0.14308100E+00, 0.14884300E+01, -.88073700E+00, 0.20959600E+00, 0.43538200E+00, -.95098100E-01, -.27139600E+01, 0.24862900E+00, -.27551400E+00, 0.11416400E+00, -.66190600E-01, -.61803800E-01, 0.91413600E+00, 0.27111100E-01, -.40146100E+00, -.25204100E+01, 0.23632900E+01, -.71934000E+00, 0.44192400E+00, -.11035600E+00, 0.72389800E+00, 0.86441500E+00, 0.21486100E+00, 0.51201300E+00, -.33705000E+00, -.14488800E+01, 0.26089400E-01, -.69684600E+00, 0.12979000E+01, -.11557000E+00, 0.10075200E+01, 0.10094100E-01, 0.30789800E+01, -.19208300E+01, -.23268600E+01, 0.16984700E+01, -.64095600E+00, -.32628900E+00, -.61887400E+00, -.11211600E+01, 0.30891500E+00, 0.97912800E+00, 0.25419500E+00, -.46138100E+00, 0.21770000E+01, 0.10967500E+01, -.48290700E+00, -.40502700E+01, -.25731100E+01, -.11268500E+01, 0.19983300E+01, -.93684600E-01, 0.73351500E+00, -.11403600E-01, 0.42481000E+00, 0.22133400E+01, 0.11829800E+01, -.18554300E+00, -.69176300E+00, -.78937300E-01, -.21207200E+00, 0.38531500E+00, -.99603300E-02, 0.24273500E-01, -.10238700E+00, 0.29476400E+00, 0.42070100E+00, -.11606700E+01, 0.16505700E+00, 0.10929300E+01, 0.44255900E+00, 0.31474200E-01, -.83644600E+00, 0.30204400E+00, -.12852600E+01, 0.99609200E+00, -.84092000E+00, -.28543500E+00, 0.35622200E+00, -.34337800E+00, 0.61179100E+00, 0.15747000E+01, 0.54905800E+00, 0.44699100E+00, -.57214200E+00, 0.15034500E-02, 0.27327500E-01, 0.47263800E-01, -.75789400E+00, 0.10732900E+00, -.26794900E+00, 0.28072800E+00, 0.33486600E+00, 0.55779200E+00, 0.38877900E+00, -.36217000E+00, -.67979400E+00, 0.38287500E+01, -.33035000E+00, 0.11535600E+01, 0.26453400E+00, -.56832700E+00, -.67106300E+00, -.19014700E-02, 0.48453800E+00, -.31554700E+01, 0.29897000E-01, -.39334200E-02, 0.46012100E+00, -.10266200E+01, 0.22930800E+00, 0.58699700E+02, 0.15403700E+02, 0.75320600E-01, 0.56301400E+01, 0.42774400E+02, 0.73286100E+00, -.12893500E+01, -.46579700E+01, 0.65690500E+00, -.52937000E-01, -.50790600E+00, -.13653000E+01, 0.28006600E+00, 0.28597700E+01, -.43506900E+00, 0.11138400E+01, 0.32725800E+00, 0.70983400E+00, 0.29048900E+01, 0.69412600E+00, 0.55733600E+00, -.58181400E+00, 0.18759300E+01, 0.62861000E+00, 0.23020900E+01, -.65078100E+00, 0.13160400E+00, 0.45819900E+00, 0.13903200E+01, 0.95322700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15838200E+02, 0.18591400E+01, -.74782800E+01, 0.81616600E+00, 0.30830600E+01, -.39916500E+01, 0.16998700E+01, 0.19200700E+00, -.11108400E+01, -.82925700E+00, 0.17371900E+00, -.15017900E+00, -.11159500E+01, -.96557500E+01, 0.98213000E-01, 0.22095500E+01, -.18802500E+01, -.69058500E+01, -.36354000E+00, -.14669600E+01, 0.27568400E+01, -.94205200E+00, 0.11988800E+01, -.20721800E+01, 0.53433800E+00, 0.19813600E+01, 0.45130300E+01, 0.24773400E+01, -.26326800E+01, 0.18062400E+01, -.12820700E+00, 0.39068700E+00, -.76285100E+00, 0.18064900E+01, -.43519200E+00, 0.70104100E+00, 0.39859800E-02, -.39922800E+00, 0.19390800E+00, 0.94102400E+00, -.17272900E+00, 0.19287300E+00, -.37460400E+01, 0.20349400E+00, 0.24925700E+01, 0.27473700E-01, 0.66482100E+00, -.12541400E+01, -.50486000E+00, -.33353200E+00, -.24689000E+01, 0.11366800E+01, 0.36900800E-01, 0.13392400E+01, -.18842300E+00, 0.23908300E+01, 0.17222000E-01, -.15448000E+01, -.58446000E-02, 0.14279400E+01, -.34553600E+01, -.15809600E+01, 0.48829900E+00, -.63303800E+00, -.14813600E+01, 0.27923200E+01, -.10816300E+01, -.52809800E+01, 0.23883000E+00, 0.26910900E-01, -.10206100E+01, 0.68095900E+00, -.52819800E+00, 0.32579800E+00, 0.10752900E+01, -.40771200E+01, 0.50715500E+00, 0.26360200E+01, 0.36403300E+00, 0.53883600E+00, -.12270100E+00, -.25851700E+01, 0.75108700E+00, -.71655300E+00, -.75383300E+00, 0.33700600E+00, 0.35732300E+00, -.28005300E+00, -.19594900E+01, 0.10290700E+01, 0.21220600E+01, -.10239700E-01, 0.41762700E-01, -.38727600E+00, -.27038100E+01, -.10593200E+00, 0.96552900E+00, 0.15994500E+00, 0.88307500E+00, -.40145900E+00, -.46736100E+00, 0.86432100E+00, -.88396600E-01, -.30659400E+00, 0.90455200E-01, 0.31752800E+00, -.10638900E+00, -.44041800E+00, -.94694100E+00, -.21835600E+01, -.62658600E+00, -.25514500E+00, 0.25495900E+00, -.39570900E-01, 0.33016900E+00, 0.58248700E-01, 0.66424200E+00, 0.90084000E+00, -.22959700E+01, 0.42192600E+00, 0.35077600E+00, -.42701200E-01, 0.10041600E+00, -.52893400E+00, 0.68261200E-02, 0.11295200E+01, 0.23313300E+00, 0.23935600E-01, 0.16497100E+00, 0.60527600E-01, 0.11749300E+01, -.97098000E+00, 0.84181400E+00, 0.53426100E+00, 0.33655300E-01, -.84131700E-01, 0.40074400E+00, -.20027600E-01, 0.11964700E+01, -.29329800E+00, 0.74878200E+00, -.20401600E-02, 0.71918100E+00, 0.14556600E+01, -.39551100E+00, 0.17753100E+01, 0.75160300E-01, 0.21980500E+00, -.48317800E-01, -.20890100E+01, 0.61218000E+00, -.31470800E+00, -.12662500E+00, -.67530200E-01, 0.67187700E+00, -.58398700E-01, 0.18160800E+00, 0.28384300E+00, -.21045900E+00, 0.33502900E+00, -.65658000E+00, -.15873400E+00, 0.11082000E+01, 0.92936600E+00, -.79599500E+00, -.29574000E-01, -.17096600E+00, 0.39752200E-03, -.61616200E+00, -.32706300E+00, -.48651200E-01, 0.65943500E-01, -.13400200E+00, 0.12578200E+01, 0.24333800E+00, 0.11133700E+00, 0.25209700E+00, 0.29446700E+00, -.64434900E+00, -.95256900E-01, -.14837900E+01, 0.71035100E+00, 0.11540900E+01, -.33774100E+00, 0.33068000E+00, -.12548800E+00, -.11524400E+00, 0.16973500E+00, -.48894800E-01, 0.44163200E+00, -.17807900E+00, 0.17192600E+01, 0.15202800E+00, -.32902100E+00, -.52001100E-02, 0.24684200E+00, 0.12473400E+01, 0.69318500E+00, -.53567000E+00, 0.19652100E+00, -.77032300E+00, 0.80094900E-02, -.54017400E-01, -.18296100E+01, -.64722800E+00, 0.28501900E+00, 0.13874600E+00, 0.51469600E-01, 0.65799800E+00, 0.28394200E+00, -.35744900E-01, -.14462500E+00, -.34629600E-01, -.18994900E-01, 0.41891500E+00, -.22940200E+01, 0.54155400E+00, -.22676000E+00, -.46707000E+00, -.11915500E+01, 0.22376900E+00, -.18143400E+00, 0.63608000E-01, -.76108200E+00, 0.22463700E+00, 0.45092500E+00, 0.39668700E+00, -.10447100E+00, -.65441800E+00, -.80681000E+00, -.34807700E+00, -.28746300E+00, -.81897200E-01, -.24501000E-01, -.84860700E-01, 0.24850100E+00, 0.44513400E+00, 0.25249400E+00, 0.55493100E+00, -.13726300E+00, -.27619300E+00, -.69332800E+00, 0.24617700E+01, 0.36691400E-01, 0.64922700E-01, -.16807100E+01, -.47423000E+00, 0.35647900E+00, -.79726000E+00, 0.24033700E+01, 0.20100000E-01, -.36053800E+00, -.32411900E+00, -.19722200E+01, -.11204100E+00, 0.40897600E-01, 0.10607700E+00, 0.75425400E-04, -.74283900E+00, -.17086400E+00, 0.40292300E+02, -.65452000E+02, 0.58243100E+02, 0.23930600E+03, 0.63376500E+01, -.13589800E+01, -.17110500E+02, -.71673300E+00, 0.26028100E+02, 0.39684700E-01, -.27267300E+01, 0.23108500E+02, -.16210500E+02, -.21615300E+01, 0.58953000E+01, 0.23350600E+01, 0.45730700E+01, -.17616000E+02, -.73935700E+00, -.22010000E+01, 0.72647600E+01, 0.90090200E+01, 0.16300100E+01, 0.47246900E+01, -.31193700E+00, -.12971400E+01, 0.63870800E+01, 0.64423100E+01, -.35683600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.45214400E+02, -.45450600E+01, -.24800000E+01, -.13550800E+02, -.72702200E+01, 0.13814000E+02, -.89695300E+01, -.87235400E+00, 0.35304000E+01, -.10931200E+02, -.11418900E+01, -.49286500E+01, -.18578000E+01, 0.21896900E+01, -.19711500E+01, -.73400500E+01, -.67335100E+01, 0.76581000E+00, -.31884600E+01, 0.12890800E+01, 0.46974600E+01, 0.23513000E+01, -.94802900E+00, -.38262600E+01, -.15629600E+01, -.23963800E+01, -.44865700E+01, 0.29586600E+01, 0.38475700E+01, -.22769200E+01, 0.48083800E-02, -.16503700E+01, -.37859000E+01, -.17108300E+00, -.78054000E+00, 0.42851600E+00, -.31424800E-01, 0.95322300E+00, -.12589200E+01, 0.50450400E+01, 0.99543800E-01, 0.12254800E+01, 0.31221500E+01, 0.29307600E+00, 0.76501700E+00, 0.10727600E+01, -.31389800E+01, 0.41238700E+01, -.31865500E+01, -.11655400E+00, 0.91009700E+00, -.70766800E+00, 0.55082400E+00, -.73282500E+00, -.88243300E+00, -.63657200E+01, -.10607600E+01, 0.13691500E+01, 0.98300300E-02, -.35146800E+00, 0.87435000E+01, 0.45189100E+01, -.74895600E+00, 0.13939400E+01, 0.22494500E+01, -.83721500E+00, 0.19550800E+01, 0.13831800E+02, -.15277400E+00, -.57431700E-01, -.48354200E-01, -.16406900E+01, 0.18414900E+01, -.13908400E+01, -.11563200E+01, 0.73503700E+01, -.11775200E+01, -.49518700E+01, -.15757000E+01, -.50423900E+00, 0.23476500E+00, 0.66041700E+01, -.20676900E+01, 0.90312900E+00, 0.13850400E+01, -.69723200E+00, -.38356200E+00, 0.14748000E+01, 0.22384700E+01, -.20240600E+01, -.57435500E+01, 0.69692600E-01, -.83690000E+00, 0.97445100E+00, 0.37934000E+01, 0.10483800E+01, -.22184200E+01, 0.65516300E+00, -.24947600E+01, 0.16883500E+01, 0.69424000E+00, -.15984900E+01, 0.14697400E+00, 0.27901800E+00, -.76923200E+00, -.28005900E+00, 0.19368800E+00, -.10226700E+00, 0.26496300E+01, 0.19164400E+01, 0.14550900E+01, -.41064100E-02, -.22806800E+01, 0.16250700E+00, -.72897400E+00, 0.37156200E+00, -.21546400E+00, -.45469900E+00, 0.55479200E+01, -.16997700E+01, 0.14322000E-01, -.60412200E-01, -.13801600E-01, 0.99149500E+00, -.17769600E+00, -.19854800E+01, -.41380800E+00, 0.11082100E+00, -.33785000E+00, -.42953000E+00, -.24272900E+01, 0.17602600E+01, -.15350500E+00, 0.82836400E+00, 0.13510200E+00, 0.26947100E+00, -.19043400E+00, 0.26097900E+00, -.25748000E+01, 0.24716500E+01, -.23580700E+01, -.70726000E-01, -.95011500E+00, -.81918900E+00, 0.12326600E+01, -.15297900E+01, -.17953000E+00, -.28702100E+00, -.22930700E+01, 0.69048100E+01, -.27660100E+00, 0.35924700E+00, -.18816000E+00, 0.46148100E+00, -.31592300E-01, -.31486700E-02, -.14672100E+00, -.62391900E+00, 0.47220100E+00, -.11362100E+01, 0.23583300E+01, 0.18610100E+00, -.19227200E+01, -.87984100E+00, 0.29772700E+00, 0.53273100E+00, -.13882100E+00, -.15974700E+00, -.99573800E+00, -.46987700E+00, 0.47340400E-01, -.16902800E+01, 0.43509100E-01, -.10991700E+01, -.34057200E+00, 0.68685800E+00, 0.61457500E-01, -.43151200E+00, 0.88788900E-01, 0.16797200E+00, 0.12387600E+01, -.19587500E+00, -.12812700E+01, -.12807800E+00, 0.38819100E+00, 0.13130600E+01, 0.32184700E+00, -.52108200E+00, 0.51379100E-01, -.56203600E+00, 0.46072400E+00, -.12022500E+01, -.23959700E+00, 0.35745600E+00, 0.17258400E+00, -.18147900E+01, -.39195400E+01, -.80746900E+00, 0.15757700E+01, -.26058100E+00, 0.79727300E+00, -.13501400E-01, 0.66412900E-01, 0.42583000E+01, 0.12181500E+01, -.57901600E-02, -.32065900E+00, -.50273400E-01, -.11510800E+01, -.73468900E+00, -.16976600E-01, -.47714400E-02, 0.33205100E-01, -.55480100E+00, 0.10798500E+00, 0.23063400E+01, -.13028200E+01, 0.69011900E-01, 0.71797000E+00, 0.43453400E+00, 0.26235100E+00, -.93432700E-01, 0.66229300E+00, 0.97261300E+00, -.26627900E+00, -.13995100E+00, -.14526300E+00, 0.51221200E+00, 0.13169800E-01, 0.90844300E+00, 0.79392900E+00, 0.11696300E+00, -.12683400E+00, 0.62178000E+00, -.11871400E+00, -.12819300E+01, -.31119900E+00, -.55137900E+00, -.31996100E+00, -.27003000E+00, -.13765300E+01, 0.94017900E+00, -.97108100E+01, 0.31162900E+00, 0.93020500E+00, -.15954100E+01, 0.12323200E+01, -.30447200E+01, -.72004600E+00, 0.21916500E+00, 0.13776400E+01, -.55436300E+00, -.88451000E+00, -.31557300E+01, -.15456400E+00, 0.80634200E-01, 0.59856000E-01, -.18756000E+01, 0.11276600E+01, 0.92395600E+00, 0.10016700E+01, 0.15525400E+03, -.14479200E+03, -.56869400E+03, -.13014500E+02, 0.50812400E+01, 0.32805300E+02, 0.51360200E+00, -.58654400E+02, 0.86674300E+00, 0.49796000E+01, -.51486000E+02, 0.41113200E+02, 0.51507200E+01, -.14678900E+02, -.47206100E+01, -.13464500E+02, 0.44226600E+02, 0.16127200E+01, 0.36487800E+01, -.10158900E+02, -.21110500E+02, -.53969700E+01, -.53933000E+01, -.21690900E+00, 0.38004700E+00, -.12824700E+02, -.15546000E+02, 0.68251000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.96719400E+01, -.89657500E+00, -.31396800E+01, -.56224300E+00, 0.47138200E-01, 0.44128300E+00, -.11198600E+01, -.42870700E+00, -.36033400E-01, -.32864000E+01, 0.90062700E-01, -.19432800E+01, -.16536800E+01, -.48651600E+01, -.69452700E+00, -.69958600E+00, -.57940600E+01, -.64889600E+01, 0.57372800E+00, -.32430400E+01, 0.33720500E+01, 0.99817100E-01, -.62202800E+00, -.50153400E+01, -.53133800E+00, 0.60101900E+00, 0.17943700E+00, 0.40316800E+01, -.24141300E+00, 0.87638300E+00, -.98860700E-01, -.17540800E+01, -.25041200E+01, 0.89233500E+00, -.73134100E+00, -.13652100E+01, -.15929900E-01, -.15517100E+00, -.10267100E+01, 0.48382400E+01, -.11715800E+01, 0.62627400E+00, 0.11584000E+01, 0.27308200E+00, 0.30095800E+01, 0.60131600E+00, -.86768700E+00, 0.80191200E+00, -.14056200E+01, -.63311500E+00, 0.69928000E+00, -.31866800E+00, -.34591300E+00, 0.14387100E+00, -.71514300E+00, 0.15961100E+00, -.56927400E+00, -.14867500E+01, 0.10715200E-01, 0.24467800E+01, -.42949300E-01, 0.19343800E+01, -.35610600E+00, -.84813600E+00, -.27421200E+01, 0.31328100E+01, -.45855000E+00, 0.12088100E+01, 0.51289600E+00, -.59294000E-02, -.87938200E+00, -.12405600E-01, 0.66563800E+00, 0.20492300E+01, -.62538400E+00, -.14274100E+01, 0.29880200E-01, 0.24169400E+00, -.54256300E+00, 0.37513800E+00, -.28195400E-01, -.36612100E+00, 0.30197600E+00, 0.59857200E+00, -.30627400E+00, -.64922400E+00, 0.71460500E+00, -.41192600E+00, -.13439400E+00, 0.13541700E+01, 0.96431100E+00, 0.30100400E-01, 0.12427500E+01, -.29463300E+00, -.20617200E+00, 0.46163700E+00, 0.16532300E+01, -.66672600E+00, -.23571600E+00, -.31586700E+00, 0.10934900E+01, -.62417900E+00, 0.10178100E+00, 0.44401600E-01, 0.27561300E+00, 0.83594000E-01, -.57230900E+00, 0.92240700E+00, 0.15283200E+00, 0.42926500E+00, 0.50187000E+00, -.50001700E-01, 0.20868500E+00, 0.28717800E-01, -.14769100E+00, 0.62517200E-01, -.39461800E+00, 0.28549300E+00, 0.17636100E+01, -.12844700E+01, 0.38554900E+00, -.20099700E+00, 0.17096600E-02, -.12928900E+00, -.53356100E-02, -.19349000E+00, 0.32186200E+00, 0.41590200E-01, -.10764200E+00, 0.17548800E+00, -.11846100E+01, 0.14728800E+01, -.39102200E+00, 0.49036600E+00, -.28038700E-01, -.47234300E-02, 0.45412000E-01, -.22883400E+00, -.11859400E+01, -.11456200E+00, 0.66145400E-01, -.21610100E+00, -.15262900E+00, 0.31120600E+00, 0.96971200E-01, -.91824500E-01, -.11339100E-01, -.15803500E+00, -.19293600E+00, -.10563400E+01, -.74564500E-01, 0.32774000E-02, -.19624400E+00, -.35674600E-02, 0.88027300E+00, 0.42790900E-01, 0.99445300E-01, 0.44459000E-01, -.10821900E-01, -.14920500E+00, -.13998100E+01, 0.15208400E-01, 0.27849400E+00, 0.72400600E+00, -.10204000E+01, 0.31213000E+00, -.32232000E-01, 0.19436600E+00, 0.11585800E+01, -.10516300E+00, 0.83683100E-01, 0.45894000E+00, -.14320600E+00, 0.52720000E+00, -.28231700E+00, -.51420600E+00, -.71935500E+00, 0.17234100E+00, -.18500800E-01, -.61809700E-02, -.95001800E+00, 0.14163500E+01, 0.55351900E+00, -.86239200E-01, -.84923500E-01, 0.11605100E+00, -.81328700E-01, 0.56561500E-02, -.27259300E-01, 0.21255400E-01, -.81044200E-01, 0.22224700E+00, -.10122300E+01, 0.23369700E+00, 0.19898700E+00, 0.40871100E+01, 0.84197800E+00, 0.30193500E+00, 0.24587800E-01, 0.50201800E-02, -.21460800E-01, 0.25275700E-02, -.23124300E-01, -.14263500E+01, 0.93789600E-01, 0.31974400E-01, 0.33463200E-01, -.12630700E+00, -.78678300E-01, -.21142500E+00, 0.90828500E-01, 0.57063400E-01, 0.59222400E-01, -.12314700E+00, -.32960500E+00, 0.10823900E+00, 0.21617600E+00, -.35490400E+00, -.19512800E+00, -.57507500E+00, -.12422000E+00, -.24923800E+00, 0.70850400E-01, -.52375300E+00, -.60995600E-02, 0.62839900E-01, 0.15468700E+00, -.17828300E+00, -.10400600E+00, -.42864300E+00, -.27705800E+00, -.27799600E+00, 0.45835100E-01, 0.14843400E+00, 0.13443600E+00, -.68171300E+00, -.12097000E+00, 0.18369600E-01, 0.71778500E-01, -.17196900E+00, 0.74774800E-01, -.10032500E+00, 0.11878700E+01, -.97634700E-03, -.34997400E+00, -.57726500E+00, 0.13153700E+00, 0.70221700E+00, 0.92705300E-01, 0.60465300E-01, -.25078500E+00, 0.34359700E+00, -.59622600E-01, -.55484500E+00, 0.18060000E-01, -.65400400E-01, -.18142400E-01, 0.26575500E+00, 0.11294900E-02, -.29876400E+00, -.27676200E+00, -.18625300E-01, 0.16457300E+02, 0.32288400E+02, 0.90237400E+00, -.83059200E-01, -.20400000E+01, 0.10260900E+00, 0.73813800E+01, 0.31829400E+00, -.88316700E+00, 0.67465100E+01, -.71144300E+01, -.24966900E+00, 0.11314200E+01, 0.71549100E+00, 0.11204800E+01, -.74901200E+01, 0.20712300E+00, -.34533500E-01, 0.25899400E+01, 0.14035800E+01, 0.56509300E-01, 0.24737200E+01, -.24540200E+00, 0.36168900E-01, 0.18075900E+01, 0.11458800E+01, 0.23649000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.97084400E+01, -.12505300E+01, 0.41464900E+01, -.37513400E+00, -.38528600E+01, 0.14607900E+01, 0.14221800E-01, -.14606500E+00, 0.36204300E+00, 0.82883500E+00, 0.59068200E+00, -.76008200E+00, 0.17548600E+00, 0.74580200E+01, -.10591200E+00, -.17610900E+00, -.31469900E+00, 0.28019000E+01, -.58980200E+00, -.38723000E-01, -.12457500E+01, 0.34624900E+00, -.94859700E+00, -.26607000E+00, -.41375100E+00, -.71492300E+00, -.20422700E+01, -.35001700E+00, 0.21126000E+01, -.11492000E+01, 0.48062500E-01, -.78189000E+00, -.87031900E+00, -.14282000E+00, -.18433400E+00, -.74959100E+00, -.55440100E-01, 0.17824200E+00, 0.26175200E+00, 0.43696900E+00, -.39280500E-01, -.24122900E+00, 0.27342500E+01, 0.59344600E-01, -.14690700E+01, 0.11567700E+00, -.44745400E+00, 0.16653600E+01, -.59519400E+00, -.24430200E+00, 0.14236700E+01, -.37289100E+00, -.50591900E+00, 0.78779700E-01, 0.75070300E+00, -.20368900E+01, -.30041800E-01, 0.84469100E+00, -.22255300E-02, -.11516100E+01, 0.14837000E+01, 0.11993600E+01, -.12935900E+00, 0.22906100E+00, 0.16447600E+01, -.58077700E-01, 0.34442600E+00, 0.40096000E+01, -.28236500E-01, -.56285300E-02, 0.82318700E+00, -.59128600E-01, 0.17262800E+01, 0.43622800E+00, -.11854700E+01, 0.13370500E+01, -.24996500E+00, -.13824900E+01, -.58858300E+00, -.72851300E+00, 0.36376400E-01, 0.10056900E+01, -.36291300E+00, 0.24440300E-01, 0.34375900E+00, -.17148900E+00, 0.74915200E+00, 0.68378600E+00, 0.19458800E+01, -.58856900E+00, 0.13313700E+01, -.40931900E-01, -.92570200E+00, 0.56275600E+00, 0.14713300E+01, -.44647500E+00, 0.53188600E+00, -.91579400E+00, -.22112400E+00, 0.50287100E+00, -.18106800E+00, -.88560200E+00, 0.10182300E-01, -.11921700E+00, 0.48160200E-01, 0.23659000E+00, 0.50174000E+00, 0.17748100E+00, -.41988600E-01, -.80498900E+00, -.82345200E-01, -.15163200E+00, -.39129800E+00, -.11333700E-02, 0.80124000E-01, -.24596100E+00, 0.19808100E+00, 0.17823000E+00, -.11707500E+01, 0.22502800E+00, -.16068700E+00, -.64903100E+00, -.19105800E+00, -.55952000E+00, 0.97042700E-01, -.29242100E+00, 0.39793800E+00, -.95056700E-01, -.30100800E-01, 0.55474300E+00, 0.67979300E+00, -.79000200E+00, -.55811800E+00, -.93974600E+00, -.15746100E+00, 0.84687300E-02, -.21358900E+00, -.47809000E+00, 0.73472900E+00, -.98449200E+00, 0.54369800E+00, 0.19246000E+00, -.12305800E+00, -.27363100E+00, -.18477400E+00, -.88809900E+00, -.14353800E-01, -.98840000E-01, 0.10216400E+01, -.18970600E+01, -.52930100E-01, 0.16149400E+00, 0.14653700E+00, -.62087500E-03, -.18249600E+01, 0.10781100E-01, -.16451600E+00, -.48514300E-02, 0.11558000E+00, 0.39600300E+00, 0.58522200E+00, 0.24174400E+00, -.53905600E+00, -.34614200E+01, 0.88922400E+00, 0.68282500E+00, 0.34796500E+00, 0.89483800E-01, 0.42068300E+00, 0.18481900E+00, 0.17620800E+00, 0.10172700E+01, 0.29241300E+00, -.16758000E+01, 0.62002300E+00, -.21553000E+00, -.46550000E-01, -.50327200E-01, 0.11041000E+01, 0.13275700E+00, 0.14513400E+01, -.28034900E+01, -.12412500E+01, 0.96782700E+00, -.12298900E+01, -.47678700E+00, -.69008500E-01, -.40037800E+00, 0.24318900E+00, -.11457200E+01, 0.54286100E-01, 0.11841800E+01, 0.64326900E+00, 0.21055600E+00, 0.10214100E+00, 0.29160600E+01, 0.12550600E+01, 0.20056200E+00, 0.26052800E+00, -.15455600E+00, 0.11578100E+00, 0.33036000E-02, 0.15999900E+00, -.17802800E+01, 0.24363000E+00, -.28041100E+00, -.49862000E+00, -.39682600E+00, -.23934600E+00, -.37519000E+00, -.17392800E-01, 0.97415000E-01, 0.73306200E-01, -.25454700E+00, 0.16457200E+00, 0.19916400E+01, 0.44850000E-01, 0.10784900E+01, 0.92361300E+00, -.10467800E+01, 0.11861800E-01, -.25928500E+00, -.93600500E-01, -.10141500E+00, -.38770600E+00, -.80854800E-01, -.15474100E-01, -.15517800E+00, -.36204400E-01, 0.22738200E+00, 0.25543400E+00, 0.13555000E+00, 0.97409600E-01, -.34826300E+00, -.17817000E-01, 0.61583100E-02, 0.18322600E+00, -.14387700E+00, -.60915200E-01, -.54556300E-02, -.87287900E-01, 0.18499400E+00, -.14687600E+01, 0.25546800E-03, 0.35144700E+00, -.38643700E+00, 0.28146200E+00, -.54380300E-01, -.45163600E+00, 0.36492100E+00, 0.34961200E+00, 0.44319900E+00, -.30221500E+00, -.57895800E+00, 0.17237000E-01, -.13524800E+00, -.50300700E-01, 0.52785900E+00, -.40138100E+00, 0.18390900E+00, 0.12383100E+00, 0.61130100E-01, 0.67751600E+00, -.85099000E+02, -.14713900E+01, 0.85386000E-01, 0.16925000E+02, -.47417800E+00, -.34963400E+01, -.37097700E+00, 0.76827600E+00, -.31441600E+01, -.16762500E+01, 0.36589500E+01, -.20064000E+01, 0.81157600E+00, 0.14854300E+00, -.14242000E+01, -.27194900E+00, -.95687100E-01, -.27692900E+01, -.26986000E+01, 0.32610500E+00, -.30550200E+01, 0.10596600E+01, 0.46702300E+00, -.92436000E+00, -.20491500E+01, -.30987000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42078200E+02, -.44710300E+01, -.19478700E+01, -.11001200E+02, -.94480900E+01, 0.99617300E+01, -.50443300E+01, -.10432100E+01, 0.25446500E+01, -.95716500E+01, -.96215400E-02, -.69086400E+01, -.41942900E+01, 0.37714200E+01, -.83341700E+00, -.64627800E+01, -.91621000E+01, -.56736400E+00, -.20641000E+01, 0.13141200E+00, 0.49378000E+01, 0.18812300E+01, -.11517200E+01, -.62160000E+01, -.17363800E+01, -.12197700E+01, -.48600100E+01, 0.12987600E+01, 0.60561100E+01, -.17986700E+01, -.26062200E+00, -.14306800E+01, -.51393400E+01, -.13547700E+00, -.11068200E+01, 0.11231100E+01, -.18828100E+00, 0.11594600E+01, 0.47765800E+00, 0.18647100E+01, 0.76481700E+00, 0.86538000E-01, 0.26574200E+01, 0.48781100E+00, -.36326700E+00, 0.45939100E+00, -.21907600E+01, 0.41166200E+01, -.16517600E+01, -.73379500E+00, 0.20470400E+01, -.14366600E+01, 0.48608000E+00, 0.72699800E+00, -.12423900E+01, -.69509100E+01, -.16248100E+01, 0.75776600E+00, 0.36981900E-02, -.10491300E+01, 0.10215900E+02, 0.45644700E+01, -.37731000E+00, 0.28825300E+01, 0.17733100E+01, 0.22312800E+01, 0.16106900E+01, 0.17916800E+02, -.46837900E+00, -.35908100E-01, -.26664700E+00, -.15678300E+01, 0.36084700E+01, -.68900600E+00, -.32492100E+00, 0.35224800E+01, -.13334000E+01, -.23891300E+01, -.20057100E+01, -.17613400E+01, 0.19414200E+00, 0.58626500E+01, -.16776700E+01, 0.79353400E+00, 0.10238400E+01, -.68140300E+00, 0.48718900E+00, 0.17851500E+01, 0.21781400E+01, -.14936600E+01, -.27984200E+01, 0.32143600E-01, -.19504900E+01, 0.94686800E+00, 0.17053200E+01, 0.11434100E+01, -.17334900E+01, 0.40175900E+00, -.13399900E+01, 0.23042100E+01, -.20396600E+00, -.13139300E+01, 0.10394200E+00, 0.27058800E-01, -.58816400E+00, 0.67065400E+00, -.42991500E+00, -.30209700E+00, 0.18819200E+01, -.18191200E+01, 0.24930700E+01, -.11013000E+00, -.26751400E+01, 0.51727800E+00, -.86896200E+00, 0.21066000E+00, 0.15010300E+00, 0.31211100E+00, 0.17375500E+01, -.25908400E+01, 0.81223000E-01, -.57367700E-01, -.39614900E+00, 0.25493400E+00, 0.27247600E-01, -.13960000E+01, 0.30216800E+01, -.70536300E+00, -.25362300E+00, 0.12112100E+00, -.24570900E+01, 0.76759000E+00, 0.94729000E+00, 0.40011400E+00, 0.85448500E-01, 0.14622500E+00, -.13615400E+01, 0.34165300E+00, -.35756700E+01, 0.87131700E+00, -.48463100E+00, -.70587700E+00, -.79385400E+00, 0.37464600E+01, -.89546900E-01, 0.68782800E+00, 0.10151400E+00, -.18267700E-01, 0.10437200E+01, 0.33361300E+01, -.17476200E+01, 0.76330100E-01, 0.45932400E+00, 0.26102500E+00, 0.15092200E+01, -.30239800E+00, 0.29514100E+00, -.17490300E+00, 0.37899900E+00, 0.96128700E+00, -.17455400E+01, -.17807000E+00, -.13899300E+01, 0.16831000E+01, 0.67825600E+00, 0.26921400E+00, -.59450800E+00, -.14717000E+00, 0.48081300E+00, 0.76156900E+00, -.15303500E+00, -.13059300E+00, -.68366700E-02, -.97856600E+00, 0.10631600E+01, 0.35239500E+01, 0.15883000E+01, -.51795900E+00, 0.36054900E-01, 0.86083900E-01, 0.26948600E+01, -.25771200E+01, -.17886100E+01, 0.11921600E+00, 0.11064300E+01, 0.20610600E+01, 0.20188400E+00, -.14735100E+01, 0.21462500E+00, 0.25612300E+01, 0.39945000E+00, -.22652400E+01, 0.17768600E+01, 0.18614100E+01, -.35987000E+00, -.63725500E+01, -.62311800E+01, -.17237500E+01, 0.99354300E+00, -.43183600E+00, 0.12373500E+01, -.30493200E-01, 0.83594800E+00, 0.55570100E+01, 0.76725900E+00, 0.29973900E+00, -.11483300E+00, 0.10421400E+01, -.16394400E+01, -.77632600E-02, 0.76583800E-02, 0.14962500E+00, -.87283800E-01, -.54916700E+00, -.94049900E+00, -.17395300E+01, -.16596000E-01, 0.79175500E+00, 0.13530800E+00, 0.18167400E+01, 0.66192000E+00, -.23539400E+00, 0.54547800E+00, 0.48550400E+00, -.17498200E-01, -.43090700E-02, -.93463600E+00, 0.46874300E+00, 0.15445200E+00, 0.18485300E+01, 0.51407200E+00, 0.22238200E+00, -.16043900E-01, 0.24540900E+00, 0.27536200E+00, -.65127600E+00, -.12272800E+00, -.30670600E+00, -.45120000E+00, -.26870600E+00, -.38902400E+00, -.28228400E+00, 0.41954400E+01, -.20265200E+00, -.96888800E+00, -.24215800E+01, 0.74706100E+00, 0.16026400E+01, 0.24259500E+01, -.46150200E+01, -.10896700E+01, 0.31065100E+01, 0.13099800E+01, 0.65285500E+01, 0.16862800E+00, 0.15841700E+00, -.24321400E+00, 0.12776400E+01, -.26019600E-01, 0.19761800E+00, -.64210500E+00, 0.28454700E+00, -.23809700E+01, -.29431500E+01, -.36428800E+01, -.43871800E+01, 0.60696000E+02, -.28942800E+01, 0.27267800E+02, -.57158100E+01, 0.51713000E+01, 0.23118900E+02, -.37745400E+02, 0.14159500E+02, -.29717500E+01, -.15536200E+01, 0.28761200E+01, -.38644600E+02, -.50327900E+01, -.25946700E+01, -.12355200E+02, -.31083000E+01, 0.67928700E+01, -.79003400E+01, 0.65176400E+01, 0.41688000E+01, 0.56568300E+01, -.33380000E+01, -.11215000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14309000E+01, 0.75597300E-01, -.59263500E+00, -.80408200E+00, -.10517000E+01, -.36169600E+00, 0.75153600E+00, 0.50882700E-01, -.31612300E-01, 0.40473500E+00, -.29417900E+00, -.63342000E-01, -.37060100E+00, -.46197000E+00, 0.98870200E-01, 0.34982500E+00, -.80608000E-01, -.32489500E+00, -.38169400E+00, 0.14132600E-01, 0.19824700E+00, -.56405300E-01, 0.14560300E+00, -.13396500E+00, -.70639300E-04, -.38110800E-01, 0.73519200E+00, -.75029800E+00, -.19934100E+00, 0.12489300E+00, -.27031000E-01, -.14553200E+00, 0.18147400E+00, -.19939600E-02, 0.19723300E-01, 0.29286800E+00, 0.77157600E-02, 0.92855900E-02, 0.50387300E-01, -.29739100E+00, -.59088700E-01, -.83294300E-01, -.36650100E+00, 0.78841100E-02, 0.21202800E-01, -.22578500E-01, 0.54496200E-01, -.13595200E+00, 0.21287700E+00, 0.45620300E-01, -.18177200E+00, -.54439200E-01, -.22924900E-01, 0.18413100E+00, -.40067200E-01, 0.19811800E+00, 0.83567800E-01, 0.23023700E-02, -.11616600E-02, -.11117300E-01, -.45997400E+00, -.28532600E+00, 0.11915600E-01, 0.27128500E-01, 0.14399600E+00, -.20481800E+00, -.28334600E-01, -.70775700E+00, -.27890000E-01, 0.10911800E-02, -.25057900E-01, 0.38748600E-01, -.25457500E+00, 0.65509600E-02, -.50912700E-01, -.33697200E-01, 0.13773100E-03, 0.18110800E+00, 0.95965400E-01, 0.66207000E-01, -.96584400E-02, -.89555000E-01, -.73560700E-01, -.52222600E-01, -.17073500E-01, 0.24389400E-01, -.63993900E-01, -.43869300E-01, -.18548100E-01, 0.46597400E-01, 0.50596600E+00, -.33574800E-02, 0.28774200E-01, -.59551700E-01, -.25714600E+00, -.11241000E+00, 0.34370400E+00, -.18269300E+00, 0.14611400E+00, -.12779700E+00, 0.80534300E-01, 0.20152600E+00, 0.34154300E-02, 0.17017600E-01, 0.54886800E-01, 0.98198000E-01, -.30131700E-01, -.73578400E-01, -.24808600E+00, 0.51331000E+00, -.52240100E-01, -.68020100E-01, -.39157600E-01, -.19132400E-01, 0.33662500E-01, 0.14163500E-02, 0.42434700E-01, 0.44630200E-01, 0.11446900E+00, -.15801200E-01, -.65489100E-02, -.50797400E-01, 0.94628300E-02, 0.10665900E+00, 0.10796600E-01, 0.91321000E-01, -.13830800E-01, 0.10725400E-01, 0.29201900E-01, -.10561200E-01, -.85342800E-01, 0.18339800E-01, -.44728200E-01, 0.18588800E+00, 0.12863300E-03, -.82649000E-02, 0.59809500E-01, -.39816700E-01, 0.22144300E+00, -.17657400E-01, 0.13147100E-01, -.11361200E-02, 0.44673300E-01, -.25111500E+00, 0.52728500E-01, -.45211000E-01, -.16146100E-01, 0.31162700E-01, -.15192900E+00, 0.29810300E+00, 0.81951500E-01, 0.20326400E-01, 0.57344200E-01, 0.24500000E-01, -.12901400E+00, 0.18725600E-01, 0.32069800E-02, 0.13348100E-01, 0.26736800E-01, 0.59919100E-01, 0.10874600E+00, 0.19478500E-01, -.16802400E-01, 0.47561900E-01, 0.54755900E-01, -.10482300E+00, 0.19120600E-01, 0.60743000E-03, 0.18420900E-01, 0.87785500E-01, -.41736200E-02, 0.99713100E-01, -.25533500E-01, 0.61718100E-01, 0.19426200E-01, -.58926200E-01, 0.20913300E-01, 0.11836100E-01, 0.10381500E+00, 0.52326600E-02, -.21528700E-01, -.10246700E+00, -.86765200E-01, -.20488800E-02, -.30789100E-01, -.14177000E+00, -.22726500E-01, -.15804900E-01, 0.95921300E-02, 0.14786200E+00, 0.20877300E-01, 0.25525800E-01, -.90950600E-01, 0.48402800E-01, -.34790700E-01, 0.40707400E+00, 0.11124900E+00, 0.27035300E-01, -.83912600E-03, 0.26800400E-02, -.23206800E-01, -.62624500E-03, 0.13107900E-01, -.16288100E+00, 0.16778700E-01, -.78504800E-02, -.31827300E-01, -.51983400E-01, 0.12414600E-01, -.38455900E-01, 0.10927600E-01, 0.15898500E-02, 0.46215300E-03, 0.50010800E-01, -.80902500E-02, -.19348300E-01, 0.19448500E-01, 0.11216400E-01, -.38617300E-02, -.13979100E+00, 0.25122200E-01, -.24152700E-01, 0.32172000E-02, -.10873000E-01, -.28774800E-01, 0.33009700E-01, 0.65246300E-01, 0.49056300E-01, -.49081300E-01, 0.77466300E-02, -.16065000E-01, -.12362000E-01, 0.48996100E-02, -.33540400E-01, 0.21814600E-02, 0.10863100E-01, 0.24076900E-01, 0.16989000E-01, 0.10148800E-01, -.58025900E-02, -.39969300E-03, 0.35903400E-03, 0.27476600E-01, -.87103200E-02, 0.19510900E-01, 0.37669000E-01, -.13174700E-01, 0.48064700E-01, -.57378400E-01, 0.75595100E-01, 0.30663000E-01, -.48546800E-01, -.28618100E-01, -.16332500E+00, -.62415400E-02, -.59038900E-02, 0.45405000E-02, 0.17387400E-01, -.76049400E-02, -.59023100E-02, 0.13288200E-01, -.67014000E-02, 0.18075000E-01, 0.49359800E-01, 0.25202800E-03, 0.32356500E+00, -.10793400E+01, 0.12463300E+00, 0.43739400E+00, 0.21425600E+00, -.23812700E+00, 0.42922600E+00, 0.38565100E+00, -.43362000E+00, 0.16726500E-01, 0.87524900E-01, -.30524400E-01, 0.37186700E+00, 0.15788300E+00, 0.11928200E+00, 0.26626400E+00, 0.60839200E-01, -.24709900E+00, 0.24552100E+00, -.22850300E+00, -.96028300E-01, 0.18652700E+00, 0.19367400E-01, 0.37150100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.38244500E+01, -.31211400E+00, 0.19003200E+00, 0.85488900E+00, 0.10025200E+01, -.30554800E-01, -.34096000E+00, -.11484400E+00, 0.10260000E-01, -.59878400E+00, 0.36847500E-02, -.61817500E+00, -.69458100E+00, 0.42106400E+00, -.66473000E-01, -.48122600E+00, -.67721400E+00, -.47364300E+00, 0.94102800E+00, -.42793800E+00, -.48470100E-01, 0.15702900E+00, -.15088200E+00, -.31655200E+00, -.18749200E+00, -.41969500E+00, -.82466000E+00, 0.51396300E+00, -.35036800E-01, -.25234100E+00, 0.86724600E-01, -.63860800E+00, -.47957000E+00, -.10907500E+00, -.12258800E+00, -.16542800E+00, -.49509000E-01, 0.14503200E+00, -.26981500E-01, 0.89061500E+00, 0.37673300E+00, 0.13182400E-01, -.10528800E+01, 0.13332200E+00, -.19637300E+00, -.12015300E-01, -.11412700E+00, 0.52341600E+00, 0.78628200E-01, -.10657400E+00, 0.46521400E+00, -.96199500E-01, -.12468200E-01, -.72844600E+00, -.65835800E+00, -.18737900E+00, -.21464900E+00, 0.10434900E+00, 0.52482300E-03, 0.66789200E+00, 0.91802600E+00, 0.45528100E+00, -.52056300E-01, 0.27974400E+00, -.13849100E+00, 0.29576500E+00, 0.12693300E+00, 0.72519500E+00, -.60359900E-02, -.33012100E-02, -.37586100E+00, -.53362000E-01, 0.87192700E+00, -.27030400E+00, 0.11514300E+00, 0.40357100E+00, 0.12088100E-01, -.27764000E+00, -.24001600E-01, -.27618100E+00, 0.19606500E-01, -.81667000E-01, -.25323500E-01, -.10403500E+00, -.17049900E-01, 0.45063200E-01, 0.19203400E+00, 0.28468900E+00, 0.11427600E+00, -.12710100E+00, -.85601200E+00, -.99577500E-02, -.29294500E+00, 0.66757200E-01, 0.45765400E+00, 0.80416500E-01, -.75921300E+00, 0.23319700E+00, -.20230000E-01, 0.17305200E+00, -.11963400E+00, 0.72232100E-01, -.12491600E-01, -.14522600E-01, -.83969200E-01, -.13632200E+00, -.66443700E-01, -.36324100E-01, 0.23636000E+00, -.37969100E+00, 0.13950800E+00, -.71822400E-01, -.36500600E+00, 0.80893100E-02, 0.17465500E-01, 0.36285400E-01, 0.19818500E+00, 0.14225200E+00, -.45123200E-01, -.30848900E+00, 0.47856000E-01, -.12368100E+00, -.59602400E-02, -.84526500E-01, -.49031000E-02, -.91185400E-01, 0.13730100E+00, -.70023900E-02, -.65355200E-01, -.11183600E-01, -.34091500E+00, 0.23003800E+00, 0.16734500E+00, 0.22346800E+00, 0.99810000E-02, 0.11272300E-01, -.10380800E+00, 0.16825100E-01, -.23745100E+00, 0.65747500E-01, 0.18731400E-01, -.13272700E+00, -.64955100E-01, 0.54889600E+00, -.29220600E-01, 0.10130900E+00, 0.22492400E-01, -.26590400E-01, -.37148200E-01, -.74464300E-01, 0.62165700E-01, -.12623600E-01, -.92209500E-01, 0.31575100E-01, 0.12236200E+00, -.18356500E-01, 0.23458900E-01, -.47063300E-01, -.31666700E-01, 0.14695100E+00, 0.32109700E-01, 0.23215100E-02, -.11242600E-01, -.23098500E+00, 0.33531800E-01, 0.80609900E-01, -.12904700E-01, -.47907100E-01, -.21424400E+00, -.37351800E-02, 0.24634700E-01, -.17317000E+00, 0.37089600E-01, -.17935400E+00, -.49125100E-02, 0.28176100E+00, 0.10106100E+00, -.49987300E-01, -.12074400E-01, 0.94205000E-02, 0.36757800E+00, -.46533200E+00, -.87723500E-01, 0.60508600E-01, -.73222300E-01, 0.11718600E+00, 0.50196900E-01, 0.43838100E-01, 0.14514000E-01, -.55362400E-01, 0.48734700E-02, 0.15226800E+00, 0.60566900E+00, -.15486600E+00, -.23099000E-01, -.90363600E+00, 0.20909700E+00, -.27671500E-02, -.15966500E+00, 0.27963500E-01, -.44473700E-01, 0.19248800E-03, 0.25461600E-01, 0.51362200E-01, -.73773500E-01, -.50403800E-01, 0.25169100E-01, 0.89120000E-01, -.47182100E-01, 0.39722000E-01, -.79234700E-02, 0.17585400E-01, 0.45084800E-03, -.65739900E-01, 0.27618800E-01, 0.49293600E+00, 0.50301900E-01, 0.32410900E-01, -.20364400E-01, 0.76611300E-01, 0.73507300E-03, -.10840900E-01, 0.64796000E-01, 0.44962800E-01, 0.11889600E-02, 0.58563100E-02, -.11011500E+00, 0.38614200E-01, -.20571500E-01, 0.67012800E-02, -.51696300E-01, 0.68077700E-01, 0.59775000E-01, 0.38701600E-01, 0.16855800E-02, 0.81907800E-01, 0.33859500E-02, -.50188000E-02, -.52595900E-01, 0.53694500E-02, 0.22180000E-03, -.13718900E-01, -.53203500E-01, -.17278600E-02, 0.10010400E-01, 0.24636300E-01, 0.21563100E-01, -.35545500E-01, 0.64488700E-01, -.19334000E+00, 0.11601400E-02, 0.12037200E+00, 0.58321200E-01, 0.41790400E+00, 0.64473400E-02, 0.85966500E-02, -.10776400E-01, 0.80152900E-01, -.35587400E-01, -.28739500E-02, -.23181400E-01, -.10388400E-02, -.11509900E+00, -.11219900E+00, -.88251300E-01, -.19621600E+01, 0.58924500E+01, -.33228600E+00, 0.41129700E+01, -.28259600E+00, 0.20234000E+00, 0.35367700E+01, -.37539600E+01, 0.11074700E+01, 0.11012600E+00, -.32781700E-01, 0.45931000E+00, -.38873900E+01, -.46428100E+00, -.32587400E+00, -.11987300E+01, 0.39223000E+00, 0.20224800E+00, -.65671100E+00, 0.47761600E+00, 0.28784300E+00, 0.95504300E+00, 0.64872700E-01, -.83115800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.59288300E+01, 0.56316500E+00, 0.18932600E+00, 0.15798000E+01, 0.86522200E+00, -.16488700E+01, 0.11905400E+01, 0.15414300E+00, -.30863700E+00, 0.13919300E+01, 0.17636500E+00, 0.76413300E+00, 0.42792500E+00, -.13568600E-01, 0.64213200E-01, 0.10393100E+01, 0.13782500E+01, 0.38206900E+00, 0.16751800E+00, 0.15427300E+00, -.76278600E+00, -.28711100E+00, 0.19329600E+00, 0.93837600E+00, 0.31722000E+00, 0.21704900E+00, 0.95188900E+00, -.90965800E+00, -.81366100E+00, 0.31550000E+00, 0.88827000E-03, 0.32169000E+00, 0.56852700E+00, -.20359800E+00, 0.16463700E+00, 0.30881400E+00, 0.22141100E-01, -.74152200E-01, 0.68649000E-01, -.72344300E+00, -.33195700E-01, -.97288100E-02, -.50147400E+00, -.86680600E-01, 0.24066100E+00, -.83069400E-01, 0.39741000E+00, -.75098100E+00, 0.50201700E+00, 0.97924200E-01, -.41784500E+00, -.52116100E-01, 0.21786200E-01, 0.58769300E-01, 0.96999300E-02, 0.86111100E+00, 0.21042600E+00, -.24617900E+00, -.16517000E-02, 0.31830400E+00, -.10772700E+01, -.56947800E+00, 0.79948400E-01, -.21050100E+00, -.18846900E+00, -.39068700E+00, -.10850500E+00, -.20004700E+01, 0.26348800E-02, 0.56202600E-02, -.46283400E-02, 0.92240900E-01, -.71106100E+00, 0.44406100E-01, 0.23520200E+00, -.38404900E+00, 0.82339000E-01, 0.45994500E+00, 0.24559300E+00, 0.20069500E+00, -.24259700E-01, -.57336300E+00, 0.11274500E+00, -.24741100E-01, -.10189300E+00, 0.40249800E-01, 0.15376800E-01, -.23852800E+00, -.43563500E+00, 0.29213300E+00, 0.57130300E+00, 0.11663600E-02, 0.34313100E+00, -.12958400E+00, -.38558500E+00, -.11592700E+00, 0.31848700E+00, -.10516500E+00, 0.16716600E+00, -.23807000E+00, -.19612900E-01, 0.19162200E+00, -.32955100E-02, 0.14134100E-01, 0.11239900E+00, -.27742800E-01, -.12050800E+00, 0.36030700E-01, -.20296100E+00, 0.56603500E+00, -.34921600E-01, 0.44602000E-01, 0.29690500E+00, -.16043000E-01, -.47695800E-02, 0.43261000E-02, -.88741600E-01, -.10739200E+00, 0.39219400E-01, 0.60049100E-01, -.14284500E-01, 0.10056500E+00, 0.25439400E-01, 0.93843500E-01, -.29902400E-02, 0.88609400E-01, -.11144100E+00, 0.92886400E-02, 0.54969500E-01, -.54772300E-01, 0.30044700E-01, -.47602900E-01, 0.57388400E-01, 0.34011000E-01, 0.13706800E-01, -.21461800E-01, 0.70599500E-01, 0.88030200E-01, 0.17832000E+00, -.96083200E-01, 0.71896500E-01, -.68773600E-01, 0.88721200E-01, -.34115700E+00, -.23415300E-01, 0.13895500E+00, -.26556200E-02, 0.39724900E-01, -.13107900E-03, -.48929900E-01, 0.18413200E-01, 0.29288900E-02, 0.49188200E-01, -.40390800E-01, 0.92016600E-01, -.64042100E-02, -.70219300E-02, 0.36388800E-01, -.14200800E-01, 0.63996100E-01, -.78930300E-02, -.26668500E-01, -.29955700E-01, -.31659200E-01, 0.20677100E-02, -.30477200E-01, 0.10988600E-01, 0.28400900E-01, 0.16987300E+00, 0.15455300E+00, -.15544900E-01, 0.19436700E+00, -.22907000E-01, 0.74573200E-01, -.17337200E-01, -.38545400E-01, -.63114000E-01, 0.12533200E-01, 0.57967500E-01, -.40912400E-01, 0.47509100E-01, -.91261000E-01, -.81866100E-01, 0.32977200E-01, 0.36649900E-01, -.17923700E+00, -.66519100E-01, -.41017500E-01, 0.56936100E-02, 0.11198400E+00, -.16882800E-01, -.93581200E-01, -.11215100E+00, 0.12133800E-01, -.30537000E-01, 0.58943400E+00, 0.87862200E-01, 0.48358900E-01, 0.99367200E-01, 0.56870000E-02, -.21567800E-01, 0.90383500E-03, -.75604100E-02, -.72826900E-01, 0.30656500E-01, -.22193800E-01, -.23754300E-01, -.10472200E+00, 0.63032900E-01, -.17362800E-01, 0.15321800E-01, -.10756200E-01, 0.18506300E-02, 0.64946700E-01, 0.11100400E-01, -.25188200E+00, 0.41924100E-01, -.74094500E-01, -.52997500E-01, -.13248900E+00, -.94150600E-02, 0.13227800E-01, -.60048800E-01, -.77892400E-01, -.12045400E-01, 0.38417600E-02, 0.11454100E+00, -.60612700E-01, 0.44620600E-02, 0.54340300E-02, -.20096300E-01, -.43353700E-01, -.82189800E-02, -.15529900E+00, -.16123200E-01, 0.12039800E-01, 0.27652400E-01, 0.18306000E-01, 0.55571300E-01, 0.12096800E-01, 0.20349900E-01, -.28057500E-01, 0.30157700E+00, -.11280700E-01, -.36343500E-01, 0.13745400E+00, -.73584100E-01, 0.13496900E+00, -.16557000E-01, 0.11434000E+00, -.34390700E-01, -.32718500E-01, -.24783200E-02, -.24706700E+00, -.10018100E-01, -.21959500E-01, 0.77955300E-02, 0.25297800E-01, -.56095600E-01, -.19589300E-01, -.60048100E-02, -.35237100E-01, 0.14123600E+00, 0.16602800E+00, 0.53300700E-01, 0.16089600E+01, -.77551600E+00, 0.28475900E+00, -.61399300E-01, 0.46338400E-01, -.45696800E-01, -.92391200E-01, 0.27020300E+00, -.14793900E-01, 0.19234400E+00, -.99177400E-01, 0.34704200E-01, 0.25592300E+00, 0.22054800E-01, 0.14019400E+00, 0.63789100E-01, 0.34126300E+00, -.37093600E-01, -.12234700E-01, -.32296800E-01, 0.63757100E-01, -.12039700E+00, 0.18791200E+00, 0.23157700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.46046600E+02, -.46352400E+01, -.21809100E+01, -.12664600E+02, -.11627400E+02, 0.10569300E+02, -.52996900E+01, -.10468700E+01, 0.25848600E+01, -.98714200E+01, -.43915800E+00, -.59605200E+01, -.25953000E+01, 0.40851300E+01, -.90681900E+00, -.65281200E+01, -.12017400E+02, -.35838100E+01, -.24028400E+01, -.14989600E+01, 0.55388200E+01, 0.18571000E+01, -.20839600E+01, -.94942300E+01, -.18342300E+01, 0.34404100E+00, -.62509600E+01, -.16789200E+00, 0.69269900E+01, -.14857100E+01, -.52041700E+00, -.23776600E+01, -.45254200E+01, 0.22070100E+01, -.17693600E+01, -.95144200E+00, -.23262800E+00, 0.14867200E+01, 0.11234500E+01, -.43780100E+01, 0.74009200E+00, -.30815600E+01, 0.24344700E+01, 0.13082300E+01, -.41663200E+01, -.16543000E+00, -.25895200E+01, 0.85394300E+01, -.35609900E+01, -.14851200E+01, 0.43147800E+01, 0.32853700E+00, -.15941700E+00, -.24308900E+00, -.42631100E+01, -.70346700E+01, -.19298000E+01, 0.28918200E+01, 0.41654600E+00, -.67990400E+00, 0.94348800E+01, 0.59681700E+01, -.10835600E+01, 0.36093100E+01, 0.79671200E+00, 0.43650200E+01, 0.12261200E+01, 0.23167600E+02, -.57711500E+00, -.49097200E+00, 0.20431800E+00, -.90637900E+00, 0.92626600E+01, 0.13373000E+01, -.27268500E+01, -.49179100E+00, 0.27544500E+00, -.83079400E+00, -.33816300E+01, -.24996900E+01, 0.87912300E+00, 0.24627200E+01, -.22832400E+01, 0.43722400E+00, -.96220000E-01, -.76116800E+00, 0.26747700E+01, 0.12950500E+01, 0.12631700E+01, 0.54337400E+00, -.46948300E+01, -.21085100E+00, -.45921900E+01, 0.13598500E+01, 0.70248400E+00, 0.71204100E+00, 0.46167000E+01, -.21078200E+01, 0.73238900E+00, 0.53513300E+00, 0.27259500E+01, 0.74411900E+00, -.12216600E-01, 0.55818600E+00, -.10092800E+01, 0.28165600E+01, 0.29873800E+01, -.69208400E+00, 0.27360200E+00, -.77229300E+01, -.17057000E+01, -.10891200E+01, -.21440600E+01, -.18128900E+00, 0.59515100E+00, -.56748100E+00, 0.19966300E-01, 0.12965600E+01, -.42565600E+01, -.23449200E+00, 0.39802600E+00, -.16415600E+01, -.27864700E+00, -.21461200E+01, 0.48127800E+00, 0.13443000E+01, -.22512100E+00, 0.45208900E+00, -.16093700E+00, 0.58588400E+00, 0.31915500E+01, -.40967200E+00, -.21037300E+01, 0.82434700E+00, -.20895700E+00, 0.23004300E+00, -.13411500E+00, -.21324100E+01, 0.24715900E+01, -.15575500E+01, 0.11139800E+01, 0.16943100E+00, -.73091500E+00, 0.15284100E+00, 0.16675100E+00, -.27385300E+01, 0.57797300E-01, -.97802100E-01, 0.71986100E+00, -.45389300E+00, 0.10286400E+01, -.98916300E-01, -.21729300E+00, -.27372200E-01, -.65390500E+00, 0.86912100E-01, -.21710700E-01, 0.13341800E-01, -.15896800E+00, 0.23331200E+01, 0.37635100E+01, 0.59195600E+00, -.67890500E+00, 0.22823700E+01, 0.18459500E+01, -.17682500E+01, -.23209300E+00, -.16097600E+00, -.18493300E+01, 0.12651300E+01, -.98366800E+00, -.49782400E+00, 0.39022100E+00, -.15935400E+01, 0.92453500E+00, 0.35182900E+01, 0.12309400E+01, -.82481300E+00, 0.19805100E+01, 0.11213300E+00, 0.68137800E+01, -.35418300E+01, -.12834500E+01, 0.16856100E+01, 0.93675500E-01, 0.16209500E+01, 0.52242600E+00, -.13266800E+01, 0.49698400E+00, 0.21586400E+01, 0.23052300E+00, -.80225200E+00, 0.41656100E+01, -.32551000E+01, 0.26630900E+00, 0.30867900E+01, -.13092700E+01, 0.87219100E+00, -.21897300E-01, -.30310500E+00, -.89127300E-01, 0.16817400E-02, 0.43843500E+00, 0.26125900E+01, -.43626200E+00, 0.20601100E-01, -.67363900E+00, 0.17374800E+00, -.31246200E+00, -.10976400E+00, -.16488200E+00, 0.36575600E-01, 0.15466100E-01, 0.14470000E+01, 0.11763200E+01, 0.37809100E+01, 0.13615100E+00, 0.24925500E+01, 0.13546500E+01, -.11900200E+01, -.73534000E+00, -.17505900E-01, -.11625200E+01, -.11410000E+00, -.87120600E+00, -.88811900E-02, -.50988200E+00, 0.18716700E+01, -.21080900E+00, 0.85079400E+00, 0.98638200E+00, 0.91683900E+00, 0.40362500E+00, 0.24243100E+00, 0.99831100E-01, 0.32208500E+01, 0.12233500E+01, -.27059000E+00, -.60106900E+00, 0.74921900E+00, -.48416500E+00, 0.14944900E+01, -.90882100E+01, -.37497000E+00, 0.26014500E+01, 0.94658200E-01, -.41249600E+00, -.45503400E+01, -.12817700E+00, -.22736900E+01, 0.22978900E+01, -.73441300E+00, -.16197500E+00, 0.85203600E+01, -.73030000E-02, -.14916900E+00, -.33296300E+00, 0.29153000E+00, 0.70179000E+00, 0.52021100E-02, 0.74888900E-01, 0.72073900E+00, -.26963200E-01, -.22954100E+01, 0.36545900E+00, -.18288300E+01, 0.43585900E+01, 0.25502200E+01, -.69487000E+02, 0.78814100E+00, -.80583100E-01, -.61894200E+02, 0.38947200E+02, 0.28372000E+01, -.36895000E+01, 0.14919600E+01, -.46290700E-01, 0.41546000E+02, 0.11302900E+01, 0.10957900E+01, 0.45590100E-01, -.68365900E+01, -.10334200E+01, -.78645500E+00, -.18348900E+01, -.11738300E+01, -.19505400E+02, -.35609800E+01, -.28070300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19450600E+01, 0.15333300E+00, 0.22339100E+00, 0.15772600E+01, 0.22882600E+00, -.14506400E+01, 0.10160600E+01, -.39123300E-01, -.41438300E+00, 0.10833300E+01, 0.38866200E-01, -.15936100E+00, -.53134100E+00, 0.82327600E-01, -.27212600E-01, 0.63329700E+00, 0.13767600E-01, -.62464200E+00, 0.78368000E+00, -.35687300E+00, -.44460100E+00, -.11728900E+00, 0.29829200E-01, 0.45450700E+00, 0.22879300E-01, -.11042100E-01, 0.10348000E+00, -.50794200E+00, -.42205400E+00, 0.20937300E+00, 0.33515900E-02, -.31709900E+00, 0.33499900E+00, -.21843300E+00, 0.38718900E-01, -.55300400E-01, -.81016100E-02, 0.21637100E-01, -.55607700E-01, 0.12169700E-01, 0.33973900E-01, -.71322500E-01, -.75052400E+00, 0.50225300E-01, 0.16544400E+00, -.61669000E-01, 0.16331500E+00, -.25796600E+00, 0.25187300E+00, 0.18477300E-01, -.31423700E-01, 0.19225300E+00, 0.57842100E-01, -.18324800E+00, -.17018500E+00, 0.55280100E+00, 0.44321600E-01, 0.10822600E+00, -.11543600E-02, 0.22960800E-01, -.46028600E+00, -.79745800E-01, 0.40337500E-01, -.13013400E+00, -.81563900E-02, -.80217000E-01, 0.14213100E-02, -.50753500E+00, -.39047800E-01, 0.31330200E-02, -.55844300E-01, 0.12221100E+00, 0.72006800E-01, -.17686600E+00, 0.21884600E+00, -.67083400E-01, 0.13897600E+00, 0.56193900E-01, 0.62325400E-01, 0.42303600E-01, -.73075900E-02, -.33930700E+00, 0.15441300E-01, -.13300100E+00, -.10380600E+00, 0.77283300E-01, 0.21739800E-01, -.49348900E-01, -.40299100E+00, 0.13168900E+00, -.61342000E+00, 0.58044800E-03, -.54032400E-01, -.22058000E-03, 0.21982700E+00, -.22816300E-01, -.10057900E+00, 0.10941300E+00, 0.54319400E-01, -.72780600E-01, -.31767800E-01, -.51478800E-01, -.82564400E-02, -.17411400E-01, 0.23230200E-01, -.17328200E-01, -.28928600E-01, -.51871100E-02, 0.42033200E-01, -.29134700E+00, 0.51451900E-01, 0.19376500E-01, 0.14166600E+00, 0.33694400E-02, -.10152700E+00, 0.82082600E-02, 0.62919200E-01, -.18703400E+00, -.14917100E+00, -.10271300E+00, 0.19817700E-02, 0.64018300E-01, -.11940300E-01, -.41830100E-01, -.23470300E-02, 0.22534800E-01, 0.87657900E-01, -.25583800E-01, 0.65189100E-02, 0.46854300E-02, 0.13468500E+00, -.18028600E-01, 0.45409400E-01, -.24527900E+00, -.11043800E-01, -.14399600E-01, -.61693400E-02, 0.69653400E-01, 0.31367700E+00, -.17612500E+00, -.10984800E-01, -.14525600E-01, -.33614400E-01, -.82728100E-01, -.11057200E+00, 0.25134300E+00, 0.61151700E-02, 0.21776400E-01, 0.52357100E-01, -.31879400E+00, 0.78750100E-01, -.23576200E-01, 0.11846600E-01, -.12819000E-01, 0.44466300E-01, -.21644200E-01, 0.11421900E-02, 0.22952900E-01, -.14404800E-01, 0.48694400E-01, -.16321400E+00, -.11851000E-01, 0.14830400E+00, -.97560200E-01, 0.12601700E-01, -.14782700E-01, -.33651100E-01, 0.50025900E-01, 0.37152600E+00, -.44085600E-01, 0.46425100E-01, 0.19614700E+00, -.51619600E-02, -.12600100E-01, -.70281100E-01, -.10915300E+00, -.11898700E+00, 0.34342800E-01, -.34173800E-01, 0.33923100E-01, -.27307300E+00, 0.35778600E-01, 0.91022200E-01, 0.63859400E-01, -.72415200E-01, -.77830800E-01, 0.24629300E-01, 0.87560100E-01, -.51018500E-02, -.90256500E-01, 0.18031100E-01, 0.10196200E+00, -.68620200E-01, 0.25336000E+00, -.10119800E+00, 0.21146900E+00, 0.50044000E+00, 0.79746700E-01, -.13410300E+00, 0.27744200E-01, -.18241700E-01, -.99085400E-03, 0.15125800E-01, -.21566600E+00, -.13631200E+00, -.21163700E-01, 0.10842200E-01, -.23584500E-01, 0.44373900E-01, -.12423600E-02, 0.12547300E-01, 0.10587900E-01, -.59104100E-02, 0.62905100E-01, -.94749000E-01, 0.60008200E-03, 0.64657800E-01, -.42370400E-01, -.57855200E-01, -.13316900E+00, -.62098800E-01, -.49782500E-01, -.12408800E-01, 0.56686800E-01, -.21702800E-01, -.68617300E-02, 0.20999100E-01, -.45723100E-02, -.59283100E-02, -.11041000E+00, -.41090000E-01, -.79341100E-01, -.12314500E-01, -.87241500E-02, -.68396600E-02, -.47002100E-01, -.92185500E-02, -.80108600E-02, 0.28782100E-01, -.67481300E-02, 0.63661400E-03, -.27005600E-01, -.49482200E-01, 0.76963100E-02, 0.10499200E-01, -.96075600E-01, -.18580200E-02, -.17848600E-01, -.47798700E-01, 0.15030500E+00, 0.10474900E-01, 0.19612000E-01, -.35051700E-01, -.22910700E+00, -.17264100E-02, 0.51070100E-02, 0.89747100E-02, -.64080200E-01, -.93932700E-02, 0.80123400E-02, 0.47110300E-01, 0.47249700E-02, -.17098300E-01, 0.39155600E-01, -.12381700E-01, 0.16086500E+00, 0.11979300E+00, -.16517900E+00, 0.96004300E-03, 0.19604500E+00, -.13477000E+00, -.43922400E-01, -.11935000E+00, 0.10397200E-03, 0.10338900E+00, 0.76487100E-02, 0.53640500E-01, -.12139700E+00, 0.76453900E-01, -.51200200E-02, -.26930700E+00, 0.83631700E-01, -.89349000E-01, 0.10098300E-01, -.10149500E+00, 0.65653000E-03, -.81751000E-01, 0.10874300E+00, 0.71885300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42658600E+01, -.35839300E+00, 0.74297900E+00, -.10135700E+01, -.34527400E+00, 0.16298800E+01, -.11390600E+01, -.46881300E-01, 0.52680000E+00, -.11372400E+01, 0.21715100E+00, -.15367800E+00, 0.34338700E+00, 0.10856200E+01, -.88406500E-01, -.82026500E+00, -.50155500E+00, 0.69071600E+00, -.13684100E+00, 0.27685500E+00, 0.17898800E+00, 0.20828100E+00, -.22456500E+00, -.51076100E+00, -.12345700E+00, -.23640000E+00, -.10735000E+01, 0.66743000E+00, 0.78034500E+00, -.46327400E+00, 0.42382000E-02, 0.36869600E-01, -.45223000E+00, 0.12331500E+00, -.99610000E-01, -.46397300E+00, -.11639800E-01, 0.73311400E-01, -.12845700E-01, 0.50413200E-01, 0.96494100E-01, 0.15961600E+00, 0.22313400E+00, 0.51220800E-01, -.22699200E+00, 0.68209200E-01, -.18853200E+00, 0.56677900E+00, -.51090400E+00, -.77822600E-01, 0.27207800E+00, 0.24335500E-02, -.25540100E-02, -.28977800E+00, 0.91876600E-01, -.74329200E+00, -.13237400E+00, 0.42161100E-01, 0.13052000E-02, -.47610600E-03, 0.73848900E+00, 0.33467400E+00, -.66019400E-01, 0.22090000E+00, 0.70594200E-01, 0.38589800E+00, 0.65191700E-01, 0.17555000E+01, 0.28589800E-01, -.47901900E-02, 0.38175700E-01, -.13905000E+00, 0.64118500E+00, 0.17554900E+00, -.23025600E+00, 0.15786700E+00, -.70860500E-01, -.24124100E+00, -.19627000E+00, -.17164300E+00, 0.14880800E-01, 0.35698800E+00, -.12013000E+00, -.19063500E-01, 0.67066800E-01, -.50178000E-01, 0.19084900E+00, 0.21206000E+00, 0.24870200E+00, -.11816300E+00, -.30805800E+00, -.27899000E-02, -.19573300E+00, 0.99396000E-01, 0.17732500E+00, 0.42229600E-01, -.20840700E+00, 0.28005900E-01, -.10542300E+00, 0.18675600E+00, -.66124500E-01, -.10372800E+00, 0.61324500E-03, -.10690300E-01, -.11449700E+00, 0.50839700E-02, 0.98130800E-01, -.31969200E-01, 0.18814500E+00, -.42901000E+00, 0.28483100E-01, -.22912300E-01, -.25862100E+00, 0.12120100E-01, 0.20472000E-01, 0.15218500E-02, 0.57208200E-01, 0.16002500E+00, -.93646300E-01, -.35218400E-01, 0.15127300E-01, -.10764000E+00, -.19991300E-01, -.90680400E-01, 0.75742900E-03, -.72079300E-01, 0.56462100E-01, -.12064200E-02, -.33970700E-01, 0.35065100E-01, -.95848600E-01, 0.53906100E-01, -.37242800E-01, -.26098800E-01, 0.11445200E-01, 0.15855900E-01, -.21411900E-01, -.13373700E-01, -.24674800E+00, 0.10000500E+00, -.26161900E-01, 0.45009100E-01, -.38977900E-01, 0.24934900E+00, 0.14909000E-01, -.13343600E+00, 0.77133100E-02, -.27676000E-01, -.11716400E-01, 0.51953200E-01, 0.19861900E-01, 0.16998100E-01, -.13096900E-01, 0.21923200E-01, -.92230700E-01, 0.43002600E-02, 0.84039900E-02, -.43187000E-01, 0.22615000E-01, 0.72637700E-01, -.45757100E-01, 0.11348000E-01, -.42967200E-01, 0.64997900E-01, -.29822700E-01, 0.30227000E-01, 0.38198200E-01, -.29259200E-01, -.16514800E+00, -.25040700E-01, -.34440400E-01, -.10261500E+00, 0.46491000E-01, -.27785400E-01, 0.27840200E-01, 0.20162000E+00, 0.30387700E-01, -.35574400E-01, -.19788500E-01, 0.17194800E-01, 0.47067800E-01, -.12460600E-01, 0.10672900E-01, -.45673900E-01, 0.20873300E-01, 0.14497700E+00, 0.53030000E-01, 0.16719100E-02, 0.50096200E-03, -.75865300E-01, 0.28024900E-02, -.68608600E-01, 0.80109400E-01, -.11410400E+00, 0.51798800E-01, -.13655100E+00, -.25964200E+00, -.49379900E-01, 0.64871700E-01, -.17719500E-01, 0.49238000E-01, 0.27356800E-03, -.61125300E-03, 0.40258900E+00, 0.48514800E-01, 0.52560500E-02, -.26045900E-01, 0.46142200E-01, -.25207900E-01, 0.76431600E-02, -.57950400E-02, -.54122700E-03, 0.26904500E-02, -.41996300E-01, 0.61728800E-01, 0.12388500E+00, -.77755000E-01, 0.52361700E-01, 0.82387500E-01, 0.12729800E+00, 0.71528300E-01, 0.35762900E-01, 0.59772500E-01, 0.39472200E-02, 0.35751700E-01, 0.13015600E-01, -.38659200E-01, 0.63264800E-01, 0.35416500E-02, 0.55016300E-01, 0.55673000E-01, 0.35421100E-01, 0.38071900E-01, -.35842000E-01, -.94328400E-02, 0.88316700E-01, 0.64247300E-01, -.25351800E-01, -.39555900E-01, -.29636600E-03, -.32953300E-01, 0.14346100E-01, -.13472700E+00, 0.28553900E-02, 0.58644700E-01, -.14624900E+00, 0.52440400E-01, -.62150500E-01, 0.16474900E-01, -.13173900E+00, 0.46579100E-01, 0.32721700E-01, 0.64571400E-03, 0.30178300E+00, 0.43790200E-02, 0.35462400E-02, -.11136800E-01, 0.45557600E-01, 0.73511300E-02, 0.19280400E-01, 0.12456600E-01, 0.27496600E-01, -.19782100E-01, -.44243700E-01, 0.37302900E-02, -.77045700E+00, 0.40842200E-01, -.31043200E-01, -.50369200E-03, -.77720000E+00, 0.16653100E+00, -.17180700E-01, 0.79855300E-01, 0.27295100E-01, -.63008500E-02, -.27706700E-01, -.16956700E-01, 0.72323600E-01, -.34831100E-01, -.17673200E-01, -.28326300E+00, -.28504700E-01, -.12399200E-01, -.11381600E+00, 0.42746400E-01, 0.11109100E-01, 0.11012900E-01, -.10825900E-01, -.14579800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16325700E+01, 0.52425600E-01, -.49123000E+00, 0.10702400E+01, 0.34714700E+00, -.26643200E+00, 0.91919700E-01, 0.10791500E+00, -.31851600E-01, 0.39839900E+00, 0.22797500E+00, 0.25154000E+00, 0.70117700E+00, 0.96891900E+00, 0.14298300E+00, 0.23013200E+00, 0.98170700E+00, 0.11109000E+01, -.27386000E+00, 0.24215900E+00, -.64987300E+00, -.12228500E+00, -.30753600E-01, 0.39087200E+00, 0.95896800E-01, 0.15290200E+00, -.56132300E-01, -.53312600E+00, 0.21477400E+00, -.21664500E+00, -.92137200E-02, 0.37390200E-01, 0.16090100E-01, 0.21621700E+00, -.76227000E-01, 0.23347400E+00, 0.11662300E-01, 0.13781000E+00, -.61541200E-01, -.14343000E+00, -.84902000E-01, 0.10104500E+00, 0.53361500E+00, -.98680900E-01, 0.56933700E-01, -.31303100E-01, 0.20074500E+00, -.48873200E+00, 0.68960900E-01, 0.62183100E-01, -.24478800E+00, -.14528700E+00, -.77614800E-01, -.66311400E-01, 0.82693900E-01, 0.22692300E+00, 0.13013000E+00, -.10296200E+00, -.27014300E-02, 0.16505100E+00, -.26948600E+00, -.23786000E+00, 0.38540900E-01, -.11188900E+00, 0.32876500E-01, -.34424400E+00, 0.42377500E-02, -.38988400E+00, 0.74429200E-02, 0.65709900E-02, 0.11537000E+00, -.85750000E-01, -.50020100E+00, 0.26296000E+00, -.12869800E+00, 0.25722100E-01, -.77654700E-01, 0.13850600E+00, 0.28568300E-01, 0.16857400E+00, -.23456700E-01, 0.73934500E-01, -.48219300E-01, 0.10059600E+00, 0.49202500E-01, -.14347600E-01, -.18021300E+00, -.17640000E+00, -.21737400E+00, 0.91963800E-01, 0.83517700E+00, 0.13147900E-01, 0.33894800E-01, 0.51515500E-01, -.23233400E+00, -.58551900E-01, 0.61206200E+00, -.10252400E+00, -.54729900E-01, -.16334800E+00, 0.24719700E+00, 0.56790000E-01, 0.90728700E-02, -.11109100E+00, 0.13056200E+00, 0.10843100E+00, -.57743800E-01, 0.21450500E-01, -.24209800E+00, 0.69069500E+00, -.46077100E-01, 0.23622300E-01, 0.77607700E-02, -.90068700E-02, 0.53380600E-01, -.11960700E-01, -.18277000E-01, -.43619400E-01, -.19964100E+00, 0.70698900E-01, -.51005700E-01, -.19705100E-01, 0.21440500E-01, -.69653500E-02, -.29838600E-02, 0.71719300E-01, -.17273300E-01, 0.31613100E-01, -.83667600E-02, 0.10521000E-01, 0.57866000E-01, -.90535000E-01, 0.24803900E-02, -.20502000E-01, 0.14664700E-01, -.14423300E-01, 0.10838000E+00, 0.71533600E-02, 0.19515800E+00, -.35820700E-02, -.17129800E-01, -.23331400E-01, 0.15093200E-02, 0.12231200E+00, -.28776400E-02, 0.70722300E-01, 0.12179200E-01, 0.34139700E-03, 0.71115900E-01, 0.28865400E-01, -.73288800E-01, -.89421300E-02, -.38490100E-02, -.20845600E-01, 0.72762700E-02, -.16320500E-01, -.35881100E-02, -.11892900E-01, -.46289600E-01, -.16516200E-01, 0.45166400E-02, -.96700200E-02, -.21918100E-01, 0.32510000E-03, -.68223600E-02, 0.27280500E-01, 0.98950300E-02, -.33259000E-02, -.28105600E-01, -.81165500E-02, -.57667700E-02, -.45950400E-02, -.93420800E-02, 0.49057400E-01, -.82043300E-02, -.10067500E+00, -.41628700E-01, 0.13257500E-01, -.69491200E-02, 0.51227400E-02, -.19769900E+00, 0.10866100E-01, -.66357100E-02, -.16173100E-01, 0.21786900E-01, -.87623100E-02, -.20303400E-01, 0.54967400E-02, 0.38292600E-02, 0.84125700E-01, 0.49875700E-03, -.29751900E-02, -.23985600E-01, -.38870100E-02, -.47584000E-02, -.99368500E-01, -.11369700E+00, -.12270600E-01, 0.85153000E-02, 0.58988200E-02, -.90130600E-02, 0.16482000E-03, -.52482600E-02, -.13819700E+00, 0.40216000E-01, 0.37274600E-02, 0.16988400E-01, -.98345400E-02, 0.35941500E-03, -.13496800E-01, -.35452800E-02, -.91406700E-02, 0.17663000E-02, -.31079800E-01, 0.23130400E-02, -.18518900E+00, -.20316200E-01, -.62649200E-01, -.31851800E-01, 0.72604600E-02, 0.48714100E-01, 0.25728100E-01, -.58149200E-02, 0.54155000E-02, -.82704100E-02, -.64742800E-02, 0.85238200E-02, -.19496300E-01, -.21803400E-02, -.54970300E-02, -.84587700E-02, 0.97292500E-03, 0.13301000E-02, 0.22585100E-02, -.11909400E-02, -.13073700E-01, -.74784300E-02, 0.12354500E-02, -.33804900E-04, -.82812200E-02, 0.26630000E-02, -.33070700E-02, 0.36838200E-01, 0.60871100E-03, -.59497700E-02, -.73519400E-02, -.45688400E-03, 0.92418200E-02, -.31689500E-02, 0.15301800E-01, -.77552800E-02, -.34233700E-01, -.91200600E-02, -.74236700E-01, -.17419000E-02, -.91608700E-03, 0.25471600E-02, 0.18029900E-02, -.39915400E-03, 0.28702300E-03, 0.31171900E-02, -.25559000E-03, 0.18295900E-01, 0.11711600E-01, 0.56607500E-03, 0.10197300E+00, -.50893800E-01, -.95378600E-03, -.36166900E-02, -.87347000E-01, -.58513500E-01, 0.14398500E+00, -.28882600E-02, -.14896300E-01, -.51352400E-01, 0.15456000E-01, -.36125300E-01, -.45458700E-02, -.54605100E-02, 0.39131900E-02, -.33646100E-01, -.38854700E-01, -.25551100E-03, 0.16457000E-02, 0.21883900E-03, -.18512300E-01, 0.13159900E+00, -.51037600E-01, 0.14617500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.59983200E+02, -.65076400E+01, -.84991200E+01, -.16780500E+02, -.13489800E+02, 0.15047500E+02, -.76411900E+01, -.12448900E+01, 0.54411600E+01, -.15363500E+02, 0.34916500E+01, -.11622700E+02, -.45238300E+01, 0.10926600E+02, -.20526700E+01, -.92129400E+01, -.11814900E+02, 0.29399100E+01, -.36416100E+01, -.22095800E+00, 0.66863800E+01, 0.25028200E+01, -.23382600E+01, -.92998300E+01, -.19021600E+01, 0.26785200E+00, -.67093100E+01, 0.69589400E+01, 0.86010300E+01, -.25928900E+01, 0.10216100E+00, -.27822900E+01, -.80167000E+01, 0.43021600E+01, -.27980100E+01, -.39104700E+00, -.42887300E+00, 0.17703400E+01, -.43611100E+00, 0.12377300E+01, 0.15274900E+01, 0.10844400E+01, -.81639600E+01, 0.14251300E+01, 0.83663700E+00, 0.41446300E+00, -.36380700E+01, 0.86594000E+01, -.40396800E+01, -.11365400E+01, 0.24689100E+01, -.11421200E+01, 0.22355500E+01, 0.43358400E+01, -.17178900E+01, -.14509100E+02, -.33099900E+01, 0.34998600E+01, -.11599500E-01, -.62864000E+01, 0.21536600E+02, 0.90139300E+01, -.83745500E+00, 0.68658400E+01, 0.58782900E+01, 0.32491000E+01, 0.35093900E+01, 0.34930300E+02, -.87502600E+00, -.44281300E-01, 0.26190800E+00, -.38718800E+01, 0.60045900E+01, -.28906000E+01, 0.15584800E+01, 0.31008500E+01, -.17086400E+01, -.46500100E+01, -.52881600E+01, -.42505500E+01, 0.43822400E+00, 0.31423100E+01, -.20232400E+01, 0.15292700E+01, 0.18721900E+01, -.41115800E+00, 0.13219800E+01, 0.33484500E+01, 0.76803800E+00, -.22018200E+01, -.83705500E+01, 0.32654300E-01, -.61742000E+01, 0.35257400E+01, 0.31951100E+01, 0.28607800E+01, -.17490800E+01, 0.64731600E+00, -.28631300E+01, 0.30452600E+01, 0.22412100E+01, 0.55715000E+00, 0.15053900E+00, 0.43091300E+00, -.19970700E+01, 0.29386500E+01, 0.40977400E+01, -.12909500E+01, 0.21099000E+01, -.10007000E+02, -.98822700E-01, -.43708700E+00, -.42036400E+01, 0.16589500E+00, -.10423000E+01, -.33881200E+00, 0.59211800E+00, -.88120200E+00, -.66384600E+01, 0.15112400E+01, 0.25600500E+00, 0.72665800E+00, -.60094200E+00, -.12993200E+01, 0.22430900E+00, -.10526300E+01, 0.18381100E+01, -.37316700E+00, -.40372300E+00, 0.10915000E+01, 0.49237900E+01, -.47584500E+01, 0.33902500E+00, -.48365100E+01, 0.97537700E-01, 0.12635800E+00, 0.59640800E+00, -.20985200E+01, 0.15195000E+01, -.11279300E+01, 0.13871300E+01, 0.12076000E+01, 0.65527400E+00, 0.27501600E+01, -.54684500E-01, -.19268200E+01, 0.40181300E-01, 0.40979200E-01, 0.23249400E+01, 0.12305500E+01, -.16242800E+01, -.45352900E+00, 0.25006700E+00, 0.47677100E+00, -.34341100E+00, -.23736000E+00, -.24006400E-01, 0.18382900E-01, 0.66691600E+00, 0.63399700E+00, 0.79440900E-01, 0.87533900E-01, -.74962200E+00, 0.67351500E+00, -.40319100E+00, 0.70706000E+00, -.39233900E+00, -.24162000E+00, -.25536800E+01, -.31989000E+00, -.27396700E+00, -.10936500E+01, 0.68556000E+00, -.12055500E+01, 0.15096500E+01, 0.48864500E+01, 0.24520100E+01, -.52592300E+00, -.42500300E+00, -.27798400E+00, 0.83092200E+01, -.88731100E+00, -.13992900E+01, 0.69430600E-01, 0.12683700E+00, 0.13740000E+01, -.62639000E-01, -.16424600E+01, 0.28468900E+00, 0.28971000E+00, -.34464300E-01, 0.35796400E+00, 0.10885900E+01, -.12546800E+00, 0.61624600E+00, 0.17236200E+01, 0.23442000E+00, 0.22993800E+00, 0.48898100E+00, -.42236900E+00, 0.12817400E+00, -.54339600E-02, 0.25914200E+00, -.12382600E+01, -.65905900E+00, -.22575100E+00, -.31523100E-01, -.26066400E+00, -.41024200E+00, -.20118200E+00, -.24863600E+00, 0.28838200E+00, 0.38099400E-01, -.42583900E+00, 0.72111500E+00, 0.45172100E+01, 0.68545900E+00, 0.68471700E+00, 0.38136700E+00, -.22137300E+01, -.24018900E+01, -.16825100E+01, -.37453500E+00, -.15967100E+01, -.64264100E+00, -.11750300E+01, -.27465100E+01, -.24100200E+01, 0.70788200E+00, 0.55796200E+00, 0.13074700E+01, 0.37687400E+00, -.41134500E+00, 0.30647000E+01, 0.32123000E+00, -.32365600E+01, -.12361800E+01, -.80102100E+00, -.11808700E+00, -.48557400E+00, -.72510000E+00, 0.61173100E+00, -.68288500E+01, 0.98478000E-01, -.34329300E+00, -.55071100E+01, 0.37354200E+00, -.21658100E+01, -.42780200E+00, 0.36833300E+00, 0.85202400E+00, 0.21209000E+01, -.59064400E+00, 0.48065300E+01, 0.16556400E+00, 0.42586500E+00, 0.10109600E+00, -.26095500E+01, 0.12795600E+01, 0.50373600E+00, 0.92035000E+00, 0.76343500E+00, -.13228600E+01, -.12379100E+01, 0.37967200E+00, 0.50834500E+01, -.65482600E+00, -.44327600E+01, 0.50343200E+00, 0.20764800E+02, -.42472300E+01, -.27144200E+02, -.46754000E+02, 0.16177500E+00, 0.53882500E+01, -.58699200E-01, 0.19003800E+01, -.47481800E+02, 0.16152100E+01, -.23478200E+00, 0.96334800E+01, 0.47012000E+01, -.46100400E+00, 0.12353100E+01, 0.71785600E+00, -.15201300E+00, -.10208100E+02, 0.48055900E+01, -.98008300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20713800E+01, -.16137000E+00, 0.17241900E+01, 0.20913900E+00, 0.53666700E+00, 0.67253100E+00, -.75870400E+00, -.52677000E-01, 0.38641200E-01, 0.24713100E-01, 0.32199100E-01, 0.31962300E+00, 0.51821400E+00, 0.14564500E+01, 0.12214600E+00, -.51269000E+00, 0.53338600E+00, 0.99170900E+00, 0.62048100E+00, 0.21793300E+00, -.80861600E+00, 0.10868900E+00, -.19471900E+00, 0.71182900E+00, -.10055900E+00, -.27864800E+00, -.15376300E+01, -.79383300E+00, 0.38761500E+00, -.19606400E+00, -.63850400E-02, 0.24174500E-01, 0.24370900E+00, -.11301200E+00, 0.21822500E-01, -.18863200E+00, -.35276900E-01, 0.10659600E+00, -.65160900E-01, -.45872400E-01, 0.97791900E-01, -.12431800E-01, 0.89242000E+00, 0.19482100E-01, -.51510000E+00, -.29261800E-01, -.20257600E-01, 0.48569800E+00, 0.85919700E-01, -.39016800E-01, 0.50693500E+00, 0.40750900E-02, -.23961800E-01, -.11713700E+00, -.37786800E-01, -.17020300E+00, -.96000800E-01, 0.20171000E+00, 0.30001900E-02, -.41696800E+00, 0.58719600E+00, 0.24573100E+00, -.42298000E-01, -.77331900E-01, -.15026100E+00, -.24268300E-02, 0.91198000E-03, 0.80073500E+00, 0.59158400E-02, -.30560400E-02, 0.22412300E+00, -.39694800E-01, 0.48349600E+00, 0.13693500E+00, -.34970300E-01, 0.15741100E+00, -.42828200E-01, -.13933700E+00, -.74339600E-01, -.23082100E+00, 0.17851900E-01, 0.11182300E+00, -.40428400E-01, 0.14777300E+00, 0.26776200E-01, -.15554300E-01, -.85663300E-02, 0.30725200E-01, 0.20012700E+00, -.74089300E-01, -.90967400E+00, -.68107500E-03, -.12892800E+00, 0.34590500E-01, 0.43528400E+00, 0.46032900E-01, -.11955600E+00, 0.34409600E-01, -.46609100E-01, 0.92600800E-01, 0.74968800E-01, -.26311400E+00, 0.87377700E-02, 0.29776700E-01, -.61720300E-01, -.42177900E-01, 0.10340700E+00, 0.13129000E+00, 0.17722900E+00, -.20037900E+00, -.23758900E-01, 0.84819600E-02, 0.66768000E-01, 0.96032700E-02, -.20439200E-01, -.31886300E-01, -.91707800E-01, -.45726500E-01, 0.60909300E-01, -.40177900E-01, -.43267300E-01, 0.74089000E-03, -.29394100E-01, -.46995600E-01, 0.83546800E-02, -.48714100E-01, 0.25374500E-01, -.11033900E-02, -.24100900E-01, 0.51325600E-01, 0.96498500E-01, 0.70455500E-01, -.23119700E+00, -.12502700E+00, -.91594100E-02, 0.10335300E-01, -.12466300E+00, -.71407500E-01, -.27811800E+00, -.45012700E-01, 0.24838200E-01, 0.35582400E-01, -.10336200E+00, -.48366500E-01, 0.20952300E-01, -.28558300E+00, -.35959000E-02, -.45347900E-01, 0.15566400E+00, -.79517600E-01, -.17170700E+00, 0.28799700E-01, -.45403100E-02, -.80845200E-02, -.93971600E-01, 0.19039100E-01, -.27866300E-01, -.19916300E-01, 0.14311100E-01, -.20964100E-01, 0.20280900E+00, 0.15901600E-01, -.73396800E-01, -.21005200E+00, 0.92558500E-01, 0.17024300E-02, 0.48574600E-01, -.22194500E-01, -.13797700E+00, 0.14323000E-01, 0.88165600E-02, -.12512200E-01, 0.45587700E-01, -.60546100E-01, 0.39277800E-01, -.12258200E+00, -.44917200E-01, 0.12885100E-01, 0.10543200E+00, 0.93655500E-02, 0.98260100E-01, 0.16488500E+00, -.35360600E-01, 0.11733900E+00, -.89337700E-01, 0.47173300E-01, 0.59422300E-02, -.19323200E-01, 0.10539600E-01, -.13998000E+00, -.38304300E-02, 0.89800300E-02, -.41830900E-01, 0.42004400E-01, 0.40523400E-01, 0.42701900E+00, 0.19731000E+00, -.13261900E-01, 0.12865400E-01, -.38425500E-02, 0.27218500E-02, 0.91104100E-03, -.19185400E-02, 0.31792500E-01, 0.51125000E-01, -.21488300E-01, -.20226400E-01, 0.40223300E-01, -.39526300E-01, 0.14114700E-01, -.76251900E-02, 0.36145900E-02, 0.57693800E-02, -.31891500E-01, -.11274300E-01, 0.10400200E+00, -.25950400E-01, 0.17991000E-01, 0.60166800E-01, 0.39911800E-01, -.87893800E-01, 0.15434200E-01, -.60127200E-01, 0.51790500E-01, -.10808100E-01, -.52242200E-01, -.51048500E-01, -.56762500E-01, 0.78413000E-01, 0.60164700E-01, 0.33520600E-01, 0.25545700E-02, -.15249500E-01, 0.23868200E-01, 0.14878200E-01, -.11047100E-01, -.48680600E-01, -.20015800E-01, -.42956600E-01, 0.99242100E-02, 0.47453400E-01, 0.47076500E-01, -.55958400E-01, -.12356600E-01, -.36710600E-01, 0.12117800E+00, 0.41660900E-01, 0.55654500E-01, 0.84465600E-01, -.15772500E+00, -.64934800E-01, 0.10588200E+00, 0.46104400E-01, 0.57514900E-01, 0.73779600E-02, 0.43302200E-03, -.90256700E-02, 0.32751500E-01, -.24364600E-01, 0.24308900E-01, -.26198900E-01, 0.70953800E-02, 0.15768400E-01, 0.20647600E-01, -.17459900E-01, -.90427600E+00, 0.18031000E+00, -.11592300E+00, -.92227200E-02, -.18952200E+00, 0.96196400E-01, 0.13223200E+00, -.41520600E-02, 0.22850200E+00, -.23506700E-01, 0.49724000E-01, 0.53007400E-01, 0.24718100E-02, -.17044600E-01, -.30857800E-01, -.50799500E-01, -.45298400E-01, 0.37983900E-01, -.12555600E+00, 0.77298800E-02, 0.21162100E-02, 0.55402400E-01, -.18252100E-01, -.16794000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33348500E+02, 0.34907500E+01, 0.25424700E+01, 0.74377300E+01, 0.49022100E+01, -.80931600E+01, 0.50033100E+01, 0.68591000E+00, -.21305400E+01, 0.69290300E+01, -.12759200E+01, 0.58517100E+01, 0.33900800E+01, -.38015500E+01, 0.45941300E+01, 0.28209400E+01, 0.57147100E+01, 0.33766900E+01, 0.10256000E+01, 0.10648300E+01, -.32031100E+01, -.12040600E+01, 0.55615400E+00, 0.50760500E+01, 0.13854200E+01, 0.19470700E+01, 0.85668500E+00, -.25973200E+01, -.49013100E+00, -.11830600E+00, 0.14326900E+00, 0.20492100E+01, 0.96542600E-01, -.26626600E+01, 0.16536000E+01, 0.17719600E+01, 0.19346600E+00, -.16737200E+01, 0.28877300E+01, -.23113800E+01, -.65560700E+00, -.18998500E+01, 0.11198800E+02, -.81398200E+00, -.40744400E+00, -.33104700E+00, 0.83769500E+00, -.40522200E+01, 0.15949700E+01, 0.12624600E-01, -.26657100E+01, -.18029200E+01, -.28560800E+01, 0.32097200E+01, 0.25948500E+01, 0.21520100E+01, 0.14850300E+01, -.84789800E+00, 0.18885000E-02, -.62999500E+01, -.47147700E+01, -.45147300E+01, 0.36457100E+00, -.24063400E+01, -.50184200E+00, -.11809200E+01, -.18529800E+01, -.11572300E+02, 0.92308900E-01, 0.39130800E-01, 0.17014200E+01, 0.12998000E+01, -.10478200E+02, 0.14005600E+01, -.93866500E+00, -.13773100E+01, -.10659200E+00, 0.25488900E+01, 0.55327000E+00, 0.12002600E+01, -.74438500E-01, 0.28099100E+01, 0.27583400E+00, 0.10523700E+01, 0.77137700E+00, 0.32881600E+00, -.21181400E+01, -.19275900E+01, -.96548900E+00, 0.10846700E+00, 0.10718300E+02, -.60666000E-02, 0.25568800E+00, -.25109400E+00, -.44379000E+01, 0.12174500E+00, 0.57407900E+01, -.29543800E-01, 0.33774200E+00, -.75649600E+00, 0.18179000E+01, 0.65118800E+00, -.42499700E-01, -.99557000E+00, 0.21648000E+01, 0.11179200E+01, -.19731000E+01, -.27946300E+00, -.27326000E+01, 0.18049800E+01, -.12741900E+01, 0.11272900E+01, 0.15037200E+01, -.13454600E+00, 0.11616000E+01, -.26814900E+00, -.71272400E+00, 0.35514800E+00, 0.12863000E+00, 0.14787600E+01, -.35591300E+00, -.14641000E+01, 0.31772100E+00, -.44781500E+00, -.99180300E-01, 0.15436500E+01, -.33728200E+01, 0.71937900E+00, 0.23470300E+00, 0.15984300E+00, 0.95488000E+00, -.35530100E+01, 0.23022000E+01, 0.17830900E+01, 0.29337900E+00, 0.41513800E-01, -.92842200E+00, 0.16795100E+01, -.35077300E+00, 0.45020700E+00, 0.79887300E+00, -.11363100E+01, -.93632800E+00, 0.14872300E+01, -.74190700E+00, 0.24304500E+01, 0.95155500E-01, 0.12017200E+00, 0.67069800E+00, -.35537100E+01, -.41644000E+00, -.20230900E+00, -.55763900E+00, -.47779700E+00, 0.46808600E+00, -.43157400E+00, -.13350200E+00, 0.30088300E+00, -.80621900E+00, -.81661800E+00, -.17456900E+01, -.17294100E-01, 0.21236000E+00, 0.26898000E+01, -.13418100E-01, 0.52150800E+00, -.76749000E-01, 0.94970000E-01, 0.38775500E+00, -.15265000E+01, -.52153200E+00, -.26548700E+00, -.63436700E+00, 0.16037100E+01, -.47522600E+00, -.41965400E+01, -.79469200E+00, 0.38200500E+00, -.64270000E+00, -.22096600E-01, -.35749800E+01, 0.44196000E+01, 0.16330000E+01, -.54474400E+00, -.75841900E+00, -.32515600E+00, -.46236900E+00, 0.54138000E+00, -.73044500E-01, 0.21763800E+00, -.28895300E+00, 0.47466600E+00, -.15766100E+01, 0.91965300E+00, -.12875800E+00, 0.15325600E+01, 0.14119000E+01, 0.32452500E-01, 0.37939800E+00, -.50891100E-02, -.32882300E+00, 0.65654300E-02, -.33924900E+00, -.50274300E+01, 0.41773200E+00, -.58844200E-01, 0.43396700E+00, -.55029600E+00, 0.37952500E+00, -.29868000E+00, -.12505500E+00, -.22190000E+00, 0.18525000E-01, -.52851400E+00, 0.34345700E+00, -.31852000E+01, -.58993000E+00, -.11877600E+01, -.43995700E+00, -.18332400E+00, -.13644200E-01, 0.81551000E-01, -.13112700E+00, -.10218400E+00, -.59109700E-01, -.30322000E+00, -.70258300E-01, -.84519700E+00, 0.21632800E+00, -.16698200E+00, -.35885800E+00, -.21928900E+00, 0.11291700E+00, -.15366300E+00, 0.18399700E+00, -.12281400E+01, -.24866900E+00, 0.30158300E-01, -.20053100E+00, -.46288300E+00, -.75021800E+00, -.13877900E+00, 0.33274500E+01, -.45953600E+00, -.62176000E+00, -.74395700E+00, 0.13154700E+00, 0.18354500E+01, 0.24965000E+00, 0.55329700E+00, -.11014300E+01, -.42048100E+00, -.63461800E-01, -.50354300E+01, -.39920400E-01, -.11976000E-01, 0.10025200E+00, 0.10883600E+00, -.10819800E+00, -.74923000E-01, -.12513200E-01, -.13000300E+00, -.21542800E+00, -.13605800E+00, 0.13111600E+00, -.78863600E-01, -.16959200E+01, -.13921500E+01, -.22492800E+00, -.32165900E+01, -.24757600E+01, 0.14281300E+02, 0.14886900E+00, 0.80331100E-01, -.22005700E+01, 0.33972400E-01, -.83351700E+00, 0.23296900E+00, -.57643500E+00, 0.35311000E-01, -.37524400E+01, -.16674500E+01, 0.36754800E+00, -.69622700E+00, -.13845600E+00, 0.46199700E-01, 0.82476500E+01, -.18697300E+01, 0.26773900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16112000E+02, 0.19307800E+01, -.52873400E+01, 0.12140000E+01, 0.32079500E+01, -.30080900E+01, 0.10599000E+01, 0.27618200E+00, -.80503000E+00, 0.46246300E+00, 0.80228200E-01, 0.71673400E+00, 0.21435400E-02, -.72512900E+01, -.33089200E+00, 0.20310400E+01, 0.13460800E+00, -.44680700E+01, -.28500100E+00, -.92576500E+00, 0.11029600E+01, -.73203500E+00, 0.95101200E+00, 0.24653000E+00, 0.57446600E+00, 0.12438300E+01, 0.32431200E+01, 0.16450600E+01, -.29147700E+01, 0.13691100E+01, 0.10242000E+00, -.26680900E+00, 0.57402100E+00, 0.12744300E+01, -.11198900E+00, -.86082700E+00, 0.79599600E-01, -.43870100E+00, -.12918400E+01, 0.69835500E+00, -.83429000E+00, 0.86477700E+00, -.37980000E+01, -.18318200E-01, 0.23303300E+01, -.28699900E-01, 0.62832900E+00, -.16610400E+01, -.35664600E+00, -.43958600E-01, -.26966500E+01, 0.12363300E+01, 0.17728200E+00, 0.56458500E+00, 0.17710000E+00, 0.29695200E+01, 0.41589500E+00, -.16640100E+01, -.34719100E-02, 0.19994700E+01, -.36182800E+01, -.15701800E+01, 0.16956300E+00, -.13238900E+01, -.19476100E+01, 0.93557700E+00, -.10060500E+01, -.80035700E+01, 0.45666200E+00, 0.17011300E-01, -.13053400E+01, 0.90258900E+00, -.17812700E+01, -.29196900E+00, 0.61585900E+00, -.24924800E+01, 0.73794600E+00, 0.13846700E+01, 0.71278200E+00, 0.95799300E+00, -.92102200E-01, -.30410100E+01, 0.60160300E+00, -.43963400E+00, -.68565000E+00, 0.29390600E+00, -.11701100E+00, -.99421600E+00, -.15682800E+01, 0.96893400E+00, 0.23183700E+01, -.11104100E-01, 0.79555500E+00, -.28327500E+00, -.15514400E+01, -.51211300E+00, 0.52103600E+00, -.70264800E-01, 0.60782300E+00, -.72891800E+00, -.42320500E+00, 0.96868000E+00, -.60988200E-01, -.18538800E+00, 0.15085000E+00, 0.45264400E-02, -.53797400E-01, -.27310000E+00, -.99760500E+00, 0.58276800E+00, -.77942800E+00, -.13095800E+00, 0.79338100E+00, -.54589500E-01, 0.17725900E+00, 0.73726100E-02, 0.22223300E+00, 0.12572600E-01, -.63752200E+00, 0.72681700E+00, 0.21354200E+00, 0.64103500E-01, 0.17888200E+00, 0.51710900E-02, -.66517800E-03, 0.38003400E+00, -.92838400E+00, 0.17912800E+00, 0.25893400E+00, -.70666700E-01, 0.11094900E+01, -.76302100E+00, -.70630400E-01, -.37140900E+00, 0.21901300E-01, -.67162700E-01, 0.96256700E+00, -.33088500E+00, 0.19781700E+01, -.32306800E+00, 0.24926900E+00, 0.22002700E+00, 0.64223200E+00, -.77132500E+00, 0.55888100E-01, -.20091800E+00, -.26138900E-01, 0.71871400E-01, -.34861300E+00, -.83446500E+00, 0.65792600E+00, -.21666400E+00, -.27651100E+00, -.48117000E-01, -.41198500E-01, 0.23308700E-01, -.34363700E-01, 0.13510500E+00, -.12054700E+00, -.69802800E-01, 0.73978900E+00, -.30697100E-01, 0.29365900E+00, -.52585000E+00, -.61483400E+00, 0.20109300E+00, 0.12646700E-01, 0.13087500E+00, 0.23334100E+00, -.17139700E+00, 0.26127100E-01, -.21577800E+00, 0.35774800E-01, 0.19318400E-01, -.26026400E+00, 0.99014300E+00, -.22401000E+00, -.82689300E-01, -.44476800E-01, -.22013200E+00, 0.19996100E+01, 0.81182400E+00, 0.73945100E+00, -.21661900E+00, -.30363400E+00, -.53342400E+00, 0.10051300E+00, 0.34106200E+00, -.95670300E-01, -.23018200E+01, -.23765400E+00, 0.12031300E+01, -.21114200E+00, -.55891400E+00, 0.27972300E+00, 0.23537900E+01, 0.55175000E+00, 0.42811300E+00, 0.22656300E-01, 0.86996800E-01, -.61481700E-01, 0.13707200E-01, -.25013500E+00, -.64457900E+00, -.52335400E+00, -.92341300E-02, -.42505700E-01, -.26077600E+00, 0.54292800E+00, -.17040900E+00, 0.78095200E-01, -.24607200E-01, 0.76233100E-01, -.18465600E+00, -.21737500E+00, 0.17700000E+01, 0.19833300E+00, -.46287900E+00, -.39771900E-02, -.14634800E+00, 0.99687300E-01, 0.33774200E-01, 0.30923100E+00, -.67269800E+00, 0.30126800E+00, 0.12534600E+00, 0.71706900E-01, -.31452100E+00, -.20003700E+00, -.93791300E+00, -.32629000E+00, -.17968000E+00, 0.13620800E+00, -.41835400E+00, -.62705900E-01, -.15315600E+00, 0.14474300E+00, 0.10479700E+00, 0.40971300E+00, -.27910600E-01, 0.12038800E-02, -.26037800E+00, 0.11773200E+01, 0.14006700E+00, -.10939100E+00, -.16414300E+00, -.35187900E+00, -.14182800E+00, -.35946600E+00, 0.12588500E+01, -.76258400E-01, -.20803900E+00, -.19347700E+00, -.18604300E+01, -.57729700E-01, -.11140100E+00, 0.42621000E-01, -.27792200E+00, -.12611800E+00, -.12049800E+00, -.19714400E+00, -.27495200E+00, 0.15033000E+01, 0.15704000E+01, -.24447600E+00, -.24619100E+00, -.22708600E+01, 0.92957900E+00, -.12392500E-01, 0.36807600E+00, 0.10035100E+01, -.14030700E+01, 0.28614400E-01, 0.40842000E+00, -.22224500E+00, -.21139900E+01, -.59486400E+00, 0.76926000E-02, -.47710200E+00, 0.82021600E-01, -.11721400E+01, 0.36773500E+00, 0.29059900E+00, -.21205300E+00, 0.19311100E-01, 0.53744900E+00, 0.20722900E+01, 0.12956400E+00, 0.15658200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.43406300E+02, 0.44464600E+01, 0.43375400E+01, 0.13125800E+02, 0.98653500E+01, -.10978500E+02, 0.59381500E+01, 0.10574600E+01, -.29413300E+01, 0.11115600E+02, -.56438200E+00, 0.74651100E+01, 0.37858800E+01, -.43677600E+01, 0.15715600E+01, 0.60739700E+01, 0.73531800E+01, -.88188100E+00, 0.30302500E+01, -.42463800E+00, -.60592400E+01, -.21698200E+01, 0.10932700E+01, 0.62921800E+01, 0.13850200E+01, 0.10655400E+01, 0.29570300E+01, -.68781400E+01, -.64475300E+01, 0.40235400E+01, -.29689300E+00, 0.14522600E+01, 0.82360800E+01, -.33490600E+01, 0.19873100E+01, -.29165900E+01, 0.23439800E+00, -.15154300E+01, -.54845000E+00, -.29190400E+01, -.19213800E+01, -.27602900E+01, 0.76184200E+01, -.13118100E+01, -.24600500E+01, -.15743900E+01, 0.86090300E+00, -.62845200E+01, 0.40979100E+01, 0.82724900E+00, 0.23886700E+01, -.61995300E+00, -.10224100E+01, 0.32708700E+01, 0.23652700E+01, 0.11367300E+02, 0.20842100E+01, -.37921200E+01, 0.29071500E-01, 0.18504500E+01, -.13815000E+02, -.65009400E+01, 0.62799200E+00, -.33067400E+01, -.59777400E+01, -.17291100E+01, -.17639900E+01, -.18239500E+02, 0.19143100E+00, 0.18775500E-01, 0.26162300E+00, 0.14045000E+01, -.35085700E+01, -.35000700E+00, 0.54908700E+01, -.38851600E+01, 0.48492800E+00, 0.36531600E+01, 0.29176800E+01, 0.19102100E+01, -.14430000E+00, -.26072900E+01, 0.27484600E+01, -.91422700E+00, -.13145900E+01, -.10195200E+00, -.76932400E+00, -.47217400E+00, -.52782100E+01, 0.35049400E+01, -.16048000E+01, 0.47990700E-01, 0.18985200E+01, -.10576300E+01, 0.10023800E+01, -.40425600E-01, -.64722100E+01, 0.22170400E+01, 0.73502200E+00, 0.12169800E+01, -.32513900E+01, 0.10128000E+01, -.87986800E-02, 0.19751800E+00, 0.38831500E+00, -.59451500E+00, -.16728500E+01, -.40800500E+00, -.91649800E+00, 0.43935700E+01, -.84833000E+00, 0.42407200E+00, 0.17978900E+01, -.89603700E-02, 0.30859500E+00, -.12435800E+00, -.20164400E+01, 0.75592100E+00, 0.74992000E+01, -.17631000E+01, 0.18851300E+00, -.12088700E+01, 0.24788600E+00, 0.11928500E+01, 0.39508100E+00, -.10038400E+01, -.10511400E+01, -.59476900E+00, 0.74731100E+00, -.41699200E+00, 0.12315200E+01, -.17360400E+01, 0.44465100E+00, 0.49593600E+00, -.34085600E+00, 0.12022700E+00, -.14609600E+01, 0.14172600E+01, -.43484200E+01, 0.51477100E+00, -.24315400E+00, -.49152600E+00, -.88772700E+00, -.50241400E+01, 0.44720500E+00, 0.52581500E+00, -.34555200E+00, -.13721100E+00, 0.85971700E-01, -.20117900E+01, -.67995700E+00, 0.87576000E+00, 0.71836900E+00, -.75679900E-01, -.22884600E+01, 0.31317500E+00, -.27374200E+00, 0.45974900E+00, 0.30454600E+00, -.14990600E+01, -.51238200E+00, 0.51519400E+00, -.48560200E+00, 0.15688200E+01, 0.15163000E+00, -.10892100E+01, -.12790900E+00, 0.54595000E+00, 0.36493500E+01, 0.17588000E+00, 0.46167600E+00, 0.21551100E+01, -.58856200E+00, -.48551600E+00, 0.40719200E+00, -.50914000E+01, -.19317800E+00, 0.65196100E+00, 0.77108500E-01, -.56072900E-01, -.20297500E+01, 0.11891400E+01, 0.18082600E+00, 0.59735200E+00, -.13725100E+01, -.94203200E+00, -.30905800E+00, 0.61378500E-01, 0.99754400E-01, 0.22434000E+01, -.32781600E+00, -.14577800E+01, -.11399500E+01, 0.19754000E+01, -.90891500E+00, 0.82140700E+01, 0.68097100E+01, 0.51241900E+00, 0.84278000E+00, -.17798400E+00, -.27339300E+00, 0.11868900E-01, -.75073800E-01, -.22240200E+01, 0.98079600E+00, -.52677900E+00, -.33465100E-01, -.12147100E+01, 0.17900200E+00, 0.59921400E+00, -.10585100E+00, 0.87013600E-01, -.18935600E-01, 0.95186600E+00, 0.22334200E+01, -.50497600E+01, -.13806500E-01, 0.77503800E+00, 0.13857900E+00, -.16536500E+01, 0.64650400E-01, 0.50452300E+00, 0.69014500E-02, -.19940000E+01, 0.30233300E+00, 0.50105400E+00, 0.11704900E+01, -.13274900E+01, 0.79347100E+00, 0.14583500E+01, 0.49083600E+00, -.41074700E+00, 0.15495600E-01, 0.57799800E+00, 0.22677200E+00, -.26515300E+01, -.20404300E+00, -.41905500E+00, 0.16223700E+00, -.77139200E+00, -.10910800E+01, -.26781300E+00, 0.41813600E+01, 0.22371700E+00, -.14405700E+01, -.54939000E+01, 0.10744300E+01, 0.11117400E+00, 0.23765100E+01, -.43953400E+01, -.85941600E+00, 0.18819100E+01, 0.63499700E+00, 0.21364100E+01, 0.20366100E+00, 0.28431500E+00, -.12727100E+00, -.72406800E+00, 0.85166500E+00, 0.59424000E+00, 0.82349300E-01, 0.79287800E+00, -.12229000E+01, -.26450300E+01, 0.92604400E+00, 0.23966900E+01, -.18712100E+00, -.83819600E+00, 0.11897100E+00, -.69459800E+01, 0.13177100E+01, 0.27211700E+01, 0.62831800E-01, -.98772000E+00, 0.11172900E+01, 0.37658500E+00, -.80308300E+01, -.55966000E+00, 0.10562500E+01, -.13431800E+00, 0.11993100E+01, -.38420900E+00, -.78075100E+00, 0.80315900E+00, -.23867000E+00, -.36150800E+01, -.97594700E+01, -.46730800E+00, 0.47358100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16588100E+01, 0.60119500E-01, 0.23249600E+01, -.52087000E+00, -.16569400E+00, 0.37019300E+00, 0.13069200E+00, 0.44841700E-03, 0.28286600E+00, -.10032200E-01, -.85620200E+00, 0.87746900E+00, -.27048800E+00, -.18245800E+00, 0.56991800E-01, -.23178000E+00, -.38742600E+00, -.34676000E+00, 0.29312300E+00, -.14489800E+00, 0.69325100E-01, 0.51628900E-01, -.47181200E-01, -.95604700E-01, 0.19040700E-01, 0.63378100E-01, -.75969200E-01, 0.93486700E+00, -.12847700E+00, 0.67590100E-02, 0.56824400E-01, 0.18338100E+00, -.99304500E-01, -.96147800E-01, -.22219700E-02, -.16185600E+00, -.26623900E-02, -.67867500E-01, 0.32080500E-01, -.18933400E+00, -.36673300E-01, -.53371900E-01, -.29040700E+00, 0.39895500E-01, -.93352100E-01, -.29089300E-01, -.98788400E-01, 0.20036700E+00, 0.20346000E-01, -.11040100E-01, 0.28713500E+00, -.28841200E-01, 0.44236900E-01, 0.13136200E+00, 0.56363100E-01, -.20567400E+00, -.63179800E-01, 0.10920000E+00, -.12473100E-02, -.34939700E+00, 0.13307400E+00, 0.14584600E+00, -.17318700E-01, 0.12560500E+00, 0.17835800E+00, 0.87748500E-01, 0.69834900E-01, -.13972800E+00, -.27571600E-03, 0.10327100E-02, 0.93171400E-02, -.18295000E-01, 0.26909400E+00, 0.45385000E-01, -.47015900E-01, -.15823300E+00, 0.45392900E-01, -.31730200E-02, -.47289100E-01, -.76502600E-01, -.90494100E-04, -.54565400E-01, -.35165400E-02, -.31636600E-01, -.48333800E-01, 0.12372000E-01, -.14230600E-01, 0.57593400E-01, 0.21175700E-01, -.41820900E-01, -.28060300E+00, 0.12529100E-02, 0.62684800E-02, -.22910500E-01, -.61336600E-01, 0.29983600E-01, -.15481600E+00, 0.43331000E-01, -.14010300E-01, 0.53962600E-01, -.43189700E-01, -.70435900E-01, -.25713500E-02, 0.18916800E-01, -.64554000E-01, 0.11664100E-01, 0.14293100E-01, -.66318700E-02, -.20663500E-01, -.40036100E-01, -.13430900E-02, -.92821700E-02, -.85412900E-02, -.35796600E-02, 0.47000800E-02, -.58735200E-02, -.21303300E-01, 0.22930500E-01, 0.50592300E-01, 0.11762700E-01, -.12912000E-01, -.65377700E-02, -.45480100E-02, 0.24187900E-01, 0.30113300E-02, 0.33329100E-02, 0.17474600E-01, 0.51948800E-02, 0.36993700E-02, 0.85036400E-03, 0.48916900E-01, -.37577900E-01, -.16034000E-01, 0.78305400E-01, 0.13374700E-01, -.41881600E-02, 0.15190100E-01, -.75098400E-01, 0.11619700E+00, 0.10326000E-02, 0.28242700E-01, -.93809500E-02, -.27271400E-01, -.20762900E-01, 0.32531000E-01, 0.43908500E-02, -.46299500E-02, -.18026700E-02, -.31041200E-02, 0.21023800E-01, -.11979800E-01, 0.34787100E-02, 0.57574500E-02, 0.17090700E-02, -.46031300E-02, 0.22068500E-02, -.31243000E-02, 0.56477300E-02, 0.76956900E-02, 0.57609800E-02, 0.47020000E-01, 0.29380300E-02, -.10493400E-01, -.16797700E-01, -.99184800E-02, 0.11734100E-02, -.57166700E-02, 0.35567900E-02, -.80688600E-02, -.12721000E-01, 0.74993000E-02, -.21652900E-02, -.35828800E-02, 0.11104000E-01, 0.13404400E-02, -.37359100E-01, -.12841300E-01, 0.10031700E-01, 0.92986300E-02, -.83701500E-02, -.75116000E-03, 0.48044700E-01, 0.27121000E-01, 0.35140600E-01, 0.94448100E-02, 0.18211100E-01, 0.95354400E-02, -.79850100E-03, 0.46640300E-03, 0.80392100E-02, -.41551700E-02, -.84016000E-02, -.14551500E-01, 0.13372600E-01, -.34473300E-02, 0.10345600E-01, 0.11730500E-01, 0.51970800E-02, 0.11955900E-02, -.11347100E-02, 0.25375000E-02, -.43000000E-04, 0.14663100E-02, -.12929500E-01, -.44645300E-02, 0.48181300E-02, -.11122100E-02, -.64033200E-02, 0.82250300E-03, -.40540700E-02, -.54213900E-03, 0.12935000E-03, -.39665200E-04, 0.59549800E-02, 0.52085200E-02, 0.25816200E-01, -.73557200E-03, -.32815500E-02, 0.45992300E-02, -.18100200E-01, -.68237400E-02, -.33034500E-02, 0.12254700E-02, -.97253700E-02, -.35540900E-03, 0.29768400E-02, 0.17585200E-02, 0.58504200E-03, -.43274600E-02, -.10961400E-02, 0.12164300E-02, -.28603900E-02, 0.21985000E-02, 0.51713200E-02, -.69637900E-02, -.67571500E-02, 0.52713700E-02, 0.32523900E-02, -.56040000E-02, -.64570200E-02, -.11290600E-02, 0.17449500E-03, -.25704300E-01, 0.16738600E-02, 0.53714800E-02, -.14546400E-02, 0.66599900E-02, 0.16914000E-02, -.16207900E-01, 0.18651900E-01, 0.84205400E-02, -.63019300E-02, -.61470900E-02, -.32096900E-01, -.22363400E-03, 0.14673100E-02, 0.34212000E-03, -.13782100E-01, 0.75727700E-02, -.12086200E-03, 0.19027500E-02, 0.77847800E-03, -.57290200E-02, -.35652500E-02, -.23157700E-02, 0.62617700E-02, 0.83752000E-02, -.49014100E-01, -.32673300E-03, 0.67149100E-01, -.16138000E-01, -.51112000E-01, 0.96230700E-03, -.10392900E-01, -.55685300E-03, -.24989400E-02, 0.94223200E-03, 0.13087500E+00, -.24314700E-02, -.21441300E-02, 0.21813800E-01, -.19333700E-02, -.12213100E-02, 0.22191300E-02, 0.29929300E-02, 0.35702400E-02, 0.16728500E-01, -.10793700E-02, -.25813900E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.38001300E+01, 0.35121000E+00, -.93996600E+00, 0.94440800E+00, 0.52239700E+00, -.11430300E+01, 0.47493600E+00, -.99231600E-02, -.52244400E+00, 0.72613800E+00, 0.75014400E-01, -.63253600E-02, -.31178700E+00, -.14872700E+01, -.48758100E-01, 0.59167800E+00, 0.10453900E-01, -.10831700E+01, 0.23740600E+00, -.31662100E+00, 0.43440700E-01, -.15353500E+00, 0.20398800E+00, 0.30506200E+00, 0.10717900E+00, 0.26087700E+00, 0.77594100E+00, -.12439800E+00, -.66505600E+00, 0.32459900E+00, -.13413100E-01, 0.53935700E-01, 0.16348900E+00, -.40159200E-01, 0.32624600E-01, -.44725700E-01, 0.23965700E-01, -.77996100E-01, -.79729600E-01, 0.79613500E-02, -.15705600E+00, 0.25158600E-01, -.39936700E+00, -.35796400E-01, 0.41525100E+00, -.30681000E-01, 0.15358000E+00, -.58583200E+00, 0.20873800E+00, 0.25616300E-01, -.30716800E+00, 0.12792100E+00, -.10999600E-02, -.55931700E-01, -.22792000E-01, 0.87613500E+00, 0.11048900E+00, -.24885600E+00, -.85436000E-03, 0.48033000E+00, -.90180800E+00, -.20679800E+00, 0.50026300E-01, -.16038400E+00, -.35098200E+00, -.28488700E-01, -.72836400E-01, -.13434400E+01, -.35373800E-01, 0.44102400E-02, -.15426500E+00, 0.14540700E+00, -.38712100E+00, -.17134200E-01, 0.28091500E+00, -.37624200E+00, 0.12582900E+00, 0.36026100E+00, 0.92986900E-01, 0.20819200E+00, -.19709500E-01, -.56312300E+00, 0.66859300E-01, -.32503600E-01, -.16535600E+00, 0.16891500E-01, 0.52146200E-01, -.21282100E+00, -.47360600E+00, 0.38070500E+00, 0.23369300E+00, 0.69024500E-03, 0.22804500E+00, -.62590400E-01, -.16671300E+00, -.39720100E-01, 0.12298500E+00, -.98288300E-02, 0.10344600E+00, -.15878700E+00, -.68173000E-03, 0.83050400E-01, -.41162900E-02, -.25699200E-01, 0.62243800E-01, -.92663900E-02, -.84477100E-01, 0.24687000E-01, -.10997900E+00, 0.27488300E+00, 0.11250000E-01, 0.28379900E-02, 0.18173500E+00, -.87850600E-02, -.32859300E-01, 0.17250300E-01, 0.14829600E-01, -.20676400E-01, 0.86427500E-02, -.11351500E+00, 0.13955200E-01, 0.33483100E-01, 0.58433800E-02, 0.36983700E-03, -.49783600E-03, 0.63291700E-01, -.23715300E-01, 0.17436900E-01, 0.29098100E-01, -.18276900E-01, 0.72222200E-01, -.15448100E-01, 0.19593300E-01, 0.11890800E-01, 0.21357100E-01, -.12748300E-01, 0.33402400E-01, 0.48828000E-01, 0.14038000E+00, -.30929300E-01, 0.14323300E-01, -.51517700E-01, 0.45258600E-01, -.15936900E+00, -.12878000E-01, 0.18262400E+00, -.68601900E-02, 0.23003100E-01, -.95472200E-01, -.89174700E-01, 0.83484400E-01, -.15081300E-01, -.19229200E-01, -.14466400E-01, 0.29584900E-01, -.85063100E-02, 0.14376300E-02, 0.27726300E-01, -.40051100E-01, -.83107000E-03, -.66389900E-01, -.12172600E-01, 0.83870800E-01, 0.37275800E-01, -.27261100E-01, 0.17446900E-01, -.13372500E-01, 0.36858400E-01, 0.21355700E+00, -.48548400E-01, 0.37800700E-02, 0.58191700E-01, -.56671500E-01, 0.69224900E-01, -.82984500E-01, -.20916500E+00, -.92156400E-01, 0.20361800E-01, -.18655500E-01, -.30901200E-02, -.20177000E+00, -.93694900E-01, -.89667000E-03, -.10697500E-01, 0.71775000E-02, -.12349200E+00, -.27379500E-01, 0.53494500E-01, -.31080900E-03, 0.16288500E+00, 0.74801300E-02, 0.70581500E-01, 0.12206500E-01, 0.92433100E-01, -.91947900E-01, 0.32846900E+00, 0.31625700E+00, 0.92636000E-01, -.23495700E-01, 0.37827500E-01, -.98595700E-01, -.54634400E-03, -.12902900E-02, -.57453400E+00, -.34686900E-02, 0.25880400E-01, 0.79608100E-02, -.74685900E-01, 0.81972100E-01, -.41145300E-01, 0.33670300E-02, -.23040100E-01, -.47112700E-02, 0.30283800E-01, -.19979700E-01, -.12998800E+00, 0.11614900E-01, -.18658700E+00, -.92089400E-01, -.11225900E+00, -.44563000E-01, -.13449800E-01, -.14996000E-01, 0.14987700E-01, -.19366000E-01, -.11165000E-01, 0.41454900E-01, -.48646400E-01, -.92279800E-02, -.21585600E-01, -.83716300E-02, -.46681300E-01, -.12326000E-01, -.80879800E-01, -.24800800E-01, -.35410800E-01, -.74886800E-02, 0.78453200E-02, 0.28978400E-01, -.41235500E-02, 0.32384600E-01, -.33709600E-01, 0.16273600E+00, 0.77014500E-02, -.15058700E-01, 0.53171400E-01, -.40448600E-01, 0.57712900E-01, -.63672100E-01, 0.23036100E+00, -.17022700E-01, -.48032200E-01, -.42125600E-01, -.50155300E+00, -.82710800E-02, -.50356600E-02, 0.18271800E-01, -.73399900E-01, -.60290300E-02, -.11625400E-01, 0.30066600E-01, -.17830300E-01, 0.67753800E-01, 0.10266700E+00, 0.17360100E-01, 0.10663100E+01, -.40256500E+00, 0.11031300E+00, -.69246700E-02, 0.46200100E+00, -.13200000E+00, 0.14120000E+00, -.73032700E-02, -.95513700E-01, -.40972800E-01, -.95245600E-02, -.47751200E-03, 0.74320800E-01, 0.11573600E+00, 0.38705100E-01, 0.33062200E-01, 0.54780700E-01, -.23042200E-01, 0.20838700E-01, -.29940700E-01, 0.30342200E-01, 0.31200100E+00, 0.21606100E-01, -.95494500E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.60178800E+01, 0.54323300E+00, -.43553500E+00, 0.12525600E+01, 0.86995100E+00, -.15168300E+01, 0.10012600E+01, 0.14441400E+00, -.36517900E+00, 0.13727000E+01, 0.29005300E-01, 0.67685700E+00, 0.20308400E+00, -.48347400E+00, 0.12084500E+00, 0.98338700E+00, 0.11725700E+01, 0.40772000E-01, 0.15836400E+00, -.28994200E-01, -.51214000E+00, -.25703000E+00, 0.20541100E+00, 0.72135700E+00, 0.23484500E+00, 0.20450200E+00, 0.97388000E+00, -.72456300E+00, -.74412300E+00, 0.30485500E+00, -.96037100E-02, 0.19520600E+00, 0.76539000E+00, -.12719600E+00, 0.15839100E+00, 0.84168900E-01, 0.23470300E-01, -.11086400E+00, 0.46212100E-02, -.26382400E+00, -.87972000E-01, 0.36210900E-01, -.12197000E+00, -.99444800E-01, 0.26523200E+00, -.42317300E-01, 0.28030300E+00, -.63415100E+00, 0.45267900E+00, 0.99108300E-01, -.37315000E+00, -.73353900E-01, -.15751000E-01, 0.36952200E-01, 0.63124700E-01, 0.87071000E+00, 0.20749800E+00, -.28030900E+00, -.10046800E-02, 0.31895400E+00, -.10973900E+01, -.54766500E+00, 0.57258200E-01, -.24301900E+00, -.28750600E+00, -.36100000E+00, -.13459300E+00, -.20086700E+01, 0.21912800E-01, 0.52308200E-02, -.53011500E-03, 0.11168000E+00, -.73010000E+00, 0.11825900E+00, 0.19962900E+00, -.44507000E+00, 0.90038700E-01, 0.49125200E+00, 0.23676700E+00, 0.22644900E+00, -.24699000E-01, -.55106800E+00, 0.11212700E+00, 0.12654600E-01, -.11741500E+00, 0.39279400E-01, -.87023500E-01, -.32930100E+00, -.39094800E+00, 0.28538900E+00, 0.55031000E+00, 0.23671200E-02, 0.33279900E+00, -.13236600E+00, -.41281200E+00, -.10816200E+00, 0.37227200E+00, -.97645600E-01, 0.17291400E+00, -.24909100E+00, -.24704700E-03, 0.19128000E+00, -.24885300E-02, 0.15164200E-01, 0.11336400E+00, -.19433600E-01, -.90797300E-01, 0.41570500E-01, -.22548700E+00, 0.60962100E+00, -.61833800E-01, 0.53939800E-01, 0.34801800E+00, -.16786800E-01, -.23918900E-02, -.48805400E-02, -.11391600E+00, -.12161900E+00, 0.43324100E-01, 0.90292600E-01, -.32600800E-01, 0.11138000E+00, 0.20428300E-01, 0.86884000E-01, -.81537000E-03, 0.99484600E-01, -.12973300E+00, 0.20196200E-01, 0.58246600E-01, -.49442400E-01, 0.19719200E+00, -.12728100E+00, -.91241600E-02, -.81478200E-02, 0.69427600E-02, -.22066300E-01, 0.77252900E-01, 0.33866500E-01, 0.24211500E+00, -.12468200E+00, 0.88438400E-01, -.53262600E-01, 0.10029700E+00, -.41310900E+00, -.64140500E-02, 0.50222800E-01, -.39944900E-02, 0.39831100E-01, -.83363600E-02, -.50736300E-01, -.86260200E-02, -.73210000E-02, 0.29327900E-01, -.50805400E-01, 0.71985100E-01, -.79264000E-02, -.11477600E-01, 0.39410700E-01, -.18825400E-01, 0.27307600E-01, 0.58459700E-02, -.25174800E-01, -.46963800E-01, -.60682000E-01, 0.32994300E-01, -.94201500E-02, 0.19827900E-01, 0.26715200E-01, 0.15693300E+00, 0.13703000E+00, -.11212000E-01, 0.19848300E+00, -.33823900E-01, 0.72172900E-01, -.54229900E-01, -.18496200E+00, -.61770700E-01, 0.17965200E-01, 0.52141700E-01, -.43797800E-01, 0.44595600E-01, -.30269000E-01, -.50774200E-01, 0.33299100E-01, 0.31190600E-01, -.20021700E+00, -.75113600E-01, -.18994100E-01, 0.49334200E-02, 0.12792700E+00, -.17040700E-01, -.12349600E+00, -.13028100E+00, -.43862500E-02, -.26004500E-01, 0.49542500E+00, 0.39831200E-01, 0.71393200E-02, 0.99860800E-01, 0.49574500E-02, -.58626000E-02, 0.11463700E-02, -.15237700E-01, 0.66478400E-01, 0.29581500E-01, -.14124700E-01, -.22847500E-01, -.75497600E-01, 0.47989900E-01, -.92614200E-02, 0.19148200E-01, -.13567900E-01, 0.19884800E-02, 0.70005700E-01, -.27886600E-01, -.16296600E+00, 0.35125600E-01, -.66977800E-01, -.38666900E-01, -.75890600E-01, -.14341300E-01, 0.23313400E-01, -.57438500E-01, -.44124700E-01, -.60396500E-02, 0.31120300E-02, 0.11252800E+00, -.53806000E-01, 0.10750400E-01, 0.91491700E-02, -.24978900E-01, -.49429400E-01, -.12641900E-01, -.16948800E+00, -.18339300E-01, -.55800700E-02, 0.25899100E-01, 0.16932200E-01, 0.60943500E-01, 0.97223100E-02, 0.28420500E-01, -.35849500E-01, 0.38297100E+00, -.12774800E-01, -.47935700E-01, 0.11535500E+00, -.96191200E-01, 0.12905600E+00, 0.46121400E-02, 0.96483400E-01, -.47108300E-01, -.33808300E-01, 0.70043700E-02, -.20292200E+00, -.12126500E-01, -.23454500E-01, 0.78893400E-02, 0.25998300E-01, -.60087000E-01, -.21475100E-01, -.10610500E-01, -.36560700E-01, 0.14554800E+00, 0.15892200E+00, 0.55860800E-01, 0.16992900E+01, -.80031000E+00, 0.53820000E+00, 0.47781400E-02, 0.25490400E+00, -.64441100E-01, -.14124800E+00, 0.18505300E-02, -.11863900E+00, -.34137100E-01, 0.20481400E-01, -.21255400E-03, 0.16121400E-01, 0.14453000E+00, 0.84889400E-01, -.49240400E-01, 0.70181500E-01, -.12884600E-01, -.28465700E-01, -.46584100E-02, 0.48369700E-02, 0.16976600E+00, 0.54272400E-02, 0.73641000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20461000E+02, 0.19703200E+01, -.11953600E+02, -.40216700E+01, 0.19154500E+01, -.23865200E+01, 0.13105600E+01, 0.51085300E+00, -.12550600E+01, -.17030100E+01, -.13344900E+01, 0.11568400E+00, -.12785500E+00, -.14014800E+02, -.31790900E+00, 0.14788700E+01, 0.46876400E-01, -.76643000E+01, -.34970600E+01, -.91593600E+00, 0.49087100E+01, -.68864200E+00, 0.13563100E+01, -.26542100E+01, 0.52015400E+00, 0.22045100E+01, 0.58542900E+01, -.10970500E+01, -.24657600E+01, 0.18765800E+01, -.41126300E+00, 0.52424500E+00, 0.86916100E+00, 0.21432300E+01, -.39645100E+00, -.31953400E+00, 0.17983600E+00, -.62100500E+00, -.74756600E+00, 0.22420000E+01, -.15012300E+01, 0.63140300E+00, 0.21047300E+01, -.36222200E+00, 0.22067800E+01, 0.18765300E+00, 0.15618900E+01, -.37118600E+01, -.14807900E+01, -.87386000E-01, -.32870700E+01, 0.14714100E+01, 0.32501600E+00, 0.36743800E+01, 0.10533700E+01, 0.57710000E+01, 0.74797400E+00, -.41713200E+01, 0.11030000E-01, 0.62043500E+01, -.88961900E+01, -.11202000E+01, 0.46973200E+00, -.21848500E+01, -.48679400E+01, 0.31104800E+01, -.11377800E+01, -.45474000E+01, 0.20384300E+00, 0.13850700E-01, -.34984000E+00, 0.90948600E+00, 0.10853400E+01, 0.30955100E+01, 0.42568600E+00, -.55887400E+01, 0.47906300E+00, 0.31995500E+01, -.43373800E+00, 0.17967700E+01, -.19566900E+00, -.38016600E+01, 0.11983800E+01, 0.24534600E+00, -.13870600E+01, -.61476000E+00, 0.71728600E+00, -.13068100E+01, -.20829800E+01, 0.23846200E+01, 0.63220400E+01, 0.73581500E-01, 0.27057200E+01, -.84528100E+00, -.30271200E+01, -.27511700E+00, 0.11026700E+01, -.62956700E+00, -.27811700E+00, -.80370900E+00, -.48378300E+00, -.10821300E+01, -.12003600E-01, -.73091100E+00, 0.32058900E+00, -.50554100E+00, -.19039700E+01, 0.45109300E+00, -.32414900E+00, 0.82811800E+00, 0.96284200E+00, -.21192100E+00, 0.20667400E+00, 0.52141600E-01, 0.99830300E-01, 0.32692700E+00, 0.19505400E+00, 0.14618300E+01, -.18106500E+00, -.22185700E+00, 0.45499400E+00, -.31583100E+00, 0.15068400E+00, -.23178800E+00, -.14274200E+00, 0.21995500E+00, -.45324000E+00, 0.19500000E+00, -.28194300E-01, 0.79907100E-01, -.16998000E+01, 0.13510600E+01, -.13018100E+00, 0.14892600E+01, 0.49499400E-01, -.15760700E-01, -.96002500E-01, -.20920500E+00, -.80175200E+00, 0.51902700E+00, 0.47315700E+00, -.28807200E+00, 0.39583300E+00, 0.10694800E+01, 0.25626700E+00, 0.33656900E+00, 0.14623400E+00, 0.52195000E-01, -.12012100E+01, -.31278200E+00, 0.10616200E+01, -.29406400E-01, -.43747200E+00, 0.41057600E-01, 0.57936400E+00, 0.87126300E-01, 0.26725600E+00, -.20294400E+00, -.47803700E+00, 0.48173900E+00, -.20579600E+00, -.90411400E-02, 0.37147300E+00, 0.18888300E+01, -.15646600E+00, 0.50274100E-01, -.50311700E-01, -.25152600E+00, -.12946800E+01, 0.22119200E-01, -.35849100E+00, -.94053000E+00, -.53175200E+00, 0.51676700E+00, 0.27800200E+00, 0.72613900E+00, 0.12299200E+01, -.17174600E+00, -.24657200E+00, 0.21723400E+00, -.12795900E+00, -.43369800E+01, -.14656400E+01, -.31697000E+00, -.23528700E-01, 0.20598500E+00, -.60990300E+00, -.73190200E+00, 0.27995300E+00, 0.48659800E+01, 0.33487800E+00, -.58493900E+00, 0.26600700E+01, -.16514900E+01, -.47568100E+00, 0.24997300E+01, -.48515400E+00, 0.68314400E+00, 0.38005600E+00, 0.10302600E+00, -.12416100E+01, -.13371400E-01, 0.25517000E+00, -.66006200E+01, 0.98148400E+00, 0.80201000E+00, 0.12877500E+00, 0.29794000E+00, -.10330900E+01, -.45763700E-01, -.10668800E+00, 0.10783000E+00, -.14906500E-01, 0.37081200E+00, 0.64921300E+00, 0.18660100E+00, 0.45919500E+00, 0.51419500E+00, -.40860700E+00, -.44201000E+00, -.68164900E-01, 0.15372900E+00, -.65893700E-01, -.43660400E+00, -.28732700E+00, -.25589200E-01, 0.13271800E+00, -.23728400E+00, -.12154100E+00, 0.12923700E+01, 0.46946700E-01, 0.67064500E+00, 0.87989800E-01, -.19884600E+00, 0.22541300E-01, 0.82744000E-01, -.28773500E+00, 0.26046800E+00, -.41667100E+00, -.38660300E-02, 0.65838100E+00, 0.11418500E+00, 0.22592100E+01, -.15182400E+00, -.48060000E+00, 0.27814400E+01, -.12308800E+00, 0.15634000E+01, 0.48886500E+00, -.10853700E+01, -.56757700E+00, -.33928200E+00, 0.42572900E+00, 0.16448200E+00, -.86980100E-02, -.88145400E-01, 0.64197400E-02, 0.72464000E+00, 0.11899300E+00, -.49146300E+00, -.10804200E+01, -.44171800E+00, 0.48142900E+00, -.17660500E+00, 0.87024600E-01, 0.65530400E+01, -.12035200E+01, 0.31927000E+01, -.62388900E-01, -.29118300E+00, 0.10445100E+01, 0.65320200E+01, -.11585400E+00, -.84362800E+00, 0.74173300E-01, -.16839500E+00, -.12912600E-02, 0.12716700E+01, 0.17970400E+01, 0.25244200E+01, 0.77909400E+01, -.28397000E+00, 0.26609500E+00, 0.10898600E+01, 0.67204300E-01, -.33346700E-01, -.15773600E+01, -.59681700E-01, -.90440800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.72701300E+01, -.75198400E+00, -.68462500E+00, -.19525600E+01, -.15040600E+01, 0.16810900E+01, -.88064900E+00, -.17382100E+00, 0.44067700E+00, -.17291700E+01, 0.58480800E-01, -.13400200E+01, -.74936100E+00, 0.79580200E+00, -.16958900E+00, -.10861800E+01, -.14609700E+01, -.10633500E+00, -.25806800E+00, -.18985700E-01, 0.72143500E+00, 0.31008000E+00, -.19732300E+00, -.86575300E+00, -.28912300E+00, -.16409300E+00, -.10189000E+01, 0.58093500E+00, 0.97262800E+00, -.37306400E+00, -.57776400E-02, -.34235700E+00, -.93011900E+00, 0.15493900E+00, -.23340800E+00, -.94993200E-03, -.36504100E-01, 0.17363900E+00, 0.10917600E+00, 0.26716400E+00, 0.21007900E+00, -.14197500E+00, -.19889000E-02, 0.14797700E+00, -.42819500E+00, 0.21687100E-01, -.35887000E+00, 0.79069300E+00, -.52993300E+00, -.12434500E+00, 0.56594300E+00, 0.50491400E-01, 0.31513500E-01, -.64540700E-01, -.23260700E+00, -.10828800E+01, -.29278000E+00, 0.34696300E+00, 0.36715400E-03, -.11954200E+00, 0.14262200E+01, 0.81049400E+00, -.65985500E-01, 0.48399400E+00, 0.35696500E+00, 0.56298200E+00, 0.20826400E+00, 0.27497500E+01, -.63930000E-01, -.55520700E-02, -.65454800E-01, -.14281600E+00, 0.11036000E+01, -.13402500E+00, -.20784800E+00, 0.56260700E+00, -.91835300E-01, -.49392500E+00, -.33502300E+00, -.30930400E+00, 0.26465600E-01, 0.56244200E+00, -.17480000E+00, -.14153800E-01, 0.11943300E+00, -.59197000E-01, 0.26853900E+00, 0.38753900E+00, 0.43694700E+00, -.23280100E+00, -.56452100E+00, -.63430300E-02, -.39199600E+00, 0.18039000E+00, 0.44941800E+00, 0.14810600E+00, -.47435400E+00, 0.85403000E-01, -.18908800E+00, 0.36398200E+00, -.13541200E-01, -.23600300E+00, 0.36290700E-02, -.28569000E-01, -.16345600E+00, 0.84380100E-01, 0.86522300E-01, -.10104000E+00, 0.29348100E+00, -.93217700E+00, 0.12112800E+00, -.70988700E-01, -.50440500E+00, 0.23783800E-01, 0.17012600E-01, 0.10634500E-01, 0.14856900E+00, 0.17165900E+00, -.87877700E-01, -.18529900E+00, 0.46956600E-01, -.14507100E+00, -.27380800E-01, -.10524300E+00, -.11639600E-03, -.10061300E+00, 0.22985300E+00, -.29064300E-01, -.78532100E-01, 0.53615800E-01, -.23533600E+00, 0.19922700E+00, 0.13799800E-01, 0.81841000E-01, -.21473100E-03, 0.24675800E-01, -.24225700E-01, -.15206100E+00, -.24815100E+00, 0.16275900E+00, -.53675000E-01, 0.65629500E-01, -.90211200E-01, 0.59252700E+00, 0.36679200E-01, -.14688200E+00, 0.10190100E-01, -.58309100E-01, -.78890800E-03, 0.16152800E+00, 0.21843800E-04, -.15144500E-01, -.76586700E-01, 0.73405800E-01, -.24702300E-01, 0.36178700E-02, 0.24545300E-01, -.57385600E-01, 0.41214300E-03, -.20209400E-01, -.58831200E-01, 0.26315500E-01, 0.27011500E-01, 0.51886700E-01, 0.12178100E-01, 0.12978200E-01, -.35454600E-01, -.42920800E-01, -.19402000E+00, -.86033900E-01, -.23809800E-02, -.30101400E+00, 0.35930300E-01, -.13849100E+00, 0.88357700E-01, 0.30734900E+00, 0.17710000E+00, -.48177300E-01, -.23830800E-01, 0.41865500E-01, 0.17358900E+00, -.17986400E+00, -.41654300E-01, 0.81723500E-02, 0.25820800E-02, 0.24726400E+00, 0.65531600E-01, -.37323500E-01, 0.11936900E-01, 0.55622600E-01, 0.25314300E-01, 0.14087900E-01, 0.37938800E+00, -.10983900E+00, 0.25571000E-01, -.93564700E+00, -.52490500E+00, -.11087800E+00, -.96160200E-01, 0.10555300E-02, 0.21621800E-01, 0.39558900E-04, 0.34826900E-01, 0.19889100E+00, -.12022600E-01, 0.28924800E-01, 0.98396800E-02, 0.16625300E+00, -.96745500E-01, 0.24198300E-01, -.98414600E-02, 0.12887300E-01, 0.57299900E-02, -.78853100E-01, 0.19496000E-02, 0.35853900E+00, -.15860500E-01, 0.78440700E-01, 0.33215100E-01, 0.22037000E+00, 0.53674500E-01, 0.17373200E-01, 0.38039600E-01, 0.40031000E-01, 0.27281500E-01, 0.16748800E-01, -.18673900E+00, 0.11448500E+00, -.24721600E-01, 0.46864900E-02, -.17319800E-01, 0.97944600E-01, 0.44537900E-01, 0.23522400E+00, 0.38814700E-01, 0.12652500E+00, -.39793000E-02, 0.69043700E-02, -.88014000E-01, 0.10403300E-01, 0.14849300E-01, 0.51168800E-01, -.30649500E+00, -.11415200E-01, 0.39797100E-01, 0.11257900E-01, 0.25893100E-01, -.16428700E+00, 0.65968100E-01, -.23499900E+00, 0.25653300E-01, 0.13551700E+00, 0.63642700E-01, 0.72066400E+00, 0.88353200E-02, 0.13358300E-01, -.26405900E-01, 0.12353900E+00, -.17984100E-02, 0.79219600E-03, -.15467300E-01, 0.28763000E-01, -.20941200E+00, -.25794300E+00, -.14388400E+00, -.31343700E+01, 0.17718600E+01, -.16894800E+00, 0.10703200E-01, -.37822600E+00, 0.30747300E-01, 0.21270200E+00, 0.12033700E-01, -.20582900E-01, 0.15726900E+00, -.58471700E-01, -.10078000E-01, -.19351800E+00, 0.75461500E+00, -.31938200E+00, 0.48349400E-01, -.34847100E+00, 0.26271900E-01, 0.40647500E-01, 0.24016800E-01, -.69723600E-01, -.12288500E+01, -.40831500E-01, 0.17379200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.27072700E+01, 0.28736500E+00, 0.49304900E+00, -.52071300E+00, -.30787500E+00, 0.19471500E+00, 0.12688200E-01, 0.40878300E-01, 0.36991800E-01, 0.58730100E+00, -.19166700E-01, 0.67501800E+00, 0.47755000E+00, -.64791600E+00, 0.19021500E+00, 0.27138100E+00, 0.80877000E+00, 0.62813400E+00, -.40368200E+00, 0.43837000E+00, -.67605900E-01, -.59473100E-01, 0.20625900E+00, 0.68961200E+00, 0.96170100E-01, 0.26540500E+00, 0.30279600E-01, -.59554400E+00, 0.60045800E-01, 0.26012200E+00, -.96022700E-01, 0.70873900E+00, 0.49483600E-01, 0.27986700E+00, 0.81351400E-01, 0.24671900E+00, 0.19661800E-01, -.11695000E+00, 0.11961200E+00, -.57028800E+00, -.75068300E-01, -.87023800E-01, 0.31240400E+00, -.88561300E-01, -.28887900E-02, -.33986900E-01, 0.19006600E+00, -.37560600E+00, 0.34815900E+00, 0.70358600E-01, -.15756500E+00, -.69912700E-01, -.34699400E-01, 0.38192100E+00, 0.92344900E-01, 0.43929400E+00, 0.93538000E-01, -.88055000E-01, 0.13056900E-02, -.99620900E-01, -.29592500E+00, -.23105100E+00, 0.61179100E-01, -.60568300E-01, -.28502800E+00, -.29061300E+00, -.65672000E-01, -.46967900E+00, -.98211700E-01, 0.19097000E-02, 0.20257700E+00, 0.12694300E+00, -.50106800E+00, 0.13995500E-01, 0.15623900E+00, -.36951600E+00, 0.54347500E-01, 0.48547800E+00, 0.54883600E-01, 0.99519200E-01, -.42421800E-02, -.26218000E+00, 0.40055000E-02, 0.17469600E+00, -.55299300E-01, -.20687100E-01, 0.18150000E+00, -.28500300E+00, 0.17863700E+00, 0.14945100E+00, 0.78031200E+00, -.10230600E-01, 0.27803200E+00, -.96554600E-01, -.46403400E+00, -.16993100E-01, 0.47244300E+00, -.25482100E+00, 0.15862000E+00, -.21561600E+00, 0.22455800E+00, 0.94882300E-01, 0.32142100E-02, 0.72690000E-01, 0.50941700E-01, -.29347500E-02, -.55248900E-01, 0.59495100E-01, 0.61038600E-01, 0.12602900E+00, -.12434600E+00, 0.59711900E-01, 0.36586300E+00, -.69059800E-02, -.97024400E-01, -.79149300E-02, -.15430100E+00, -.70812300E-01, 0.53327600E-01, 0.34519200E+00, 0.49032800E-01, 0.24581000E+00, -.17652800E-01, 0.60341000E-01, 0.10390300E-01, 0.96089800E-01, -.16468100E+00, 0.26434400E-01, 0.38430600E-01, -.49531000E-01, 0.25087200E+00, -.40339500E-01, -.13553900E+00, 0.38980400E-01, 0.10163900E-01, -.88265600E-02, -.39542500E-02, 0.37197700E-01, -.65307400E-01, -.26677800E-01, 0.99485600E-01, -.48019300E-01, 0.11084900E+00, -.57286600E-01, -.31955800E-01, -.87643600E-01, 0.13170400E-01, 0.17235200E-01, 0.13935200E+00, -.45497700E-01, -.68090700E-01, -.31971700E-01, -.14249600E-01, -.13863000E-01, 0.13384900E+00, 0.91774900E-02, 0.10996400E-01, 0.14544000E-01, -.22293300E-01, -.59863200E-01, 0.17430200E+00, -.84698900E-02, 0.44905100E-01, 0.70004400E-01, -.96425500E-03, -.88521100E-01, -.71464500E-01, 0.19247100E-01, 0.37405500E-01, 0.22134000E-01, -.19967400E-02, -.73715900E-01, -.19800300E-01, 0.13578500E-01, 0.57913600E-01, 0.31991900E-01, -.62231800E-02, -.51160700E-02, 0.12349200E-01, -.13162600E-01, 0.10501500E+00, 0.29976700E-01, -.33858000E-01, 0.41997400E-01, 0.35202600E-02, -.11635400E+00, -.46531700E-01, -.57135100E-01, -.91636400E-02, 0.69617700E-02, 0.31663300E-02, 0.44038100E-01, -.20818100E+00, -.74270500E-01, 0.31485300E-01, 0.13984900E+00, -.11424900E+00, 0.51595000E-01, 0.14146500E-01, -.20765900E-01, 0.18789100E-02, 0.18042000E-03, -.11045400E-01, -.16466200E+00, -.12693300E-01, 0.24704600E-01, 0.28759700E-02, -.38059700E-01, 0.17427400E-01, 0.14303400E-01, -.47155200E-02, 0.52120500E-02, -.77138900E-03, 0.36731900E-01, 0.19556400E-01, -.23552300E+00, 0.56728400E-01, 0.83694700E-01, -.94926200E-02, 0.27648600E-01, -.31217600E-02, 0.20318000E-01, -.42013900E-01, -.67254000E-01, 0.29837200E-01, 0.53850600E-02, 0.47393800E-01, -.44676700E-01, 0.18609200E-01, -.21870200E-01, -.14627200E-01, -.24392100E-02, -.15138700E-01, -.58732800E-01, 0.42671100E-02, 0.43008600E-01, 0.30366300E-02, 0.12712900E-01, 0.29057000E-01, 0.24940800E-01, 0.54834800E-01, -.23784500E-01, 0.50571700E+00, -.17006300E-01, -.68662500E-01, 0.88935500E-01, -.62663400E-01, 0.16690900E+00, 0.65649800E-01, -.17108500E-01, -.10952300E+00, -.51477000E-02, 0.51819700E-01, 0.10547000E+00, 0.64012800E-02, -.81491300E-02, -.45643700E-02, 0.75267800E-01, -.58675900E-01, -.28752100E-01, -.50682100E-01, -.45499700E-01, 0.35494100E-01, 0.52996000E-01, 0.54901800E-01, 0.36396000E+00, -.62233300E+00, 0.94979600E-01, -.68648100E-02, -.31233700E+00, -.11723300E+00, -.83277500E-01, -.18290700E-02, 0.18731500E+00, -.24537400E-01, 0.26377200E-01, -.39046700E-02, -.37163300E-01, -.35032700E+00, -.51461700E-01, -.26093800E-01, -.31930700E+00, 0.12233900E+00, 0.84253200E-02, 0.12559000E-01, -.18899200E-01, -.18283700E+00, -.15956800E-01, 0.12857700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39476000E+01, 0.34342200E+00, -.21857500E+01, 0.27721600E+00, 0.47975600E+00, -.12736500E+01, 0.72808600E+00, 0.26686600E-01, -.46059300E+00, 0.57743300E-01, -.24700700E+00, -.24991700E+00, -.72712100E+00, -.28574200E+01, -.82676800E-01, 0.57343300E+00, -.43443000E+00, -.19421500E+01, -.11352400E+00, -.62996900E+00, 0.83420200E+00, -.18165600E+00, 0.30909200E+00, -.46099300E+00, 0.80542900E-01, 0.35203400E+00, 0.13017400E+01, -.14668200E+00, -.93954600E+00, 0.42527200E+00, -.10955800E-01, -.30474000E+00, -.10041200E-01, 0.18142700E+00, -.43206400E-01, -.18392500E+00, 0.28889800E-01, -.12237300E+00, -.25047300E+00, 0.48391100E+00, -.27592300E+00, 0.29002900E+00, -.10180700E+01, -.29251100E-01, 0.10469800E+01, 0.25216900E-01, 0.19996200E+00, -.72969500E+00, 0.42408800E-01, -.20012100E-01, -.63874800E+00, 0.11085000E+00, 0.50719000E-01, 0.15066200E-02, -.20790200E+00, 0.97514700E+00, 0.33771700E-01, -.56139900E+00, 0.43375700E-04, 0.11317600E+01, -.84811700E+00, -.10590800E+00, 0.30891000E-01, -.33231700E-01, -.67214200E+00, 0.39154200E+00, -.13140600E+00, -.15249100E+01, 0.38426300E-01, 0.40465600E-02, -.39222500E+00, 0.13207800E+00, -.52419200E+00, 0.38956300E-01, 0.44658200E+00, -.80603900E+00, 0.13058500E+00, 0.68251200E+00, 0.24838700E-01, 0.35065400E+00, -.23808300E-01, -.68120200E+00, -.78999700E-02, -.73661700E-02, -.24169100E+00, 0.30732300E-01, -.15331300E-01, -.29770200E+00, -.49876600E+00, 0.39047400E+00, 0.12302000E+00, 0.34217500E-02, 0.29870300E+00, -.15396900E+00, -.41916400E+00, -.21917200E-01, 0.44726600E+00, -.12636200E+00, 0.20599100E+00, -.26148100E+00, 0.97204000E-01, 0.10176000E+00, 0.23649200E-02, 0.17267200E-01, -.20985200E-01, -.38661600E-01, 0.22587500E+00, 0.15524100E+00, -.19146700E+00, 0.22596500E+00, -.14153700E+00, -.39546200E-01, 0.24440700E+00, -.96818300E-02, 0.21548400E-01, 0.90921700E-02, -.27996700E-01, 0.98564500E-01, -.97462000E-01, -.53442700E-01, -.22753800E-02, -.61859100E-01, 0.22560000E-01, -.54694200E-01, -.27454800E-02, 0.14609300E+00, -.10803000E+00, 0.64798700E-01, 0.62782800E-02, 0.52889700E-01, 0.54361300E-02, 0.34240300E-01, -.21451700E+00, 0.41833300E-01, 0.96324400E-02, -.85846000E-02, -.85529900E-01, -.62612600E-01, -.28849900E-01, -.54909800E-01, 0.49451100E-01, 0.30332200E-01, 0.33274300E-01, -.24851600E+00, 0.36955400E-01, 0.14133900E+00, -.58124100E-02, 0.11710100E-01, -.18594700E+00, -.18397400E+00, 0.14445600E+00, 0.12555600E-01, -.32670500E-01, -.18000400E-01, -.80607300E-01, 0.18688100E-01, 0.31603400E-01, 0.18671600E-01, -.75173300E-01, 0.15490200E-01, -.30766900E+00, 0.30981900E-01, 0.15289600E+00, 0.29585500E+00, -.95614200E-01, -.55093700E-01, -.17754600E-01, 0.37432800E-01, 0.36347900E+00, 0.58412500E-01, 0.20566700E-01, 0.11552100E+00, -.84156600E-01, -.21234800E-01, -.10445000E+00, -.74110400E-01, 0.31414300E-01, -.34656900E-02, -.57233100E-01, -.33167200E-02, 0.41587300E-01, -.98105800E-01, -.47597500E-01, 0.27741200E-01, -.19454900E-01, -.58676700E-01, -.72899700E-01, -.24215700E-01, 0.47701500E-02, 0.19388400E+00, 0.20381100E-01, -.21606800E-01, 0.11950100E+00, 0.79021700E-01, -.69035900E-01, 0.26275500E+00, 0.11984300E+00, 0.46937500E-01, 0.72521500E-01, 0.27903300E-01, -.28927800E-01, -.17793500E-02, 0.22852600E-01, -.50417000E+00, 0.53101500E-01, 0.43944300E-01, -.50323000E-02, -.43998000E-01, 0.32851100E-01, -.21505900E-01, 0.13101600E-01, -.89597800E-02, -.89800500E-02, 0.84482200E-01, -.34189800E-01, -.26378700E+00, 0.81595700E-01, -.17067800E+00, -.15849600E+00, -.18803400E+00, -.90912500E-01, -.35453100E-01, -.79890600E-01, 0.99332200E-02, -.74533200E-01, -.20209900E-01, 0.58547400E-01, -.82210100E-01, -.12028400E-01, -.29934500E-01, -.71519200E-01, -.90921300E-02, -.33655800E-01, 0.29235400E-01, 0.19877200E-01, -.10292100E+00, -.10481000E+00, 0.41521600E-01, 0.49793700E-02, 0.93839700E-03, 0.96130700E-01, 0.45000500E-02, 0.35522800E+00, -.22764800E-01, -.11534500E+00, 0.37395300E+00, -.45788900E-01, 0.23955500E+00, -.33067200E-03, 0.93677500E-01, -.11262000E+00, -.66592400E-01, 0.16197500E-01, -.45631700E+00, -.49992800E-02, -.11711900E-01, 0.13341800E-01, -.32162000E-01, 0.48046600E-01, -.36156300E-01, -.81991500E-01, -.42912600E-01, 0.14165100E+00, 0.20302600E-01, 0.70368400E-02, 0.90294400E+00, -.24122400E+00, 0.89638200E-01, -.68339600E-02, 0.32985900E+00, -.39445400E+00, 0.26350200E+00, -.92339400E-02, -.52996800E+00, -.21071200E-01, -.10666800E-01, -.73956400E-02, 0.58656600E-01, 0.25030500E+00, -.94450500E-01, 0.22282000E-01, -.45684300E-01, 0.46346000E-01, 0.25899700E+00, -.23995600E-01, -.41629600E-02, 0.21014000E-01, 0.13599100E-02, 0.89995400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34989600E+01, -.31171700E+00, 0.58595800E+00, -.12416000E+01, -.87032400E+00, 0.13735900E+01, -.58610300E+00, 0.14666000E-01, 0.53595000E+00, -.45667300E+00, 0.17498100E+00, -.80079600E-01, 0.47655100E+00, 0.14768100E+01, -.10782800E-01, -.60233700E+00, 0.26478300E-01, 0.11254300E+01, -.61057000E+00, 0.62021300E+00, -.72831700E-01, 0.14691800E+00, -.10981300E+00, -.34386800E-01, -.10120800E+00, -.18239600E+00, -.84000900E+00, -.20234700E+00, 0.78301300E+00, -.28588800E+00, -.40909600E-01, 0.25697600E+00, -.65327500E-01, 0.74715100E-01, -.52399800E-01, -.93085900E-02, -.17913500E-01, 0.94597000E-01, 0.68220000E-01, -.50634700E+00, 0.89249000E-01, -.17572100E+00, 0.59450500E+00, 0.38910700E-01, -.74228700E+00, -.12139500E-01, -.24285900E+00, 0.68523900E+00, -.18677200E+00, -.18019900E-01, 0.52847000E+00, -.68455500E-01, -.14985700E-01, 0.36870100E+00, 0.34902400E+00, -.76499400E+00, -.18924400E-01, 0.20187500E+00, 0.87585300E-03, -.59480200E+00, 0.56056800E+00, 0.12782300E+00, -.23893100E-01, 0.12535600E+00, 0.38671300E+00, -.81646300E-01, 0.90972800E-01, 0.15147500E+01, -.12608500E-01, -.46218000E-02, 0.30232900E+00, -.11356700E+00, 0.65355100E+00, 0.76505400E-01, -.32776000E+00, 0.48802700E+00, -.12233400E+00, -.47454200E+00, -.94778400E-01, -.21064700E+00, 0.15138300E-01, 0.55637100E+00, -.68081000E-01, -.60330300E-01, 0.15042800E+00, -.58696500E-01, 0.83716000E-01, 0.30442700E+00, 0.50107300E+00, -.26544500E+00, -.12627400E+00, -.42495500E-02, -.18990900E+00, 0.80224900E-01, 0.35149200E+00, -.34850800E-01, -.31449100E+00, 0.50888700E-02, -.12890100E+00, 0.24690200E+00, -.16229100E+00, -.22570500E+00, 0.62117500E-03, 0.51139600E-02, -.87753700E-01, -.73530100E-01, -.16359500E-01, 0.39867100E-02, 0.10799500E+00, -.22132100E+00, 0.11537800E+00, -.36709100E-01, -.29301700E+00, 0.98704200E-02, 0.31013100E-01, -.28949800E-02, 0.59631300E-01, 0.12617700E+00, 0.11678600E-02, -.83312900E-01, 0.89898900E-02, -.12745000E+00, -.11598000E-01, -.23615000E-01, 0.47920900E-02, -.15310500E+00, 0.11030200E+00, -.35508800E-01, -.23727700E-01, -.12249400E-02, -.27068000E+00, 0.81628600E-01, 0.29341700E-01, 0.38072800E-01, 0.49707800E-02, 0.20674400E-01, -.10096400E-01, -.34549700E-01, -.30662500E+00, 0.14552500E+00, -.49386400E-01, 0.20489900E-01, -.27241000E-01, 0.29946300E+00, 0.44962400E-01, -.20115600E+00, 0.21107000E-02, -.37025400E-01, 0.12743100E-01, 0.32373200E+00, -.11227200E+00, 0.10555600E-01, -.23242800E-01, 0.28587600E-01, 0.26505600E-02, -.22436500E-02, -.13478900E-01, -.48846700E-01, 0.34368300E-01, -.37060800E-01, 0.17578600E+00, -.11082900E-01, -.47202600E-01, -.11964500E+00, -.13014500E-01, -.27332900E-01, 0.96763900E-03, -.40402200E-01, -.26993100E+00, 0.67219300E-03, -.18760200E-01, -.17212900E+00, 0.42357400E-01, 0.47149200E-02, 0.32737200E-01, 0.31477400E+00, 0.50865400E-01, -.36895200E-01, 0.66789200E-02, 0.16972000E-01, 0.61620400E-01, -.93969400E-01, -.57630000E-01, -.21269400E-01, -.11671300E-02, 0.15789000E+00, 0.68984600E-01, -.20027600E-01, 0.26987700E-02, -.17006500E+00, -.60047500E-02, 0.73323700E-01, 0.11203100E+00, -.22117600E+00, 0.77577000E-01, -.17983900E+00, -.15920100E+00, 0.32813700E-01, -.32595800E-01, -.17703800E-01, -.10970200E-02, 0.59089600E-03, -.38072300E-02, 0.18391100E+00, 0.24365100E-01, 0.47401200E-02, -.19075700E-01, 0.73463500E-01, -.25829400E-01, 0.25644300E-01, -.17550000E-01, 0.17675500E-01, 0.70573100E-02, -.49640200E-01, 0.38006400E-01, 0.27241500E+00, -.29509900E-01, 0.12354600E+00, 0.76439800E-01, 0.21844800E+00, 0.90578900E-01, 0.60214600E-01, 0.51687000E-01, -.18666500E-01, 0.50370800E-01, 0.59867400E-02, -.97730000E-01, 0.61537800E-01, 0.25537600E-01, 0.10045800E+00, 0.51368500E-01, 0.71239500E-01, 0.63609900E-01, -.19161900E-01, -.10732500E-01, 0.13150000E+00, 0.73410700E-01, -.21490500E-01, -.63267000E-01, 0.59856800E-02, -.33031600E-02, 0.37362600E-01, -.23149400E+00, 0.15998900E-03, 0.54099200E-01, -.51079300E-01, 0.27907700E-01, -.11565300E+00, 0.50948200E-01, -.20043700E+00, 0.47526600E-01, 0.50820100E-01, 0.16866900E-01, 0.49454500E+00, 0.98722100E-02, 0.73608300E-02, -.12696900E-01, 0.68424800E-01, 0.88298000E-03, 0.14824200E-01, 0.88186000E-03, 0.21018500E-01, -.35252200E-01, -.49515500E-01, -.23445100E-01, -.10012600E+01, 0.25393700E+00, -.63693100E-01, 0.56530200E-03, -.56825800E+00, 0.23600300E+00, -.46619700E-01, 0.60091300E-02, 0.44838900E-01, 0.24183300E-01, -.48800700E-02, -.23098000E-02, -.21504300E-01, -.14699600E+00, -.66419200E-01, -.40056500E-02, 0.94176700E-01, 0.68663300E-01, -.91806100E-01, 0.14766400E+00, 0.38816600E-02, 0.19170700E-01, -.63977200E-02, 0.70376100E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.27909500E+01, 0.26266100E+00, 0.11088600E+00, 0.92694500E+00, 0.47890900E+00, -.56757700E+00, 0.30080900E+00, 0.65514800E-01, 0.96194500E-02, 0.49228000E+00, 0.38508100E+00, 0.40282200E+00, 0.44416500E+00, 0.36779100E+00, 0.23637300E-02, 0.50368600E+00, 0.86747600E+00, 0.76691100E+00, 0.69030000E-01, 0.37735300E-02, -.27378800E+00, -.12494600E+00, 0.15323800E-01, 0.21208600E+00, 0.17050700E+00, 0.10643500E+00, 0.54573300E+00, 0.45163600E+00, -.34464100E+00, 0.10300400E+00, 0.41336400E-01, 0.29586700E+00, 0.34576200E+00, -.35973900E+00, 0.14820200E+00, 0.15746300E-01, 0.27540900E-01, -.10391600E+00, -.10638900E+00, -.62494000E-01, -.22949800E+00, -.45840100E-01, 0.15423000E+01, -.16158200E+00, -.56848400E-01, -.31524300E-01, -.62763700E-01, -.37857800E+00, 0.51349700E-01, 0.34179100E-01, -.54574600E-01, 0.30911300E-01, -.85453200E-01, 0.10670600E-01, 0.37552100E+00, 0.40087900E+00, 0.14078100E+00, -.23383000E+00, -.65799100E-04, -.96744600E-02, -.89777900E+00, -.33156000E+00, -.88956100E-02, -.37745200E+00, -.20431500E+00, -.14332600E+00, -.12188500E+00, -.12860400E+01, 0.76246700E-01, 0.17190400E-02, 0.35390500E-01, 0.10893400E+00, -.20425900E+00, 0.26821100E+00, -.11327800E+00, -.76659800E-01, -.30870900E-01, -.66252900E-01, 0.16335300E+00, 0.12133000E+00, -.18560000E-01, -.10997500E+00, 0.18601000E+00, -.25232400E-01, 0.10904000E-01, -.16836400E-01, -.27259600E+00, -.76356200E-01, -.29195000E+00, 0.14914400E+00, 0.12377000E+00, 0.11568100E-01, 0.18288600E+00, -.89498200E-01, 0.83114600E-02, -.37879400E-02, -.15808600E+00, 0.20202000E+00, -.14157700E-01, 0.28809000E-01, -.12647400E+00, -.28887700E-01, 0.77706400E-03, -.37020000E-01, 0.55396800E-01, -.84072800E-01, -.42995200E-01, 0.65087800E-01, -.20771500E+00, 0.66323900E+00, 0.10414700E-01, 0.50711500E-01, 0.10243600E+00, -.51815900E-02, 0.87859200E-01, -.19983300E-01, -.13562500E+00, -.25386300E-01, 0.20387900E+00, 0.33388900E-01, -.65527000E-01, -.26962600E-01, 0.29743700E-01, 0.10106500E+00, -.31853600E-02, 0.58558600E-02, -.62243300E-01, -.16243200E-02, 0.15703600E-01, -.39169800E-01, 0.12454900E+00, -.21984100E+00, 0.66356300E-01, 0.40586100E-01, 0.91797500E-02, 0.80053900E-02, -.41228000E-02, 0.11397500E-01, -.17761900E+00, 0.86069600E-01, -.19639800E-01, 0.45288600E-01, -.10926300E-01, -.21653100E+00, 0.67316000E-01, -.70345100E-01, -.14393900E-01, 0.13989800E-02, -.83416000E-01, 0.51684900E-01, -.51470400E-01, 0.20400600E-01, -.13469100E-01, -.24112800E-01, 0.14235900E-01, 0.18570500E-01, -.22445600E-01, 0.16584500E-01, 0.13101100E-01, -.18732400E+00, -.80486600E-01, -.22486700E-01, -.79125000E-01, -.16796000E+00, -.36042300E-01, 0.30990500E-01, 0.36419800E-01, -.17568500E-01, -.14630600E+00, 0.78088100E-01, -.37655200E-01, 0.24981700E-01, -.13515700E-01, 0.16451400E+00, -.51603200E-01, -.22722300E+00, -.71546100E-01, 0.41910600E-01, 0.68481600E-01, -.49914400E-01, -.81375500E-01, 0.54657500E+00, 0.14080500E+00, -.65120700E-01, 0.44424700E-01, -.12130200E-01, -.19909600E-01, 0.21564000E-01, -.14709800E-01, -.11749500E+00, -.52961300E-01, -.13113100E+00, -.25281800E+00, 0.56871100E-01, 0.41554300E-01, 0.26752200E+00, -.28714000E+00, -.94917700E-01, 0.16092700E+00, -.14765400E-01, 0.84796400E-01, 0.19643300E-02, -.44706600E-01, 0.28634700E+00, 0.60947300E-01, -.33138800E-01, 0.93924800E-02, -.47566700E-01, 0.65194900E-01, 0.28768800E-01, 0.76433900E-02, -.40932000E-02, 0.60605100E-02, -.45013400E-01, 0.64219100E-02, -.17004800E+00, -.59653300E-01, -.95894800E-01, 0.36699300E-01, 0.15791800E+00, 0.56944000E-01, 0.87066300E-01, -.78475000E-02, -.11285800E+00, 0.68444400E-01, -.92279400E-02, 0.23029300E-01, -.20869300E-01, 0.15305600E-02, -.14041800E+00, 0.37386000E-01, -.24598700E-02, -.76178900E-02, -.95126700E-01, -.34110700E-02, 0.74095400E-01, 0.12020800E-01, 0.45583800E-01, 0.24894900E-01, 0.27122900E-01, 0.16052900E-01, -.17573200E-01, 0.33745900E+00, -.70231300E-03, -.13539000E-01, 0.30587800E+00, -.42224900E-01, 0.13387300E+00, -.77518400E-01, 0.61912900E-01, -.27081900E-01, -.91672200E-01, 0.12676600E-02, -.30694500E+00, -.61523000E-02, -.18727100E-01, 0.64020200E-02, 0.39954400E-01, -.46764900E-01, -.26602500E-01, -.35615100E-01, -.47542900E-01, 0.13405800E+00, 0.15167100E+00, 0.98660300E-02, 0.56141900E+00, -.49264000E+00, 0.23836600E+00, -.17305500E-01, -.35465100E+00, 0.14826900E+00, 0.43341700E+00, -.25822400E-01, -.62513300E-02, -.59587200E-01, 0.16854300E-01, -.62111800E-02, 0.82895300E-01, -.91857600E-01, 0.35821900E-01, -.15581600E-01, -.18499900E+00, -.48122500E-01, -.27485300E-01, 0.11744700E-02, 0.14530100E+00, 0.97443500E-01, -.64780900E-02, 0.13923700E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.46129400E+01, -.45738700E+00, -.68317100E+00, 0.27022300E+00, 0.47098300E+00, 0.32374500E+00, -.59764900E+00, -.12370900E+00, 0.86607500E-01, -.95794100E+00, -.13640600E+00, -.79983600E+00, -.65445300E+00, 0.47342900E-01, -.14565700E+00, -.72532600E+00, -.11755300E+01, -.57428300E+00, 0.41961900E+00, -.43335100E+00, 0.14986300E+00, 0.14795000E+00, -.19014800E+00, -.52081300E+00, -.18467400E+00, -.16697700E+00, -.48936200E+00, 0.30499900E+00, 0.35071200E+00, -.65625800E-01, -.34980000E-02, -.41735100E+00, -.34012700E+00, -.27755100E+00, -.51830600E-01, -.41306900E-01, -.34844500E-01, 0.90198900E-01, 0.43322600E-01, 0.65484900E+00, 0.21325800E+00, -.15844400E+00, 0.27473100E+00, 0.99071400E-01, -.36200900E+00, 0.51846200E-02, -.32494000E+00, 0.59914500E+00, -.55475800E-01, -.12841700E+00, 0.59411400E+00, -.55649500E-01, -.13040200E+00, -.48587300E+00, -.38570900E+00, -.32640100E+00, -.20503900E+00, 0.11490600E+00, 0.11167100E-02, 0.36171400E+00, 0.87824000E+00, 0.56460100E+00, -.75662600E-01, 0.22235800E+00, -.21304400E+00, 0.38819400E+00, 0.99798500E-01, 0.11879200E+01, -.29718600E-01, -.31436700E-02, -.26470800E+00, 0.42257600E-01, 0.83785700E+00, -.13750100E+00, -.58967200E-01, 0.49562100E+00, -.32915400E-02, -.31486700E+00, -.40613700E-01, -.25765400E+00, 0.15989900E-01, 0.25291400E+00, -.10810400E+00, -.89042000E-01, 0.18906900E-01, 0.21624300E-01, 0.93325700E-01, 0.21620400E+00, 0.16014000E+00, -.12406400E+00, -.66534100E+00, -.74458200E-02, -.30743400E+00, 0.80030900E-01, 0.42536100E+00, 0.10272100E+00, -.55954400E+00, 0.26353800E+00, -.23814900E-01, 0.18201600E+00, -.82644400E-01, -.55386600E-01, -.10768300E-01, -.48065100E-01, -.72074300E-01, -.10212400E+00, -.78352300E-01, -.38881300E-02, 0.20507400E+00, -.24235200E+00, 0.19678500E+00, -.26810100E-01, -.30291200E+00, 0.46365700E-02, -.50299800E-02, 0.19090700E-01, 0.13004000E+00, 0.17477000E+00, -.23258800E-01, -.29607200E+00, 0.38191300E-01, -.17947000E+00, -.30753000E-01, -.10146600E+00, 0.60154400E-02, -.75779900E-01, 0.91719900E-01, -.77495800E-02, -.55019700E-01, 0.30919200E-01, -.11999200E+00, -.17739200E-01, 0.13722600E+00, 0.14052700E+00, 0.28866500E-01, 0.17715400E-01, -.12775800E+00, 0.45748900E-01, -.30180300E+00, 0.85131700E-01, 0.45641100E-01, -.13320100E+00, -.68435800E-01, 0.59730000E+00, -.48790400E-01, 0.25351900E-01, 0.28290400E-01, -.28621400E-01, 0.18125500E-01, -.69430000E-01, 0.54030200E-01, -.24096300E-01, -.10931500E+00, 0.33898600E-01, 0.95886500E-01, -.28341300E-01, 0.31375200E-01, -.52661500E-01, -.27898600E-01, 0.18604200E+00, -.14883900E+00, -.31528700E-02, 0.34594700E-01, -.18781600E+00, -.14953100E-01, 0.75762600E-01, -.17214900E-01, -.27452200E-01, -.40845600E-01, -.26263600E-02, 0.10367700E-01, -.14178300E+00, 0.22523700E-01, -.13098400E+00, -.34348000E-01, 0.35725400E+00, 0.53369400E-01, -.57763000E-01, -.19555200E-01, 0.18039500E-01, 0.27144700E+00, -.32414100E+00, -.55248800E-01, -.14356800E-01, -.25147900E-01, 0.17673600E+00, 0.85315100E-01, 0.26670400E-01, 0.58343000E-02, -.18534100E+00, 0.80301100E-02, 0.20319000E+00, 0.47431400E+00, 0.65481900E-02, -.32587600E-01, -.58941600E+00, -.55239000E-01, 0.40217500E-02, -.54501700E-01, 0.17928900E-01, 0.25446700E-01, -.74218500E-03, 0.37357400E-01, 0.11722300E+00, -.88387300E-01, -.22396900E-01, 0.87888900E-02, 0.46128900E-01, -.12702400E-01, 0.21222000E-01, 0.29968300E-02, 0.16602700E-01, -.34209800E-02, -.38672900E-01, 0.51308000E-03, 0.27401500E+00, 0.92003200E-02, 0.31552700E-02, 0.13722000E-01, 0.13926700E+00, 0.49576700E-01, 0.35966500E-01, 0.60812500E-01, 0.16870500E-01, 0.25504100E-01, 0.19108700E-01, -.78553400E-01, 0.59285400E-01, -.14227900E-01, -.70435200E-02, -.62558200E-02, 0.55203400E-01, 0.51930100E-01, -.14709600E-01, -.48515200E-02, 0.10665600E+00, 0.27874400E-01, 0.76157100E-02, -.41010600E-01, 0.11524100E-01, 0.16445400E-01, -.55605500E-02, 0.14121000E+00, -.43115300E-02, 0.69184400E-02, 0.64807400E-01, 0.32868800E-02, -.18034000E-01, 0.27519500E-01, -.11683500E+00, 0.40435400E-03, 0.87966600E-01, 0.32420300E-01, 0.17583000E+00, 0.89481800E-03, 0.19420100E-03, -.59974700E-02, 0.73686000E-01, -.32211200E-01, -.41845400E-02, -.19832300E-01, -.83047900E-02, -.47507100E-01, -.36442900E-01, -.82936500E-01, -.16739600E+01, 0.75158500E+00, -.23406600E-01, -.88723700E-02, 0.52334400E-01, 0.11092900E+00, 0.14601700E+00, -.46791000E-02, 0.24052800E-01, -.78709700E-01, 0.14244800E-01, -.19211900E-03, 0.20772800E+00, -.19953800E+00, 0.11714900E+00, -.25190900E-01, 0.59389200E+00, 0.46756200E-01, -.82462500E-01, -.22863900E+00, 0.65564100E+00, 0.13157900E+01, -.25475800E-02, -.20500500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.52870800E+01, -.55518300E+00, -.76759000E+00, -.40243200E-01, 0.14611700E+00, 0.59229600E+00, -.65421000E+00, -.11992300E+00, 0.19008800E+00, -.11247800E+01, -.22083800E-01, -.98462400E+00, -.57024200E+00, 0.46735300E+00, -.34979000E+00, -.79466500E+00, -.12926200E+01, -.46605500E+00, 0.12838800E-01, -.31512000E+00, 0.26965800E+00, 0.14990500E+00, -.21334700E+00, -.58754000E+00, -.18323700E+00, -.94752900E-01, -.41005200E+00, 0.43799600E+00, 0.50209100E+00, -.14037800E+00, -.40298600E-02, -.44475900E+00, -.53987400E+00, -.10326000E+00, -.11747000E+00, 0.38874600E-01, -.30280100E-01, 0.12210300E+00, -.10372700E-01, 0.39678700E+00, 0.88299200E-01, -.30322900E-01, -.21406100E+00, 0.10298800E+00, 0.19250100E-01, 0.49405300E-01, -.27855600E+00, 0.58362000E+00, -.26563200E+00, -.99813700E-01, 0.31531500E+00, -.83005600E-01, 0.70243600E-01, -.15398400E+00, -.36940500E+00, -.82195100E+00, -.22439900E+00, 0.23562500E+00, -.14124200E-02, -.73698400E-02, 0.14584200E+01, 0.74724900E+00, -.63668900E-01, 0.32770300E+00, 0.23021000E+00, 0.24764700E+00, 0.19800000E+00, 0.18673900E+01, -.22575400E-01, -.26313700E-02, -.14485000E+00, -.15600100E+00, 0.54344300E+00, -.31412400E+00, -.12697600E+00, 0.59552200E+00, -.56677700E-01, -.58355900E+00, -.25392600E+00, -.20339400E+00, 0.21729200E-01, 0.33809700E+00, -.15009200E+00, 0.44973600E-01, 0.88989100E-01, -.36667900E-01, 0.37641900E-01, 0.20902100E+00, 0.20051400E+00, -.20615400E+00, -.40183400E+00, 0.27586700E-02, -.21251300E+00, 0.16896400E+00, 0.34315300E+00, 0.98214200E-01, -.29063000E+00, 0.73617100E-01, -.21101200E+00, 0.19349300E+00, -.17003700E-01, -.13400100E+00, 0.45783500E-02, -.42966500E-01, -.70216400E-01, 0.87362100E-01, 0.16884400E-01, -.38182900E-01, 0.20072500E+00, -.36240800E+00, 0.19454800E+00, -.46214100E-01, -.34604400E+00, 0.99491400E-02, -.31203700E-01, 0.12537700E-01, 0.11463500E+00, -.12489100E-01, -.11377700E+00, -.25056400E+00, 0.27554500E-01, -.77990700E-01, -.76674400E-02, -.65012700E-01, -.33584400E-04, -.19937800E+00, 0.21410400E+00, -.43407500E-01, -.34854100E-01, 0.23229700E-01, -.17408300E+00, 0.30469000E-01, 0.11961500E+00, -.12797400E+00, -.21202300E-02, 0.32106300E-02, -.53895900E-01, -.38924300E-01, 0.72132000E-02, -.26044600E-02, -.43012000E-01, -.45117300E-01, -.65379900E-01, 0.42458200E+00, -.30484200E-01, 0.94325900E-01, 0.10836700E-01, -.24932300E-01, 0.32696000E-01, 0.63238000E-01, -.30244100E-01, -.26189600E-01, -.65545000E-01, 0.50217200E-01, 0.54178900E-01, -.24952600E-01, 0.12255800E-01, -.31706400E-01, -.51631000E-02, 0.44075500E-01, -.93474600E-01, -.23125100E-02, 0.37738200E-01, -.17089500E+00, -.31446100E-01, 0.89273200E-01, -.39331300E-01, -.17605400E-01, -.46351800E-01, -.83259400E-01, 0.24231300E-01, -.15692100E+00, 0.15599800E-01, -.99422200E-01, -.73074300E-02, 0.26599300E+00, 0.37603500E-01, -.27382600E-01, -.31823900E-01, 0.17826200E-01, 0.17679400E+00, -.24111600E+00, -.15690000E-01, 0.30397800E-01, 0.44235400E-03, 0.21846700E+00, 0.72614200E-01, -.28505400E-02, 0.11874100E-01, -.75979300E-01, 0.73592600E-02, 0.19795800E+00, 0.43809100E+00, 0.55656300E-02, -.19709500E-01, -.87393700E+00, -.16259600E+00, -.27569300E-01, -.73414000E-01, 0.85095000E-02, 0.33026300E-01, -.88612100E-03, 0.38637900E-01, 0.12905500E+00, -.10655800E+00, -.18564100E-01, 0.27300100E-01, 0.52679300E-01, -.40422500E-01, 0.17211700E-01, -.74122300E-02, 0.16006400E-01, -.40726200E-02, -.71320700E-01, 0.63883100E-02, 0.20339500E+00, 0.19361400E-01, 0.34489400E-01, 0.81420400E-02, 0.11197500E+00, 0.37881500E-01, 0.11917700E-01, 0.55481200E-01, 0.10460900E-01, 0.15040000E-01, 0.18237300E-01, -.85093500E-01, 0.64796300E-01, -.71654300E-02, 0.71883000E-02, -.76541800E-02, 0.55673300E-01, 0.50876800E-01, 0.47146200E-01, -.45861900E-02, 0.82891800E-01, 0.15543500E-01, 0.27863200E-02, -.39939700E-01, 0.97163800E-03, 0.16166700E-01, 0.19864200E-02, -.60245100E-01, 0.51381000E-02, 0.11558300E-01, 0.11712800E-01, 0.10134300E-01, -.75303900E-01, 0.25999800E-01, -.46384700E-01, 0.42096500E-02, 0.12525000E+00, 0.32383800E-01, 0.21160200E+00, 0.40838900E-02, 0.43315000E-02, -.55405300E-02, 0.52968400E-01, -.13386300E-01, -.34973800E-02, -.24991400E-01, -.60384900E-02, -.66027200E-01, -.57250000E-01, -.79590600E-01, -.16535000E+01, 0.75151300E+00, -.35872700E-01, -.59871100E-02, 0.19592000E+00, 0.50947700E-01, 0.39051400E-01, 0.13542100E-02, 0.33292200E-01, -.42435100E-01, 0.17067000E-01, -.25328200E-02, 0.13107400E+00, 0.10251800E+00, 0.16055600E-01, -.67102300E-02, 0.50560000E+00, -.10602100E+00, -.47927400E-01, -.19113900E+00, 0.38441700E+00, 0.65234300E+00, 0.75867600E-01, 0.48547700E-03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.38219500E+01, 0.34372200E+00, -.17226300E+01, 0.36312700E+00, 0.17148900E+00, -.12883000E+01, 0.10799600E+01, 0.75216300E-01, -.19959700E+00, 0.34792600E+00, -.12784600E+00, -.15860400E+00, -.57637400E+00, -.19194000E+01, -.34512300E-01, 0.68063300E+00, -.15606300E+00, -.11749800E+01, -.12954200E+00, -.43064900E+00, 0.51415800E+00, -.18875000E+00, 0.23647200E+00, -.30979900E+00, 0.13496700E+00, 0.33356600E+00, 0.13794000E+01, 0.78905700E-01, -.67448800E+00, 0.35919700E+00, 0.69764900E-03, -.13562500E+00, 0.83480100E-01, 0.26430600E-01, 0.16127500E-01, -.78989400E-01, 0.32505000E-01, -.12685800E+00, -.98000900E-01, -.32494500E-01, -.21471800E+00, 0.57383400E-01, -.91891800E+00, -.48161900E-01, 0.59210300E+00, -.49281100E-01, 0.15920300E+00, -.72420400E+00, 0.25098800E+00, 0.34183000E-01, -.36900800E+00, 0.30410400E-01, -.13572600E-01, -.12783300E+00, -.46841600E-01, 0.88621200E+00, 0.15488000E+00, -.33225000E+00, -.19590700E-02, 0.68970600E+00, -.98238800E+00, -.34616200E+00, 0.54201200E-01, -.33246600E-01, -.25101600E+00, -.33219200E-01, -.66143800E-01, -.14955700E+01, -.29633500E-02, 0.46444800E-02, -.23471300E+00, 0.15198900E+00, -.51987400E+00, -.74606100E-01, 0.22471900E+00, -.41526500E+00, 0.14442800E+00, 0.39816000E+00, 0.12222600E+00, 0.32821200E+00, -.25404900E-01, -.45714600E+00, 0.24302500E-01, -.14066200E+00, -.14430000E+00, 0.40658200E-01, 0.32065000E-01, -.22501700E+00, -.42779600E+00, 0.27867300E+00, 0.53736500E+00, 0.50790300E-03, 0.22692800E+00, -.95095200E-01, -.37213800E+00, -.10537500E+00, 0.25827500E+00, -.70509600E-01, 0.14047900E+00, -.18802700E+00, -.50681100E-01, 0.11741300E+00, -.80831800E-02, -.22699200E-01, 0.45973000E-01, -.32194500E-01, -.14998600E-02, 0.26470400E-01, -.18455900E+00, 0.25922300E+00, -.29616700E-01, -.15992000E-02, 0.14184700E+00, -.12444800E-01, 0.53000100E-02, 0.65139300E-02, 0.42893300E-02, -.52868800E-01, -.12571000E+00, 0.20059700E-01, -.35229500E-02, -.72906400E-02, 0.30567400E-01, 0.43997600E-01, -.17725800E-02, 0.87626300E-01, -.12236900E-01, 0.43755100E-02, 0.22193500E-01, -.76045000E-02, -.34037100E-01, -.69902600E-01, 0.51792000E-01, 0.29142600E-01, 0.10166900E-01, -.14647700E-01, 0.59319100E-01, 0.17648100E-01, 0.24097800E+00, -.54014500E-01, 0.13016400E-01, -.21574500E-01, 0.54026300E-01, -.21047800E+00, -.51416400E-02, 0.18728400E+00, -.14620700E-02, 0.27337700E-01, -.10190700E+00, -.28335100E-01, 0.12273700E+00, -.43755400E-02, 0.26810600E-02, -.18924000E-01, 0.44929100E-01, -.54779300E-02, 0.15875400E-01, 0.22044500E-01, -.54842600E-01, -.22812200E-01, -.17282400E+00, -.12290600E-01, 0.13669000E+00, 0.14161400E+00, -.23156800E-01, -.11853200E+00, -.54170200E-01, 0.34575400E-01, 0.32735700E+00, 0.13297700E+00, 0.16419000E-01, 0.13569900E+00, -.69641900E-01, 0.52290500E-01, -.54756800E-01, 0.49142900E-01, 0.11049200E-01, 0.96881800E-02, -.25549600E-01, 0.42742700E-02, -.54915800E-01, -.62285200E-01, 0.38922000E-01, 0.67743300E-02, -.10036300E-01, -.11674300E+00, -.46579400E-01, -.29179300E-02, -.29901800E-02, 0.86349100E-01, 0.17678700E-01, 0.47552400E-01, 0.40083600E-01, 0.47572300E-01, -.53801400E-01, 0.79753300E-01, 0.47545800E-01, 0.40221200E-01, 0.18999900E-01, 0.20169700E-01, -.13929500E-01, -.99184400E-03, 0.10539400E-01, -.21902800E+00, -.57599300E-01, -.53432000E-02, 0.15270100E-01, -.50614100E-01, 0.51273000E-01, 0.27733500E-02, 0.18448500E-01, 0.66777200E-03, -.81869800E-02, 0.82285200E-01, -.32378800E-01, -.28146400E+00, 0.80853000E-01, -.50947200E-01, -.10872300E+00, -.81581300E-01, -.13659100E-01, -.13286900E-01, -.54225300E-01, -.13072500E-01, -.38857200E-01, 0.20866800E-01, 0.76109600E-01, -.19620100E-01, -.20980600E-01, -.54198000E-01, -.66706900E-01, -.20460600E-01, -.15167700E-01, 0.40787300E-02, 0.12941200E-01, -.53684500E-01, -.31219500E-01, 0.35243600E-01, 0.36614900E-01, 0.15897500E-02, 0.28431500E-01, -.15599400E-01, 0.28996200E+00, -.19086000E-01, -.73833000E-01, 0.16208100E+00, -.56841800E-01, 0.14294200E+00, -.18990200E-01, 0.90648200E-01, -.52600800E-01, -.41899000E-01, 0.48034200E-02, -.27026200E+00, -.39130900E-02, -.13157700E-01, 0.57929100E-02, -.13502700E-01, 0.19167800E-01, -.17452600E-01, -.20018500E-01, -.19362300E-01, 0.77155200E-01, 0.77070400E-02, 0.27943800E-01, 0.96813600E+00, -.24015300E+00, 0.66486000E-01, 0.72335200E-02, 0.35810000E+00, -.24769800E+00, -.10121800E+00, 0.22483700E-02, -.73028800E+00, -.12368700E-01, 0.60607200E-02, 0.24405500E-02, 0.13961000E-01, -.91939100E-01, 0.52033900E-01, -.11408100E-01, -.77965800E-01, 0.75110700E-01, 0.34714100E+00, 0.45261500E-01, 0.31266100E-01, 0.17135500E-01, 0.63990100E-02, 0.93132400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
    },
    {
        { 0.11223500E+07, -.55445200E+06, -.60710000E+06, -.55510000E+06, -.10711900E+06, -.11640700E+06, -.12757500E+06, 0.18260000E+06, -.30443100E+06, -.10767900E+06, -.41906000E+06, 0.21630600E+07, -.10644300E+07, -.13665700E+07, -.10717900E+07, -.14267500E+06, -.13280600E+06, -.28123600E+06, 0.39517800E+06, -.50952000E+06, -.14464200E+06, -.81149600E+06, -.38548600E+06, 0.18598100E+06, 0.80233000E+06, 0.19128300E+06, -.84740700E+04, -.34012700E+05, 0.82800500E+05, -.10250800E+06, 0.26167500E+05, -.67907600E+04, -.12943100E+06, 0.11146200E+07, -.54874600E+06, -.92452600E+06, -.55210200E+06, -.15669700E+06, -.13973400E+06, -.10305300E+06, 0.20892900E+06, -.23552700E+06, -.13703500E+06, -.40471400E+06, -.60703100E+06, 0.29743200E+06, 0.54019400E+06, 0.29936900E+06, 0.59324400E+05, 0.78294700E+05, 0.59748900E+05, -.10403700E+06, 0.14064200E+06, 0.74768300E+05, 0.21192000E+06, 0.88462000E+06, -.43812400E+06, -.58445600E+06, -.43646400E+06, -.95323100E+05, -.48900400E+05, -.12878600E+06, 0.12368100E+06, -.21386400E+06, -.62025100E+05, -.26787800E+06, -.16750600E+07, 0.82815200E+06, 0.10081300E+07, 0.83276400E+06, 0.15386000E+06, 0.16439300E+06, 0.19350900E+06, -.26997600E+06, 0.47741500E+06, 0.15527500E+06, 0.61941500E+06, -.42984800E+06, 0.21141700E+06, 0.31579700E+06, 0.21278600E+06, 0.34563500E+05, 0.28790500E+05, 0.53552500E+05, -.74137500E+05, 0.10602400E+06, 0.31044000E+05, 0.14596400E+06, 0.13658100E+07, -.66928500E+06, -.10723600E+07, -.66957600E+06, -.11495500E+06, -.44436300E+05, -.19703300E+06, 0.23466600E+06, -.28869500E+06, -.81704600E+05, -.43541200E+06, 0.17419000E+07, -.85777900E+06, -.12565500E+07, -.86217600E+06, -.14446900E+06, -.14840200E+06, -.21042200E+06, 0.31388700E+06, -.41904600E+06, -.14769600E+06, -.61025800E+06, 0.49307100E+06, -.24249200E+06, -.30227100E+06, -.24340500E+06, -.35316400E+05, -.97039300E+04, -.70671300E+05, 0.95461400E+05, -.12362100E+06, -.16059100E+05, -.14763600E+06, -.12770400E+07, 0.62759900E+06, 0.11071900E+07, 0.63405400E+06, 0.66539300E+05, 0.10653000E+05, 0.21000700E+06, -.19578400E+06, 0.33487000E+06, 0.46790900E+05, 0.40523200E+06, 0.14484400E+07, -.71411300E+06, -.83395100E+06, -.71622200E+06, -.16708300E+06, -.17212500E+06, -.12986400E+06, 0.26082900E+06, -.37665600E+06, -.15429400E+06, -.59178300E+06, 0.55327900E+06, -.27196500E+06, -.42814800E+06, -.27523200E+06, -.75623100E+05, -.58303300E+05, -.56405100E+05, 0.11059200E+06, -.11546000E+06, -.61542400E+05, -.17914100E+06, -.19682100E+07, 0.96922600E+06, 0.16839900E+07, 0.96869000E+06, 0.15303800E+06, 0.13451800E+06, 0.19736400E+06, -.45815000E+06, 0.43224800E+06, 0.13664500E+06, 0.56469300E+06, 0.59423000E+06, -.28874500E+06, -.44072500E+06, -.29604500E+06, -.17935800E+05, -.84564900E+04, -.98333800E+05, 0.99146400E+05, -.14080100E+06, -.17347800E+05, -.17888000E+06, -.57069900E+06, 0.28032200E+06, 0.47958100E+06, 0.28159100E+06, 0.53321400E+05, 0.48885000E+05, 0.68189200E+05, -.10294500E+06, 0.12291100E+06, 0.53481200E+05, 0.17438700E+06, -.11710700E+07, 0.57814900E+06, 0.97189600E+06, 0.57977100E+06, 0.89100300E+05, 0.71449900E+05, 0.13222000E+06, -.28033100E+06, 0.21775300E+06, 0.10315100E+06, 0.35389900E+06, 0.12622400E+07, -.61702200E+06, -.10699200E+07, -.61964100E+06, -.10103200E+06, -.63362000E+05, -.19144800E+06, 0.17212000E+06, -.28978600E+06, -.76770300E+05, -.41381400E+06, -.15109800E+07, 0.74461600E+06, 0.12144100E+07, 0.74578100E+06, 0.12797600E+06, 0.11372600E+06, 0.17225400E+06, -.34704600E+06, 0.28576500E+06, 0.14769300E+06, 0.46277500E+06, 0.43479100E+05, -.16260700E+05, -.74417600E+06, -.91152800E+04, 0.23214900E+05, 0.38339300E+05, -.32225800E+05, 0.13267400E+05, 0.78713700E+05, 0.15101000E+05, 0.84076700E+05, -.46776700E+06, 0.22997200E+06, 0.36304300E+06, 0.23146500E+06, 0.36582100E+05, 0.31674400E+05, 0.57465900E+05, -.83259400E+05, 0.11305600E+06, 0.34574500E+05, 0.15752500E+06, -.87618000E+06, 0.43149800E+06, 0.54309400E+06, 0.43519400E+06, 0.54979500E+05, 0.48818300E+05, 0.11978800E+06, -.15810800E+06, 0.20644200E+06, 0.54252900E+05, 0.30877400E+06, 0.18002300E+07, -.89050700E+06, -.15292400E+07, -.89724500E+06, -.92011300E+05, -.44927200E+05, -.25842100E+06, 0.28551800E+06, -.54200500E+06, -.70655600E+05, -.59917800E+06, -.22622300E+07, 0.11191900E+07, 0.18263800E+07, 0.11271600E+07, 0.13762100E+06, 0.10966000E+06, 0.31104800E+06, -.35346400E+06, 0.67315400E+06, 0.12713400E+06, 0.75328000E+06, 0.38162100E+06, -.49197500E+05, 0.10876800E+06, -.41494000E+06, -.26489700E+06, 0.18700100E+06, 0.19703100E+06, -.45009000E+05, 0.17667900E+05, -.25457700E+06, -.63657200E+05, 0.19974600E+06, -.17621500E+06, 0.27734600E+06, 0.22792300E+06, 0.24718700E+06, -.30114000E+06, -.16102900E+06, -.12197800E+06, -.23247100E+06, 0.25093500E+06, 0.40579300E+06, 0.83981200E+05, 0.10590200E+06, -.14505100E+06, -.81282400E+05 },
        { -.35278800E-01, -.18317800E+04, 0.25111000E+05, -.41602500E+03, 0.11235200E+05, 0.29103200E+05, -.15813800E+05, -.16341100E+05, -.23258000E+05, 0.21695500E+05, 0.34959500E+04, 0.32498900E+05, -.14742800E+05, 0.30200200E+05, -.16977100E+05, 0.52674300E+05, 0.11818200E+06, -.63033700E+05, -.44440300E+05, -.82849400E+05, 0.94875600E+05, -.18970800E+05, -.68391600E+04, 0.52711900E+04, -.18585300E+05, 0.35271600E+04, -.36202700E+05, -.73322400E+05, 0.34294700E+05, 0.20664900E+05, 0.32137900E+05, -.57717200E+05, 0.22306800E+04, -.89444200E+05, 0.43536200E+05, 0.24122700E+05, 0.44300000E+05, 0.24251200E+05, 0.51733300E+05, -.17767700E+05, -.44347900E+05, -.15977800E+05, 0.44075800E+05, 0.35495000E+05, 0.61467300E+05, -.28798500E+05, -.88015100E+04, -.30456600E+05, -.12280700E+05, -.21744300E+05, 0.52587900E+04, 0.24341600E+05, 0.12534600E+04, -.18621300E+05, -.25893900E+05, 0.68421500E+04, -.18510400E+04, 0.32802600E+04, -.38577100E+04, 0.18615200E+05, 0.40840200E+05, -.23690400E+05, -.20651300E+05, -.34102100E+05, 0.33792500E+05, -.24487200E+04, 0.10891500E+04, 0.22055300E+04, -.12889100E+05, -.21512800E+03, -.11165500E+05, -.34981300E+05, 0.19098500E+05, 0.16730000E+05, 0.20245400E+05, -.25268100E+05, -.96112700E+04, -.44882000E+04, 0.22181900E+04, -.15717800E+04, 0.23908200E+04, -.11040400E+05, -.23396100E+05, 0.12194900E+05, 0.84095400E+04, 0.14472200E+05, -.18877400E+05, 0.20512700E+04, 0.76206300E+05, -.35234700E+05, 0.12442700E+05, -.39010800E+05, 0.50611400E+05, 0.10949300E+06, -.62106200E+05, -.25688000E+05, -.81358300E+05, 0.87072300E+05, -.36044700E+05, -.93342600E+05, 0.42473400E+05, 0.89501200E+04, 0.46058400E+05, 0.27269700E+05, 0.53454300E+05, -.18463800E+05, -.47623900E+05, -.20427300E+05, 0.44669400E+05, 0.41583500E+05, 0.38039700E+05, -.17971200E+05, 0.23337900E+04, -.19228500E+05, 0.13020400E+05, 0.30125000E+05, -.18823900E+05, -.37449900E+04, -.25740100E+05, 0.23495600E+05, -.18149900E+05, -.98963400E+05, 0.48899100E+05, 0.24075400E+05, 0.49789200E+05, -.41083000E+05, -.92921500E+05, 0.53652900E+05, 0.36779000E+04, 0.59604900E+05, -.72610600E+05, 0.38991900E+05, -.31805000E+04, 0.84672400E+03, 0.33657200E+05, 0.10390500E+04, 0.28197100E+05, 0.59767400E+05, -.29995400E+05, -.27525100E+05, -.40261000E+05, 0.49253900E+05, -.36341800E+04, -.45135900E+05, 0.22387500E+05, 0.11402000E+05, 0.22437000E+05, 0.11258800E+05, 0.23787900E+05, -.74999400E+04, -.22053100E+05, -.82824900E+04, 0.20447200E+05, 0.17858000E+05, 0.16016200E+05, -.56207700E+04, -.15796300E+05, -.69832200E+04, -.62196600E+05, -.12691800E+06, 0.56427800E+05, 0.42965400E+05, 0.61807800E+05, -.10356000E+06, -.51258200E+04, 0.59789300E+05, -.30429200E+05, 0.20221200E+04, -.29978100E+05, 0.26661000E+05, 0.55587200E+05, -.32143400E+05, -.52494900E+04, -.40117500E+05, 0.43096500E+05, -.26381600E+05, 0.26590900E+05, -.12239100E+05, -.78142700E+04, -.13037500E+05, -.13545200E+05, -.27810700E+05, 0.11711700E+05, 0.18674200E+05, 0.12114200E+05, -.22726500E+05, -.12510600E+05, -.12957800E+05, 0.76705800E+04, -.53745400E+04, 0.68619100E+04, -.30922700E+05, -.66185800E+05, 0.30891600E+05, 0.13856800E+05, 0.30021600E+05, -.50208300E+05, 0.18688500E+04, 0.18081800E+05, -.77433700E+04, 0.10048300E+05, -.98203900E+04, 0.39270300E+05, 0.84072800E+05, -.46239400E+05, -.35396700E+05, -.57860700E+05, 0.68249100E+05, -.83354800E+04, -.11569000E+05, 0.89199400E+04, -.15465500E+05, 0.64225600E+04, -.36917900E+05, -.80746800E+05, 0.39722400E+05, 0.22556200E+05, 0.39729500E+05, -.61573900E+05, 0.11702700E+04, -.29164100E+05, 0.14569900E+05, 0.75842700E+04, 0.13787800E+05, 0.28218900E+05, 0.57930600E+05, -.24953700E+05, -.24592500E+05, -.16825100E+05, 0.46765600E+05, 0.12599800E+05, -.40275800E+04, 0.20572300E+04, -.24439900E+04, 0.21795400E+04, -.12845200E+05, -.26955600E+05, 0.13756800E+05, 0.94615700E+04, 0.15857600E+05, -.21678900E+05, 0.19696600E+04, -.59425700E+04, 0.23546300E+04, -.12121500E+05, 0.32085600E+04, -.19486500E+05, -.45435900E+05, 0.23998900E+05, 0.19959500E+05, 0.31610600E+05, -.36641900E+05, 0.38900000E+04, 0.70850300E+05, -.35317300E+05, -.65780600E+05, -.35617900E+05, 0.33220300E+05, 0.80227600E+05, -.45056100E+05, -.28489100E+03, -.37686600E+05, 0.63117300E+05, -.15252500E+05, -.63837300E+04, 0.48250200E+04, 0.55975900E+05, 0.34603400E+04, -.24022100E+05, -.64708500E+05, 0.33788700E+05, 0.16996300E+05, 0.20130900E+05, -.49780500E+05, -.21398900E+05, 0.37715900E+04, -.51786500E+05, -.15664900E+05, -.15728900E+04, -.24841100E+05, 0.27134500E+05, 0.22423400E+03, -.59725100E+05, -.10854100E+04, 0.68857400E+04, 0.37268800E+05, -.34982400E+05, 0.27583300E+05, 0.11787600E+05, 0.22964400E+05, 0.51982900E+04, 0.10603200E+05, -.25626500E+05, -.35450500E+05, -.10500800E+03, 0.32032300E+05, 0.69384500E+04, 0.38396400E+04, -.17037600E+05, 0.39487600E+05, 0.47359900E+05 },
        { -.30491200E-01, -.42257500E+00, 0.20141500E+05, -.10908900E+04, 0.15680100E+05, 0.23763100E+05, -.12673000E+05, -.14184600E+05, -.23281400E+05, 0.18785300E+05, -.85490700E+04, 0.12798900E+05, -.29964800E+04, 0.28633900E+05, -.82298200E+04, 0.64496100E+05, 0.10359900E+06, -.54653800E+05, -.47215600E+05, -.81914900E+05, 0.86210700E+05, -.36135000E+05, 0.38467100E+05, -.19824700E+05, -.24169900E+05, -.18961300E+05, -.47745600E+05, -.67925100E+05, 0.24430800E+05, 0.26358800E+05, 0.21202300E+05, -.55184500E+05, 0.95003300E+04, -.11121600E+06, 0.55315900E+05, 0.29154500E+05, 0.54586500E+05, 0.32037400E+05, 0.47379900E+05, -.11808700E+05, -.46446400E+05, -.14154300E+05, 0.42128300E+05, 0.32040300E+05, 0.61972700E+05, -.30845900E+05, -.73709900E+04, -.30250600E+05, -.17402600E+05, -.21174900E+05, 0.47039200E+04, 0.24824900E+05, 0.36872100E+04, -.19055700E+05, -.17971300E+05, -.27814300E+05, 0.15139000E+05, 0.12589800E+05, 0.12808400E+05, 0.25613300E+05, 0.37745100E+05, -.17335300E+05, -.26629900E+05, -.26955300E+05, 0.32711800E+05, -.10963100E+04, -.57380400E+04, 0.30747400E+04, -.42119100E+04, 0.37293100E+04, -.17303500E+05, -.26363200E+05, 0.14509800E+05, 0.11204200E+05, 0.21097900E+05, -.20362400E+05, 0.11190600E+05, 0.58528000E+03, -.98567200E+03, -.16760200E+04, 0.91744600E+02, -.14332700E+05, -.21268500E+05, 0.10386500E+05, 0.86552300E+04, 0.13672000E+05, -.17717600E+05, 0.58441900E+04, 0.22355100E+05, -.68462800E+04, 0.20939100E+05, -.13565000E+05, 0.63494600E+05, 0.99580800E+05, -.49655800E+05, -.31422500E+05, -.67793000E+05, 0.81545200E+05, -.32583700E+05, -.92910200E+05, 0.46159000E+05, 0.71187100E+04, 0.44864100E+05, 0.39421900E+05, 0.50429900E+05, -.16689900E+05, -.47717700E+05, -.24794700E+05, 0.44393400E+05, 0.18195100E+05, 0.25852400E+05, -.11417800E+05, 0.45530300E+04, -.13481000E+05, 0.16793000E+05, 0.26700500E+05, -.15124600E+05, -.40707500E+04, -.22382400E+05, 0.21425100E+05, -.21075700E+05, -.74005700E+05, 0.34535000E+05, 0.23888500E+05, 0.37807500E+05, -.51195500E+05, -.82372000E+05, 0.43987300E+05, 0.34670600E+04, 0.51962200E+05, -.65990300E+05, 0.46176800E+05, -.10184500E+05, 0.58958100E+04, 0.33447500E+05, 0.36511600E+04, 0.35313300E+05, 0.54099500E+05, -.26203200E+05, -.27473900E+05, -.41244300E+05, 0.46141900E+05, -.12524400E+05, -.63449200E+05, 0.31682000E+05, 0.17354300E+05, 0.31427100E+05, 0.15586600E+05, 0.22201100E+05, -.35931900E+04, -.24510900E+05, -.56192600E+04, 0.20022200E+05, 0.17852300E+05, 0.49966000E+05, -.26090300E+05, -.20248200E+05, -.22254300E+05, -.80337200E+05, -.11712600E+06, 0.46789200E+05, 0.47411000E+05, 0.57927700E+05, -.98602000E+05, 0.17720500E+05, 0.65152400E+05, -.30178300E+05, -.34882200E+04, -.32782000E+05, 0.32315800E+05, 0.50525700E+05, -.31018700E+05, -.35719800E+04, -.40858000E+05, 0.39926300E+05, -.40067400E+05, 0.35184300E+05, -.17867300E+05, -.87491700E+04, -.16916400E+05, -.18556000E+05, -.25687900E+05, 0.92159200E+04, 0.19431600E+05, 0.10939300E+05, -.21906100E+05, -.67587400E+04, 0.13554100E+04, -.13946000E+04, -.44720600E+04, 0.34223400E+03, -.40064300E+05, -.59856000E+05, 0.25503900E+05, 0.13767800E+05, 0.24908000E+05, -.47379000E+05, 0.13730400E+05, -.18032700E+05, 0.12329900E+05, 0.11813400E+05, 0.69634800E+04, 0.51038800E+05, 0.76429800E+05, -.37704100E+05, -.39671800E+05, -.49217600E+05, 0.63944200E+05, -.10522700E+05, 0.75857500E+04, -.39822000E+04, -.12779000E+05, -.20840000E+04, -.48375500E+05, -.72086800E+05, 0.32415200E+05, 0.22293500E+05, 0.33089700E+05, -.57412000E+05, 0.15864400E+05, -.67443600E+05, 0.34175400E+05, 0.62282000E+04, 0.31547000E+05, 0.36790700E+05, 0.53049000E+05, -.16635100E+05, -.27794300E+05, -.66588400E+04, 0.43727100E+05, 0.21385000E+05, 0.16154700E+04, -.15312100E+04, -.22381600E+04, -.37323100E+03, -.16567300E+05, -.24560800E+05, 0.11749500E+05, 0.97854900E+04, 0.15004800E+05, -.20396500E+05, 0.61362400E+04, 0.63731000E+04, -.47191300E+04, -.13685200E+05, -.26148600E+04, -.23766100E+05, -.39137700E+05, 0.19534900E+05, 0.21551500E+05, 0.30584200E+05, -.32841000E+05, 0.10847300E+05, 0.60277200E+05, -.28851500E+05, -.67515900E+05, -.30649000E+05, 0.44001100E+05, 0.68998600E+05, -.36612300E+05, 0.17261300E+04, -.35369800E+05, 0.55887000E+05, -.34165400E+05, -.41968000E+04, 0.15410800E+04, 0.61406800E+05, 0.28057600E+04, -.36464300E+05, -.52877700E+05, 0.25403000E+05, 0.11610600E+05, 0.19452700E+05, -.42631600E+05, 0.77256800E+04, -.10368400E+04, -.52299300E+05, -.23610600E+05, -.33054900E+04, -.26105900E+05, 0.22480800E+05, 0.45457300E+04, -.59263000E+05, -.72178200E+03, 0.49610000E+04, 0.30700900E+05, -.31483800E+05, 0.26460900E+05, 0.11910100E+05, 0.27060500E+05, 0.32468800E+04, 0.17766300E+05, -.26658800E+05, -.36889700E+05, -.12203100E+04, 0.35792600E+05, 0.55301500E+04, 0.29277300E+04, -.26001700E+05, 0.36944900E+05, 0.45672800E+05 },
        { 0.15435500E+00, -.51949500E+00, 0.17603600E+01, 0.17155100E+05, -.37767500E+05, -.45346700E+05, 0.43311200E+05, 0.75985000E+05, 0.87061100E+05, -.39122000E+05, 0.36081100E+04, 0.20322700E+06, -.10492300E+06, -.10695600E+05, -.74791800E+05, -.16976000E+06, -.24393700E+06, 0.15085200E+06, 0.27102400E+06, 0.22669700E+06, -.22041600E+06, -.40281800E+05, -.38805500E+06, 0.19488300E+06, -.73146700E+05, 0.18999100E+06, 0.14584600E+06, 0.16648800E+06, -.49229400E+05, -.15108900E+06, 0.18145900E+05, 0.14223400E+06, 0.13731500E+06, 0.41160100E+06, -.20435100E+06, -.19050500E+05, -.19185700E+06, -.12030400E+06, -.17932100E+06, 0.85048700E+05, 0.23935200E+06, 0.76295100E+05, -.16933000E+06, -.15691500E+06, -.22450900E+06, 0.11186100E+06, -.17453700E+05, 0.10045500E+06, 0.75890200E+05, 0.84853300E+05, -.37745300E+05, -.11780200E+06, -.25674600E+05, 0.78552400E+05, 0.85954600E+05, 0.19130800E+06, -.97036000E+05, -.24674100E+05, -.79559800E+05, -.96768100E+05, -.11988200E+06, 0.72808700E+05, 0.15508300E+06, 0.87112000E+05, -.11027500E+06, -.69634000E+05, 0.54804500E+05, -.27493100E+05, -.90905700E+05, -.40838300E+05, 0.38480800E+05, 0.46651400E+05, -.58030100E+05, -.72802300E+05, -.88746400E+05, 0.38114300E+05, -.19697500E+05, -.58948900E+05, 0.30371400E+05, -.14860900E+05, 0.23437700E+05, 0.42069700E+05, 0.57122000E+05, -.34386100E+05, -.58367100E+05, -.36343300E+05, 0.51516100E+05, 0.19473300E+05, 0.28784700E+06, -.14872400E+06, 0.74363300E+04, -.10621800E+06, -.19000000E+06, -.26674500E+06, 0.15022100E+06, 0.26437800E+06, 0.15979400E+06, -.23937700E+06, -.11016000E+06, 0.34250100E+06, -.17035000E+06, 0.46185900E+05, -.14662200E+06, -.14440000E+06, -.16930700E+06, 0.83777900E+05, 0.22519800E+06, 0.10047000E+06, -.15436000E+06, -.11864800E+06, 0.45091000E+03, -.21883800E+04, 0.88980900E+04, 0.86881600E+04, -.35754000E+05, -.56830900E+05, 0.36068600E+05, 0.43653400E+05, 0.51340500E+05, -.49974900E+05, 0.11963700E+05, -.28625800E+05, 0.17777900E+05, -.17859700E+06, 0.17045100E+04, 0.11571700E+06, 0.17153300E+06, -.10569500E+06, -.11946400E+06, -.94993800E+05, 0.14743900E+06, 0.18086600E+05, 0.14270200E+06, -.71962800E+05, -.50616000E+05, -.48805600E+05, -.10203000E+06, -.14844800E+06, 0.96699200E+05, 0.17217900E+06, 0.14070600E+06, -.14056200E+06, -.33548100E+05, 0.20672700E+06, -.10262000E+06, -.20197500E+05, -.99797400E+05, -.54792700E+05, -.84321200E+05, 0.33254400E+05, 0.11426600E+06, 0.37911000E+05, -.79895100E+05, -.75589000E+05, -.59485400E+06, 0.29869300E+06, -.35605700E+05, 0.25349900E+06, 0.26209200E+06, 0.31506800E+06, -.12226700E+06, -.28649500E+06, -.94308600E+05, 0.28187000E+06, 0.19257700E+06, -.39671100E+05, 0.16342600E+05, 0.49054800E+05, 0.22748400E+05, -.58075600E+05, -.83821600E+05, 0.59387600E+05, 0.54649000E+05, 0.74342300E+05, -.69494800E+05, 0.28469900E+05, -.17067600E+06, 0.85531100E+05, -.10795200E+05, 0.74727400E+05, 0.67564000E+05, 0.85225500E+05, -.42513100E+05, -.10403300E+06, -.34586700E+05, 0.77271100E+05, 0.67013200E+05, -.23352500E+06, 0.11741100E+06, -.59675700E+05, 0.10033400E+06, 0.12422300E+06, 0.14705900E+06, -.62526900E+05, -.11284800E+06, -.14851000E+05, 0.12283300E+06, 0.87402700E+05, 0.31219600E+06, -.15962600E+06, 0.39465700E+05, -.12360000E+06, -.17222100E+06, -.21809000E+06, 0.12889700E+06, 0.25456500E+06, 0.12758200E+06, -.19592600E+06, -.13297000E+06, -.28806700E+06, 0.14362300E+06, -.50658700E+05, 0.11627300E+06, 0.15321100E+06, 0.18144300E+06, -.89643300E+05, -.15861600E+06, -.37665400E+05, 0.15321700E+06, 0.10697100E+06, 0.48875900E+06, -.24428800E+06, 0.11111600E+06, -.20788200E+06, -.15753500E+06, -.19340000E+06, 0.68384500E+05, 0.21115800E+06, -.26772700E+05, -.17216900E+06, -.22820900E+06, -.77096000E+05, 0.39481200E+05, -.18415200E+05, 0.31717900E+05, 0.49537900E+05, 0.65414200E+05, -.37215200E+05, -.65648400E+05, -.36739500E+05, 0.58663200E+05, 0.26434500E+05, -.94561600E+05, 0.48681300E+05, 0.11897500E+05, 0.39549200E+05, 0.63893900E+05, 0.93502800E+05, -.56861800E+05, -.11113700E+06, -.90326100E+05, 0.84817800E+05, 0.19375800E+05, 0.97914900E+04, -.71456500E+04, 0.32325600E+06, 0.32550000E+04, -.11707700E+06, -.15528900E+06, 0.96167600E+05, 0.87254200E+05, 0.53583100E+05, -.13141100E+06, -.22411100E+05, -.60972700E+05, 0.31704900E+05, -.34766300E+06, 0.19281100E+05, 0.11720400E+06, 0.14271500E+06, -.98839300E+05, -.11960100E+06, -.52813100E+05, 0.11976200E+06, 0.59179900E+05, 0.60606900E+05, 0.16398600E+06, 0.62392200E+05, 0.13801600E+05, 0.74705400E+05, -.32996700E+05, 0.43547300E+05, 0.18587200E+06, -.13894400E+05, -.35001400E+05, -.56349000E+05, 0.91296700E+05, -.11406100E+06, -.69005600E+05, -.82048700E+05, 0.16431300E+05, -.76581100E+05, 0.59515700E+05, 0.11335400E+06, -.43371600E+05, -.16206200E+06, 0.13340000E+05, -.15401400E+05, 0.67053000E+05, -.10920300E+06, -.12134500E+06 },
        { -.92384400E-01, -.37935300E-01, -.22808500E+01, -.15548600E+00, 0.21354200E+05, 0.20566900E+05, 0.21030100E+04, 0.52366600E+04, -.25843400E+05, 0.15301100E+05, -.24135200E+05, 0.98968100E+04, -.12281400E+04, -.61471900E+05, -.52068500E+04, 0.94658200E+05, 0.10829700E+06, -.15136400E+05, 0.13248400E+05, -.73565700E+05, 0.81412300E+05, -.65080800E+05, 0.18023100E+06, -.91081100E+05, 0.69066200E+05, -.90083300E+05, -.85864400E+05, -.90301600E+05, -.13824000E+05, 0.16684400E+05, -.31221500E+05, -.68580200E+05, -.35689600E+05, -.20779500E+06, 0.10216300E+06, -.44630500E+05, 0.10361800E+06, 0.29642600E+05, 0.53341100E+04, 0.69704700E+05, 0.64827600E+04, 0.42996800E+05, -.29108700E+04, 0.55275400E+05, 0.92259100E+05, -.45901400E+05, 0.41022300E+05, -.46159600E+05, -.18451900E+05, -.12711700E+05, -.25020800E+05, 0.66432800E+04, -.15062600E+05, -.88727200E+04, -.20851000E+05, -.36701100E+05, 0.18861900E+05, -.29788300E+05, 0.18194500E+05, 0.27540400E+05, 0.24099600E+05, 0.21902000E+05, 0.87377600E+04, -.11580700E+05, 0.17165800E+05, -.13263700E+05, 0.13448900E+04, -.50955900E+03, 0.54108500E+05, -.66011700E+03, -.25626600E+05, -.21572700E+05, -.10416900E+05, -.22611600E+05, 0.15270200E+05, -.14415100E+05, 0.27275300E+05, -.55669800E+03, -.57052600E+03, 0.25564200E+05, 0.27936100E+03, -.20060900E+05, -.18181000E+05, -.51612600E+04, -.10035200E+05, 0.83069600E+04, -.12257600E+05, 0.13805500E+05, -.10054200E+04, 0.55990400E+04, -.69407200E+05, 0.52411000E+03, 0.93106500E+05, 0.80305200E+05, 0.24293400E+05, 0.54802000E+05, -.28041000E+05, 0.50712500E+05, -.50524700E+05, -.12358800E+06, 0.61428700E+05, -.75658300E+05, 0.61743200E+05, 0.56406900E+05, 0.54873300E+05, 0.17930600E+05, -.15120300E+05, -.12962100E+05, 0.43477900E+05, 0.42567700E+04, 0.28977000E+05, -.12615000E+05, -.10530100E+05, -.14463600E+05, 0.30082700E+05, 0.27952600E+05, -.64427500E+04, 0.14494000E+05, -.21900000E+05, 0.19536900E+05, -.33728000E+05, -.31250600E+05, 0.12749300E+05, 0.13218600E+06, 0.15631400E+05, -.10250200E+06, -.10843400E+06, 0.12852800E+05, -.52333300E+05, 0.22891900E+05, -.77755200E+05, 0.47842100E+05, 0.38806500E+05, -.19157800E+05, -.14780400E+05, -.19418600E+05, 0.32648500E+05, 0.22190100E+05, 0.23070800E+05, 0.33269300E+05, -.39283300E+05, 0.11179400E+05, -.53214300E+05, -.12764900E+06, 0.62665500E+05, -.14600000E+04, 0.63678500E+05, 0.22177100E+05, 0.87528500E+04, 0.28516300E+05, -.66396500E+04, 0.21486700E+05, 0.51121800E+04, 0.33220200E+05, 0.26909300E+04, -.27059900E+04, 0.16706800E+06, -.14787300E+04, -.10162900E+06, -.11755000E+06, -.10115000E+05, -.15855400E+05, 0.53654400E+05, -.86875900E+05, 0.64643800E+05, 0.90132700E+05, -.40947300E+05, -.46965600E+05, -.45109200E+05, 0.58924300E+05, 0.79718800E+05, -.35296800E+05, 0.15613700E+05, -.50719400E+05, 0.61193500E+05, -.63220400E+05, 0.61208200E+05, -.30815000E+05, 0.31559700E+05, -.30601900E+05, -.22767600E+05, -.16941300E+05, -.20117400E+05, -.25057200E+04, -.64851600E+04, -.10562800E+05, -.74496200E+04, -.41571500E+05, 0.19950500E+05, 0.10899000E+06, 0.20734800E+05, -.48185100E+05, -.59283600E+05, -.73246700E+04, -.24786500E+05, 0.20584300E+05, -.38966000E+05, 0.39894500E+05, -.85666500E+05, 0.46416800E+05, -.84858400E+05, 0.42861800E+05, 0.72811100E+05, 0.64938200E+05, 0.31717300E+05, 0.20648100E+05, -.27862900E+04, 0.45768400E+05, -.85371900E+04, -.24243900E+05, 0.12014600E+05, 0.12826800E+06, 0.12005700E+05, -.51212300E+05, -.56996000E+05, -.21372100E+05, -.31648500E+05, 0.16168100E+05, -.34316000E+05, 0.42066600E+05, -.26820200E+06, 0.13355500E+06, -.99371000E+05, 0.13440300E+06, 0.63325200E+05, 0.28750900E+05, 0.70380400E+05, 0.16820100E+05, 0.94319600E+05, 0.12059100E+05, 0.10051200E+06, 0.19327700E+04, -.18578800E+04, 0.31514600E+05, -.96604700E+03, -.23085000E+05, -.21932600E+05, -.54413800E+04, -.10029400E+05, 0.84307600E+04, -.15035400E+05, 0.13606800E+05, 0.20469700E+05, -.12728900E+05, 0.18293200E+05, -.10069100E+05, -.34766400E+05, -.42624600E+05, 0.44968800E+04, 0.15753400E+04, 0.25476700E+05, -.32911800E+05, 0.18720800E+05, 0.77457800E+05, -.36919800E+05, -.22945800E+06, -.38712700E+05, 0.89175200E+05, 0.98347300E+05, -.16442000E+05, 0.59104700E+05, -.28099800E+05, 0.72066000E+05, -.57507500E+05, 0.25194600E+05, -.13517700E+05, 0.22462900E+06, -.12607900E+05, -.74721600E+05, -.69174600E+05, -.13066800E+05, -.47785900E+05, -.46152700E+04, -.49300900E+05, 0.17168300E+05, -.34439100E+04, -.69503800E+05, -.47784400E+05, -.33269700E+05, -.40395900E+05, 0.18136400E+05, 0.26763300E+05, -.73722300E+05, 0.46594000E+04, 0.89763200E+03, 0.12249000E+04, -.48644200E+05, 0.18138200E+04, 0.37185400E+05, 0.26823500E+05, -.25119300E+04, 0.30200300E+05, -.36090800E+05, -.24788000E+05, -.28409100E+05, 0.59182000E+05, 0.23449900E+05, 0.56431400E+04, -.52041400E+05, 0.45962500E+04, 0.25365400E+05 },
        { -.35400200E+00, -.40171300E+01, 0.16272300E+01, 0.33769100E-01, 0.30578500E-01, 0.55666000E+05, -.33618200E+05, -.51159200E+05, -.84773100E+05, 0.39289300E+05, 0.24025800E+05, -.20412500E+06, 0.12569700E+06, -.52991200E+05, 0.10182300E+06, 0.94669700E+05, 0.28689300E+06, -.11806100E+06, -.17407200E+06, -.16684300E+06, 0.22670400E+06, 0.10922600E+06, 0.35222700E+06, -.17743200E+06, 0.17176000E+06, -.17608300E+06, -.10076000E+06, -.20020800E+06, 0.49071100E+05, 0.11457300E+06, -.33580800E+05, -.15456000E+06, -.20427700E+06, -.33802700E+06, 0.17375500E+06, -.12561000E+06, 0.16875300E+06, 0.46624000E+05, 0.15004300E+06, -.43359200E+05, -.14964400E+06, -.33391400E+05, 0.12364100E+06, 0.16133400E+06, 0.22399600E+06, -.11161700E+06, 0.73793000E+05, -.11202600E+06, -.29758000E+05, -.66945300E+05, 0.88971000E+04, 0.76417500E+05, -.66049300E+04, -.54673100E+05, -.10579800E+06, 0.73619300E+04, 0.62361800E+04, -.63037900E+05, -.38240900E+04, 0.31062400E+05, 0.10224600E+06, -.60161300E+05, -.62559400E+05, -.10768500E+06, 0.82541500E+05, 0.18281800E+05, -.74009700E+04, 0.50810700E+04, 0.11531700E+06, 0.37119900E+04, 0.14145500E+05, -.67356500E+05, 0.42540500E+05, 0.49908600E+05, 0.76424900E+05, -.42285900E+05, -.48745100E+05, 0.37700600E+05, -.22607500E+05, 0.41962900E+05, -.18849400E+05, -.17969000E+05, -.55797900E+05, 0.23924500E+05, 0.33315400E+05, 0.29549400E+05, -.44124300E+05, -.26356500E+05, -.90569300E+04, 0.30632700E+05, -.14644800E+06, 0.45504700E+04, 0.91317500E+05, 0.25700400E+06, -.13219900E+06, -.11914600E+06, -.17615200E+06, 0.20184600E+06, 0.41167000E+05, -.36300700E+06, 0.18060200E+06, -.13145800E+06, 0.18145600E+06, 0.51772300E+05, 0.15691200E+06, -.41545600E+05, -.15976800E+06, -.53510200E+05, 0.12545600E+06, 0.18974900E+06, 0.48631900E+05, -.16188300E+05, -.31401600E+05, -.24292800E+05, 0.16334300E+05, 0.65780900E+05, -.40398300E+05, -.25457800E+05, -.60011100E+05, 0.50342400E+05, -.11963900E+05, -.17914500E+05, -.41648300E+04, 0.28028700E+06, 0.89629600E+04, -.64212000E+05, -.21118700E+06, 0.10460800E+06, 0.56746700E+05, 0.83203300E+05, -.15900500E+06, -.54512200E+05, -.26531600E+05, 0.20859600E+05, -.27792400E+05, 0.13252600E+05, 0.26420300E+05, 0.12150300E+06, -.64514400E+05, -.89921500E+05, -.12958000E+06, 0.10027900E+06, 0.13400600E+05, -.13131100E+06, 0.70133600E+05, -.53212600E+05, 0.65516200E+05, 0.24780600E+05, 0.73355200E+05, -.26783700E+05, -.71402900E+05, -.31647400E+05, 0.60594500E+05, 0.65034700E+05, 0.40486000E+06, -.20892100E+06, 0.24763500E+06, -.20255400E+06, -.12396000E+06, -.31849400E+06, 0.10264800E+06, 0.19725100E+06, 0.82404800E+05, -.25436700E+06, -.22866700E+06, -.62954100E+05, 0.39619300E+05, -.40197000E+05, 0.31436500E+05, 0.39809900E+05, 0.11824100E+06, -.43292200E+05, -.46694200E+05, -.43926100E+05, 0.90077400E+05, 0.47661100E+05, 0.14672200E+06, -.75225100E+05, 0.60773500E+05, -.73359200E+05, -.28170200E+05, -.77102400E+05, 0.23075500E+05, 0.66450400E+05, 0.18846400E+05, -.61010800E+05, -.81820100E+05, 0.15129100E+06, -.79835300E+05, 0.15504500E+06, -.75693100E+05, -.52470900E+05, -.15906400E+06, 0.54541500E+05, 0.73234000E+05, 0.28264900E+05, -.11278900E+06, -.11650200E+06, -.15869900E+06, 0.10025700E+06, -.15119100E+06, 0.79377100E+05, 0.76941800E+05, 0.21033600E+06, -.89767500E+05, -.13048600E+06, -.11228900E+06, 0.16812800E+06, 0.10434900E+06, 0.20189000E+06, -.10272300E+06, 0.17233700E+06, -.10105300E+06, -.58345800E+05, -.18854300E+06, 0.68245200E+05, 0.98162300E+05, 0.36103300E+05, -.13316000E+06, -.14738400E+06, -.41743700E+06, 0.21514600E+06, -.22921200E+06, 0.20900100E+06, 0.93608000E+05, 0.18075900E+06, -.35869200E+05, -.12205600E+06, 0.67773400E+05, 0.14393300E+06, 0.21652900E+06, 0.54518700E+05, -.31177800E+05, 0.51053000E+05, -.27259000E+05, -.22071500E+05, -.64699800E+05, 0.25859100E+05, 0.38526500E+05, 0.28415100E+05, -.50937200E+05, -.35020700E+05, 0.95718200E+05, -.57186400E+05, 0.16674700E+05, -.47703600E+05, -.40109700E+05, -.11627600E+06, 0.47846100E+05, 0.75934800E+05, 0.63377000E+05, -.92272200E+05, -.50749000E+05, 0.38150000E+05, -.12077400E+05, -.46992300E+06, -.19059900E+05, 0.43730200E+05, 0.19243900E+06, -.98870800E+05, -.31130000E+05, -.48408000E+05, 0.14312200E+06, 0.84215400E+05, 0.65890000E+05, -.36072500E+05, 0.48760600E+06, -.32954900E+05, -.24742300E+05, -.17244100E+06, 0.82305200E+05, 0.65230400E+05, 0.32567700E+05, -.12370900E+06, -.15667500E+06, -.44054300E+05, -.15397100E+06, -.22853000E+05, -.43496800E+05, -.43695000E+05, 0.36498800E+05, -.62973400E+05, -.17667000E+06, 0.18228300E+05, 0.53052300E+05, 0.42933900E+05, -.11498600E+06, 0.83037100E+05, 0.74264300E+05, 0.89925700E+04, -.14623900E+05, 0.40582200E+05, -.52190800E+05, -.84728300E+05, 0.33337800E+05, 0.16099500E+06, -.26976300E+04, 0.20720700E+05, -.10296500E+05, 0.75251600E+05, 0.90776700E+05 },
        { 0.63361500E-01, 0.94042200E-01, 0.25525800E+00, 0.99932000E-02, -.42645300E-01, 0.27427300E-01, -.11130000E+05, -.15634800E+05, -.64627300E+03, 0.53157100E+03, 0.80676600E+04, -.12830400E+05, 0.52327300E+04, 0.29458900E+05, 0.64414000E+04, -.14842500E+04, -.11081200E+05, -.20588700E+05, -.36916000E+05, -.60929800E+04, -.56181800E+04, 0.14798100E+05, -.46672500E+05, 0.23401400E+05, -.39523900E+05, 0.23333000E+05, 0.14588000E+05, 0.18227500E+05, 0.12639500E+05, 0.76232500E+04, 0.20749300E+05, 0.12160500E+05, 0.15950500E+05, 0.56232800E+04, -.29038700E+04, 0.46570100E+05, -.27833400E+04, 0.98431200E+04, 0.10674800E+05, -.29641000E+05, -.24827700E+05, -.16845200E+05, 0.12561500E+05, 0.16013100E+04, -.17042000E+05, 0.84702200E+04, -.23982700E+05, 0.85240300E+04, -.23529300E+04, -.52281800E+04, 0.18556300E+05, 0.14277800E+05, 0.13597700E+05, -.58478300E+04, 0.31244600E+04, -.29959400E+04, 0.10412800E+04, 0.16153900E+05, 0.15137400E+04, 0.37586900E+04, 0.42648700E+04, -.21529400E+05, -.25598700E+05, -.95568300E+04, 0.56533600E+04, 0.76945100E+04, -.57888500E+04, 0.28632500E+04, -.16496000E+05, 0.28931500E+04, 0.12992100E+03, -.49188300E+03, 0.17475200E+05, 0.22976700E+05, 0.49756300E+04, -.12486000E+04, -.75516700E+04, 0.41511600E+04, -.18674900E+04, -.12561000E+05, -.20756800E+04, -.45428600E+03, 0.20613300E+03, 0.71485800E+04, 0.93889400E+04, 0.22308900E+04, -.87331500E+03, -.38370400E+04, -.31908500E+05, 0.14608400E+05, 0.46083900E+05, 0.15952000E+05, -.49366900E+03, -.56248500E+04, -.22542500E+05, -.36213700E+05, -.59335600E+04, 0.52482000E+03, 0.19311900E+05, 0.30159400E+05, -.14957900E+05, 0.37523500E+05, -.15074600E+05, -.51286400E+03, 0.46509800E+03, -.27274700E+05, -.24805200E+05, -.18045500E+05, 0.24123700E+04, -.36665800E+04, -.14405700E+05, 0.67498300E+04, 0.77851700E+04, 0.72003500E+04, -.22988600E+04, -.54191600E+04, 0.79123000E+03, -.52503000E+04, 0.49799900E+04, -.36845900E+04, 0.87571600E+04, -.39400900E+04, 0.26928600E+04, -.46487000E+05, 0.19694100E+04, 0.13301700E+05, 0.21412900E+05, 0.81436200E+04, 0.20336400E+05, 0.80131200E+04, 0.14733000E+05, -.24687800E+04, -.48572100E+05, 0.23944300E+05, 0.28939600E+05, 0.24287600E+05, 0.10634700E+05, 0.10257900E+05, -.19348300E+05, -.28829800E+05, 0.55013700E+04, 0.11484800E+05, 0.25990600E+05, 0.46509700E+04, -.24385700E+04, 0.18703000E+05, -.23105600E+04, 0.15902400E+04, 0.17106900E+04, -.90259600E+04, -.74709400E+04, -.57758200E+04, 0.26322800E+04, 0.45436300E+03, 0.45499900E+05, -.22381300E+05, -.95996300E+05, -.22736500E+05, -.20406400E+04, 0.38981000E+04, 0.22698500E+05, 0.30000300E+05, -.14894700E+04, -.24590400E+04, -.21435500E+05, 0.27504700E+04, -.19007000E+04, 0.71325700E+04, -.13708400E+04, -.69585000E+04, -.13443700E+05, -.38680800E+04, -.12657000E+05, -.22373700E+04, -.99040800E+04, 0.35318000E+04, -.75195400E+04, 0.38264800E+04, -.19769600E+05, 0.37595700E+04, -.14773400E+04, -.21678700E+04, 0.14300100E+05, 0.12702400E+05, 0.87127700E+04, -.34651700E+04, 0.48841100E+02, 0.21522300E+05, -.10571900E+05, -.50409000E+05, -.10756000E+05, -.11101100E+04, 0.14657100E+04, 0.16066000E+05, 0.18053300E+05, 0.26414300E+04, -.28818200E+04, -.99480000E+04, 0.20658100E+05, -.11353900E+05, 0.35516500E+05, -.10332000E+05, -.14131100E+04, -.26908200E+04, -.34684800E+05, -.38777500E+05, -.23383000E+05, 0.14331900E+04, 0.16010900E+04, 0.22336800E+05, -.11178700E+05, -.57466600E+05, -.11156700E+05, -.42435500E+04, -.22880300E+04, 0.24604100E+05, 0.27122800E+05, 0.68651500E+04, -.72085900E+04, -.12925500E+05, 0.51895700E+05, -.26152600E+05, 0.56764300E+05, -.25978500E+05, -.73822500E+04, -.72341200E+04, -.23663600E+05, -.12452400E+05, -.31795700E+05, -.20538700E+04, -.23164500E+05, 0.37464700E+04, -.16557200E+04, -.15341300E+05, -.18732600E+04, -.26153600E+03, 0.52737300E+03, 0.79603400E+04, 0.10161900E+05, 0.28758400E+04, -.78877000E+03, -.36690900E+04, -.18253100E+04, 0.14329800E+04, -.86021300E+04, 0.89577000E+03, 0.11668600E+04, 0.49788200E+04, 0.85672700E+04, 0.14321500E+05, 0.43143700E+04, 0.28759500E+04, -.41588400E+04, -.51847100E+04, 0.20602500E+04, 0.79364600E+05, 0.25907300E+04, -.11499200E+05, -.17531800E+05, -.93825200E+04, -.21692900E+05, -.46859600E+04, -.12240800E+05, 0.36647000E+04, -.27653400E+05, 0.14148700E+05, -.77231700E+05, 0.13827800E+05, 0.97835900E+04, 0.10406000E+05, 0.25054200E+05, 0.30839500E+05, 0.17586700E+05, 0.66991100E+04, 0.51117500E+04, -.23088800E+04, 0.85501500E+04, 0.41951800E+04, 0.15473900E+05, 0.39557700E+04, -.21941900E+04, -.44219800E+04, 0.74576900E+04, -.26148800E+04, -.19096600E+04, 0.11747300E+05, 0.10772200E+05, 0.13013900E+05, -.74844000E+04, 0.57452900E+04, 0.83202000E+03, 0.11328100E+04, 0.54722800E+04, -.62833000E+04, 0.85821400E+04, -.87005600E+04, -.87671000E+04, -.21684200E+04, 0.24499700E+04, 0.16425100E+05, 0.10082900E+05 },
        { 0.42798900E-01, 0.46065200E+00, -.13542100E+01, -.27375700E+00, 0.60224900E+00, 0.80234700E-01, 0.10749900E+01, -.13170900E+05, -.31037300E+05, 0.41081100E+04, -.13462900E+05, -.29931600E+05, 0.17947400E+05, 0.23242500E+05, 0.14686600E+05, 0.17932200E+05, 0.40781300E+05, -.24415600E+05, -.66362600E+05, -.87150100E+05, 0.47921500E+05, -.21140100E+05, 0.29789500E+05, -.14687400E+05, -.36636400E+05, -.14857600E+05, -.30935400E+04, -.50585500E+04, 0.24259800E+04, 0.28561700E+05, 0.30543400E+05, -.11650100E+05, 0.21765500E+05, 0.16143900E+05, -.67131900E+04, 0.18649700E+05, -.83949100E+04, 0.81026700E+04, 0.31091900E+05, -.26053300E+05, -.46445800E+05, -.74219400E+05, 0.35935200E+05, -.26136100E+05, -.47686000E+04, 0.25630600E+04, -.11260500E+05, 0.23463800E+04, -.40290700E+04, -.54910500E+04, 0.50845500E+04, 0.14477000E+05, 0.33048700E+05, -.90635200E+04, 0.16373400E+05, -.21528500E+05, 0.12885500E+05, 0.19242900E+05, 0.10596400E+05, 0.74164400E+04, 0.22437600E+05, -.12198300E+05, -.28561300E+05, -.36396500E+05, 0.24314800E+05, -.82737900E+04, -.50566200E+05, 0.25367600E+05, 0.15442100E+05, 0.25291400E+05, 0.64565400E+04, 0.92864000E+04, 0.11785900E+04, 0.58646600E+04, 0.50941500E+05, 0.15448700E+04, 0.42848200E+05, -.40955200E+04, 0.15663600E+04, -.14153500E+04, 0.20501300E+04, -.50080000E+03, -.61985000E+04, 0.57600600E+04, 0.12170900E+05, 0.20025700E+05, -.82826100E+04, 0.87471500E+04, -.19697400E+05, 0.12922900E+05, 0.17087500E+05, 0.98711000E+04, 0.16263900E+04, 0.41500600E+05, -.31325800E+05, -.66358300E+05, -.73301700E+05, 0.48085500E+05, -.11833400E+05, -.69568400E+04, 0.29528300E+04, 0.25260600E+05, 0.33948800E+04, 0.97435100E+04, 0.16043600E+05, -.94672600E+04, -.37818400E+05, -.70682400E+05, 0.23577600E+05, -.29404700E+05, 0.34717100E+04, -.69696800E+03, -.31176400E+04, -.17059500E+04, -.73466400E+03, 0.92266300E+04, -.78534900E+04, -.16353600E+05, -.19552500E+05, 0.11300200E+05, -.99091000E+04, -.54923800E+05, 0.25504700E+05, 0.12204500E+05, 0.27465300E+05, 0.97735000E+04, -.10484200E+05, 0.20415100E+05, 0.30465600E+05, 0.64271000E+05, -.19791900E+05, 0.41964400E+05, 0.13892900E+05, -.54733600E+04, -.10976700E+05, -.69648700E+04, 0.22012600E+04, 0.19881600E+05, -.19393200E+05, -.38709400E+05, -.63424200E+05, 0.25819300E+05, -.21196000E+05, 0.15503500E+04, 0.45768200E+03, 0.10649100E+05, -.94662100E+03, 0.55368600E+04, 0.18612100E+05, -.13070000E+05, -.25997000E+05, -.35232000E+05, 0.20489000E+05, -.11334500E+05, -.20934200E+04, 0.26463200E+03, -.23128400E+05, 0.87162800E+03, -.67872000E+04, -.19839400E+05, 0.18728500E+05, 0.56737300E+05, 0.97077600E+05, -.31304100E+05, 0.48565800E+05, -.23288700E+05, 0.11572000E+05, 0.81975100E+04, 0.11603400E+05, -.24578000E+03, 0.36469200E+03, 0.11461600E+04, -.15927700E+05, -.15859700E+05, 0.45194600E+04, -.14364100E+04, 0.51485800E+04, -.27599300E+04, -.12027000E+05, -.25698500E+04, -.28320000E+04, -.91281100E+04, 0.65477200E+04, 0.19055100E+05, 0.28209500E+05, -.12121200E+05, 0.96615400E+04, 0.33346600E+05, -.16986300E+05, -.25879500E+05, -.16737600E+05, -.64669100E+03, -.38140400E+04, 0.80518100E+03, 0.25949400E+05, 0.29438600E+05, -.10042600E+05, 0.79248900E+04, 0.43631200E+04, 0.41286400E+03, 0.17320800E+05, -.21586400E+04, 0.25313700E+04, 0.29026600E+05, -.23171200E+05, -.44050600E+05, -.70055700E+05, 0.33446900E+05, -.22133500E+05, 0.36116600E+05, -.17779600E+05, -.35933100E+05, -.18207100E+05, -.36773800E+04, -.94952800E+04, 0.43302800E+04, 0.34855400E+05, 0.42453200E+05, -.17122800E+05, 0.14066700E+05, 0.42159600E+05, -.19666500E+05, 0.16521000E+05, -.20734400E+05, -.76924100E+04, 0.20793200E+05, -.26657500E+05, -.32984600E+05, -.56717600E+05, 0.25184300E+05, -.27417000E+05, -.44819400E+04, 0.17449900E+04, -.22153500E+04, 0.22424700E+04, -.46571700E+03, -.61154700E+04, 0.59595400E+04, 0.13147500E+05, 0.22394400E+05, -.85633800E+04, 0.10001700E+05, 0.18739600E+05, -.97739800E+04, -.14680700E+05, -.91898200E+04, -.10648000E+05, -.17387200E+05, 0.86776400E+04, 0.27309800E+05, 0.33334400E+05, -.20062100E+05, 0.84082700E+04, 0.14858100E+06, -.72857500E+05, -.44382000E+05, -.74267200E+05, -.18730300E+05, -.89936900E+04, -.18822400E+05, -.38851800E+04, -.88146500E+05, 0.44411200E+04, -.88547300E+05, -.16216600E+06, 0.80221600E+05, 0.43583000E+05, 0.81065600E+05, 0.20094900E+05, 0.16842800E+05, 0.13574200E+05, -.78423200E+03, 0.97800800E+05, 0.18770700E+04, 0.10125200E+06, 0.45127600E+04, -.17174300E+05, 0.20488200E+05, -.71791800E+04, 0.22777300E+04, 0.10217800E+04, -.34874000E+04, -.26670100E+05, -.37285300E+04, -.36721700E+04, 0.12387400E+05, 0.11970800E+04, 0.75645300E+04, -.10183400E+05, 0.37338200E+03, 0.48673900E+04, -.10401000E+05, -.17424100E+05, -.53710500E+05, 0.47569200E+04, 0.46698700E+05, 0.63379600E+02, 0.16076500E+03, 0.27502100E+05, 0.26563100E+05, 0.35219600E+05 },
        { -.27015800E+00, 0.96996300E+00, -.21773100E+01, -.38166000E+00, 0.42099200E+00, 0.26105900E+00, 0.23566300E+01, 0.21680900E+01, 0.46305400E+05, -.91170200E+04, 0.22457300E+05, 0.10633900E+06, -.62776900E+05, -.10352700E+06, -.52915300E+05, -.44728200E+05, -.91953900E+05, 0.64518900E+05, 0.11759200E+06, 0.16974600E+06, -.11333100E+06, 0.14241600E+05, 0.23924800E+05, -.12217800E+05, 0.14076100E+06, -.11998200E+05, -.16011300E+05, -.79882100E+04, -.20262100E+05, -.38510000E+05, -.95550900E+05, 0.13542500E+05, -.75648700E+05, 0.18934200E+05, -.13459000E+05, -.13718300E+06, -.91551200E+04, -.49197300E+05, -.10316900E+06, 0.92345700E+05, 0.10885100E+06, 0.16921900E+06, -.11700600E+06, 0.38569400E+05, -.10086800E+05, 0.47761500E+04, 0.85328300E+05, 0.50824700E+04, 0.18457100E+05, 0.28939500E+05, -.27756900E+05, -.31839000E+05, -.76881700E+05, 0.37830300E+05, -.27826100E+05, 0.10245300E+06, -.56946700E+05, -.97256100E+05, -.51074600E+05, -.31506100E+05, -.68097900E+05, 0.42024800E+05, 0.64221500E+05, 0.75977300E+05, -.74017900E+05, -.47002600E+04, 0.12159500E+06, -.61269500E+05, -.11130500E+05, -.60800800E+05, -.15089700E+05, -.19638200E+05, -.50869700E+04, 0.28785900E+05, -.84951000E+05, -.34700500E+04, -.89215500E+05, -.84034500E+04, 0.56386400E+04, 0.28898300E+05, 0.41985300E+04, 0.45136400E+04, 0.18076300E+05, -.18986900E+05, -.25235900E+05, -.40194300E+05, 0.23778700E+05, -.10280700E+05, 0.12454100E+06, -.72171400E+05, -.13739600E+06, -.62290700E+05, -.19452200E+05, -.10855600E+06, 0.95589200E+05, 0.15054000E+06, 0.16134800E+06, -.12950000E+06, -.10678400E+05, -.23924700E+04, 0.20529200E+04, -.12772600E+06, 0.12959900E+04, -.24179800E+05, -.44990000E+05, 0.40449600E+05, 0.50502100E+05, 0.15137300E+06, -.64134300E+05, 0.63097600E+05, -.10310500E+05, 0.20632100E+04, 0.53089900E+04, 0.51255000E+04, 0.57325500E+04, -.13115900E+05, 0.16934500E+05, 0.26433600E+05, 0.35481700E+05, -.19293600E+05, 0.15338100E+05, 0.10139900E+06, -.45261900E+05, 0.61968900E+05, -.50699900E+05, -.36555700E+05, 0.51799300E+04, -.43592700E+05, -.49363400E+05, -.13212900E+06, 0.29857900E+05, -.77330900E+05, 0.82000300E+05, -.45210500E+05, -.40036000E+05, -.40982100E+05, -.34203200E+05, -.76646500E+05, 0.66247700E+05, 0.95945700E+05, 0.11436700E+06, -.90862300E+05, -.45409600E+04, 0.62098800E+03, -.38523100E+04, -.56667400E+05, -.14233300E+03, -.20483600E+05, -.50149100E+05, 0.40558200E+05, 0.55583100E+05, 0.83371900E+05, -.55987800E+05, 0.22152800E+05, -.18771900E+03, 0.25729600E+04, 0.17573900E+06, 0.27898900E+03, 0.24106100E+05, 0.61302000E+05, -.93153700E+05, -.11814000E+06, -.21560500E+06, 0.93992300E+05, -.85334300E+05, 0.55412800E+05, -.28320000E+05, -.32051200E+05, -.27673300E+05, 0.11589400E+05, 0.14533200E+05, -.93589300E+04, 0.17939900E+05, 0.22512500E+05, 0.20242000E+04, -.52537600E+04, -.19174500E+05, 0.10321100E+05, 0.67404300E+05, 0.95814800E+04, 0.12730500E+05, 0.30128300E+05, -.28849300E+05, -.37190800E+05, -.63970900E+05, 0.38345900E+05, -.16274900E+05, -.25309400E+05, 0.13996900E+05, 0.99693100E+05, 0.12720900E+05, 0.26031600E+04, 0.14386400E+05, -.39523000E+05, -.31409000E+05, -.72167400E+05, 0.32978700E+05, -.27654500E+05, 0.46782700E+05, -.31718600E+05, -.14395500E+06, -.23406100E+05, -.15766600E+05, -.75331400E+05, 0.68032500E+05, 0.89556500E+05, 0.14886600E+06, -.91252900E+05, 0.31242100E+05, -.40334800E+05, 0.20275000E+05, 0.13583100E+06, 0.20322100E+05, 0.14622400E+05, 0.32848800E+05, -.53736300E+05, -.48089100E+05, -.97913600E+05, 0.55513500E+05, -.36283700E+05, -.12650700E+06, 0.59133200E+05, -.15636700E+06, 0.62922900E+05, 0.19428600E+05, -.47677800E+05, 0.86134700E+05, 0.69711500E+05, 0.16493500E+06, -.64833600E+05, 0.85752600E+05, -.71086600E+04, 0.50417200E+04, 0.35294900E+05, 0.35520400E+04, 0.43542900E+04, 0.18148800E+05, -.20731400E+05, -.27272200E+05, -.46118900E+05, 0.24928100E+05, -.13075300E+05, -.44473900E+05, 0.24464600E+05, 0.45821600E+05, 0.22071900E+05, 0.24478400E+05, 0.37867700E+05, -.22459900E+05, -.45937700E+05, -.65602300E+05, 0.45706700E+05, -.99234900E+04, -.30321600E+06, 0.14834400E+06, -.38013200E+05, 0.15158200E+06, 0.59121200E+05, 0.31910300E+05, 0.45237300E+05, -.12342000E+05, 0.17718600E+06, 0.15436600E+04, 0.17358900E+06, 0.38155800E+06, -.18908500E+06, 0.35805600E+05, -.19075800E+06, -.61756000E+05, -.45509400E+05, -.39009600E+05, 0.43912500E+05, -.19805900E+06, -.12458900E+05, -.22570800E+06, 0.37940800E+04, 0.30332600E+05, -.40378700E+05, -.22158300E+05, -.87101500E+04, -.11856600E+05, 0.46743000E+04, 0.42423300E+05, 0.13772200E+05, 0.41191500E+04, -.48817700E+05, 0.53298000E+04, -.15957300E+05, 0.35552800E+05, -.10331000E+05, 0.42283600E+04, 0.12645600E+05, 0.34757600E+05, 0.10955100E+06, -.13448600E+05, -.73025800E+05, 0.21354200E+05, 0.65995400E+04, -.54662500E+05, -.63931500E+05, -.80413500E+05 },
        { -.13942100E+00, 0.16100800E+00, -.19012100E+00, -.50254400E-01, 0.69582200E+00, 0.29239900E+00, 0.89479500E+00, -.12837000E+01, -.95682600E-01, 0.81624700E+04, 0.46889400E+04, 0.14271700E+06, -.74193800E+05, -.56027500E+05, -.71495400E+05, -.10999100E+05, 0.49024900E+05, -.56983100E+05, -.25154400E+05, -.68089900E+05, 0.70938700E+05, -.49081500E+05, -.13026400E+05, 0.75079100E+04, 0.17673100E+05, 0.65327900E+04, -.16315600E+04, -.10291700E+05, 0.20129000E+05, 0.18432200E+05, 0.11230400E+05, -.25068500E+05, -.13005200E+05, 0.68925600E+05, -.32669200E+05, 0.12989200E+05, -.34634100E+05, 0.18319300E+05, 0.75376800E+05, -.71093700E+05, -.56568000E+05, -.51978200E+05, 0.83601400E+05, -.19367500E+05, 0.26743700E+05, -.13322400E+05, -.18908000E+05, -.13393800E+05, -.19544000E+05, -.20386300E+05, 0.11579300E+05, 0.13739100E+05, -.84037700E+03, -.24877700E+05, -.12233700E+05, 0.13753100E+04, -.15269300E+02, -.20507200E+04, -.77006000E+03, 0.19509200E+05, 0.47070100E+05, -.31828700E+05, -.19968600E+05, -.12474900E+05, 0.50748400E+05, 0.68854500E+04, -.16758800E+04, 0.63423700E+03, -.19703000E+05, 0.83887900E+03, -.89601700E+04, -.92897800E+04, 0.53818000E+04, 0.78096400E+04, 0.11312900E+05, -.21438000E+05, 0.39116300E+02, -.10475700E+05, 0.57974800E+04, 0.71098200E+04, 0.52397800E+04, -.22530500E+04, -.16623700E+05, 0.15933700E+05, 0.14168400E+05, 0.10864100E+05, -.21062000E+05, -.32132400E+03, 0.34865100E+05, -.21313800E+05, -.48579700E+05, -.17422600E+05, -.85520700E+03, 0.84814200E+05, -.79780700E+05, -.84447500E+05, -.47748600E+05, 0.10261100E+06, 0.74212800E+04, -.35701500E+04, 0.14491800E+04, 0.75768300E+04, 0.17262800E+04, 0.28580700E+05, 0.37150300E+05, -.21659600E+05, -.17393200E+05, -.97272800E+04, 0.51016800E+05, 0.84204200E+04, 0.50322900E+05, -.26387900E+05, -.32864700E+05, -.25144900E+05, -.95491400E+04, 0.16405300E+05, -.22419600E+05, -.16903000E+05, -.24074000E+05, 0.23069400E+05, -.13001900E+05, -.51194900E+05, 0.27081500E+05, 0.26985000E+05, 0.25597100E+05, 0.68561500E+04, -.49613100E+05, 0.51392500E+05, 0.62936000E+05, 0.53049000E+05, -.70106600E+05, 0.12621000E+05, 0.25915600E+05, -.12623200E+05, -.29437500E+05, -.12968300E+05, 0.56847200E+04, 0.51304200E+05, -.50567100E+05, -.47722200E+05, -.32176000E+05, 0.63086100E+05, 0.10816100E+04, 0.46823300E+05, -.22008300E+05, -.56072100E+04, -.23503100E+05, 0.34626100E+04, 0.37016900E+05, -.32903000E+05, -.27079200E+05, -.27753100E+05, 0.40789900E+05, -.12064400E+05, -.46451600E+05, 0.24227900E+05, 0.40272000E+05, 0.23120700E+05, -.25298300E+05, -.64128900E+05, 0.67744600E+05, 0.42495500E+05, 0.41047600E+05, -.84966800E+05, -.11797300E+05, 0.45749600E+04, -.62303900E+04, -.14791000E+05, -.23040000E+04, -.17819700E+05, -.15281100E+05, 0.30588400E+04, -.17795300E+04, -.14970800E+04, -.20686500E+04, 0.41403900E+04, 0.32433600E+04, -.14020100E+04, -.38501000E+04, -.16181600E+04, -.10472800E+05, -.24061800E+05, 0.19943700E+05, 0.19539300E+05, 0.83585000E+04, -.29891900E+05, -.71949900E+04, 0.12925400E+06, -.63758600E+05, -.40961700E+05, -.64664300E+05, -.27897600E+05, -.33850700E+05, 0.13813700E+05, 0.42774200E+05, -.16333000E+05, -.49495600E+05, -.52340400E+05, 0.50753100E+05, -.28005500E+05, -.27336600E+05, -.25370600E+05, 0.13174800E+05, 0.64565800E+05, -.58618900E+05, -.36845500E+05, -.35210800E+05, 0.73733300E+05, -.19157000E+04, 0.12208900E+06, -.60269300E+05, -.63278100E+05, -.61131800E+05, -.35734300E+05, -.48426900E+05, 0.27722300E+05, 0.52508300E+05, -.56075000E+04, -.67562600E+05, -.47250200E+05, 0.62586600E+05, -.30303000E+05, -.23352300E+05, -.31112600E+05, 0.11823500E+05, 0.70853300E+05, -.74327900E+05, -.66132500E+05, -.48768400E+05, 0.76714100E+05, -.76819600E+04, -.77954900E+04, 0.44942900E+04, 0.62581700E+04, 0.38991900E+04, -.32528000E+04, -.17307400E+05, 0.16537900E+05, 0.15119200E+05, 0.10613700E+05, -.22373400E+05, -.14074600E+04, -.72960000E+05, 0.39336400E+05, 0.21336400E+05, 0.36568400E+05, 0.33589700E+04, -.16835100E+05, 0.21609900E+05, 0.39081600E+04, 0.30597300E+05, -.25519000E+05, 0.25601400E+05, 0.28240900E+05, -.14691300E+05, -.17381400E+05, -.14105300E+05, 0.24735000E+05, 0.69015300E+05, -.51044000E+05, -.56485700E+05, -.53489500E+05, 0.88202400E+05, -.25137000E+04, 0.10083400E+04, -.38582400E+03, -.12276000E+04, -.51655000E+03, -.36834700E+05, -.64775200E+05, 0.39181200E+05, 0.47792200E+05, 0.37944300E+05, -.84129400E+05, -.12174400E+05, 0.96631100E+04, -.48778800E+05, 0.72895700E+04, -.86125100E+04, -.21585000E+05, 0.34018900E+05, -.23947500E+05, -.45755300E+05, 0.42967000E+04, 0.17258500E+04, 0.30258600E+05, -.16413700E+05, 0.75865500E+04, 0.11841100E+05, 0.31534600E+05, 0.52668200E+04, -.16672300E+05, -.19873500E+05, -.33368000E+05, 0.22639200E+05, 0.33489500E+05, 0.66384700E+04, 0.93114700E+04, 0.94329100E+04, 0.16843000E+05, 0.32231300E+05 },
        { -.33246400E+00, 0.40719400E-01, -.21404700E+01, -.55021600E+00, 0.10485900E+01, 0.23590000E+00, 0.76993400E+00, -.89001500E+00, -.64688000E+00, 0.89160400E-01, 0.73226400E+05, -.74591000E+05, 0.23271200E+05, 0.32791200E+05, 0.36346800E+05, -.37535700E+05, -.71312400E+05, 0.57006700E+05, 0.38660700E+05, 0.66670800E+05, -.60389800E+05, 0.21022500E+06, -.14933000E+06, 0.75522800E+05, 0.16261900E+06, 0.74785300E+05, 0.13677600E+05, 0.13318300E+05, 0.21660300E+05, -.43114500E+05, -.10392600E+05, 0.19977100E+05, -.11001800E+06, -.12941500E+05, 0.30778000E+04, -.18798400E+05, 0.54252700E+04, -.75241500E+04, -.20692200E+05, 0.16742200E+05, 0.21442700E+05, 0.33926000E+05, -.21998100E+05, 0.11117700E+06, 0.10389300E+04, -.71864100E+03, 0.36586600E+05, -.63556800E+03, -.39869600E+04, 0.52773300E+04, -.50787700E+04, -.14547000E+05, -.20591200E+05, 0.75627000E+04, -.62655400E+05, -.71486200E+05, 0.29134000E+05, -.32004900E+04, 0.35167200E+05, -.17078000E+03, -.17641200E+05, 0.20613300E+05, 0.94926700E+04, 0.48707500E+05, -.17483600E+05, 0.13931100E+06, 0.12592800E+05, -.72201900E+04, 0.78176800E+04, -.62570600E+04, -.73515200E+04, -.32046100E+04, 0.13856600E+04, 0.45182700E+04, -.34129900E+04, -.18257200E+04, -.10691700E+06, 0.17331100E+05, -.64116300E+04, 0.50198500E+04, -.86603800E+04, 0.25251300E+04, 0.97889600E+04, -.78023700E+04, -.52284300E+04, -.15425800E+05, 0.91027200E+04, -.48501800E+05, -.16193100E+06, 0.65371800E+05, 0.10284200E+05, 0.81038200E+05, -.11457700E+04, -.39639100E+05, 0.43405900E+05, 0.55589200E+04, 0.89076200E+05, -.35609300E+05, 0.22447300E+06, -.20092300E+05, 0.10623700E+05, -.46708400E+05, 0.98277100E+04, -.15110200E+04, -.18069500E+05, 0.16313100E+05, 0.25753600E+05, 0.42786600E+05, -.20937500E+05, 0.16564600E+06, -.85076100E+03, -.44300200E+04, -.38923600E+04, 0.51981000E+03, -.99119200E+04, -.16139900E+05, 0.67450000E+04, 0.70189400E+04, 0.13125400E+05, -.14584800E+05, 0.53144300E+05, 0.13044800E+06, -.57169200E+05, -.58890800E+04, -.65205500E+05, 0.17319100E+03, 0.32980900E+05, -.31741300E+05, 0.57605500E+04, -.61855000E+05, 0.29449400E+05, -.17542200E+06, -.41312200E+05, 0.15777900E+05, 0.16860900E+05, 0.20595300E+05, -.93237600E+04, -.28985100E+05, 0.25885700E+05, 0.16396400E+05, 0.34895600E+05, -.26496600E+05, 0.10596800E+06, 0.17448100E+05, -.11971100E+05, -.21954100E+05, -.92669400E+04, -.98759900E+04, -.14028100E+05, 0.51969000E+04, 0.13851400E+05, 0.12548600E+05, -.14351700E+05, 0.54394500E+05, -.41247600E+05, 0.24445300E+05, 0.11516100E+06, 0.20100500E+05, 0.16665200E+05, 0.48148600E+05, -.14337700E+05, -.46422100E+05, -.58747800E+05, 0.50359000E+05, -.22167500E+06, 0.10426700E+03, -.43659200E+04, 0.45480100E+03, -.20107600E+03, -.18679000E+05, -.26090700E+05, 0.12580100E+05, 0.12519200E+05, 0.14483400E+05, -.21976700E+05, 0.66314700E+05, 0.53165900E+04, -.14319000E+04, 0.25393800E+05, -.26478900E+04, -.33542300E+03, 0.59314000E+04, -.42894300E+04, -.95574300E+04, -.16973700E+05, 0.72645700E+04, -.68135800E+05, 0.50890100E+05, -.22889700E+05, 0.26379500E+05, -.25642300E+05, -.46786600E+04, 0.94675900E+04, -.88556400E+04, 0.10857300E+04, -.27591900E+05, 0.11133000E+05, -.13607300E+06, -.17226600E+06, 0.73414000E+05, 0.73810200E+04, 0.86225700E+05, 0.12279000E+05, -.21537200E+05, 0.37507100E+05, 0.29537400E+03, 0.85204300E+05, -.19787800E+05, 0.21975500E+06, 0.46338200E+05, -.21979600E+05, 0.38872200E+05, -.23621100E+05, -.41987400E+04, 0.10276700E+05, -.68333900E+04, -.20183200E+04, -.32241800E+05, 0.13281400E+05, -.16883200E+06, -.12305100E+06, 0.57022800E+05, -.58913500E+05, 0.62650700E+05, 0.39228200E+05, 0.16548500E+05, 0.87276300E+04, -.71605400E+04, 0.62696900E+05, 0.99951500E+04, 0.12944000E+06, 0.20285600E+05, -.77973500E+04, 0.72986900E+04, -.10140300E+05, 0.17580600E+04, 0.10205100E+05, -.85164800E+04, -.57870400E+04, -.17695100E+05, 0.96493500E+04, -.54314800E+05, -.89505900E+02, 0.48211500E+04, -.20805000E+04, 0.65006900E+03, 0.20580800E+05, 0.31117900E+05, -.18991300E+05, -.19838800E+05, -.20420500E+05, 0.26707700E+05, -.83246900E+05, -.15685400E+06, 0.74631500E+05, -.17831800E+05, 0.78492800E+05, 0.21676500E+05, -.19246100E+05, 0.27043900E+05, -.14615700E+05, 0.66996400E+05, -.19939500E+05, 0.20196400E+06, 0.12809900E+06, -.62590700E+05, 0.48150800E+05, -.64095200E+05, -.35909300E+05, -.52236900E+04, -.11777500E+05, 0.16204300E+05, -.51813000E+05, -.60924700E+03, -.22418900E+06, -.17652700E+05, 0.32972700E+05, 0.85435700E+04, 0.33976500E+05, -.17560100E+05, -.15298400E+05, -.38145000E+04, 0.28828000E+05, 0.38957700E+04, -.14045700E+04, -.33907200E+05, -.81434400E+04, -.11581000E+05, 0.24697900E+05, 0.12475900E+05, -.24524800E+05, 0.17114400E+05, 0.28179100E+05, 0.48859900E+05, -.78854100E+04, -.31002400E+05, -.12262300E+04, -.87092900E+03, -.77164300E+03, -.34662500E+05, -.43439900E+05 },
        { -.42216500E-02, 0.87071400E-01, 0.14097900E+01, -.45754200E-01, -.53291400E+00, 0.11939700E+00, -.21242800E+00, -.55044600E+00, -.67709300E-01, -.26508100E-01, 0.18906100E-01, 0.83757300E+05, -.41759000E+05, 0.66367400E+04, -.41935600E+05, -.70166800E+04, -.57169800E+04, -.10424400E+05, 0.58345500E+04, -.36454100E+05, -.26052700E+04, -.42344700E+05, -.12205100E+06, 0.61268500E+05, -.63040500E+05, 0.61032700E+05, 0.31784800E+05, 0.36153300E+05, -.72061100E+03, -.17861600E+05, 0.49173200E+05, 0.25428100E+05, 0.60169500E+05, 0.81356100E+05, -.39898200E+05, 0.57967600E+05, -.40739500E+05, -.45347800E+04, -.84529000E+04, -.40254600E+04, 0.10618600E+05, -.34476300E+05, -.51702200E+04, -.45105100E+05, -.49593500E+05, 0.24803800E+05, -.39541300E+05, 0.24790100E+05, 0.62724800E+04, 0.70508100E+04, 0.19213700E+04, -.62002200E+04, 0.21082500E+05, 0.45512600E+04, 0.27324800E+05, 0.38064500E+05, -.18444100E+05, 0.79209100E+04, -.19066800E+05, -.61684400E+04, 0.21374100E+04, -.51090400E+04, 0.35156500E+04, -.14322100E+05, 0.19036300E+04, -.19725400E+05, -.32874500E+05, 0.16459500E+05, -.21784300E+05, 0.16439900E+05, 0.14631800E+04, 0.12902500E+04, 0.30810200E+04, -.40971900E+04, 0.14961800E+05, 0.62187600E+03, 0.16962400E+05, -.22580800E+05, 0.11325100E+05, -.99521300E+04, 0.11290600E+05, 0.40134300E+04, 0.34887600E+04, 0.11890600E+04, -.26569800E+04, 0.92578200E+04, 0.23181000E+04, 0.11752100E+05, 0.80580500E+05, -.40434100E+05, 0.20056000E+05, -.40285800E+05, -.22995100E+05, -.16596400E+05, -.27785400E+04, 0.10105500E+05, -.30136800E+05, -.12464200E+05, -.41881100E+05, 0.99433900E+05, -.49785900E+05, 0.58507800E+05, -.49728200E+05, -.84074600E+04, -.76150600E+04, -.79648500E+04, 0.12398100E+05, -.40969500E+05, -.40066700E+04, -.52757400E+05, 0.15323800E+05, -.77408400E+04, -.44055700E+04, -.76564400E+04, -.38159600E+04, -.23862800E+04, -.13918500E+04, 0.17964900E+04, -.61823300E+04, -.14532600E+04, -.70875800E+04, -.10921300E+06, 0.54597000E+05, -.38767100E+05, 0.54608000E+05, 0.20692700E+05, 0.19059200E+05, 0.75184800E+04, -.12155000E+05, 0.44984800E+05, 0.13428900E+05, 0.55980900E+05, 0.70049100E+04, -.31010000E+04, 0.70355200E+04, -.35059800E+04, -.58685500E+03, -.16731100E+03, -.11715300E+03, -.84690600E+03, -.52818000E+04, 0.93592800E+03, -.56617600E+04, 0.33538100E+05, -.16124800E+05, 0.24408200E+05, -.16800900E+05, -.17008600E+04, -.53321400E+03, -.31583000E+04, 0.35877200E+04, -.14960500E+05, 0.17250600E+03, -.18662000E+05, -.16185900E+06, 0.81002000E+05, -.79649300E+05, 0.80900100E+05, 0.30871100E+05, 0.31132600E+05, 0.51816300E+04, -.20909400E+05, 0.66916600E+05, 0.20350200E+05, 0.78673600E+05, 0.26209100E+05, -.14015900E+05, 0.53076800E+04, -.13113900E+05, -.80194300E+04, -.13644100E+05, 0.12177000E+04, 0.30572100E+04, -.10513600E+05, -.96011800E+04, -.12997000E+05, -.42686500E+05, 0.21321400E+05, -.25404000E+05, 0.21343800E+05, 0.66574500E+04, 0.67720200E+04, 0.16504100E+04, -.56068300E+04, 0.17309100E+05, 0.46235200E+04, 0.22514800E+05, -.72393000E+05, 0.36276500E+05, -.42477500E+05, 0.36185200E+05, 0.17198700E+05, 0.16817400E+05, 0.23369900E+04, -.70333700E+04, 0.32788700E+05, 0.11868200E+05, 0.37235400E+05, 0.10370300E+06, -.51798700E+05, 0.34584900E+05, -.51845300E+05, -.21155400E+05, -.14322700E+05, -.62381400E+04, 0.12673800E+05, -.38831000E+05, -.10426800E+05, -.53450600E+05, -.89058900E+05, 0.44617200E+05, -.53942100E+05, 0.44503700E+05, 0.18812100E+05, 0.18668600E+05, 0.15654000E+04, -.81869500E+04, 0.41809600E+05, 0.12376600E+05, 0.46600300E+05, 0.15822300E+06, -.78518000E+05, 0.82772400E+05, -.79045200E+05, -.35420000E+05, -.38033300E+05, -.11669900E+04, 0.25389400E+05, -.59711500E+05, -.28641200E+05, -.81112300E+05, -.28533200E+05, 0.14306700E+05, -.13087100E+05, 0.14266700E+05, 0.53039400E+04, 0.49893600E+04, 0.12813700E+04, -.34198600E+04, 0.11667000E+05, 0.33771400E+04, 0.14763400E+05, -.35766500E+05, 0.18356500E+05, -.22937000E+04, 0.17919600E+05, 0.11248300E+04, 0.10390400E+04, 0.49061500E+04, -.26094100E+04, 0.15947400E+05, -.52719900E+02, 0.17905300E+05, 0.16783000E+06, -.83936600E+05, 0.76029800E+05, -.83911500E+05, -.23913200E+05, -.18466500E+05, -.13883700E+05, 0.21640000E+05, -.69454600E+05, -.11798700E+05, -.83200300E+05, -.18046300E+06, 0.90259500E+05, -.92743800E+05, 0.90229000E+05, 0.23629300E+05, 0.17697400E+05, 0.14827300E+05, -.24598700E+05, 0.73207900E+05, 0.11894400E+05, 0.90025500E+05, 0.24002200E+05, 0.17031500E+05, 0.19687500E+05, 0.62607600E+04, 0.44013100E+04, 0.52877000E+04, 0.17275700E+05, 0.15085100E+05, -.83597800E+04, -.16171800E+05, 0.17329900E+05, 0.20695500E+05, -.12450100E+05, -.18836200E+05, 0.36649100E+04, 0.12161600E+05, -.23110100E+05, -.39340700E+04, -.17943500E+05, -.12307700E+05, -.94097700E+04, 0.76712600E+04, -.37851800E+04, 0.21185400E+05, 0.94942200E+04, 0.13463100E+05 },
        { -.27187800E+00, 0.21444700E+01, -.93075400E+00, -.73304000E-02, -.50847300E+00, -.27463600E+00, -.96411100E+00, 0.15137700E+01, -.73321500E-01, -.58333800E+00, -.55776800E-01, -.17150500E+01, -.13957300E+05, 0.53578800E+05, -.69981900E+02, -.13691600E+05, -.46982600E+05, 0.27855800E+05, 0.21393600E+05, 0.61409800E+04, -.37615000E+05, -.11086000E+05, -.12470400E+05, 0.74701600E+04, -.32335800E+05, 0.62416100E+04, -.82538200E+04, 0.19588000E+05, -.12035600E+05, -.49625000E+04, 0.11741900E+05, 0.12075600E+05, 0.12361600E+05, 0.43407000E+05, -.23634500E+05, 0.54199900E+05, -.21758300E+05, 0.54626800E+04, -.21508200E+05, 0.13991500E+05, 0.24766900E+05, -.88664700E+04, -.18725400E+05, -.28687400E+05, -.13829900E+05, 0.66951500E+04, -.23368400E+05, 0.69120500E+04, -.65361100E+04, 0.20104600E+04, -.33875600E+04, -.47100400E+04, 0.41278800E+04, 0.11136400E+04, 0.10585900E+05, -.23489700E+05, 0.62681700E+04, -.85643200E+04, 0.11701500E+05, -.26832900E+03, -.70963200E+04, 0.11249400E+05, 0.44042800E+04, 0.15694200E+05, -.64201100E+04, 0.13140200E+05, -.30157900E+05, 0.14233000E+05, -.20161300E+05, 0.15087100E+05, -.25801500E+04, -.17633300E+04, 0.50382700E+04, -.18437200E+04, 0.15996600E+05, -.19969500E+04, 0.13786400E+05, 0.81641700E+04, -.17451200E+04, -.13436600E+05, -.40830200E+04, 0.62557700E+03, 0.90807700E+04, -.72886900E+04, -.38916000E+04, -.44238600E+04, 0.73487400E+04, -.21536900E+04, -.79601800E+05, 0.23876500E+05, 0.26994300E+05, 0.39806900E+05, -.56481500E+04, -.51869800E+05, 0.45278400E+05, 0.22433900E+05, 0.46038400E+05, -.44565500E+05, 0.33445100E+05, 0.33432000E+05, -.16194800E+05, 0.40029800E+05, -.16702200E+05, 0.75786600E+04, -.45405000E+04, 0.28814400E+04, 0.85667100E+04, -.13321100E+05, -.24063200E+04, -.23325800E+05, -.17137200E+05, 0.35196700E+04, 0.91957500E+04, 0.85723800E+04, -.29416800E+04, -.13105300E+05, 0.97279700E+04, 0.54319200E+04, 0.69480200E+04, -.10835000E+05, 0.62700000E+04, 0.18565400E+05, -.11967200E+04, -.54655100E+05, -.92779700E+04, 0.44375700E+04, 0.41114000E+05, -.23225000E+05, -.10467900E+05, -.57394100E+04, 0.32486300E+05, -.59663300E+04, -.19794300E+05, 0.57218700E+04, 0.26052700E+05, 0.98945200E+04, 0.93842300E+03, -.15773500E+05, 0.16475400E+05, 0.13122000E+05, 0.15488500E+05, -.14143400E+05, 0.54642500E+04, 0.90222900E+04, -.65151700E+04, 0.19259800E+05, -.45369100E+04, 0.32759100E+04, -.60207800E+04, 0.55094900E+04, 0.10059500E+05, -.60270100E+03, -.59974200E+04, -.74375900E+04, -.18475000E+05, 0.13258000E+05, -.77877500E+05, 0.92312600E+04, 0.68610400E+03, 0.36548100E+05, -.21695600E+05, -.96576300E+04, 0.10015900E+05, 0.25717200E+05, 0.15834500E+05, -.15634900E+05, 0.17422000E+04, 0.41138800E+05, 0.78009900E+04, -.13084900E+05, -.30730700E+05, 0.15918400E+05, 0.25786400E+04, 0.48715000E+04, -.22675600E+05, 0.29961300E+04, -.40446600E+04, 0.31775400E+04, -.18428000E+05, 0.20208900E+04, -.35288600E+04, 0.69689900E+04, -.64871600E+04, -.60983800E+04, -.58714400E+01, 0.55294700E+04, 0.54779500E+04, 0.14479300E+05, -.45664200E+04, -.35663000E+05, -.72445600E+04, -.35271200E+04, 0.11101500E+05, -.84919500E+04, 0.58167500E+04, 0.23188100E+04, 0.64474800E+04, -.36613500E+04, -.26220900E+05, 0.47339700E+03, 0.14758500E+05, 0.13125400E+05, -.13592200E+04, -.29560000E+05, 0.26700300E+05, 0.16260500E+05, 0.21379100E+05, -.24406100E+05, 0.11278500E+05, -.21255900E+04, 0.22969800E+04, -.51021600E+05, 0.10535600E+04, -.15437200E+04, 0.18161600E+05, -.11856600E+05, 0.28531200E+04, 0.10273700E+05, 0.11388700E+05, 0.68474300E+04, 0.19514400E+04, -.43079900E+04, 0.29127300E+05, -.91267000E+03, 0.16796500E+05, -.32670000E+05, 0.28688900E+05, 0.28494400E+05, 0.80387300E+04, -.27891100E+05, -.78464600E+04, 0.61244500E+04, -.62233900E+03, -.15392400E+05, -.30632100E+04, 0.42950200E+03, 0.99907200E+04, -.76097500E+04, -.41524100E+04, -.35911600E+04, 0.78989500E+04, -.10980400E+04, -.93516800E+04, 0.10524800E+05, -.20942100E+05, 0.47194000E+04, 0.53430700E+04, 0.17672100E+05, -.89556400E+04, -.82927700E+04, 0.23090900E+04, 0.13809500E+05, 0.10399500E+05, 0.13586700E+05, -.10863600E+05, 0.69148100E+05, -.67946500E+04, 0.43301100E+04, -.23585100E+05, 0.94711200E+04, 0.75454200E+04, -.13915500E+05, -.16195000E+05, -.49145100E+04, -.35548300E+05, 0.19500400E+05, -.56374400E+05, 0.17777100E+05, -.15353300E+05, 0.28957300E+04, 0.10286100E+04, -.91194900E+04, 0.22545300E+05, 0.11871500E+03, 0.15032800E+05, -.57688300E+04, 0.21604200E+05, 0.76961500E+04, 0.22264700E+05, 0.32333600E+04, -.90032100E+04, 0.68707200E+04, 0.19470700E+05, -.45980200E+04, -.56100900E+04, -.52222000E+04, 0.14119900E+05, -.11505100E+05, -.18174500E+05, 0.66939700E+04, -.79286900E+04, 0.11436000E+04, 0.84037500E+04, 0.61377900E+04, -.80632800E+04, -.19082100E+05, -.26509500E+04, -.68303500E+04, 0.88676000E+04, -.50285200E+04, -.42596000E+04 },
        { 0.56198600E-01, -.74519300E+00, -.52815000E+00, -.24716400E-01, -.11715400E+00, -.11535500E-01, -.27685300E+00, -.19779700E-01, -.49581100E-01, -.38856700E+00, 0.11568800E+00, 0.23593400E+01, -.31219400E+00, -.76295500E+05, 0.92964300E+02, 0.66883200E+04, 0.21797200E+05, -.37231800E+04, 0.14565900E+05, 0.32291500E+05, 0.13379300E+05, 0.19003600E+05, 0.13200100E+06, -.66577300E+05, 0.12875800E+06, -.66012500E+05, -.39612800E+05, -.40340700E+05, -.45792600E+04, 0.27060600E+04, -.84913000E+05, -.23114300E+05, -.77119500E+05, -.54418800E+05, 0.25706200E+05, -.13465000E+06, 0.27313800E+05, -.15118400E+05, -.17170100E+04, 0.76175000E+04, 0.91037600E+03, 0.52608800E+05, -.65749300E+04, 0.63488400E+05, 0.46741600E+05, -.23330100E+05, 0.77998600E+05, -.23358800E+05, 0.99600700E+02, -.26072600E+04, -.50354900E+04, -.43445100E+03, -.34995100E+05, 0.13959200E+04, -.40690200E+05, 0.72154100E+04, -.43669500E+04, -.48993400E+05, -.35510800E+04, -.11825700E+04, -.96745600E+04, 0.58720100E+04, 0.11495100E+05, 0.15667800E+05, -.10241500E+05, 0.86292700E+04, 0.55679400E+05, -.27852300E+05, 0.31848500E+05, -.27843000E+05, -.34462000E+04, -.43816200E+04, -.39935100E+04, 0.86320200E+04, -.23420100E+05, -.32862200E+04, -.24937600E+05, 0.49647400E+04, -.26525800E+04, 0.30378600E+05, -.24830100E+04, -.43781800E+04, -.70227100E+04, 0.13115900E+04, -.17548400E+04, -.94021600E+04, -.43396200E+04, -.77429500E+04, 0.12398000E+05, -.54416500E+04, -.10030800E+06, -.62056500E+04, 0.27558300E+05, 0.35795500E+05, -.11572200E+05, 0.99680300E+04, 0.21139300E+05, 0.25214500E+05, 0.16018800E+05, -.89569900E+05, 0.44766000E+05, -.12647200E+06, 0.44809400E+05, 0.14361100E+04, 0.64133100E+04, 0.85876000E+04, -.26949900E+04, 0.58852800E+05, 0.14299700E+02, 0.68924900E+05, 0.15026900E+05, -.71367100E+04, -.11870600E+05, -.75230200E+04, 0.65809000E+04, 0.94402700E+04, -.45457400E+04, 0.36312600E+04, 0.76382400E+03, 0.69603500E+04, -.52079100E+04, 0.75175100E+05, -.38038100E+05, 0.10508200E+06, -.37589100E+05, -.41987900E+05, -.56948500E+05, 0.11165800E+05, 0.75604000E+04, -.41385500E+05, -.43840900E+05, -.41531000E+05, 0.75611800E+05, -.38419400E+05, -.48722500E+05, -.37799500E+05, -.10435600E+05, 0.17760600E+03, -.64005100E+04, 0.18301600E+05, -.48989200E+04, -.33194000E+04, -.14314700E+05, -.18636700E+05, 0.81394500E+04, -.59498800E+05, 0.93723200E+04, -.79640000E+04, -.59909100E+04, 0.47157200E+04, 0.31153600E+04, 0.24450700E+05, -.69594900E+04, 0.27027800E+05, 0.97815500E+05, -.49171100E+05, 0.20288600E+06, -.48853200E+05, -.33064400E+05, -.41960800E+05, -.55686200E+04, -.13780700E+05, -.94257600E+05, -.20859400E+05, -.73060200E+05, 0.11314300E+05, -.37192300E+04, -.27917800E+05, -.56433100E+04, 0.21998100E+05, 0.36421200E+05, -.13953400E+05, 0.38057200E+04, 0.11592700E+04, 0.26874300E+05, -.62099800E+04, 0.36178800E+05, -.18087400E+05, 0.55535200E+05, -.18090600E+05, -.39121800E+04, -.62596900E+04, -.27036400E+04, 0.93579000E+03, -.25696500E+05, -.26145100E+04, -.28302800E+05, 0.67841100E+05, -.34135800E+05, 0.86375300E+05, -.33900300E+05, -.25494200E+05, -.29507500E+05, -.40563900E+04, -.33747800E+04, -.44934000E+05, -.19430200E+05, -.42289200E+05, -.56233800E+05, 0.28409900E+05, -.10923600E+06, 0.28109000E+05, 0.24211300E+05, 0.24081900E+05, -.12225800E+04, -.88460900E+03, 0.42310200E+05, 0.15485800E+05, 0.45990600E+05, 0.84648000E+05, -.42424900E+05, 0.11360900E+06, -.42277300E+05, -.25118200E+05, -.27934200E+05, -.49930300E+04, -.45852300E+04, -.60310500E+05, -.16122100E+05, -.56137600E+05, -.19506100E+06, 0.96582600E+05, -.16434800E+06, 0.97418800E+05, 0.42154900E+05, 0.50600600E+05, 0.95120600E+03, -.30463600E+05, 0.90053000E+05, 0.36426700E+05, 0.11616000E+06, 0.11365000E+05, -.58654800E+04, 0.36711800E+05, -.56828600E+04, -.61669700E+04, -.92142400E+04, 0.11898400E+04, -.14561900E+04, -.13000900E+05, -.57492300E+04, -.11675900E+05, 0.66660400E+04, -.40669000E+04, 0.29965000E+05, -.33920900E+04, 0.17632100E+04, -.33414400E+04, -.17211500E+04, -.65866600E+04, -.18453500E+05, -.74000100E+03, -.10461700E+05, -.18500700E+06, 0.92741300E+05, -.15875700E+06, 0.92496200E+05, 0.50292500E+05, 0.59840200E+05, -.25621700E+03, -.24692500E+05, 0.82672100E+05, 0.45060800E+05, 0.81933700E+05, 0.24861100E+06, -.12442200E+06, 0.16448500E+06, -.12430100E+06, -.42850000E+05, -.44042500E+05, -.11652100E+05, 0.38121300E+05, -.10346600E+06, -.33007200E+05, -.11073000E+06, -.98258700E+04, -.31579200E+05, -.28298300E+05, -.31989000E+05, -.18897700E+05, 0.60324100E+04, -.15750500E+05, -.28550100E+05, 0.13379800E+05, 0.11514500E+05, -.20776900E+05, -.26245700E+05, 0.10195500E+05, 0.42120100E+05, 0.35534800E+02, -.16621200E+04, 0.18939500E+05, -.23062200E+04, 0.25737300E+05, 0.63033200E+04, 0.17828400E+05, 0.12312800E+05, 0.11057800E+05, -.31747200E+05, -.18121000E+05, -.18899700E+05 },
        { 0.74312200E-01, 0.23037600E+00, -.36203600E+00, 0.12742700E+00, -.16479000E+00, -.20678100E-01, -.15720500E+00, -.51994200E-01, 0.71130200E-01, -.19289900E-02, -.40771300E-02, 0.43098500E+00, -.59999800E-01, 0.27035300E+00, 0.26252700E+03, -.33552100E+04, -.61164300E+04, 0.30071600E+04, 0.24737600E+04, 0.66109800E+04, -.57314900E+04, -.19959100E+04, 0.12467000E+05, -.62613700E+04, -.35115400E+03, -.62669600E+04, -.75347500E+04, -.71145600E+04, 0.16279500E+04, 0.39375800E+04, -.13028200E+04, -.67910000E+04, -.43383300E+04, -.95456800E+03, 0.47156300E+03, -.17598400E+04, 0.76883100E+03, 0.11340000E+04, -.37094800E+01, -.59018400E+03, 0.13979600E+04, 0.34706800E+04, 0.61695200E+02, -.43844600E+04, 0.33754600E+04, -.16799600E+04, 0.11577500E+04, -.16550400E+04, -.18731300E+04, -.76625400E+03, 0.18193200E+03, 0.16561600E+03, -.24687500E+04, -.64773700E+03, 0.94654900E+03, -.65909000E+04, 0.33647500E+04, -.10421800E+04, 0.34547500E+04, 0.15191500E+04, 0.14502000E+03, 0.13554300E+03, -.61688100E+03, 0.38923000E+04, 0.15834200E+03, 0.19377700E+04, 0.29907300E+04, -.14971000E+04, -.88885500E+03, -.15057300E+04, -.87124000E+03, -.49166600E+03, -.21994000E+03, 0.71302300E+03, -.83740400E+03, -.56700200E+03, -.14797400E+04, 0.20488700E+04, -.10435300E+04, -.38600800E+03, -.10260000E+04, -.12072900E+04, -.77674500E+03, 0.29233000E+03, 0.42335300E+03, -.10248300E+04, -.67870100E+03, -.32466600E+03, -.79671300E+04, 0.40639100E+04, -.69285600E+03, 0.39635100E+04, 0.43843600E+04, 0.19552600E+04, -.40361400E+03, -.56772800E+03, 0.53852200E+04, 0.16187000E+04, 0.15129600E+04, -.85830300E+04, 0.42603100E+04, 0.40765900E+03, 0.43549400E+04, 0.22992100E+04, 0.61766000E+03, 0.86669900E+03, -.10519200E+04, 0.43159200E+04, 0.57576800E+03, 0.48759700E+03, -.30392900E+04, 0.15583200E+04, 0.20197500E+04, 0.14932000E+04, 0.89443900E+03, 0.69504700E+03, 0.12975200E+03, -.89875100E+03, 0.77772700E+03, 0.66180300E+03, 0.12531700E+04, 0.96581800E+04, -.49133100E+04, -.23533100E+04, -.48339500E+04, -.49264900E+04, -.25269000E+04, -.99770300E+03, 0.13333200E+04, -.36148300E+04, -.21548400E+04, -.41413100E+04, -.85655800E+03, 0.44596200E+03, 0.26050100E+04, 0.44529600E+03, 0.17387500E+04, 0.85194800E+03, -.10653600E+04, 0.87516000E+03, 0.30297000E+04, 0.56565300E+03, -.27937900E+04, 0.29927900E+04, -.14857500E+04, -.27154000E+04, -.13447700E+04, -.30185800E+03, -.55418200E+03, -.99349900E+02, 0.14180700E+04, 0.10985200E+04, -.45875000E+03, -.36879400E+04, 0.15822100E+05, -.79320800E+04, -.52930100E+04, -.77630400E+04, -.88127800E+04, -.71732500E+04, 0.23970400E+04, 0.33192600E+04, -.52327600E+04, -.67223700E+04, -.36433500E+04, -.14203000E+03, 0.97975200E+02, 0.26074600E+04, 0.11168600E+03, 0.22984100E+04, 0.18774200E+04, -.67870800E+03, -.11080300E+04, -.11061000E+04, 0.15588800E+04, 0.18579300E+03, 0.33737500E+04, -.16943200E+04, 0.34594000E+03, -.16899800E+04, -.17665300E+04, -.11771300E+04, 0.46489600E+03, 0.59886300E+03, -.16378300E+04, -.10947000E+04, -.11918300E+03, 0.99032500E+04, -.49660600E+04, -.20579400E+04, -.48961000E+04, -.62256700E+04, -.50811600E+04, 0.20847200E+04, 0.23354600E+04, -.29764000E+04, -.49651700E+04, -.13057700E+04, -.84457400E+04, 0.42819200E+04, -.28075500E+04, 0.41980600E+04, 0.34518500E+04, 0.92118800E+03, 0.10962500E+03, -.77607300E+03, 0.54881300E+04, 0.48279700E+03, 0.30301400E+04, 0.10166000E+05, -.50739900E+04, -.31481600E+04, -.49555200E+04, -.64200400E+04, -.50230400E+04, 0.24236400E+04, 0.25082000E+04, -.31246000E+04, -.50546000E+04, -.33640700E+03, -.12896500E+05, 0.64796100E+04, -.47448700E+04, 0.61348900E+04, 0.58512600E+04, 0.35236800E+04, 0.55481900E+02, -.11606200E+04, 0.56926500E+04, 0.30278700E+04, 0.46219100E+04, 0.24774900E+04, -.12583800E+04, -.43319100E+03, -.12395700E+04, -.14844800E+04, -.94519400E+03, 0.31096100E+03, 0.45413100E+03, -.12190300E+04, -.82530000E+03, -.38104800E+03, 0.37459100E+03, -.11839900E+03, 0.42824300E+03, -.35492700E+03, 0.25443200E+04, 0.37968900E+04, -.19648800E+04, -.13422000E+04, -.35496600E+04, 0.33995900E+04, 0.31256800E+03, -.18188400E+05, 0.91317100E+04, 0.35145100E+04, 0.90753200E+04, 0.61047800E+04, 0.31999500E+04, 0.13421100E+04, -.36167900E+04, 0.59249700E+04, 0.30554900E+04, 0.98034800E+04, 0.17587700E+05, -.88134600E+04, -.11356800E+03, -.87805600E+04, -.57314300E+04, -.36097300E+04, -.76256400E+03, 0.40201500E+04, -.56899500E+04, -.35283100E+04, -.10149300E+05, -.19867900E+04, -.18195300E+04, -.28039000E+04, 0.12407700E+04, -.97473000E+03, 0.77057200E+03, -.12795300E+04, -.17933100E+04, 0.52210100E+03, 0.12664200E+04, 0.95727100E+01, -.21652300E+04, 0.18126800E+04, 0.84146700E+03, 0.13573500E+04, -.94037800E+03, 0.33879600E+04, -.28890200E+03, 0.12277100E+04, 0.10504300E+04, -.53312400E+03, -.36482000E+03, 0.14999700E+03, -.24873000E+04, 0.46998400E+03, 0.30376300E+03 },
        { 0.13758000E+00, 0.53082600E+00, -.54383600E+00, 0.22540400E+00, -.53831000E+00, 0.10456200E+00, -.34128700E+00, 0.71038000E+00, 0.16740000E+00, 0.10020300E-01, -.94826200E-01, -.97989800E+00, 0.19194400E+00, -.53067500E+00, -.18608200E+00, 0.33769300E+05, 0.24153000E+05, -.51385000E+04, 0.55817400E+04, -.52314600E+04, 0.18806300E+05, -.35656000E+04, -.39204400E+05, 0.18695600E+05, -.10381500E+04, 0.19600300E+05, -.72319700E+04, -.10619900E+04, -.23274400E+04, -.16694600E+05, 0.54218900E+04, 0.21394100E+04, 0.24662300E+05, -.31346500E+05, 0.13560600E+05, -.54332000E+02, 0.15689700E+05, -.69139500E+04, -.19577500E+05, 0.21148100E+05, 0.82501800E+04, 0.91894400E+04, -.17154900E+05, 0.17852700E+05, -.12450200E+05, 0.62467400E+04, 0.16096900E+04, 0.62292300E+04, 0.82234000E+04, 0.42968800E+04, -.14032100E+04, -.31016400E+03, 0.59491700E+04, 0.36219300E+04, 0.26571500E+04, 0.24356300E+05, -.13230300E+05, -.13242800E+05, -.12179000E+05, -.53172500E+04, -.82169600E+04, 0.40704600E+04, 0.43474300E+04, -.12364000E+05, -.66362000E+04, -.13589700E+05, -.45689300E+04, 0.23259200E+04, 0.44126400E+04, 0.22882200E+04, 0.56904100E+04, 0.38647300E+04, -.20730600E+04, -.36542300E+04, -.37440400E+04, 0.35258300E+04, 0.25773000E+04, -.16752600E+05, 0.81363500E+04, 0.40427600E+04, 0.83753600E+04, -.43670000E+04, -.33697700E+04, 0.92897600E+03, -.55256000E+04, 0.53430800E+04, -.20123200E+04, 0.94170200E+04, 0.66158400E+05, -.31969300E+05, -.11587600E+05, -.33079100E+05, 0.22190800E+05, 0.11179500E+05, 0.18286900E+04, 0.28723900E+05, -.26361000E+05, 0.60353400E+04, -.39166000E+05, 0.33966700E+05, -.16927000E+05, -.81252200E+04, -.16961600E+05, -.62269900E+04, -.29666600E+03, -.34219500E+04, 0.31478700E+04, -.15250700E+05, -.31320900E+03, -.14746900E+05, 0.16559000E+05, -.77525100E+04, -.27494600E+04, -.82818500E+04, 0.10534900E+05, 0.51711400E+04, -.33891200E+03, 0.10881600E+05, -.28803800E+04, 0.29413500E+04, -.11244300E+05, -.63404800E+05, 0.31060600E+05, 0.12462700E+05, 0.31704800E+05, -.31519100E+05, -.29432900E+05, 0.88819000E+04, -.26927300E+05, 0.19331000E+05, -.20823900E+05, 0.39634900E+05, 0.20923500E+05, -.11320500E+05, 0.63532900E+04, -.10460600E+05, 0.71331000E+04, 0.37472500E+04, 0.39029700E+04, 0.13258800E+05, -.73118700E+04, 0.12005600E+04, -.10349600E+05, -.28815600E+05, 0.12781700E+05, 0.69207900E+04, 0.14418800E+05, -.39078400E+03, -.91694600E+04, 0.10755000E+05, 0.23972500E+04, 0.82793300E+04, -.78384300E+04, 0.14061800E+05, -.10858400E+06, 0.53940200E+05, 0.20785900E+05, 0.54315400E+05, -.12712000E+05, -.15995900E+05, 0.29694000E+04, -.36369800E+05, 0.27274700E+05, -.90500400E+04, 0.60892900E+05, 0.73692200E+05, -.34015100E+05, -.18833600E+05, -.36849900E+05, 0.30282500E+05, 0.34589000E+05, -.22397500E+05, 0.10050300E+05, -.25739800E+05, 0.26494000E+05, -.39462900E+05, -.12219700E+05, 0.60654100E+04, 0.17343400E+04, 0.61082600E+04, 0.16581200E+04, 0.30864900E+04, -.27216600E+04, -.45807600E+04, 0.43920300E+04, 0.31976400E+04, 0.61695500E+04, -.81208500E+05, 0.40241900E+05, 0.17965600E+05, 0.40611200E+05, -.63812000E+04, -.86236300E+04, 0.43383500E+04, -.23211000E+05, 0.16687400E+05, -.53999400E+04, 0.37300000E+05, 0.51916600E+05, -.25449900E+05, -.17414800E+05, -.25952700E+05, 0.51998100E+04, -.74799000E+03, 0.15159600E+03, 0.10179700E+05, -.23840000E+05, -.14904900E+04, -.29643300E+05, -.82843700E+05, 0.41132200E+05, 0.26738400E+05, 0.41439400E+05, -.36811800E+04, -.21631000E+04, -.47731200E+03, -.26030100E+05, 0.14714000E+05, 0.32522100E+03, 0.36784500E+05, 0.75192400E+04, -.50237100E+04, 0.16415200E+04, -.37744900E+04, -.94454800E+04, -.24683200E+05, 0.20801200E+05, 0.18427400E+05, -.13404600E+04, -.22263000E+05, -.72127800E+04, -.19489700E+05, 0.94873800E+04, 0.42662900E+04, 0.97439900E+04, -.45875200E+04, -.39108400E+04, 0.11708300E+04, -.60537100E+04, 0.62772900E+04, -.24200900E+04, 0.10612700E+05, 0.16668400E+05, -.93144300E+04, -.20060900E+04, -.83352800E+04, -.10239500E+05, -.65463100E+04, -.11030100E+04, 0.24551400E+02, -.39041600E+04, -.51062100E+04, -.63777300E+04, 0.75439300E+05, -.37631800E+05, -.14970500E+05, -.37724100E+05, 0.13062100E+05, 0.21681200E+05, -.85464200E+04, 0.26125900E+05, -.19295100E+05, 0.14445000E+05, -.50985600E+05, -.43808700E+05, 0.21987000E+05, 0.30420600E+04, 0.21909000E+05, 0.77015500E+04, 0.99879400E+03, -.23975400E+03, -.15116900E+05, 0.74308600E+04, 0.31613100E+04, 0.34543000E+05, 0.15672100E+05, -.49707000E+04, -.13067000E+05, -.77255500E+04, -.62374900E+04, 0.67172700E+04, 0.19276100E+05, -.41877400E+04, -.23531900E+04, -.12970900E+05, 0.79362100E+04, -.30859000E+04, -.54886600E+04, 0.51443500E+04, 0.23619700E+04, 0.83817000E+04, 0.46535600E+04, -.94449600E+04, -.70036300E+04, -.16906600E+05, 0.27390700E+04, 0.14105700E+05, 0.81391400E+03, -.19023400E+05, 0.20037300E+04, 0.60284700E+04 },
        { -.99099400E-01, 0.48505200E+00, -.10092200E+00, -.15349500E+00, 0.29309000E-02, 0.52069700E-01, -.73332600E-02, -.23738100E+00, -.14211200E+00, 0.50369600E-01, 0.89667400E-01, 0.12499300E+00, 0.16817100E+00, 0.12885500E+00, -.10567900E+00, -.31741900E+00, -.13972000E+05, 0.10119000E+05, 0.99944800E+04, 0.95669300E+04, -.14665300E+05, -.47135800E+03, -.32968500E+05, 0.16233900E+05, -.58508800E+04, 0.16484500E+05, 0.10925300E+05, 0.12291100E+05, -.56039300E+04, -.11973500E+05, 0.52333600E+04, 0.11917800E+05, 0.16018700E+05, 0.90707400E+04, -.51273900E+04, -.14934700E+04, -.45373000E+04, -.11254100E+05, -.22294700E+05, 0.19045600E+05, 0.19292400E+05, 0.88349200E+04, -.22311500E+05, -.41779300E+04, -.21670900E+05, 0.10846100E+05, 0.19989100E+04, 0.10835000E+05, 0.87261600E+04, 0.86209100E+04, -.39374100E+04, -.67656500E+04, 0.25482200E+04, 0.83666100E+04, 0.88294100E+04, 0.22305600E+05, -.11430100E+05, -.24953600E+04, -.11152500E+05, -.10071500E+05, -.14326200E+05, 0.76918900E+04, 0.81750500E+04, -.21876900E+04, -.13446000E+05, -.10759800E+05, 0.48432100E+03, -.22118400E+03, 0.60383500E+03, -.24254900E+03, 0.19026300E+04, 0.16890200E+04, -.16166200E+04, -.20626500E+04, -.23427100E+04, 0.13960700E+04, 0.14251100E+03, -.78073800E+04, 0.38394000E+04, 0.33317500E+03, 0.39037900E+04, 0.24254400E+04, 0.53159800E+04, -.36387800E+04, -.49157200E+04, -.26757200E+03, 0.53795000E+04, 0.41175100E+04, 0.26484900E+05, -.12951500E+05, 0.53966600E+04, -.13242200E+05, -.11030200E+05, -.27564100E+05, 0.20590900E+05, 0.24911300E+05, 0.32532800E+04, -.27384200E+05, -.16581300E+05, 0.34107900E+05, -.17039600E+05, -.15256200E+04, -.17056300E+05, -.10654000E+05, -.12405100E+05, 0.41220900E+04, 0.10404200E+05, -.55969700E+04, -.11884100E+05, -.15096500E+05, -.98057800E+03, 0.63440300E+03, 0.25531900E+04, 0.49055300E+03, 0.10775300E+04, -.40779200E+04, 0.39653300E+04, 0.53001900E+04, 0.26717600E+04, -.43230400E+04, -.95049400E+03, -.58816900E+04, 0.27552300E+04, -.98010200E+04, 0.29405900E+04, 0.18734200E+04, 0.11877200E+05, -.10154600E+05, -.13915000E+05, -.36840800E+04, 0.12421900E+05, 0.68729900E+04, 0.10516900E+05, -.54945800E+04, -.25082900E+04, -.52584600E+04, -.65146500E+04, -.16049700E+05, 0.13874400E+05, 0.15174500E+05, 0.66596900E+04, -.16665600E+05, -.48580200E+04, -.37688300E+04, 0.14388800E+04, 0.42081000E+04, 0.18827700E+04, -.30996000E+04, -.94010700E+04, 0.85102700E+04, 0.81683800E+04, 0.61317100E+04, -.94043800E+04, 0.77694600E+03, -.58792600E+05, 0.29312000E+05, 0.27988900E+04, 0.29393700E+05, 0.20760600E+05, 0.28442900E+05, -.18325300E+05, -.27217400E+05, 0.32531400E+04, 0.27902700E+05, 0.27789300E+05, 0.13154600E+05, -.58008500E+04, -.51414100E+04, -.65770200E+04, 0.46262300E+04, 0.20566600E+04, -.31284700E+04, 0.13533300E+04, -.34448100E+04, 0.96516200E+03, -.67254200E+04, -.15304500E+05, 0.76405400E+04, 0.75399800E+03, 0.76524200E+04, 0.61552900E+04, 0.89792500E+04, -.55946400E+04, -.74128800E+04, 0.88472200E+03, 0.87647700E+04, 0.74201200E+04, -.43889900E+05, 0.21852600E+05, 0.52279500E+04, 0.21944200E+05, 0.12186500E+05, 0.15299400E+05, -.89427600E+04, -.15138100E+05, 0.64972100E+04, 0.14346600E+05, 0.19621000E+05, 0.34765300E+05, -.17245400E+05, 0.27076400E+03, -.17383100E+05, -.12920200E+05, -.21540300E+05, 0.11590300E+05, 0.13983500E+05, -.36357300E+04, -.20656300E+05, -.18723800E+05, -.48181700E+05, 0.24018500E+05, 0.10375500E+05, 0.24088900E+05, 0.14998500E+05, 0.19083000E+05, -.12562200E+05, -.18153600E+05, 0.52072600E+04, 0.18157500E+05, 0.21034500E+05, 0.31938700E+05, -.16311500E+05, 0.12218700E+05, -.15967500E+05, -.17539900E+05, -.26494400E+05, 0.17559800E+05, 0.22856800E+05, -.18820500E+04, -.25190100E+05, -.18379200E+05, -.99131300E+04, 0.48878700E+04, 0.40107700E+03, 0.49566600E+04, 0.31302900E+04, 0.59384600E+04, -.39221000E+04, -.54824600E+04, 0.10941400E+03, 0.59767500E+04, 0.50029500E+04, 0.45457800E+04, -.25261900E+04, -.34233100E+03, -.22725700E+04, 0.11176600E+03, 0.49625300E+04, -.39324500E+04, -.26963300E+04, -.51425800E+04, 0.52007600E+04, -.21112400E+04, 0.20313800E+05, -.10144600E+05, 0.15225500E+05, -.10156400E+05, -.95277700E+04, -.14979100E+05, 0.92979000E+04, 0.14278200E+05, -.15815700E+04, -.14709900E+05, -.14165000E+05, -.28489800E+05, 0.14290500E+05, -.15608700E+05, 0.14244400E+05, 0.13224200E+05, 0.15824400E+05, -.73724000E+04, -.12695200E+05, 0.43830400E+04, 0.14705000E+05, 0.18110100E+05, 0.75866400E+04, 0.11693200E+05, 0.30132500E+04, -.22206200E+04, 0.63409500E+04, -.53397100E+04, 0.10180200E+05, 0.12024800E+05, -.20171600E+04, -.68539300E+04, -.54803900E+04, 0.94798400E+04, -.86676200E+04, -.47267700E+04, -.93174700E+04, 0.34080600E+04, -.39428200E+04, 0.30002900E+04, 0.43212000E+04, -.86128500E+04, -.81486100E+04, 0.35892300E+04, -.15452600E+04, 0.17492200E+04, -.69242900E+04, -.76659000E+04 },
        { -.39845400E+00, 0.49249500E+00, -.65674100E+01, 0.61271200E+00, 0.59695700E+01, 0.63641900E+00, 0.83422900E+01, -.19658600E+00, -.29248000E+00, 0.73845800E+00, 0.13528400E+00, -.48626300E+01, 0.65546500E+00, -.70727800E+00, -.51349900E+01, -.16075600E+01, -.53271100E+01, -.32331300E+05, -.68772400E+05, -.14743800E+05, 0.31099200E+04, 0.57426000E+04, -.69548600E+05, 0.33122700E+05, -.35860600E+05, 0.34790000E+05, 0.13483600E+05, 0.32935500E+05, 0.11049800E+05, -.26616300E+04, 0.15335700E+05, 0.25946100E+05, 0.45225200E+05, 0.68423100E+05, -.36453300E+05, 0.19511000E+05, -.34353400E+05, -.10216600E+05, 0.43664000E+05, -.63752800E+05, -.66101200E+05, -.70798900E+05, 0.45889500E+05, -.22389300E+05, -.32080000E+05, 0.16434300E+05, -.27781500E+05, 0.16003800E+05, 0.25512200E+04, -.45130400E+04, 0.15575600E+05, 0.59031300E+04, 0.19748200E+05, -.57423300E+04, 0.15926400E+05, -.25622500E+05, 0.14266100E+05, 0.38899700E+05, 0.12817400E+05, -.93413800E+03, 0.63803900E+04, -.18380000E+05, -.35292600E+05, -.21588800E+05, 0.57411100E+04, -.29777600E+04, -.38792000E+05, 0.19437200E+05, 0.58000800E+04, 0.19363000E+05, 0.87651900E+04, 0.98215100E+04, -.15051300E+04, -.14319200E+05, -.94995600E+04, 0.87715400E+04, 0.23655900E+05, -.23502300E+05, 0.10943100E+05, -.28035400E+03, 0.11759600E+05, -.20781800E+04, -.99447300E+04, 0.17205400E+05, 0.15253100E+05, 0.15602700E+05, -.98251800E+04, 0.12107000E+05, 0.98650300E+05, -.46453600E+05, -.21238800E+05, -.49328200E+05, -.80747600E+04, 0.55165100E+05, -.93562300E+05, -.11454900E+06, -.10149900E+06, 0.55905000E+05, -.39591700E+05, 0.69042600E+05, -.35814900E+05, 0.35966100E+05, -.34710900E+05, -.12807100E+04, -.10166700E+03, -.18517100E+05, -.40743100E+04, -.32178500E+05, 0.15942600E+04, -.33857600E+05, 0.43670900E+05, -.20146600E+05, -.23550600E+05, -.21815300E+05, -.25785400E+04, 0.11887100E+05, -.20659500E+05, -.17841300E+05, -.17288500E+05, 0.11505700E+05, -.12780800E+05, -.10084300E+06, 0.46873800E+05, 0.62705000E+04, 0.50400400E+05, 0.10943800E+05, -.12494700E+05, 0.40675400E+05, 0.49881100E+05, 0.47165800E+05, -.11997100E+05, 0.48282300E+05, 0.69718700E+04, -.33703800E+04, -.14360300E+04, -.34972400E+04, 0.31575000E+04, 0.37407000E+05, -.49371100E+05, -.62438600E+05, -.35269300E+05, 0.38155600E+05, 0.11300000E+04, 0.49603000E+05, -.25905000E+05, -.17345900E+04, -.24893700E+05, -.10527500E+05, 0.19058700E+05, -.29182300E+05, -.30294800E+05, -.36210300E+05, 0.19095700E+05, -.14110200E+05, -.26898500E+05, 0.12559200E+05, -.47757500E+05, 0.13243800E+05, -.12299300E+05, 0.66338300E+04, 0.42672700E+05, 0.29507900E+05, 0.24376500E+05, 0.18778400E+03, 0.27589700E+05, 0.58733300E+05, -.25751400E+05, -.28383000E+05, -.29332500E+05, 0.23793400E+05, 0.24515600E+04, -.15323200E+05, -.25561400E+04, -.16266600E+05, 0.13274000E+04, -.34423400E+05, -.35178700E+05, 0.17299300E+05, -.12662000E+05, 0.17603300E+05, 0.13866200E+04, -.92807000E+04, 0.22204600E+05, 0.16378300E+05, 0.24349300E+05, -.10267700E+05, 0.17023700E+05, -.92675200E+05, 0.45752600E+05, 0.51280200E+04, 0.46276500E+05, -.96761200E+04, 0.78483900E+04, 0.32490000E+05, -.35298500E+04, 0.17469500E+05, 0.61326100E+04, 0.53654300E+05, 0.28795700E+05, -.12194600E+05, 0.44398200E+05, -.14448700E+05, -.10878700E+04, 0.21042600E+05, -.51742700E+05, -.67191100E+05, -.62133000E+05, 0.21583400E+05, -.25601100E+05, -.10286100E+06, 0.51833700E+05, 0.37549600E+03, 0.51277500E+05, -.15326500E+05, -.44487700E+04, 0.47512300E+05, 0.24679000E+04, 0.22035400E+05, -.51758700E+04, 0.60465000E+05, 0.14912900E+06, -.74658200E+05, 0.21809200E+05, -.74433300E+05, -.37939200E+05, 0.28627100E+05, -.79392800E+05, -.81912600E+05, -.10289900E+06, 0.37820600E+05, -.61553000E+05, -.24616200E+05, 0.11475700E+05, -.29794800E+04, 0.12315600E+05, -.21221900E+04, -.90059400E+04, 0.17886800E+05, 0.15572600E+05, 0.16634500E+05, -.90611600E+04, 0.13102000E+05, 0.34669300E+05, -.15946400E+05, -.13828700E+05, -.17327100E+05, 0.58420500E+04, 0.13296800E+05, -.28562500E+04, 0.18655600E+05, -.12943200E+05, 0.10641500E+05, -.18724000E+05, 0.77806900E+05, -.37709200E+05, 0.45204900E+05, -.38864400E+05, -.21872700E+05, -.17378000E+05, -.13524900E+05, -.29337300E+05, -.16296400E+05, -.17498600E+05, -.60523200E+05, -.11683700E+06, 0.58042000E+05, -.62725900E+05, 0.58378300E+05, 0.32678000E+05, 0.28080500E+05, 0.85625200E+04, 0.44776800E+03, 0.18954000E+05, 0.26238100E+05, 0.90000700E+05, 0.23356500E+05, -.93635000E+04, 0.34519300E+04, -.96246400E+04, 0.23675900E+03, 0.20321300E+05, -.92325800E+04, -.68398700E+04, -.19138200E+04, -.76102000E+04, 0.30993900E+05, 0.15771000E+05, 0.25803900E+05, 0.18601300E+04, 0.63391900E+02, 0.22727900E+05, -.35624200E+04, -.14324300E+05, -.26151400E+05, 0.12058900E+05, 0.95093500E+04, 0.63766200E+04, 0.47456500E+04, 0.18733900E+04, 0.29901300E+05, 0.23391300E+05 },
        { -.12810500E+00, -.30561400E+00, -.89837300E+00, -.39598700E-01, 0.36198400E+00, -.18658900E-01, -.77082300E+00, 0.14056900E+00, -.56743700E-01, 0.75085300E-01, -.13218300E-01, -.31944400E-01, -.83993700E-01, 0.93563500E-02, 0.11951000E+00, 0.29061800E+00, -.64930800E+00, 0.14595600E+00, 0.87508400E+04, 0.26408800E+04, -.98155800E+03, 0.26043700E+04, 0.85843000E+04, -.39844300E+04, 0.58602400E+04, -.42945300E+04, -.24536700E+04, -.95892700E+04, 0.54326300E+04, 0.59252000E+03, -.11285100E+04, -.69418500E+04, -.10835900E+05, -.17726800E+05, 0.92963400E+04, -.15269400E+04, 0.88850400E+04, 0.55586500E+04, -.41584000E+03, -.81458400E+03, 0.65189400E+04, 0.11196500E+05, -.19382300E+04, 0.73094400E+04, 0.53127700E+04, -.27177500E+04, 0.53946700E+04, -.26508600E+04, -.16817000E+04, -.18004400E+04, 0.31586800E+04, 0.84641700E+03, -.24433600E+04, -.94895100E+03, -.32628200E+04, 0.10809800E+04, -.74361800E+03, -.22981700E+04, -.54131600E+03, 0.22187100E+04, 0.19592700E+04, -.36304800E+04, 0.31158600E+04, 0.25271700E+04, 0.18843600E+04, 0.28167400E+04, 0.57223800E+04, -.28691000E+04, 0.11208900E+04, -.28561400E+04, -.11426500E+04, -.15619500E+04, 0.94507000E+03, 0.22497100E+04, 0.14462600E+04, -.12168700E+04, -.43595800E+04, 0.60283600E+04, -.28734600E+04, -.11129400E+04, -.30154600E+04, -.54418300E+03, 0.21491300E+03, 0.76312300E+02, -.10760600E+04, -.24370100E+04, 0.38878400E+03, -.35909900E+04, -.26156100E+05, 0.12568700E+05, 0.12469500E+05, 0.13078700E+05, 0.47527100E+04, -.40783400E+04, 0.42774100E+04, 0.13347800E+05, 0.16720600E+05, -.45498000E+04, 0.12823200E+05, -.25488100E+04, 0.14810500E+04, -.12601900E+05, 0.13034100E+04, -.91013900E+03, 0.40079900E+03, -.38213700E+04, 0.76322600E+02, 0.29672600E+04, -.96155600E+03, 0.53593900E+04, -.76210200E+04, 0.35166100E+04, 0.42995600E+04, 0.38074300E+04, 0.18631500E+03, -.19693100E+04, 0.25467900E+04, 0.28478200E+04, 0.28352100E+04, -.20273300E+04, 0.36688700E+04, 0.68621500E+04, -.28342500E+04, 0.13280100E+04, -.34278500E+04, 0.23461000E+04, 0.56227400E+04, -.30858800E+04, -.89499700E+04, -.63295100E+04, 0.58348600E+04, -.80540800E+04, -.75074100E+04, 0.37603700E+04, 0.38012700E+04, 0.37555000E+04, 0.32594100E+04, -.62999800E+03, -.13683800E+04, 0.56041800E+04, 0.46603100E+04, -.13409700E+04, 0.30375700E+04, -.40392800E+04, 0.22485500E+04, -.15311500E+04, 0.20334900E+04, 0.12096100E+04, -.29220400E+04, 0.16446500E+04, 0.58030300E+04, 0.51744500E+04, -.34463500E+04, 0.20146400E+04, 0.24981600E+05, -.12325000E+05, 0.11128500E+03, -.12459400E+05, -.49243500E+04, -.13981700E+05, 0.11391500E+05, 0.42570000E+04, -.42359400E+04, -.10764900E+05, -.19440900E+05, -.95616700E+04, 0.40928400E+04, 0.38586800E+04, 0.47755500E+04, -.47909300E+04, -.14306600E+04, 0.18253000E+04, -.59928900E+03, 0.31477200E+04, -.13475600E+04, 0.74055700E+04, 0.82315200E+04, -.40634000E+04, 0.11535700E+04, -.41179000E+04, -.19045800E+04, -.14187900E+04, 0.15769600E+04, -.62554100E+03, -.35627700E+04, -.74322200E+03, -.48523300E+04, 0.22521400E+05, -.11147100E+05, -.68762800E+04, -.11251400E+05, -.22440500E+04, -.82938300E+04, 0.64716200E+04, 0.54456300E+04, -.17241200E+04, -.64851200E+04, -.15794500E+05, -.14163400E+05, 0.67011000E+04, 0.23163300E+03, 0.70895900E+04, 0.39543200E+04, 0.18000600E+04, -.15115200E+04, 0.54539300E+04, 0.96346800E+04, 0.15560800E+04, 0.81585500E+04, 0.31990300E+05, -.16041100E+05, -.52405200E+04, -.15971700E+05, -.38797700E+04, -.96747200E+04, 0.72217200E+04, 0.65798100E+04, -.39136300E+04, -.73843400E+04, -.21041000E+05, -.33026900E+05, 0.16567700E+05, 0.28721700E+04, 0.16493600E+05, 0.10371400E+05, 0.32811600E+04, 0.19145800E+04, 0.76692900E+04, 0.16494400E+05, 0.87853000E+03, 0.13246500E+05, 0.65193400E+04, -.31142500E+04, -.79908400E+03, -.32608100E+04, -.67133300E+03, -.24043700E+03, 0.43774400E+03, -.94696300E+03, -.26007400E+04, 0.27941600E+02, -.39822100E+04, -.54743900E+04, 0.25406600E+04, 0.25656300E+04, 0.27361500E+04, -.64961400E+03, -.18430600E+04, 0.16353000E+04, -.27905200E+04, 0.16716200E+04, -.12388400E+04, 0.12954000E+04, 0.17444400E+02, -.19303200E+03, -.15813400E+05, -.14686700E+02, -.13122600E+04, -.91758100E+03, -.31141200E+04, 0.53332200E+04, 0.82824100E+03, -.16043700E+04, 0.10899500E+05, 0.49964100E+04, -.24467000E+04, 0.18701000E+05, -.24920500E+04, -.17113400E+04, -.28273100E+04, 0.48104800E+04, -.14970300E+04, 0.98651200E+02, -.17400900E+04, -.14095800E+05, -.58529000E+04, -.14883700E+03, -.20409300E+04, 0.37216800E+04, -.18052400E+04, -.12518500E+04, -.70412100E+02, -.49689700E+03, 0.42692800E+03, 0.22430800E+04, -.27711200E+04, -.38907300E+04, -.11981000E+04, 0.21264900E+04, 0.26370800E+04, -.42388700E+04, 0.25163800E+04, 0.22238000E+04, 0.37203600E+04, -.21016200E+03, -.14012500E+04, -.26855600E+04, -.65801400E+03, -.20232400E+04, -.23238300E+04, -.22242000E+04 },
        { 0.12213800E+00, -.59765000E+00, -.17015700E+00, 0.12789100E+00, -.29938900E+00, -.23660600E+00, -.40898100E+00, 0.84159700E+00, 0.14342500E+00, -.14397600E+00, -.41970400E-01, 0.29604800E+00, -.35055600E+00, 0.17984000E+00, -.66669600E-01, 0.20746800E+00, 0.88682200E+00, -.16495000E+00, -.15278800E+01, -.13395000E+05, 0.15382900E+04, -.43715800E+04, 0.27264800E+05, -.13355200E+05, 0.19985600E+05, -.13635100E+05, -.13185900E+05, -.19477800E+05, 0.72614200E+04, 0.11271300E+05, 0.55999800E+04, -.15208300E+05, -.22163100E+05, 0.46578900E+04, -.19064800E+04, -.22377700E+05, -.23044800E+04, -.93055700E+03, -.10029600E+05, 0.68765800E+04, 0.69629700E+04, -.34877000E+04, -.10938100E+05, -.56441200E+04, 0.69423900E+04, -.35996900E+04, 0.14408200E+05, -.34649100E+04, -.18356900E+04, -.60564300E+03, -.70332300E+03, 0.18532800E+04, -.88051100E+03, 0.12917900E+04, -.24161500E+04, -.26661700E+04, 0.88405300E+03, -.13794600E+05, 0.13322800E+04, 0.25313100E+04, -.14804600E+04, 0.25110100E+04, -.36726100E+03, -.47667000E+04, -.45097900E+03, 0.58832600E+04, -.41747100E+04, 0.21086300E+04, 0.81693500E+04, 0.20931100E+04, 0.85621700E+03, 0.91848000E+03, 0.92347700E+03, -.26130700E+04, -.39693800E+04, 0.18621900E+04, -.38282100E+04, 0.29161900E+04, -.12791200E+04, 0.37408900E+04, -.14595600E+04, 0.57809500E+03, 0.20237400E+04, -.21208400E+04, -.96081300E+03, 0.94540800E+02, 0.20479700E+04, -.28643800E+04, -.27168100E+05, 0.13033600E+05, -.67313900E+04, 0.13584900E+05, 0.51713400E+04, -.11205000E+05, 0.13797300E+05, 0.50632400E+04, 0.34661700E+04, -.94403400E+04, 0.15182600E+05, -.42612600E+04, 0.25267200E+04, -.27443000E+05, 0.21636400E+04, 0.51433000E+03, 0.27024300E+04, -.34133800E+04, -.36813500E+04, -.43691000E+04, -.28387300E+03, 0.50538100E+04, -.73928400E+04, 0.33188900E+04, 0.33647500E+04, 0.36929200E+04, 0.99235000E+03, -.76137700E+03, 0.11611400E+04, 0.20069300E+03, -.11406400E+04, -.15995300E+03, 0.42791300E+04, -.95778300E+03, 0.13215100E+04, 0.17063900E+05, 0.48256400E+03, 0.19121800E+04, 0.82373600E+04, -.20951400E+04, -.64534800E+04, -.31078500E+04, 0.80838200E+04, -.13555300E+05, 0.19772200E+05, -.99910100E+04, -.72096400E+04, -.98839600E+04, -.37364100E+04, -.83849900E+04, 0.49769200E+04, 0.85215700E+04, -.80311600E+04, -.86753800E+04, -.10338900E+05, 0.12607500E+04, -.46027100E+03, -.10187800E+05, -.61493400E+03, 0.35858200E+03, -.37950600E+04, 0.11383400E+04, 0.35261000E+04, -.30452300E+04, -.41458600E+04, -.17050800E+04, 0.11890800E+05, -.57533900E+04, 0.30553700E+05, -.59096900E+04, -.27154100E+04, -.94538400E+04, 0.10910100E+04, 0.53051700E+04, 0.10738500E+05, -.55301400E+04, -.16131700E+05, -.13959800E+05, 0.63527200E+04, 0.11167000E+05, 0.69738000E+04, -.34019200E+04, 0.15843400E+04, 0.47349600E+03, -.49283800E+04, -.18222700E+04, 0.19501500E+04, 0.99570700E+04, 0.14591300E+04, -.69159600E+03, 0.12069400E+05, -.73201000E+03, -.16677900E+03, 0.17286400E+04, -.23428300E+04, -.11170800E+04, 0.74384500E+03, 0.26233100E+04, -.22832600E+04, -.57876300E+05, 0.29001100E+05, 0.46417500E+05, 0.28948800E+05, 0.17034000E+05, 0.20827300E+05, -.82994900E+04, -.20401400E+05, 0.21095100E+04, 0.22178900E+05, 0.13700100E+05, -.27414600E+05, 0.13272600E+05, -.15948800E+05, 0.13716400E+05, 0.77570900E+04, -.44728600E+03, 0.73889500E+04, 0.35006700E+03, 0.28046300E+04, 0.82515700E+03, 0.15812700E+05, -.63486500E+05, 0.31501700E+05, 0.56536500E+05, 0.31769900E+05, 0.18684800E+05, 0.24213600E+05, -.10293100E+05, -.23878300E+05, 0.17556800E+04, 0.26083400E+05, 0.14709900E+05, -.51078500E+05, 0.25511400E+05, -.25979000E+05, 0.25517200E+05, 0.18373900E+05, 0.22706200E+04, 0.10557600E+05, 0.39879400E+02, 0.18661100E+05, -.15497300E+03, 0.23134000E+05, 0.34573500E+04, -.15454400E+04, 0.49347700E+04, -.17299800E+04, 0.33867100E+03, 0.17497900E+04, -.21475600E+04, -.90477300E+03, 0.88204000E+01, 0.19289200E+04, -.32914400E+04, -.19005100E+04, 0.54241100E+03, 0.56509300E+03, 0.94923200E+03, -.17403800E+04, -.38202300E+04, 0.32496000E+04, 0.20423600E+04, 0.85909800E+04, -.43501800E+04, 0.32362000E+04, 0.16153600E+05, -.85103400E+04, -.49138600E+05, -.80835700E+04, -.41733500E+04, -.53291200E+04, -.34289000E+04, 0.94449900E+04, 0.82204900E+04, -.77791400E+04, 0.22256400E+05, -.10780000E+05, 0.56216500E+04, 0.57352600E+05, 0.53970300E+04, 0.62033200E+03, -.11295800E+03, 0.49443700E+04, -.11015200E+05, -.11339800E+05, 0.36619500E+04, -.27182800E+05, -.34664300E+04, 0.14577500E+03, 0.35766800E+04, -.14300200E+04, -.26377600E+04, -.46244900E+04, 0.26243300E+04, 0.80406300E+03, 0.65624300E+03, -.19466000E+04, -.76814500E+04, -.22326000E+04, -.30915400E+04, 0.23791500E+04, 0.13185800E+04, -.27645400E+04, 0.22879600E+03, 0.45456100E+03, 0.34574500E+04, -.34779300E+04, 0.38612400E+04, 0.32394600E+04, -.63978000E+02, 0.55321800E+04, -.75108000E+04, -.82954900E+04 },
        { 0.85731600E-01, -.38328700E+00, -.22658200E+00, 0.45824300E-01, -.98073100E-01, -.19777100E+00, -.28563400E+00, 0.12753300E+00, 0.34135600E-01, -.84521600E-01, -.14726700E-01, 0.23813200E+00, -.21979800E+00, 0.23587300E+00, 0.53263100E+00, -.76369700E-01, 0.99102000E+00, -.38909600E-01, 0.51857600E+00, -.30174400E+00, 0.23594200E+04, -.67254000E+04, 0.52288000E+05, -.25822800E+05, 0.11588500E+05, -.26144200E+05, -.24827300E+05, -.20391000E+05, 0.48923300E+04, 0.17050700E+05, -.77479600E+04, -.19022800E+05, -.20579800E+05, -.75730000E+04, 0.46512100E+04, -.71584800E+04, 0.37877800E+04, 0.88651500E+04, 0.11591400E+05, -.10315300E+05, -.11773300E+05, -.22470100E+04, 0.12371300E+05, -.22563200E+03, 0.23785200E+05, -.11959200E+05, 0.31798700E+04, -.11892400E+05, -.95686100E+04, -.76453300E+04, 0.13090200E+04, 0.52938200E+04, -.64717300E+04, -.69504400E+04, -.75695100E+04, -.31424600E+05, 0.15863600E+05, -.53376700E+04, 0.15711300E+05, 0.10195000E+05, 0.83632600E+04, -.13341700E+04, -.66411900E+04, 0.75158800E+04, 0.82845800E+04, 0.14223200E+05, -.22809400E+02, 0.18912900E+02, -.59488500E+03, 0.11438700E+02, -.20958000E+04, -.20858500E+04, 0.17041300E+04, 0.19252000E+04, -.38640000E+02, -.16643200E+04, -.16445900E+04, 0.79771500E+04, -.38803300E+04, 0.12271000E+04, -.39885900E+04, -.40389400E+04, -.46747400E+04, 0.20032600E+04, 0.33284400E+04, -.11094600E+04, -.45716200E+04, -.33084200E+04, -.34818200E+05, 0.17027300E+05, -.15493900E+05, 0.17407800E+05, 0.18498200E+05, 0.19719400E+05, -.98916500E+04, -.17307100E+05, 0.52013500E+04, 0.19809900E+05, 0.17807900E+05, -.39217000E+05, 0.19755700E+05, -.49358500E+04, 0.19609100E+05, 0.13156500E+05, 0.12799900E+05, -.13804500E+04, -.93548600E+04, 0.90949500E+04, 0.11618500E+05, 0.12960200E+05, -.13223300E+04, 0.42315500E+03, -.86760700E+03, 0.66104200E+03, 0.18259600E+04, 0.41216900E+04, -.29352200E+04, -.43066800E+04, -.22664700E+04, 0.43682900E+04, 0.11087500E+04, 0.11430000E+05, -.52936100E+04, 0.13020500E+05, -.57149600E+04, -.13991700E+05, -.14583200E+05, 0.76043900E+04, 0.10654100E+05, -.59289500E+03, -.14296600E+05, -.96021100E+04, 0.10749300E+03, 0.20707600E+03, 0.31551200E+04, -.54304200E+02, 0.66926100E+04, 0.10834500E+05, -.88662100E+04, -.69407300E+04, -.34418800E+04, 0.11072000E+05, -.29492500E+04, 0.23188400E+04, -.58154700E+03, -.90498100E+04, -.11569100E+04, 0.23345400E+04, 0.48956300E+04, -.52173500E+04, -.50572100E+04, -.24165000E+04, 0.52269800E+04, -.20314200E+04, 0.59455900E+05, -.29610900E+05, 0.60178300E+04, -.29727100E+05, -.32404600E+05, -.31265500E+05, 0.12959000E+05, 0.22935900E+05, -.73847900E+04, -.29367100E+05, -.20725600E+05, -.44861700E+04, 0.13026500E+04, 0.94219200E+04, 0.22435000E+04, 0.25652100E+04, 0.41290200E+04, 0.47360400E+03, -.47232900E+03, -.20787000E+04, 0.40628000E+04, 0.35657300E+03, 0.16456800E+05, -.82271900E+04, 0.34619700E+04, -.82283900E+04, -.73489400E+04, -.74262400E+04, 0.28258000E+04, 0.56931400E+04, -.32173900E+04, -.70551500E+04, -.63072800E+04, 0.27733500E+05, -.13792000E+05, 0.10062800E+05, -.13866500E+05, -.16222100E+05, -.13211400E+05, 0.53185300E+04, 0.79876800E+04, -.97131500E+04, -.11966000E+05, -.96792900E+04, -.46547100E+05, 0.23078200E+05, -.12869100E+05, 0.23272900E+05, 0.17971800E+05, 0.15546800E+05, -.28702900E+04, -.98495600E+04, 0.11965900E+05, 0.14967100E+05, 0.23483300E+05, 0.26366400E+05, -.13249300E+05, 0.65722100E+04, -.13182500E+05, -.17574400E+05, -.13632700E+05, 0.72674300E+04, 0.88949400E+04, -.84891000E+04, -.12879800E+05, -.74250500E+04, -.58539100E+05, 0.29703000E+05, -.29892500E+05, 0.29268300E+05, 0.26409800E+05, 0.21943900E+05, -.74119000E+04, -.21082200E+05, 0.15161400E+05, 0.20718500E+05, 0.30087900E+05, 0.10186400E+05, -.49798100E+04, 0.15407800E+04, -.50932000E+04, -.51779200E+04, -.54234300E+04, 0.21456900E+04, 0.37889700E+04, -.16896000E+04, -.52502100E+04, -.41122300E+04, -.23273200E+04, 0.13003600E+04, 0.51887300E+03, 0.11626100E+04, 0.15614600E+04, 0.28164200E+04, -.94923200E+03, -.12457800E+04, -.17965900E+03, 0.13322000E+04, 0.45575500E+04, -.34694900E+05, 0.17154900E+05, -.21757400E+05, 0.17347300E+05, 0.21851000E+05, 0.20760200E+05, -.75552600E+04, -.13659600E+05, 0.10983400E+05, 0.19110400E+05, 0.23677100E+05, 0.48649100E+05, -.24246500E+05, 0.25594400E+05, -.24324400E+05, -.22304600E+05, -.21284700E+05, 0.54966400E+04, 0.13411300E+05, -.16663700E+05, -.18832300E+05, -.31617700E+05, -.80447700E+04, -.12065500E+05, -.76879900E+04, 0.13565300E+04, -.82770600E+04, 0.48439500E+04, -.70691500E+04, -.12097600E+05, 0.24928900E+04, 0.48114200E+04, 0.26139200E+04, -.10421400E+05, 0.74331200E+04, 0.63271900E+04, 0.10618700E+05, -.37113300E+04, 0.87867900E+04, -.33909500E+04, -.34436100E+03, 0.52511600E+04, 0.65703800E+04, -.42331200E+03, 0.15879700E+04, -.69045700E+04, 0.33637900E+04, 0.43801600E+04 },
        { -.24704800E-01, 0.14711100E+00, 0.58672000E+00, -.57117000E-01, -.20135400E+00, 0.51833200E-01, -.30270600E+00, -.16116800E+00, 0.25417500E-02, -.11512300E-01, -.61067300E-03, 0.47874900E+00, -.66461500E-01, 0.42463800E-01, -.87574900E-01, -.11116200E+00, -.46472600E-01, -.26190300E-01, -.90310700E-01, -.95513400E-01, 0.32918200E-01, -.33258000E+04, 0.14814100E+05, -.74605400E+04, 0.49085700E+04, -.74068600E+04, -.68139200E+04, -.63289200E+04, 0.99394100E+03, 0.31230200E+04, -.26006100E+04, -.45435400E+04, -.56468900E+04, 0.82129800E+03, -.45816100E+03, -.68536100E+04, -.41229900E+03, 0.48261200E+02, -.43739200E+03, -.57515400E+02, 0.76970700E+03, 0.38349400E+03, -.92284900E+03, -.23396000E+04, 0.31230400E+04, -.15523300E+04, 0.47102300E+04, -.15619300E+04, -.11896000E+04, 0.13190700E+03, -.87755500E+02, 0.30752500E+03, -.15906500E+04, 0.38726000E+03, -.57345100E+03, -.38107300E+04, 0.19855700E+04, -.35948000E+04, 0.19055100E+04, 0.98046100E+03, 0.27104700E+03, 0.17731100E+03, -.84155900E+03, 0.67629600E+03, 0.25691000E+03, 0.11634500E+04, 0.24967600E+04, -.12433000E+04, 0.32481400E+04, -.12487400E+04, 0.21953400E+02, 0.41614400E+03, -.36982100E+03, -.80595700E+02, -.17264100E+04, 0.37997300E+03, -.24554400E+04, 0.11224600E+04, -.58505100E+03, 0.12092000E+04, -.56113800E+03, -.45366800E+03, -.21068900E+03, 0.12941300E+02, 0.15753100E+03, -.39834500E+03, -.97991300E+02, -.22020000E+03, -.71343300E+04, 0.36521200E+04, -.36237400E+04, 0.35672300E+04, 0.28854000E+04, 0.22427900E+04, 0.41600600E+03, -.82192800E+03, 0.21435100E+04, 0.16022500E+04, 0.22976900E+04, -.50560500E+04, 0.24875600E+04, -.64833700E+04, 0.25259100E+04, 0.14060600E+04, -.53040600E+03, -.18602900E+02, -.10455600E+04, 0.17470400E+04, -.67416600E+03, 0.10050500E+04, -.35891400E+03, 0.22648800E+03, 0.55468900E+03, 0.17968700E+03, 0.63208400E+03, 0.14666800E+04, -.61505500E+03, -.51770600E+03, -.70549800E+03, 0.12038900E+04, -.11740700E+03, 0.51352200E+04, -.26871400E+04, 0.49949300E+04, -.25678400E+04, -.15934400E+04, -.74321100E+03, -.57712500E+03, -.30330300E+03, -.28446500E+04, -.20865300E+03, -.41556900E+04, 0.65185400E+04, -.32420500E+04, -.17353900E+04, -.32593500E+04, -.30556000E+03, 0.32651600E+02, -.93683300E+03, 0.12541800E+04, -.16885800E+04, -.32383000E+03, -.46633800E+04, 0.10431900E+04, -.52671500E+03, -.33509200E+04, -.52279800E+03, -.32586300E+02, 0.18677400E+03, -.40016600E+03, 0.31491500E+03, -.26607600E+03, -.14884600E+03, -.14158500E+04, 0.11610000E+05, -.58195300E+04, 0.61698800E+04, -.58073100E+04, -.51641400E+04, -.41128600E+04, 0.11318400E+04, 0.23978100E+04, -.23083600E+04, -.27089000E+04, -.23370600E+04, -.13473800E+04, 0.75583100E+03, 0.23150400E+04, 0.67402900E+03, 0.63198500E+03, 0.33073900E+03, -.56539600E+02, -.51365100E+03, -.29574300E+02, 0.27965000E+03, 0.10240100E+03, 0.22271400E+04, -.11291000E+04, 0.33405600E+04, -.11134200E+04, -.99220700E+03, -.24489000E+03, -.10258500E+03, 0.14795300E+03, -.93874200E+03, 0.89215300E+01, -.49589900E+03, -.20392700E+04, 0.99843800E+03, 0.58175600E+04, 0.10189500E+04, -.93232500E+03, 0.62823800E+03, -.45362400E+03, -.17856700E+04, -.13154000E+04, 0.10331500E+04, 0.47229600E+03, -.87661800E+04, 0.44652400E+04, -.74883800E+04, 0.43825900E+04, 0.31350700E+04, 0.18766700E+04, 0.28951400E+03, -.10785400E+04, 0.29158500E+04, 0.14043900E+04, 0.31004100E+04, 0.11152200E+04, -.55557600E+03, 0.89382800E+04, -.55933600E+03, -.11393500E+04, 0.66784000E+03, -.96525200E+03, -.19625300E+04, -.28887400E+04, 0.13334200E+04, -.94689300E+03, -.16019100E+05, 0.80344200E+04, -.11110000E+05, 0.80110600E+04, 0.64528900E+04, 0.47893900E+04, 0.58984600E+03, -.16908100E+04, 0.60446900E+04, 0.32425200E+04, 0.69366300E+04, 0.15152700E+04, -.78182800E+03, 0.15089900E+04, -.75755100E+03, -.65873400E+03, -.34447100E+03, 0.80242000E+01, 0.15833200E+03, -.56789300E+03, -.17542400E+03, -.36472200E+03, 0.13350300E+04, -.58878900E+03, -.56058200E+03, -.66735200E+03, 0.53970300E+02, 0.13549700E+03, -.17729500E+03, 0.27738200E+03, -.13902200E+03, 0.35939200E+02, 0.10121100E+04, -.71488000E+04, 0.35861400E+04, -.10412100E+05, 0.35748400E+04, 0.15492000E+04, -.33346800E+03, 0.41857500E+03, -.21270200E+03, 0.45899700E+04, -.71698900E+03, 0.69614700E+04, 0.86020800E+04, -.42876900E+04, 0.12775300E+05, -.43014900E+04, -.22864300E+04, 0.15638000E+03, -.36349400E+03, 0.15852100E+03, -.51842900E+04, 0.45608600E+03, -.79800000E+04, -.12724500E+04, -.15470600E+04, -.12996400E+04, -.10168300E+04, -.13798200E+04, -.55402100E+03, -.10690100E+04, -.12883800E+04, 0.61026600E+03, 0.85379300E+03, -.19543300E+04, -.17857700E+04, 0.71754600E+03, 0.14584400E+04, 0.91723300E+03, -.31957600E+03, 0.15316200E+04, -.35746200E+03, 0.99792600E+03, 0.33474500E+03, 0.12556200E+04, 0.96521700E+03, 0.35736200E+03, -.97638500E+03, -.10915100E+04, -.14295200E+04 },
        { -.25181000E+00, 0.10063400E+01, 0.30046900E+01, -.82144200E+00, -.24899700E+01, -.76677500E+00, -.41418200E+01, -.39630700E+00, -.10325300E+01, -.11859300E+01, 0.38384500E+00, 0.21528500E+01, 0.64632100E+00, 0.11481500E+01, 0.14374500E+01, 0.17383400E+00, 0.26470700E+01, -.40902400E+00, 0.19029600E+01, 0.55298600E+00, 0.41808900E-01, 0.55057200E+01, -.20194800E+06, 0.10058300E+06, -.13903600E+06, 0.10098700E+06, 0.97354200E+05, 0.75317200E+05, -.22299400E+04, -.20046400E+05, 0.73314600E+05, 0.48550900E+05, 0.11781800E+06, -.28178700E+05, 0.12677900E+05, 0.14682300E+06, 0.13969500E+05, 0.18035500E+05, 0.21273900E+05, -.45060900E+04, -.13782100E+05, -.15257400E+05, 0.25337700E+05, -.17154000E+05, -.43344100E+05, 0.21824900E+05, -.96001100E+05, 0.21641300E+05, 0.11711500E+05, 0.15361800E+04, 0.14218700E+04, -.30343000E+04, 0.28051800E+05, -.46389600E+04, 0.34799200E+05, 0.39936800E+05, -.20332500E+05, 0.96409200E+05, -.19964900E+05, -.30085100E+04, 0.15511200E+05, -.12553200E+05, -.40952800E+02, -.24916500E+05, 0.13876900E+05, -.40045800E+05, -.33988800E+05, 0.16897000E+05, -.41339300E+05, 0.16966100E+05, 0.18731900E+04, -.18034400E+04, 0.22627200E+04, -.75395300E+03, 0.19075100E+05, -.27375000E+04, 0.28503200E+05, -.14125000E+05, 0.68868200E+04, -.27595600E+05, 0.70696800E+04, 0.29653100E+04, 0.19955000E+03, 0.16171700E+04, -.88535100E+03, 0.89902400E+04, -.13978300E+04, 0.14203800E+05, 0.87670200E+05, -.43348300E+05, 0.10990900E+06, -.43839900E+05, -.33397200E+05, -.11774400E+05, -.13631900E+05, 0.31760000E+04, -.48980600E+05, -.65422900E+04, -.73943300E+05, 0.58457300E+05, -.29584600E+05, 0.14978400E+06, -.29390700E+05, -.55434500E+04, 0.47944900E+04, 0.27274900E+04, 0.98555400E+04, -.34166600E+05, 0.11878000E+05, -.54015700E+05, -.11856100E+03, 0.45017500E+03, -.19085200E+04, 0.76438900E+02, -.44555600E+04, -.89288700E+04, 0.40873400E+04, 0.18618700E+04, 0.35669900E+04, -.73116900E+04, -.41229000E+04, -.86572600E+05, 0.42637500E+05, -.94571800E+05, 0.43268200E+05, 0.28727900E+05, 0.13183000E+05, 0.36246800E+04, -.26608800E+04, 0.48327100E+05, 0.61625900E+04, 0.82536200E+05, -.13969600E+06, 0.69456000E+05, 0.41115700E+05, 0.69837300E+05, 0.21430300E+05, 0.68974400E+04, 0.13136200E+05, -.24194300E+05, 0.32453700E+05, 0.11271700E+05, 0.47702900E+05, -.70636400E+04, 0.26173500E+04, 0.70512300E+05, 0.34569700E+04, 0.77539200E+04, 0.65453100E+04, 0.17388800E+04, -.54612100E+04, -.77053400E+04, 0.90618000E+04, -.14399800E+05, -.13537900E+06, 0.67436900E+05, -.16645000E+06, 0.67514400E+05, 0.53098000E+05, 0.39107400E+05, 0.25262500E+04, -.72168200E+04, 0.64349300E+05, 0.15823600E+05, 0.94896000E+05, 0.12693700E+05, -.47999600E+04, -.47835500E+05, -.63167000E+04, -.73129800E+04, -.10257500E+05, 0.26085700E+04, 0.49674700E+04, 0.15311600E+04, -.72572000E+04, -.57631100E+04, -.32187200E+05, 0.16150600E+05, -.69191900E+05, 0.16105600E+05, 0.10114500E+05, 0.27231700E+04, 0.30736700E+04, -.14032500E+04, 0.19520200E+05, -.16729100E+04, 0.27713500E+05, 0.38161100E+04, -.19476800E+04, -.11081500E+06, -.19601200E+04, 0.12942500E+05, -.72563000E+04, 0.15389700E+05, 0.29012400E+05, 0.32409400E+05, -.17809000E+05, 0.32334000E+05, 0.14742000E+06, -.73536900E+05, 0.15546000E+06, -.73754800E+05, -.43402200E+05, -.15333900E+05, -.15484300E+05, 0.12968300E+05, -.66895900E+05, -.10607500E+05, -.94465800E+05, -.30844100E+05, 0.15736100E+05, -.15922400E+06, 0.15291500E+05, 0.12752300E+05, -.17089100E+05, 0.25073300E+05, 0.33116500E+05, 0.53591600E+05, -.29955800E+05, 0.57164300E+05, 0.27300900E+06, -.13737500E+06, 0.24252900E+06, -.13639500E+06, -.10379900E+06, -.64624300E+05, -.14823400E+05, 0.30204200E+05, -.11904700E+06, -.45240800E+05, -.15334600E+06, -.20715700E+05, 0.10172800E+05, -.33970600E+05, 0.10364300E+05, 0.63226900E+04, 0.23613600E+04, 0.19380000E+04, -.73220900E+03, 0.12322000E+05, -.20806600E+03, 0.18314900E+05, -.10269200E+05, 0.47469200E+04, 0.57118800E+04, 0.51392700E+04, -.25395300E+03, -.99924100E+03, 0.65245000E+03, -.29698400E+04, -.72009100E+03, 0.16766800E+03, 0.81822600E+03, 0.14743600E+06, -.73083900E+05, 0.19451900E+06, -.73684800E+05, -.33056100E+05, -.10403600E+05, -.65052400E+03, 0.13110300E+05, -.82403100E+05, -.33719900E+03, -.12936700E+06, -.19371700E+06, 0.96391800E+05, -.23924100E+06, 0.96824300E+05, 0.47624700E+05, 0.21370100E+05, -.16027800E+03, -.18496600E+05, 0.96574700E+05, 0.10261700E+05, 0.15135200E+06, 0.17710500E+05, 0.20877900E+05, 0.14913900E+05, 0.16813700E+05, 0.25081100E+05, 0.67454400E+04, 0.21074500E+05, 0.18070100E+05, -.12062700E+05, -.86494100E+04, 0.36645000E+05, 0.20563200E+05, -.74238100E+04, -.32334300E+05, -.99565700E+04, 0.71179200E+04, -.21179800E+05, -.96555400E+03, -.28157200E+05, -.37765300E+04, -.16913100E+05, -.22906800E+05, -.79838700E+04, 0.13942000E+05, 0.24973900E+05, 0.30524600E+05 },
        { 0.84484300E-01, -.66371000E+00, -.78277800E+00, 0.56819100E-01, -.66563400E-01, -.22508100E+00, 0.35266100E-01, 0.11722300E+01, 0.15483000E+00, -.37927100E+00, -.22873900E-01, -.57870800E+00, -.34281500E-01, -.97472200E-01, 0.29927900E+00, 0.14998200E+00, 0.88223200E+00, 0.53659700E-01, 0.42270100E+00, 0.27529500E+00, 0.97954200E+00, -.22017400E+01, 0.11628000E+00, -.36036400E+03, 0.60752100E+04, -.12863100E+01, -.79261700E+02, -.13580700E+02, -.23436700E+03, -.19582900E+04, -.85115800E+03, 0.30477900E+04, -.28664800E+04, 0.80686900E+04, -.49939300E+04, -.12214800E+05, -.40219100E+04, -.64953100E+04, -.96783800E+04, 0.44297800E+04, 0.69506500E+04, 0.48514000E+04, -.99798300E+04, -.28857400E+04, -.79426300E+04, 0.40244600E+04, 0.75088000E+04, 0.39746400E+04, 0.38116600E+04, 0.43868100E+04, -.49333600E+02, -.22078000E+04, -.31036200E+03, 0.45213200E+04, 0.26321400E+04, 0.10721200E+05, -.55967900E+04, -.87296400E+04, -.53602000E+04, -.57588300E+04, -.80636100E+04, 0.26150100E+04, 0.45739600E+04, 0.12268400E+04, -.67439300E+04, -.31355900E+04, 0.37272700E+04, -.18623700E+04, 0.61254800E+04, -.18604700E+04, 0.11969600E+04, 0.12890300E+04, -.68462500E+03, -.40284500E+03, -.40044400E+03, 0.62728400E+03, -.43068700E+04, -.18110900E+04, 0.79746300E+03, 0.19715900E+04, 0.90474500E+03, 0.19135400E+04, 0.26410900E+04, -.77573400E+03, -.12074800E+04, -.73454000E+03, 0.23995500E+04, 0.24812800E+03, 0.30714500E+04, -.11085000E+04, -.23997700E+04, -.15341100E+04, -.75865200E+04, -.13009900E+05, 0.75794800E+04, 0.81685100E+04, 0.84274600E+04, -.11932800E+05, -.11923800E+02, 0.20455700E+05, -.10328200E+05, -.14432100E+05, -.10210100E+05, -.66261900E+04, -.75027700E+04, -.15513900E+04, 0.46380500E+04, -.25709400E+04, -.67806200E+04, -.74333900E+04, 0.13999100E+04, -.46481500E+03, -.49249500E+02, -.70179300E+03, 0.27336100E+03, 0.53141100E+03, -.14760800E+03, 0.81227700E+03, -.10622900E+04, 0.32932900E+03, -.11924600E+04, 0.37835500E+04, -.23017600E+04, 0.48395500E+04, -.18897600E+04, 0.86029800E+04, 0.14649400E+05, -.70738100E+04, -.59475200E+04, -.66021700E+04, 0.12324400E+05, -.62884200E+04, 0.17485700E+05, -.90757800E+04, -.70458700E+04, -.87411400E+04, -.57992200E+04, -.58062200E+04, 0.66060500E+03, 0.55091800E+04, -.12290300E+04, -.59366300E+04, -.74536800E+04, 0.37263200E+03, -.84918800E+03, -.24812000E+04, -.17998700E+03, -.21922900E+04, -.42439200E+04, 0.23845400E+04, 0.26950700E+04, 0.23793500E+04, -.43248600E+04, -.31093700E+03, -.77420100E+04, 0.37795200E+04, 0.15141200E+05, 0.38901000E+04, 0.86587700E+04, 0.85571600E+04, -.62326300E+03, -.37483800E+04, -.96477400E+03, 0.94545300E+04, -.12993800E+04, -.11828900E+04, 0.16461400E+04, 0.19911100E+04, 0.58767300E+03, -.20304200E+04, -.31019800E+04, 0.40015600E+03, -.33594200E+03, 0.18017500E+04, -.27557400E+04, 0.15908100E+04, -.40458600E+04, 0.20167000E+04, 0.45916300E+04, 0.20215700E+04, 0.22219100E+04, 0.32873300E+04, -.87027700E+03, -.23110400E+04, -.10730600E+04, 0.33894400E+04, 0.11089900E+04, 0.10245200E+04, -.61229800E+03, -.30652000E+04, -.50660600E+03, 0.43569000E+04, 0.51524900E+04, -.19237800E+04, -.11189300E+04, 0.96125400E+03, 0.46164700E+04, -.59122100E+04, 0.82280600E+04, -.38965500E+04, -.11539100E+05, -.41083900E+04, -.61471600E+04, -.10737000E+05, 0.41670400E+04, 0.53968000E+04, 0.42888300E+04, -.93284100E+04, -.40737300E+04, 0.12816500E+05, -.64008800E+04, 0.51957800E+04, -.63940700E+04, 0.40780500E+04, 0.63710000E+04, -.47313400E+04, -.91956300E+03, -.38523000E+04, 0.63533300E+04, -.12742500E+05, 0.13233100E+04, -.11635800E+04, -.11739600E+05, -.67282100E+03, -.18588200E+04, -.59652600E+04, 0.45346500E+04, 0.66379900E+04, 0.68060100E+04, -.75123800E+04, -.13304100E+04, -.21481800E+04, 0.96046200E+03, 0.24445600E+04, 0.10733800E+04, 0.21209000E+04, 0.28528600E+04, -.80174900E+03, -.13841700E+04, -.84889600E+03, 0.26630200E+04, 0.23001100E+03, 0.25592700E+04, -.14988800E+04, -.10159000E+04, -.12792500E+04, -.13850600E+04, -.24861800E+04, 0.68517900E+03, 0.13693300E+04, 0.11582400E+04, -.20538000E+04, -.95668400E+03, 0.14929600E+05, -.73209900E+04, -.16424400E+05, -.74684500E+04, -.10799900E+05, -.12478400E+05, 0.41415900E+03, 0.62719500E+04, -.28449900E+04, -.96234600E+04, 0.17308400E+04, -.19725000E+05, 0.98349100E+04, 0.17080500E+05, 0.98662700E+04, 0.77533700E+04, 0.81964900E+04, 0.22512500E+04, -.60744900E+04, 0.61932000E+04, 0.57543700E+04, 0.49872300E+03, 0.15791100E+04, 0.39497100E+04, 0.24234300E+04, -.22469500E+04, 0.25165700E+04, -.35253700E+04, 0.39357600E+03, 0.41740300E+04, 0.18346200E+03, -.13801400E+04, -.52897800E+04, 0.29649600E+04, -.42725600E+04, -.36699300E+03, -.43853600E+04, 0.12220000E+04, -.25277300E+04, 0.22541100E+04, 0.24264000E+04, -.11822600E+04, -.12559800E+04, 0.21483400E+04, 0.70201300E+02, 0.23669400E+04, -.56296000E+04, -.55575700E+04 },
        { 0.16405700E+00, 0.46211200E+00, 0.13317300E+01, -.57916700E-01, -.38048300E+00, -.20859500E+00, 0.19941900E+00, 0.75870600E+00, 0.83742700E-02, -.26719400E+00, 0.19837700E+00, 0.13430700E+01, -.23064600E+00, 0.26052500E+00, 0.42406100E+00, -.28206000E+00, 0.61664700E+00, -.81782600E-01, -.42083200E+00, 0.70603200E+00, -.14356400E-01, -.87155400E+00, -.18963100E+00, 0.10114300E+01, -.24872400E+05, 0.51455300E+01, 0.90850000E+04, 0.12953700E+05, -.75361400E+04, -.13939100E+04, -.43437800E+04, 0.54461400E+04, 0.10064200E+05, -.39566200E+05, 0.19524300E+05, 0.48930900E+05, 0.19735800E+05, 0.21818900E+05, 0.20860900E+05, -.53323400E+04, -.12558800E+05, 0.19597100E+04, 0.21653500E+05, 0.88458400E+04, 0.17222500E+05, -.85749900E+04, -.24874700E+05, -.86234100E+04, -.85886500E+04, -.81545200E+04, -.38107600E+03, 0.41865000E+04, -.46590000E+03, -.96805000E+04, -.41177300E+04, -.21489100E+05, 0.10606700E+05, 0.26809100E+05, 0.10745800E+05, 0.12220200E+05, 0.16600000E+05, -.53326300E+04, -.76917300E+04, 0.11189700E+04, 0.14092000E+05, 0.48471500E+02, -.57930700E+03, 0.25461500E+03, -.17162800E+05, 0.27846800E+03, -.35033200E+04, -.31386100E+04, 0.27514000E+03, 0.26377100E+04, 0.24922600E+04, -.28366200E+04, 0.67705400E+04, 0.10592500E+05, -.53004500E+04, -.87882600E+04, -.52934100E+04, -.39185400E+04, -.37005600E+04, 0.88817000E+02, 0.23352400E+04, -.16907100E+04, -.37797200E+04, -.16844600E+04, -.35615000E+05, 0.17729100E+05, 0.26531200E+05, 0.17805500E+05, 0.13093200E+05, 0.17908800E+05, -.61352800E+04, -.12574600E+05, -.61667600E+03, 0.16397400E+05, 0.39163300E+04, -.44137400E+05, 0.21996400E+05, 0.45427300E+05, 0.22004700E+05, 0.15733100E+05, 0.12850400E+05, 0.57247700E+04, -.74575600E+04, 0.83279400E+04, 0.14369900E+05, 0.12157100E+05, -.77283400E+04, 0.38823600E+04, 0.96681900E+03, 0.38709400E+04, -.11070000E+04, -.33289600E+04, 0.29978200E+04, 0.38146600E+03, 0.51995700E+04, -.29911900E+04, 0.25951900E+04, 0.30546000E+05, -.15276200E+05, -.28728600E+05, -.15280100E+05, -.12220900E+05, -.14874200E+05, 0.12678400E+03, 0.11218300E+05, -.83653500E+01, -.14080700E+05, 0.58665900E+04, -.66469600E+05, 0.33154800E+05, 0.22409900E+05, 0.33230500E+05, 0.16020200E+05, 0.10532700E+05, 0.20898200E+04, -.13351000E+05, 0.14814100E+05, 0.11760100E+05, 0.24477400E+05, -.15819200E+05, 0.77599800E+04, 0.19053400E+05, 0.78802800E+04, 0.90103200E+04, 0.80580800E+04, -.24311300E+03, -.39448100E+04, 0.24124200E+04, 0.83600800E+04, 0.22518200E+04, 0.43828900E+05, -.21944900E+05, -.49495500E+05, -.21983700E+05, -.13230700E+05, -.53893500E+04, -.48597300E+04, 0.91881300E+04, -.13151500E+05, -.11059400E+05, -.66178800E+04, -.85500000E+04, 0.44688400E+04, -.70847000E+04, 0.42869800E+04, -.33789500E+04, -.42824500E+04, 0.47302100E+04, 0.12448900E+04, 0.33402200E+04, -.29786200E+04, 0.20806900E+04, 0.16646100E+05, -.82850900E+04, -.19293000E+05, -.83182800E+04, -.62048700E+04, -.60794300E+04, 0.45958700E+03, 0.41402100E+04, -.20971100E+04, -.69554400E+04, -.32633600E+04, 0.60807000E+05, -.30358100E+05, -.28804300E+05, -.30424000E+05, -.15454300E+05, -.19012300E+05, 0.45477200E+04, 0.19578800E+05, -.12195600E+05, -.21078500E+05, -.14822200E+05, -.17934100E+05, 0.88666800E+04, 0.37338400E+05, 0.89492200E+04, 0.91809400E+04, 0.14879500E+05, -.46278100E+04, -.75960500E+04, -.34449100E+04, 0.12888900E+05, -.18065200E+04, 0.42803000E+05, -.21282000E+05, -.51796800E+05, -.21453100E+05, -.15106000E+05, -.21805100E+05, 0.92124800E+04, 0.19901300E+05, -.37107800E+04, -.25151300E+05, -.27209700E+04, -.23500000E+04, 0.94822800E+03, 0.49794800E+05, 0.12182600E+04, 0.11654900E+04, 0.41975600E+04, -.28266200E+04, -.52542100E+04, -.10928400E+05, 0.69539500E+04, -.56821100E+04, 0.11593000E+05, -.58014700E+04, -.10328800E+05, -.57939500E+04, -.40434800E+04, -.38985300E+04, 0.13615800E+03, 0.29641200E+04, -.15574100E+04, -.42154300E+04, -.18070700E+04, -.15692100E+05, 0.77050400E+04, 0.46472000E+04, 0.78478200E+04, 0.19528500E+04, 0.26107200E+04, 0.90322100E+03, -.33015300E+04, 0.19081900E+04, 0.25879700E+04, 0.59538500E+04, -.64898200E+05, 0.32593300E+05, 0.64284200E+05, 0.32462200E+05, 0.22877800E+05, 0.18769900E+05, 0.77282400E+04, -.15908900E+05, 0.96038200E+04, 0.18402900E+05, -.28925200E+04, 0.65434100E+05, -.32856100E+05, -.71290200E+05, -.32730600E+05, -.20680300E+05, -.14917600E+05, -.10312600E+05, 0.16354500E+05, -.11620500E+05, -.14666000E+05, 0.34644400E+04, -.93136100E+04, -.37386200E+04, -.61199200E+04, 0.10672800E+05, -.16361800E+04, 0.35467300E+04, -.18443200E+04, -.45093800E+04, -.55305600E+03, 0.66014500E+04, 0.89935700E+04, -.54320500E+04, 0.74782300E+04, -.32966400E+04, 0.98435700E+04, -.67727300E+04, 0.62211000E+04, -.38472600E+03, -.13394200E+04, 0.53046200E+04, -.34706400E+04, -.11918900E+05, -.17933000E+04, -.61611500E+04, 0.10104800E+05, 0.10675600E+05 },
        { -.11284500E+00, -.27645300E+00, 0.83439200E-01, -.76315500E+00, -.15094400E-01, -.15320500E+00, -.10023700E+01, -.14648400E+01, -.47610800E+00, -.36833100E-01, 0.80635400E-01, 0.52274200E+00, -.14433500E+00, 0.11925300E+00, 0.17513400E+01, -.17711300E+00, 0.54615100E+00, -.97959000E-01, 0.13132800E+01, -.12230100E-01, 0.24478500E+00, 0.21807900E+00, -.56272600E+00, 0.47206900E+00, 0.10215800E+01, 0.11649100E+02, 0.85606800E+04, 0.22392100E+05, -.72284900E+04, -.66101700E+03, -.79545100E+04, 0.15919700E+05, 0.65350800E+04, 0.12984100E+05, -.63076500E+04, 0.30443800E+05, -.65965200E+04, 0.54866300E+04, 0.35223100E+04, 0.57375000E+03, 0.53717300E+04, -.10701400E+05, 0.28348200E+04, -.83218000E+04, 0.52597800E+04, -.25393500E+04, -.12739700E+05, -.26562300E+04, -.59540900E+04, -.15371000E+04, -.29504200E+04, -.31977000E+04, 0.28756800E+03, -.20917100E+04, -.29099600E+04, -.13749500E+05, 0.74815600E+04, 0.10491900E+05, 0.68807500E+04, 0.11510100E+05, 0.11541200E+05, -.26543200E+04, -.37245400E+03, 0.33932900E+04, 0.80782700E+04, 0.22376800E+04, -.27119100E+04, 0.12991500E+04, -.56227000E+04, 0.13321900E+04, -.26645000E+04, -.82991400E+03, -.95097700E+03, 0.95790900E+02, 0.44251000E+04, -.11706200E+04, 0.71309000E+04, 0.20739700E+04, -.11303200E+04, -.21925000E+03, -.10309200E+04, -.17324200E+04, 0.47372000E+03, -.95165600E+03, -.54261900E+03, -.42216600E+03, 0.41149900E+03, 0.92671600E+03, -.27673100E+05, 0.14035000E+05, -.55689700E+04, 0.13836500E+05, 0.81344600E+04, 0.32853600E+04, -.15006000E+04, -.55682800E+04, 0.63660000E+04, 0.10697000E+04, 0.43003700E+04, -.85934400E+04, 0.39468900E+04, 0.21692400E+05, 0.41592700E+04, 0.13603400E+05, 0.32092200E+04, 0.66819100E+04, 0.77310600E+04, 0.42260900E+04, 0.38050300E+04, 0.10963000E+04, 0.11739900E+04, -.40442400E+03, -.71132100E+04, -.57226300E+03, -.12663700E+04, -.31072200E+04, 0.43962200E+03, -.54464400E+03, 0.18815500E+04, -.26765500E+04, -.28854500E+04, 0.19930500E+05, -.10488600E+05, 0.88990800E+03, -.99804400E+04, -.30065700E+04, 0.41576500E+04, -.43519900E+04, 0.42448900E+04, -.24846500E+04, 0.28362400E+04, 0.73370700E+04, -.32496900E+05, 0.16557300E+05, -.18790100E+04, 0.16241300E+05, 0.74948100E+03, -.56928100E+04, 0.81477300E+04, -.29043800E+04, 0.62936600E+04, -.43433300E+04, 0.13928100E+05, 0.96086200E+04, -.45253000E+04, 0.13127700E+05, -.48748900E+04, 0.16854400E+04, 0.89339700E+03, 0.53400500E+03, 0.14869700E+04, -.55668200E+04, 0.68038500E+03, -.67460800E+04, 0.10438400E+05, -.53229200E+04, 0.59401000E+04, -.53684100E+04, -.88494400E+03, 0.22674000E+05, -.11548700E+05, -.25261500E+03, -.68400800E+04, 0.15850400E+05, 0.33035700E+04, 0.31064000E+04, -.17078400E+04, -.19028900E+05, -.15293400E+04, -.48891200E+04, -.10343300E+05, 0.28047000E+04, 0.21514100E+04, 0.44260500E+04, -.77246300E+04, -.37040400E+04, 0.38421200E+04, -.19438700E+04, -.75571700E+04, -.19109900E+04, -.37289000E+04, 0.24963200E+03, -.17804200E+04, -.15457500E+04, -.61414800E+03, 0.91588400E+01, 0.42425900E+03, 0.39927600E+05, -.19938600E+05, -.90161800E+04, -.20008200E+05, -.49692700E+04, 0.22384200E+04, -.32890000E+04, 0.14451900E+05, 0.56687400E+03, -.57776900E+03, -.77873600E+04, -.54937300E+04, 0.29909200E+04, 0.93638000E+04, 0.27114600E+04, 0.11061700E+05, 0.79691100E+04, -.41686500E+04, -.19955800E+03, 0.36449900E+03, 0.46214100E+04, -.11094500E+04, 0.36452200E+05, -.17959800E+05, -.18911000E+05, -.18337400E+05, -.10454300E+05, -.62502400E+04, 0.23143100E+04, 0.17604600E+05, 0.47252000E+04, -.83610200E+04, -.42350200E+04, -.18056800E+04, 0.12029600E+04, 0.26962100E+05, 0.99872800E+03, 0.59189800E+04, -.13066800E+03, -.33393600E+04, 0.35551500E+03, -.51106200E+04, -.23113900E+03, -.28560000E+04, 0.23234700E+04, -.12552300E+04, -.19845600E+03, -.11563500E+04, -.15363100E+04, 0.11093800E+04, -.11229100E+04, -.26995800E+03, -.34025300E+03, 0.82416800E+03, 0.90629400E+03, -.70758000E+03, 0.89765700E+03, -.48676300E+04, 0.36120100E+03, -.54181800E+02, -.57549400E+03, -.62962300E+03, -.78340100E+03, -.94825400E+03, -.31504000E+03, -.27048400E+03, -.17155800E+05, 0.89512700E+04, 0.16952900E+05, 0.86061900E+04, 0.12935800E+05, -.24945000E+04, 0.99300000E+04, -.40382100E+03, -.39179600E+04, -.70855900E+03, -.18543200E+05, 0.72231800E+04, -.38898100E+04, -.26940900E+05, -.36407600E+04, -.15016900E+05, 0.27739200E+04, -.11652300E+05, -.17776000E+04, 0.59575100E+04, 0.16891300E+04, 0.23778600E+05, -.17722900E+04, 0.14998900E+04, -.18129600E+04, -.37283400E+03, -.27430100E+04, 0.48521900E+03, 0.47594400E+04, 0.87182700E+03, -.12023300E+03, 0.10970600E+03, 0.38203800E+03, 0.36350200E+04, 0.26837800E+03, 0.67584900E+03, 0.68059100E+04, -.11207900E+04, -.10822900E+04, -.17139100E+03, -.35490300E+04, -.24299400E+04, 0.34980200E+04, -.12304400E+04, -.64137400E+03, -.20992800E+04, 0.15900200E+04, 0.28734800E+04 },
        { 0.13206100E+00, -.14797900E+01, 0.25725200E+01, 0.16272600E+00, -.76174600E+00, -.43628400E-01, -.20184700E+01, -.17351400E+01, -.49906200E+00, 0.66792600E-01, 0.78755600E-01, 0.10163600E+01, -.93632700E-01, 0.23120000E+00, -.12558300E+00, 0.22552700E+00, 0.19755700E+00, -.26422400E+00, 0.35424700E+00, -.38247700E+00, -.41276200E-01, 0.97922300E+00, -.21889400E-01, 0.37998200E+00, 0.99849300E-01, 0.49666600E+00, -.10646600E+05, -.15359900E+05, 0.79418900E+04, 0.16077800E+04, 0.58626100E+04, -.13919400E+05, -.19436900E+04, 0.24040800E+04, -.10383900E+04, -.14922500E+05, -.12028900E+04, -.11839100E+04, 0.66555600E+04, -.12702900E+05, -.18655700E+05, -.95444300E+04, 0.70652100E+04, -.15584400E+04, 0.10914700E+04, -.55318600E+03, 0.29973300E+04, -.54616900E+03, 0.99575100E+03, -.15660700E+04, 0.25643200E+04, 0.28596200E+04, 0.72757000E+03, -.11034900E+04, 0.18683500E+04, -.10029800E+05, 0.51338200E+04, 0.32553400E+04, 0.50137600E+04, -.14278500E+04, -.47323400E+03, -.97254100E+03, -.68317900E+04, -.37848900E+04, 0.44450900E+03, 0.27696000E+04, -.46485800E+04, 0.23537700E+04, 0.44678400E+04, 0.23237200E+04, 0.14837800E+04, 0.13007600E+04, 0.99363400E+03, -.84386800E+03, -.44768500E+04, 0.16869800E+04, 0.66609500E+03, -.39770000E+04, 0.19856000E+04, 0.12333000E+04, 0.19886300E+04, -.10839000E+04, -.34835500E+04, 0.30052400E+04, 0.17912600E+04, 0.28332500E+04, -.30843900E+04, 0.12718600E+04, 0.25539800E+05, -.12740600E+05, -.64825600E+04, -.12771600E+05, 0.42016400E+04, 0.16006000E+05, -.16809000E+05, -.17150100E+05, -.22290800E+05, 0.15684200E+05, -.95247100E+04, 0.72035300E+03, -.34568100E+03, -.63955000E+04, -.36291600E+03, -.22703600E+04, 0.21500100E+04, -.38698800E+04, -.41394700E+04, -.36351600E+04, 0.11143400E+04, -.86004300E+01, 0.47162800E+04, -.23531600E+04, 0.39692100E+03, -.23579200E+04, 0.23746500E+04, 0.46732000E+04, -.37157400E+04, -.25285100E+04, -.35594900E+04, 0.44755600E+04, 0.31792500E+03, -.36549600E+05, 0.18232600E+05, 0.10833000E+05, 0.18274500E+05, -.55583100E+04, -.14073100E+05, 0.13323000E+05, 0.47567800E+04, 0.13242400E+05, -.11264500E+05, 0.10689600E+05, 0.17015300E+05, -.84285700E+04, 0.10556400E+04, -.85086400E+04, 0.28678200E+04, 0.99763200E+04, -.11990900E+05, -.93072500E+04, -.10900700E+05, 0.89324300E+04, -.85357800E+04, 0.37152000E+04, -.17230000E+04, -.98410500E+04, -.18560100E+04, -.11208800E+04, 0.31400300E+04, -.69215600E+04, -.88695000E+04, -.51070400E+04, 0.32898700E+04, -.38629300E+03, -.80513000E+04, 0.40403700E+04, -.28992500E+04, 0.40229100E+04, -.16516500E+05, -.24041300E+05, 0.16576200E+05, 0.53057500E+04, 0.11370000E+05, -.20314400E+05, 0.21464600E+03, 0.10700700E+05, -.54511700E+04, 0.46650700E+04, -.53491500E+04, 0.82889000E+04, 0.10722900E+05, -.19381100E+04, 0.71485900E+04, -.48503900E+04, 0.84718200E+04, -.44096700E+04, -.39825100E+04, 0.19685700E+04, 0.38080400E+04, 0.19915100E+04, 0.43586600E+03, -.28595600E+04, 0.36140600E+04, 0.30450300E+04, 0.36242300E+04, -.26549700E+04, 0.15572900E+04, -.46744500E+05, 0.23357200E+05, 0.18814600E+05, 0.23371400E+05, -.30707000E+04, -.11032000E+04, 0.59636700E+04, -.11555100E+05, 0.39059200E+04, 0.12583000E+04, 0.21307200E+05, -.13643800E+05, 0.68880200E+04, 0.38580000E+04, 0.68200400E+04, 0.37922200E+03, 0.61641400E+04, -.33856900E+04, -.85445000E+04, -.55840800E+04, 0.65601400E+04, 0.61937800E+04, -.49059600E+05, 0.24491600E+05, 0.21987900E+05, 0.24527800E+05, -.12647100E+04, 0.34841500E+03, 0.61423400E+04, -.13179800E+05, 0.32726500E+04, 0.25993400E+04, 0.22976000E+05, 0.48001300E+04, -.22452300E+04, -.15979200E+05, -.23993800E+04, -.59874000E+03, 0.11163000E+05, -.12518000E+05, -.19703700E+05, -.10176300E+05, 0.12253100E+05, 0.65471200E+03, -.39622500E+04, 0.19790800E+04, 0.10816800E+04, 0.19812500E+04, -.15444200E+04, -.39222100E+04, 0.32027300E+04, 0.16991100E+04, 0.29143000E+04, -.33931700E+04, 0.14022900E+04, 0.46677200E+04, -.22107600E+04, 0.54712200E+03, -.23352200E+04, 0.16286400E+04, 0.32125800E+04, -.17373300E+04, -.65615200E+03, -.23185100E+04, 0.25290900E+04, -.25237600E+04, 0.24920700E+05, -.12530900E+05, -.14243300E+05, -.12459800E+05, 0.51184300E+03, 0.71692200E+04, -.87297100E+04, -.33277500E+04, -.34378900E+03, 0.37472200E+04, -.13930500E+04, -.14357900E+05, 0.72660100E+04, 0.15058800E+05, 0.71783800E+04, 0.51018600E+04, -.24543200E+04, 0.61684600E+04, 0.52428700E+03, -.46177800E+04, -.19116100E+03, -.35183200E+04, 0.36274400E+04, -.60521100E+04, -.12099600E+04, -.13727500E+04, -.22895400E+04, 0.46051800E+04, -.28804200E+04, -.52701700E+04, 0.77425000E+02, -.10515800E+04, 0.52947400E+04, -.42935000E+04, 0.42567900E+04, 0.26783400E+04, 0.18735600E+04, 0.29398300E+04, 0.20298700E+04, -.44556800E+04, -.29509900E+04, 0.16458500E+04, 0.25387100E+04, 0.28667400E+04, 0.13717700E+04, -.83065000E+03, 0.41308800E+04, 0.32522400E+04 },
        { -.16983900E+00, 0.72066800E+00, -.26715400E+01, -.37584900E+00, 0.47840500E+00, 0.13101800E+00, 0.47210900E+00, 0.52099100E-01, -.83281700E-01, -.65603500E-01, 0.32924500E+00, -.63674200E-01, 0.17777300E+00, 0.12244900E+00, 0.39233300E+00, 0.32019100E+00, -.35523100E+00, 0.11909800E+00, -.18683500E-01, -.30685900E-01, -.60038400E+00, 0.11437900E+01, 0.30447100E-01, -.10547200E+01, -.65811400E-01, -.23150800E+00, -.32135300E+00, -.93809000E+04, 0.45241300E+04, 0.11230500E+04, 0.80056400E+04, -.83071700E+04, -.76700500E+04, -.45688800E+04, 0.21419800E+04, -.20213900E+04, 0.22852400E+04, -.11168500E+04, -.63633000E+04, 0.41592000E+04, 0.31101300E+04, 0.79830800E+04, -.64621600E+04, -.78206400E+04, -.27024600E+04, 0.13561100E+04, 0.24244100E+04, 0.13516000E+04, 0.17776700E+04, 0.24464000E+04, -.40730000E+03, -.10785400E+04, -.76409900E+03, 0.25942800E+04, 0.76004900E+04, 0.13394600E+05, -.67926300E+04, -.38629200E+04, -.66963100E+04, -.28469900E+04, -.33734400E+04, 0.83259900E+03, 0.55091100E+04, 0.30696700E+03, -.24053400E+04, -.93411700E+04, 0.53992300E+04, -.27004800E+04, 0.44439200E+03, -.26991300E+04, -.39720800E+03, -.12537300E+04, 0.25731300E+03, 0.15849700E+04, 0.25796800E+04, -.14752000E+04, -.62429500E+04, -.38088200E+03, 0.20091200E+03, 0.62341300E+03, 0.19032600E+03, 0.14693800E+04, 0.15850900E+04, -.72005100E+03, -.88738700E+03, -.58845000E+03, 0.12700500E+04, -.54044800E+02, 0.42086500E+04, -.21382700E+04, 0.13383700E+04, -.21028700E+04, -.71177200E+04, -.11594300E+05, 0.67458800E+04, 0.97091700E+04, 0.98704100E+04, -.96700100E+04, -.36443200E+04, 0.60859400E+04, -.30257700E+04, -.55859500E+04, -.30406300E+04, -.29556300E+04, -.19590500E+04, -.12811600E+04, 0.32306900E+03, -.62050300E+03, -.19112300E+04, -.63180900E+04, -.70060600E+04, 0.34832100E+04, 0.30790000E+04, 0.35028400E+04, 0.23837700E+03, 0.22860600E+03, 0.88958400E+03, -.11047400E+04, 0.28886800E+03, 0.70372700E+03, 0.62310200E+04, -.53566300E+04, 0.27065200E+04, 0.37237100E+04, 0.26786100E+04, 0.86764200E+04, 0.98810300E+04, -.34539800E+04, -.59422100E+04, -.17139100E+04, 0.68207300E+04, -.47625000E+04, 0.30035000E+04, -.15875000E+04, -.33335500E+04, -.15009400E+04, -.35649700E+04, -.65472500E+04, 0.26437100E+04, 0.21503300E+04, 0.28937400E+04, -.60059900E+04, -.53837500E+04, -.72084500E+04, 0.34856000E+04, 0.22984600E+04, 0.36029100E+04, 0.60488800E+03, -.25153100E+04, 0.26454300E+04, 0.75105700E+03, 0.43442500E+04, -.23020900E+04, -.11368400E+04, -.36451300E+04, 0.18716500E+04, 0.86926400E+04, 0.18249000E+04, 0.51878100E+04, -.58529200E+04, 0.57349100E+04, 0.50292200E+04, 0.80936900E+04, -.52732100E+04, -.14340600E+05, -.26272600E+04, 0.13906500E+04, -.76887600E+03, 0.13126200E+04, -.34728000E+04, -.77015300E+03, 0.44999400E+03, 0.38268400E+03, 0.12785800E+04, -.26758800E+03, 0.52676000E+04, -.26496500E+04, 0.13403900E+04, 0.19390600E+04, 0.13246100E+04, 0.16403100E+04, 0.16606400E+04, -.65382600E+03, -.18040000E+04, -.79665300E+03, 0.16330600E+04, 0.26762200E+04, 0.10628800E+05, -.52996800E+04, -.73167500E+04, -.53137300E+04, 0.48507200E+04, 0.12031200E+04, -.17565500E+04, 0.38751500E+04, 0.35506600E+04, 0.36589000E+03, -.12517800E+05, 0.12268900E+05, -.61772800E+04, -.35722800E+04, -.61329200E+04, -.57865200E+04, -.82720000E+04, 0.36299400E+04, 0.80898200E+04, 0.50352000E+04, -.67762200E+04, -.13287600E+05, 0.20545000E+05, -.10264900E+05, -.37364800E+04, -.10270800E+05, 0.33288600E+04, 0.45735400E+03, -.32749900E+04, 0.49150100E+04, 0.91371300E+03, -.37244800E+02, -.16138700E+05, 0.49269800E+04, -.25753100E+04, -.22156700E+03, -.24639900E+04, -.36575800E+04, -.58463300E+04, 0.28023200E+04, 0.75752000E+04, 0.58614700E+04, -.62433600E+04, -.68390600E+04, -.63752400E+03, 0.32957100E+03, 0.90876700E+03, 0.31865700E+03, 0.17430500E+04, 0.17160500E+04, -.66392300E+03, -.87370600E+03, -.61841700E+03, 0.13991500E+04, 0.20621000E+02, -.13561500E+04, 0.58143400E+03, 0.51594800E+02, 0.67915700E+03, -.19357600E+04, -.35321400E+04, 0.17133600E+04, 0.10061900E+04, 0.29218300E+04, -.30355700E+04, 0.42720500E+03, 0.25245100E+05, -.12616100E+05, -.15314400E+05, -.12623000E+05, -.92491600E+04, -.35501700E+04, -.44428700E+04, 0.53216600E+04, -.10802500E+05, -.80578300E+03, 0.93850700E+04, -.23646300E+05, 0.11826100E+05, 0.12531600E+05, 0.11823600E+05, 0.66209700E+04, 0.19066400E+03, 0.52647800E+04, -.44557600E+04, 0.12615400E+05, -.18255700E+04, -.93187100E+04, 0.32747200E+03, 0.19041500E+04, 0.20619500E+04, 0.29387900E+03, 0.32256000E+04, -.23218400E+04, 0.71514100E+03, 0.14565600E+04, 0.54653100E+02, -.38404500E+03, -.24059000E+04, -.62630200E+03, -.44702900E+04, -.15195000E+04, -.28773800E+04, -.36017700E+03, -.26882300E+04, 0.13536800E+04, -.37365200E+03, 0.83271500E+00, 0.75721800E+03, -.29739700E+03, -.96587600E+02, 0.18698500E+04, -.36828800E+04, -.21726500E+04 },
        { -.20302500E+00, 0.96602100E+00, -.25296900E+01, -.17706200E+00, 0.13689000E+01, 0.12879300E+00, 0.30237700E+01, 0.16904600E+01, 0.51039300E+00, 0.59781500E-01, -.38466300E+00, -.26950000E+01, 0.41314800E+00, -.78690700E+00, -.53994900E+00, -.33388200E+00, -.13873400E+01, 0.17915000E-01, -.10387200E+01, 0.99361800E-01, 0.12141200E-01, 0.43338100E+01, 0.39467400E+00, -.11428300E+01, -.60031300E+00, -.63225000E+00, -.10290000E+01, -.11530500E+01, 0.14072700E+05, 0.24006200E+05, 0.12688100E+05, -.39393400E+02, 0.68217700E+03, 0.20059100E+05, -.10375100E+05, -.29399500E+03, -.10028100E+05, -.75905400E+04, -.21387900E+04, -.10581400E+05, -.10682800E+05, -.38936400E+04, -.14755600E+04, -.11057400E+05, -.84940000E+04, 0.42727300E+04, -.16028500E+04, 0.42476200E+04, 0.38808300E+04, 0.56841700E+03, 0.25847000E+04, -.15203900E+04, 0.12792400E+04, 0.15174000E+04, 0.54522800E+04, 0.64978200E+04, -.35349300E+04, -.73456900E+03, -.32472800E+04, -.47140900E+04, -.48601200E+04, -.27581700E+03, 0.31146800E+04, 0.37586600E+04, -.46182300E+04, -.22734100E+04, -.11030100E+05, 0.55077600E+04, 0.21862700E+03, 0.55158600E+04, -.12240800E+03, -.16557200E+04, 0.40211300E+04, 0.95303600E+03, 0.77175600E+04, -.18144500E+04, 0.10558600E+04, -.58646700E+04, 0.29413000E+04, 0.36727400E+04, 0.29321400E+04, 0.20032100E+04, 0.15616500E+03, 0.26335100E+04, 0.14684900E+04, 0.15952700E+04, -.56016600E+02, 0.14039300E+04, 0.34596900E+05, -.17324200E+05, -.26592100E+05, -.17296000E+05, -.13319800E+05, -.78295800E+04, -.12953200E+05, -.82591100E+04, -.14899800E+04, -.53044800E+04, -.94648000E+04, 0.23279600E+05, -.11614000E+05, -.74890200E+04, -.11635800E+05, -.36088600E+04, 0.11033500E+04, -.43223000E+04, 0.60056200E+04, -.33161600E+04, -.10067500E+04, -.13923700E+05, 0.18460800E+04, -.92454200E+03, -.68095100E+04, -.92335400E+03, 0.44595100E+03, 0.11123800E+04, -.44297700E+04, -.84522200E+04, -.41159700E+04, 0.19075000E+04, -.26899800E+03, -.55691000E+05, 0.27904700E+05, 0.28004300E+05, 0.27846000E+05, 0.14931300E+05, 0.11578500E+05, 0.12556200E+05, 0.47031100E+04, 0.15310700E+05, 0.75555200E+04, 0.12432200E+05, 0.97348300E+04, -.50662000E+04, -.12486600E+05, -.48660700E+04, -.89656600E+04, -.48116200E+04, -.44078600E+04, -.56706200E+04, -.11302700E+04, -.33082700E+04, -.50018200E+04, 0.14924200E+04, -.10832700E+04, 0.24091000E+04, -.74839900E+03, -.26141600E+04, -.20581700E+04, -.36218000E+04, -.92204100E+04, -.77590300E+03, -.14751700E+04, -.31944100E+04, 0.77689200E+04, -.38501500E+04, 0.22123800E+05, -.38805200E+04, -.32693600E+04, -.35500700E+04, 0.17526300E+05, 0.27218400E+05, 0.88261600E+04, -.26350900E+04, 0.90314300E+03, 0.10249800E+05, -.48536300E+04, -.98954000E+04, -.51265800E+04, -.25350800E+04, -.65403200E+03, -.40152600E+03, 0.55607900E+04, -.18482000E+03, -.62959100E+03, -.37021700E+03, -.93608700E+04, 0.47314500E+04, 0.19401300E+04, 0.46800700E+04, 0.27383400E+04, -.45112200E+03, 0.47809100E+04, 0.23761200E+04, 0.23712000E+04, -.16024800E+03, 0.35477200E+04, 0.10777200E+05, -.53503500E+04, -.10844000E+04, -.53874800E+04, -.10157900E+04, 0.94924600E+03, 0.69128200E+04, 0.97771900E+04, 0.57099300E+04, 0.16401200E+04, -.58382100E+04, 0.16715900E+05, -.84705800E+04, -.13159100E+04, -.83553900E+04, -.10444500E+05, -.86775100E+04, -.34609500E+04, 0.10267100E+04, 0.37386700E+04, -.65410600E+04, -.38958900E+04, 0.16092700E+05, -.79863100E+04, 0.55203200E+03, -.80435000E+04, -.49804500E+04, -.31898700E+04, 0.11061800E+05, 0.14626000E+05, 0.56487700E+04, -.17178300E+04, -.93396000E+04, 0.34879900E+05, -.17729000E+05, -.92177300E+04, -.17440800E+05, -.10786000E+05, -.26795500E+04, -.20379200E+05, -.17867400E+05, -.10872900E+05, -.10448100E+03, -.11765300E+05, -.60346400E+04, 0.30254700E+04, 0.40460500E+04, 0.30171400E+04, 0.22399100E+04, 0.68997800E+03, 0.28237400E+04, 0.16520400E+04, 0.14818500E+04, 0.45611600E+03, 0.16651600E+04, -.12240700E+03, -.22609400E+03, -.32143100E+04, 0.62968100E+02, -.25928900E+04, -.37528400E+04, 0.18371900E+04, 0.32947100E+04, 0.40908400E+04, -.29303000E+04, -.58016900E+02, 0.66509800E+05, -.33145100E+05, -.37188900E+05, -.33255700E+05, -.85719900E+04, -.79366600E+03, -.18600200E+05, -.24056900E+04, -.25182100E+05, 0.44047700E+03, -.11054700E+05, -.66284000E+05, 0.33064200E+05, 0.23192500E+05, 0.33142800E+05, 0.71553100E+04, -.29327100E+04, 0.18526200E+05, 0.12830800E+04, 0.26408600E+05, -.32348100E+04, 0.88680200E+04, 0.53654600E+04, 0.44911900E+03, 0.33786800E+04, -.77057000E+04, 0.33391900E+04, 0.30097100E+04, -.32131300E+04, -.24834000E+03, 0.68177800E+03, -.21746300E+04, 0.34892600E+04, 0.63060800E+04, -.90607100E+03, 0.11625400E+04, -.20598500E+04, 0.71339800E+04, -.64908900E+04, -.22171500E+03, -.46704000E+04, 0.26299100E+04, 0.48067400E+04, 0.23945700E+04, 0.17347800E+04, 0.30272000E+04, 0.97109200E+03, 0.19906500E+04 },
        { -.15676700E+00, -.51489100E+00, -.36711700E+01, 0.22094900E+00, 0.30319400E+01, 0.34059400E+00, 0.32734900E+01, -.11575300E+01, 0.16198400E+00, 0.74720800E+00, -.15738300E+00, -.21677500E+01, -.11647800E+00, -.56082000E+00, -.88109200E+00, -.77760100E+00, -.24433500E+01, 0.43324200E+00, 0.65840000E+00, -.30541300E+00, 0.13051800E+00, -.79071100E+00, -.18568200E+00, -.35437600E-01, -.27337200E+00, -.21117100E+00, -.77623300E+00, -.82210900E+00, 0.26481100E+00, -.88850100E+04, -.50104200E+04, -.16267300E+04, -.50780000E+03, -.97700200E+04, 0.49140600E+04, 0.26544700E+04, 0.48852700E+04, 0.47923200E+04, 0.51312700E+04, -.50287900E+04, -.72113700E+04, 0.23823200E+04, 0.43781800E+04, 0.22363100E+04, 0.61230500E+04, -.30448500E+04, -.31143300E+04, -.30614600E+04, -.20172600E+04, -.92591300E+03, -.20154700E+03, -.57747200E+03, -.25663200E+04, -.96145500E+03, 0.29561900E+03, -.66726300E+04, 0.34325400E+04, 0.85857700E+04, 0.33365000E+04, 0.24084400E+04, 0.35107700E+04, -.12600500E+04, -.24895900E+03, 0.38433900E+04, 0.24276800E+04, -.36885600E+04, 0.65765100E+04, -.32970100E+04, 0.70032100E+03, -.32881600E+04, -.18646900E+04, -.10106800E+04, -.13604000E+03, 0.15059200E+04, -.92777600E+03, -.67127100E+03, -.17619000E+04, 0.11437500E+04, -.58982100E+03, -.60878000E+03, -.57190000E+03, -.15665400E+04, -.17256400E+04, 0.83088800E+03, 0.15222700E+02, -.23680200E+03, -.14756500E+04, 0.36351600E+03, -.10952400E+04, 0.59173500E+03, 0.22813900E+04, 0.54783100E+03, 0.47258700E+04, 0.87680800E+04, -.76319600E+04, -.63766200E+04, 0.94035800E+03, 0.71099200E+04, -.41029900E+04, -.12798200E+05, 0.63425700E+04, 0.66344000E+04, 0.63995600E+04, 0.37754500E+04, 0.15909800E+04, 0.17279000E+04, 0.39246700E+03, 0.54515600E+04, 0.15310400E+04, 0.52844100E+04, -.12892100E+03, 0.10133900E+03, -.48653300E+03, 0.64429400E+02, 0.88625600E+03, 0.11151000E+04, -.69963400E+03, 0.95712000E+02, 0.31180300E+03, 0.11786500E+04, 0.28337300E+04, -.34604900E+04, 0.16381200E+04, 0.87610500E+03, 0.17303000E+04, -.56092400E+04, -.76576700E+04, 0.44794100E+04, 0.18520000E+04, 0.20122400E+04, -.66292200E+04, 0.77033800E+04, -.72633300E+04, 0.36816300E+04, 0.26479400E+04, 0.36317700E+04, 0.43425200E+04, 0.32253300E+04, -.30041800E+04, -.58290400E+04, 0.93167200E+02, 0.29584200E+04, 0.25559700E+04, -.28603700E+04, 0.14692300E+04, -.12362500E+04, 0.14300000E+04, 0.13553600E+04, 0.19043700E+04, -.19433700E+04, -.29746500E+04, 0.12026700E+04, 0.15959200E+04, 0.17350300E+04, 0.54992500E+04, -.27739000E+04, 0.93276200E+03, -.27491900E+04, -.10044700E+05, -.78327800E+04, 0.63901400E+04, -.70308500E+03, -.12574500E+04, -.78311500E+04, -.12474800E+05, 0.32032200E+04, -.16120300E+04, -.23674700E+04, -.16017700E+04, 0.23551800E+04, 0.25406000E+04, 0.12821600E+04, 0.60861400E+04, 0.25541100E+03, 0.24944400E+04, -.34992700E+04, 0.47041500E+04, -.23541200E+04, -.27323000E+04, -.23521200E+04, -.14293800E+04, -.14262300E+04, 0.46984800E+03, 0.86266000E+02, -.16850700E+04, -.13400000E+04, -.58110700E+03, 0.40280800E+04, -.20119000E+04, -.59121300E+04, -.20139200E+04, -.32838900E+04, -.36898400E+04, 0.34923300E+04, 0.53196400E+04, 0.40250600E+04, -.41548700E+04, -.23055200E+04, -.12772800E+05, 0.64268500E+04, 0.10530600E+05, 0.63866000E+04, 0.34714100E+04, 0.59568000E+04, -.21991400E+04, 0.55271200E+03, 0.63606600E+04, 0.38944700E+04, -.35408300E+04, 0.19736400E+05, -.98228600E+04, -.40364000E+04, -.98679000E+04, -.72261100E+04, -.89759000E+04, 0.45800500E+04, 0.79044500E+04, -.37431600E+03, -.88930800E+04, -.77394300E+04, -.58135400E+04, 0.29566300E+04, 0.48019900E+04, 0.29067000E+04, 0.10065000E+04, 0.38597300E+04, -.64688100E+04, -.42897800E+04, 0.49490300E+04, 0.32260300E+04, 0.19510100E+03, 0.13607300E+04, -.69855900E+03, -.63281800E+03, -.68038900E+03, -.17227800E+04, -.18433000E+04, 0.10307000E+04, 0.13217700E+03, -.29706000E+03, -.16073100E+04, 0.23564700E+03, -.45669100E+03, 0.32082000E+03, -.32193200E+03, 0.22844300E+03, 0.86770500E+03, 0.15342500E+04, -.11218400E+04, -.18200100E+04, -.37766300E+03, 0.12090400E+04, 0.15215600E+03, -.36117300E+04, 0.18822300E+04, 0.32282300E+04, 0.18057800E+04, 0.83184100E+04, 0.47953200E+04, -.12060000E+04, -.96694600E+03, -.46161700E+03, 0.40803700E+04, -.43538100E+04, 0.10534800E+05, -.53239400E+04, -.10317200E+05, -.52672900E+04, -.47856500E+04, 0.75493100E+02, -.25316300E+04, -.17853300E+04, -.13818200E+04, 0.32319100E+03, 0.39583700E+04, -.10424100E+04, -.28783900E+04, -.30525500E+04, 0.15680100E+04, -.20414300E+04, 0.16702800E+04, -.85106300E+03, -.29168300E+04, 0.20025400E+03, 0.18105300E+04, 0.19424500E+04, -.40469300E+04, 0.20979500E+04, 0.18991200E+04, 0.36134000E+04, -.11856600E+04, 0.23183200E+04, -.99276900E+03, -.19509600E+04, 0.12801000E+04, 0.17120000E+04, -.14896200E+04, 0.16585600E+03, -.27802900E+04, 0.23588300E+04, 0.26912500E+04 },
        { 0.25657900E+00, 0.62926300E+00, 0.61530200E+00, -.23163700E-01, -.29082600E+00, 0.16868500E+00, 0.17659000E+01, -.71112100E+00, -.83042200E-01, -.80486500E-01, 0.54528900E-01, 0.19799300E+01, 0.21802900E+00, 0.67661700E+00, -.31037000E+00, -.38517700E+00, 0.39405000E+00, -.14353300E+00, -.11459100E+01, -.28838800E+00, 0.18793500E+00, 0.14098000E+01, 0.15021400E+00, 0.36897500E+00, -.17415200E+00, -.70188700E-01, 0.39223600E+00, 0.11574600E+01, 0.42154200E+00, -.76973600E-01, -.57939800E+04, -.58225800E+03, 0.55185200E+04, -.50396600E+04, 0.26001600E+04, 0.22877000E+04, 0.25186600E+04, 0.33195000E+04, 0.70690200E+04, 0.19453600E+03, 0.15424600E+04, -.37429800E+04, 0.67334900E+04, 0.10017800E+05, 0.67549900E+04, -.34556300E+04, 0.10013400E+04, -.33780100E+04, -.31391000E+04, -.27497400E+04, -.35239400E+03, 0.20048100E+04, -.68546900E+03, -.27419800E+04, -.85230300E+04, -.12541200E+05, 0.59307000E+04, 0.80969400E+04, 0.62692300E+04, 0.54482500E+04, 0.58494500E+04, -.81718700E+03, -.62487200E+04, -.23416900E+04, 0.48454300E+04, 0.11214800E+05, -.29914400E+04, 0.15007700E+04, 0.23308500E+04, 0.14950500E+04, 0.13117600E+03, 0.82497900E+03, 0.53903200E+03, -.11002800E+04, -.50280600E+04, 0.19764400E+04, 0.47902500E+04, 0.21512100E+04, -.10368100E+04, -.12839900E+04, -.10754400E+04, -.20746100E+04, -.17430200E+04, 0.18564500E+03, 0.78057000E+03, 0.10572600E+03, -.13349300E+04, -.86197800E+03, -.11663100E+05, 0.57614600E+04, 0.10754100E+05, 0.58295800E+04, 0.10706000E+05, 0.12306600E+05, -.18022000E+04, -.47398300E+04, -.80504400E+04, 0.10132400E+05, 0.65651400E+04, -.20897000E+05, 0.10646200E+05, 0.38405500E+04, 0.10445200E+05, 0.55367600E+04, 0.37772400E+04, 0.89985800E+03, -.65935600E+04, 0.26579300E+04, 0.29299700E+04, 0.12760400E+05, 0.15605500E+04, -.86552200E+03, 0.13956400E+04, -.78001900E+03, -.76428900E+02, -.59686000E+03, 0.16295700E+03, 0.14505700E+04, 0.12599200E+04, -.10571200E+04, -.38685900E+04, 0.61156800E+04, -.27352400E+04, -.79469800E+04, -.30582600E+04, -.12044600E+05, -.16488100E+05, 0.73192000E+04, 0.55653800E+04, 0.25728000E+04, -.11362400E+05, 0.34938400E+04, -.90765400E+04, 0.44668700E+04, 0.66757300E+04, 0.45371600E+04, 0.53697200E+04, 0.43963600E+04, 0.18424500E+04, 0.10276700E+04, 0.12037600E+03, 0.41310600E+04, 0.70484800E+04, 0.67662300E+04, -.34035300E+04, -.17031500E+04, -.33813200E+04, 0.95400500E+01, 0.25470900E+04, -.14476200E+04, 0.25483500E+04, -.41669400E+04, 0.21924700E+04, 0.49586100E+03, 0.96883600E+04, -.48959500E+04, -.13740900E+05, -.48474300E+04, -.52020200E+04, -.91784600E+03, -.59786700E+04, -.53968000E+04, -.94998400E+04, -.46743400E+03, 0.10843300E+05, -.73529100E+03, 0.45861500E+03, -.30692300E+03, 0.36904300E+03, 0.42242000E+04, 0.40778500E+04, -.33815200E+04, -.60190400E+04, -.33094300E+04, 0.33459700E+04, -.25145400E+04, 0.52331300E+04, -.26262700E+04, -.73634500E+03, -.26162600E+04, -.22719400E+04, -.19851800E+04, -.15015600E+03, 0.19070600E+04, 0.72447500E+02, -.18603500E+04, -.37803800E+04, -.28222700E+05, 0.14054300E+05, 0.14329100E+05, 0.14110400E+05, -.25082400E+03, 0.18975000E+02, 0.21632100E+04, -.75049900E+04, -.23121800E+04, 0.17029000E+04, 0.20768100E+05, -.12365700E+05, 0.60866900E+04, 0.78565300E+04, 0.61807100E+04, 0.94249300E+04, 0.12122800E+05, -.37450800E+04, -.79206700E+04, -.63543500E+04, 0.10228400E+05, 0.16175300E+05, -.37536000E+05, 0.18572700E+05, 0.14925900E+05, 0.18765600E+05, 0.90654300E+03, -.64476400E+03, 0.37698400E+04, -.86043800E+04, -.72391000E+03, 0.95798700E+03, 0.24061100E+05, -.12268500E+05, 0.60333000E+04, 0.70700700E+04, 0.61347800E+04, 0.57401300E+04, 0.87341800E+04, 0.69089900E+03, -.11913200E+04, -.73511900E+03, 0.81038600E+04, 0.93432400E+04, 0.25542200E+04, -.12401000E+04, -.14895600E+04, -.12769600E+04, -.23518000E+04, -.21658800E+04, 0.20263200E+03, 0.76907400E+03, 0.83814000E+02, -.17135500E+04, -.96544800E+03, 0.18053600E+04, -.12157000E+04, 0.83813300E+03, -.90413600E+03, 0.20760600E+04, 0.30715600E+04, -.14676600E+04, -.15376600E+04, -.35208700E+04, 0.24932700E+04, -.74108300E+03, -.31311000E+05, 0.15447100E+05, 0.14175200E+05, 0.15656200E+05, 0.11555700E+05, 0.68829500E+04, 0.36404400E+03, -.67731000E+04, 0.15667200E+05, 0.18619400E+04, -.26783900E+04, 0.29606800E+05, -.14707500E+05, -.55172500E+04, -.14804100E+05, -.79170600E+04, -.15488200E+04, -.11717000E+04, 0.60178400E+04, -.17641200E+05, 0.25591600E+04, 0.81210700E+03, -.21595300E+04, -.32702800E+04, -.29659100E+04, 0.62398300E+03, -.38030600E+04, 0.12819200E+04, 0.11374700E+04, -.26101100E+04, -.15616900E+00, 0.10132900E+04, 0.11148100E+04, -.16550500E+04, 0.57119700E+04, 0.14869700E+04, 0.29430300E+04, -.12796200E+04, 0.44087400E+04, -.12307900E+04, 0.14125900E+04, -.48586900E+03, -.10192000E+04, -.10858600E+04, -.14432700E+03, -.26733300E+04, 0.42370600E+04, 0.15171400E+04 },
        { -.32396900E+00, -.22900800E+01, 0.11162300E+01, -.24241500E-03, 0.11080000E+01, 0.55572700E+00, 0.17236400E+01, -.25759700E+00, -.45512600E-01, 0.33231200E+00, 0.18407300E+00, -.14596400E+01, -.29425800E+00, -.93753700E+00, -.31026900E+00, -.12319800E+00, -.19621600E+00, 0.87020700E-01, -.19455900E+00, 0.14131500E+00, 0.45967000E+00, -.36561800E+01, -.17492900E+00, -.29908800E+01, -.56544900E+00, 0.23596300E+00, -.12999600E+01, 0.31730700E+00, -.20005300E+00, 0.84245800E+00, 0.40508900E-01, 0.93097300E+04, -.17233400E+04, -.25124900E+04, 0.16024800E+04, -.28860700E+05, 0.12614300E+04, -.12780800E+05, -.11804300E+05, 0.91250900E+03, -.97935800E+04, 0.66735400E+04, -.11913100E+05, 0.78946900E+03, -.22879400E+05, 0.11465900E+05, 0.15111400E+05, 0.11441900E+05, 0.14587700E+05, 0.10126900E+05, 0.21948500E+04, -.49090000E+03, 0.24399600E+04, 0.98712500E+04, 0.75119400E+04, 0.25653800E+05, -.11987200E+05, -.13418400E+05, -.12821200E+05, -.24311300E+05, -.25321800E+05, 0.74451800E+04, 0.19014300E+04, -.76252200E+04, -.19825000E+05, -.12129700E+05, -.68242200E+04, 0.34923400E+04, 0.18937500E+05, 0.34149900E+04, 0.66768900E+04, 0.58883800E+04, 0.47109400E+03, -.38014200E+04, -.51986500E+04, 0.41338200E+04, -.44760800E+04, -.49575600E+04, 0.24880600E+04, 0.22957300E+04, 0.24780900E+04, 0.68617700E+04, 0.60071800E+04, -.84900700E+03, -.39461100E+03, -.52131500E+03, 0.51297700E+04, 0.13855300E+04, 0.26939500E+05, -.13531000E+05, 0.26929700E+04, -.13461500E+05, -.32426600E+05, -.30636300E+05, 0.12724700E+05, 0.25413400E+04, -.25281700E+04, -.25475900E+05, -.11114600E+05, 0.58929500E+05, -.29597100E+05, -.34137300E+05, -.29450800E+05, -.24187200E+05, -.19097600E+05, -.73907400E+04, 0.58580400E+04, -.14046300E+05, -.16384300E+05, -.23472600E+05, 0.85334400E+04, -.43006800E+04, -.33282400E+03, -.42678100E+04, 0.39612800E+03, 0.31182800E+04, -.25867900E+04, 0.64921600E+03, -.49807300E+04, 0.22274800E+04, -.63612200E+04, -.12372300E+05, 0.59036900E+04, 0.94670700E+04, 0.61879300E+04, 0.29756100E+05, 0.36409700E+05, -.11779500E+05, -.62989400E+04, -.82997100E+04, 0.30993200E+05, -.78005300E+04, 0.44699100E+05, -.22103300E+05, -.11108900E+05, -.22344900E+05, -.13122000E+05, -.39226300E+04, -.75007000E+04, 0.83805500E+03, -.93747100E+04, -.44163300E+04, -.23123700E+05, -.25952100E+05, 0.13488000E+05, -.17058100E+04, 0.12968600E+05, 0.76277800E+02, -.15676600E+04, 0.14001100E+04, -.88072500E+04, 0.76827100E+04, -.23742200E+04, 0.91508500E+04, -.78951000E+04, 0.41588100E+04, 0.12513100E+05, 0.39613200E+04, 0.21855100E+05, 0.18240700E+05, 0.13293900E+04, -.50319100E+03, -.40618000E+04, 0.21986700E+05, 0.73889500E+04, -.87078700E+04, 0.35634700E+04, 0.14725700E+05, 0.43480500E+04, -.57849900E+04, -.10381500E+05, 0.59757300E+04, 0.59242400E+04, 0.84525500E+04, -.97200900E+04, 0.84489700E+04, -.13952100E+05, 0.69118500E+04, 0.96779300E+04, 0.69747800E+04, 0.88178900E+04, 0.72155700E+04, 0.13993500E+03, -.15070800E+04, 0.10843600E+04, 0.70092000E+04, 0.46961300E+04, -.26518700E+05, 0.13301300E+05, -.58986900E+03, 0.13263300E+05, 0.98696400E+04, 0.14558000E+05, -.30137200E+04, -.12160900E+05, -.51685600E+04, 0.14466700E+05, 0.27039700E+04, 0.14693600E+05, -.71761700E+04, -.14634000E+05, -.73378900E+04, -.32023300E+05, -.32595400E+05, 0.13357400E+05, 0.23683200E+04, -.25584800E+04, -.25014900E+05, -.10528800E+05, -.12729500E+05, 0.63971200E+04, 0.17438300E+05, 0.63747000E+04, 0.15943800E+05, 0.24384800E+05, -.11507700E+05, -.15899400E+05, -.14661800E+05, 0.24711300E+05, -.79397400E+04, 0.33501700E+05, -.16176700E+05, -.36423200E+05, -.16752800E+05, -.20438100E+05, -.12859000E+05, 0.38712700E+04, -.32205600E+04, -.66417500E+04, -.13960500E+05, -.17427200E+05, -.57765900E+04, 0.29052400E+04, 0.26748700E+04, 0.28876700E+04, 0.74371900E+04, 0.64355400E+04, -.95231500E+03, -.82532100E+03, -.70363100E+03, 0.57418000E+04, 0.15435300E+04, 0.90446800E+03, 0.42166100E+03, 0.10637300E+04, -.44628600E+03, -.32114300E+04, -.40989600E+04, 0.27560800E+04, 0.28575400E+04, 0.43362200E+04, -.31339200E+04, -.10873400E+04, 0.46432800E+05, -.23454300E+05, -.33430900E+05, -.23219100E+05, -.41015500E+05, -.34746700E+05, -.23195800E+04, 0.60806800E+04, -.95391200E+03, -.28679000E+05, -.39932800E+04, -.60213200E+05, 0.30433500E+05, 0.36838700E+05, 0.30109500E+05, 0.34219700E+05, 0.22668200E+05, 0.10705500E+05, -.94348900E+04, 0.73367600E+04, 0.17147500E+05, 0.97986700E+04, 0.45539200E+04, 0.10428600E+05, 0.90598600E+04, -.44789000E+04, 0.12237900E+05, -.91126100E+04, -.75330900E+04, 0.12103800E+05, -.48491100E+01, -.14523600E+04, -.97368900E+04, 0.90368500E+04, -.71782800E+04, -.60921900E+04, -.16031900E+05, 0.51313800E+04, -.68937100E+04, 0.58339200E+04, 0.79735700E+04, 0.37140500E+04, -.80573000E+04, 0.12903300E+04, 0.14137900E+03, 0.85505400E+04, -.11256800E+05, -.13838400E+05 },
        { 0.13086000E+00, 0.27552500E+00, 0.24006100E+01, 0.11794300E+00, -.11495700E+01, -.17128600E-01, -.48228600E+00, -.24366100E+00, -.64980600E-02, 0.67649300E-01, 0.32451200E+00, -.10825900E+00, -.12818400E+00, -.36967500E+00, 0.10600200E+01, 0.35462300E+00, 0.96816100E+00, -.13066400E+00, -.57015900E-01, 0.39817000E+00, -.14533700E+00, 0.21420100E+01, 0.13108300E+00, -.46224300E+00, 0.11713600E+00, 0.12715600E-01, -.30322300E+00, -.43179500E+00, 0.32751800E+00, 0.35683600E+00, -.32262300E+00, 0.96186500E-01, -.28121600E+04, -.72624200E+04, 0.36885100E+04, -.11949000E+04, 0.36301900E+04, 0.81463000E+03, -.30240700E+04, 0.69088200E+04, 0.64734200E+04, 0.50464800E+04, -.23628800E+04, 0.32141700E+04, 0.82071000E+03, -.42925400E+03, 0.72182800E+03, -.41076300E+03, 0.19511400E+03, -.51207300E+03, -.77774300E+03, 0.83923200E+03, -.38336000E+03, -.58938600E+03, -.17998400E+04, 0.92895500E+04, -.46603700E+04, -.76524800E+04, -.46458500E+04, -.18453400E+04, -.17814100E+04, 0.13516000E+04, 0.18319700E+04, -.20993200E+04, -.10675000E+04, -.21503800E+04, -.28488700E+03, 0.15076700E+03, -.19600700E+04, 0.14189800E+03, 0.54309500E+03, -.60667200E+03, 0.62910000E+03, 0.22927100E+03, 0.81616800E+03, -.34580700E+03, 0.65460800E+02, 0.16489600E+04, -.81228000E+03, -.10222400E+04, -.82434900E+03, 0.51634500E+03, 0.10754900E+04, -.13591400E+04, -.62787300E+03, -.91115600E+03, 0.94284500E+03, -.80310000E+03, -.60117000E+04, 0.29698400E+04, 0.35993500E+04, 0.30043100E+04, -.91105900E+03, -.79575700E+04, 0.10399700E+05, 0.87946200E+04, 0.52480300E+04, -.69738500E+04, 0.91829100E+03, -.30554600E+04, 0.15662700E+04, -.10862700E+04, 0.15250900E+04, -.16130000E+04, 0.17469600E+04, -.81532100E+03, -.27656500E+04, -.55061400E+03, 0.16708200E+04, 0.40750400E+04, -.13255300E+04, 0.63463600E+03, 0.15783800E+04, 0.66296900E+03, -.63417700E+03, -.19732100E+04, 0.15589700E+04, 0.25296700E+04, 0.96017100E+03, -.19409500E+04, -.67990700E+01, 0.11466500E+05, -.56688600E+04, -.81784500E+04, -.57335900E+04, -.21909000E+03, 0.12194000E+04, -.24373500E+04, -.98119000E+03, -.27028200E+04, 0.12150700E+04, -.51371300E+04, 0.22293500E+03, -.10199200E+03, 0.34744500E+04, -.11232200E+03, 0.90335800E+03, -.24457100E+03, 0.35814400E+04, 0.50427600E+04, 0.19040400E+04, -.41396700E+03, -.56163300E+03, -.34146200E+04, 0.17585200E+04, -.89751900E+03, 0.17087000E+04, 0.73789100E+03, -.82025500E+03, 0.26235300E+04, 0.41698300E+04, 0.21829800E+04, -.61834900E+03, 0.19371200E+04, -.90473300E+03, 0.45527200E+03, -.31343300E+04, 0.44976400E+03, 0.65132200E+04, 0.29451700E+04, -.50829300E+04, -.42659500E+04, -.22595600E+04, 0.24556200E+04, 0.29134100E+03, -.63697200E+04, 0.31361600E+04, 0.73473800E+04, 0.31859600E+04, -.14239400E+04, -.98958900E+03, -.82798600E+03, -.53063100E+04, -.11343700E+03, -.82508200E+03, 0.35689400E+04, 0.13790700E+04, -.69916500E+03, 0.40549300E+02, -.68929000E+03, 0.23155900E+03, 0.74225300E+03, -.16992700E+04, -.60493900E+03, -.97379100E+03, 0.59713100E+03, -.10163100E+04, 0.64724700E+03, -.33371000E+03, -.42658300E+03, -.32436700E+03, 0.29985600E+04, 0.34595400E+03, -.23820000E+04, -.82299400E+02, -.18772200E+04, 0.35338900E+03, -.13273400E+04, 0.70954400E+04, -.35600000E+04, -.59931900E+04, -.35493800E+04, -.12588800E+04, -.32483300E+04, 0.37641400E+04, 0.27807300E+04, -.74585000E+03, -.24447200E+04, -.19472800E+04, -.27853900E+04, 0.13448700E+04, -.89581100E+03, 0.13908200E+04, 0.46212500E+04, 0.33527200E+04, -.41340000E+04, -.83453700E+03, -.11358200E+04, 0.27803000E+04, -.23258500E+03, -.87074900E+04, 0.43770100E+04, -.15671800E+04, 0.43541500E+04, 0.16546400E+04, -.69416400E+04, 0.10577100E+05, 0.83604100E+04, 0.70764500E+04, -.64297300E+04, 0.22735500E+04, 0.15460300E+04, -.76052200E+03, -.10452000E+04, -.77289700E+03, 0.55219600E+03, 0.96295600E+03, -.13807500E+04, -.60842200E+03, -.87409700E+03, 0.82706600E+03, -.81823700E+03, -.64379900E+03, 0.31131000E+03, 0.14595700E+04, 0.32081400E+03, -.26497700E+03, -.60306300E+03, 0.87375100E+03, 0.12839700E+03, 0.12387700E+03, -.59403600E+03, 0.37228800E+03, -.11137900E+05, 0.54838000E+04, 0.48506200E+04, 0.55694500E+04, -.20726800E+04, 0.14173700E+04, -.57964900E+03, -.69589500E+03, 0.29864500E+04, 0.11935600E+04, 0.62284100E+04, 0.10235900E+05, -.50584600E+04, -.61968200E+03, -.51184800E+04, 0.94263900E+03, -.36970700E+04, 0.20761300E+04, 0.17419300E+04, -.21161600E+04, -.30148700E+04, -.65927900E+04, -.15406900E+04, 0.14322500E+04, 0.66738300E+03, 0.20936500E+04, 0.78557700E+03, -.13028800E+04, 0.63111200E+03, 0.12413800E+04, -.17608900E+03, -.14278500E+02, -.12188900E+04, 0.56212400E+03, -.89654100E+03, -.17913000E+04, -.15523500E+04, -.17260800E+04, 0.65557700E+03, 0.13459500E+04, 0.18780300E+04, -.68371300E+03, -.19635400E+04, -.63196500E+03, -.61203100E+03, 0.59766000E+03, -.97688200E+03, -.11577100E+04 },
        { 0.19340500E+00, 0.39956000E+00, 0.20879700E+01, 0.10653000E+00, -.78480200E+00, 0.22944000E-01, 0.29639200E+00, -.11628300E+01, -.32904600E+00, -.23183000E+00, 0.37880700E-01, 0.69937600E+00, 0.28212000E+00, 0.33014900E+00, -.60618900E+00, -.19020100E+00, -.67272800E-01, 0.11767600E+00, 0.11287700E+01, -.41723400E+00, 0.29213800E+00, 0.18587400E+01, 0.13464100E+00, 0.97869700E-01, 0.21257000E+00, -.11819000E+00, -.20476000E-01, -.81600800E-01, 0.28688700E+00, -.14037200E-01, -.58292200E+00, -.32737000E+00, -.19959500E+00, -.11229400E+05, 0.59584100E+04, 0.12807100E+04, 0.56159200E+04, 0.10144000E+04, 0.68104100E+03, 0.57539800E+04, 0.48328400E+04, 0.23197000E+04, -.74651000E+02, 0.61505200E+04, -.78167600E+02, -.31249300E+02, 0.20962200E+04, 0.39566600E+02, 0.12111000E+04, 0.11467500E+04, -.16061700E+04, -.83355800E+03, -.94541700E+03, 0.10705800E+04, -.30198700E+04, 0.69262600E+02, 0.10922000E+03, -.86535400E+03, -.33362200E+02, -.26755300E+04, -.11883900E+04, 0.23591000E+04, -.19240800E+04, -.44664900E+04, -.80744500E+03, 0.44011400E+04, -.77161500E+04, 0.38931100E+04, 0.79262900E+04, 0.38587200E+04, 0.22641900E+04, 0.29346200E+04, 0.47746500E+02, -.44076000E+04, -.55152800E+04, 0.32000700E+04, 0.42211800E+04, 0.17052200E+04, -.82117900E+03, -.11042700E+04, -.85276300E+03, 0.36719800E+03, 0.87864700E+03, -.97461600E+03, -.44413500E+03, -.54216800E+03, 0.83680400E+03, -.80441800E+03, -.11501600E+05, 0.57015600E+04, 0.86447100E+04, 0.57526100E+04, -.18515900E+04, -.39560500E+04, 0.82679500E+04, 0.17294100E+03, -.25411500E+04, -.40087700E+04, 0.38649100E+04, 0.51223700E+03, -.14273500E+03, -.89217800E+03, -.25299700E+03, -.21339300E+04, -.27197700E+04, 0.11347200E+04, -.23449100E+02, -.18615200E+04, -.23325800E+04, 0.19151600E+04, 0.14148700E+04, -.79053700E+03, 0.16176500E+04, -.70767500E+03, -.13378300E+03, -.37595500E+03, -.18216500E+03, 0.15145000E+04, -.56202700E+03, -.65083000E+03, -.35718500E+04, 0.12931900E+05, -.63209700E+04, -.55154000E+04, -.64655600E+04, -.31582300E+02, 0.15791500E+04, -.26765000E+04, 0.40359400E+03, -.38440600E+04, 0.32378000E+04, -.36587000E+04, -.27281000E+04, 0.14725500E+04, 0.39377700E+04, 0.13650600E+04, 0.53071700E+03, 0.41057900E+03, 0.25905700E+04, 0.38935700E+04, 0.17965600E+04, -.19856500E+03, 0.90737800E+03, -.60529700E+04, 0.33173000E+04, 0.11892200E+04, 0.30248500E+04, 0.12004500E+04, 0.16024000E+04, 0.15801800E+04, 0.21829100E+04, 0.33043000E+02, 0.72189900E+03, 0.27055900E+04, 0.76318200E+03, -.36248700E+03, -.99385000E+04, -.37851200E+03, 0.55082700E+04, 0.62436200E+04, -.32795100E+04, -.58553200E+04, -.23196900E+04, 0.47196100E+04, 0.67254600E+04, -.50544900E+04, 0.21928300E+04, 0.39716100E+04, 0.25259400E+04, 0.42364600E+03, -.22661400E+04, -.76815100E+03, -.50140600E+04, -.74225400E+03, -.14061400E+04, 0.29181500E+04, 0.12105700E+04, -.65913400E+03, 0.39484000E+03, -.60557400E+03, 0.20168900E+03, 0.81233800E+03, -.13970300E+04, -.57484300E+03, 0.30584500E+03, 0.69802200E+03, -.11889100E+04, -.37489500E+05, 0.18691300E+05, 0.18320800E+05, 0.18745600E+05, 0.46151400E+04, 0.69691800E+04, 0.29808300E+04, -.77898300E+04, 0.69784200E+03, 0.63741400E+04, 0.18925900E+05, -.53714000E+04, 0.27229900E+04, 0.16869000E+03, 0.26876600E+04, -.18162800E+04, -.26558500E+03, 0.41684800E+04, -.21479500E+03, -.47664800E+04, 0.48841100E+01, 0.84515500E+04, -.47524700E+05, 0.23575900E+05, 0.19243300E+05, 0.23764600E+05, 0.62437300E+04, 0.71233700E+04, 0.35380400E+04, -.10569400E+05, 0.26728500E+04, 0.66340200E+04, 0.22639000E+05, -.43132600E+04, 0.24114600E+04, -.73931000E+03, 0.21559700E+04, -.68637400E+03, -.23260200E+04, 0.92194500E+04, 0.59298200E+04, 0.12203100E+04, -.27365800E+04, 0.96864500E+03, 0.16902900E+04, -.81223900E+03, -.12053400E+04, -.84528600E+03, 0.41711200E+03, 0.78444000E+03, -.10022700E+04, -.55213600E+03, -.49205200E+03, 0.75269500E+03, -.80514000E+03, 0.16372900E+04, -.63940700E+03, 0.17799000E+03, -.81736200E+03, 0.32821500E+03, 0.43374000E+02, 0.45797300E+02, -.62847200E+03, -.10201000E+04, -.56306300E+02, -.12374400E+04, -.76079100E+04, 0.34981000E+04, 0.50254400E+04, 0.38033400E+04, -.58226000E+04, -.76742500E+04, 0.19249900E+04, 0.47820500E+03, 0.10497500E+05, -.85448900E+04, -.12346100E+04, -.35439500E+04, 0.20009400E+04, 0.44868400E+04, 0.17726300E+04, 0.52052800E+04, 0.62790000E+04, 0.29252800E+03, -.61437900E+04, -.92173100E+04, 0.73486800E+04, 0.34625000E+04, -.15594800E+04, 0.16408600E+04, 0.56339600E+03, 0.17625700E+04, 0.11446100E+04, -.20603700E+04, -.32849400E+03, 0.27361600E+04, -.31246300E+03, 0.49482700E+03, -.23667600E+04, 0.86457700E+03, 0.37819400E+03, -.16136000E+04, -.28835800E+04, -.16117500E+04, 0.17883900E+04, 0.98284000E+03, 0.20356600E+04, -.75317900E+03, -.23248300E+04, -.11761900E+04, -.68858100E+03, 0.61612200E+03, -.16762500E+04, -.36894400E+04 },
        { -.26663900E+00, 0.22031500E+01, -.58977400E+01, -.32482400E+00, 0.13882900E+01, 0.35908200E+00, 0.14744100E+01, 0.21015100E+00, -.19580500E+00, 0.94079500E-01, 0.33214600E+00, -.11295100E+01, 0.54902300E+00, 0.12027900E+00, 0.29469100E+00, 0.15707200E+00, -.11331600E+01, 0.26238100E+00, -.25419100E+00, 0.27153100E+00, -.90274600E+00, 0.51069200E+00, 0.30835400E+00, -.90135300E+00, -.23012300E+00, -.72531600E+00, -.22723500E+00, -.19415800E+00, 0.15016200E+00, 0.20807600E+00, -.61998500E+00, 0.75700600E-01, -.10354600E+00, -.66062900E+00, 0.70355700E+03, -.91715300E+03, 0.90075400E+00, -.38840100E+04, -.51069500E+04, 0.14001200E+05, 0.19157300E+05, 0.30519800E+04, -.64840700E+04, -.57197800E+04, -.33647800E+04, 0.16535400E+04, 0.57289000E+04, 0.16828300E+04, 0.16817000E+04, 0.38349500E+04, -.37245900E+04, -.35894600E+04, -.34621600E+03, 0.36256700E+04, -.71592100E+03, 0.84125800E+04, -.36127400E+04, -.38272900E+04, -.42051400E+04, -.25226500E+04, -.23457600E+04, 0.31858300E+04, 0.17340200E+04, -.48727200E+04, -.21253800E+04, -.56494800E+03, 0.15902500E+04, -.75949800E+03, 0.74551900E+04, -.79454900E+03, 0.15505200E+04, 0.20434200E+04, -.11439500E+04, -.26462300E+04, -.42267100E+04, 0.24971000E+04, 0.61404600E+03, -.36179800E+03, 0.14044100E+03, 0.44311800E+02, 0.18076200E+03, 0.10843400E+04, 0.27724700E+04, -.24182200E+04, -.20930900E+04, -.46749000E+03, 0.26728200E+04, 0.10294800E+04, -.12175500E+05, 0.62699300E+04, 0.10834400E+05, 0.60895300E+04, -.40624700E+04, -.11669200E+05, 0.16728400E+05, 0.12758900E+05, 0.41570200E+04, -.11665400E+05, -.33653500E+04, 0.28037600E+04, -.14627600E+04, -.33525400E+04, -.13990800E+04, -.17875000E+04, -.57058600E+04, 0.28628700E+04, 0.19287200E+04, -.23401800E+04, -.51457100E+04, -.15331600E+04, 0.34041200E+03, -.10928900E+03, 0.31251300E+04, -.17043100E+03, -.20613200E+03, -.86671800E+03, 0.65757500E+03, 0.20999800E+04, -.34388400E+02, -.11903000E+04, -.54465300E+04, 0.18715500E+05, -.95862000E+04, -.78883700E+04, -.93574000E+04, 0.46812100E+03, 0.37113700E+04, -.50628100E+04, -.43174600E+04, -.56237600E+04, 0.53111500E+04, -.14222100E+04, 0.37364900E+04, -.14689600E+04, -.46919100E+03, -.18672400E+04, -.37425500E+04, -.66894200E+04, 0.98348500E+04, 0.12236900E+05, 0.20462700E+04, -.70213700E+04, -.64887300E+04, 0.10207900E+03, 0.51391900E+03, 0.28974800E+04, -.52631700E+02, -.57957200E+03, -.34386600E+03, 0.45171000E+04, 0.85061500E+04, -.10084800E+03, -.14696300E+04, -.52410200E+04, -.12751100E+05, 0.63056000E+04, -.57092900E+04, 0.63783300E+04, 0.13129500E+05, 0.17078100E+05, -.12316200E+05, -.13324100E+05, -.57016400E+03, 0.14711300E+05, 0.18460700E+05, -.40528100E+04, 0.15484300E+04, -.13720200E+03, 0.20251700E+04, 0.23738200E+03, -.34738400E+04, -.32553600E+04, -.95254000E+04, -.13149200E+04, -.21379400E+04, 0.56617100E+04, -.22853300E+04, 0.10472600E+04, 0.27290600E+04, 0.11424000E+04, 0.12334000E+04, 0.37568900E+04, -.39563200E+04, -.37790300E+04, -.13061300E+02, 0.36531600E+04, 0.16262700E+04, -.33763700E+05, 0.16804100E+05, 0.11724400E+05, 0.16882700E+05, 0.10856100E+05, 0.12779100E+05, -.39287800E+04, -.86386800E+04, 0.49119400E+04, 0.11846000E+05, 0.19784100E+05, 0.11793300E+05, -.56072500E+04, -.77273500E+04, -.58947700E+04, -.23370300E+04, -.31081900E+04, 0.47598100E+04, 0.58884700E+04, -.49798000E+04, -.36052300E+04, -.98311200E+03, -.35827500E+05, 0.17823200E+05, 0.18789400E+05, 0.17915700E+05, 0.10391400E+05, 0.10813500E+05, -.44092100E+04, -.99082100E+04, 0.44249200E+04, 0.10584200E+05, 0.19223900E+05, 0.10994100E+04, 0.93222100E+02, 0.22118900E+04, -.55047100E+03, -.20234500E+04, -.54154800E+04, 0.14279900E+05, 0.20317000E+05, 0.42030700E+04, -.71849200E+04, -.63195400E+04, -.90199100E+03, 0.41165800E+03, 0.26025200E+03, 0.45087100E+03, 0.13651800E+04, 0.28696900E+04, -.25837100E+04, -.24424700E+04, -.35166600E+03, 0.27654300E+04, 0.13504000E+04, 0.73027600E+04, -.30732900E+04, -.16135800E+04, -.36500400E+04, -.77539300E+03, -.75307000E+03, -.40944100E+03, 0.66241600E+03, -.25502700E+04, -.96953200E+03, -.43692300E+04, -.39769600E+04, 0.18658600E+04, 0.45149400E+04, 0.19879300E+04, -.76796700E+04, -.13339900E+05, 0.43485600E+04, 0.61934900E+04, 0.53213300E+04, -.13247000E+05, -.68797400E+04, -.10533300E+05, 0.53922800E+04, 0.78456600E+04, 0.52672600E+04, 0.63530500E+04, 0.11873000E+05, -.16577900E+04, -.87355400E+04, -.17199300E+04, 0.12238700E+05, 0.83580700E+04, 0.35325300E+03, 0.38297200E+04, 0.20538800E+04, 0.33508000E+01, 0.31563800E+04, -.42885100E+04, 0.37911600E+04, 0.44651300E+04, -.69628000E+03, -.11100000E+04, -.59973000E+04, 0.38048000E+04, -.26769500E+04, -.35650400E+04, -.71965300E+04, -.71688300E+03, 0.20331400E+03, 0.12827600E+04, 0.12540800E+04, -.39672300E+04, -.12584300E+04, 0.91273100E+03, -.10383900E+04, 0.16549000E+04, -.34706000E+04, -.52032900E+04 },
        { -.29320000E+00, 0.49558100E+00, -.49031600E+00, -.44123200E-01, 0.82796100E+00, -.23388600E-01, 0.13459400E+01, 0.61138700E+00, -.13336900E+00, -.53876100E-01, 0.16425500E+00, -.13686800E+01, 0.52483800E+00, -.51231900E+00, -.19686600E+00, 0.11234700E+00, -.99692800E+00, 0.11898600E+00, -.33537100E+00, 0.34857000E+00, -.46760600E+00, -.12734900E+01, 0.91536100E-01, 0.26591100E+00, 0.12810200E+00, 0.23560700E-01, -.15566700E+00, 0.35379300E+00, 0.16592900E+00, 0.13462300E+00, 0.31172900E+00, 0.27999800E+00, -.20571900E+00, 0.10798300E+00, -.11421400E+00, 0.15743900E+05, 0.20049200E+01, 0.19452800E+03, 0.20817800E+04, 0.21644100E+04, -.12431300E+04, -.44540300E+04, 0.22768600E+04, -.22433100E+04, 0.39824400E+04, -.20070400E+04, -.11738900E+04, -.19903800E+04, -.20642100E+04, -.79905600E+03, -.10987600E+04, 0.16051000E+04, -.43487000E+01, -.87737600E+03, -.13370400E+04, -.55875000E+04, 0.26079300E+04, 0.26432000E+04, 0.27959600E+04, 0.42823900E+04, 0.35499400E+04, 0.10190800E+04, -.14346200E+04, -.32064400E+03, 0.29251100E+04, 0.90821900E+03, -.34044200E+04, 0.17211800E+04, -.63301500E+03, 0.17033300E+04, -.32302600E+03, -.20601600E+03, 0.44495500E+03, -.77555200E+03, -.26296900E+03, 0.29224800E+03, 0.21968700E+04, 0.78373700E+03, -.38284300E+03, -.40377200E+02, -.39213700E+03, -.48068000E+02, 0.27828300E+03, -.10494400E+04, -.12932800E+03, 0.38750200E+02, 0.34098100E+03, -.10368500E+02, -.62197200E+04, 0.30779200E+04, 0.13199300E+03, 0.31130900E+04, 0.25072200E+04, 0.13164200E+04, 0.37081900E+04, 0.41935200E+03, -.53407100E+03, 0.11216700E+04, 0.97549900E+03, -.10368700E+05, 0.52531500E+04, 0.27510100E+04, 0.51897600E+04, 0.40871500E+04, 0.24162700E+04, 0.95119400E+03, -.33941100E+04, 0.12347700E+04, 0.18854900E+04, 0.40849000E+04, -.21038600E+04, 0.10387800E+04, 0.79214000E+02, 0.10515100E+04, -.75036100E+03, -.75419000E+03, 0.93696200E+03, 0.87924700E+03, 0.10662300E+04, -.81769100E+03, 0.12964500E+04, 0.63780000E+03, -.23782600E+03, -.33897800E+04, -.31821300E+03, -.22172700E+04, -.40830400E+04, 0.13124500E+04, 0.48651900E+03, 0.95622400E+03, -.30724800E+04, 0.15488800E+04, -.97769900E+04, 0.48685600E+04, 0.13240600E+04, 0.48902900E+04, -.15781500E+04, -.29013100E+04, 0.57025800E+04, -.65849200E+03, 0.15966400E+04, -.20963200E+04, 0.35085400E+04, -.30546400E+04, 0.14377800E+04, 0.14462000E+05, 0.15244100E+04, 0.18681800E+04, 0.25973300E+04, 0.13038300E+03, -.11075500E+04, -.23183800E+04, 0.27591300E+04, -.15596800E+03, 0.11319100E+04, -.57819200E+03, 0.33905200E+04, -.56060400E+03, 0.19354800E+04, 0.22781600E+04, -.61065800E+04, -.18847900E+04, -.29736200E+03, 0.29877800E+04, 0.94328800E+03, -.32079300E+04, 0.17675600E+04, -.50263700E+04, 0.16016800E+04, -.23367300E+04, -.11925200E+04, 0.24329500E+03, -.14004800E+04, 0.79031400E+03, -.12257500E+04, 0.20086400E+04, 0.86147700E+03, -.43248200E+03, -.21731600E+03, -.43123700E+03, -.36103800E+03, 0.41608500E+03, -.15399200E+04, 0.22068300E+03, 0.41879600E+03, 0.41495600E+03, -.11045300E+03, -.11532000E+05, 0.57517100E+04, 0.89431600E+04, 0.57675500E+04, 0.31021400E+04, 0.50683800E+04, -.50193700E+04, -.36988300E+04, 0.85980700E+03, 0.52204200E+04, 0.61958100E+04, -.47243500E+04, 0.23358900E+04, 0.46041000E+04, 0.23656300E+04, 0.36888200E+04, 0.28279000E+04, 0.14837800E+04, -.96214600E+03, -.12444800E+04, 0.24818100E+04, -.67526100E+02, -.15251500E+05, 0.75715800E+04, 0.77552400E+04, 0.76296200E+04, 0.28323700E+04, 0.32754100E+04, -.44447900E+04, -.39712300E+04, 0.23566700E+04, 0.38066400E+04, 0.80217800E+04, 0.80206700E+04, -.40611200E+04, 0.50056100E+04, -.40111600E+04, 0.50400200E+03, 0.10249300E+04, 0.20781000E+03, 0.73651200E+03, -.39321500E+04, 0.89018600E+03, -.49909300E+04, 0.85132800E+03, -.41708200E+03, 0.45121300E+02, -.42590700E+03, -.13357900E+01, 0.29789300E+03, -.11480000E+04, -.93262200E+02, 0.74830600E+02, 0.35847200E+03, -.16236800E+02, -.20930300E+04, 0.85322700E+03, 0.19472500E+04, 0.10488300E+04, -.40986600E+03, 0.92961100E+01, 0.73370900E+03, -.74518300E+03, -.22294200E+03, 0.65978100E+02, 0.93276700E+03, -.60137400E+04, 0.29429300E+04, -.99999600E+03, 0.30058100E+04, 0.42042500E+04, 0.22886300E+04, 0.13795000E+04, 0.36646100E+03, 0.43470700E+04, 0.45889700E+03, 0.28227100E+03, 0.64582000E+04, -.31773900E+04, 0.11386900E+04, -.32279600E+04, -.52132200E+04, -.59855100E+03, -.20504900E+04, -.12487200E+04, -.52016100E+04, 0.10262500E+04, -.26465200E+02, -.79106700E+03, 0.13831000E+03, 0.48967100E+03, -.35475800E+02, 0.10892100E+04, -.11982300E+04, 0.15184400E+04, 0.12627500E+03, -.45426600E+02, 0.33179800E+03, -.83346100E+03, -.72222100E+03, 0.41457900E+03, -.15442200E+04, 0.30340500E+03, -.65497100E+03, -.78259200E+03, 0.18775600E+02, 0.10413300E+00, -.37042100E+03, 0.82076700E+03, -.41101600E+03, -.23352100E+03, 0.25049500E+03, 0.97716500E+02, -.28099700E+03 },
        { 0.51392600E+00, -.73098800E+00, 0.75674600E+01, 0.19915100E+00, -.45645800E+01, -.42701400E+00, -.56760500E+01, -.89240300E+00, -.21147500E+00, -.30945600E+00, 0.11212600E+01, 0.43493100E+01, -.10882600E+01, 0.38272400E+00, 0.29119900E+01, 0.13017000E+01, 0.47129700E+01, -.60012100E+00, 0.16167700E+00, 0.68729800E+00, -.20728600E+00, -.64560500E+00, -.12330500E+00, 0.55343100E+00, 0.82633700E+00, 0.96685700E+00, 0.11869400E+01, 0.32163500E+00, -.76162500E+00, -.85955600E+00, -.39352700E+00, -.10191200E-01, 0.32366800E+01, 0.29442100E-01, -.54885100E+00, -.26376100E+00, 0.36046700E+02, -.68117200E+03, -.26492000E+03, -.68087900E+04, -.58548300E+04, 0.45872000E+04, -.16816100E+04, -.35518500E+04, -.62303900E+03, 0.33248100E+03, -.17436900E+03, 0.32147400E+03, 0.78666500E+03, 0.18924700E+04, 0.14139200E+04, -.20306700E+04, -.19980900E+04, 0.20346500E+04, 0.34243000E+04, -.28874600E+04, 0.15535500E+04, 0.86850300E+04, 0.14474300E+04, -.99805500E+03, -.82041700E+03, -.18610000E+04, 0.20682800E+04, 0.66725400E+04, -.12930500E+04, -.51313500E+04, 0.44222900E+04, -.22110500E+04, 0.47570900E+04, -.22012800E+04, -.15482800E+04, 0.25221100E+03, 0.30846300E+02, 0.10040100E+04, 0.88102800E+03, -.18180700E+03, -.29544000E+04, -.60951600E+03, 0.28739900E+03, 0.63792900E+03, 0.30228700E+03, -.56627200E+03, -.80516400E+03, 0.16322000E+04, 0.17600200E+03, -.22293500E+03, -.70571000E+03, 0.37387200E+03, 0.41020000E+04, -.19682800E+04, 0.82414300E+03, -.20429400E+04, -.99277300E+03, 0.37472500E+04, -.10717200E+05, -.47459600E+04, 0.66957500E+04, 0.26937100E+04, -.41819800E+04, 0.34648700E+04, -.17759000E+04, -.14146800E+04, -.16779900E+04, -.32036300E+02, -.38152400E+04, 0.69513700E+03, 0.39842900E+04, 0.40169800E+04, -.35015100E+04, -.55108800E+04, -.99652800E+03, 0.53730100E+03, -.10072800E+04, 0.49281200E+03, 0.18678400E+04, 0.27615700E+04, -.15206800E+04, -.31364900E+04, -.99855500E+03, 0.28389600E+04, 0.23557400E+04, -.20425800E+05, 0.10109700E+05, 0.10213200E+05, 0.10219100E+05, 0.24855300E+04, 0.34586400E+04, 0.30768500E+04, -.17480000E+04, 0.31119800E+04, 0.20555700E+04, 0.11665200E+05, 0.36869500E+04, -.18309800E+04, -.49412400E+04, -.18368300E+04, -.15953900E+04, -.23072700E+04, -.46474600E+04, -.32986100E+04, 0.63422100E+03, -.23711800E+04, -.17599700E+04, -.39300600E+04, 0.19423300E+04, 0.22336100E+04, 0.19788300E+04, -.77627300E+02, -.10910400E+04, -.10169400E+04, -.44883700E+04, 0.31345200E+04, -.15106800E+04, -.20498900E+04, 0.10600900E+05, -.52965400E+04, 0.94578800E+04, -.52426300E+04, -.10407600E+05, -.69616300E+04, 0.11563100E+05, 0.11190000E+05, 0.80090100E+03, -.59099200E+04, -.16045000E+05, 0.54485300E+04, -.27636900E+04, -.67854600E+04, -.27371200E+04, 0.10308700E+04, 0.12950200E+04, 0.23168900E+04, 0.73930400E+04, 0.89114400E+03, 0.15082700E+04, -.14640200E+04, 0.17716500E+04, -.88101600E+03, -.12596900E+04, -.89006500E+03, -.31554900E+03, -.57709600E+03, 0.23428000E+04, 0.45653900E+03, -.13917800E+04, -.36572000E+03, 0.67779200E+02, 0.10658100E+05, -.53251600E+04, -.91306700E+04, -.53119700E+04, -.49246600E+04, -.42208200E+04, 0.83008000E+04, 0.88057700E+04, 0.74509900E+04, -.49475200E+04, -.89342500E+04, -.52571500E+04, 0.26709800E+04, 0.88565800E+04, 0.26478200E+04, -.19057900E+04, 0.79884000E+02, -.43902100E+04, 0.28273100E+04, 0.99858000E+04, -.86857700E+03, -.52837600E+04, 0.30292900E+05, -.15104400E+05, -.48694000E+04, -.15103700E+05, -.95526200E+04, -.10376900E+05, 0.10261400E+05, 0.12521100E+05, 0.27102800E+04, -.10066600E+05, -.17786800E+05, 0.53439900E+04, -.26092500E+04, 0.22442000E+04, -.27022700E+04, -.27368800E+04, 0.38498100E+04, -.12962500E+05, -.60252400E+04, 0.38549300E+04, 0.21663900E+04, -.27713300E+04, -.53129100E+03, 0.24820500E+03, 0.83056400E+03, 0.26343600E+03, -.57356500E+03, -.71527400E+03, 0.19035100E+04, 0.31898000E+03, -.36824100E+03, -.60065000E+03, 0.27555500E+03, -.14531400E+04, 0.84327600E+03, -.55395500E+03, 0.73022500E+03, -.59704600E+02, 0.38490300E+02, -.82035300E+03, 0.84937000E+01, 0.19448100E+04, 0.12239800E+02, 0.30755500E+03, 0.22911500E+05, -.11366500E+05, -.14868100E+05, -.11466800E+05, 0.25601900E+04, -.33738400E+04, -.45488200E+04, 0.11263100E+04, -.89612700E+04, -.15825000E+04, -.93843800E+04, -.20868400E+05, 0.10385900E+05, 0.54528800E+04, 0.10445700E+05, -.85641200E+03, 0.62714500E+04, 0.24855200E+04, -.30112300E+04, 0.91830400E+04, 0.40856700E+04, 0.10018900E+05, 0.53346900E+03, -.11347100E+04, -.18200600E+04, -.10259300E+04, 0.27483900E+03, 0.34159500E+03, -.17274600E+04, -.11753300E+04, 0.42483500E+03, 0.12371400E+04, 0.21209600E+03, -.17768200E+04, -.47464900E+02, 0.23406900E+04, 0.11558300E+04, 0.13222700E+04, 0.11495900E+03, 0.10723300E+03, -.29518000E+04, 0.18184400E+04, 0.26673400E+04, -.73661500E+03, 0.58593700E+03, -.17106600E+04, 0.29842500E+03, 0.91080400E+03 },
        { -.94665800E-01, -.29759200E+00, 0.68725200E+00, -.13055300E+00, 0.29313600E+00, 0.22743600E+00, 0.55663300E+00, -.66436200E+00, -.23461800E+00, 0.11802600E+00, 0.12669500E+00, 0.38094900E+00, -.31044200E-01, -.17095900E+00, -.49337500E+00, -.18220700E+00, -.81040800E+00, 0.32740300E-01, 0.27414600E+00, 0.29831700E-01, -.46932100E+00, 0.14921300E+01, -.64433700E-01, -.46368500E+00, 0.15254500E+00, -.27524500E-01, -.64242600E-01, -.52894000E+00, 0.30909300E-01, 0.10765600E+00, -.29035600E+00, -.49726800E-01, 0.30584400E+00, -.87738400E-01, 0.38696000E+00, 0.32971600E+00, -.17454600E-01, 0.26721600E+04, 0.12236500E+04, -.65136600E+04, -.73450100E+04, -.22254400E+04, 0.13658600E+04, 0.32782700E+03, 0.21657700E+03, -.69531700E+02, -.26719600E+04, -.10840800E+03, -.82994300E+03, -.37660600E+03, 0.16099300E+04, 0.62737200E+03, 0.30272100E+03, -.50718500E+03, 0.20256100E+04, -.42317700E+04, 0.23827300E+04, 0.33950300E+04, 0.21151800E+04, 0.20815400E+04, 0.39406600E+04, -.33921300E+04, -.20730000E+04, -.24175700E+03, 0.33315300E+04, 0.85744300E+03, -.42114100E+03, 0.18782800E+03, 0.10823400E+04, 0.21035700E+03, -.83417700E+02, 0.75252900E+03, -.50076700E+03, -.70361800E+02, -.74441100E+03, 0.63705700E+02, -.52469000E+03, 0.41386200E+03, -.23248100E+03, -.48348200E+02, -.20688200E+03, -.78547800E+03, -.11535800E+04, 0.14087300E+04, 0.95194100E+03, 0.18798800E+03, -.11718000E+04, -.38490200E+03, -.32373600E+02, 0.67670500E+02, -.17186100E+04, 0.15171400E+02, 0.30186600E+04, 0.71570000E+04, -.94421800E+04, -.84314800E+04, -.32692300E+04, 0.64384100E+04, 0.30703900E+04, 0.37784400E+03, -.32451700E+03, 0.37831000E+04, -.18983800E+03, 0.12730400E+04, -.62737900E+02, -.54558700E+03, 0.40878000E+03, 0.61147600E+03, 0.72216300E+03, -.18337600E+04, -.18663400E+04, 0.98106300E+03, -.53602900E+03, 0.93322500E+03, 0.54471600E+03, 0.89936100E+03, -.50195300E+03, -.17539900E+04, 0.41108100E+03, 0.99426700E+03, 0.25209800E+04, -.23768300E+04, 0.99859400E+03, 0.51578100E+04, 0.11882800E+04, 0.20485200E+04, 0.24087300E+04, -.40733100E+03, 0.19879800E+04, -.49544600E+03, 0.10265100E+04, -.14302400E+04, -.27385200E+04, 0.14370900E+04, -.47289500E+03, 0.13687200E+04, 0.21792700E+04, 0.22779900E+04, -.54213100E+04, -.57631400E+04, -.10899800E+04, 0.23375800E+04, 0.22642300E+04, 0.24920500E+04, -.11485100E+04, -.29217300E+04, -.12447400E+04, 0.57740100E+02, -.80001500E+03, -.20126900E+04, -.32520300E+04, -.14041400E+04, -.56744900E+03, -.22677300E+03, 0.88128000E+04, -.43963200E+04, 0.37761700E+04, -.44072500E+04, -.73876800E+04, -.65889400E+04, 0.77197300E+04, 0.66761700E+04, -.55608700E+03, -.66501600E+04, -.10738200E+05, 0.34427700E+04, -.18585600E+04, -.20008400E+04, -.17208000E+04, 0.29892600E+03, 0.52743100E+03, 0.14120600E+04, 0.44998600E+04, 0.85274600E+03, 0.45428500E+03, -.28190900E+04, 0.79497000E+03, -.39753400E+03, -.16030200E+04, -.39738700E+03, -.11985600E+04, -.14927600E+04, 0.22719200E+04, 0.13527200E+04, 0.31163100E+03, -.15232100E+04, 0.14731300E+02, 0.10405200E+05, -.51778100E+04, -.50421300E+04, -.52028400E+04, -.55229800E+04, -.51590000E+04, 0.48452000E+04, 0.42568700E+04, -.17271700E+04, -.57223600E+04, -.63145900E+04, -.57473100E+04, 0.29399100E+04, 0.40964600E+04, 0.28727500E+04, 0.21719600E+04, 0.34603000E+04, -.43923200E+04, -.37469000E+04, -.38660900E+03, 0.29749500E+04, 0.73176200E+03, 0.15856700E+05, -.78167400E+04, -.50676700E+04, -.79289500E+04, -.63359300E+04, -.52562300E+04, 0.50961900E+04, 0.50133100E+04, -.37823800E+04, -.58442400E+04, -.79575600E+04, -.43178900E+04, 0.22451900E+04, 0.27837900E+04, 0.21586900E+04, 0.20826400E+04, 0.29370400E+04, -.70505900E+04, -.93215900E+04, -.23522000E+04, 0.28535900E+04, 0.30954500E+04, 0.74216400E+03, -.39589600E+03, -.14925000E+03, -.37103800E+03, -.88869800E+03, -.11338400E+04, 0.15226400E+04, 0.11567100E+04, 0.11017900E+03, -.11616400E+04, -.56690800E+03, -.97735300E+03, 0.74571800E+03, -.94708200E+03, 0.48787200E+03, 0.64070500E+03, 0.15657800E+03, -.71386600E+03, -.60677700E+03, 0.34988800E+03, 0.25219800E+03, 0.58932300E+03, 0.32124400E+04, -.14737200E+04, -.19268100E+04, -.16060500E+04, 0.80168000E+03, 0.13312800E+04, -.58330300E+03, -.22936800E+04, -.10960600E+04, 0.27979200E+04, 0.29866800E+04, -.46047200E+04, 0.22121400E+04, -.34540000E+04, 0.23021600E+04, -.54080000E+03, -.65240000E+03, 0.32070300E+03, 0.15512000E+04, 0.13624600E+04, -.24975400E+04, -.67097100E+03, -.42213000E+03, -.15897700E+04, -.13481600E+04, 0.18055500E+03, -.18557000E+04, 0.11690900E+04, -.14044000E+04, -.13247900E+04, 0.29231900E+03, 0.47812300E+03, 0.18944200E+04, -.17204700E+04, 0.10440800E+04, 0.21334200E+04, 0.38245700E+04, 0.12778500E+03, 0.41470500E+03, -.65242400E+03, -.60602400E+03, 0.13496100E+04, 0.42792500E+03, -.53785900E+03, 0.39932000E+03, -.10988700E+04, 0.43845800E+03, 0.11073700E+04 },
        { -.24792000E+00, 0.68145700E+00, -.23895100E+01, -.17803100E+00, 0.13937900E+01, 0.29158300E+00, 0.19361200E+01, -.42231300E+00, -.20801000E+00, 0.31602900E+00, 0.44585800E+00, -.12211000E+01, 0.28721700E+00, -.23196100E+00, -.27930000E+00, 0.12263900E+00, -.94211200E+00, 0.26103600E+00, -.52643100E+00, 0.53861100E+00, -.56244000E+00, -.42594100E+01, 0.41221000E-01, 0.17344300E+00, -.34394100E+00, 0.15384900E+00, -.71714900E+00, 0.12594800E+01, -.25069500E+00, 0.42030600E+00, 0.95976000E+00, 0.26416700E+00, -.58432200E+00, 0.98294800E+00, -.20466500E+00, -.42107700E+00, 0.49020500E-01, 0.39537000E+00, 0.11710400E+05, -.91859700E+04, -.14189500E+05, -.53124100E+04, 0.11733100E+05, 0.87043400E+04, 0.15551900E+04, -.63696400E+03, -.13195900E+04, -.77731100E+03, -.15275200E+03, -.30740000E+04, 0.13445000E+04, 0.23561400E+04, 0.18026800E+04, -.30623500E+04, -.16272600E+04, 0.48594700E+04, -.20194200E+04, -.42626700E+04, -.24277300E+04, -.41104700E+04, 0.29420200E+03, -.15821400E+04, -.28268700E+03, -.85945500E+03, 0.30674500E+03, -.51028600E+04, 0.41824600E+04, -.20605700E+04, -.10617200E+05, -.20906600E+04, -.13387900E+04, -.31979400E+04, 0.74937800E+03, 0.41843800E+04, 0.51810300E+04, -.29197700E+04, -.20507500E+04, -.23949000E+04, 0.11097400E+04, 0.74379600E+03, 0.11973200E+04, 0.14640200E+04, -.13237100E+04, 0.74815300E+03, 0.11771900E+04, 0.14360200E+04, -.12046900E+04, 0.14214600E+03, 0.25451600E+05, -.12598700E+05, -.14153400E+05, -.12723000E+05, -.82164700E+04, 0.75415600E+04, -.88001600E+04, -.45864200E+04, -.92797600E+04, 0.78882200E+04, -.46532300E+04, -.28071000E+04, 0.10851500E+04, -.28550900E+03, 0.14059200E+04, -.20207300E+04, 0.41962300E+04, -.14831300E+04, -.27114700E+04, -.16571000E+03, 0.34662900E+04, 0.51274500E+04, 0.65713000E+04, -.30775800E+04, -.33155100E+04, -.32857700E+04, -.25800400E+04, 0.10129200E+04, -.16283900E+04, -.11539300E+04, -.21967600E+04, 0.88201700E+03, 0.18945900E+04, -.20425000E+05, 0.96284800E+04, 0.46902800E+04, 0.10212900E+05, 0.22212900E+04, -.10390700E+05, 0.82515300E+04, 0.46803200E+04, 0.10327300E+05, -.99429800E+04, 0.21413200E+04, 0.72452400E+04, -.33852400E+04, -.51647000E+03, -.36212000E+04, -.89201100E+03, 0.79165300E+04, -.56039700E+04, -.71834500E+04, -.65049600E+04, 0.75853900E+04, 0.15560400E+04, -.86291400E+04, 0.43221200E+04, 0.20368200E+04, 0.43108700E+04, 0.17429500E+04, 0.90145500E+04, -.51852700E+04, -.85917500E+04, 0.12749300E+04, 0.85577300E+04, 0.11432400E+05, -.85874300E+04, 0.42802000E+04, -.12180900E+04, 0.42958400E+04, 0.25834400E+04, -.47489700E+04, 0.26532300E+03, 0.58972400E+04, 0.57648900E+04, -.28435500E+04, 0.23961900E+04, -.30560900E+04, 0.16881000E+04, 0.56196700E+04, 0.15264900E+04, -.23170900E+04, -.20924200E+04, 0.41925400E+04, 0.54606900E+04, 0.31900800E+04, -.25566300E+04, -.10661200E+04, -.34311500E+04, 0.17183400E+04, 0.15780000E+04, 0.17153100E+04, 0.21796300E+04, -.16025200E+04, 0.10285600E+04, 0.16982900E+04, 0.15671400E+04, -.15498600E+04, -.17428900E+03, 0.24069000E+05, -.11956800E+05, -.10176600E+05, -.12033900E+05, -.10213700E+04, -.36877400E+04, -.74265000E+04, 0.25867300E+04, -.23027300E+04, -.17488300E+04, -.11900000E+05, 0.88943300E+04, -.42450200E+04, -.67164100E+04, -.44447800E+04, -.74367600E+04, 0.27577900E+04, -.24332200E+04, -.20178200E+04, -.16391200E+04, 0.29187500E+04, -.47883500E+04, 0.20685600E+05, -.10016500E+05, -.16192500E+05, -.10341300E+05, 0.11958000E+04, -.10726900E+04, -.85872200E+04, 0.25825400E+04, 0.28493900E+03, 0.27288500E+03, -.10119000E+05, 0.18452300E+05, -.90039400E+04, -.14934500E+05, -.92249900E+04, -.65581700E+04, 0.67786800E+04, -.87080300E+04, -.90115200E+04, -.10596800E+05, 0.80296600E+04, -.11805300E+04, -.24427500E+04, 0.11355200E+04, 0.60139700E+03, 0.12212600E+04, 0.13782000E+04, -.13651300E+04, 0.62493700E+03, 0.11360400E+04, 0.14997700E+04, -.12230800E+04, 0.22955000E+03, -.56094800E+04, 0.31372700E+04, 0.35539800E+04, 0.28068600E+04, -.63228900E+03, 0.26751000E+04, 0.60344600E+03, 0.15230700E+03, 0.13822200E+04, 0.21765100E+04, 0.42802100E+04, 0.24652900E+04, -.87580100E+03, -.59323300E+03, -.12330900E+04, -.16671800E+04, 0.96859200E+04, -.22503600E+04, -.58460400E+04, -.86108300E+04, 0.85991800E+04, 0.30483700E+04, 0.17018100E+05, -.86494000E+04, -.48223000E+04, -.85085700E+04, 0.87169200E+03, -.89293900E+04, -.11125800E+04, 0.10548500E+05, 0.32879500E+04, -.78931800E+04, -.75703700E+04, 0.23362100E+04, -.20063300E+04, 0.24353000E+04, -.16895500E+04, 0.31280700E+03, 0.31315500E+04, -.59238100E+04, -.31578400E+04, 0.12950500E+03, 0.13707100E+04, 0.36862500E+04, -.75951700E+03, 0.10741100E+04, -.55166600E+03, -.63077800E+03, 0.21850600E+04, -.31398400E+04, -.12305700E+04, -.21228200E+04, 0.34590000E+04, 0.19747100E+04, 0.84620800E+03, 0.80690200E+03, 0.19790900E+04, 0.38911100E+04, 0.45497300E+04 },
        { -.19981500E+00, 0.59401200E+00, 0.63085200E-01, -.19089800E+00, -.39467300E+00, -.21694200E+00, -.50264800E+00, 0.10327500E+01, 0.10553300E+00, -.40542100E+00, -.54751400E-01, -.11355600E+01, 0.52606600E+00, 0.10756800E+00, -.22929300E+00, -.55057100E-01, 0.12480900E+00, -.67200300E-01, 0.11773800E+00, 0.46745000E-01, -.21321200E+00, 0.58297300E+00, 0.12307400E+00, -.55256000E+00, 0.96968100E-01, -.75227900E-01, 0.11140200E+00, 0.44052500E+00, -.40423200E-01, -.24563500E+00, -.29228000E+00, 0.69343100E-01, -.70712600E+00, 0.36845400E+00, -.71568300E-01, 0.29970000E+00, -.54334100E-01, 0.69417000E+00, -.24803400E+00, 0.65031900E+04, 0.11610600E+05, 0.38727800E+04, -.11394800E+03, 0.10869400E+04, 0.96929600E+03, -.49871100E+03, 0.93333800E+03, -.48476000E+03, -.11740600E+04, -.10359700E+04, -.81609100E+03, -.26760900E+03, 0.22812200E+03, -.99982200E+03, -.29444300E+04, 0.72803800E+04, -.38249000E+04, -.59997300E+04, -.36411200E+04, -.38177000E+03, -.13192900E+03, 0.33430300E+03, 0.24406000E+04, 0.10121200E+04, -.24365800E+03, -.18778600E+03, 0.50644000E+04, -.25261900E+04, -.48217700E+04, -.25324500E+04, -.81627000E+03, -.15558200E+04, -.12104200E+03, 0.14633800E+04, 0.33003300E+04, -.10779300E+04, -.13893100E+04, 0.96825900E+02, -.46321900E+02, -.46534800E+03, -.48355800E+02, -.90470100E+02, 0.28333800E+03, -.98316600E+03, -.84707600E+03, -.18732700E+03, 0.41295200E+03, 0.72738200E+02, -.17097900E+04, 0.84674000E+03, 0.13904600E+04, 0.85365500E+03, 0.37693400E+03, -.29718100E+04, 0.76223500E+04, 0.11755900E+05, 0.65884200E+04, -.32159500E+04, -.66202100E+03, -.48572900E+04, 0.24837400E+04, 0.88470200E+03, 0.24276300E+04, 0.75997300E+03, 0.21816800E+04, -.22237500E+03, -.17006800E+04, 0.58309200E+03, 0.15557200E+04, 0.43428900E+04, 0.40228400E+03, -.20061600E+03, 0.16982700E+04, -.20110000E+03, -.81021600E+03, -.12549400E+04, 0.11711600E+04, 0.19759700E+04, 0.50614800E+03, -.14743300E+04, -.20997600E+04, 0.76372300E+04, -.37465000E+04, -.74048700E+04, -.38187600E+04, -.46153700E+04, -.57263300E+04, 0.30666100E+03, -.28246400E+04, 0.46188700E+03, -.40262200E+04, -.16283300E+04, 0.43256400E+03, -.22944200E+03, 0.25520700E+04, -.21690400E+03, 0.10623800E+04, 0.24536200E+03, 0.46963300E+04, 0.71887800E+04, 0.18342800E+04, -.86191500E+02, -.64140600E+03, 0.23604700E+04, -.12609300E+04, -.66268700E+03, -.11785200E+04, -.13126500E+03, 0.97734600E+03, 0.18593200E+04, 0.62834200E+04, 0.16631300E+04, 0.70842200E+03, -.32993600E+03, -.91282600E+04, 0.45214900E+04, -.79568100E+04, 0.45632500E+04, 0.47558400E+04, 0.33954700E+04, -.68479900E+04, -.68212200E+04, 0.12838800E+04, 0.33758600E+04, 0.12208000E+05, -.22748700E+04, 0.13161400E+04, 0.29585200E+04, 0.11381300E+04, 0.22813700E+03, -.29062100E+02, -.23189900E+04, -.64704600E+04, -.19381800E+04, -.92421200E+02, 0.14163000E+04, 0.10785900E+04, -.53874400E+03, 0.19062300E+02, -.53918200E+03, -.17014600E+03, 0.29129300E+03, -.17119000E+04, -.10934600E+04, -.79842600E+03, 0.36469500E+03, -.96771700E+03, 0.97052300E+04, -.48698700E+04, -.72240400E+04, -.48528500E+04, 0.20530000E+04, -.12427700E+04, -.40450500E+04, 0.10098700E+04, 0.22833700E+04, -.65512100E+03, -.18223700E+04, 0.11066400E+05, -.55540000E+04, -.92412700E+04, -.55342600E+04, 0.75795400E+03, 0.59494500E+03, 0.87796900E+03, 0.37807800E+04, 0.16222300E+04, -.12188400E+03, -.71361300E+03, 0.94812500E+04, -.47811100E+04, -.79159300E+04, -.47412200E+04, 0.21580000E+04, -.93309500E+03, -.49767900E+04, 0.18176500E+04, 0.37364800E+04, -.57160800E+03, -.24213700E+04, -.50993100E+04, 0.24846400E+04, -.40959100E+03, 0.25492100E+04, 0.14101500E+04, -.23803700E+04, 0.84854100E+04, 0.13178400E+05, 0.70331200E+04, -.27525900E+04, 0.18911600E+04, -.20259600E+03, 0.10225200E+03, -.49703100E+03, 0.10135100E+03, -.92949400E+02, 0.17352400E+03, -.10678200E+04, -.10290800E+04, -.76170300E+02, 0.30239200E+03, 0.25234400E+03, 0.12902900E+04, -.83966100E+03, 0.91574800E+03, -.64605700E+03, -.59446100E+01, 0.83030800E+03, 0.10233200E+02, 0.68907600E+03, -.92586700E+03, 0.53104600E+03, -.43699700E+03, -.94828100E+04, 0.47201400E+04, 0.90399000E+04, 0.47415900E+04, 0.28787800E+04, 0.34034500E+04, 0.14242000E+03, 0.20101000E+04, -.29218400E+04, 0.21903900E+04, 0.43771100E+03, 0.12093400E+05, -.60437500E+04, -.37771100E+04, -.60469100E+04, -.24750300E+04, -.29362200E+04, -.71977200E+02, 0.20830200E+04, 0.32020500E+04, -.16608800E+04, -.34779600E+04, 0.57052800E+02, 0.23652800E+03, 0.42294000E+02, 0.62748300E+03, -.82464800E+03, 0.42276900E+03, 0.14542100E+04, -.57821400E+03, -.34052900E+03, -.16576900E+03, -.12755100E+03, 0.71752500E+03, -.48583500E+03, -.97993300E+03, -.85864900E+03, -.55536500E+03, 0.54204300E+03, -.15897700E+02, -.98070600E+03, -.17499800E+04, 0.60317800E+03, 0.84193900E+03, -.41807200E+03, -.10162100E+03, 0.15662100E+04, 0.17524900E+04 },
        { 0.10897100E+00, 0.86890000E-01, 0.11015500E+01, 0.43407200E-01, -.27415800E+00, 0.21354500E-01, 0.63185600E+00, -.21358000E+00, 0.41816900E-01, 0.15786100E-01, -.65466800E-02, 0.75352800E+00, -.13604100E+00, 0.17722400E+00, 0.29268400E-01, -.19364700E+00, 0.11562300E+00, 0.27786700E-01, -.38600100E+00, 0.29026400E+00, -.33461100E-01, -.90211800E+00, -.13633700E+00, 0.35001700E+00, 0.40471500E+00, -.23391300E-01, -.19021000E+00, 0.27894500E+00, -.10214800E+00, -.30186600E+00, -.26999600E-01, -.95400300E-01, -.14737800E+00, 0.25544000E+00, -.10625500E+00, -.22163100E+00, 0.15591800E-02, -.54719900E+00, -.20605000E+00, -.12887000E+00, -.49601200E+04, -.24085800E+04, 0.17194800E+03, -.22129100E+04, 0.24674800E+02, 0.17398300E+02, -.37761000E+03, -.12381000E+02, 0.57812100E+03, 0.85699800E+03, -.11771300E+04, -.18737500E+02, 0.79951400E+03, 0.61631800E+03, 0.18454100E+04, 0.15805200E+04, -.66813100E+03, 0.89120800E+03, -.79036500E+03, -.10006100E+04, 0.36293600E+03, 0.15100500E+03, -.78864500E+03, -.12535000E+04, 0.28481400E+03, -.36875200E+04, 0.29758200E+04, -.14893400E+04, -.21300500E+03, -.14879600E+04, -.30169200E+03, -.11532400E+03, -.67548500E+03, 0.10492300E+04, 0.53454500E+03, -.23709500E+03, -.12788200E+04, -.14032100E+04, 0.68326700E+03, 0.71030600E+03, 0.70161400E+03, 0.73262400E+03, 0.41362000E+03, -.56332000E+03, -.14287700E+03, 0.56538900E+03, 0.37389500E+03, 0.88435700E+03, 0.85606200E+04, -.42721400E+04, -.37083300E+04, -.42805200E+04, -.26986300E+04, 0.74572900E+03, -.10828300E+04, -.21566500E+04, -.34212800E+04, 0.73098600E+03, -.48882500E+04, -.31449300E+04, 0.14854200E+04, 0.20142100E+04, 0.15722200E+04, -.28725900E+03, -.66343100E+03, 0.18251400E+04, 0.17971600E+03, 0.64192300E+03, -.33698000E+03, 0.54163900E+02, -.10932300E+03, 0.93237700E+02, -.32481800E+03, 0.54684900E+02, -.40794500E+02, 0.55259600E+03, -.41028900E+03, -.10283900E+04, -.11465500E+03, 0.56270400E+03, 0.13575300E+04, -.49044900E+04, 0.23148800E+04, 0.30194700E+04, 0.24522100E+04, 0.11789400E+04, -.85136800E+03, 0.10770700E+04, 0.12209100E+04, 0.18552200E+04, -.11515100E+04, 0.17457200E+04, 0.28001400E+04, -.13352200E+04, -.16570300E+04, -.14002000E+04, -.11791100E+04, -.11284100E+04, 0.11152200E+04, -.23029800E+04, -.28494900E+04, -.87538500E+03, -.26596400E+04, -.56472600E+04, 0.28510900E+04, 0.24763000E+04, 0.28238200E+04, 0.15682900E+04, 0.16780800E+04, -.52547900E+03, -.38239400E+04, 0.48217700E+03, 0.17235400E+04, 0.19197800E+04, -.52435500E+04, 0.26260500E+04, 0.60185900E+04, 0.26215100E+04, 0.14493100E+04, 0.30948300E+04, -.36721300E+04, 0.46426700E+03, 0.26298300E+04, 0.31236200E+04, 0.17086900E+04, -.14007100E+03, 0.80548400E+02, -.94152300E+02, 0.70180600E+02, -.11859500E+04, -.47647700E+03, 0.17853400E+04, 0.42459900E+04, 0.20334600E+04, -.58198700E+03, 0.40203200E+03, -.25113600E+04, 0.12522300E+04, 0.94089500E+03, 0.12557000E+04, 0.12912600E+04, 0.11295000E+04, -.10970800E+04, -.41227300E+03, 0.75313200E+03, 0.10322500E+04, 0.17087400E+04, 0.13855800E+04, -.67453400E+03, -.24478200E+04, -.69286900E+03, 0.15632000E+04, 0.33547300E+04, -.57821000E+04, -.56217200E+03, 0.15815700E+04, 0.33536500E+04, 0.22386300E+03, 0.21349700E+04, -.10200500E+04, 0.25292700E+03, -.10677100E+04, -.32459700E+04, -.68434700E+03, 0.12775700E+04, 0.19690000E+03, -.18621000E+03, -.71926700E+03, -.41588100E+04, 0.69924300E+04, -.34200800E+04, -.52193500E+03, -.34964000E+04, 0.18020400E+04, 0.35781700E+04, -.72092600E+04, 0.91801500E+02, -.33701900E+03, 0.36670400E+04, -.19643400E+04, 0.74149500E+04, -.36556600E+04, -.30970200E+04, -.37075100E+04, -.31324000E+04, -.47886500E+03, -.15590600E+04, -.26896300E+04, -.31799600E+04, -.34177100E+03, -.38056300E+04, -.15287600E+04, 0.74673300E+03, 0.81533600E+03, 0.76439100E+03, 0.81521200E+03, 0.58053800E+03, -.70230000E+03, -.18181000E+03, 0.58514300E+03, 0.53617100E+03, 0.10092100E+04, -.27980900E+04, 0.15015200E+04, 0.12016700E+04, 0.13988400E+04, -.40836800E+03, -.92925300E+01, 0.11636700E+04, 0.68451400E+03, 0.10718700E+04, -.21318000E+02, 0.11578400E+04, 0.51937300E+04, -.25247300E+04, -.30130900E+04, -.25968200E+04, -.17506700E+04, -.13119400E+04, 0.19592800E+04, 0.90563000E+02, -.34364800E+04, -.88040400E+03, -.14841000E+04, -.33619200E+04, 0.16476700E+04, -.29096100E+03, 0.16809000E+04, 0.22054000E+04, 0.27138600E+04, -.33412400E+04, 0.84640500E+02, 0.33060800E+04, 0.19605500E+04, 0.19534800E+04, 0.13018500E+04, 0.54523200E+03, 0.12575500E+04, -.13314500E+04, 0.10804700E+04, -.10444700E+04, -.75932900E+03, 0.38921100E+03, -.80156200E+02, -.12035900E+03, -.72201100E+03, 0.39888500E+03, -.78774500E+03, -.10128100E+04, -.26537800E+03, 0.97058700E+03, -.18180500E+04, -.15970900E+03, -.10835900E+04, 0.45173900E+03, 0.12092200E+04, 0.50698100E+03, 0.10183600E+03, 0.10323600E+04, -.30519900E+03, -.97165900E+02 },
        { -.50354600E-01, 0.36720300E-01, -.50018900E+00, -.17920000E-01, 0.26623100E+00, -.92191000E-01, -.19057500E+00, 0.24941500E+00, 0.66555500E-01, 0.82498700E-02, 0.21357300E-01, -.31765500E+00, 0.70651200E-02, -.30930500E-01, 0.15311600E+00, 0.53745700E-01, 0.22253800E+00, 0.54182000E-01, 0.41810100E+00, 0.17353500E-01, 0.10015200E+00, -.70595300E-01, 0.16042700E-01, -.80402700E-01, 0.15381900E+00, -.78703800E-01, -.27755300E+00, 0.47186400E-01, 0.40943300E-01, -.80752300E-02, -.13083700E+00, 0.20573900E-01, -.24164800E-01, 0.25777400E-01, -.20264300E-02, -.12588800E+00, 0.13395200E-02, -.23288400E+00, -.72812200E-01, 0.37478700E-02, 0.38529700E+00, -.12968400E+04, 0.30538400E+03, 0.75831600E+03, 0.45520300E+03, -.25434600E+03, -.63180800E+02, -.22759700E+03, -.15397100E+03, -.46535400E+03, 0.51007600E+03, 0.59712800E+03, 0.15624300E+03, -.35704500E+03, -.67964500E+03, -.27704100E+04, 0.12454500E+04, 0.76279100E+03, 0.13852500E+04, 0.11034000E+04, 0.43131800E+03, -.39218000E+03, -.13148300E+04, -.81595500E+03, 0.60035700E+03, 0.19954900E+04, -.20246800E+04, 0.10143800E+04, 0.72668400E+03, 0.10123500E+04, 0.30904800E+03, 0.43620200E+03, 0.12676500E+02, -.11104100E+04, -.12911000E+04, 0.53024200E+03, 0.12236300E+04, 0.39685600E+03, -.18272600E+03, -.22046200E+03, -.19843100E+03, -.12364300E+03, -.18230000E+03, 0.19184500E+03, 0.24841700E+03, 0.14796400E+03, -.16974700E+03, -.27148400E+03, -.22541900E+04, 0.11026000E+04, 0.96373900E+03, 0.11271500E+04, 0.14926900E+04, 0.10269200E+04, -.99559700E+03, -.19125100E+04, -.22258500E+04, 0.12709700E+04, 0.14921100E+04, -.48230100E+03, 0.31513500E+03, -.10853100E+03, 0.24119700E+03, -.15769800E+03, 0.41362400E+03, -.39877800E+03, -.59731400E+03, -.44884200E+03, 0.18681200E+03, 0.39522200E+03, -.16110600E+03, 0.46912900E+02, 0.15952700E+03, 0.80551700E+02, -.36131400E+02, -.21193000E+03, 0.18475500E+03, 0.33648000E+03, 0.14163600E+03, -.13689000E+03, -.21570000E+03, 0.26026600E+04, -.11820400E+04, -.21993300E+04, -.13013200E+04, -.30425800E+03, -.29094000E+03, -.32352600E+03, 0.45354900E+03, -.70099500E+03, -.10373200E+03, -.65128200E+03, -.31517400E+03, 0.11336100E+03, 0.50995100E+03, 0.15761600E+03, 0.77616400E+02, 0.45748100E+03, -.34619400E+03, -.19816300E+02, -.53252000E+03, 0.51212200E+03, 0.65270600E+03, 0.71718100E+03, -.41172000E+03, -.18726700E+03, -.35867100E+03, -.22124800E+03, -.68398700E+03, 0.58448900E+03, 0.84108500E+03, -.54320600E+03, -.38426800E+03, -.16145000E+03, 0.10768100E+04, -.54674300E+03, -.10043500E+04, -.53836500E+03, -.15590400E+03, -.72918400E+03, 0.48622700E+03, -.10811200E+04, -.20168800E+03, -.57564300E+03, -.81684400E+02, -.86929300E+03, 0.47615200E+03, 0.75985500E+03, 0.43461200E+03, 0.17130100E+03, 0.58302300E+03, -.38647600E+03, -.12230800E+04, -.60850000E+03, 0.37025900E+03, 0.20346300E+03, 0.33825800E+03, -.16942800E+03, -.48948300E+02, -.16913400E+03, -.20372400E+03, -.30082000E+03, 0.36759200E+03, 0.46630200E+03, 0.49522800E+03, -.29654300E+03, -.33777600E+03, -.93099900E+04, 0.46379700E+04, 0.48378400E+04, 0.46550000E+04, 0.80823800E+03, 0.15636400E+04, 0.67443900E+03, -.30496000E+04, 0.75005600E+02, 0.15129200E+04, 0.49413700E+04, -.46468400E+04, 0.22835100E+04, 0.19694800E+04, 0.23234700E+04, 0.17330400E+04, 0.97838400E+03, -.83884100E+03, -.21438500E+04, -.13648800E+04, 0.12259800E+04, 0.32846800E+04, -.10912700E+05, 0.53887500E+04, 0.48802700E+04, 0.54563600E+04, 0.56914000E+03, 0.13502400E+04, 0.11878700E+04, -.33310400E+04, 0.43860900E+03, 0.13293300E+04, 0.55887200E+04, -.16612100E+04, 0.77762500E+03, 0.31772600E+03, 0.83068900E+03, 0.89096000E+03, 0.10381000E+04, -.11083500E+04, -.19836000E+04, -.11980200E+04, 0.12741600E+04, 0.13047500E+04, 0.47744000E+03, -.22358300E+03, -.27085200E+03, -.23872300E+03, -.15409000E+03, -.21728300E+03, 0.20624800E+03, 0.24312800E+03, 0.15274800E+03, -.19616100E+03, -.30942900E+03, -.34261400E+03, 0.36182500E+02, 0.35983800E+03, 0.17134900E+03, 0.18197900E+03, 0.14944600E+02, -.22231800E+02, -.34559400E+03, -.32829400E+03, 0.77495400E+02, 0.58130200E+02, -.25251400E+04, 0.11900100E+04, 0.11371100E+04, 0.12625600E+04, -.39446700E+03, -.24586300E+03, 0.52295800E+03, 0.45594800E+03, 0.34180300E+04, -.77427200E+03, 0.21064000E+03, 0.28425600E+03, -.10669400E+03, 0.55082700E+03, -.14211900E+03, 0.52292500E+03, 0.37691000E+03, -.49823500E+02, -.14164400E+04, -.32933300E+04, 0.88593000E+03, 0.58651000E+03, -.37619000E+03, -.20158300E+03, 0.23509700E+02, 0.34751900E+03, -.11178300E+03, 0.61706300E+02, 0.21316900E+03, 0.26056700E+02, -.35804200E+02, -.13440900E+03, 0.29990600E+03, -.25410100E+03, 0.59592100E+03, 0.79924000E+01, -.15606700E+02, -.33281200E+03, 0.31922000E+03, -.12315000E+03, 0.16969400E+03, 0.46345600E+02, -.10724000E+03, -.18761500E+03, -.44009100E+02, 0.47559700E+02, 0.75034600E+02, -.25394800E+03 },
        { -.38874700E-01, 0.86542100E+00, -.18302100E+00, -.11239800E-01, 0.68299900E-01, -.32025800E-01, 0.95573200E-01, 0.14006500E+00, -.98741900E-02, 0.13985700E+00, 0.32161700E-02, -.29935500E+00, -.27825600E-02, -.88389700E-01, 0.13532000E+00, 0.10701800E+00, 0.23701800E+00, -.32661600E-01, 0.97389100E-02, 0.10281900E+00, 0.32747400E-03, -.26276800E+00, 0.82199300E-02, 0.66443900E-01, -.63382500E-02, 0.30843400E-01, 0.70622300E-01, -.10474000E+00, -.21907200E-01, 0.42703200E-01, -.22551200E-01, 0.30049300E-01, 0.17726000E-01, 0.59517900E-03, -.13064300E-01, -.42343300E-02, -.14549900E-02, 0.62634400E-02, -.42200400E-01, 0.73086400E-01, -.35075700E-01, -.11182600E+00, -.37425900E+03, 0.31179800E+03, 0.21023000E+03, -.99991800E+02, -.12297200E+02, -.10509000E+03, -.31684500E+02, -.21730200E+02, -.11352800E+03, -.16307600E+03, -.10149900E+03, 0.13053600E+03, -.29324700E+01, 0.74566000E+02, -.22324800E+02, -.52697100E+02, -.37147200E+02, 0.52460200E+02, 0.15392100E+03, -.77646200E+02, 0.33509700E+03, 0.12103800E+03, -.12350700E+03, -.84840400E+02, -.13390500E+04, 0.66804700E+03, 0.36307600E+03, 0.66956600E+03, 0.36133700E+02, 0.82953700E+01, 0.15393100E+03, -.26322100E+03, 0.19109300E+03, 0.10210300E+03, 0.47542400E+03, 0.64677100E+02, -.36712800E+02, -.48496400E+02, -.32348100E+02, 0.70576700E+01, -.19771700E+02, -.16732900E+02, -.71985200E+02, -.42410200E+02, 0.27885000E+02, -.10128000E+03, 0.26295000E+03, -.12184600E+03, -.35176300E+03, -.13127600E+03, -.18976000E+03, -.23884400E+02, -.18982800E+03, 0.34432900E+03, 0.25972100E+03, -.27415000E+03, 0.65653800E+03, -.31084100E+03, 0.14090800E+03, -.10858100E+03, 0.15560400E+03, -.78332800E+02, -.43002600E+02, 0.29190200E+03, 0.25676200E+03, 0.22978000E+03, -.32636100E+03, 0.15714800E+03, -.11135000E+03, 0.64752300E+02, 0.46147300E+01, 0.55663600E+02, -.47850900E+02, 0.11182400E+02, -.58571200E+02, -.92642200E+02, 0.27909500E+02, 0.20305300E+02, 0.42707100E+03, -.28110900E+04, 0.13796100E+04, 0.75636500E+03, 0.14055700E+04, 0.47649000E+03, 0.87817600E+02, 0.38754000E+03, -.46817200E+03, 0.53563800E+03, 0.21783900E+03, 0.51462000E+03, 0.25953300E+03, -.12063700E+03, -.40748300E+02, -.12965900E+03, 0.72788900E+02, -.39528300E+02, -.28195200E+02, 0.13378800E+03, -.24332600E+02, -.22998900E+03, 0.16815700E+03, -.12448000E+03, 0.59622500E+02, -.15009200E+02, 0.61992500E+02, -.68326100E+02, -.38603400E+02, 0.73297000E+02, -.11575300E+02, 0.42167500E+01, -.29587500E+03, 0.30889700E+03, 0.47154300E+03, -.23659800E+03, -.15462800E+03, -.23560000E+03, -.50515200E+03, -.71108700E+03, 0.57173700E+03, 0.76125800E+03, 0.26567200E+03, -.40478900E+03, -.86166800E+03, -.28685000E+03, 0.15298700E+03, 0.35302300E+03, 0.14330700E+03, -.81145200E+02, 0.96446000E+02, 0.15529900E+03, 0.19371200E+03, 0.12220600E+03, 0.26659100E+03, 0.10660400E+02, 0.44691300E+02, -.22472600E+02, 0.33549200E+01, -.22365000E+02, 0.52177600E+01, -.64991500E+02, 0.84704000E+01, -.87375800E+02, -.11892100E+02, 0.56092000E+02, -.10644900E+03, -.84231600E+03, 0.42269900E+03, 0.67903700E+03, 0.42120600E+03, 0.24651700E+03, -.18666000E+03, 0.55080200E+03, 0.33244100E+03, 0.33986200E+03, 0.35506500E+02, -.45149700E+03, -.33572400E+03, 0.17878100E+03, 0.64548800E+03, 0.16804300E+03, 0.30923700E+03, 0.44450500E+03, -.12105600E+03, 0.46928700E+03, 0.15486600E+03, 0.22599400E+03, -.15864000E+03, -.11515600E+04, 0.58835100E+03, 0.41870400E+03, 0.57589800E+03, 0.17719600E+03, -.20255800E+03, 0.73374800E+03, 0.30920500E+03, 0.47607000E+03, -.84676100E+01, -.29579100E+03, -.47238600E+03, 0.24313800E+03, 0.33982200E+03, 0.23631900E+03, 0.28485400E+03, 0.17846800E+03, -.22989500E+03, -.95344800E+02, 0.25083000E+03, 0.71018800E+02, 0.47463400E+03, 0.61007000E+02, -.34871300E+02, -.37889200E+02, -.30512300E+02, 0.60703900E+01, -.21309600E+02, -.31296200E+01, -.57322000E+02, -.40392200E+02, 0.27090100E+02, -.11525300E+03, -.13268000E+02, 0.15742300E+02, 0.54436300E+02, 0.67943100E+01, -.35367200E+02, -.95319000E+01, -.67052500E+01, 0.34781400E+02, 0.53181600E+02, -.27425400E+02, 0.16077200E+03, 0.29650800E+04, -.14631700E+04, -.13722800E+04, -.14825800E+04, -.42158100E+03, -.93450600E+02, -.32026800E+03, 0.34854300E+03, -.51758400E+03, -.38263300E+03, -.34942600E+03, -.17868400E+04, 0.88144200E+03, 0.11363200E+04, 0.89345900E+03, 0.32623700E+03, 0.15926400E+03, -.28166700E+02, -.56034300E+03, 0.61459100E+02, 0.50868100E+03, 0.14086900E+03, -.72056300E+02, 0.99921600E+02, -.80415100E+00, 0.91134200E+02, -.12233000E+03, -.32124500E+01, 0.53611500E+02, 0.10413100E+03, -.14086400E+02, 0.10291600E+03, 0.24021900E+02, -.15027600E+03, -.67445600E+02, 0.11127900E+03, -.65362500E+01, -.52985100E+01, -.20310000E+02, 0.52326600E+02, 0.10407600E+03, -.10968100E+03, -.10832500E+03, -.22829100E+02, -.25576700E+02, 0.33632300E+01, 0.23542300E+01, -.73598100E+02 },
        { -.12975500E+00, 0.53898400E+00, 0.14401200E+01, -.30447200E+00, -.10752400E+00, 0.20449300E+00, -.17168600E+00, -.12015600E+01, -.44246100E+00, 0.10161100E+00, 0.15729900E+00, 0.73403000E+00, -.12747800E+00, -.15844100E+00, -.30162000E+00, -.18864700E+00, -.16513800E+01, -.70508200E-01, 0.49240700E-01, -.38188000E+00, -.12697000E+01, 0.18012700E+01, -.29676700E+00, -.43978700E-01, 0.43976900E+00, 0.22995500E+00, 0.48327400E+00, -.38612900E+00, -.60694400E-01, -.10202600E+00, -.46201800E-01, -.94168700E-01, 0.70157900E+00, -.94319100E-01, 0.16487000E+00, 0.29916200E+00, 0.30011700E-02, 0.94008100E+00, 0.19005200E+00, 0.10048900E+00, -.69357500E+00, 0.86831700E+00, 0.25888200E+01, -.39425800E+04, -.83667100E+03, 0.42937200E+03, -.38003500E+03, 0.41827800E+03, 0.29707400E+03, 0.19740700E+04, -.96927100E+03, -.17610200E+04, -.13176200E+03, 0.13427500E+04, 0.21445800E+04, -.10842300E+04, 0.65370100E+03, 0.30691600E+04, 0.54201600E+03, -.52752400E+03, -.17060200E+03, 0.11354500E+04, 0.10642200E+04, 0.24119200E+03, 0.85818800E+02, -.21109600E+04, 0.85794900E+04, -.42850800E+04, 0.16180800E+04, -.42898100E+04, -.37071600E+03, 0.64412600E+03, -.17486100E+04, 0.12147300E+04, -.19886500E+04, 0.11507700E+02, -.33184800E+04, -.10260200E+04, 0.51018500E+03, 0.69045200E+03, 0.51302500E+03, 0.57253200E+02, 0.11845300E+03, -.16541300E+03, -.29363000E+03, 0.22597300E+03, 0.53895900E+02, 0.96514200E+03, 0.11872600E+04, -.58789900E+03, 0.10837600E+04, -.59385300E+03, -.20215100E+03, 0.35763600E+04, -.12407600E+04, -.20154200E+04, -.15886500E+04, 0.29923400E+04, -.44224100E+04, 0.15721600E+04, -.81491700E+03, 0.24171300E+04, -.78638000E+03, 0.68846900E+03, -.33549400E+04, 0.17275000E+04, 0.30163500E+04, 0.41058500E+03, -.16779100E+04, -.31165100E+04, -.22778300E+03, 0.11784300E+03, -.42644000E+02, 0.11392400E+03, 0.52779900E+03, 0.15345500E+04, -.58946000E+03, -.15805800E+04, -.39038600E+03, 0.13210200E+04, -.51821300E+02, 0.49082800E+04, -.25168500E+04, 0.36091300E+04, -.24541800E+04, -.17248800E+03, 0.20123900E+04, -.27557900E+04, -.64149000E+03, -.21505900E+04, 0.13723400E+04, 0.89206600E+03, -.19521800E+03, 0.11050000E+03, -.15978700E+04, 0.97452400E+02, -.79279000E+03, -.94184400E+03, 0.45023500E+03, -.10430900E+04, -.61142200E+03, -.78076900E+03, -.21447000E+04, -.10688900E+04, 0.60552600E+03, 0.71862200E+03, 0.53460700E+03, 0.64232500E+03, 0.13395700E+04, -.10194900E+04, -.17488100E+04, 0.39379600E+02, 0.14230600E+04, -.17631300E+04, -.25166100E+04, 0.12962500E+04, 0.50728900E+04, 0.12579700E+04, 0.78519700E+03, 0.37353900E+04, -.11401900E+04, 0.82348200E+03, 0.56663500E+03, 0.23887000E+04, 0.96766200E+03, 0.34891500E+04, -.18186200E+04, -.40091700E+04, -.17444100E+04, 0.62481400E+03, -.56441900E+03, 0.48095200E+03, 0.28063200E+04, 0.57734600E+03, -.81036900E+03, -.63513000E+03, -.12277600E+04, 0.61183300E+03, 0.74526500E+02, 0.61390400E+03, 0.36347900E+03, 0.11064200E+04, -.72411800E+03, -.11024800E+04, -.80524900E+02, 0.80352500E+03, 0.16089500E+04, -.74396400E+03, 0.38236900E+03, -.35845900E+04, 0.37188100E+03, 0.37738600E+03, 0.31823700E+04, -.22376800E+04, -.67090600E+02, 0.19545100E+04, 0.17247200E+04, 0.28163400E+04, 0.27489700E+04, -.13487800E+04, -.15171000E+04, -.13747500E+04, -.22500500E+04, -.12791600E+04, 0.16110700E+04, 0.28585800E+04, 0.87679000E+03, -.18372900E+04, -.34920100E+04, 0.87740500E+04, -.43637500E+04, 0.11507800E+04, -.43872700E+04, -.49924400E+03, 0.16465500E+04, -.35156000E+04, 0.78000000E+03, -.16162300E+04, 0.81110000E+03, -.13246100E+04, 0.39396200E+04, -.19305900E+04, 0.23035700E+03, -.19700200E+04, -.23781900E+04, 0.78669000E+03, -.36070500E+03, 0.14258400E+04, -.11523700E+04, -.23296000E+03, -.34620700E+04, -.10619100E+04, 0.52899100E+03, 0.75037400E+03, 0.53096500E+03, 0.13231300E+03, 0.29479000E+03, -.24519100E+03, -.34089000E+03, 0.19155200E+03, 0.21716900E+03, 0.10721500E+04, 0.10574300E+03, 0.68698500E+02, -.66916600E+03, -.53115700E+02, 0.29339800E+02, 0.45643400E+03, -.18876600E+03, 0.15334400E+03, -.92833700E+01, 0.31045700E+03, -.59823000E+03, -.24861300E+03, 0.13562900E+03, 0.99591200E+02, 0.12437000E+03, 0.16299400E+03, -.42237300E+04, 0.33054500E+04, 0.13402000E+04, -.13310400E+04, -.21418900E+04, -.30760100E+04, -.36822300E+04, 0.18541500E+04, -.36513600E+04, 0.18410500E+04, 0.60132800E+03, 0.55191200E+04, -.34654000E+04, -.15887900E+04, 0.23226500E+04, 0.29415000E+04, 0.48904800E+04, 0.97427300E+03, 0.19438100E+03, -.47913300E+02, -.11123100E+04, 0.61279400E+03, -.86890600E+03, 0.30339500E+03, 0.37342400E+03, 0.21562500E+02, 0.18577000E+03, -.12609700E+04, -.17262600E+03, -.98386600E+03, -.15830500E+03, -.21806300E+03, 0.72836900E+03, -.41343400E+03, -.34885300E+03, -.11907800E+04, -.39165500E+03, 0.11257100E+04, 0.37872500E+03, 0.13511300E+03, -.14850700E+03, -.12147700E+04, -.74249100E+03 },
        { -.11983900E+00, -.26330500E-01, -.13863800E+01, -.73258400E-01, 0.35283700E+00, -.49319700E-01, -.79438400E+00, 0.42709900E+00, 0.10032500E+00, -.51395500E-01, 0.90787000E-01, -.43679800E+00, 0.89910400E-02, -.17229800E+00, 0.36243900E+00, 0.20102100E+00, 0.20008600E+00, -.70477200E-01, -.16437100E+00, 0.83664300E-01, -.27665500E+00, 0.99673000E+00, 0.49391600E-01, -.36048800E+00, -.41675700E-01, -.17598200E-01, -.25667200E+00, 0.46586000E-01, 0.25039700E+00, 0.48217100E-01, 0.15392400E+00, 0.25886400E-01, 0.54103200E-03, 0.12816700E+00, -.31807200E-01, 0.12287500E+00, -.24606500E-01, 0.21061600E+00, 0.81895100E-01, 0.71150200E-01, 0.23961400E+00, -.37720800E+00, -.84077000E+00, -.87137300E-01, 0.19104800E+04, -.97264700E+03, -.10862600E+04, -.95533300E+03, -.68178800E+03, -.12249600E+04, 0.10329400E+04, 0.16164200E+04, -.46670300E+03, -.87666400E+03, -.82953400E+03, -.23280300E+04, 0.10814000E+04, 0.16253900E+04, 0.11633200E+04, 0.77125400E+03, -.78233300E+03, 0.14829300E+03, -.52634200E+03, 0.43266500E+03, -.70304400E+03, 0.96589800E+03, -.47084300E+04, 0.23503000E+04, -.14085800E+04, 0.23540200E+04, -.17498700E+03, -.49261900E+03, 0.94824200E+03, -.96413600E+03, 0.37727800E+03, -.25173800E+03, 0.20061100E+04, 0.56667000E+03, -.27403500E+03, -.23558000E+03, -.28329000E+03, -.43730700E+03, -.42463800E+03, 0.23916800E+03, 0.19107700E+03, -.10632100E+03, -.31510200E+03, -.36725800E+03, -.23508900E+04, 0.11758000E+04, 0.56373300E+03, 0.11744900E+04, 0.14705600E+04, -.71296700E+02, -.36739600E+03, -.50860100E+03, -.96794000E+02, 0.50300800E+02, 0.17616400E+04, -.36020400E+04, 0.18490200E+04, -.48704600E+03, 0.18002200E+04, 0.16118700E+04, 0.28354700E+04, -.11422700E+04, -.13870700E+04, 0.94810500E+03, 0.19196500E+04, 0.12075900E+04, -.26823700E+03, 0.11459000E+03, -.60551000E+03, 0.13415600E+03, 0.26574300E+03, -.10545200E+03, 0.64905000E+03, 0.13084100E+04, 0.37068500E+03, -.90824000E+02, -.86027100E+02, 0.30616700E+04, -.14462900E+04, -.55812100E+04, -.15309500E+04, -.12038600E+04, -.50477800E+03, -.71708600E+03, -.65806500E+03, -.14675400E+04, -.14318700E+03, -.84957000E+03, -.16184600E+04, 0.77020100E+03, 0.65260500E+03, 0.80875100E+03, 0.77656900E+02, -.12484400E+03, 0.81365200E+03, 0.84080100E+03, 0.10530800E+04, -.14284000E+03, 0.11485500E+04, 0.12083000E+04, -.62527400E+03, -.13519400E+04, -.60286500E+03, -.38824000E+03, -.56278500E+03, 0.46488100E+03, 0.10543500E+04, -.35146100E+02, -.46743600E+03, -.11419200E+04, 0.20575200E+04, -.10419500E+04, 0.16730700E+04, -.10294700E+04, -.23499900E+04, -.37308800E+04, 0.81224400E+03, -.19926000E+04, -.13811700E+04, -.27993800E+04, -.26473300E+04, 0.70141900E+03, -.35127300E+03, -.12901900E+03, -.35018300E+03, 0.11365300E+04, 0.13875900E+04, -.10309300E+04, -.13304500E+04, -.15499600E+04, 0.11937400E+04, -.35103200E+03, 0.13333300E+04, -.66313700E+03, -.55754000E+03, -.66657500E+03, -.58717000E+03, -.78580000E+03, 0.60721100E+03, 0.79975600E+03, -.10373900E+03, -.58838300E+03, -.74958900E+03, -.67467100E+04, 0.33617400E+04, 0.51266800E+04, 0.33731600E+04, 0.76460100E+02, -.90023100E+03, 0.16726400E+04, -.24717100E+04, -.49681500E+03, -.57159400E+03, 0.14900700E+04, -.44487500E+04, 0.21935900E+04, 0.33647700E+04, 0.22235700E+04, 0.19879200E+04, -.13013900E+03, -.10370400E+04, -.24432500E+04, 0.69987300E+02, 0.29867700E+02, 0.15933400E+04, -.94048100E+04, 0.46610300E+04, 0.39269600E+04, 0.47019200E+04, -.38324900E+03, -.64510700E+03, 0.24081100E+04, -.24491000E+04, 0.38504400E+03, -.46678400E+03, 0.26226000E+04, -.38967700E+04, 0.19100800E+04, 0.11174200E+04, 0.19483200E+04, 0.13471200E+04, 0.77006900E+03, -.17229700E+04, -.28764500E+04, 0.83456500E+03, 0.82356700E+03, 0.21825400E+04, 0.67127700E+03, -.32698900E+03, -.26680200E+03, -.33559800E+03, -.49001100E+03, -.50075800E+03, 0.30369700E+03, 0.23848600E+03, -.12665700E+03, -.38320700E+03, -.45775900E+03, 0.43141200E+03, -.29020700E+03, -.50236800E+03, -.21641900E+03, 0.32020500E+03, 0.14821400E+03, -.37827300E+03, -.47960300E+03, -.47285500E+03, 0.18836700E+03, -.23150500E+03, -.64905500E+04, 0.32146500E+04, 0.15068600E+04, 0.32454200E+04, 0.28954900E+04, 0.38141200E+04, -.27242400E+03, 0.11309800E+04, 0.50265900E+04, 0.23441100E+04, 0.30569800E+04, 0.42434800E+04, -.21180200E+04, 0.40556800E+03, -.21219100E+04, -.23649100E+04, -.42062900E+04, 0.15157600E+04, -.10986700E+04, -.45352300E+04, -.25836800E+04, -.22214900E+04, -.58289100E+03, -.57421900E+03, -.73824400E+03, 0.43668400E+03, -.42707200E+03, 0.65220100E+03, 0.45939800E+03, -.57173900E+03, 0.77314700E+02, 0.44609400E+02, 0.11827000E+04, -.12221000E+04, 0.86667800E+03, 0.40807200E+03, 0.19168600E+03, -.53578700E+03, 0.10570100E+04, -.11274100E+03, 0.69251100E+03, 0.18457400E+03, -.41795500E+03, -.43621800E+03, 0.31055100E+02, -.63397400E+03, 0.35412500E+03, 0.40822000E+03 },
        { 0.21693100E+00, 0.10297900E+01, 0.34849300E+01, 0.12177500E+00, -.21097100E+01, -.37777900E+00, -.19275200E+01, 0.11604100E+01, -.23358900E-01, -.44673600E+00, 0.59525100E+00, 0.87853200E+00, -.17449900E+00, -.38655800E+00, 0.26687800E+01, 0.74158400E+00, 0.18428200E+01, -.37601100E+00, -.82934800E+00, 0.10686800E+01, -.48553900E+00, 0.48083400E+01, 0.52692600E+00, -.11019900E+01, -.57912600E+00, 0.52377300E-01, -.73439100E+00, -.55758000E+00, -.61651200E-01, -.50521200E-01, -.11022200E+01, -.21598700E-02, 0.13909200E+01, 0.57796600E+00, -.86484400E+00, -.98383500E-01, 0.89503700E-02, 0.52233300E+00, 0.76217900E+00, -.72625000E-01, -.70138500E+00, -.15416900E+01, -.17930700E+01, 0.82691300E-01, 0.21060100E+01, -.13856300E+03, 0.47229900E+04, 0.15493300E+00, 0.72206800E+03, 0.14783800E+04, -.19224300E+04, -.22937000E+04, -.11148900E+04, 0.12481700E+04, -.44800300E+04, -.95744800E+04, 0.40727500E+04, 0.81072200E+04, 0.47881700E+04, 0.33310200E+04, 0.24872300E+04, 0.15981200E+03, -.47200000E+04, 0.40561100E+03, 0.20790600E+04, 0.64467100E+04, 0.48234900E+03, -.22356400E+03, 0.97667700E+04, -.24089500E+03, 0.10251400E+04, 0.19392700E+04, 0.63904700E+03, -.30272700E+03, -.41319500E+04, 0.26786800E+04, -.62186300E+03, 0.18922200E+04, -.86049100E+03, -.97168700E+03, -.94617200E+03, -.46752400E+03, 0.26448100E+03, -.65831300E+02, 0.27135100E+03, -.45649100E+03, 0.18545900E+03, -.89007900E+03, -.10632600E+05, 0.51289800E+04, 0.12354000E+05, 0.53176500E+04, 0.45127300E+04, 0.18602900E+04, 0.63913600E+02, -.50141900E+04, 0.81607900E+03, 0.15672300E+04, -.18872700E+04, -.51623600E+04, 0.29628300E+04, -.74363700E+03, 0.25823800E+04, -.88032500E+03, -.39671600E+04, 0.19697100E+04, -.23324000E+04, -.30706800E+03, -.38244700E+04, 0.63068500E+04, -.23366700E+04, 0.98344800E+03, 0.39309500E+04, 0.11682700E+04, 0.67614800E+03, -.11534000E+04, -.86797900E+03, -.23273200E+04, -.13273000E+03, -.10520900E+04, -.28972900E+04, -.81843500E+04, 0.47080900E+04, 0.51215500E+04, 0.40923400E+04, -.35173000E+04, -.54547500E+04, 0.88724600E+04, 0.64820400E+04, 0.44783700E+04, -.34737100E+04, 0.86200100E+04, -.17210500E+04, 0.64976500E+03, 0.10816500E+04, 0.86122900E+03, 0.98198500E+03, -.14347700E+04, -.30681200E+03, -.13020900E+04, 0.83489800E+03, -.82821900E+03, 0.29978300E+03, 0.13688800E+04, -.88166800E+03, 0.35628200E+04, -.68614700E+03, -.63928000E+02, -.25264300E+04, 0.79535800E+03, 0.30951100E+03, -.14614500E+04, -.24998300E+04, -.37094400E+04, 0.12438200E+05, -.62485000E+04, -.13605400E+05, -.62180200E+04, -.26942300E+04, 0.55898300E+04, -.18940200E+04, 0.77182700E+03, -.32071800E+04, 0.50795300E+04, -.90175000E+02, -.41754000E+04, 0.23300500E+04, -.14961400E+04, 0.20869300E+04, -.82626200E+03, 0.98943900E+03, 0.26048500E+03, -.70255900E+03, 0.32000600E+03, 0.11597500E+04, 0.48695300E+04, 0.29387400E+04, -.14753800E+04, 0.30272800E+03, -.14695000E+04, -.56349200E+03, 0.31534100E+03, -.43586600E+03, 0.19655100E+03, -.62489600E+03, 0.12799500E+03, -.23770400E+04, -.16314000E+05, 0.80713500E+04, 0.56069200E+04, 0.81572900E+04, 0.72589300E+02, 0.17694000E+04, 0.48451800E+04, 0.42360300E+03, 0.13669700E+04, 0.26422600E+04, 0.67572300E+04, -.18579100E+05, 0.90680700E+04, 0.12231400E+05, 0.92907200E+04, 0.40453900E+04, 0.47445200E+04, 0.17641800E+04, -.12984200E+04, 0.28227000E+04, 0.43484200E+04, 0.12127000E+05, -.17484300E+05, 0.83883600E+04, 0.95687900E+04, 0.87429200E+04, 0.56288900E+03, -.15182800E+04, 0.65702400E+04, -.35803800E+03, 0.75966300E+03, -.43704400E+02, 0.51984400E+04, 0.19183700E+03, -.37412700E+03, 0.56450200E+04, -.96046600E+02, 0.14834000E+04, 0.41987600E+04, -.62996400E+03, -.36934100E+03, -.14428600E+03, 0.41978600E+04, -.26483600E+04, 0.20341900E+04, -.93386400E+03, -.95284700E+03, -.10171500E+04, -.50680300E+03, 0.86981300E+02, -.14725600E+02, 0.16622700E+03, -.50532300E+03, 0.44509400E+02, -.10494800E+04, -.11418700E+04, -.10149700E+03, 0.20408000E+04, 0.57198600E+03, -.33060700E+03, -.48829700E+03, 0.73855800E+03, -.39374700E+03, 0.49163700E+03, -.35301900E+03, -.31252700E+03, 0.23690200E+04, -.15899300E+04, -.87237100E+03, -.11847400E+04, 0.17027700E+04, -.62151900E+04, -.55127800E+04, -.68265800E+04, 0.23405300E+04, -.71023400E+04, -.68939700E+04, -.24569700E+04, 0.14414400E+04, 0.50436000E+04, 0.12287300E+04, -.55630300E+03, 0.86856900E+04, 0.37780200E+04, 0.21488000E+04, -.21560600E+04, 0.91392800E+04, 0.17060100E+04, -.17732300E+04, 0.16835700E+02, -.55441600E+03, 0.16079400E+04, 0.28231000E+03, -.17654100E+04, 0.18681300E+03, 0.72198700E+03, -.37140900E+02, 0.74949900E+03, -.27929800E+04, 0.22890200E+04, 0.26488700E+04, -.97547300E+02, 0.35886600E+03, -.99857200E+03, 0.11802100E+04, 0.85628700E+03, 0.12039000E+04, 0.53689300E+03, -.12253200E+04, -.16413400E+04, -.35294100E+03, -.61165000E+03, 0.12483900E+04, -.16532400E+04 },
        { 0.11226600E+00, -.23726300E+00, 0.78492900E+00, 0.24199900E+00, -.99067500E-01, -.37643100E-01, -.34219800E+00, -.69315700E+00, -.16088300E+00, 0.14158000E+00, 0.39409600E-01, -.24061100E-01, -.68868700E-01, -.10257700E+00, 0.19562300E+00, 0.12524700E+00, 0.16178000E+00, -.41170100E-01, 0.30318400E+00, 0.11484200E+00, -.12674100E+00, -.70696200E+00, -.35909400E-01, 0.29651700E+00, 0.92819800E-01, 0.19793100E+00, 0.20867200E+00, -.46037500E+00, -.91998700E-01, 0.24325100E+00, -.13230800E+00, 0.32243300E-01, 0.13969000E+00, -.22388100E+00, 0.27673000E+00, 0.45804800E-01, -.64526600E-02, 0.18970200E+00, 0.20374700E+00, -.18906900E+00, 0.21645100E-02, -.20598000E+00, -.11040200E+01, -.35286700E+00, 0.46713700E+00, 0.21436700E+00, -.12337800E+04, -.88019900E-01, -.15780300E+03, 0.32943800E+03, 0.83592500E+02, 0.34087400E+03, -.15112200E+02, 0.19563800E+03, 0.12832800E+04, 0.74046000E+03, -.32217000E+03, -.12608900E+04, -.37070300E+03, -.66594000E+03, -.66511200E+03, 0.76729100E+03, 0.14100200E+04, 0.34132300E+03, -.45509300E+03, -.78493100E+03, -.87355300E+03, 0.43731900E+03, 0.46244700E+03, 0.43662700E+03, 0.20120400E+03, 0.29748700E+03, -.28677000E+03, -.56800300E+03, 0.12801400E+03, 0.17391000E+02, 0.56464000E+03, -.24610100E+03, 0.12510000E+03, 0.15127800E+03, 0.12308400E+03, 0.10178900E+03, -.68006200E+02, 0.95607700E+01, -.73935100E+02, 0.34778100E+02, -.79944200E+02, 0.12720500E+03, 0.72321400E+03, -.36529100E+03, -.20021400E+04, -.36230500E+03, -.10009700E+04, 0.49660900E+03, 0.43978000E+03, 0.49085900E+03, 0.64153900E+02, 0.39710500E+03, 0.14596500E+04, 0.28211200E+04, -.14170900E+04, 0.58764100E+03, -.14112100E+04, 0.63941400E+02, -.27732300E+03, -.13690900E+03, 0.11565200E+04, -.43661500E+03, 0.11215200E+03, -.24880400E+04, 0.10062600E+04, -.51109000E+03, -.10326000E+04, -.50309100E+03, -.19623300E+03, 0.80271000E+03, -.66129500E+02, 0.77015300E+03, -.24500600E+03, 0.62490300E+03, 0.63031700E+03, 0.28281700E+04, -.14313600E+04, 0.34776700E+03, -.14141700E+04, 0.14398100E+04, 0.25209800E+04, -.28051300E+04, -.15243800E+04, -.19520400E+04, 0.20706500E+04, -.22460300E+04, 0.30978900E+03, -.15423800E+03, -.23352600E+03, -.15527100E+03, -.84578200E+02, 0.76772500E+03, -.42119600E+03, -.17917400E+01, -.21134100E+03, 0.53206600E+03, 0.10503800E+03, 0.65834700E+03, -.29756700E+03, -.10059700E+04, -.32831000E+03, -.12800000E+03, 0.78508200E+03, -.39930100E+03, 0.24846600E-01, -.30504300E+03, 0.73257400E+03, 0.53748700E+03, -.23543400E+04, 0.12058300E+04, 0.36451200E+04, 0.11765600E+04, 0.10680700E+04, -.12743300E+04, 0.13435700E+04, -.36958400E+02, 0.10422100E+04, -.14504300E+04, -.57918800E+03, 0.76570600E+03, -.42668000E+03, 0.31524600E+03, -.38244100E+03, 0.15011700E+03, -.70482900E+03, -.34423400E+02, -.12846200E+03, -.10493200E+02, -.63973900E+03, -.12121200E+04, -.36598100E+03, 0.17969700E+03, -.33273700E+03, 0.18305900E+03, -.74117000E+01, -.23031000E+02, 0.31556700E+02, -.41061000E+01, 0.11981600E+03, -.67947400E+02, 0.53018900E+03, -.26477300E+03, 0.13442500E+03, 0.89837900E+02, 0.13221600E+03, -.88915900E+02, -.60019900E+02, 0.15685000E+02, 0.27337900E+03, 0.70829100E+03, -.58310000E+03, 0.79226100E+03, 0.22019600E+04, -.10884300E+04, -.20271500E+04, -.11016200E+04, -.83144800E+03, -.12051700E+04, 0.63249900E+03, 0.84932300E+03, -.19085300E+03, -.10824300E+04, -.17452700E+04, 0.13535800E+04, -.67828700E+03, -.48635100E+02, -.67722000E+03, -.17131300E+03, 0.32051800E+03, -.44035700E+03, 0.47935200E+03, 0.27165700E+03, -.23860300E+03, 0.61020900E+03, 0.29208200E+03, -.13072300E+03, -.12445400E+04, -.14623500E+03, -.40424800E+03, -.91721900E+03, 0.81353900E+03, -.74669000E+02, 0.30439900E+03, -.10715400E+04, 0.72132300E+03, -.25202400E+03, 0.12861200E+03, 0.14434200E+03, 0.12604300E+03, 0.10995600E+03, -.95778800E+01, 0.61486700E+01, -.42829800E+02, 0.39616300E+02, -.33485300E+02, 0.16142000E+03, 0.10547700E+04, -.47709500E+03, -.88042200E+03, -.52795100E+03, 0.34514300E+02, 0.10874800E+03, -.36156000E+03, -.21291200E+03, -.36042000E+03, 0.69771800E+02, -.23120400E+03, 0.37499300E+04, -.18879400E+04, -.19604100E+04, -.18748400E+04, -.15066300E+04, -.66835500E+03, 0.11953000E+04, 0.25348500E+04, -.66394900E+03, -.13520200E+03, -.85514700E+03, -.61440100E+04, 0.30894500E+04, 0.70745200E+03, 0.30718700E+04, 0.94136800E+03, 0.12125500E+03, -.60506700E+03, -.29479900E+04, 0.15089400E+04, -.47898400E+03, 0.33790000E+04, 0.24804400E+03, 0.97049600E+01, 0.12223300E+03, -.26665600E+03, -.29303300E+02, -.54110500E+01, -.80970200E+02, 0.68634900E+02, 0.22811900E+02, 0.10530900E+03, 0.27768700E+03, -.10771300E+04, -.68343300E+03, 0.80415100E+02, -.18790200E+03, 0.69397100E+02, -.18844400E+03, -.14977300E+03, -.58602200E+03, -.92084100E+02, 0.46014900E+03, 0.20119500E+03, 0.63239200E+02, 0.17183400E+03, -.77119600E+03, -.81842200E+02 },
        { 0.36999100E+00, -.90836300E+00, 0.29552100E+01, -.23490000E+00, -.25100100E+01, -.40296800E+00, -.33131300E+01, 0.47978200E+00, 0.19793400E+00, -.47637700E+00, 0.38922300E-01, 0.28855900E+01, -.61834400E+00, 0.64729100E+00, 0.11579600E+01, 0.58442300E+00, 0.30699800E+01, -.45828400E+00, 0.73609100E+00, -.49804200E+00, 0.59136700E+00, 0.19493200E+01, -.15709700E+00, 0.28067000E+00, 0.64736200E+00, -.93321400E-01, 0.52129500E+00, -.63738000E-01, 0.96163700E-01, -.38508200E+00, -.46009500E+00, -.32510700E+00, 0.56277700E+00, 0.12653800E+00, -.10346800E+00, -.30572800E-01, 0.50358100E-01, -.15961300E+00, -.51155500E+00, 0.15143000E-01, 0.17498800E+00, 0.15289200E+01, 0.15593300E+01, 0.33987500E+00, -.10285800E+01, -.35736400E+00, -.89566600E+00, 0.37949800E+01, -.16108900E+02, -.37103600E+03, 0.47871700E+03, 0.10460200E+04, 0.19041100E+03, -.29313000E+03, -.37752400E+03, 0.14805400E+04, -.70423700E+03, 0.29139300E+03, -.73841300E+03, -.69758000E+03, -.14954600E+04, 0.10304100E+03, -.11207100E+03, -.56095800E+02, -.11621900E+04, -.14731700E+04, -.17636500E+04, 0.87736300E+03, -.10280600E+04, 0.88239400E+03, -.21448400E+02, -.24270900E+03, 0.40426900E+03, -.15873500E+02, 0.89462300E+03, -.23753400E+03, 0.60131100E+03, -.11804500E+03, 0.60327300E+02, 0.18523200E+02, 0.58894900E+02, -.13894800E+03, 0.15674500E+02, 0.29980100E+02, 0.21347700E+02, -.17684900E+02, 0.25509700E+02, 0.55560700E+02, -.31031600E+03, 0.15799800E+03, 0.71005400E+03, 0.15783300E+03, -.90171500E+02, -.19463100E+04, 0.11577400E+04, 0.12715100E+04, 0.12156100E+04, -.16522800E+04, -.84616300E+03, 0.79428300E+03, -.40231400E+03, -.17675800E+04, -.39471600E+03, 0.64804700E+03, 0.14352100E+04, -.12210500E+04, -.82567200E+03, -.37091400E+03, 0.10191600E+04, 0.31718200E+03, 0.88182000E+03, -.44358000E+03, -.49478700E+03, -.44105200E+03, 0.25050300E+03, -.63025200E+02, 0.38171400E+03, 0.13747500E+04, 0.19035400E+02, -.10492000E+03, -.77830200E+03, 0.29443300E+04, -.14628800E+04, -.34283100E+04, -.14718200E+04, -.95979300E+03, 0.31179200E+03, -.67279000E+03, -.64826200E+03, -.14568300E+04, 0.38800000E+03, -.53392300E+03, -.86972200E+02, 0.39213500E+02, 0.27208400E+03, 0.44918700E+02, 0.59024500E+02, -.30792300E+03, 0.68736200E+03, 0.86726100E+03, 0.42573900E+03, -.30112400E+03, 0.37375800E+02, -.70818700E+03, 0.37701200E+03, -.13439300E+03, 0.35071500E+03, 0.23724400E+03, 0.31003000E+03, -.12566000E+03, -.58138900E+02, -.11234800E+02, 0.31718900E+03, 0.47891300E+02, -.13456500E+04, 0.66777800E+03, 0.13694900E+04, 0.67507600E+03, -.42271800E+03, -.74226200E+03, -.84170400E+03, -.24114200E+04, -.21308700E+03, -.46145800E+03, 0.33207300E+03, 0.82021100E+03, -.46850500E+03, -.34977700E+03, -.41169100E+03, 0.58951100E+03, 0.20724100E+03, -.69353500E+03, -.95109900E+03, -.74225000E+03, 0.16823400E+03, -.11001100E+03, 0.14297700E+03, -.69087900E+02, -.12230200E+02, -.71746800E+02, -.14726800E+03, -.13017700E+03, 0.15346500E+03, 0.31085600E+03, -.13043200E+03, -.85385300E+02, -.14247500E+03, 0.22495400E+04, -.11226400E+04, -.63568100E+03, -.11241400E+04, -.54689700E+03, -.10776100E+04, -.56000400E+03, -.49144100E+03, -.12216000E+04, -.82887200E+03, -.13433200E+04, 0.34102800E+03, -.18010000E+03, 0.32784500E+03, -.16810000E+03, -.62104100E+02, -.12364400E+04, -.49494600E+03, -.16225000E+04, -.23998100E+02, -.88659200E+03, -.87540800E+03, 0.89012100E+03, -.44088200E+03, -.10720700E+04, -.44348800E+03, 0.65706400E+01, -.12606900E+03, -.71843700E+03, -.48890300E+03, -.85904700E+03, -.77660700E+02, -.86763200E+03, -.18273900E+04, 0.92240300E+03, -.78045000E+02, 0.91591500E+03, 0.39714500E+03, -.31616300E+03, 0.20503500E+03, -.39040900E+03, 0.12098500E+04, -.42006800E+03, 0.74038500E+03, -.15326000E+03, 0.77903700E+02, 0.29492200E+02, 0.76513400E+02, -.14567500E+03, -.21698100E+02, 0.43980800E+02, 0.12410400E+02, -.11504400E+02, -.64310100E+01, 0.57666600E+02, 0.72401200E+03, -.31261200E+03, -.48637200E+03, -.35987600E+03, 0.18524900E+03, 0.85818900E+01, -.22581200E+03, -.19990100E+03, -.27976600E+03, -.57720600E-01, -.43109900E+03, -.37538300E+04, 0.18803000E+04, 0.99340900E+03, 0.18764500E+04, 0.19708000E+04, 0.16462300E+04, 0.52711800E+02, 0.84220400E+03, 0.16652800E+04, 0.12445900E+04, 0.99847600E+03, 0.26058500E+04, -.13121200E+04, 0.25660900E+03, -.13024100E+04, -.16677000E+04, -.22751600E+04, 0.89906000E+03, 0.27403300E+03, -.64781900E+03, -.18520700E+04, -.91575300E+03, 0.90389100E+02, -.57119300E+02, -.28211500E+03, -.29924900E+02, -.21468600E+03, 0.20001400E+03, 0.31978500E+03, -.15848000E+03, 0.82388400E+01, -.28870200E+03, 0.35944400E+03, -.15834600E+03, 0.19420800E+03, 0.11675800E+03, 0.20750600E+03, -.10436000E+03, 0.42994400E+03, -.17209700E+02, 0.46081800E+03, 0.63047200E+02, -.37374800E+03, 0.57482700E+02, 0.21957400E+02, -.20677500E+03, 0.33720500E+02, 0.25491500E+03 },
        { -.20088900E+00, 0.53629000E+00, -.14322900E+01, -.22926500E+00, 0.66570500E+00, 0.21484100E+00, 0.20655100E+01, 0.17241500E+01, 0.49407000E+00, -.26284900E-01, 0.23543200E-01, -.14475300E+01, 0.25350500E+00, -.65521500E+00, -.87518700E+00, 0.35652100E-02, -.10780200E+01, 0.19875400E+00, -.11456600E+01, 0.37361900E+00, -.10060100E+01, -.95533500E+00, -.33177200E-02, -.90524900E+00, -.52449800E+00, -.26466100E+00, -.19942000E+00, -.36904000E-01, -.19687200E+00, -.14503500E+00, 0.10191700E+00, 0.89442900E-01, 0.78535200E+00, -.61998500E-01, -.55815600E+00, 0.49734800E+00, 0.51412300E-01, 0.35236800E+00, -.57527700E+00, 0.36765100E+00, -.75322300E+00, -.33318600E+01, 0.65166500E-02, 0.34349600E+00, -.42428600E-01, -.10337700E+00, -.68693600E+00, 0.14827500E+00, 0.98632400E+03, 0.14447100E+03, 0.10573900E+03, -.93186700E+03, -.13903000E+03, 0.46214700E+03, 0.41149700E+03, 0.10684800E+04, -.65358700E+03, -.11253400E+04, -.53083900E+03, 0.80450000E+02, -.42862800E+03, -.17597100E+04, -.75253700E+02, -.58291200E+03, -.21020000E+03, -.15875300E+04, -.75048700E+03, 0.37706100E+03, -.84467900E+03, 0.37623000E+03, -.61490000E+03, -.65489400E+03, -.10692700E+03, -.96977000E+03, 0.65348800E+03, -.47231600E+03, 0.61616800E+03, -.47354100E+03, 0.22601200E+03, 0.10112800E+03, 0.23654500E+03, 0.43397900E+03, -.20383400E+03, 0.12501700E+03, -.57938700E+03, 0.71469500E+02, -.13336000E+03, 0.16227400E+03, 0.59956800E+04, -.29635600E+04, -.39596900E+04, -.29930600E+04, -.35939900E+03, 0.65924100E+03, -.29975500E+04, 0.19958200E+04, -.85602500E+03, 0.10031500E+04, -.15172900E+04, 0.83994500E+02, -.34842400E+02, -.19184100E+03, -.37837600E+02, -.25418200E+04, -.42671500E+03, 0.17608600E+04, 0.32937000E+04, 0.15653900E+04, -.12561800E+04, -.12663700E+04, 0.21591700E+04, -.10550300E+04, -.11677000E+04, -.10798000E+04, -.20502100E+02, 0.64808200E+03, -.39618300E+03, 0.21153900E+03, -.63666900E+03, 0.71649000E+03, 0.15250200E+03, -.71805100E+04, 0.35715400E+04, 0.48052400E+03, 0.35908500E+04, 0.37142900E+03, -.13757600E+04, 0.62137800E+03, -.31928500E+04, 0.95404700E+03, -.14675400E+04, 0.31998700E+04, 0.38223600E+04, -.18958900E+04, -.14272500E+04, -.19087000E+04, -.10772900E+04, 0.12799100E+03, -.86356700E+03, 0.11242300E+04, -.11684200E+04, 0.16859100E+03, -.13528400E+04, -.60308400E+04, 0.28605500E+04, 0.21444300E+04, 0.30091700E+04, 0.46703600E+03, -.10100500E+04, 0.31719600E+04, 0.12523100E+04, 0.30823400E+04, -.81848400E+03, 0.26964500E+04, -.49825600E+04, 0.24595100E+04, 0.10989200E+04, 0.24950500E+04, -.47738500E+03, -.25186200E+04, 0.24413500E+04, -.85023700E+02, 0.24760000E+04, -.14938900E+04, 0.24116400E+04, -.12833400E+04, 0.82188600E+03, 0.15067200E+04, 0.63894700E+03, -.16469200E+04, 0.57447100E+03, 0.18706000E+04, 0.37425000E+04, 0.18972900E+04, 0.25015700E+03, 0.48993400E+03, -.76702000E+03, 0.38018700E+03, 0.35331700E+03, 0.38305500E+03, 0.64030900E+03, -.11604800E+03, 0.25981300E+03, -.66144600E+03, 0.21662900E+03, 0.57200300E+02, 0.40443300E+03, -.93710500E+03, 0.45544000E+03, 0.19741000E+03, 0.46958900E+03, -.22305000E+03, 0.15317800E+03, -.13605000E+03, -.26270700E+04, 0.15728600E+04, 0.44704700E+03, 0.50485400E+03, -.13208900E+04, 0.68646300E+03, 0.11215900E+04, 0.66459800E+03, -.92401200E+03, 0.12638700E+02, -.10079400E+04, 0.19798900E+04, 0.88749100E+03, 0.56729500E+03, -.47530400E+03, 0.42256400E+03, -.21712000E+03, -.57665800E+03, -.20866500E+03, -.16359200E+04, -.13384200E+04, 0.81286500E+03, -.24161500E+04, 0.17480500E+04, -.88416300E+03, -.87869000E+02, 0.27525500E+04, -.13928300E+04, -.13243500E+04, -.13749700E+04, -.71179400E+03, 0.19142900E+04, -.42807200E+04, -.14266100E+04, -.21810800E+04, 0.22734500E+04, -.24585200E+03, -.54031200E+03, 0.25856700E+03, 0.11291500E+03, 0.26994800E+03, 0.43663100E+03, -.17264400E+03, 0.13271800E+03, -.67709900E+03, 0.55297100E+02, -.98967700E+02, 0.23159500E+03, -.43756500E+04, 0.20296700E+04, 0.22834500E+04, 0.21915100E+04, -.67768300E+03, -.30264800E+03, 0.20135600E+04, 0.27599500E+04, 0.23931400E+04, -.17681900E+03, 0.19564900E+04, 0.80901300E+04, -.40168800E+04, -.24092300E+04, -.40458500E+04, -.16893200E+04, 0.11007900E+04, 0.15976400E+03, 0.43561800E+04, -.15874700E+04, 0.56561600E+03, -.38729600E+04, -.38522400E+04, 0.19038900E+04, 0.14669300E+04, 0.19269900E+04, 0.22244000E+04, 0.12201000E+03, -.18607400E+04, -.41880000E+04, -.18437600E+02, 0.73286200E+03, 0.30339600E+04, 0.45495600E+03, 0.11343800E+03, 0.64256200E+03, -.22672900E+03, 0.29547900E+03, 0.48064300E+03, -.44952300E+02, 0.43373800E+01, -.96935400E+02, -.13979000E+03, 0.54236100E+03, -.91874000E+03, -.13450300E+04, -.30554000E+03, -.52483400E+03, 0.26737000E+03, -.13775400E+04, -.23061700E+03, -.14602700E+03, -.79346100E+02, 0.19736000E+03, 0.31783800E+03, 0.57910600E+01, 0.30628800E+03, -.61742100E+03, -.40413000E+02 },
        { 0.69432300E-01, -.34180700E+00, 0.70376600E+00, 0.10130300E+00, -.10593100E+01, -.18441600E+00, -.14462400E+01, 0.58470900E+00, -.16467800E-01, -.69741700E+00, 0.17735300E+00, 0.13442900E+01, 0.31352500E-01, 0.86677500E+00, 0.35118200E+00, 0.36619900E+00, 0.46509600E+00, -.12913100E+00, -.17288500E+00, 0.10470600E+00, 0.21282000E+00, 0.25872300E+01, 0.11817900E+00, -.74000700E+00, 0.27607200E+00, -.19030800E+00, -.26811300E+00, 0.67137700E+00, 0.17051100E+00, -.17888200E+00, -.49622200E+00, -.16967700E+00, -.44485200E+00, 0.42780000E+00, 0.32112200E-01, -.99915300E-03, -.18478500E-01, 0.96793100E-01, -.11860200E-01, 0.28847200E+00, 0.45240600E+00, 0.86065500E+00, 0.70134700E-01, 0.28525800E+00, -.93723600E+00, 0.23585500E+00, 0.55392700E+00, -.29845800E-01, -.32635900E+00, -.22539800E+04, 0.24269800E+04, 0.31987800E+04, 0.55279700E+03, -.16089100E+04, -.10116800E+04, 0.24234400E+04, -.11892100E+04, -.15693800E+04, -.12114900E+04, -.13083900E+04, -.34517300E+04, -.53258000E+03, -.12375000E+04, -.41713700E+03, -.26602800E+04, -.21436500E+03, -.10803400E+05, 0.53940500E+04, -.46603900E+04, 0.54017700E+04, -.12517400E+03, -.12218200E+04, 0.23358900E+04, -.12471900E+04, 0.39909500E+04, -.97042000E+03, 0.50645900E+04, 0.47752200E+03, -.23726300E+03, -.23606000E+03, -.23878000E+03, 0.14524800E+02, 0.21687600E+03, 0.18479200E+03, 0.13519100E+03, -.25557300E+03, 0.20729100E+03, -.19041100E+03, -.19774900E+04, 0.99420600E+03, 0.28052500E+03, 0.98912100E+03, -.13273200E+04, -.73080400E+04, 0.31455500E+04, 0.30887900E+04, 0.27282700E+04, -.59004500E+04, 0.25526700E+03, 0.40248200E+04, -.20182400E+04, -.67518200E+04, -.20120100E+04, 0.40778100E+03, 0.47664800E+04, -.39848900E+04, -.18419200E+04, -.12822700E+04, 0.30717100E+04, -.85007200E+03, 0.20559600E+04, -.10287100E+04, -.17605100E+04, -.10280100E+04, 0.82182700E+02, -.12660800E+04, 0.12260100E+04, 0.35001400E+04, 0.25382500E+03, -.10796100E+04, -.23467200E+04, 0.42230600E+04, -.20839900E+04, -.96251100E+04, -.21114800E+04, 0.72449000E+03, 0.30037900E+04, -.23040200E+04, -.19529100E+04, -.21373300E+04, 0.28821800E+04, -.85554900E+03, -.45326700E+03, 0.21951500E+03, 0.39208500E+03, 0.22686000E+03, -.51490000E+03, -.44617800E+03, 0.75365900E+03, 0.22669400E+04, 0.14496000E+04, -.41776500E+03, -.11222700E+03, -.67017200E+03, 0.32878700E+03, -.11003700E+04, 0.33468500E+03, -.20509700E+03, -.10632500E+04, 0.14544500E+04, 0.20290100E+04, 0.97762200E+03, -.99411700E+03, -.26947000E+03, 0.47520700E+03, -.26370800E+03, -.84218200E+02, -.23719600E+03, -.11009800E+04, -.36246300E+04, 0.32339300E+03, -.49836500E+04, -.16694600E+04, -.25491000E+04, 0.93951500E+03, -.27426900E+03, 0.65872400E+02, 0.89769800E+03, 0.13688300E+03, -.17394800E+03, -.63608700E+03, -.65455200E+03, -.17569500E+04, -.56347700E+03, -.42735000E+03, 0.25723200E+03, 0.57692100E+03, -.28298200E+03, 0.14641600E+03, -.28850000E+03, -.31236700E+03, -.81324600E+03, 0.99790400E+03, 0.10820100E+04, -.88630200E+02, -.54231000E+03, -.47498900E+03, 0.47032400E+04, -.23474900E+04, 0.31526900E+04, -.23515000E+04, -.12547400E+04, -.34659800E+04, 0.80428100E+03, -.19201400E+04, -.32635300E+04, -.21670300E+04, -.29146800E+04, -.17737100E+04, 0.86430800E+03, 0.14776300E+04, 0.88724300E+03, -.27274900E+03, -.38088600E+04, -.10376600E+04, -.43307700E+04, -.53279400E+03, -.22857600E+04, 0.12335200E+04, -.64685000E+04, 0.32442800E+04, -.24756600E+04, 0.32345400E+04, 0.60271800E+02, -.28542700E+03, 0.15286000E+04, -.29255400E+04, 0.10875200E+04, 0.25153400E+03, 0.21750100E+04, -.38278500E+04, 0.19197100E+04, -.71081300E+03, 0.19144500E+04, 0.15353300E+04, -.73915300E+03, -.31793300E+03, -.25045400E+04, 0.81346800E+03, -.18462800E+03, 0.86880700E+03, 0.43070400E+03, -.21417900E+03, -.24485100E+03, -.21536900E+03, -.65685100E+01, 0.83797100E+02, 0.25830300E+03, 0.13204400E+03, -.22249300E+03, 0.89895500E+02, -.21358500E+03, 0.11714700E+04, -.55398300E+03, -.10673300E+04, -.58539500E+03, -.12024500E+03, -.92938500E+03, 0.30491300E+03, 0.76406800E+03, 0.18707600E+03, -.67808300E+03, -.88516900E+03, -.61246200E+04, 0.30716400E+04, 0.53079900E+03, 0.30622300E+04, 0.95084900E+03, 0.40968800E+04, -.90403400E+03, 0.21659400E+04, 0.40088400E+04, 0.22971800E+04, 0.19967300E+04, 0.40119600E+04, -.20286300E+04, 0.54325700E+04, -.20058900E+04, -.20923800E+04, -.82637300E+04, 0.42162700E+04, -.22872900E+03, -.22403400E+04, -.57007600E+04, -.20575800E+04, -.47469600E+03, 0.37036700E+03, -.11605000E+03, 0.33891300E+03, -.32987500E+02, 0.10571500E+04, 0.12229800E+03, -.42098500E+02, 0.40267900E+02, -.65001100E+03, 0.13536600E+04, 0.38417700E+03, 0.26109300E+03, -.16304800E+03, -.31548200E+03, -.56313500E+03, 0.43668600E+03, 0.25205600E+03, 0.15542900E+04, 0.50467700E+03, -.11962800E+04, -.28118900E+03, -.49522300E+02, -.76496300E+02, 0.27365700E+03, 0.60529500E+03 },
        { 0.11476900E+00, 0.53145900E+00, -.82751000E+00, 0.19727800E+00, -.53029700E+00, 0.90921800E-01, -.26786800E+00, 0.60226800E+00, 0.12732900E+00, -.22533300E+00, -.84188700E-01, 0.98938800E-01, 0.24213200E+00, 0.14699300E+00, -.52070300E+00, 0.20588100E+00, 0.22222100E-01, 0.58561700E-01, -.41285200E+00, 0.36624500E-01, -.25401800E+00, 0.65983200E+00, 0.27629600E+00, -.27083500E+00, -.50855400E+00, -.34745900E+00, 0.23898600E-02, 0.50529200E+00, 0.60535500E-01, -.15179300E+00, 0.22866200E+00, -.10293200E-01, -.26663200E+00, 0.13519500E+00, 0.14603600E-01, -.12737100E+00, -.17413500E-02, 0.21738400E+00, 0.18295800E+00, 0.23406300E+00, -.26563800E+00, -.61062300E-02, 0.10129600E+01, 0.32301400E+00, 0.32474700E-01, 0.11193000E+00, 0.73108900E+00, 0.10351900E-01, -.14991400E+00, 0.46307500E+00, -.62590800E+03, -.10403400E+04, -.77283200E+02, -.37657400E+01, 0.34967200E+03, 0.12331300E+04, -.71588500E+03, -.83311200E+03, -.61606700E+03, 0.38025200E+03, 0.26767500E+04, -.17826300E+04, -.89084400E+03, -.11341600E+04, 0.18523200E+04, -.65696800E+02, 0.44027500E+04, -.22002300E+04, -.70435500E+03, -.22012300E+04, 0.19184400E+01, -.16007200E+03, -.94793500E+03, 0.62170400E+03, -.11636100E+04, -.11808600E+03, -.23483400E+04, -.20767100E+02, 0.25550900E+01, -.78541900E+01, 0.10349400E+02, 0.11316300E+03, -.15888000E+03, 0.72362400E+02, 0.93589800E+02, 0.11480900E+03, -.13374400E+03, -.12288400E+02, 0.34471600E+04, -.16884100E+04, -.19139600E+04, -.17228700E+04, -.37415700E+03, 0.22394000E+04, -.30098300E+04, -.18530400E+04, -.21834800E+04, 0.17264100E+04, -.43541900E+03, -.48740700E+04, 0.24537400E+04, 0.32909800E+04, 0.24376800E+04, -.37659300E+03, -.45326700E+03, 0.15895000E+04, -.47845600E+03, 0.14106700E+04, -.25817700E+03, 0.18519300E+04, -.16112400E+04, 0.82667000E+03, 0.81536500E+03, 0.80558200E+03, -.31207600E+03, -.38701400E+03, -.29306000E+03, -.16501200E+04, 0.23138900E+03, -.25596800E+03, 0.13457500E+04, -.26412800E+04, 0.13249700E+04, 0.20269000E+04, 0.13207300E+04, 0.15345200E+04, -.28572100E+04, 0.22495800E+04, 0.22196000E+04, 0.21200500E+04, -.28807100E+04, -.66535100E+03, 0.29422600E+03, -.15096500E+03, -.24307300E+03, -.14673600E+03, -.53150400E+00, 0.17877500E+03, -.59994500E+03, -.94840300E+03, -.59834800E+03, 0.23172900E+03, -.10288800E+03, 0.10345400E+03, -.12310500E+03, 0.44239600E+03, -.52635600E+02, -.15260100E+03, -.26959100E+03, 0.16553100E+03, -.23157200E+03, 0.35723100E+02, -.32638300E+03, 0.26783800E+03, 0.10085000E+04, -.53893600E+03, -.84913200E+03, -.50365600E+03, -.43441900E+03, 0.74918300E+03, 0.64662000E+00, 0.21308000E+04, 0.10693000E+03, 0.60043000E+03, -.61185500E+03, -.27894700E+03, 0.26446700E+03, 0.62470100E+03, 0.13906200E+03, -.16913500E+03, 0.73326600E+03, 0.33525600E+03, 0.91548100E+03, 0.17221800E+03, 0.71922300E+03, -.54626200E+02, -.24978200E+03, 0.12825500E+03, 0.12420100E+02, 0.12482200E+03, 0.21482200E+03, -.81305500E+02, -.45119300E+02, -.17829100E+03, 0.10958200E+03, -.62620900E+02, 0.11363800E+03, 0.35527100E+04, -.17862800E+04, -.21927500E+04, -.17761900E+04, 0.63914700E+03, 0.15052400E+03, -.31407500E+03, 0.16943300E+04, -.32229100E+03, -.11224600E+03, -.29097300E+04, 0.27082700E+04, -.13480900E+04, -.10207400E+04, -.13535000E+04, 0.10470100E+03, 0.32316400E+04, -.18860400E+04, 0.13368100E+03, -.12608600E+04, 0.22452200E+04, -.13216500E+04, 0.51971000E+04, -.26036400E+04, -.19779500E+04, -.25981400E+04, 0.10894800E+03, -.82346400E+03, -.10843000E+03, 0.18616700E+04, -.10319400E+04, -.98901600E+03, -.35740100E+04, 0.66569500E+03, -.36209200E+03, -.52611100E+02, -.33281400E+03, -.17000500E+03, 0.23976200E+03, -.11791700E+04, -.20707700E+03, -.81769000E+03, 0.44682300E+03, -.54270500E+03, 0.27391900E+02, -.22531700E+02, -.18956100E+02, -.13727200E+02, 0.11723000E+03, -.15001800E+03, 0.62047400E+02, 0.13498200E+03, 0.10578700E+03, -.13383800E+03, -.47044400E+02, -.89886100E+03, 0.33549800E+03, 0.85518300E+03, 0.44999400E+03, -.77025700E+02, 0.23930600E+03, 0.42696400E+02, 0.16379900E+02, 0.13042800E+03, 0.21124800E+03, 0.57104000E+03, -.30784100E+04, 0.15738700E+04, 0.28039200E+04, 0.15390800E+04, -.12123900E+04, 0.12123300E+04, -.10081000E+03, -.34891200E+04, -.10248100E+04, 0.15713500E+04, 0.37400200E+04, 0.65180800E+04, -.32893800E+04, -.49172900E+04, -.32589100E+04, 0.11675600E+04, 0.31022100E+03, -.18036700E+04, 0.31934000E+04, -.66042300E+03, -.11490400E+03, -.48085500E+04, 0.37330800E+01, -.35759800E+03, 0.26104800E+03, 0.15545700E+01, 0.13513600E+03, 0.19104600E+03, -.95209600E+03, -.32933700E+03, 0.17503500E+01, 0.32176100E+03, 0.13540900E+03, 0.41456100E+03, 0.25840600E+03, -.75111000E+02, -.13285000E+03, 0.16756300E+03, -.40354500E+03, -.71588100E+02, -.23543700E+03, 0.28104700E+03, 0.19269400E+03, -.39871600E+02, 0.34984200E+02, 0.19578300E+03, 0.58807700E+03, 0.31698400E+03 },
        { -.11418100E+00, -.10271200E+00, -.12309100E+01, -.58038400E-01, 0.53387500E+00, -.74968300E-01, -.89794700E+00, 0.30172200E+00, 0.12003300E+00, -.25864600E-03, 0.92364100E-01, -.22745900E+00, -.12292600E+00, -.17883200E+00, 0.35857000E+00, 0.10201700E+00, 0.33104400E+00, 0.12839700E-02, 0.12285400E+00, 0.26926300E-01, -.94168600E-02, 0.22580100E+00, 0.12921700E-01, -.30674700E+00, 0.79946700E-03, -.32276800E-01, -.33404700E+00, 0.20794900E-01, 0.90254500E-01, -.11319000E-01, 0.12605000E+00, 0.92619200E-01, 0.42497000E+00, -.15957900E+00, -.89376700E-01, -.14182400E+00, 0.15015100E-01, -.43875200E+00, -.50231400E-01, -.22205300E+00, 0.23512900E+00, 0.55695100E+00, 0.40170500E+00, 0.11511700E+00, 0.20436700E+00, -.12050100E+00, -.25433200E+00, 0.62969400E-02, -.19642200E+00, -.90737100E-01, -.57745200E+00, -.63765800E+03, -.11785300E+03, 0.66053000E+02, 0.38176100E+03, -.16936900E+02, -.21283700E+02, 0.31529300E+03, 0.96233300E+01, 0.60278600E+03, 0.24124100E+04, -.22121000E+04, -.13727600E+04, -.91815800E+03, 0.18020000E+04, 0.60338200E+02, 0.31763200E+04, -.15903800E+04, -.48334700E+02, -.15878200E+04, -.37973200E+02, 0.11015100E+03, -.88421300E+03, -.67112000E+02, -.10407700E+04, 0.71279100E+02, -.15634300E+04, -.82118000E+01, 0.12224000E+01, -.71906800E+02, 0.40289900E+01, 0.14444700E+03, -.22209100E+03, 0.27486600E+03, 0.15612200E+03, 0.17478500E+03, -.20637600E+03, -.96578100E+02, 0.28859600E+04, -.14496000E+04, -.12652400E+04, -.14413500E+04, -.35604600E+03, 0.27234200E+04, -.42846700E+04, -.29759000E+04, -.23238400E+04, 0.24541000E+04, -.14183900E+03, -.43036200E+04, 0.21466700E+04, 0.25723800E+04, 0.21532300E+04, -.45409700E+03, -.54271600E+03, 0.13239000E+04, -.32334800E+02, 0.16855300E+04, -.42305300E+03, 0.11261400E+04, -.13203700E+04, 0.66634900E+03, 0.75092000E+03, 0.66010800E+03, -.19086900E+03, -.68852100E+02, -.19330800E+03, -.11765900E+04, 0.13454200E+03, 0.91290700E+02, 0.10820700E+04, -.41002400E+03, 0.20370100E+03, -.60689000E+03, 0.20521400E+03, 0.17531400E+04, -.17774800E+04, 0.11468200E+04, 0.16500400E+04, 0.93031600E+03, -.20439800E+04, -.18132600E+03, 0.16577500E+04, -.81381800E+03, -.54831900E+03, -.82802900E+03, -.31421700E+03, 0.20456400E+03, -.84887300E+03, -.37186200E+03, -.94105300E+03, 0.25618100E+03, -.44064000E+03, -.52020000E+03, 0.22968700E+03, 0.74418600E+03, 0.25798100E+03, -.56590700E+02, -.34190400E+03, 0.68760500E+03, 0.75867000E+02, 0.47355000E+03, -.28156800E+03, 0.20156200E+03, 0.56416600E+03, -.30127000E+03, 0.20216300E+03, -.28079000E+03, -.10097500E+04, -.19386300E+03, 0.10262300E+04, 0.10652500E+04, 0.59441200E+03, -.22037300E+03, -.11813500E+04, -.83582700E+03, 0.47345900E+03, 0.83836200E+03, 0.41698600E+03, -.55256000E+03, 0.17802300E+03, 0.78289300E+03, 0.10509700E+04, 0.51537400E+03, 0.24143900E+03, 0.25203900E+03, -.12678000E+03, 0.61412600E+02, -.10382400E+01, 0.63235000E+02, 0.13184500E+03, -.21479300E+03, 0.36272800E+03, 0.10122100E+03, 0.26305300E+03, -.19049700E+03, 0.52065000E+02, 0.10287200E+04, -.51678300E+03, -.16906600E+04, -.51400500E+03, 0.31379200E+03, 0.33710300E+03, 0.47905200E+03, 0.76883900E+03, 0.10607300E+04, -.95822100E+02, -.12848100E+04, -.37594500E+03, 0.18913700E+03, 0.53684000E+03, 0.18938900E+03, 0.26854600E+03, 0.30542700E+04, -.27298200E+04, -.95098700E+03, -.54760000E+03, 0.22807400E+04, 0.28533600E+03, 0.45291000E+04, -.22615100E+04, -.11843000E+04, -.22636600E+04, -.10672200E+04, -.12641200E+04, 0.10245800E+04, 0.13938600E+04, 0.13768700E+03, -.14927300E+04, -.28305400E+04, 0.90828000E+03, -.46195300E+03, -.53217600E+03, -.45383200E+03, -.12873400E+03, 0.16182100E+04, -.34818500E+04, -.20881000E+04, -.12700000E+04, 0.15945800E+04, -.19733600E+00, 0.41870600E+02, -.24075100E+02, -.95383100E+02, -.21006000E+02, 0.13184500E+03, -.21036500E+03, 0.28715600E+03, 0.16539200E+03, 0.16039300E+03, -.19581400E+03, -.12186600E+03, -.13907600E+04, 0.65871000E+03, 0.11393700E+04, 0.69663900E+03, -.85665600E+02, 0.18251900E+03, 0.16236200E+03, 0.21391900E+03, 0.42896800E+03, 0.21456900E+03, 0.59598200E+03, -.32214000E+04, 0.16161200E+04, 0.23362700E+04, 0.16104300E+04, -.14690600E+04, 0.28305400E+03, 0.48453700E+03, -.18961600E+04, 0.39004400E+02, 0.71235500E+03, 0.22413100E+04, 0.37130900E+04, -.18667900E+04, -.31932700E+04, -.18562500E+04, 0.16126400E+04, 0.10784500E+04, -.15637200E+04, 0.12000900E+04, -.62826500E+03, 0.60694800E+03, -.22580000E+04, 0.14158200E+02, -.36767700E+03, 0.31937500E+03, 0.67676100E+02, 0.11190700E+03, 0.16257800E+03, -.10846600E+04, -.30253500E+03, -.13407100E+02, 0.33873500E+03, 0.20168300E+03, -.36387800E+02, 0.26258500E+03, -.81329600E+02, -.12654600E+03, 0.67251000E+02, -.48710600E+03, -.90699800E+02, -.67324800E+03, 0.54796200E+03, 0.52325200E+03, -.89391000E+02, 0.44438900E+02, 0.23176500E+03, 0.43083400E+03, 0.27318600E+03 },
        { -.98255100E-01, -.23533000E+00, -.68864400E+00, 0.32321700E-01, 0.60433400E+00, 0.49765200E-01, 0.45120600E+00, -.78348100E+00, 0.74581000E-01, 0.32127900E+00, -.12417700E+00, -.66148100E+00, -.24876800E-01, -.38565100E-01, -.14960400E+00, -.11065900E+00, 0.24518900E-01, 0.16924600E+00, 0.60251300E+00, -.13084100E+00, 0.57922800E+00, -.91064900E+00, 0.32354800E-01, -.23595700E+00, 0.10787100E-01, -.22253100E+00, -.84385000E+00, 0.38327800E+00, 0.95431200E-01, 0.27425700E+00, -.14149300E-01, 0.91480100E-01, -.82684500E+00, 0.66924900E+00, -.18545100E+00, -.51967500E+00, -.74521200E-01, -.79539100E+00, 0.12934000E+00, -.16782000E-01, 0.42534000E+00, 0.74410500E+00, 0.39763000E+00, 0.49071000E+00, 0.17041000E+00, -.14995600E+00, -.93979900E+00, -.13975000E+00, -.51144900E+00, 0.62335100E-01, -.26244200E+00, 0.88182500E-01, 0.74233200E+03, 0.42141400E+02, 0.69619300E+03, 0.74487300E+03, -.48451400E+03, -.15051000E+04, -.37412300E+03, 0.52595300E+03, 0.18766600E+04, -.19134800E+04, -.55281700E+03, -.42002000E+03, 0.16733900E+04, -.15895100E+03, 0.21982400E+04, -.10947900E+04, -.51474700E+02, -.10995900E+04, -.35289100E+03, -.23694200E+03, -.49695700E+03, 0.14423100E+03, 0.53397500E+03, -.12127100E+03, -.56716800E+03, -.17308300E+03, 0.80754400E+02, 0.34525200E+02, 0.86647900E+02, 0.43519500E+03, 0.59097200E+02, -.22559100E+02, -.63151300E+02, 0.32767900E+03, 0.67289200E+02, 0.15423200E+03, 0.36818800E+04, -.18202300E+04, -.27907000E+04, -.18432300E+04, -.94776800E+03, 0.11244900E+04, -.20989200E+04, 0.52602700E+03, -.92316300E+03, 0.11908600E+04, -.75524100E+03, -.62482900E+03, 0.32811000E+03, 0.12057300E+04, 0.31050400E+03, -.17294000E+04, -.73701900E+03, 0.11590500E+04, 0.62443200E+03, 0.11965400E+03, -.85637700E+03, -.49911400E+03, -.32272100E+03, 0.17726300E+03, 0.22767900E+03, 0.16144800E+03, -.60804100E+03, -.15788600E+03, 0.97840300E+02, 0.58477300E+02, 0.31349000E+03, -.11071100E+03, 0.91497500E+03, -.12367800E+04, 0.61851500E+03, 0.11574500E+04, 0.61811500E+03, 0.17305000E+04, -.60265600E+03, 0.36133700E+03, 0.12700900E+03, 0.71476300E+03, -.68980300E+03, 0.44976200E+02, 0.26256500E+04, -.13150200E+04, -.78710400E+03, -.13139900E+04, -.45648500E+03, 0.39417800E+03, -.82688300E+03, -.75608500E+02, -.19588400E+04, 0.32677900E+03, -.12610600E+04, -.18057200E+04, 0.78835200E+03, 0.10109100E+04, 0.90595600E+03, 0.23202900E+03, -.28250500E+03, 0.11662700E+04, 0.11253200E+04, 0.19076300E+04, -.23896100E+03, 0.12844300E+04, -.21452200E+04, 0.10511300E+04, 0.81897800E+03, 0.10709300E+04, 0.15732600E+04, 0.33939800E+03, -.37587200E+03, -.53330200E+03, 0.23809500E+04, 0.73848000E+03, 0.17988700E+04, -.22309500E+04, 0.12465400E+04, 0.19562200E+04, 0.11167600E+04, -.13696800E+04, -.26435900E+03, 0.97971200E+03, 0.39544500E+03, 0.94072100E+03, -.32963300E+03, 0.57321300E+03, -.73746500E+03, 0.36985600E+03, 0.27436200E+03, 0.36894700E+03, 0.54235100E+03, 0.15488900E+03, -.66759400E+02, -.90685800E+02, 0.60682700E+03, 0.19343300E+03, 0.58754200E+03, 0.37514600E+04, -.18853400E+04, -.26671000E+04, -.18761900E+04, 0.11773100E+04, 0.91765100E+03, -.21315400E+04, 0.39900200E+03, 0.23018800E+04, 0.11660600E+04, 0.74136000E+02, -.57504000E+03, 0.29182400E+03, 0.13279200E+03, 0.28558100E+03, -.77909500E+02, 0.20081200E+04, -.17036000E+04, -.24271400E+03, 0.10903900E+03, 0.18974000E+04, 0.36986300E+03, 0.72047200E+04, -.36112600E+04, -.28181400E+04, -.36035100E+04, 0.40664000E+03, -.31109200E+02, -.19412500E+04, 0.11723700E+04, 0.18492200E+04, 0.33024000E+03, -.11818800E+04, 0.28313000E+04, -.14361600E+04, -.12052400E+04, -.14165200E+04, -.60277400E+03, 0.49787400E+03, -.22016500E+04, -.75589500E+03, -.17989300E+04, 0.87037100E+03, -.10231800E+04, -.20941600E+03, 0.98254000E+02, 0.56341500E+02, 0.10480600E+03, 0.45377000E+03, 0.10823100E+03, -.61494600E+02, -.10589200E+03, 0.36283300E+03, 0.11829800E+03, 0.21492400E+03, -.20870200E+04, 0.90422400E+03, 0.14157000E+04, 0.10418000E+04, -.32816300E+03, -.38863700E+02, 0.71190900E+03, 0.74931700E+03, 0.83703500E+03, -.38581800E+02, 0.99857300E+03, 0.67958100E+04, -.33788000E+04, -.25456900E+04, -.33975500E+04, -.34293600E+04, -.18130300E+04, 0.12019500E+04, 0.20011500E+04, -.33196200E+04, -.17729300E+04, -.26949500E+04, -.56348500E+04, 0.28039500E+04, 0.15372900E+04, 0.28170300E+04, 0.27865000E+04, 0.23494500E+04, -.19965600E+04, -.19550300E+04, 0.36473600E+04, 0.21937900E+04, 0.30530000E+04, 0.21074600E+03, 0.10164000E+03, 0.89263500E+03, -.22371000E+03, 0.46535900E+03, -.31203800E+03, -.76906100E+03, -.49750000E+02, -.12455300E+03, 0.98327100E+02, -.90099600E+02, -.82640900E+02, -.38881000E+03, -.50689500E+03, -.46357400E+03, 0.97121300E+02, -.11673700E+04, -.99720100E+02, -.12861400E+04, 0.30473700E+03, 0.12132500E+04, 0.17967400E+03, -.61963600E+02, 0.72044500E+03, 0.19142300E+03, 0.37318400E+03 },
        { -.28702000E-01, 0.14194800E+00, 0.35791500E+00, -.63435500E-01, -.12211900E+00, 0.14031200E-01, -.19751600E+00, -.27812300E-01, -.12621200E-02, 0.10190900E+00, -.20774700E-02, 0.17408900E+00, -.55762100E-01, -.18472300E-01, 0.97384700E-02, -.66318500E-02, 0.10291100E+00, -.38680900E-01, -.67954000E-01, -.24733600E-01, 0.40672900E-01, 0.69385100E+00, 0.17514300E-01, 0.46779900E-01, -.23743700E-01, 0.56229500E-02, 0.39116500E-01, -.20333300E-01, -.29306000E-01, -.67716100E-02, -.42533100E-02, 0.80613900E-02, 0.58747000E-01, -.49186200E-01, -.48154300E-01, -.59133400E-01, 0.87436200E-02, -.15107600E+00, -.41897100E-01, -.85956800E-02, 0.25003600E-01, 0.21438700E+00, 0.58008000E+00, 0.41621200E-01, -.15715300E+00, 0.14845300E-01, 0.60214900E-02, 0.45192600E-02, 0.16559200E-01, 0.27181200E-01, 0.29462100E-01, -.57615800E-01, -.28721500E-01, 0.47353100E+02, -.10833100E+02, -.11028000E+03, 0.60306200E+02, 0.13325600E+03, 0.55172500E+02, 0.59987500E+02, 0.90382100E+02, 0.39892200E+01, -.17101900E+02, -.33394800E+01, 0.93473700E+02, -.34524900E+02, -.41577300E+02, 0.20806800E+02, 0.26563700E+03, 0.20799600E+02, 0.37038800E+02, 0.99410600E+02, -.94279500E+02, -.16583800E+03, -.14760600E+03, 0.86037100E+02, 0.47451100E+02, -.32162200E+02, 0.16433000E+02, 0.12798800E+02, 0.16078700E+02, -.17279900E+02, -.26790100E+02, 0.19660000E+02, 0.16612700E+02, 0.21651800E+02, -.22538500E+02, 0.37097100E+01, 0.32552200E+03, -.16332700E+03, -.12580800E+03, -.16271100E+03, 0.10513100E+03, 0.11931000E+03, -.23902700E+03, -.27509400E+03, -.21764400E+03, 0.17082100E+03, -.16891500E+03, 0.10804200E+03, -.54221300E+02, 0.12333700E+02, -.53972900E+02, -.51888700E+02, -.35122900E+02, 0.37896100E+02, 0.11985100E+03, 0.23610800E+02, -.85265000E+02, -.83105500E+02, -.10681200E+03, 0.52545500E+02, 0.78519900E+02, 0.53402800E+02, 0.26473200E+02, 0.31945700E+02, -.22509400E+02, -.80008200E+02, -.28006200E+01, 0.98758200E+02, 0.50779400E+02, 0.19409900E+03, -.96958700E+02, -.88358300E+02, -.97042700E+02, -.20987600E+02, 0.10850200E+03, -.99429400E+02, -.39861600E+02, -.19971900E+03, 0.44277500E+02, -.19396900E+02, 0.75367500E+02, -.38382700E+02, -.23074800E+02, -.37656100E+02, -.98909600E+01, 0.34213600E+01, 0.24951200E+02, -.18286500E+02, -.54988500E+02, 0.86800100E+01, 0.21647400E+01, 0.14829800E+02, -.13115500E+01, 0.24211300E+02, -.74739400E+01, 0.39807700E+02, 0.23963700E+02, -.85613100E+02, -.88682300E+02, -.50134900E+02, 0.57561400E+02, -.72948500E+02, -.20225200E+03, 0.10312100E+03, 0.18068900E+03, 0.10117200E+03, -.53164200E+02, -.15136500E+03, 0.91792500E+02, -.64312000E+02, 0.16044600E+03, -.16933200E+03, -.82188800E+01, 0.15399800E+03, -.83479400E+02, -.78744300E+02, -.77029200E+02, 0.94749100E+02, 0.13783900E+03, -.65436800E+02, -.25651900E+02, -.72482800E+02, 0.79241100E+02, -.47371200E+02, 0.58145800E+01, -.28514100E+01, -.15435200E+02, -.29122200E+01, -.11220000E+02, -.60529000E+01, 0.23345100E+02, 0.33481700E+02, 0.25191600E+02, 0.62348100E+01, -.16681700E+02, -.48537200E+03, 0.24296800E+03, 0.68404500E+00, 0.24269900E+03, -.56840700E+02, 0.14540600E+03, 0.11724500E+03, -.60993600E+02, 0.12642600E+03, 0.90107200E+02, 0.32700600E+03, -.23310400E+03, 0.11626000E+03, 0.11776300E+03, 0.11659900E+03, 0.10608200E+03, 0.18512500E+03, -.89695500E+02, -.11131300E+03, -.22140500E+02, 0.16838700E+03, 0.10244100E+03, 0.13343600E+02, -.68395300E+01, 0.24644100E+03, -.66391900E+01, -.16127300E+03, 0.86340500E+01, 0.12553000E+03, 0.11900600E+02, -.62563200E+02, -.11006900E+02, 0.73971100E+02, 0.82532700E+02, -.40237100E+02, -.15638200E+02, -.41246200E+02, -.48250100E+02, 0.27233800E+02, -.13827100E+03, -.12576200E+03, -.35865100E+02, 0.36656000E+02, 0.47463600E+02, -.27768200E+02, 0.14274600E+02, 0.11544500E+02, 0.13881900E+02, -.17470000E+02, -.23962500E+02, 0.19024200E+02, 0.14226000E+02, 0.18877700E+02, -.18452900E+02, 0.13269700E+01, 0.42509300E+02, -.14278500E+02, 0.11582700E+02, -.21213200E+02, 0.55855900E+02, 0.59583400E+02, -.71106000E+02, -.77890600E+02, -.51006600E+02, 0.50824700E+02, -.34738200E+02, 0.42916000E+03, -.21569300E+03, -.13916000E+03, -.21458900E+03, -.38658700E+02, -.15384500E+03, 0.73225600E+02, 0.20530300E+03, 0.69667500E+02, -.95919800E+02, -.26890100E+03, -.66620400E+03, 0.33429300E+03, 0.12877500E+03, 0.33311200E+03, 0.12133200E+03, 0.28787800E+03, -.94473200E+02, -.34320400E+03, -.26129800E+02, 0.23378900E+03, 0.41483600E+03, 0.30663100E+02, -.38856100E+02, -.32417000E+02, -.18148000E+02, -.22738800E+02, 0.59609600E+01, -.11982100E+00, -.82321900E+01, 0.14749800E+01, -.34238700E+02, 0.33723800E+02, -.46553400E+02, 0.18855700E+01, 0.24201600E+02, 0.64487100E+02, 0.86581100E+01, 0.24627100E+02, -.17372600E+02, -.50148700E+02, 0.13670400E+02, 0.34850100E+02, 0.16911800E+02, 0.10575000E+02, -.18051600E+02, -.47191300E+02, -.25519300E+02 },
        { -.89982400E-01, -.13931800E+00, -.12391900E+00, -.59351400E-01, 0.57604800E+00, 0.30091300E-01, 0.76880600E+00, -.48052300E-01, -.67826000E-01, 0.11068000E+00, 0.34158400E-01, -.89672700E+00, 0.47384300E-01, -.44388500E+00, -.62406100E+00, -.11019100E+00, -.49365400E+00, 0.54827200E-01, -.62001700E-01, 0.46556900E-01, 0.15083100E-01, -.44725000E+00, -.45190000E-02, -.74531800E-01, 0.10366000E+00, -.29132100E-01, -.18432700E+00, -.64353300E-01, -.30489800E-02, 0.17312700E+00, 0.17887700E-01, 0.13795600E+00, 0.16896300E+00, 0.96769600E-01, -.11134600E+00, 0.66109100E-01, 0.26626900E-01, 0.16375000E+00, -.21092800E-01, 0.25417600E+00, 0.36407400E+00, 0.10315100E+01, 0.13722800E+01, 0.58490600E+00, -.23332300E+00, -.91474300E-01, -.79330900E+00, 0.38188900E-01, 0.83572700E-01, 0.16626700E+00, 0.95332800E-01, -.81256100E+00, -.36925500E+00, 0.17610300E+01, 0.60249000E+03, 0.12886400E+03, -.84133000E+02, -.91729600E+03, -.63800000E+02, 0.15979400E+03, 0.13948800E+04, -.11120900E+04, -.39194700E+03, -.43492800E+03, 0.10208600E+04, 0.49832500E+03, -.17587300E+02, 0.27670200E+01, 0.78209400E+03, 0.89953400E+01, 0.25508300E+03, -.39034200E+02, -.82236300E+00, -.16452800E+03, -.14004200E+03, 0.12239000E+03, -.27357700E+03, -.13162500E+03, 0.62334100E+02, 0.56387200E+02, 0.65766800E+02, 0.26239800E+03, -.33012200E+01, 0.16508600E+03, 0.87587800E+02, 0.17387400E+03, -.17408600E+01, 0.28453000E+02, 0.23221500E+04, -.11633400E+04, -.21628400E+04, -.11601300E+04, -.13529900E+04, 0.37615400E+03, -.17262800E+04, -.40466200E+03, -.11452000E+04, 0.30420700E+03, 0.55417400E+03, -.13701200E+04, 0.67516600E+03, 0.10451600E+04, 0.68594100E+03, -.74024500E+03, -.26533700E+02, 0.41680200E+03, -.67523600E+03, 0.15818600E+03, -.68241700E+02, -.11725600E+03, -.14295800E+03, 0.76561400E+02, -.32370100E+02, 0.71422200E+02, -.43215800E+03, -.70501300E+02, -.12615000E+03, 0.18419900E+02, -.30025400E+01, -.15166000E+03, 0.71062200E+03, -.29104200E+04, 0.14443100E+04, 0.14374400E+04, 0.14553300E+04, 0.21930700E+04, -.78803100E+03, 0.14484400E+04, 0.11336400E+04, 0.16304100E+04, -.78669900E+03, 0.28667500E+03, 0.21299800E+04, -.10518500E+04, -.80130900E+03, -.10644800E+04, -.58208800E+03, 0.11515400E+03, -.82922800E+03, -.16545300E+03, -.98745400E+03, 0.96970100E+02, -.72908500E+03, 0.42009200E+02, -.41567500E+02, 0.14283800E+03, -.22163400E+02, 0.12444900E+03, 0.12091600E+03, 0.29558100E+03, 0.35646800E+03, 0.10553600E+03, 0.77036500E+01, 0.15098000E+03, -.14289500E+03, 0.61424800E+02, 0.56679200E+03, 0.72286500E+02, 0.90084100E+03, -.16958000E+03, 0.76776100E+03, 0.48066600E+03, 0.74476100E+03, 0.10132000E+03, -.60180500E+03, -.10103800E+04, 0.55022800E+03, 0.11743200E+04, 0.50463700E+03, -.38443200E+03, -.14778100E+03, 0.12706600E+03, -.63575400E+03, 0.13651100E+03, 0.27162000E+02, -.37631100E+01, -.40517900E+03, 0.20001300E+03, 0.20418300E+03, 0.20249700E+03, 0.19456100E+03, -.14930200E+03, 0.26485700E+03, 0.17794100E+03, 0.41148400E+03, -.13418200E+03, 0.28896900E+03, -.66552200E+03, 0.32945700E+03, 0.72665200E+03, 0.33299700E+03, 0.10460700E+04, 0.67950900E+02, 0.59462500E+03, 0.88144100E+03, 0.15779300E+04, 0.99494400E+02, -.12645000E+03, 0.12107100E+04, -.59785800E+03, -.41574700E+03, -.60450100E+03, 0.75201400E+02, 0.17412500E+04, -.18836400E+04, -.47627000E+03, -.10911900E+04, 0.14540000E+04, -.53834200E+03, -.27903900E+03, 0.14299100E+03, 0.96727400E+02, 0.14011100E+03, -.36261600E+02, -.11957500E+04, 0.14347600E+04, 0.12714800E+04, 0.18417800E+04, -.10591500E+04, -.51549700E+02, 0.19141800E+04, -.96623100E+03, -.10647300E+04, -.95726600E+03, -.60664300E+03, -.19334400E+03, -.16402900E+04, -.80115000E+03, -.10631200E+04, 0.13072100E+03, -.61918800E+03, -.14021400E+03, 0.66443000E+02, 0.73104200E+02, 0.70065000E+02, 0.27040200E+03, -.33949200E+01, 0.19113600E+03, 0.11439600E+03, 0.19288900E+03, -.45902100E+01, 0.25690800E+02, 0.56047600E+03, -.31199800E+03, 0.41117400E+02, -.27947000E+03, -.94029900E+02, 0.76922400E+02, -.30477600E+03, -.20765200E+03, -.22844000E+03, 0.74975800E+02, -.13038700E+03, 0.41716700E+04, -.20746300E+04, -.20007500E+04, -.20860100E+04, -.28825500E+04, -.20643900E+03, -.92961400E+03, -.60353100E+03, -.16747500E+04, -.31842500E+03, -.49000700E+03, -.40854900E+04, 0.20272700E+04, 0.15563200E+04, 0.20429300E+04, 0.23340900E+04, 0.40346500E+03, 0.44123300E+03, -.26676100E+03, 0.15837900E+04, 0.56438100E+03, 0.90365600E+03, 0.12201200E+03, -.30356400E+03, 0.50863300E+03, -.14162800E+03, 0.26850800E+03, 0.33650400E+02, -.69364300E+03, -.28062900E+03, -.23534000E+02, 0.79020900E+02, 0.20299200E+03, 0.48257900E+02, 0.10933600E+03, -.17153900E+03, -.29994800E+03, 0.14344800E+03, -.52381000E+03, -.60500500E+02, -.82934700E+03, 0.24845000E+03, 0.76136800E+03, 0.93223300E+02, 0.29399300E+02, 0.49044900E+03, 0.35461700E+03, 0.25762300E+03 },
        { -.11309800E+00, -.71371300E-01, -.80656900E+00, -.32717800E-01, 0.26686300E+00, -.17424800E+00, -.12306500E+01, 0.19152500E+00, -.10862400E+00, -.75903700E-01, 0.37933300E-01, -.54647100E+00, 0.10618300E+00, 0.18025300E-01, 0.96960800E-01, 0.17543800E-01, 0.23825700E-01, -.57493100E-02, 0.96826400E-03, -.17389300E-01, 0.13240400E+00, -.29514900E+00, 0.56467800E-01, 0.75584000E-01, -.34423400E-01, -.57435100E-01, -.22552500E-01, 0.64353400E-01, 0.95632300E-01, 0.19328600E+00, 0.25682100E-01, 0.89110100E-01, -.71098100E-01, -.26131000E+00, -.13977800E+00, 0.83019800E-01, -.82843300E-02, -.41835400E+00, 0.98471700E-01, 0.13468700E+00, -.15079200E+00, 0.97030200E+00, 0.10580200E+01, 0.12669400E+00, -.18232600E+00, 0.17932800E+00, 0.66082800E+00, -.28922800E-01, -.94447000E-01, 0.18311600E+00, 0.10874000E+00, -.66936700E-02, -.49054200E+00, 0.54888400E+00, -.10340100E+00, -.27675200E+04, 0.13737100E+04, 0.57421600E+03, 0.13824600E+04, 0.50470800E+03, 0.22704000E+03, 0.10981800E+04, 0.21267800E+03, 0.33206200E+03, 0.35518800E+03, 0.18868700E+04, 0.45986600E+03, -.22490800E+03, 0.52747400E+03, -.23029000E+03, 0.63552900E+02, -.12356300E+02, 0.22234800E+03, 0.98524900E+02, -.63656900E+03, 0.93480400E+02, -.10055900E+03, 0.38659800E+02, -.19108200E+02, 0.62045800E+02, -.19247600E+02, 0.26182900E+02, 0.45286400E+02, -.95795700E+01, 0.38858800E+02, 0.67488100E+02, 0.29890700E+02, -.94310300E+01, -.10931100E+04, 0.56034400E+03, -.21214600E+03, 0.54478700E+03, -.12482400E+02, -.32496500E+03, 0.85642900E+03, -.21046400E+03, -.69472900E+03, -.11901100E+03, 0.71426500E+03, 0.17222100E+04, -.85120500E+03, -.27620500E+03, -.86258100E+03, -.26011800E+03, -.32431800E+03, 0.18206500E+02, 0.27102100E+03, -.91185600E+03, -.22365700E+03, -.94509700E+03, 0.32764000E+03, -.16376600E+03, -.16133100E+03, -.16375200E+03, -.73990100E+02, 0.66780800E+02, -.17091100E+03, -.12732900E+03, -.15263600E+03, 0.33342900E+02, -.31718400E+03, -.17050000E+04, 0.84588600E+03, 0.24168800E+04, 0.85228500E+03, 0.11417500E+03, 0.74650800E+03, 0.19083600E+03, 0.26432900E+03, 0.11931500E+04, 0.69067900E+03, 0.96321700E+03, -.44772600E+03, 0.21329300E+03, -.87232800E+02, 0.22296700E+03, -.10617900E+03, 0.13103300E+03, -.29394800E+03, -.60798200E+03, -.73961000E+02, 0.12244500E+03, 0.19328100E+03, 0.76686600E+03, -.40299400E+03, -.43834700E+03, -.38104400E+03, -.94212300E+02, -.14955700E+03, -.33123700E+02, 0.30965800E+03, 0.11333100E+03, -.16230100E+03, -.29287200E+03, 0.96232100E+03, -.46683500E+03, -.46953300E+03, -.48246300E+03, 0.80237100E+03, 0.28912300E+03, 0.36213100E+03, 0.58612200E+03, -.37792500E+03, 0.28702300E+03, -.27279900E+03, -.91936600E+02, 0.48930100E+02, -.22832600E+03, 0.46958600E+02, 0.31451300E+02, -.19753200E+03, -.13469900E+03, -.22720900E+03, -.75226600E+02, -.18641100E+03, -.91144400E+02, -.16793600E+03, 0.84299500E+02, 0.72986100E+02, 0.84133600E+02, 0.32776200E+02, 0.79216700E+02, -.82865700E+02, -.62374000E+02, 0.19117800E+03, 0.46098400E+02, 0.10158000E+03, -.23714300E+04, 0.11846100E+04, 0.15598600E+04, 0.11853600E+04, 0.45098700E+03, 0.92116500E+03, 0.10843000E+03, -.53465700E+03, 0.31206500E+03, 0.10277600E+04, 0.15252700E+04, -.14306500E+04, 0.72351300E+03, 0.36003300E+03, 0.71383000E+03, 0.28423400E+03, -.17973300E+02, 0.99828300E+03, 0.35448200E+03, -.45081400E+03, 0.20786700E+03, 0.13759700E+04, -.30735100E+04, 0.15305700E+04, 0.15889200E+04, 0.15358600E+04, 0.36902600E+03, 0.51790100E+03, 0.27745800E+03, -.77739700E+03, 0.48476100E+03, 0.73453700E+03, 0.19333900E+04, 0.11290500E+04, -.56230700E+03, 0.16548200E+03, -.56529600E+03, -.34649300E+03, -.34345500E+03, 0.39567600E+03, 0.82501500E+02, -.11937800E+04, -.97372400E+02, -.67057900E+03, 0.52379200E+02, -.25871800E+02, 0.65582200E+02, -.26113600E+02, 0.33523500E+02, 0.51830900E+02, -.90664400E+01, 0.41071600E+02, 0.72585400E+02, 0.40709600E+02, -.13678400E+02, 0.33529100E+03, -.18483000E+03, -.27360900E+03, -.16896800E+03, 0.38120300E+02, -.10020800E+03, -.30392500E+02, 0.33545400E+01, -.85416600E+02, -.91462200E+02, -.26717900E+03, 0.43011200E+04, -.21518100E+04, -.22497800E+04, -.21502800E+04, -.11115900E+04, -.11618800E+04, -.79691900E+03, -.39250800E+02, -.12617500E+04, -.11736900E+04, -.20970600E+04, -.30710300E+04, 0.15457800E+04, 0.11802500E+04, 0.15352100E+04, 0.76072500E+03, 0.49287500E+03, 0.85697800E+03, -.27315900E+03, 0.57395700E+03, 0.62608700E+03, 0.12491800E+04, -.34766200E+02, -.46558100E+02, 0.98210900E+02, -.46771800E+02, 0.12145900E+03, -.52300400E+02, 0.20787200E+03, 0.37400900E+02, -.70833300E+01, -.13507200E+03, -.98846700E+02, 0.16416000E+03, -.30104200E+02, -.47538000E+00, -.98425700E+02, 0.48000600E+02, -.18650300E+02, -.32587000E+02, -.68560800E+02, -.18689200E+03, 0.14117100E+03, 0.11135700E+02, -.99358700E+01, 0.11684800E+03, 0.49645500E+02, -.10437400E+03 },
        { 0.15002600E+00, -.87116800E+00, 0.53711400E+00, 0.12272100E+00, -.32268600E+00, -.24443600E+00, -.56428300E+00, 0.11039000E+01, 0.17482000E+00, -.17196700E-02, -.41648000E-01, -.71376100E+00, -.43933400E+00, -.47094600E+00, 0.68755700E+00, 0.79853500E+00, -.41305600E+00, -.21246000E+00, 0.21982800E+00, 0.22924900E-01, -.40623700E+00, 0.26916800E-01, -.12237200E+00, 0.17264500E-01, 0.25715000E+00, 0.24971000E+00, 0.62918100E+00, -.51968100E+00, -.11261300E-01, -.10050000E+00, -.35950200E+00, 0.78532500E-01, 0.73132300E+00, -.44992600E-01, -.20759500E-01, 0.29115400E+00, -.29169400E-02, 0.78626000E+00, -.12952900E+00, 0.47691300E+00, -.31565300E+00, 0.64689000E-01, 0.14776300E+01, -.73409700E-01, 0.70765600E+00, 0.24301200E+00, 0.97203400E+00, 0.67775200E-01, 0.41265800E+00, -.16909800E+00, 0.88041200E+00, -.56709800E+00, -.35689800E-01, 0.25872300E+00, -.42686600E+00, 0.15655600E-01, 0.89264300E+02, 0.30646600E+03, 0.65153300E+00, -.51625900E+03, -.85028700E+03, 0.67474000E+03, 0.10836000E+04, 0.97166600E+03, -.58611300E+03, -.12413300E+03, -.29122800E+04, 0.14501300E+04, 0.11743400E+04, 0.14563300E+04, 0.27681700E+03, 0.52560400E+03, 0.38889300E+03, -.19431800E+03, 0.10103600E+04, 0.41484400E+03, 0.12633900E+04, -.33813800E+03, 0.17310300E+03, 0.16259400E+03, 0.16902500E+03, -.47855000E+02, 0.16810300E+03, 0.40616500E+02, 0.14500600E+02, 0.89724000E+02, 0.15246600E+03, 0.18306600E+03, -.62125600E+03, 0.28696100E+03, 0.32255600E+03, 0.31155700E+03, -.37702500E+03, -.20491800E+04, 0.88541800E+03, 0.93646300E+03, 0.17542700E+04, -.18776300E+04, -.15760700E+03, 0.25567700E+04, -.12986200E+04, -.15666800E+04, -.12775600E+04, 0.25778100E+03, 0.57969000E+03, -.10966000E+04, -.35154600E+03, -.67432300E+03, 0.43380200E+03, -.75998800E+03, 0.14006300E+04, -.71374200E+03, -.60729000E+03, -.70036100E+03, 0.23517600E+03, 0.26349300E+03, -.45008500E+03, -.41922800E+02, -.50911400E+03, 0.20084300E+03, -.70844300E+03, -.47191100E+04, 0.23512000E+04, 0.23696100E+04, 0.23596700E+04, -.30525200E+03, 0.12199400E+04, 0.97892000E+03, -.38627200E+03, 0.13141700E+04, 0.10973900E+04, 0.26284800E+04, 0.91477000E+03, -.44810500E+03, -.36090800E+03, -.45689700E+03, -.15784300E+03, -.50056600E+03, 0.78845100E+02, -.11830300E+03, -.33130900E+03, -.44786200E+03, -.32930600E+03, -.15209800E+03, 0.14449600E+03, 0.57240900E+02, 0.74855000E+02, 0.29796100E+03, 0.65185700E+03, -.79473900E+03, -.96758000E+03, -.44372600E+03, 0.63599100E+03, -.72377400E+01, 0.10428100E+03, -.32473900E+02, 0.17132200E+03, -.51380600E+02, 0.46089400E+03, 0.68527600E+03, 0.28295400E+03, 0.16479500E+04, 0.81654000E+03, 0.51100900E+03, -.10048100E+04, 0.39237900E+03, -.29199600E+03, -.46104100E+03, -.19672500E+03, 0.33059300E+03, -.45929300E+03, -.20091200E+03, -.62141000E+03, -.13298700E+03, -.47262000E+03, -.30747000E+03, -.16415400E+03, 0.78894800E+02, 0.12395800E+03, 0.81987500E+02, -.10590600E+03, 0.39680400E+02, 0.37049900E+02, -.46815000E+02, 0.10634100E+03, 0.56080400E+02, 0.13343800E+03, 0.27026900E+02, -.75604900E+01, 0.34124500E+02, -.13303300E+02, -.46261500E+03, 0.29012400E+02, 0.49566600E+03, 0.11657800E+04, 0.12687300E+04, 0.66803600E+02, 0.77670900E+03, 0.15561300E+04, -.77946400E+03, -.91907400E+03, -.77724700E+03, -.33067400E+03, -.79427000E+03, -.91362900E+02, 0.72359700E+03, 0.23070600E+03, -.53405500E+03, -.81403300E+03, -.17860500E+03, 0.96289700E+02, -.81638200E+01, 0.89832200E+02, -.11244700E+04, -.48838300E+03, 0.77268400E+03, 0.12937800E+04, 0.18443700E+04, -.37533600E+03, 0.10437300E+04, 0.36316300E+03, -.16008800E+03, -.25678700E+03, -.18127200E+03, -.34060000E+03, -.84156300E+03, 0.34307800E+03, 0.11432400E+04, 0.91351700E+03, -.94042000E+03, -.25109200E+03, -.42199500E+03, 0.21566800E+03, 0.19765100E+03, 0.21095700E+03, -.41246000E+02, 0.16917200E+03, 0.68270400E+02, 0.34388800E+02, 0.12397900E+03, 0.15895400E+03, 0.20707400E+03, 0.10769500E+04, -.43288500E+03, -.50047800E+03, -.53774600E+03, 0.18446300E+03, 0.86194600E+02, -.60089700E+03, -.68572300E+03, -.47146300E+03, 0.21794800E+02, -.47856900E+03, 0.62402500E+04, -.31369200E+04, -.37229500E+04, -.31202800E+04, 0.94656500E+02, -.12483800E+04, -.14575200E+04, -.13880700E+03, -.23348300E+04, -.97495800E+03, -.30968100E+04, -.70038700E+04, 0.35117900E+04, 0.40379200E+04, 0.35021100E+04, 0.17870400E+03, 0.82420800E+03, 0.15785500E+04, -.26342300E+03, 0.24508100E+04, 0.67123100E+03, 0.33529300E+04, 0.32641200E+03, 0.27440100E+02, -.77678700E+02, -.26218900E+03, -.11519200E+03, 0.70140100E+02, 0.39205900E+03, -.14674400E+02, -.25227300E+02, -.40823600E+03, 0.27425600E+02, 0.62728900E+03, -.85846700E+02, 0.10650400E+03, 0.28494200E+03, 0.34802300E+03, 0.11262600E+03, -.59471900E+02, -.74282300E+03, -.32751400E+03, 0.61158600E+03, 0.32589500E+03, 0.19109700E+02, 0.21922900E+02, 0.98053400E+02, 0.10821200E+03 },
        { 0.15209800E+00, -.30633200E+00, 0.91518200E+00, 0.10615400E+00, -.81590500E+00, -.16197400E+00, -.17586900E+01, -.82834700E+00, -.18157300E+00, -.11514200E+00, -.58212200E-01, 0.14571400E+01, -.22720100E+00, 0.67548400E+00, 0.51503600E+00, 0.13689600E-01, 0.15420800E+01, -.43364600E-01, 0.12468000E+01, -.15100200E+00, 0.60725800E+00, 0.15395600E+01, -.82276700E-01, 0.10093800E+00, 0.42841800E+00, -.14068200E-01, 0.23797500E-02, -.17667200E+00, 0.89405600E-01, -.26671300E+00, -.45483600E+00, -.33570200E+00, -.13698800E+00, 0.26855700E+00, 0.13425400E+00, -.11839400E+00, -.70989000E-01, -.12043900E+00, -.19040300E+00, -.44962400E-01, 0.14494200E-01, -.10089100E+01, -.11138000E+01, 0.36235700E-01, 0.13981300E-01, -.18687600E-01, 0.34063900E+00, -.76305800E-01, -.54164000E-01, 0.12323500E+00, -.54185800E+00, 0.69510400E+00, 0.61787300E+00, 0.24502500E+00, -.23665100E+00, 0.39158300E+00, -.27069500E+00, 0.11337800E+04, -.34425800E+00, -.27371800E+03, -.69181100E+03, -.13750600E+03, -.14423800E+03, 0.29139100E+03, -.60543400E+03, -.54091900E+03, 0.11422600E+04, -.57945100E+03, -.64734600E+03, -.57124100E+03, 0.40984400E+01, -.17570200E+02, -.27353100E+03, 0.44740200E+03, -.49730500E+02, -.59944400E+02, -.50510200E+03, -.28765300E+02, 0.13907800E+02, -.42840000E+02, 0.14407400E+02, -.96481700E+02, -.56584300E+02, 0.10988700E+03, 0.17117300E+03, 0.70606900E+02, -.64409600E+02, 0.20634000E+02, -.46665500E+03, 0.23315800E+03, 0.12021600E+04, 0.23281700E+03, -.21672100E+03, -.20243900E+03, -.45325500E+03, -.92500300E+03, 0.43294700E+03, -.12533300E+03, -.38982400E+03, 0.18368400E+03, -.97334200E+02, -.49008900E+03, -.92316400E+02, 0.45103100E+03, 0.15958000E+03, -.40289400E+03, -.38983600E+03, -.83276700E+02, 0.51595400E+02, 0.32550500E+02, 0.31581400E+03, -.15597500E+03, -.16000300E+03, -.15787700E+03, 0.15980200E+03, 0.13974900E+03, -.20251700E+03, -.29106600E+03, -.27180100E+03, 0.17752500E+03, -.19774500E+03, 0.70756500E+02, -.18013000E+02, -.93246300E+03, -.35444200E+02, -.86996400E+02, -.10069200E+03, 0.23849100E+03, 0.48689600E+03, -.18087100E+03, -.15949100E+03, 0.27820600E+03, 0.20912900E+03, -.10747500E+03, 0.52336800E+02, -.10483900E+03, 0.67508200E+02, 0.30247900E+02, -.28646900E+02, -.14990000E+03, -.24575200E+03, 0.22120300E+02, -.77157600E+02, -.20919600E+03, 0.11606400E+03, 0.21908600E+03, 0.10522900E+03, 0.11085500E+03, -.26810900E+03, 0.22242500E+03, 0.17870000E+03, -.46460700E+02, -.19789600E+03, -.21784300E+03, 0.66880900E+03, -.35824800E+03, 0.19783500E+03, -.33485300E+03, -.79109900E+03, 0.20200300E+03, -.49695300E+02, 0.19100300E+03, 0.25420000E+03, 0.22537300E+03, -.84860500E+03, 0.19084600E+03, -.12070700E+03, -.64649700E+02, -.95124700E+02, 0.36861900E+03, 0.95333800E+02, -.24249400E+03, -.48140300E+03, -.37328400E+03, 0.13709300E+03, 0.50807200E+02, 0.17718700E+03, -.84425900E+02, -.11314900E+03, -.88543500E+02, -.48258100E+02, -.58997100E+02, 0.99580600E+02, 0.10946100E+03, -.13355100E+03, -.37681800E+02, -.60463500E+02, 0.42559300E+04, -.21267400E+04, -.24285800E+04, -.21280900E+04, -.36258200E+03, -.21655700E+03, -.58570100E+03, 0.11705800E+04, -.12088200E+04, -.22070100E+03, -.18029400E+04, -.18250200E+04, 0.89473600E+03, 0.14560500E+04, 0.91204600E+03, 0.23523900E+03, -.32346000E+03, -.43523100E+03, -.10579800E+04, 0.43679000E+03, -.23606600E+03, 0.18043200E+03, 0.49047800E+04, -.24441700E+04, -.23113500E+04, -.24527100E+04, -.12884400E+03, 0.40938900E+02, -.70577500E+03, 0.12884600E+04, -.15721300E+04, -.11056700E+02, -.21136100E+04, -.78832000E+03, 0.38520900E+03, -.38781700E+03, 0.39435700E+03, 0.41047600E+02, 0.10028200E+04, -.91150400E+03, -.14868200E+04, 0.35044300E+03, 0.83399300E+03, 0.41147700E+03, -.16645700E+02, 0.74376400E+01, -.48740600E+02, 0.83454500E+01, -.10818100E+03, -.53597400E+02, 0.11286900E+03, 0.17191900E+03, 0.68864100E+02, -.60955200E+02, 0.94750300E+01, -.30427800E+02, 0.20909900E+02, 0.49321600E+02, 0.14800300E+02, 0.15342600E+03, -.48604500E+02, -.12926800E+03, -.49175200E+03, -.17659700E+03, -.84997300E+01, -.31781200E+02, -.18715300E+04, 0.95222500E+03, 0.84441300E+03, 0.93585600E+03, 0.87264700E+03, 0.82063800E+02, 0.20133000E+03, -.86707000E+03, 0.41394600E+03, 0.20472400E+03, 0.65079100E+03, 0.30958700E+04, -.15752500E+04, -.14744700E+04, -.15480400E+04, -.76403500E+03, -.90713800E+02, -.44515600E+03, 0.99865800E+03, -.33416400E+03, -.24539300E+03, -.11770100E+04, 0.26705700E+02, -.15578300E+02, -.13974600E+03, 0.58979100E+01, -.91773500E+02, 0.50823200E+02, -.42619700E+02, -.50185700E+02, 0.10676500E+02, 0.48465000E+02, 0.51618300E+02, 0.11854100E+03, 0.33310100E+03, 0.76293100E+02, 0.15070100E+03, 0.52444500E+02, 0.29810400E+03, -.11377600E+02, 0.16804000E+03, 0.25507800E+03, -.22028900E+03, -.14791000E+03, 0.31346400E+02, -.70782200E+02, 0.23150500E+03, 0.16791000E+03 },
        { -.32517700E+00, 0.39798000E+00, -.22382400E+01, 0.27824800E-01, 0.21525900E+01, 0.21701000E+00, 0.30384200E+01, 0.31333700E+00, -.56341100E-01, 0.31231600E+00, 0.85215300E-01, -.27871800E+01, 0.53508600E+00, -.68142400E+00, 0.18364800E+01, 0.53377200E-01, -.28613500E+01, 0.31581300E+00, -.86914400E+00, 0.11281900E+01, -.11321900E+01, -.38648000E+01, 0.26385800E+00, -.74792700E+00, -.60926900E+00, -.11171100E-01, -.18166500E+01, 0.59681900E+00, -.23888500E-01, 0.10567000E+01, 0.70431300E+00, 0.76300200E+00, -.11566800E+01, -.97233800E-01, 0.23385500E+00, -.59520000E+00, -.12611000E+00, 0.82926200E-01, 0.12907000E+01, 0.42626700E-01, 0.80208600E+00, 0.27327000E+01, 0.87592900E+00, 0.37121700E+00, 0.47539200E+00, 0.71708500E+00, 0.10855900E+01, -.30987000E+00, 0.24173800E-01, 0.36798600E+00, 0.12802800E+01, -.17968100E+01, -.13270900E+01, 0.24184700E+01, 0.12268300E+01, 0.21358300E+00, 0.15891300E+00, -.12443800E+01, -.89916300E+01, -.53778400E+02, 0.87532400E+03, -.10523000E+04, -.15677800E+04, -.99851000E+03, 0.64522800E+03, 0.13041600E+04, -.12416300E+03, 0.65257800E+02, -.51680200E+03, 0.59425400E+02, 0.32538500E+03, 0.33716300E+03, -.46349200E+03, -.59193500E+03, -.62919600E+03, 0.26331700E+03, 0.43130000E+03, 0.46792600E+03, -.22530400E+03, -.37964500E+03, -.23336000E+03, 0.21763500E+03, -.64867800E+01, -.45055400E+02, 0.12181000E+03, -.71505900E+02, -.26539000E+02, -.27443700E+03, -.17136600E+03, 0.11490600E+02, 0.41130700E+03, 0.72958500E+02, -.46692700E+03, 0.11117700E+04, -.13127400E+04, -.27627300E+04, -.14846400E+04, 0.11055600E+04, 0.80619200E+03, -.47851000E+04, 0.23852400E+04, 0.18131400E+04, 0.23813100E+04, -.18307800E+03, -.94633900E+02, 0.73819100E+03, -.59877300E+03, 0.14335800E+04, -.57870000E+02, 0.15785700E+04, -.13804200E+04, 0.67427400E+03, 0.90195500E+03, 0.69082500E+03, -.25406100E+03, -.19705400E+03, 0.19476100E+03, -.37348300E+03, 0.26324100E+03, -.10298300E+03, 0.23341000E+02, 0.55908600E+04, -.27595200E+04, -.48741700E+04, -.27970300E+04, 0.50399500E+03, -.75075500E+03, -.66470100E+03, 0.11625300E+04, -.19887500E+04, -.73852800E+03, -.19883000E+04, 0.10760400E+04, -.52326200E+03, 0.48952600E+03, -.54469600E+03, 0.11843000E+03, 0.47692900E+03, -.78353900E+02, 0.45649600E+03, -.48887500E+03, 0.42354800E+03, -.53277100E+03, -.77234100E+03, 0.40714200E+03, 0.91472200E+03, 0.40610500E+03, 0.14032900E+03, -.18656500E+03, 0.28607200E+03, 0.58288400E+03, 0.37315300E+03, -.19414700E+03, -.80947200E+02, 0.24101400E+03, -.13231800E+03, -.59242700E+03, -.13078000E+03, 0.35387100E+02, 0.65461900E+03, -.81392200E+03, -.19466600E+04, 0.10098500E+03, 0.55537300E+03, 0.27684700E+03, -.25226200E+04, 0.12297600E+04, 0.22300700E+04, 0.12686600E+04, -.11632500E+04, -.83109700E+03, 0.10251800E+04, 0.78220600E+02, 0.94163300E+03, -.59377100E+03, 0.11631200E+04, 0.39163700E+03, -.19616200E+03, -.16928800E+03, -.19460000E+03, 0.60219700E+02, -.11799800E+03, 0.87861600E+02, 0.22335500E+03, -.40230000E+01, -.12035500E+03, -.15941200E+03, -.83174500E+03, 0.42692800E+03, 0.32794000E+03, 0.41304100E+03, 0.23090300E+03, 0.28365400E+03, -.78953200E+02, -.20392500E+03, -.92105400E+03, 0.65386800E+02, 0.12152200E+04, -.51603500E+04, 0.25374000E+04, 0.22678600E+04, 0.25689700E+04, 0.78989400E+02, 0.98774900E+03, -.39130400E+03, -.17840800E+04, 0.31334800E+03, 0.77273900E+03, 0.37632400E+04, -.11493600E+04, 0.58286900E+03, -.43073400E+03, 0.56754100E+03, 0.71904400E+03, 0.75301200E+03, -.14630800E+03, -.35546100E+03, -.91351800E+03, 0.41045200E+03, 0.14133300E+04, -.41473800E+03, 0.20734400E+03, -.13834200E+04, 0.20386800E+03, 0.37068500E+03, 0.13704300E+04, -.14694200E+04, -.32299300E+04, -.11031900E+04, 0.13559500E+04, 0.38705500E+03, 0.52294700E+03, -.25236000E+03, -.44046200E+03, -.26092000E+03, 0.19667100E+03, -.47733700E+01, -.64940000E+02, 0.94721300E+02, -.77586700E+02, -.28319200E+02, -.30116800E+03, -.89234900E+03, 0.45384900E+03, 0.86218200E+03, 0.43625300E+03, -.32831300E+03, -.18924400E+03, 0.43354200E+03, 0.12344200E+03, 0.47325700E+03, -.10684900E+03, 0.35419900E+03, -.83348600E+04, 0.41255200E+04, 0.39910800E+04, 0.41695700E+04, -.53865100E+03, 0.20614700E+03, 0.17066600E+04, -.69878500E+03, 0.37025000E+04, 0.19261900E+03, 0.36203800E+04, 0.61370800E+04, -.30431100E+04, -.22913500E+04, -.30709000E+04, 0.63340000E+03, -.11666000E+03, -.13260900E+04, -.24198300E+03, -.27123500E+04, -.12805300E+03, -.30459600E+04, -.40413800E+03, 0.32456300E+03, 0.36342700E+03, 0.48887500E+03, 0.30110600E+03, -.27896800E+03, -.10814000E+04, 0.40711500E+03, -.25115200E+02, 0.51520800E+03, -.11669300E+03, -.11357600E+03, 0.41260400E+03, -.51618800E+03, -.26911000E+03, -.46809500E+03, -.20662900E+03, 0.21215500E+03, 0.41784900E+03, 0.70239400E+03, -.55820400E+03, -.45566300E+03, -.85710500E+02, 0.26875100E+03, -.10861500E+03, -.29432500E+03 },
        { -.12609200E+00, -.37412400E+00, 0.13806800E+00, -.31085200E+00, 0.58774400E+00, -.80682600E-01, 0.46158400E+00, -.54338400E+00, -.25218000E+00, 0.28846800E-01, 0.96443600E-01, 0.79422400E-01, -.14878300E+00, -.69259300E-01, -.91761000E+00, -.46131900E+00, -.30741800E+00, 0.43101100E-01, 0.57298300E+00, -.16689700E+00, 0.21704900E+00, 0.15753000E+01, -.10362800E+00, -.21688600E+00, 0.36572500E+00, -.11238000E+00, 0.50385100E-02, -.63310600E+00, 0.36626000E-01, 0.70975800E-01, -.60324200E+00, -.11494300E+00, 0.34902600E+00, -.44645900E+00, 0.64622500E-02, 0.36404500E+00, -.15029400E-01, -.11287200E-01, -.45225000E+00, 0.22025900E+00, 0.38085700E+00, 0.19864900E+01, 0.16387400E+01, 0.17631500E+00, -.91277400E+00, 0.20461900E-01, -.10755600E+00, -.27444700E-01, -.24910100E+00, 0.21744700E-01, -.60998400E+00, 0.10272600E+00, -.51585900E+00, 0.12999900E+01, 0.56643400E+00, 0.13719600E+00, -.38413800E-01, -.15427500E+00, 0.64797800E-01, 0.72064900E+03, -.90616600E+03, 0.31070500E+02, 0.51043100E+02, -.58799600E+02, -.65784000E+03, -.93517700E+03, 0.33568200E+02, -.18852900E+02, -.89695800E+03, -.16796600E+02, -.26039500E+03, -.43243200E+03, 0.20676700E+03, 0.43851300E+03, 0.52163800E+03, -.45159600E+03, -.39154000E+03, -.61967800E+02, 0.27610100E+02, 0.14904700E+03, 0.30986600E+02, -.74853000E+02, 0.11640100E+03, -.57963700E+02, -.99170900E+02, -.11564800E+03, 0.86502000E+02, 0.24524000E+02, -.13400800E+04, 0.71845000E+03, 0.55671700E+03, 0.67000200E+03, 0.73209900E+03, -.13359200E+04, 0.10622100E+04, 0.14351300E+04, 0.10353600E+04, -.11900000E+04, 0.22475800E+03, 0.16293500E+04, -.80677500E+03, -.99861000E+03, -.81475000E+03, 0.38902000E+03, 0.41306600E+03, -.38351800E+03, 0.43696600E+03, -.35099300E+03, 0.33215300E+03, -.39982600E+03, 0.14584800E+04, -.72056400E+03, -.96025500E+03, -.72923000E+03, 0.16362600E+03, 0.21596900E+03, -.21052000E+03, 0.26466500E+03, -.31594600E+03, 0.17610700E+03, -.38972000E+03, -.36720600E+02, 0.17396800E+02, 0.56892600E+03, 0.18351900E+02, -.10731800E+02, 0.78042200E+03, -.40256900E+03, -.68086500E+03, -.23888800E+03, 0.58983600E+03, -.86492400E+03, -.14416900E+04, 0.70204700E+03, -.23990200E+03, 0.72081100E+03, -.51458100E+02, -.50401600E+03, 0.40867200E+03, -.59785300E+02, 0.66126100E+03, -.36349100E+03, 0.57851600E+03, -.45698500E+03, 0.19271200E+03, -.21994400E+02, 0.22826600E+03, -.23974900E+03, -.53720500E+03, 0.54242800E+03, 0.26998100E+03, 0.45770400E+03, -.48474900E+03, 0.37689800E+03, 0.14413900E+03, -.77605100E+02, 0.33685300E+03, -.72162100E+02, -.47328300E+03, 0.11147500E+03, -.17936800E+03, 0.55482000E+03, -.80224700E+03, -.18882900E+02, 0.55182000E+02, 0.82223700E+03, -.42939300E+03, -.13561800E+04, -.41108700E+03, -.12863800E+03, -.20027900E+02, -.58427200E+02, 0.73536100E+03, 0.31148800E+03, -.43152200E+02, -.15640900E+03, -.35449400E+03, 0.18172200E+03, 0.20825700E+03, 0.17725300E+03, -.76686000E+02, 0.65089500E+02, -.30641100E+02, -.26664300E+03, -.16171400E+03, 0.76349700E+02, 0.13264100E+03, 0.42823100E+04, -.21456400E+04, -.13437200E+04, -.21411900E+04, -.60694100E+03, -.71464600E+03, -.57311400E+03, -.26850800E+03, -.15772300E+04, -.50414400E+03, -.27621100E+04, 0.21732900E+04, -.10790400E+04, -.63650100E+03, -.10867100E+04, 0.22617400E+03, -.13802000E+04, 0.11998400E+03, 0.25829500E+03, -.48630800E+03, -.93314000E+03, -.20708700E+04, 0.30061500E+04, -.15062300E+04, -.14341300E+04, -.15031500E+04, -.46210500E+03, -.30638000E+03, -.70924200E+03, -.60555300E+03, -.13934000E+04, -.15394900E+03, -.22003000E+04, 0.28985800E+03, -.13766900E+03, 0.17508800E+04, -.14500100E+03, 0.17849900E+03, 0.46006600E+02, 0.28209000E+03, 0.82440600E+03, -.62207800E+03, 0.24313700E+02, -.11437700E+03, -.56212000E+02, 0.24292400E+02, 0.17128400E+03, 0.28108300E+02, -.66898400E+02, 0.12683000E+03, -.72727500E+02, -.10240800E+03, -.13893400E+03, 0.94784200E+02, 0.29565900E+02, -.60136100E+03, 0.30225300E+03, -.12444400E+03, 0.30062400E+03, -.89591100E+02, -.38968000E+03, 0.43935200E+03, 0.64816000E+03, 0.50360700E+03, -.31059100E+03, 0.24069700E+03, -.71082300E+03, 0.38148800E+03, 0.15310300E+03, 0.35542800E+03, 0.78933900E+03, 0.76026200E+03, -.10929100E+03, -.50721400E+02, -.38378600E+03, 0.85839200E+03, 0.11170500E+04, 0.16862300E+04, -.86396700E+03, -.38487600E+03, -.84313000E+03, -.11235600E+04, -.13917600E+04, 0.17319200E+03, 0.11015500E+04, 0.99109400E+01, -.13262500E+04, -.14815300E+04, 0.22294100E+02, 0.91130600E+02, -.11273200E+03, -.12946500E+03, -.12707200E+03, 0.94608500E+02, 0.96736700E+03, 0.12391400E+02, 0.41605900E+02, -.34590400E+03, -.65940600E+02, 0.69669900E+02, -.37120400E+03, 0.18269400E+03, 0.29163200E+01, 0.64328600E+02, -.10154600E+03, 0.92016100E+01, 0.72109700E+03, -.33018500E+03, -.47085900E+03, 0.11622200E+03, 0.16635400E+02, -.13122800E+03, -.29094900E+03, -.11746000E+03 },
        { -.22661600E+00, -.79372000E+00, -.98494200E+00, 0.19714600E+00, 0.93696300E+00, 0.24110700E+00, 0.63235800E+00, -.12391100E+01, 0.18136200E-02, 0.51094800E+00, -.22533500E+00, -.49358900E+00, -.12088400E+00, -.23419100E+00, -.71032200E+00, 0.15658400E+00, -.19525200E+01, 0.21719600E+00, -.97668900E-01, 0.29015800E+00, -.48010100E+00, -.10356000E+01, -.93762400E-01, -.55072600E-01, -.28112800E+00, 0.51599300E-01, 0.19087400E+00, 0.11800600E+00, 0.33201600E-01, -.15317500E+00, 0.23832400E+00, -.28376900E-01, -.62232600E+00, 0.14630500E+00, 0.25020300E+00, 0.38618700E-01, -.29014200E-01, 0.80414500E+00, 0.82105000E-01, 0.44959400E+00, 0.53489500E-01, -.23733900E+01, -.18452800E+01, -.29069300E+00, 0.67621100E+00, 0.35808600E+00, 0.90731400E+00, 0.22341100E-01, 0.10815300E+00, 0.37183700E-01, 0.18963300E-01, 0.83616100E+00, 0.74712000E+00, 0.50732600E+00, 0.63955200E-01, 0.40315200E+00, 0.82515700E+00, -.94244600E-01, -.44554800E-01, -.55535600E+00, -.34116300E+04, 0.19260300E+04, 0.22013100E+04, 0.18178000E+04, -.29990800E+04, -.14912800E+04, -.30597800E+04, 0.15269700E+04, -.22004700E+04, 0.15298300E+04, -.17836900E+03, -.69286400E+03, 0.57234400E+03, 0.28604400E+03, 0.24408300E+04, -.72410100E+03, 0.13747400E+04, 0.28680300E+03, -.14458800E+03, 0.42380600E+01, -.14339100E+03, -.16015100E+03, 0.12886200E+03, -.23618400E+03, -.20385500E+03, -.33538100E+03, 0.11043100E+03, -.25389700E+02, -.37433700E+04, 0.19064300E+04, 0.18268000E+04, 0.18715300E+04, 0.81475500E+03, -.19442200E+04, 0.31864300E+04, 0.27294700E+04, 0.37461300E+04, -.17590900E+04, 0.13924300E+04, 0.30480300E+04, -.15152700E+04, -.30103500E+04, -.15243300E+04, 0.75586200E+03, 0.48235100E+03, -.35796500E+03, 0.13389300E+04, -.54905000E+03, 0.25439300E+03, -.10720100E+04, 0.16645400E+04, -.82783000E+03, -.15225600E+04, -.83222600E+03, 0.94067200E+02, 0.22774300E+03, 0.51373800E+02, 0.63638500E+03, -.39954900E+03, 0.17847000E+03, -.34174600E+03, 0.20989000E+04, -.10401800E+04, -.15198300E+04, -.10494900E+04, -.98805500E+03, 0.21971300E+04, -.28441400E+04, -.25751900E+04, -.24126300E+04, 0.18944100E+04, -.18327300E+04, -.19468800E+04, 0.95060400E+03, 0.15944000E+03, 0.97329600E+03, 0.24776400E+03, -.20140600E+03, 0.64985600E+03, 0.80930300E+03, 0.12435000E+04, -.21754500E+03, 0.58793000E+03, -.86585100E+03, 0.43028200E+03, -.31175700E+03, 0.43294500E+03, -.21982700E+03, -.59064100E+03, 0.67445400E+03, 0.25444500E+03, 0.56245600E+02, -.51330400E+03, 0.67770400E+03, 0.55620600E+03, -.28426900E+03, 0.90019800E+03, -.27849800E+03, -.35397200E+03, -.86317300E+03, 0.27382000E+03, 0.57950000E+03, -.15659300E+03, -.75002300E+03, 0.14728500E+02, 0.46623100E+03, -.26961200E+03, -.52737500E+03, -.23297500E+03, -.13820100E+03, -.22881000E+03, -.19611000E+03, 0.66052000E+02, 0.39859300E+03, -.20179200E+03, -.31590700E+03, 0.48486400E+03, -.23617900E+03, -.92382800E+02, -.24240900E+03, -.24612100E+03, -.30667600E+02, -.19264500E+03, -.26362400E+03, -.56674000E+03, 0.35172800E+02, -.17801500E+03, 0.88317300E+04, -.44168100E+04, -.94069500E+03, -.44159900E+04, -.21066100E+04, -.30070800E+04, 0.17508400E+03, 0.16331400E+04, -.20295900E+04, -.26218100E+04, -.54887700E+04, 0.38472900E+02, -.22973400E+02, 0.11126900E+04, -.19489400E+02, 0.49716800E+03, -.39860000E+04, 0.26498300E+04, 0.16541500E+04, 0.17802300E+04, -.32345000E+04, -.25604100E+04, 0.31797800E+04, -.15898100E+04, -.39123500E+04, -.15901900E+04, -.18933900E+03, -.43207600E+03, -.11614600E+02, 0.93694700E+03, -.25549900E+02, -.56811200E+03, -.27233200E+04, -.21053100E+04, 0.10502200E+04, 0.14387300E+04, 0.10531100E+04, 0.11663700E+04, 0.66299200E+03, 0.19166400E+04, 0.55031800E+03, 0.13183200E+04, 0.53082500E+03, 0.78503300E+03, 0.27815300E+03, -.14067500E+03, 0.48124100E+02, -.13906700E+03, -.15814000E+03, 0.14014400E+03, -.24342900E+03, -.18221900E+03, -.34017800E+03, 0.10234600E+03, -.21545800E+02, -.67130900E+03, 0.33787200E+03, -.41028400E+03, 0.33541300E+03, -.81619600E+02, -.45228800E+03, 0.42976300E+03, 0.12607900E+03, 0.36138200E+03, -.29843100E+03, 0.47231500E+03, -.85200800E+03, 0.44947300E+03, -.12341000E+04, 0.42607600E+03, 0.19719300E+04, 0.85057100E+03, 0.16961200E+04, 0.24075100E+04, 0.29089600E+03, 0.81619200E+03, 0.47203600E+03, 0.17459400E+04, -.89407400E+03, 0.23019200E+04, -.87304200E+03, -.25823300E+04, -.22458000E+04, -.12770300E+04, -.12771100E+04, 0.22834300E+03, -.19445400E+04, 0.19585000E+03, -.30281400E+03, 0.57314700E+03, -.39617200E+03, -.43316500E+01, -.25721100E+03, 0.45632200E+02, 0.15209400E+04, 0.26821000E+03, 0.82772900E+02, -.73200900E+01, -.28871600E+03, -.33717900E+03, -.77282300E+03, 0.23030700E+03, 0.42564100E+02, -.17609700E+03, 0.28030800E+03, 0.12174400E+03, 0.78441200E+03, -.42391200E+03, -.58715400E+03, -.19317400E+03, -.23673200E+02, -.36440900E+03, -.79626900E+03, -.11716700E+03 },
        { -.23738700E+00, 0.10275500E+01, -.26304500E+01, -.39797200E+00, 0.79933900E+00, 0.13206500E+00, 0.22201400E+01, 0.18969100E+01, 0.72356500E+00, 0.45024600E+00, -.27572600E-01, -.23729000E+01, -.19943800E+00, -.11591900E+01, 0.13276800E+00, -.18329500E-01, 0.17756600E+00, 0.16321700E+00, -.87416200E+00, 0.25308800E+00, 0.53222800E+00, -.49001800E+01, -.13840900E+00, 0.95845200E+00, -.19081800E+00, -.11049900E+00, -.48945400E+00, -.46119700E+00, -.37257300E+00, 0.11766300E+00, 0.25384000E+00, 0.15077200E+00, 0.49139600E+00, -.15384800E+00, -.14817600E+00, -.18213300E+00, 0.34741100E-01, -.28999800E+00, -.83422200E-01, -.49237500E+00, 0.11594100E+00, 0.64116100E-01, -.41371100E+00, -.37819400E+00, 0.47399900E+00, -.21124000E+00, -.10944100E+01, 0.27186300E-01, -.19136200E-02, -.48296400E+00, 0.34892400E+00, 0.12833000E+00, 0.19090900E+00, -.64595400E+01, 0.28181100E+00, -.22188900E+01, 0.91096300E+00, -.10918500E+01, 0.32449500E+00, 0.16135100E+00, 0.12112700E+00, 0.24968500E+04, 0.12711900E+04, -.90254200E+02, 0.36667300E+03, -.22049300E+04, 0.15652600E+04, -.76697700E+03, 0.18737300E+04, -.78258700E+03, -.37464800E+03, -.11848300E+03, 0.97393300E+03, 0.92619600E+03, -.46359200E+03, 0.17412200E+01, -.49738800E+03, -.68501900E+03, 0.34417200E+03, 0.49217500E+03, 0.34250200E+03, -.82646400E+02, 0.13639600E+02, -.18195500E+03, -.17606800E+03, 0.21088600E+03, 0.57381000E+01, 0.27830200E+03, 0.22646500E+04, -.11056000E+04, -.72319700E+03, -.11322100E+04, 0.43624200E+03, 0.21203600E+03, 0.26663500E+04, 0.11662600E+04, -.16411100E+04, 0.32006200E+03, -.24134200E+04, 0.54885900E+04, -.27187500E+04, -.15268200E+04, -.27440700E+04, -.24549100E+03, -.71023300E+03, -.79853800E+03, 0.82212600E+03, -.23475700E+04, -.13239000E+03, -.21240300E+04, 0.50987300E+03, -.25831300E+03, -.10642500E+03, -.25496900E+03, 0.44694400E+02, 0.99419700E+02, -.92139200E+02, -.17223700E+03, -.25618300E+03, 0.36357200E+03, 0.65895100E+03, -.62499700E+04, 0.31005500E+04, 0.68559800E+04, 0.31250100E+04, -.12963300E+04, -.10534200E+03, 0.23530000E+04, 0.26742900E+04, 0.50690400E+04, -.56080400E+02, 0.25126400E+04, -.71570800E+03, 0.33395600E+03, -.29740600E+03, 0.35796200E+03, -.92955700E+02, -.30204400E+03, 0.58860700E+03, -.69320100E+03, 0.21896100E+03, -.30322400E+03, 0.32927500E+03, 0.94361200E+03, -.46793700E+03, -.38526600E+03, -.47288500E+03, 0.25909900E+03, 0.66033100E+03, -.11800700E+04, -.37728200E+03, -.18331700E+03, 0.69228000E+03, -.50539500E+03, -.25348600E+04, 0.13186500E+04, 0.14988900E+04, 0.12677100E+04, 0.13253400E+04, 0.79154500E+02, -.47171700E+02, 0.26025000E+03, -.61889400E+03, -.30691200E+03, 0.12736000E+04, 0.26447000E+04, -.13194600E+04, -.25606800E+04, -.13224700E+04, 0.11142600E+04, 0.77271900E+03, -.60870800E+03, 0.85673300E+03, -.74419300E+03, 0.47476100E+03, -.66506300E+03, -.87116900E+03, 0.43447800E+03, 0.32995700E+03, 0.43556800E+03, 0.31159800E+03, 0.52489600E+03, -.47104100E+03, -.19557500E+03, 0.25585900E+03, 0.35949300E+03, 0.13675700E+03, -.67800400E+04, 0.33869700E+04, 0.12675300E+04, 0.33901100E+04, 0.10497500E+04, 0.24233100E+04, -.42173200E+03, -.53756900E+03, 0.28249400E+04, 0.24974900E+04, 0.38101300E+04, 0.45948200E+04, -.22712000E+04, -.35024800E+04, -.22972200E+04, -.95309500E+03, -.28148100E+03, 0.25327600E+04, 0.24748600E+04, -.68962400E+03, -.10346800E+03, -.30120100E+04, -.34047900E+04, 0.16827700E+04, 0.44278900E+04, 0.17026100E+04, 0.12682500E+04, 0.17844800E+04, -.13434300E+04, -.39331900E+03, 0.14485000E+04, 0.23024000E+04, 0.19798400E+04, 0.21302200E+04, -.10570400E+04, 0.25945600E+02, -.10651900E+04, -.16403600E+04, -.24118800E+04, 0.33458400E+04, 0.36637900E+04, 0.52848600E+03, -.23490700E+04, -.15764400E+03, -.75995100E+03, 0.38216000E+03, 0.53759600E+03, 0.37996900E+03, -.38139600E+02, 0.27845700E+02, -.19456700E+03, -.19493100E+03, 0.22455400E+03, 0.44493600E+02, 0.35691400E+03, 0.12852500E+04, -.64726400E+03, -.82284700E+03, -.64245300E+03, 0.27402300E+03, 0.26667800E+02, 0.86580400E+02, 0.78409300E+03, -.16685900E+03, -.13015200E+03, -.74927100E+03, 0.10549800E+05, -.52878700E+04, -.56068800E+04, -.52749400E+04, -.52861300E+03, -.14263700E+04, -.36748700E+04, -.21247400E+04, -.52280800E+04, -.13115700E+04, -.50324500E+04, -.89682500E+04, 0.45235400E+04, 0.26214500E+04, 0.44841800E+04, 0.68160300E+03, 0.17314500E+04, 0.35795000E+04, 0.12208700E+04, 0.38290800E+04, 0.15590600E+04, 0.47722100E+04, 0.64956300E+03, -.29497000E+03, -.15449600E+03, -.64716800E+03, -.92668500E+02, 0.57481800E+02, 0.83642500E+03, -.22501500E+03, -.10638800E+02, -.53453700E+03, -.21073600E+03, -.80232400E+02, 0.63678100E+02, 0.28692200E+03, 0.38922800E+03, 0.46668700E+03, -.40472500E+01, -.21467500E+03, -.97576700E+03, -.69707800E+03, 0.98448300E+03, 0.53927600E+03, 0.88689400E+02, -.74774200E+02, 0.63537200E+03, 0.26834600E+03 },
        { 0.40938900E+00, -.76667100E+00, 0.19000300E+00, 0.11061000E+00, 0.32983800E+00, -.45822800E-01, 0.56611500E+00, -.13944000E+01, 0.46396900E-01, 0.37744400E+00, -.10158600E+00, 0.25319600E+01, -.10115500E+01, 0.69695700E+00, 0.11037800E+01, -.58218700E+00, 0.58689200E+00, 0.48942600E-02, 0.53343700E+00, -.87431600E-01, 0.12032800E+01, -.85044500E+00, 0.84232500E-01, 0.10534400E+01, 0.42951400E+00, -.24152300E+00, 0.25534300E-01, -.54871800E+00, -.12253900E+00, 0.13001100E+00, -.10579100E+00, 0.83303000E-01, 0.35292200E+00, -.83385700E+00, 0.14991100E+00, -.55749300E+00, 0.32560300E-01, -.18247000E+01, -.21263800E+00, -.74146500E+00, 0.33307200E+00, 0.41697300E+01, 0.47938300E+01, -.54189500E-01, -.18352600E+01, -.27121800E+00, -.34438700E+00, -.10472300E+00, -.66758500E+00, -.59458700E+00, -.14446100E+01, 0.10479100E+01, 0.43139300E+00, -.31155800E+01, -.84374400E-01, -.11486600E+01, -.11942600E-01, -.55532500E-01, 0.10941100E+00, -.16463600E+01, 0.13533500E+00, 0.29559600E-01, -.17305900E+04, -.22578300E+04, 0.12642700E+03, 0.21029400E+03, 0.46502100E+04, -.23234400E+04, -.33056000E+04, -.23250900E+04, -.29040300E+03, -.98437300E+03, -.21648400E+02, 0.17792500E+04, -.58748800E+03, -.11424600E+04, -.34796000E+04, -.71771800E+02, 0.32318200E+02, 0.28245000E+03, 0.35883500E+02, 0.15064900E+03, 0.54460100E+03, -.33850700E+03, 0.42045700E+01, -.24784800E+03, 0.46839000E+03, -.26721000E+03, -.19398200E+04, 0.10676900E+04, 0.69038200E+03, 0.96994200E+03, -.43069800E+03, -.27310600E+04, 0.16268600E+04, -.16078400E+03, -.13479100E+04, -.25572300E+04, 0.16424800E+04, -.43559600E+04, 0.22078300E+04, 0.12606200E+04, 0.21780500E+04, 0.15310800E+04, 0.11634300E+04, 0.71415700E+02, -.43655100E+03, 0.10958700E+04, 0.13691000E+04, 0.20708900E+04, 0.18174100E+03, -.77529900E+02, -.38237100E+03, -.90880600E+02, 0.38164300E+03, 0.94641800E+01, 0.11572700E+03, -.60706800E+03, 0.19002300E+03, 0.58503600E+02, -.68203500E+03, 0.11117100E+05, -.55466600E+04, -.48354800E+04, -.55585400E+04, 0.11595300E+04, 0.19871300E+04, -.19001600E+04, 0.12664000E+04, -.20906300E+04, 0.13234900E+04, -.77210600E+04, -.29860000E+04, 0.14374700E+04, 0.13568000E+03, 0.14930300E+04, -.51323900E+03, -.19359700E+04, 0.23180100E+04, -.67295800E+02, 0.15826800E+04, -.15317100E+04, 0.14150200E+04, 0.26636100E+03, -.17508800E+03, -.53788900E+03, -.13389900E+03, -.70011200E+01, 0.35947400E+03, -.72118900E+03, -.91950800E+03, 0.27763300E+03, 0.35245700E+03, -.77861800E+02, 0.10215200E+04, -.51327400E+03, 0.10603900E+04, -.51067200E+03, 0.87888900E+03, 0.36996800E+04, -.39137100E+04, -.52070500E+03, -.47287700E+04, 0.25790300E+04, -.14555200E+04, 0.11861600E+04, -.66012800E+03, -.17146900E+04, -.59311600E+03, -.12053300E+03, -.11991900E+04, 0.21197700E+03, 0.18813800E+04, 0.76291700E+03, -.11755400E+04, 0.27014500E+03, -.14294400E+04, 0.72786700E+03, 0.71728100E+03, 0.71471500E+03, 0.11146400E+03, 0.44577600E+03, -.19433900E+03, -.64649200E+03, -.15050700E+03, 0.42724400E+03, 0.25627400E+03, 0.57012300E+04, -.28568600E+04, -.34341600E+04, -.28505900E+04, 0.32543300E+03, 0.59474600E+03, -.19354700E+04, -.26165900E+04, -.40295800E+04, 0.42928600E+03, -.63909500E+04, 0.80951900E+04, -.40444600E+04, -.43684100E+04, -.40475400E+04, -.21787200E+04, -.19527600E+04, -.61127000E+03, -.13664500E+04, -.33323700E+04, -.18294000E+04, -.28642500E+04, 0.62903900E+04, -.31557500E+04, -.76563200E+03, -.31451300E+04, 0.27601900E+03, 0.86543400E+03, -.28024100E+04, -.29466700E+04, -.55033100E+04, 0.79817900E+03, -.71734000E+04, 0.66322500E+03, -.32002000E+03, 0.20557900E+04, -.33237600E+03, -.56098900E+03, -.11530700E+04, 0.58379500E+03, 0.25953800E+04, -.22760800E+04, -.13345700E+04, -.14366900E+03, -.88797700E+01, 0.39213100E-01, 0.28276100E+03, 0.44379200E+01, 0.19597400E+03, 0.60463300E+03, -.40479000E+03, -.69109600E+01, -.34329200E+03, 0.52449600E+03, -.31413500E+03, -.10918600E+04, 0.55881200E+03, 0.45490100E+03, 0.54598300E+03, 0.10550500E+03, -.42268400E+03, 0.50920800E+03, 0.12753300E+04, 0.69843900E+03, -.39210400E+03, 0.32952000E+03, -.19996300E+05, 0.10045700E+05, 0.92114500E+04, 0.99981500E+04, 0.80081900E+03, 0.18909600E+04, 0.14740000E+04, -.36885200E+04, 0.37361000E+04, 0.25507800E+04, 0.13008100E+05, 0.14887100E+05, -.74752200E+04, -.70163200E+04, -.74435400E+04, -.14468300E+04, -.38920300E+04, 0.39990700E+03, 0.63474400E+04, -.33144600E+04, -.39796400E+04, -.11839600E+05, -.39435800E+02, 0.48068200E+03, 0.16191000E+03, -.92247200E+01, 0.26674100E+03, -.33677500E+03, 0.24001600E+03, 0.41299100E+03, 0.74079400E+02, -.57268000E+03, -.52651500E+03, 0.10273100E+04, -.16956800E+03, -.18470800E+03, -.13583900E+03, -.63115400E+02, -.41310400E+02, 0.41358400E+03, 0.22860200E+04, -.23918100E+03, -.16608500E+04, 0.16285800E+03, -.18060100E+02, 0.15296300E+03, -.41841200E+03, -.67934300E+03 },
        { 0.16375500E+00, 0.13492500E+00, 0.40770900E+00, 0.41761400E+00, -.46543300E+00, -.14708200E+00, -.20339600E+01, -.13212200E+01, -.39241400E+00, -.24267400E-01, -.13292600E+00, 0.97539700E+00, 0.39991200E-01, 0.73706300E+00, 0.13320500E+01, 0.12637600E+00, -.37625500E-01, -.26083000E-01, 0.38433400E+00, 0.15011100E+00, -.85994800E-01, 0.26420100E-01, 0.64875000E-01, 0.46610300E+00, 0.52477400E-01, 0.19371300E+00, 0.14858400E-01, 0.41425100E+00, 0.19552400E+00, -.93309100E-02, 0.18957700E+00, -.11197700E+00, -.47654500E+00, 0.16239500E+00, 0.16494600E+00, -.20413300E+00, -.13333100E-01, -.43794700E-01, 0.64459200E+00, -.43977900E-01, -.45618700E+00, -.62101700E+00, -.41077800E+00, 0.18801900E+00, 0.18740700E+00, 0.18833100E+00, 0.11378600E+01, -.55809600E-01, -.12877300E+00, 0.15359900E+00, 0.15594100E+00, 0.36763000E+00, 0.11989400E+00, 0.16673300E+01, -.65256700E+00, 0.10842200E+01, 0.45575700E-01, 0.21775600E+00, -.68789400E-01, -.58583500E+00, 0.10990000E+00, -.20587600E+00, -.57696000E+00, -.10943600E+04, -.10447600E+03, 0.11995100E+04, 0.95230600E+03, -.48141200E+03, -.13788400E+04, -.47615700E+03, -.12848900E+01, -.64667700E+03, 0.77307300E+03, 0.15184300E+04, 0.24220700E+03, -.51828400E+03, -.14101800E+04, -.25488100E+01, -.29035200E+01, 0.59393800E+02, 0.12753600E+01, 0.10653600E+03, 0.33935000E+03, -.61187200E+02, 0.54487200E+02, -.77736800E+02, 0.27951800E+03, -.15094200E+03, -.14911100E+04, 0.81052100E+03, 0.13803500E+03, 0.74554300E+03, -.10709500E+04, -.23795200E+04, 0.12042200E+04, 0.84358700E+03, -.31956800E+03, -.22715300E+04, 0.15152700E+04, -.13133300E+04, 0.66795400E+03, 0.35899600E+03, 0.65664000E+03, 0.61983900E+03, 0.61809200E+03, -.28115700E+03, -.82094300E+03, -.16364100E+03, 0.54236900E+03, 0.58101300E+03, 0.53769500E+03, -.25729300E+03, -.36866100E+03, -.26884400E+03, 0.96191800E+02, -.46474300E+02, -.17827900E+03, -.38691500E+03, -.35902100E+02, -.85105400E+02, -.10831900E+04, 0.76298000E+03, -.37415000E+03, -.57801200E+03, -.38149300E+03, 0.98921900E+03, 0.67565100E+03, 0.11707200E+04, 0.19752000E+04, 0.17093700E+04, 0.69192700E+03, -.21651100E+04, -.84051400E+03, 0.38960300E+03, -.87442800E+02, 0.42024500E+03, -.31646900E+03, -.97472300E+03, 0.75792700E+03, -.10578900E+03, 0.60141800E+03, -.71888500E+03, 0.28882800E+03, -.37289100E+03, 0.15176600E+03, -.62843900E+03, 0.18590700E+03, 0.31633300E+02, -.79656600E+02, 0.12341600E+03, -.24560200E+02, 0.48877500E+03, -.23096900E+03, -.25131600E+02, 0.17557300E+04, -.89292900E+03, -.12993600E+04, -.87789900E+03, 0.44374100E+03, 0.19558700E+04, -.16250700E+04, 0.15928100E+03, -.27715600E+04, 0.15207400E+04, -.99520300E+03, 0.64948200E+02, -.74330400E+02, -.41586400E+03, -.32463900E+02, -.12270200E+03, -.12853600E+04, 0.94525000E+02, 0.37593900E+03, 0.38223100E+03, -.91250400E+03, 0.32039500E+03, -.71528100E+03, 0.36632900E+03, 0.37003800E+03, 0.35764200E+03, 0.90351800E+01, 0.14829000E+03, 0.27127000E+02, -.38094800E+03, -.36722200E+02, 0.16337800E+03, 0.12182400E+03, 0.60018200E+04, -.30056000E+04, -.21204000E+04, -.30009200E+04, 0.27640900E+02, -.58071700E+03, -.23036400E+03, 0.21845500E+03, -.23587800E+04, -.82696100E+02, -.54337600E+04, 0.26841300E+04, -.13418400E+04, -.11816300E+04, -.13420900E+04, -.66243600E+03, -.15112800E+04, -.24474400E+03, -.23142800E+03, -.16579000E+04, -.11083400E+04, -.41390200E+03, 0.33026200E+04, -.16524600E+04, -.21412600E+04, -.16513400E+04, 0.54443300E+02, -.79655400E+03, 0.17811400E+03, -.22219600E+03, -.19843200E+04, -.26354400E+03, -.44017900E+04, 0.60080600E+03, -.29578700E+03, 0.89282900E+03, -.30070900E+03, -.57886900E+03, -.38457100E+03, -.17090300E+03, 0.51972400E+03, -.17977400E+04, -.11544700E+03, -.54101600E+03, 0.16028600E+01, -.57409800E+01, 0.59980700E+02, -.80062600E+00, 0.12114600E+03, 0.35341400E+03, -.69129100E+02, 0.61749600E+02, -.10081500E+03, 0.29206600E+03, -.18467800E+03, -.15084400E+02, 0.13535100E+02, -.14494700E+03, 0.75220700E+01, -.16918400E+00, -.55536400E+03, 0.25453300E+03, 0.71360700E+03, 0.43189200E+03, -.43063500E+03, -.49299500E+02, -.58935800E+04, 0.29895700E+04, 0.27477700E+04, 0.29467900E+04, -.76124900E+03, 0.60988700E+03, -.10854800E+04, -.35070100E+04, -.34534000E+03, 0.42177400E+03, 0.56298100E+04, 0.48616700E+04, -.24693600E+04, -.19265500E+04, -.24308400E+04, -.78179100E+01, -.23328700E+04, 0.18990900E+04, 0.45568300E+04, 0.16013100E+03, -.17054000E+04, -.62827400E+04, -.45008700E+02, 0.27955100E+03, 0.17235900E+03, 0.92437200E+02, 0.19525400E+03, -.13342600E+03, 0.32151500E+03, 0.19339500E+03, -.27477000E+01, -.36876100E+03, -.20288400E+03, 0.93754800E+03, 0.30656300E+03, -.13829100E+03, -.23970600E+03, 0.22793200E+02, 0.75268300E+02, 0.22157600E+03, 0.11909000E+04, -.29014900E+03, -.95370200E+03, -.11288600E+01, -.41248000E+02, 0.21861800E+03, 0.52882200E+03, -.31351300E+02 },
        { 0.73480200E+00, -.14737800E+01, -.82795800E+00, 0.51890100E+00, 0.12365500E+01, 0.38664300E+00, 0.15688400E+01, -.27348300E+01, -.11568500E+00, 0.51888600E+00, -.19629500E+00, 0.13292700E+01, -.62081900E+00, -.58055300E-02, -.21610800E+01, -.45856700E+00, -.17631900E+01, 0.16624800E-01, -.29291100E+01, 0.46510100E+00, -.16177000E+01, 0.28369600E+01, -.22915800E+00, -.11957700E+01, -.58715900E+00, -.35280700E-01, 0.56247200E+00, -.22119800E+00, 0.39210100E+00, 0.46096600E+00, 0.67579100E+00, -.49712200E-01, 0.13952500E+01, -.36406000E+00, 0.15405500E+00, 0.37591900E+00, 0.63086900E-01, -.62858400E-02, 0.69013700E-01, -.12615000E+01, -.16633600E+01, 0.66192200E+00, 0.35211300E+00, 0.52853700E+00, 0.57736000E+00, -.49679300E-01, 0.86308700E+00, 0.65694200E-01, 0.39215900E+00, -.65659500E+00, 0.22531900E+00, -.40636500E+00, 0.13422100E+01, -.39708600E+01, -.25058800E+01, 0.67361200E+00, 0.49275300E+00, 0.95753000E+00, -.61371700E+00, 0.10417600E+01, -.17325600E+01, -.45946000E+00, 0.19059100E+00, -.22661700E+00, -.15748800E+04, 0.65454700E+03, -.59673600E+04, 0.29718300E+04, -.38987800E+04, 0.29836100E+04, 0.24276900E+03, -.10722200E+04, 0.32643800E+03, -.12846700E+04, 0.19269900E+04, -.85225200E+03, 0.18373700E+04, 0.31522300E+03, -.15886100E+03, -.17150600E+03, -.15760000E+03, 0.49313200E+02, -.32965400E+03, -.18193300E+03, -.11303600E+03, -.39671500E+03, -.16679400E+03, -.48220800E+03, 0.21828100E+04, -.11484500E+04, -.11638200E+04, -.10915800E+04, -.32129100E+03, 0.34774700E+04, -.14972400E+04, -.86478100E+03, -.18280400E+04, 0.22817700E+04, 0.21859200E+04, -.16645400E+05, 0.82941200E+04, 0.50846600E+04, 0.83223100E+04, 0.13081300E+04, 0.15410700E+04, 0.29334800E+04, -.17646100E+04, 0.43799100E+04, 0.15422200E+04, 0.66002700E+04, -.47704600E+04, 0.23822800E+04, 0.14372200E+04, 0.23852800E+04, -.43271400E+03, -.54160500E+03, 0.14891900E+04, -.33104700E+03, 0.19452500E+04, -.60315400E+03, 0.16387100E+04, 0.17158900E+05, -.85870700E+04, -.12997000E+05, -.85794900E+04, -.90514800E+03, -.33347400E+04, -.37206400E+04, 0.11229900E+04, -.63163100E+04, -.30437300E+04, -.10134900E+05, -.79587000E+03, 0.43609100E+03, 0.62725700E+03, 0.39775200E+03, -.39533600E+03, -.74318900E+03, 0.18395500E+04, 0.28812100E+04, 0.25825600E+04, -.74653600E+03, 0.38450800E+03, -.51976100E+03, 0.32705700E+03, -.50921100E+03, 0.26177300E+03, 0.14823900E+03, 0.36636200E+03, -.26749900E+03, -.82794000E+03, -.11880400E+04, 0.20557600E+03, 0.10021400E+03, -.10227700E+04, 0.49527400E+03, 0.21639000E+04, 0.51092100E+03, -.68929400E+03, -.12886500E+04, -.27279500E+04, -.51044400E+04, -.33119500E+04, -.74513100E+03, -.72736600E+03, -.19935600E+02, 0.60862800E+02, 0.17851400E+04, 0.10176200E+02, 0.12246600E+03, 0.16688700E+04, -.46475800E+03, -.56827700E+03, -.30573000E+03, 0.18183700E+04, 0.45343400E+03, 0.84690600E+02, -.48739000E+02, -.11539700E+03, -.42318900E+02, -.61423500E+02, -.70976800E+03, 0.32663400E+03, 0.37248100E+03, 0.22338100E+03, -.58824600E+03, -.45124000E+03, -.16340800E+05, 0.81731900E+04, 0.82162500E+04, 0.81702600E+04, -.36120900E+03, -.69746800E+04, 0.53411700E+04, -.46831600E+04, 0.23909200E+04, -.64482000E+04, -.14368400E+04, 0.25534200E+04, -.12811900E+04, 0.14221800E+04, -.12770400E+04, 0.67753100E+03, -.34745700E+03, -.29114900E+03, -.60788900E+03, 0.68300800E+03, -.20240700E+04, -.23914300E+04, -.15814700E+05, 0.79225800E+04, 0.89191300E+04, 0.79069800E+04, 0.24907200E+04, -.57218500E+03, 0.34189800E+04, -.39778700E+04, 0.16610300E+04, -.17157900E+04, -.20830400E+04, -.15833900E+04, 0.76665100E+03, 0.89092900E+02, 0.79135500E+03, 0.70422800E+03, 0.14586200E+04, -.79025500E+03, -.15179800E+04, 0.58430600E+03, 0.12965600E+04, 0.70920800E+03, 0.45356800E+03, -.22796000E+03, -.17215800E+03, -.22677400E+03, 0.51111600E+02, -.32258700E+03, -.23006600E+03, -.81617000E+02, -.50838800E+03, -.20093000E+03, -.62358100E+03, -.15592400E+04, 0.77285000E+03, 0.43253000E+03, 0.77933400E+03, -.10937700E+03, 0.45633300E+03, 0.41857700E+02, -.41942800E+03, 0.15442300E+03, 0.54145400E+03, 0.11243600E+04, -.27336700E+05, 0.13665500E+05, 0.14342600E+05, 0.13668500E+05, 0.35529200E+04, 0.82303800E+04, 0.54157100E+04, 0.38550000E+03, 0.10046100E+05, 0.67202300E+04, 0.15718600E+05, 0.15540200E+05, -.77841900E+04, -.50923500E+04, -.77701900E+04, -.21832600E+04, -.67435100E+04, -.37009500E+04, 0.70663500E+02, -.66550000E+04, -.52134700E+04, -.10705100E+05, -.44446800E+03, 0.57682800E+02, -.23088000E+03, 0.43577800E+03, -.84877700E+01, 0.31344500E+02, -.42264100E+03, -.18134800E+03, 0.14800300E+03, 0.10598300E+04, 0.44738400E+03, -.11396000E+04, 0.47009700E+03, -.71699300E+02, -.11732200E+03, -.69950100E+03, 0.34259700E+03, 0.27369800E+02, 0.95009800E+03, 0.31235000E+03, -.67056400E+03, -.51298000E+03, 0.69857800E+02, -.29997000E+03, -.29445900E+03, 0.24543600E+03 },
        { -.42370200E+00, -.30969100E+00, 0.50862900E+00, -.35135300E+00, 0.31769800E+00, -.19798900E+00, -.54017500E+00, 0.13928000E+00, -.68022300E+00, -.40639800E+00, 0.33772300E+00, -.12851600E+01, 0.61677500E+00, 0.25970400E+00, -.14265900E+01, -.52216700E+00, -.14684000E+00, 0.33940300E-01, 0.49205200E+00, 0.20858900E+00, 0.20140400E+00, 0.30203100E+01, 0.78374300E+00, -.12218000E+01, -.60463500E+00, -.73964100E+00, -.79780200E+00, -.55713400E-01, -.55367600E-02, 0.60836800E+00, -.13293400E+00, 0.25322700E+00, -.66322700E+00, -.27066900E+00, -.13953400E+00, 0.19860100E-01, -.20568400E-01, 0.14267600E+00, 0.68228600E-03, 0.89803800E+00, 0.71533400E+00, 0.33021100E+01, 0.30719400E+01, 0.88833300E+00, -.12459800E+01, 0.36859100E+00, 0.36364200E+00, -.24372400E-01, -.10602500E+00, 0.99778500E+00, 0.53980100E+00, -.13161900E+01, -.13548200E+01, 0.28352000E+00, 0.72815600E+00, 0.15643800E+01, -.11002100E+00, 0.12756200E+01, -.97140000E-02, 0.78808800E+00, -.74694700E+00, -.61266200E-01, -.15309500E+00, 0.13020500E+00, 0.51493300E-01, -.19094800E+04, -.90499200E+03, 0.46293200E+03, 0.42668800E+03, 0.45251200E+03, 0.69035400E+02, 0.47340400E+03, -.72159400E+03, -.12048600E+04, -.12986200E+03, 0.20034300E+03, 0.58361500E+03, 0.51049200E+03, -.25400800E+03, -.13032100E+03, -.25524900E+03, 0.63402900E+02, 0.29076000E+02, -.21651400E+03, -.17190900E+03, -.25744700E+03, 0.23099400E+02, -.17274400E+03, -.14679500E+04, 0.74661500E+03, 0.96471500E+03, 0.73402300E+03, 0.70353800E+03, 0.12494600E+04, -.20425200E+03, -.10137700E+04, -.27834900E+03, 0.11480800E+04, 0.49729700E+03, -.37462600E+02, 0.31849900E+02, -.25419700E+03, 0.18823200E+02, -.26024500E+03, -.63660800E+03, 0.11832400E+04, 0.19867100E+04, 0.77558200E+03, -.16707500E+03, 0.39258700E+03, -.11864200E+03, 0.57477200E+02, -.16724200E+03, 0.59307600E+02, -.18071200E+03, -.10420000E+03, 0.32261100E+03, 0.73125500E+03, 0.27175700E+03, 0.30046100E+02, 0.11017200E+04, 0.10101100E+05, -.50602600E+04, -.35724700E+04, -.50505600E+04, 0.31436800E+03, 0.16165600E+04, -.41194100E+04, -.62052600E+03, -.41032500E+04, 0.94053100E+03, -.46643000E+04, -.13343100E+04, 0.65677000E+03, 0.37108700E+03, 0.66719800E+03, 0.19640600E+03, 0.22940700E+03, 0.99378500E+02, 0.59741900E+03, 0.70207400E+03, 0.14076900E+03, 0.54252600E+03, 0.12514000E+04, -.63831800E+03, -.16136500E+03, -.62566800E+03, -.40219400E+03, 0.12356700E+03, -.41041300E+03, -.27648700E+03, -.36958800E+03, 0.26849300E+03, -.42001800E+02, -.30199900E+03, 0.17731300E+03, 0.23529300E+04, 0.15111400E+03, 0.49208700E+03, -.29440200E+03, 0.21486100E+03, -.84598800E+03, -.20538800E+03, -.84731200E+03, 0.15952100E+03, -.32304300E+03, 0.16776800E+03, 0.20245800E+03, 0.16147700E+03, -.52055700E+03, -.97861100E+02, 0.62965500E+03, 0.10131400E+04, 0.63646400E+03, -.28966600E+03, 0.53357700E+00, 0.42509400E+03, -.21354300E+03, -.39368100E+02, -.21255400E+03, -.30616100E+02, 0.10485800E+01, -.11292700E+03, 0.65912400E+02, -.52311200E+02, -.38639200E+02, -.22111200E+03, -.11300700E+04, 0.56400500E+03, 0.31513600E+04, 0.56507100E+03, -.71633700E+03, -.56242000E+03, 0.10073800E+04, -.38782000E+03, 0.38258900E+03, -.12352500E+04, -.27865000E+03, 0.10311100E+04, -.50263000E+03, -.33683200E+03, -.51547600E+03, -.36767000E+03, 0.53284400E+03, 0.40872300E+03, 0.30446900E+03, -.87869400E+02, 0.13260200E+03, -.23320500E+04, -.50864500E+04, 0.25321600E+04, 0.72451400E+03, 0.25433100E+04, 0.98759500E+01, -.30742500E+02, 0.13423200E+04, -.10604000E+04, 0.19204000E+04, -.72448500E+03, 0.17395000E+04, -.20114100E+04, 0.10177000E+04, 0.69227600E+03, 0.10053100E+04, 0.11310900E+04, 0.44632700E+03, 0.11586700E+04, 0.23742100E+03, 0.43798800E+03, 0.10229100E+03, 0.11613100E+04, 0.55445900E+03, -.27565600E+03, -.12376700E+03, -.27723200E+03, 0.72766400E+02, 0.26382800E+02, -.23308200E+03, -.13546100E+03, -.25926500E+03, 0.11198300E+02, -.17425300E+03, -.49027700E+03, 0.24373400E+03, 0.28017600E+03, 0.24520900E+03, -.94869600E+02, 0.27784500E+03, 0.11017600E+03, 0.34637100E+03, 0.20553100E+03, 0.21051400E+03, 0.32729800E+03, -.79436700E+04, 0.39586300E+04, 0.14332800E+04, 0.39718100E+04, 0.40675500E+02, -.93134200E+03, 0.41171000E+04, 0.15508600E+04, 0.33014300E+04, -.43450900E+02, 0.25591100E+04, 0.31430200E+04, -.15443100E+04, 0.52431200E+03, -.15714900E+04, -.38849300E+03, 0.85921700E+03, -.34300300E+04, -.21961000E+04, -.22115600E+04, 0.82701700E+02, 0.78761700E+03, -.49428100E+03, 0.23767500E+03, -.43220400E+02, 0.18604400E+03, 0.72604000E+02, -.23854900E+03, -.27662700E+03, 0.31720700E+03, 0.44225100E+02, 0.42045700E+03, -.48862800E+03, -.79740400E+03, -.58066300E+03, -.74377800E+02, -.10388700E+03, -.51542200E+03, -.11379200E+03, 0.15885100E+03, -.11026400E+03, 0.24006700E+03, 0.11809500E+03, -.30819100E+03, -.66680900E+02, -.12018800E+03, -.11903500E+04, -.67512400E+03 },
        { 0.47380500E+00, 0.33401600E+01, -.10828400E+01, 0.10975200E+00, -.34064300E+00, -.91928100E+00, -.36146500E+00, -.29381900E+00, -.15841400E-01, -.76938200E-01, -.14185500E+00, 0.15323600E+01, 0.13982700E+00, 0.10761500E+01, 0.11227100E+01, -.41517900E+00, 0.48530800E-02, 0.35450200E-01, 0.26463900E+00, 0.27886800E+00, 0.22498000E+00, 0.10133900E+01, 0.12498300E+00, 0.25787300E+01, 0.12297100E+01, -.39658900E+00, -.15727200E+00, 0.39901300E+00, 0.22025300E+00, -.20343200E+00, 0.95883300E-01, -.39778900E+00, -.10464100E+01, 0.53343700E+00, 0.98335300E+00, -.67210000E+00, -.66043900E-01, 0.34723900E+00, 0.61051200E+00, -.47596700E+00, 0.16298800E+01, 0.36554500E+01, -.10979600E+01, -.78164400E+00, 0.14573600E+01, -.58203500E+00, -.27023900E+01, -.17002800E+00, -.47251400E+00, -.10251000E+01, 0.35335400E+00, -.15312600E+01, 0.55536500E+00, -.10702100E+01, -.61600400E+00, 0.13003800E+01, 0.62570800E+00, -.75422900E+00, -.26098200E+00, -.99975500E+00, 0.76411700E+00, -.79429300E+00, 0.62889800E+00, -.16563200E+01, 0.15088100E+00, 0.20145700E+00, 0.66979000E+04, -.33468800E+04, 0.16843500E+04, -.33489700E+04, 0.11585900E+03, 0.14177300E+02, 0.58823000E+03, 0.30637700E+04, -.67180100E+03, 0.15973500E+03, -.30876000E+04, -.43552300E+03, 0.20660900E+03, 0.14101400E+03, 0.21776500E+03, 0.28444000E+03, 0.19167400E+03, 0.49858800E+02, 0.78060100E+02, 0.34919300E+03, 0.11531900E+03, 0.12268700E+03, 0.33141400E+04, -.15767100E+04, -.39548000E+03, -.16571300E+04, -.16558700E+04, -.62329600E+03, -.38225300E+02, -.31022400E+02, -.14138900E+04, -.70039600E+03, -.24385700E+04, 0.59391500E+04, -.29508500E+04, -.90922500E+03, -.29696900E+04, -.95687600E+03, -.11204800E+04, -.14612700E+04, -.18485900E+03, -.25057900E+04, -.77586800E+03, -.19880100E+04, 0.11936400E+04, -.57026700E+03, 0.12373800E+03, -.59680300E+03, -.15965900E+03, -.14340100E+03, -.44878100E+03, -.12327700E+03, -.56745400E+03, 0.29111900E+01, -.43826600E+03, -.10865400E+05, 0.54123400E+04, 0.72499000E+04, 0.54326800E+04, 0.23189700E+04, -.77047500E+03, 0.61031300E+04, 0.60714500E+04, 0.91291300E+04, -.14249700E+03, 0.47403300E+04, 0.18546600E+04, -.93341600E+03, -.71186300E+03, -.92738800E+03, -.13754300E+03, 0.24850700E+03, -.69658000E+03, -.13099000E+04, -.14285900E+04, 0.15061100E+03, -.86170500E+03, 0.71302400E+03, -.35149600E+03, 0.10100500E+04, -.35746900E+03, 0.23933600E+03, 0.30097100E+03, -.50225700E+03, 0.30754900E+03, -.26206400E+02, 0.18415700E+03, -.59507100E+03, -.14934300E+02, -.16432400E+02, -.20414100E+04, 0.73206000E+01, 0.45082700E+02, 0.16450400E+04, -.68894400E+03, 0.28047700E+03, -.76281300E+03, 0.11013800E+04, 0.11481200E+04, 0.85274400E+02, 0.26778900E+02, -.61303800E+03, -.42571800E+02, -.38500000E+03, -.40427000E+03, 0.77964300E+03, 0.15304600E+04, 0.44176300E+02, -.11180900E+03, 0.38590000E+03, -.61836000E+03, 0.31173800E+03, 0.25733000E+03, 0.30918800E+03, 0.53261700E+03, 0.49503300E+03, -.18563000E+03, -.15717400E+03, 0.22999100E+02, 0.35397500E+03, 0.76441200E+02, 0.88918900E+04, -.44611000E+04, -.72204900E+04, -.44459900E+04, 0.20783600E+04, 0.23019400E+04, -.19552700E+04, 0.42823000E+04, 0.15986600E+04, 0.27478300E+04, -.32490800E+04, -.10472300E+04, 0.55522100E+03, -.13673700E+04, 0.52351100E+03, -.11196600E+04, -.63444900E+03, 0.87772800E+03, 0.16218400E+04, 0.12147500E+04, -.42079600E+03, 0.15537800E+04, 0.13779400E+05, -.69005600E+04, -.51756900E+04, -.68898300E+04, 0.99851100E+03, -.64882900E+03, -.18556000E+04, 0.48683000E+04, 0.14170100E+03, 0.57021700E+03, -.57821500E+04, 0.34823600E+04, -.17402100E+04, -.16022100E+04, -.17414600E+04, -.19668400E+04, -.11805300E+04, -.19411000E+01, 0.64391400E+03, -.48494100E+03, -.91580800E+03, -.83930200E+03, -.54049200E+03, 0.25806200E+03, 0.14376400E+03, 0.27024900E+03, 0.30083100E+03, 0.19781800E+03, 0.45766800E+02, 0.21089500E+02, 0.39625600E+03, 0.15837200E+03, 0.21429800E+03, 0.11423100E+04, -.53131500E+03, 0.21601900E+02, -.57124600E+03, -.42491400E+03, -.56945200E+03, 0.66822900E+03, 0.17224700E+04, 0.41221100E+03, -.57387300E+03, -.73920700E+03, 0.10162800E+05, -.50312400E+04, -.40586300E+04, -.50813900E+04, -.33334300E+04, -.35400600E+04, -.53569200E+04, -.67488300E+04, -.88440200E+04, -.35808100E+04, -.46207800E+04, -.54573200E+04, 0.26932300E+04, -.72409200E+03, 0.27286300E+04, 0.27859400E+04, 0.31141000E+04, 0.44848600E+04, 0.59022000E+04, 0.74383900E+04, 0.30656400E+04, 0.17981800E+04, 0.50040300E+03, -.31623500E+02, 0.75039600E+03, -.27889100E+03, 0.27830800E+03, -.11284400E+03, -.12844300E+03, -.69539800E+02, -.11990500E+03, -.24996700E+03, -.28782500E+03, 0.77084000E+03, 0.10651700E+04, -.19495400E+03, -.42877900E+02, 0.39576500E+03, -.89574800E+03, 0.10910400E+03, -.12250200E+04, -.13073400E+03, 0.91112800E+03, 0.24610700E+03, -.19558400E+02, 0.62156500E+03, 0.23865500E+04, 0.10116300E+04 },
        { -.17010800E+00, 0.50673900E+00, 0.18867300E+00, -.18870100E+00, 0.38163800E+00, 0.22855900E+00, 0.73410300E+00, -.10178300E+01, -.32630500E+00, 0.19940300E+00, 0.79510400E-01, -.13237400E+00, 0.22218700E+00, -.22543800E+00, -.29355300E+00, -.22070500E+00, -.12698300E+01, 0.14703600E+00, 0.66659000E-01, 0.12248500E-01, -.51112400E+00, -.56110500E+00, 0.78059700E-01, -.22881100E+00, -.27992600E+00, -.39749200E-01, -.40131500E-01, -.44312400E+00, -.16479400E+00, 0.41543400E+00, 0.76066600E-01, 0.20858500E+00, 0.63201000E+00, -.57831300E+00, 0.20687400E+00, -.67057200E-01, 0.18090500E-01, -.21070700E+00, 0.23580100E+00, -.25977300E+00, -.73530200E+00, 0.31742800E+00, 0.27404300E+01, 0.44190600E+00, -.94293100E+00, 0.51787600E-01, 0.13027600E+00, -.54703300E-01, -.13082200E+00, 0.92414500E-01, -.49877000E+00, 0.91274000E+00, -.12479900E+00, 0.24476100E+01, -.26956500E+00, 0.86226100E+00, -.66484400E+00, -.21785900E+00, 0.27426100E-01, -.32396900E+00, 0.43453800E+00, -.38388000E+00, 0.32281500E+00, -.45535100E+00, -.15756200E+00, -.11606700E+00, -.62082400E-02, -.92051500E+01, 0.13250600E+04, 0.60897500E-02, 0.84586700E+02, 0.27077100E+03, 0.27774700E+03, 0.34301500E+03, -.27132800E+03, 0.26651900E+03, -.35830700E+03, -.32860500E+03, 0.15967800E+03, 0.19410900E+03, 0.16430100E+03, 0.17679900E+01, 0.55667200E+02, 0.14468200E+02, 0.40415000E+02, 0.10554100E+03, 0.48687900E+02, 0.90167900E+02, 0.39506900E+03, -.18687700E+03, 0.14815000E+03, -.19751200E+03, -.31141800E+03, -.61351700E+03, 0.37883200E+03, 0.61735700E+03, -.30028400E+03, -.74664000E+03, -.55187000E+03, 0.65474700E+03, -.33909500E+03, -.37656500E+01, -.32733100E+03, 0.95840300E+02, 0.17148500E+03, -.60634000E+03, -.57612100E+03, -.34842100E+03, 0.32109100E+03, 0.16991700E+03, -.98432900E+02, 0.55717500E+02, 0.12304100E+03, 0.49210200E+02, 0.42582600E+02, -.37794700E+02, 0.73707400E+02, -.10415400E+03, 0.13537200E+03, -.95747700E+01, 0.15501800E+02, 0.16994500E+03, -.10015900E+03, 0.69018300E+03, -.84968300E+02, -.36473500E+03, -.48892300E+03, 0.14580200E+04, 0.20780600E+04, 0.12954600E+04, -.30698600E+03, -.30848100E+03, 0.18248200E+03, -.82414100E+02, -.12968100E+03, -.91225000E+02, -.12070300E+03, -.15803500E+03, 0.33829700E+03, 0.23265400E+02, 0.34396600E+02, -.15293500E+03, -.15945100E+02, 0.73716600E+03, -.36585100E+03, 0.69571700E+02, -.36889900E+03, 0.18777600E+03, 0.13288200E+03, -.40665500E+03, -.21882200E+03, -.39247800E+03, 0.14330300E+03, -.61459700E+03, -.35095700E+03, 0.16665200E+03, 0.66279700E+03, 0.17553200E+03, 0.47949200E+03, 0.86708500E+03, -.12321600E+04, -.29907400E+03, -.99576200E+03, 0.48974600E+03, -.27628800E+03, 0.10773500E+04, -.51326700E+03, -.90607200E+03, -.53868600E+03, 0.52165800E+03, 0.45409000E+03, -.53013900E+03, -.35643200E+03, -.64006800E+03, 0.42340300E+03, -.30135000E+03, -.46122000E+03, 0.22908200E+03, 0.23448800E+03, 0.23060700E+03, 0.93832300E+02, 0.96391100E+02, 0.15998100E+02, 0.99972800E+01, 0.23728200E+03, 0.54071400E+02, 0.14570600E+03, -.54694900E+04, 0.27305400E+04, 0.13931800E+04, 0.27347600E+04, 0.10383400E+04, 0.10235900E+04, 0.23059200E+03, -.12929600E+04, 0.16209400E+04, 0.96260100E+03, 0.24487500E+04, 0.31633900E+04, -.15703600E+04, -.20076400E+04, -.15816700E+04, -.24696100E+03, -.22587300E+03, -.60571200E+03, 0.12300200E+03, -.58246900E+03, -.30779200E+03, -.12861600E+04, -.32690700E+04, 0.16390000E+04, 0.32371000E+04, 0.16345800E+04, 0.36425000E+03, 0.40593300E+03, 0.13273800E+03, -.83183300E+03, 0.84318900E+03, 0.52342100E+03, 0.13923700E+04, 0.92555400E+03, -.47047300E+03, -.25365800E+03, -.46313400E+03, -.89804300E+03, -.91311000E+03, 0.27646100E+03, 0.13066300E+04, 0.19479700E+03, -.99994300E+03, -.22512900E+03, -.34672800E+03, 0.16846000E+03, 0.20809300E+03, 0.17336300E+03, 0.14368300E+02, 0.59145900E+02, 0.57723400E+01, 0.42361600E+02, 0.97648100E+02, 0.62502600E+02, 0.96739000E+02, 0.68837500E+03, -.34959100E+03, -.33848600E+03, -.34415600E+03, 0.15590400E+03, 0.70956000E+02, -.20233400E+03, 0.47202700E+02, -.28741300E+03, 0.16057700E+02, -.44901500E+03, -.20159000E+04, 0.10299400E+04, 0.74888500E+03, 0.10079400E+04, 0.91210900E+02, -.18524400E+03, -.81619600E+03, -.19621500E+04, -.13220100E+03, -.15566100E+03, 0.15815300E+04, -.27180000E+04, 0.13333000E+04, 0.51597500E+03, 0.13590100E+04, 0.48449900E+03, 0.69601200E+03, 0.12936700E+04, 0.13972200E+04, 0.88539200E+03, 0.59825000E+03, 0.11748100E+03, 0.29118100E+03, -.22082100E+03, 0.17954400E+02, -.24052000E+03, -.10197300E+02, 0.26703200E+02, 0.22047600E+03, -.16210300E+03, 0.10101800E+01, -.23369900E+03, 0.20272500E+02, 0.28384500E+03, 0.47139900E+03, 0.80712000E+02, 0.22085500E+03, 0.18020000E+03, -.29625900E+01, -.70841100E+02, -.49660600E+03, -.22812600E+03, 0.50976200E+03, 0.23683000E+03, 0.49915200E+02, 0.54958100E+02, 0.41296300E+03, 0.78762700E+02 },
        { 0.15797000E+00, -.12495800E+01, 0.12925300E+00, 0.25260500E+00, -.26756500E+00, -.20433600E+00, -.34321200E+00, 0.10271500E+01, 0.22250000E+00, -.13900500E+00, -.22080300E-01, 0.56041300E+00, -.56785000E+00, 0.20503100E+00, 0.15368800E+00, 0.32412700E+00, 0.75311300E+00, -.25912000E+00, -.21204300E+01, 0.11091600E+01, -.16847800E+00, 0.97057900E-01, -.71172100E-01, -.42619700E+00, 0.29848800E-01, 0.54486300E-01, 0.21371000E+00, 0.34595400E-01, -.79205200E-01, -.28109300E+00, -.18245700E-01, 0.31496700E-01, 0.51859900E+00, -.41434100E+00, 0.52972500E-01, 0.41664600E-01, 0.30999700E-01, 0.26886800E+00, 0.77911200E-01, -.12431300E+00, -.37275300E+00, -.20608900E+00, 0.16123600E+01, 0.25789500E+00, -.63271200E+00, 0.45859100E+00, 0.14749700E+01, 0.26481900E-01, -.23012700E-01, 0.81363900E+00, 0.35056200E+00, 0.57584600E+00, 0.33853300E+00, -.16549200E-01, -.89257700E+00, 0.55658000E+00, 0.58307900E+00, 0.39741600E+00, -.13590100E+00, -.43458100E+00, 0.19379500E+00, -.72099700E-01, 0.24767700E+00, -.59809200E-01, 0.14619000E+00, -.60467800E-01, -.37545900E+00, -.75411500E+00, 0.21903700E+04, -.12063900E-01, 0.15695000E+03, 0.25963900E+03, 0.98024800E+03, 0.91612800E+03, -.15032600E+03, 0.45533500E+03, -.36190400E+03, -.57174400E+03, 0.27918400E+03, 0.19568300E+03, 0.28587300E+03, 0.70528400E+02, 0.19746600E+02, 0.73941500E+02, 0.29245200E+01, 0.31652800E+03, 0.26438000E+02, 0.18529200E+03, 0.17913900E+04, -.86515700E+03, 0.30715400E+02, -.89571700E+03, -.51091900E+03, -.11715100E+03, 0.11204100E+03, 0.43843900E+03, -.95166000E+03, -.30484500E+03, -.12770400E+04, 0.26355000E+04, -.13173400E+04, -.22942800E+03, -.13178000E+04, -.44196200E+03, -.25132800E+03, -.10146000E+04, -.85433300E+03, -.17579100E+04, -.92893400E+02, -.62472500E+03, 0.11282300E+03, -.43749400E+02, 0.42847800E+03, -.56404000E+02, 0.21287400E+02, 0.42191700E+02, -.13863300E+03, 0.30044400E+02, -.11719700E+03, 0.25924600E+02, 0.69451400E+02, -.75680100E+04, 0.37574800E+04, 0.47799600E+04, 0.37840000E+04, -.17041400E+03, -.15996800E+04, 0.42142500E+04, 0.33927100E+04, 0.56059000E+04, -.88173100E+03, 0.31555100E+04, 0.14309900E+04, -.70492200E+03, -.39071300E+03, -.71552800E+03, -.20762300E+03, -.17667800E+02, -.10741600E+03, -.14826500E+03, -.50881200E+03, -.10007300E+03, -.61214400E+03, 0.34960800E+03, -.18074600E+03, 0.37154500E+03, -.17525400E+03, 0.37579900E+03, 0.38960000E+03, -.58336700E+03, -.22363800E+03, -.24718300E+03, 0.32128600E+03, -.55091100E+03, -.13701900E+04, 0.68144300E+03, -.13914500E+04, 0.68503200E+03, 0.28124100E+03, 0.55966100E+03, -.37620500E+03, 0.29754000E+02, 0.10649500E+03, 0.30460300E+03, 0.11320800E+04, 0.99753900E+03, -.43641600E+03, -.73147100E+03, -.49872500E+03, 0.48856500E+03, 0.66147500E+03, -.19910500E+03, 0.17412000E+03, -.70485000E+03, 0.63305100E+03, -.13389000E+03, -.56929900E+03, 0.28119800E+03, 0.18479400E+03, 0.28465300E+03, 0.27522400E+03, 0.19022700E+03, -.51089000E+02, 0.67357100E+02, 0.47217200E+03, 0.11326700E+03, 0.14142900E+03, -.88823500E+04, 0.44328100E+04, 0.14720300E+04, 0.44411500E+04, 0.20133800E+04, 0.21341500E+04, 0.34374000E+03, -.42335900E+03, 0.39755500E+04, 0.22956000E+04, 0.49768800E+04, 0.19798700E+04, -.96090800E+03, -.18737800E+04, -.98999400E+03, -.46624100E+03, -.22549700E+01, -.29908200E+02, 0.12260500E+04, 0.78529800E+02, -.24614400E+02, -.50928300E+03, -.45942700E+04, 0.22924800E+04, 0.43205300E+04, 0.22970900E+04, 0.18066100E+04, 0.20143600E+04, -.10022200E+03, 0.41925800E+03, 0.28806600E+04, 0.22029300E+04, 0.28379600E+04, 0.26033800E+04, -.13001600E+04, -.85082100E+03, -.13024000E+04, -.16177000E+04, -.12221100E+04, 0.51509400E+03, 0.16132700E+04, 0.40053300E+03, -.11084700E+04, -.62933100E+03, -.66494500E+03, 0.32549600E+03, 0.21715000E+03, 0.33247300E+03, 0.84797600E+02, 0.18939900E+02, 0.77523700E+02, -.21185400E+02, 0.34582900E+03, 0.43382900E+02, 0.24342700E+03, 0.12367800E+04, -.60970100E+03, -.52262300E+03, -.61843400E+03, -.30331700E+02, -.56931100E+02, 0.60642000E+01, 0.52091700E+03, -.14496000E+03, -.12048200E+03, -.68604900E+03, 0.82113300E+04, -.40869300E+04, -.25175700E+04, -.41056500E+04, -.11323700E+04, -.12639800E+04, -.36404400E+04, -.30566000E+04, -.47520600E+04, -.17065100E+04, -.31256100E+04, -.85506100E+04, 0.42642700E+04, 0.19851600E+04, 0.42752900E+04, 0.16983200E+04, 0.20879300E+04, 0.34003800E+04, 0.20406500E+04, 0.41206200E+04, 0.23456000E+04, 0.26916400E+04, 0.56645600E+03, -.23859000E+03, 0.26518200E+03, -.32107900E+03, 0.42128100E+02, 0.29633800E+02, 0.29193200E+03, -.20570000E+03, -.91998900E+02, -.31874900E+03, 0.64031400E+02, 0.29926600E+03, 0.75929100E+03, 0.17302300E+02, 0.22961800E+03, 0.39880900E+03, -.30001500E+03, -.16434300E+03, -.15933300E+04, -.39793400E+03, 0.12926200E+04, 0.37188100E+03, 0.28439900E+02, 0.26574800E+03, 0.14935100E+04, 0.70775600E+03 },
        { 0.79235200E+00, -.33164000E+00, 0.49405800E+01, -.27185900E+00, -.33373200E+01, -.72942200E+00, -.42718700E+01, 0.46048000E-01, -.23349300E-01, -.44046500E+00, 0.56178000E-01, 0.32659500E+00, -.44099300E+00, -.10869500E+01, 0.92702700E+00, 0.80423700E+00, 0.34712000E+01, -.74818300E+00, -.38503500E-01, -.66632000E+00, 0.48342800E+00, 0.13262400E+01, -.72491900E-01, 0.10288800E+01, 0.58314500E+00, -.45245600E-01, 0.55284700E+00, -.19467200E+01, 0.37926000E-01, 0.32262200E+00, -.93984300E+00, -.18555200E+00, 0.17089100E+01, -.33942200E+00, -.12136900E+00, 0.38962500E+00, 0.68496000E-01, -.14374300E+00, -.52490000E+00, -.42434600E+00, -.31005400E+00, 0.24683800E+01, 0.22340700E+01, -.29932500E+00, 0.64447700E+00, -.57589800E+00, -.99017100E+00, 0.14190700E+00, 0.61201100E+00, -.56119400E+00, 0.15928100E+01, -.19700700E+01, -.35219600E+00, -.47324600E+01, -.10031400E+01, -.15387200E+01, 0.18073800E+01, -.46920600E+00, 0.56565200E-01, 0.62379800E+00, -.10667900E+01, 0.52795900E+00, -.15827500E+00, 0.43183800E+00, 0.19658000E+00, 0.47746500E-01, -.32886900E+00, -.77172900E+00, 0.56478100E+00, 0.35047300E+01, -.20000300E+03, -.47625600E+03, 0.56389300E+03, 0.68182600E+03, 0.53775100E+03, -.35405000E+03, -.14230700E+02, -.37346100E+03, 0.18679900E+03, 0.13204100E+03, 0.18672700E+03, -.14869200E+02, -.16382200E+03, 0.14670400E+03, 0.10230900E+03, 0.18224000E+03, -.15893500E+03, 0.19216600E+03, 0.31628600E+04, -.15686800E+04, -.12136400E+04, -.15813700E+04, -.96442300E+02, 0.15520900E+04, -.12246100E+04, -.28868900E+03, -.15942900E+04, 0.15878800E+04, -.19037800E+04, 0.75967800E+03, -.37390800E+03, -.69462800E+00, -.37969800E+03, 0.26764100E+01, -.34052500E+03, -.18496800E+03, -.18908600E+03, -.32161000E+03, -.30432200E+03, -.70046400E+03, -.11971100E+04, 0.59835000E+03, 0.62494500E+03, 0.59853700E+03, -.53550500E+01, -.19165000E+03, 0.20123500E+03, -.30908800E+03, 0.41464800E+03, -.13575000E+03, 0.28656300E+03, -.48912300E+04, 0.24436800E+04, 0.21968800E+04, 0.24456300E+04, 0.36786400E+03, -.67537400E+03, 0.13236700E+04, 0.79455700E+02, 0.22930800E+04, -.50863800E+03, 0.29093800E+04, 0.37655900E+03, -.20134200E+03, -.12800000E+03, -.18820500E+03, 0.14975800E+02, 0.32622700E+03, -.46931800E+03, -.73819800E+03, -.42496000E+03, 0.27739500E+03, -.17786900E+03, -.23440100E+03, 0.13581900E+03, 0.40174200E+02, 0.11721100E+03, 0.76616800E+02, -.76281900E+02, 0.13261600E+03, 0.25550300E+03, 0.41827900E+03, -.10811800E+03, 0.69410200E+02, -.37598300E+03, 0.19817300E+03, -.11530800E+04, 0.18816200E+03, -.57401800E+03, -.66538000E+03, 0.40706900E+03, 0.28594300E+03, -.62924100E+02, -.18789600E+03, 0.70592900E+03, 0.17952200E+04, -.90781400E+03, -.63955500E+03, -.89770400E+03, 0.70848600E+03, 0.97391800E+03, -.52048900E+03, 0.23174300E+03, -.74409300E+03, 0.92292100E+03, -.83637800E+03, -.40019500E+03, 0.20217600E+03, 0.10808600E+03, 0.20008800E+03, 0.16441000E+03, 0.11219300E+03, -.47924600E+02, -.39860900E+02, 0.13137700E+01, 0.80773400E+02, 0.25159400E+03, 0.34068800E+04, -.17048900E+04, -.25388400E+04, -.17033900E+04, 0.22255100E+03, 0.89674700E+02, -.10620000E+04, 0.91844500E+03, -.16214500E+03, 0.26285400E+03, -.11639000E+04, -.80604000E+03, 0.40498700E+03, 0.29063200E+01, 0.40315800E+03, 0.18193000E+03, 0.42918000E+02, 0.21018200E+03, 0.12460200E+03, 0.27219700E+03, 0.88064400E+02, 0.55194200E+03, 0.42767000E+04, -.21422400E+04, -.19232000E+04, -.21382200E+04, -.11075400E+02, -.54795100E+03, -.11112300E+04, 0.11182100E+04, -.58903100E+03, -.21885200E+03, -.16591500E+04, 0.81049500E+03, -.40990900E+03, -.95132400E+03, -.40424100E+03, -.40417400E+03, 0.57673800E+03, -.75221000E+03, -.61377600E+03, -.83800700E+03, 0.73501500E+03, -.32799700E+03, -.37627700E+03, 0.18818100E+03, 0.10910000E+03, 0.18813500E+03, -.16861300E+02, -.15259500E+03, 0.13851700E+03, 0.72881800E+02, 0.18378000E+03, -.14338400E+03, 0.20853600E+03, 0.13847500E+03, -.67118700E+02, 0.95042100E+02, -.69129600E+02, 0.31311500E+03, 0.29859500E+03, -.11332400E+03, 0.12393100E+02, -.15781500E+03, 0.30222300E+03, -.31704200E+03, 0.45533700E+04, -.22696900E+04, -.10580000E+04, -.22767200E+04, -.29957000E+03, -.72560000E+02, -.14888300E+04, -.57935200E+03, -.22192300E+04, -.40458600E+03, -.28536500E+04, -.97668700E+03, 0.48580100E+03, -.64565400E+03, 0.48837800E+03, 0.96354400E+02, 0.44534400E+02, 0.11576000E+04, 0.13486700E+04, 0.13593000E+04, 0.23327300E+03, 0.77102400E+03, 0.36969400E+03, -.20338500E+03, -.40023400E+02, -.24222900E+03, -.90319600E+02, 0.17528300E+03, -.27077500E+02, -.25928700E+03, 0.41362900E+01, -.68530100E+02, 0.20975100E+03, 0.79923100E+02, 0.12069100E+03, 0.10422500E+03, 0.10547500E+03, 0.37581600E+03, -.99204800E+02, -.18950200E+03, -.11709000E+03, 0.21818100E+02, 0.91721800E+02, 0.21741500E+03, 0.93181900E+02, 0.18553900E+02, 0.62174600E+03, 0.39822400E+03 },
        { -.99766600E-01, -.39030800E+00, 0.55954200E+00, -.31648800E+00, 0.26503600E-01, -.91969800E-01, -.37544400E+00, -.49347900E+00, -.19574100E+00, -.14397200E+00, 0.84672000E-01, 0.10239600E+01, -.69952000E-01, 0.52427600E+00, 0.60825300E-01, -.60919700E+00, 0.46068200E+00, -.55899500E-01, 0.11146700E+00, -.80862800E-01, -.33632700E-01, 0.52855400E+00, 0.30836900E-01, -.19463900E+00, 0.28277800E-02, 0.13250300E+00, 0.24248700E+00, 0.27071500E+00, -.36628900E-01, -.19220600E+00, 0.31562600E-01, 0.45455200E-01, 0.59806900E-01, 0.90257000E-01, -.14509600E+00, -.61081600E-02, 0.51922000E-02, -.15647300E+00, -.13107500E+00, 0.10996900E+00, -.18351800E+00, -.12491100E+00, 0.31771400E+00, 0.57598300E-01, -.22906000E-01, -.66133400E-01, -.30697600E-01, 0.20608800E-01, 0.36823000E-01, -.84645800E-01, 0.70531500E-01, -.67199800E-02, 0.19713100E+00, -.90352800E-01, -.54864700E-01, -.84337800E-01, 0.88190300E-01, 0.22886700E+00, -.66667900E-01, 0.11981900E+00, -.18532300E+00, 0.50274800E-01, -.20004400E-01, -.68626300E-01, 0.60985100E-01, -.57044400E-01, -.12171800E-01, -.79164900E-02, -.10660900E+00, -.20548200E-02, 0.20641100E+03, 0.44867800E+02, 0.57879700E+02, 0.10473500E+03, 0.13628400E+03, -.17284800E+02, -.24029100E+03, 0.31166700E+02, -.16653800E+02, 0.15023000E+00, -.15582100E+02, 0.50677600E+02, 0.62795100E+02, -.38969200E+02, -.18523100E+02, -.33549600E+02, 0.41176200E+02, -.38727200E+02, -.24812800E+03, 0.13649000E+03, 0.19282900E+03, 0.12404600E+03, -.19960800E+03, -.28450700E+03, 0.18793300E+03, 0.10680000E+03, 0.30390300E+03, -.27105100E+03, 0.21115700E+03, -.95861700E+02, 0.51003300E+02, -.12752500E+03, 0.47892700E+02, 0.33893600E+02, 0.58008400E+02, 0.19678400E+02, 0.12255600E+03, 0.84410400E+02, 0.11917200E+03, 0.11006100E+03, 0.62520400E+02, -.28024500E+02, -.74640400E+02, -.31254700E+02, -.44419700E+02, -.54770100E+02, 0.74115500E+02, 0.95313200E+02, 0.71434600E-01, -.25512300E+02, -.74219600E+02, 0.19906400E+04, -.99332800E+03, -.82048300E+03, -.99532400E+03, 0.99744700E+02, 0.23442700E+03, -.25560500E+03, 0.38124700E+03, -.52958000E+03, 0.13078500E+03, -.10415700E+04, 0.19027000E+03, -.99050800E+02, -.34502000E+02, -.95153600E+02, -.18886100E+02, -.48690300E+02, 0.15882700E+03, 0.23030100E+03, 0.25759200E+02, -.34333500E+02, -.73982000E+02, -.13883600E+03, 0.60242600E+02, 0.11372200E+03, 0.69505000E+02, 0.46356800E+02, 0.98656600E+02, -.36577500E+02, -.14668500E+03, -.11239000E+03, 0.98080100E+02, 0.48495200E+02, -.22926800E+03, 0.10866000E+03, 0.57799500E+03, 0.11458700E+03, 0.31185100E+03, 0.33634200E+03, -.41665900E+03, -.41448400E+03, -.10699600E+03, 0.12079200E+03, 0.68039100E+01, -.21674900E+03, 0.10571700E+03, 0.14112800E+03, 0.10839600E+03, -.20893300E+03, -.28256000E+03, 0.10236100E+03, 0.95279500E+02, 0.23305500E+03, -.23806300E+03, 0.12095600E+03, 0.13807500E+02, -.53967800E+01, 0.80973600E+01, -.69010900E+01, 0.39961200E+01, 0.22461700E+02, -.10476800E+02, -.39193900E+02, -.59546900E+02, 0.16089300E+02, -.45342000E+02, 0.18124200E+04, -.90742600E+03, -.82583800E+03, -.90622500E+03, -.10344000E+03, -.10006300E+03, -.10829300E+03, 0.31448000E+03, -.22993600E+03, -.23078100E+03, -.12893400E+04, 0.36743500E+03, -.18399500E+03, -.21769400E+03, -.18375100E+03, -.15859900E+03, -.19154000E+03, -.31461300E+02, -.27464000E+02, 0.23921800E+02, -.18488700E+03, -.12311000E+03, 0.20085200E+04, -.10048100E+04, -.89681200E+03, -.10043000E+04, 0.16367200E+02, -.47613100E+02, -.10765100E+03, 0.41608300E+03, -.27092200E+03, -.18394300E+03, -.14401600E+04, 0.15464800E+02, -.50634000E+01, -.59529700E+02, -.79676500E+01, -.46748900E+02, -.79895800E+02, 0.13856600E+02, 0.74536300E+02, 0.90782100E+02, -.10980100E+03, 0.49548500E+02, 0.28597600E+02, -.15549800E+02, 0.56279000E+01, -.14297800E+02, 0.55049900E+02, 0.66948000E+02, -.41942400E+02, -.18960900E+02, -.37846300E+02, 0.43757700E+02, -.40025100E+02, -.52771300E+02, 0.30912900E+02, 0.47689700E+02, 0.26356700E+02, -.53268600E+02, -.73758300E+02, 0.67121900E+02, 0.14699000E+03, 0.98470600E+02, -.54864000E+02, 0.25979500E+02, -.24438100E+04, 0.12297800E+04, 0.70292800E+03, 0.12219100E+04, -.13496900E+03, -.52792400E+02, 0.38377400E+03, -.33054100E+03, 0.31419100E+03, 0.17626100E+03, 0.12741900E+04, 0.10351500E+04, -.52442900E+03, -.22139800E+03, -.51758300E+03, 0.19725800E+03, -.60576200E+02, -.11139700E+03, 0.32989200E+03, 0.12871200E+03, -.25771300E+03, -.84469500E+03, -.31609800E+02, 0.75631900E+02, 0.64201900E+02, 0.11991800E+02, 0.40767600E+02, -.44953200E+02, -.27531900E+02, 0.68737400E+02, 0.46145600E+01, 0.15677000E+02, -.10402100E+03, 0.32811600E+02, -.17337800E+02, -.52379500E+02, -.28099800E+02, -.87474700E+02, -.71245200E+02, 0.68457600E+02, 0.23284800E+02, 0.23775700E+02, -.20420400E+02, -.22846300E+02, -.87589600E+01, 0.51316100E+02, -.92269100E+02, -.52858800E+02 },
        { -.10602800E+00, 0.62523400E+00, -.12448500E-01, -.15550500E+00, -.34284800E-01, 0.12282400E+00, -.99556900E-03, -.52405800E+00, -.16415400E+00, -.15955600E+00, 0.86082200E-01, 0.65781000E+00, 0.32671300E+00, 0.38938500E+00, -.37122400E+00, -.53942900E+00, 0.58569400E+00, 0.96084500E-01, -.15445100E+00, 0.12172000E-01, 0.21752600E+00, -.12519200E+00, 0.58155900E-01, -.37975600E-01, -.90480200E-01, -.86823300E-01, -.30401500E+00, 0.41819800E+00, -.29862000E-01, -.17916200E-01, 0.22731200E+00, -.20227800E-01, -.47230000E+00, 0.11112400E+00, 0.48059000E-01, -.12004300E+00, -.80151500E-02, -.24163000E+00, 0.61540000E-01, -.22022400E+00, 0.16672500E+00, -.88250900E-01, -.11119900E+01, 0.24445400E-01, -.42318000E+00, -.76178700E-01, -.30218100E+00, -.40106200E-01, -.26402300E+00, 0.18003200E+00, -.44500200E+00, 0.49198900E+00, 0.14750700E+00, -.93813000E+00, 0.10812600E+00, -.19413800E+00, -.50671200E+00, 0.52819400E-01, 0.15516700E-01, 0.15896900E+00, 0.88549200E-02, 0.13720800E+00, -.13353300E+00, 0.12201100E-01, 0.26745100E-01, 0.53735700E-01, 0.83871300E-01, 0.22802100E+00, -.28888100E+00, 0.36818900E-03, 0.25593000E+00, 0.23084800E+03, -.14299400E+03, -.17318400E+03, -.28921700E+03, 0.13154500E+03, 0.55362000E+02, -.99279600E+02, 0.48944900E+02, 0.44351500E+02, 0.49639000E+02, -.99415400E+01, 0.28977000E+00, -.30393200E+01, -.63980000E+01, 0.21742900E+02, 0.10023800E+01, 0.32887100E+02, 0.12608700E+03, -.61707200E+02, -.56496000E+02, -.63032200E+02, 0.64690300E+02, -.68257400E+02, -.85811500E+02, 0.77331200E+02, -.38218900E+02, -.69695400E+02, -.71218600E+02, -.80596300E+03, 0.40191800E+03, 0.26322400E+03, 0.40300200E+03, 0.13016600E+03, 0.19947500E+03, -.81886500E+02, -.27148400E+03, 0.33289300E+03, 0.20079900E+03, 0.32781400E+03, -.14699900E+03, 0.74565700E+02, 0.14286400E+03, 0.73496300E+02, 0.73807300E+02, 0.50036800E+02, 0.20282600E+01, -.83314700E+02, 0.38177200E+02, 0.57833300E+02, 0.87442700E+02, -.26880500E+03, 0.13044200E+03, -.11558300E+03, 0.13440500E+03, -.32097500E+03, -.36902400E+03, 0.14153700E+03, -.39111800E+03, 0.63057500E+02, -.39740500E+03, 0.24740700E+03, 0.19616200E+03, -.95097800E+02, -.33041400E+02, -.98072500E+02, -.85747800E+02, -.19718400E+03, 0.20479700E+03, 0.70016500E+02, -.15171100E+02, -.16367500E+03, -.11628400E+02, -.29901000E+03, 0.14795900E+03, 0.13371300E+03, 0.14949400E+03, 0.13130100E+03, 0.18805000E+03, -.17516400E+03, -.31725300E+03, 0.70443500E+01, 0.19893600E+03, 0.55256900E+02, -.50428800E+03, 0.25259300E+03, 0.72075400E+02, 0.25217000E+03, -.34332700E+02, 0.63128400E+02, -.87506800E+02, 0.25067300E+03, 0.61396900E+02, 0.32780200E+02, 0.65332100E+02, 0.10938000E+03, -.45702700E+02, -.10139700E+03, -.54695600E+02, 0.96289200E+02, 0.16292200E+03, -.51013700E+02, 0.28007900E+02, -.97529800E+02, 0.12214300E+03, -.19185600E+02, -.71624100E+02, 0.34887200E+02, 0.50998300E+02, 0.35810400E+02, 0.11503400E+02, 0.26375400E+02, -.70183200E+01, -.11269700E+02, 0.37225300E+02, 0.15953000E+02, 0.37907400E+02, -.13308200E+04, 0.66475500E+03, 0.22796300E+03, 0.66541600E+03, 0.23742800E+03, 0.54955100E+03, -.21264900E+03, -.56009300E+03, 0.41573800E+02, 0.29983200E+03, 0.95178500E+03, 0.75740500E+03, -.37431000E+03, -.60988100E+03, -.37868900E+03, -.70106200E+02, 0.38334000E+02, -.15804400E+03, 0.18144300E+03, -.14356400E+03, -.21100700E+02, -.25033200E+03, -.77052000E+03, 0.38510600E+03, 0.72782100E+03, 0.38528000E+03, 0.62554000E+02, 0.58585400E+03, -.33632300E+03, -.49950300E+03, -.14060500E+03, 0.31192900E+03, 0.68026500E+03, 0.21812900E+03, -.10893800E+03, -.97130300E+02, -.10922000E+03, -.19995800E+03, -.16781000E+03, -.86962500E+02, 0.38389300E+03, 0.48002200E+02, -.22763400E+03, 0.60675600E+01, -.10632200E+03, 0.52471400E+02, 0.41308100E+02, 0.53160400E+02, -.99444500E+01, 0.12392600E+01, -.39230900E+01, -.79766600E+01, 0.19249400E+02, 0.24263500E+01, 0.36737500E+02, -.35831400E+02, 0.17138600E+02, 0.54790200E+02, 0.17931400E+02, 0.27894900E+02, 0.71128100E+02, -.63613800E+02, -.56628600E+02, -.50291500E+02, 0.56215800E+02, 0.20261400E+02, -.11602400E+04, 0.58047400E+03, 0.67445200E+03, 0.58011600E+03, 0.44313900E+03, 0.37593900E+03, -.58996000E+02, -.14370200E+03, 0.37430400E+03, 0.50090400E+03, 0.49999100E+03, 0.15070000E+04, -.75314500E+03, -.73222900E+03, -.75349600E+03, -.14240800E+03, 0.91682900E+02, -.93094700E+02, 0.44586900E+03, -.83244600E+03, -.10013600E+03, -.64329500E+03, 0.88947000E+02, -.38660800E+02, -.84526100E+01, -.47971000E+02, -.72897400E+01, 0.34977800E+01, 0.71133700E+02, 0.47363100E+01, -.22775200E+01, -.79870800E+02, 0.46190300E+02, 0.10805300E+02, -.78630300E+02, -.15177300E+02, 0.76657900E+02, 0.74495300E+02, -.24783200E+01, -.27032800E+02, -.70360000E+02, -.96643800E+02, 0.64209600E+02, 0.95241500E+02, 0.12639400E+02, -.98411800E+01, -.52634600E+02, -.48191200E+02 },
        { 0.63149500E+00, -.92186700E+00, 0.52551200E+01, 0.52076900E+00, -.16397900E+01, -.96814900E+00, -.19755000E+01, 0.18981900E+01, 0.31453600E+00, -.49300300E+00, -.85836900E+00, -.21044300E+01, 0.11249800E+00, -.94386300E+00, -.90251100E+00, -.36116700E+00, 0.62621700E+00, -.32366000E+00, 0.58590500E+00, -.32708400E+00, 0.66055400E+00, -.98884500E+01, -.39214100E+00, 0.37228000E+01, 0.84012000E+00, 0.90346800E+00, 0.26755700E+01, -.95442000E+00, -.30142100E+00, -.11173300E+01, 0.41095000E+00, -.14371300E+00, 0.70162700E+00, 0.74726300E+00, -.24451700E+00, 0.12455500E+01, -.21593900E-01, 0.20629500E+01, -.62084200E+00, 0.12225300E+01, -.36957100E+00, -.27177400E+01, 0.20818200E+01, -.15604300E+00, 0.27956000E+01, -.16106600E+00, 0.15962100E+01, 0.22838700E+00, 0.11490300E+01, -.13699300E+01, 0.42341300E+00, 0.51488900E+00, -.12252300E+00, -.56251700E+01, -.71367100E+00, 0.10295300E+00, 0.53820600E+00, 0.23642300E+00, -.14445400E+00, -.92192500E+00, 0.58399200E+00, -.10076100E+00, 0.54034900E+00, -.14822800E+00, -.37888200E+00, 0.39234800E+00, -.62686000E+00, -.78536000E+00, 0.43825800E+00, 0.11963400E-02, -.10762200E+01, -.20174300E+01, 0.13115900E+04, 0.15428700E+04, -.79036800E+02, 0.19589000E+03, 0.59513900E+03, -.14508900E+04, 0.71859300E+03, 0.52617500E+03, 0.72544100E+03, 0.29246900E+02, 0.10825300E+03, 0.62271200E+02, 0.26561000E+02, 0.57590600E+03, 0.12028100E+03, 0.61387600E+03, 0.52830700E+04, -.26259800E+04, -.14306900E+04, -.26415100E+04, -.99985400E+03, -.16798000E+04, 0.98557700E+03, 0.27471000E+04, -.14218500E+04, -.19000000E+04, -.36718200E+04, -.13463000E+04, 0.67374800E+03, 0.12531500E+04, 0.67318900E+03, 0.15101400E+02, 0.69724100E+03, -.19933600E+04, -.35598000E+04, -.43451600E+03, 0.78936700E+03, 0.10085500E+04, 0.16617200E+04, -.81524600E+03, -.39641500E+03, -.83086600E+03, 0.50834600E+02, 0.55734000E+03, -.86037800E+03, -.95969400E+03, -.87711100E+03, 0.70848500E+03, -.17710500E+03, -.14704400E+05, 0.73413400E+04, 0.60437800E+04, 0.73522000E+04, -.18910100E+04, -.63638000E+04, 0.84913000E+04, 0.45353700E+04, 0.94802900E+04, -.48379800E+04, 0.45406800E+04, 0.25201500E+04, -.12379100E+04, -.66957400E+03, -.12600700E+04, -.54028400E+03, -.10883100E+04, 0.10082900E+04, 0.10572200E+03, -.79708000E+03, -.10302400E+04, -.10928400E+04, -.19959500E+04, 0.10274000E+04, 0.11368200E+04, 0.99858400E+03, 0.12791700E+04, 0.15306500E+04, -.15330500E+04, -.15754600E+04, -.71042600E+02, 0.13461800E+04, 0.18756200E+03, -.54410900E+04, 0.26924800E+04, -.24607800E+04, 0.27206000E+04, 0.57763900E+03, 0.21469900E+04, -.23069400E+04, -.37601000E+03, 0.35783600E+03, 0.22598000E+04, 0.40877500E+04, 0.16336300E+04, -.73656300E+03, -.16933700E+04, -.81680100E+03, 0.11974800E+04, 0.10942800E+04, -.76786900E+03, -.90013600E+03, -.12583700E+04, 0.11389500E+04, -.36075500E+02, -.16388500E+04, 0.81665900E+03, 0.68972300E+03, 0.81941900E+03, 0.65832900E+03, 0.70880200E+03, -.30971100E+03, -.19574400E+03, 0.49569900E+03, 0.55121800E+03, 0.53439300E+03, -.77198700E+04, 0.38515500E+04, -.23592800E+04, 0.38599500E+04, 0.35982700E+04, 0.39588700E+04, -.31657300E+04, -.23282300E+04, 0.23811600E+04, 0.44875800E+04, 0.67610000E+04, 0.37453200E+04, -.18561600E+04, -.41661000E+04, -.18726600E+04, -.35835300E+03, -.82093400E+01, -.12421200E+04, 0.69032100E+03, -.50107300E+03, 0.31273500E+03, -.73428200E+03, 0.11998700E+04, -.60174300E+03, 0.33851200E+04, -.59989300E+03, 0.23638800E+04, 0.35593500E+04, -.47384200E+04, -.12991800E+04, -.63408800E+03, 0.41917600E+04, 0.23037200E+04, 0.48787700E+04, -.24464800E+04, -.18917500E+04, -.24401300E+04, -.32239500E+04, -.28372800E+04, 0.46929800E+03, 0.34300900E+04, 0.13926300E+03, -.26217600E+04, -.15762900E+04, -.16182000E+04, 0.80170000E+03, 0.52350700E+03, 0.80909600E+03, 0.61598800E+02, 0.13144700E+03, 0.36823300E+01, -.92208300E+02, 0.59436000E+03, 0.18717700E+03, 0.74250500E+03, 0.18759800E+04, -.90722100E+03, -.93586000E+03, -.93796100E+03, 0.48266300E+02, -.12406000E+03, -.26698100E+03, 0.12573300E+03, -.34463900E+03, -.27429400E+03, -.92210100E+03, 0.43657200E+04, -.21655800E+04, 0.83198900E+03, -.21828700E+04, 0.11798300E+03, 0.16717400E+04, -.55012000E+04, -.69341000E+04, -.54228300E+04, 0.63753200E+03, 0.16874100E+02, 0.16646600E+04, -.84951300E+03, -.38345300E+04, -.83232000E+03, 0.17200400E+04, 0.11038100E+04, 0.37541600E+04, 0.70842400E+04, 0.19875300E+04, 0.15646900E+04, -.22509100E+04, 0.14222500E+04, -.26886000E+03, 0.23700900E+03, -.83908700E+03, 0.50750200E+02, 0.69499400E+02, 0.67140300E+03, -.28305700E+03, -.14632900E+03, -.10343600E+04, 0.38455600E+03, 0.83107400E+03, 0.11646800E+04, -.94486200E+02, 0.53233900E+03, 0.11164300E+04, -.28380400E+03, -.27866800E+03, -.99317800E+03, -.79326300E+03, 0.85915500E+03, 0.11056600E+04, 0.10526500E+03, 0.30419300E+03, 0.24616500E+04, 0.10610700E+04 },
        { 0.56728400E+00, -.15873900E+01, 0.79134200E+01, 0.66929900E+00, -.27302800E+01, -.70799900E+00, -.28883900E+01, 0.14043800E+01, 0.49074400E+00, -.87841800E+00, -.79624700E+00, 0.33128700E+01, -.20846700E+00, 0.91709200E+00, -.92380100E+00, -.18258500E+00, 0.58484300E-01, -.37812000E+00, 0.10204600E+01, -.26630500E+00, 0.45665300E+00, 0.23971900E+01, -.26624200E-01, 0.89661300E+00, 0.93401800E+00, 0.37616900E+00, 0.15668500E+01, -.91998300E+00, 0.28145600E+00, -.40603300E+00, 0.31894100E+00, -.31160400E+00, 0.21236500E+01, -.14904600E+01, 0.54227600E-01, 0.22478700E+00, 0.16410000E+00, -.17858300E+01, -.56068500E+00, -.18590000E+01, -.73138500E+00, 0.10929800E+01, 0.54667400E+01, 0.11050900E+01, -.35470000E+01, 0.24093800E+00, 0.24360500E+01, 0.77811300E-01, 0.38070100E-01, 0.14417900E+01, -.18453400E+01, 0.19685300E+01, -.40305700E+00, 0.10927100E+01, -.14005500E+01, 0.14541200E+01, -.26794400E+01, 0.30373900E+00, -.40099500E+00, -.22298800E+01, 0.17297100E+00, -.45125600E+00, -.89970900E+00, 0.39765800E+00, -.57493800E+00, -.41090800E+00, -.36553500E+00, 0.63750000E+00, -.84313700E+00, -.89315600E-02, 0.17092300E+01, 0.23129300E+01, 0.43234000E+00, 0.14848600E+04, 0.13917300E+04, -.52123000E+02, -.86828800E+03, -.19408600E+04, 0.95471800E+03, 0.11458500E+04, 0.97043500E+03, -.22768500E+03, 0.81400000E+01, 0.32879000E+03, 0.19906700E+03, 0.55318000E+03, 0.15511500E+03, 0.68738400E+03, 0.56320600E+04, -.26328200E+04, -.25669000E+04, -.28161000E+04, 0.71253400E+03, -.11937200E+04, -.13154900E+04, 0.60156500E+03, -.19414400E+04, -.16453600E+04, -.32740900E+04, -.20154400E+04, 0.10480600E+04, 0.87633500E+03, 0.10075700E+04, 0.14753100E+04, 0.20891000E+04, -.23479200E+04, -.43145700E+04, -.31223100E+03, 0.19969100E+04, 0.72070600E+03, -.25593400E+03, 0.16190400E+03, 0.50102800E+03, 0.12798800E+03, 0.12639800E+04, 0.12575500E+04, -.15943600E+04, -.28446200E+04, -.36010200E+03, 0.96803800E+03, -.92644700E+03, -.28702400E+05, 0.14298600E+05, 0.11035400E+05, 0.14351200E+05, 0.18583900E+04, 0.73555000E+03, 0.61350400E+04, 0.74229800E+03, 0.11992100E+05, 0.19192800E+03, 0.15195700E+05, 0.77425600E+02, -.10463000E+03, -.20322600E+04, -.38783000E+02, -.14618900E+04, -.27634900E+04, 0.10927300E+04, -.21049200E+04, 0.37317300E+02, -.24960900E+04, 0.13360100E+03, -.67033200E+03, 0.28667600E+03, 0.80551800E+03, 0.33531100E+03, 0.69862200E+03, 0.14605000E+04, -.23934000E+04, -.30382900E+04, -.60092500E+03, 0.14485100E+04, 0.39852300E+02, 0.47400500E+04, -.23450600E+04, -.28627000E+04, -.23702100E+04, -.24305200E+04, -.41583100E+03, 0.24405000E+04, 0.10006000E+05, -.18664400E+04, 0.18306300E+03, -.49858300E+04, 0.61257700E+04, -.30524600E+04, -.47893300E+04, -.30628000E+04, 0.23072400E+04, 0.24845100E+04, -.12205400E+04, 0.18759500E+04, -.13313100E+04, 0.17197400E+04, -.22492800E+04, -.20850600E+04, 0.10526000E+04, 0.98855300E+03, 0.10425400E+04, 0.53200200E+02, 0.75232400E+02, 0.31091600E+03, -.91763000E+02, 0.91568400E+03, 0.11594400E+03, 0.79564400E+03, -.86788700E+04, 0.43141600E+04, 0.10046500E+04, 0.43393800E+04, -.73502700E+03, -.28839800E+04, 0.42513900E+04, 0.14176900E+04, 0.62793300E+04, -.20219000E+04, 0.18440200E+03, 0.16716100E+05, -.82912700E+04, -.88192600E+04, -.83581600E+04, -.19277400E+04, -.15600400E+03, -.24601100E+04, 0.23415900E+04, -.38877700E+04, -.77734300E+03, -.75274900E+04, -.21455900E+04, 0.10445300E+04, 0.58745900E+04, 0.10726600E+04, -.26642100E+04, -.32807900E+04, 0.30671500E+04, 0.22790400E+04, 0.47771100E+04, -.27023000E+04, -.27508400E+04, 0.45620700E+04, -.22724300E+04, 0.83631500E+03, -.22821700E+04, -.23868900E+04, -.27921500E+04, 0.49874900E+03, 0.53912600E+04, -.32385500E+03, -.29816700E+04, -.21298400E+04, -.20923600E+04, 0.10292100E+04, 0.12458500E+04, 0.10461800E+04, -.17938300E+03, 0.25816800E+02, 0.36876400E+03, 0.31161600E+03, 0.57597400E+03, 0.19565200E+03, 0.70966600E+03, -.15733500E+03, 0.89413000E+02, 0.16822000E+03, 0.78556000E+02, 0.85821000E+03, 0.11227900E+04, -.10732300E+04, -.76657900E+03, -.58431300E+03, 0.82036700E+03, -.23254100E+03, 0.18388500E+05, -.90959600E+04, -.53697400E+04, -.91942000E+04, 0.60599200E+03, 0.18195100E+04, -.76363600E+04, -.79261100E+04, -.10633200E+05, 0.18277100E+04, -.85676600E+04, -.11925600E+05, 0.59063900E+04, 0.34688200E+04, 0.59627600E+04, 0.20116200E+03, -.19123500E+04, 0.60668700E+04, 0.92648800E+04, 0.65891100E+04, -.13795400E+04, 0.28923300E+04, 0.17146200E+04, -.11108400E+04, -.31247800E+03, -.14968100E+04, -.52012500E+03, 0.60019900E+03, 0.11582200E+04, -.13133900E+04, 0.52569400E+02, -.14049500E+04, 0.10833700E+04, 0.19280100E+04, -.22685900E+02, 0.81421200E+03, 0.11284700E+04, 0.22565200E+04, -.27846800E+03, -.67033900E+03, -.22271100E+04, -.13753000E+04, 0.22742800E+04, 0.16049500E+04, 0.36599100E+03, -.16450500E+03, 0.23390800E+04, 0.17199200E+04 },
        { 0.19444400E+00, 0.23151400E+00, 0.23224900E+01, 0.13615000E+00, -.72555800E+00, 0.59814000E-01, 0.16055900E+00, -.13598600E+01, -.47799000E+00, 0.26864400E+00, 0.18875700E+00, 0.73454800E+00, 0.46137600E-02, 0.49738400E-01, 0.38467200E+00, 0.36630700E+00, 0.17386600E+00, 0.65411000E-01, 0.16373100E+01, 0.90823400E-01, 0.18271000E+00, 0.16445100E+01, 0.17322000E+00, 0.46670000E+00, 0.18309000E+00, 0.11833000E+00, 0.31018100E+00, -.27816400E+00, 0.15816400E+00, 0.40516000E+00, -.51397900E+00, -.85332800E-01, 0.61057000E-01, 0.25492800E+00, 0.21092400E+00, -.11098800E+00, -.79837200E-02, -.14333800E+00, 0.12579200E+00, 0.86719600E-02, -.16703600E+00, 0.15156600E+00, -.29236300E+00, -.80325700E+00, -.20379700E+00, 0.62566700E-01, 0.67055100E+00, -.27300000E-01, 0.20461700E+00, -.53707200E+00, -.15797400E+00, 0.22120600E-01, -.58144100E+00, -.20813000E+00, 0.64307500E-01, 0.45884200E+00, -.39886400E-01, 0.26773600E+00, 0.14844800E+00, -.20542300E-01, -.14386400E+00, 0.27302900E-01, -.20847000E+00, 0.59124100E+00, -.94583200E-01, 0.45909800E+00, 0.98395900E-01, -.43232700E+00, -.64098100E+00, -.14595600E-02, -.39448500E+00, 0.22304300E+00, 0.20765900E+00, 0.18430000E+00, -.41928600E+03, -.51281400E+02, 0.16583300E+03, 0.43825800E+01, -.39398300E-01, -.41387700E+02, -.21905300E+01, -.33678700E+02, -.23172900E+03, 0.91367200E+02, 0.35868900E+02, 0.10770900E+03, -.21117200E+03, 0.18695200E+02, 0.93353300E+03, -.49561400E+03, 0.41325300E+03, -.46677900E+03, 0.40950300E+03, 0.19392500E+04, -.76241000E+03, -.10371400E+04, -.74648300E+03, 0.18030000E+04, -.90147800E+03, 0.15004100E+04, -.75605900E+03, -.59555100E+03, -.75023000E+03, -.40440900E+03, -.50387100E+03, -.14735500E+03, 0.18979700E+03, -.84712000E+03, -.40844800E+03, -.57462200E+03, -.10363400E+04, 0.51261000E+03, 0.54271700E+03, 0.51817200E+03, -.17405700E+03, -.19319500E+03, 0.28157100E+03, 0.14896500E+03, 0.19853800E+03, -.14209300E+03, 0.51376200E+03, 0.16162900E+03, -.78509000E+02, 0.20644200E+02, -.80817100E+02, -.51634800E+03, -.15022300E+03, -.62774700E+03, 0.36898200E+02, -.11199800E+04, -.10018000E+03, 0.38837400E+03, 0.29069000E+03, -.13517100E+03, 0.18872900E+03, -.14535700E+03, 0.10887300E+03, 0.84785800E+03, -.49391700E+03, 0.12063900E+03, -.35628900E+03, 0.66437700E+03, -.14352400E+03, 0.27092000E+03, -.11256500E+03, 0.15312100E+02, -.13605200E+03, 0.74814900E+02, -.32503300E+03, 0.29668000E+03, 0.47153500E+03, -.30171100E+02, -.21543100E+03, -.31897800E+03, -.98401700E+03, 0.49431600E+03, 0.48768800E+03, 0.49197900E+03, -.12958400E+03, -.13400100E+04, 0.12184300E+04, -.86322300E+03, 0.16725600E+04, -.11845000E+04, 0.85919100E+03, 0.50774400E+03, -.24863900E+03, 0.19550800E+03, -.25386000E+03, 0.32354400E+03, 0.91323900E+03, -.36118600E+03, -.32052200E+03, -.55934400E+03, 0.68872700E+03, -.24242400E+03, 0.23143000E+03, -.11797400E+03, -.23218500E+03, -.11571300E+03, 0.78589900E+02, -.62873900E+02, -.35747300E+01, 0.16894600E+03, 0.30074000E+02, -.49211900E+02, -.91742200E+01, -.36553300E+04, 0.18310300E+04, -.10122800E+03, 0.18276600E+04, 0.63880400E+03, 0.85345500E+03, -.64119400E+03, 0.10486400E+03, 0.31545900E+02, 0.61946800E+03, 0.36532900E+04, -.30899800E+04, 0.15393900E+04, 0.15772800E+04, 0.15449700E+04, 0.56558600E+03, 0.47858400E+03, 0.53567000E+03, 0.90030100E+02, 0.52003900E+03, 0.26986500E+03, 0.15906000E+04, 0.58677800E+02, -.25970600E+02, 0.17570300E+04, -.29360800E+02, 0.18526900E+04, 0.30446200E+04, -.19452700E+04, 0.50466100E+03, -.15184400E+04, 0.24306100E+04, 0.18446400E+04, -.11873000E+02, -.25142900E+00, -.67668900E+03, 0.59926200E+01, 0.13450500E+03, 0.85327000E+03, -.15596400E+03, -.13380200E+04, 0.18234400E+03, 0.75973100E+03, 0.15636000E+03, 0.37947400E+02, -.16575600E+02, -.48567200E+02, -.18973100E+02, -.40721400E+02, -.22683500E+03, 0.87386800E+02, 0.17591000E+02, 0.10343600E+03, -.20848500E+03, 0.18058300E+02, 0.15998900E+03, -.82293600E+02, -.21650500E+03, -.80012900E+02, 0.66340000E+02, 0.62032000E+02, 0.47214500E+02, -.33668700E+03, -.16698700E+03, 0.69910400E+02, -.20257300E+03, 0.32564500E+04, -.16426900E+04, -.48050100E+03, -.16282200E+04, 0.14967500E+03, -.27991300E+03, 0.27768600E+03, 0.10738400E+04, 0.66690600E+03, -.15249300E+03, -.21914500E+04, -.14904000E+04, 0.75530200E+03, -.17428700E+03, 0.74519400E+03, 0.23953400E+02, 0.75402400E+03, -.41342300E+03, -.15074700E+04, -.40289500E+03, 0.32763900E+03, 0.14116300E+04, 0.50468800E+01, -.37543200E+02, -.51026400E+02, -.64523600E+01, -.50864900E+02, 0.55982100E+02, -.11612200E+03, 0.28107800E+02, 0.19165600E+01, 0.29640900E+03, 0.85350900E+02, -.51256500E+03, 0.10339100E+03, 0.65482000E+02, 0.12714500E+03, -.10086100E+03, 0.61401500E+02, -.13065400E+03, -.20917600E+03, 0.11465600E+03, 0.76179500E+02, -.12414600E+03, 0.35976300E+02, -.25035900E+02, -.24870600E+03, -.66332600E+02 },
        { -.15585800E+00, -.19776200E+00, -.11316700E+01, 0.17064500E+00, 0.10801700E+01, -.16273100E+00, 0.24885800E+00, -.65613400E+00, -.13688200E-01, 0.23923800E+00, -.58965900E-01, -.13027600E+01, -.11140000E+00, -.34249100E+00, 0.85462600E+00, -.29339400E+00, -.16768100E+01, 0.14490500E+00, 0.23715600E+00, -.33981400E-01, 0.25876200E+00, -.13591900E+01, -.21006900E-01, 0.47875300E+00, -.21695600E+00, 0.43176300E-01, -.41887800E+00, -.54792400E+00, 0.11570700E+00, 0.59926500E+00, -.11790200E+00, 0.13183700E+00, -.88590800E+00, -.84682900E-01, -.30359800E+00, -.53049300E-01, -.34331300E-01, -.59333100E+00, 0.17852600E+00, 0.36365800E+00, -.16644400E+00, -.31245800E+00, -.13677900E+01, -.77673000E+00, 0.29430200E+00, 0.26906400E+00, 0.35521500E+00, -.59387000E-01, -.43997800E+00, -.33964600E+00, -.70911900E+00, 0.85780600E+00, -.40360600E-02, -.43892400E+00, 0.62426900E+00, 0.72068100E+00, -.37436200E+00, -.12880900E+00, -.48321900E-01, -.20677000E+00, 0.69491100E+00, 0.14512700E+00, -.25400000E+00, -.21710900E+00, -.78146600E-01, -.10290400E+00, -.29311100E+00, 0.29282800E+00, -.15930900E+00, -.28786400E-02, 0.24491600E+00, 0.25062600E+00, 0.36236500E+00, 0.13217900E+00, -.20520000E+00, -.19656800E+03, -.37247200E+03, 0.63134100E+03, -.31692300E+03, -.17107400E+03, -.31566800E+03, 0.17955700E+03, 0.24597900E+03, -.20698000E+03, -.14284800E+03, -.41136400E+03, 0.18037400E+03, -.32871100E+03, -.12743100E+04, 0.67902300E+03, 0.59291600E+03, 0.63712600E+03, -.28697100E+03, -.25794800E+03, 0.20692700E+03, -.64984400E+03, 0.65848400E+03, -.26451600E+03, 0.54009000E+03, 0.18830300E+04, -.92752000E+03, -.12332700E+04, -.94156700E+03, -.12652900E+03, -.32362700E+03, 0.56235300E+02, 0.17327000E+04, -.22824500E+03, -.27240800E+03, -.53009500E+03, 0.44672200E+02, -.15879400E+02, -.16435600E+03, -.22328300E+02, -.13021700E+03, -.46262100E+03, 0.27760700E+03, 0.50513200E+03, 0.31121900E+03, -.40632000E+03, -.32147900E+03, 0.68659800E+04, -.34179700E+04, -.20017500E+04, -.34329900E+04, 0.19658700E+04, 0.35850700E+04, -.27223600E+04, -.38642800E+03, -.36293300E+04, 0.31149100E+04, -.35078800E+04, -.15364500E+04, 0.74208300E+03, 0.17984100E+03, 0.76820300E+03, -.63653500E+00, -.88930400E+02, 0.12842500E+03, -.16974400E+03, 0.58806400E+03, -.22806500E+01, 0.56023700E+03, 0.12261200E+04, -.62091200E+03, -.50494600E+03, -.61358500E+03, -.62043200E+03, -.56199200E+03, 0.31845500E+03, 0.74986400E+03, 0.68967200E+02, -.51943100E+03, -.30806100E+03, 0.18655400E+04, -.94291600E+03, 0.12362100E+04, -.93283700E+03, 0.23012700E+03, 0.62531600E+03, -.40905800E+03, -.82686000E+03, -.13032900E+04, -.61720700E+02, -.10706100E+04, -.60756500E+03, 0.26777000E+03, 0.19019600E+03, 0.30379300E+03, -.98117400E+03, -.10562500E+04, 0.88197900E+03, 0.16227200E+04, 0.10869400E+04, -.10685500E+04, 0.48165600E+03, 0.18742400E+03, -.86136600E+02, -.98263400E+01, -.93707400E+02, -.40456400E+02, 0.28211900E+02, -.33776700E+02, -.25441500E+03, -.46759800E+03, 0.79436500E+02, -.18603500E+03, 0.32316200E+04, -.16177000E+04, 0.31343900E+03, -.16158300E+04, 0.80130400E+01, 0.75133800E+02, -.20505000E+03, 0.29227300E+03, -.24700800E+04, 0.54917100E+02, -.29344600E+04, -.20954600E+04, 0.10409900E+04, 0.13154000E+04, 0.10477000E+04, -.90068100E+03, -.99857300E+03, 0.13710800E+04, 0.49590000E+03, 0.86968300E+03, -.96574100E+03, 0.11407600E+04, -.80176600E+02, 0.37277000E+02, -.82772000E+03, 0.40036600E+02, 0.72663900E+03, 0.55253200E+03, -.21714300E+03, -.57928200E+03, -.18564300E+04, 0.62949000E+03, -.16088300E+04, -.48213800E+03, 0.24405700E+03, 0.78892100E+03, 0.24152400E+03, 0.65154000E+03, 0.46555500E+03, 0.20855000E+03, -.93242400E+03, -.71933000E+03, 0.43048300E+03, 0.37016300E+02, 0.69644100E+03, -.34997500E+03, -.17217400E+03, -.34821800E+03, 0.18492400E+03, 0.25835500E+03, -.21336300E+03, -.13288600E+03, -.44334400E+03, 0.18575600E+03, -.36698600E+03, -.13898500E+03, 0.82054500E+02, 0.14993300E+03, 0.69452400E+02, -.44595400E+03, -.57474700E+03, 0.70558500E+03, 0.11992600E+04, 0.67317500E+03, -.51346700E+03, 0.14882300E+03, -.30978100E+04, 0.15721700E+04, -.13998600E+03, 0.15489200E+04, -.68192300E+03, -.12667100E+04, 0.95944000E+03, 0.11074200E+04, 0.23672200E+04, -.85965400E+03, 0.19215200E+04, -.14607900E+02, -.11981000E+02, 0.13330300E+04, 0.72926500E+01, -.59328000E+03, -.74126900E+03, 0.39883600E+03, -.11533500E+04, -.86706500E+03, -.87785500E+03, -.97961700E+03, -.61129400E+03, 0.67778800E+03, 0.17643100E+03, 0.36597200E+03, 0.24529000E+03, -.26211900E+03, -.41259000E+03, 0.71357800E+03, 0.68873300E+02, 0.40889600E+03, -.54153100E+03, 0.56470300E+02, -.38007900E+03, -.20685100E+03, -.47509100E+03, -.58961500E+03, -.24728200E+03, 0.42798900E+03, 0.14142300E+04, 0.33020800E+03, -.11976200E+04, -.49862700E+03, -.91426100E+02, 0.65722800E+02, -.11338500E+04, -.96810000E+03 },
        { -.45690900E+00, -.41590500E+00, -.18966900E+01, 0.35740800E+00, 0.29799100E+01, 0.15433400E+00, 0.38034800E+01, 0.75210300E+00, -.37549000E+00, 0.88091800E-01, 0.34932100E+00, -.32346500E+01, 0.55241100E+00, -.57213200E+00, 0.18168000E+01, -.42007300E+00, -.44685200E+01, 0.42830200E+00, -.76384100E+00, 0.12272700E+01, -.81423300E+00, -.25986100E+01, 0.27011700E+00, -.10384100E+01, -.73685500E+00, 0.70469400E+00, -.11391900E+01, 0.38694000E+00, -.25449100E+00, 0.85147300E+00, 0.60464000E+00, 0.10423600E+01, -.11065200E+01, -.10871300E+01, -.39216900E+00, -.37914900E+00, -.21908300E-01, -.70344500E+00, 0.94345100E+00, 0.51360900E+00, 0.24785300E+00, 0.27589500E+01, 0.61116600E-02, -.93679900E+00, 0.23890500E+00, 0.13517500E+01, 0.30186300E+01, -.13086900E+00, -.22869400E+00, -.20561700E+00, 0.11556900E+00, -.40292900E+00, -.20291200E+01, 0.18169600E+00, 0.17088800E+01, 0.15195700E+01, -.75988500E+00, -.76486900E+00, 0.14410000E-01, 0.52245800E-01, -.51964500E-01, -.15306900E+00, 0.64337500E+00, -.40637200E+00, -.89907200E-02, 0.20241700E+00, -.64333200E+00, -.35151500E+00, 0.61231200E+00, -.31024700E+00, 0.74767100E+00, 0.17821500E+01, 0.22688700E-01, 0.25095600E+00, 0.29611300E+00, 0.15365500E+00, 0.12936700E+04, 0.97437500E+03, -.47678800E+03, -.49948800E+03, -.48694600E+03, 0.29193700E+03, 0.15782500E+03, -.30468800E+03, -.84411400E+02, -.35513600E+03, 0.66531100E+02, -.32292500E+03, -.45437100E+03, 0.14742300E+03, 0.88778000E+03, 0.22214400E+03, -.77980500E+03, 0.67386600E+03, 0.73378700E+03, -.12871000E+04, -.50760900E+03, 0.75788900E+03, -.78092800E+03, 0.20832700E+04, -.10431000E+04, -.10564700E+04, -.10462200E+04, -.10523000E+04, -.14158400E+04, 0.11816300E+03, 0.16534400E+04, 0.38482500E+02, -.11973700E+04, -.86853800E+03, 0.16828500E+03, -.10062700E+03, -.32507500E+03, -.83869500E+02, -.74322700E+03, -.66013300E+03, 0.25677800E+03, 0.27061800E+03, -.28486800E+02, -.29704300E+03, -.13072400E+03, 0.70557100E+04, -.34642000E+04, -.31238800E+04, -.35285000E+04, 0.12658700E+04, 0.73230000E+03, -.96355100E+03, 0.25470800E+04, -.23022100E+04, 0.10933800E+04, -.33695400E+04, -.62514900E+03, 0.31537900E+03, 0.70335000E+03, 0.30987800E+03, 0.59583600E+03, 0.11912900E+04, -.43583100E+03, 0.82163300E+02, -.28703800E+03, 0.10364700E+04, -.27935400E+03, 0.16497500E+04, -.74087400E+03, 0.40186100E+03, -.81878100E+03, -.56207400E+03, -.10583600E+04, 0.54878600E+03, 0.22044300E+04, 0.10580800E+03, -.10436600E+04, -.71840700E+03, 0.47806900E+03, -.26934300E+03, 0.95473100E+03, -.24330400E+03, 0.72958000E+03, 0.10138200E+04, -.15744800E+04, -.38184000E+04, -.57675200E+03, 0.58978600E+03, 0.15068600E+04, -.32240800E+04, 0.15529100E+04, 0.17666900E+04, 0.16150000E+04, -.17523100E+04, -.15486700E+04, 0.15403000E+04, 0.44976100E+03, 0.14881100E+04, -.11696200E+04, 0.17544200E+04, 0.75643300E+03, -.37217800E+03, -.19493600E+03, -.37772800E+03, 0.25085500E+03, 0.25494200E+03, -.29845700E+03, -.10313600E+03, -.71645400E+03, 0.20272100E+03, -.35613600E+03, 0.70110000E+04, -.34924500E+04, -.10583800E+04, -.35066900E+04, 0.75917000E+03, 0.81879600E+03, -.19239100E+04, 0.14475500E+04, -.36175000E+04, 0.13479600E+04, -.18021600E+04, -.10372400E+05, 0.51180600E+04, 0.47031800E+04, 0.51816800E+04, 0.12674600E+03, -.74591300E+03, 0.24550900E+04, -.49586600E+03, 0.26607500E+04, -.29627700E+03, 0.50750100E+04, 0.25324800E+04, -.12545800E+04, -.41472700E+04, -.12692300E+04, 0.15275300E+04, 0.22365100E+03, -.16708200E+04, 0.57396000E+02, -.26813300E+04, 0.12496800E+04, 0.26115700E+03, -.89667600E+03, 0.43061800E+03, -.13029100E+04, 0.44756200E+03, 0.60580500E+03, 0.10878600E+04, 0.44214600E+03, -.38835700E+04, -.75749200E+03, 0.12429800E+04, 0.26407200E+03, 0.10480600E+04, -.51354400E+03, -.55288500E+03, -.52380700E+03, 0.28208400E+03, 0.16117400E+03, -.35525200E+03, -.14084400E+03, -.35247400E+03, 0.81408100E+02, -.31657000E+03, 0.25208000E+03, -.96608400E+02, 0.89594200E+02, -.13006000E+03, -.84361900E+03, -.97679300E+03, 0.10937700E+04, 0.11765100E+04, 0.77199300E+03, -.85169000E+03, 0.93002100E+02, -.57719300E+04, 0.28539400E+04, -.21651500E+02, 0.28868500E+04, -.18079800E+04, -.21224700E+04, 0.18507900E+04, -.46955500E+03, 0.33613100E+04, -.25296100E+04, 0.18649000E+04, 0.36417700E+04, -.18129300E+04, -.66080500E+02, -.18218500E+04, 0.68303000E+03, 0.93318700E+03, -.11896100E+04, -.19114300E+04, -.13926200E+04, 0.12489600E+04, -.83749100E+02, -.83234400E+03, 0.10135400E+04, 0.41290800E+03, 0.59009400E+03, 0.49661500E+03, -.50227500E+03, -.91764800E+03, 0.10387800E+04, 0.10300500E+02, 0.83690800E+03, -.77481600E+03, -.35709300E+03, 0.49041100E+03, -.61551900E+03, -.66003600E+03, -.93267600E+03, -.33642700E+03, 0.55520500E+03, 0.16951100E+04, 0.87091500E+03, -.15969300E+04, -.90897300E+03, -.17652700E+03, 0.24304300E+03, -.49836300E+03, -.94188000E+03 },
        { 0.20862800E+00, -.69798800E+00, 0.15906800E+01, 0.47202300E+00, -.16558200E+00, -.16441400E+00, -.13028000E+01, -.15844700E+01, -.55010500E+00, 0.20973000E+00, -.80891300E-01, -.71479700E+00, -.87569600E-01, -.34468100E+00, 0.22364900E+00, 0.12302600E+00, -.51119700E+00, 0.33751600E-01, -.12812100E+00, 0.13058700E+00, 0.66961900E-01, -.75575300E+00, 0.11599000E-01, 0.17598500E+00, -.10946500E+00, -.36425800E-01, -.24215400E+00, -.33643800E+00, -.31708800E-01, 0.14843700E+00, 0.76489000E-01, 0.21769700E-01, 0.28747400E+00, -.39102600E+00, 0.53599700E-01, -.12377400E+00, 0.18035300E-01, -.15364500E+00, 0.17460800E+00, -.33125600E+00, -.14297300E+00, -.20993000E+00, 0.31207900E+00, -.18339600E-01, -.17377500E+00, -.30843500E-01, -.38214800E+00, -.23175500E-01, -.11510300E+00, -.23205500E+00, -.10521600E+01, 0.53585700E+00, -.10200600E-01, -.11847400E+01, -.45612100E-02, -.69435100E-01, -.73411000E+00, -.19528300E+00, -.27983200E-01, -.84151700E+00, 0.22848100E+00, -.17570700E+00, 0.18978500E+00, 0.58895500E-01, -.16486200E+00, -.75901200E-01, 0.15785600E+00, 0.16892700E+00, -.81228000E-01, 0.88675400E-03, 0.24424400E+00, -.10832800E+00, 0.12574200E+00, 0.22262000E+00, 0.15821900E+00, -.41487900E+00, -.83430400E-01, 0.67233000E+03, -.33211700E+03, -.25234100E+03, -.33614600E+03, 0.31473300E+02, 0.73346600E+02, -.74779500E+02, -.11849100E+02, -.24540700E+03, 0.47337900E+02, -.23763300E+03, -.24740500E+04, 0.12152700E+04, 0.82997200E+03, 0.12366200E+04, 0.34997300E+02, -.16906500E+03, 0.47639000E+03, -.69177800E+03, 0.75227100E+03, -.12654200E+03, 0.12195600E+04, 0.13055200E+04, -.65520100E+03, -.73529000E+03, -.65310600E+03, -.31646800E+03, -.47360300E+03, 0.48817000E+03, 0.12102900E+04, -.25120000E+03, -.47105700E+03, -.29234100E+03, 0.44367500E+03, -.22948800E+03, -.49312700E+03, -.22182000E+03, -.19237600E+03, -.20866100E+03, 0.83002400E+02, 0.45721700E+03, -.26817200E+02, -.19270800E+03, -.16243300E+03, 0.64826800E+04, -.32244200E+04, -.18087900E+04, -.32413900E+04, 0.72490800E+03, 0.17118400E+04, -.22767100E+04, -.26388600E+03, -.29644200E+04, 0.15164400E+04, -.36747000E+04, -.12200000E+04, 0.60749500E+03, 0.33192600E+03, 0.60979800E+03, 0.24672500E+03, 0.41679700E+03, -.41018200E+03, -.38467900E+02, 0.36105700E+03, 0.39178100E+03, 0.36695900E+03, 0.10333700E+04, -.51345800E+03, -.44846100E+03, -.51606800E+03, -.52124300E+03, -.66916900E+03, 0.59849000E+03, 0.91808400E+03, 0.20890900E+02, -.64662700E+03, -.28847400E+03, 0.16640600E+04, -.83161100E+03, 0.72392700E+03, -.83233800E+03, 0.28265100E+03, 0.67564400E+02, 0.21400300E+03, -.63670000E+03, -.38570200E+03, -.26702900E+03, -.78325900E+03, -.11917100E+04, 0.56404200E+03, 0.64788700E+03, 0.59607000E+03, -.63934300E+03, -.83471300E+03, 0.42451700E+03, 0.40113700E+02, 0.56186500E+03, -.77683400E+03, 0.40376200E+03, 0.62993600E+03, -.31368000E+03, -.19582300E+03, -.31493000E+03, -.16358100E+03, -.11908900E+03, 0.19607400E+02, 0.49585600E+02, -.23788300E+03, -.80227800E+02, -.23738600E+03, 0.29207600E+04, -.14547800E+04, 0.16569900E+04, -.14604600E+04, -.72247200E+03, -.50308500E+03, 0.57865200E+03, 0.98235900E+03, -.13458300E+04, -.43060300E+03, -.15577700E+04, -.26287900E+04, 0.12978500E+04, 0.19843700E+04, 0.13140600E+04, 0.11308300E+03, -.13160700E+03, 0.69048600E+03, -.39980400E+03, 0.34561300E+03, -.20295200E+02, 0.70235600E+03, -.24736600E+04, 0.12407200E+04, -.12314100E+04, 0.12366200E+04, -.93555500E+02, -.56759800E+03, 0.14638100E+04, 0.19536000E+03, 0.42947900E+03, -.38296300E+03, 0.11490600E+04, -.15876200E+04, 0.79334700E+03, 0.69444300E+03, 0.79432700E+03, 0.99527600E+03, 0.68086200E+03, 0.35485400E+03, -.13518200E+04, -.20543500E+03, 0.75876300E+03, 0.28450100E+03, 0.72674400E+03, -.35911900E+03, -.25307400E+03, -.36335400E+03, 0.23735000E+02, 0.59151400E+02, -.60853200E+02, 0.24052200E+02, -.24168000E+03, 0.23908900E+02, -.27766000E+03, 0.26910100E+03, -.13952100E+03, -.22191500E+03, -.13485700E+03, -.25583100E+03, -.29482000E+03, 0.19557200E+03, 0.22870400E+03, 0.14885100E+03, -.26168900E+03, 0.16255700E+02, -.17252500E+04, 0.84789400E+03, -.11255900E+04, 0.86269200E+03, -.61019700E+03, -.10340000E+04, 0.14844300E+04, 0.17058600E+04, 0.18779600E+04, -.85758900E+03, 0.13683400E+04, -.41659100E+03, 0.21703300E+03, 0.18611100E+04, 0.20822500E+03, -.34516100E+03, -.81987600E+02, -.70599500E+03, -.20947500E+04, -.62757100E+03, -.40473700E+02, 0.20200200E+03, -.63469300E+03, 0.33024500E+03, 0.47573800E+01, 0.37906100E+03, 0.12348900E+03, -.17134300E+03, -.29914400E+03, 0.32373400E+03, 0.36016300E+02, 0.40041700E+03, -.33888400E+03, -.19693000E+03, -.68388300E+02, -.72077900E+02, -.35678600E+03, -.54570500E+03, 0.10763500E+03, 0.23328900E+03, 0.55021100E+03, 0.35821900E+03, -.49289200E+03, -.53253500E+03, -.88618600E+02, -.31324300E+02, -.69174900E+03, -.47880200E+03 },
        { 0.23369900E+00, 0.16896500E+01, -.59382900E+00, 0.11456500E+00, -.30631000E+00, -.40515000E+00, -.29623300E+00, 0.40089100E+00, 0.11071200E+00, -.78752600E-01, -.75871700E-01, 0.29543100E+00, 0.13930600E+00, 0.25070900E+00, -.56289000E-02, 0.67456500E-01, -.10067400E+00, -.21124700E-01, -.30559400E+00, 0.77711800E-01, -.30076200E+00, 0.86620500E+00, 0.13431600E+00, 0.64692900E+00, 0.32988400E-01, -.17110100E+00, 0.28052200E+00, 0.31288800E-01, 0.34029800E-01, -.20471000E+00, 0.54941800E-01, -.18922300E+00, 0.12788100E-01, 0.26548400E-01, -.14041500E+00, -.53370100E-01, 0.26435500E-01, -.15491400E+00, 0.35148600E-02, 0.78914500E-01, 0.68418400E-01, 0.81833400E+00, 0.91150700E+00, 0.24483200E+00, -.22824700E+00, 0.73828700E-03, -.61043700E-01, 0.29956500E-01, -.21110100E-01, 0.71631500E-01, 0.16667900E+00, -.28896900E+00, -.25127900E-02, 0.11163800E+00, 0.63112100E-01, -.10714900E+00, -.43480000E-01, -.30931200E-01, -.81259900E-01, -.12914800E-01, -.12709100E+00, -.15940400E-01, 0.36332800E-01, 0.37643600E-01, 0.38246500E-01, -.51612400E-01, 0.56441500E-02, -.28468700E+00, 0.47972700E-01, 0.13002400E-02, 0.32942900E+00, 0.31769700E+00, -.12443400E-01, 0.66668700E-01, 0.35813400E-02, -.62051900E-01, 0.42799500E-01, 0.15781500E+00, 0.86163000E+01, -.12998100E+02, -.14695400E-01, 0.82530700E+01, 0.15578100E+01, -.87759000E+01, -.88435200E+01, -.10098300E+01, -.81055100E+00, -.11054700E+02, -.10730800E+03, 0.25326100E+02, 0.30056900E+02, 0.53953200E+02, -.30537200E+01, -.74001100E+02, 0.60481800E+02, 0.20695700E+02, 0.33541200E+02, -.65747200E+02, 0.75149900E+02, -.13169100E+03, 0.61556200E+02, 0.22627700E+02, 0.66136500E+02, -.12454100E+02, 0.21271900E+02, 0.73164000E+02, 0.10629100E+03, 0.82720700E+02, 0.48135500E+02, 0.12203200E+03, -.25289700E+02, 0.68045400E+01, -.64146000E+00, 0.12624600E+02, -.42046600E+02, -.43698400E+02, 0.95133800E+02, 0.13372500E+03, 0.48228800E+02, -.38237700E+02, 0.50853200E+02, 0.17188800E+04, -.85606700E+03, -.83589600E+03, -.85940100E+03, -.39546000E+03, -.13241700E+03, -.18546700E+03, 0.32217300E+03, -.50328800E+03, -.14126900E+03, -.66406700E+03, 0.25599600E+03, -.12069200E+03, 0.35459400E+02, -.12783200E+03, 0.18908200E+02, 0.66617400E+02, 0.38103900E+02, 0.22138300E+03, -.43236800E+02, 0.57390100E+02, -.68918500E+02, -.27212300E+03, 0.17241800E+03, 0.10952400E+03, 0.13582300E+03, 0.99742000E+02, 0.92178900E+02, -.13976500E+02, -.46555300E+02, -.91449700E+01, 0.10120800E+03, 0.43753300E+02, -.49266900E+03, 0.25023300E+03, 0.50365500E+03, 0.24661600E+03, 0.24577800E+03, 0.17281900E+03, -.33680200E+03, -.71494800E+03, -.16625300E+02, 0.13346400E+03, 0.83661400E+02, -.24758800E+03, 0.12900100E+03, 0.14076900E+03, 0.12361200E+03, -.89950700E+02, -.90481800E+02, 0.19740500E+02, -.23201300E+03, 0.30239400E+02, -.59761200E+02, 0.10550900E+03, 0.42908200E+01, -.36913200E+01, 0.43145000E+01, -.21752700E+01, 0.13666200E+01, -.14256700E+01, 0.26109400E+01, 0.33164600E+01, -.11234800E+02, -.78551900E+01, -.73104500E+01, 0.57441100E+03, -.28398200E+03, -.30897000E+03, -.28712600E+03, -.46862500E+02, -.98040500E+02, -.93298100E+02, 0.57019900E+02, -.16107100E+03, -.13040300E+03, -.86732400E+02, -.26609600E+03, 0.12601500E+03, 0.12549300E+03, 0.13333000E+03, 0.11875100E+03, 0.43387300E+02, -.94868300E+02, -.19117200E+03, 0.50383000E+02, 0.21755700E+02, 0.18258500E+03, 0.62262200E+03, -.30870200E+03, -.33448800E+03, -.31111200E+03, -.16354200E+03, -.17869200E+03, -.42322000E+02, 0.10091800E+03, -.22270800E+03, -.16968600E+03, -.10370000E+03, -.57683600E+02, 0.19907200E+02, -.96444200E+02, 0.28981500E+02, 0.45472500E+02, -.78942700E+01, -.94049900E+02, -.17423600E+03, -.28526600E+02, -.52536800E+02, 0.10728700E+03, -.45833200E+00, 0.27940300E+01, -.14292500E+02, 0.21581700E+00, 0.60514200E+01, 0.62822700E+00, -.11480200E+02, -.14590400E+02, -.11076500E+01, -.99209300E+00, -.10949400E+02, -.21865000E+01, 0.74971400E+00, -.40024900E+02, 0.13443500E+01, -.27646900E+02, -.21481900E+02, -.51475900E+00, -.51739300E+02, 0.68598400E+01, -.17731900E+02, 0.76465100E+01, -.18153000E+04, 0.89474000E+03, 0.55064000E+03, 0.90759400E+03, 0.24689100E+03, 0.23413400E+02, 0.40439100E+03, -.14416200E+01, 0.58934800E+03, 0.89019300E+02, 0.72341000E+03, 0.74954000E+03, -.36555200E+03, -.21050300E+03, -.37470800E+03, -.71139500E+02, -.30036600E+02, -.19957200E+03, -.98887100E+02, -.17538000E+03, -.10293700E+03, -.26520600E+03, 0.11521900E+01, -.15107300E+02, 0.15003900E+02, 0.17816700E+02, -.19607100E+01, -.16176400E+01, -.24300000E+01, -.13932800E+02, -.46280500E+01, -.62648200E+01, -.18228100E+02, -.52638000E+02, 0.74033000E+02, -.20808100E+02, 0.21946300E+02, -.67192200E+02, -.13354100E+01, 0.35196100E+01, 0.38059700E+02, 0.12136300E+02, -.50017300E+02, 0.15233800E+02, -.43750900E+01, 0.13096700E+02, -.58403500E+02, -.27385900E+02 },
        { 0.25330000E+00, -.16873000E+01, 0.80715500E+01, 0.51576100E+00, -.31801700E+01, -.76004800E+00, -.38999000E+01, 0.12919700E+01, 0.14732100E+00, -.80213100E+00, -.37594600E+00, 0.12542700E+01, -.10736300E-01, 0.40984800E+00, 0.11046900E+00, -.24768700E-01, 0.22188800E+01, -.58808300E+00, 0.16658000E+00, 0.10929100E+00, 0.93997800E+00, 0.15003200E+01, 0.38520900E+00, 0.87075300E+00, -.14712700E+00, 0.49517000E+00, 0.64330800E+00, -.42551500E+00, -.14616200E+00, -.42124700E+00, 0.64689600E+00, 0.17464600E+00, -.52049700E+00, 0.46706800E+00, -.86779100E+00, 0.10722800E+00, -.18924200E-01, 0.17530000E+00, -.40384600E+00, 0.48844600E+00, -.12055200E+00, -.14872300E+01, -.18500100E+01, -.13053200E+01, 0.76193300E+00, -.26377700E+00, -.28947500E+00, 0.62734400E-01, 0.95140900E-01, -.83395800E+00, -.43228200E+00, 0.80539800E+00, 0.21032100E+00, -.37174800E+01, 0.36435300E+00, -.72865100E+00, 0.14416000E+00, 0.28579800E-02, 0.22096000E-02, -.61345200E+00, 0.53054000E+00, 0.48675600E+00, 0.21758600E+00, -.11756300E-01, -.13126300E+00, 0.23120800E+00, 0.23752300E+00, -.70415400E+00, -.31526900E+00, -.76595600E-03, 0.48100100E+00, 0.19316200E+01, -.87018200E-01, 0.59314900E-02, 0.52115700E+00, -.21975500E+00, 0.27395700E+00, -.14260300E+00, -.82073700E-01, 0.14492000E+03, -.64052000E-01, 0.10177300E+02, 0.96866600E+02, -.86734700E+02, -.17648900E+02, -.75742500E+02, 0.12456800E+03, -.16890700E+02, -.41367200E+03, 0.22256000E+03, 0.27957400E+03, 0.20817600E+03, 0.70995100E+02, -.49367400E+03, 0.39940500E+03, 0.39647900E+02, -.41106600E+02, -.68726700E+03, -.47955800E+03, -.77381200E+03, 0.39014900E+03, 0.15080200E+03, 0.38811700E+03, 0.74294700E+02, 0.24410700E+03, -.10884700E+03, -.90658900E+02, 0.22223500E+03, 0.33029000E+03, 0.91563800E+03, -.37061200E+03, 0.18736400E+03, -.17171900E+03, 0.18523500E+03, 0.55856500E+01, -.13019300E+03, 0.17619500E+03, -.14882800E+02, 0.33729000E+03, -.19467000E+03, -.52183200E+02, 0.48482900E+04, -.24215700E+04, -.14427600E+04, -.24239800E+04, 0.10308300E+03, 0.10272700E+04, -.10940000E+04, 0.58971900E+03, -.14340900E+04, 0.10445100E+04, -.17435800E+04, -.77848300E+03, 0.38156900E+03, -.11408800E+03, 0.38995400E+03, -.24201400E+03, -.38570300E+03, 0.36624700E+03, 0.43768100E+02, 0.47939800E+03, -.41014700E+03, 0.31931200E+03, 0.14098900E+02, -.30585800E+02, 0.45950300E+01, -.77986900E+01, 0.10458200E+03, 0.15355200E+03, -.29179900E+03, -.28612200E+03, -.16915600E+03, 0.20628100E+03, 0.12828200E+03, 0.12344100E+04, -.61895000E+03, 0.22352500E+04, -.61608000E+03, 0.79200900E+03, 0.10525900E+04, -.12903700E+04, -.60640300E+03, -.16096300E+04, 0.73286100E+03, -.16898600E+04, -.13030900E+03, 0.49607300E+02, -.59939100E+03, 0.64373800E+02, -.94112300E+01, 0.29515000E+02, -.11766600E+03, -.45045700E+03, -.33839500E+02, -.14383000E+03, 0.38597600E+03, -.21224500E+03, 0.10802700E+03, 0.16186400E+03, 0.10599300E+03, 0.18812200E+02, 0.57238000E+02, -.53348600E+02, -.20746700E+02, 0.10994500E+03, 0.58819700E+02, 0.95115500E+02, -.78437300E+04, 0.39211400E+04, 0.39686800E+04, 0.39221800E+04, 0.93814500E+03, 0.34557300E+03, 0.75418100E+03, -.21365400E+04, 0.15662400E+04, 0.43834500E+03, 0.24958500E+04, 0.19506100E+04, -.97524000E+03, -.69980200E+03, -.97410600E+03, -.26618300E+03, -.47198500E+03, -.38916000E+02, -.55351100E+01, -.76043500E+02, -.71555600E+03, -.89860800E+03, -.70827100E+04, 0.35403000E+04, 0.49130800E+04, 0.35421400E+04, 0.72885300E+03, 0.61378600E+03, 0.37181400E+03, -.20692200E+04, 0.12841100E+04, 0.73165700E+03, 0.22226700E+04, -.45967200E+02, 0.28661000E+02, 0.27825700E+03, 0.23401200E+02, -.89037600E+02, -.57053500E+03, 0.56855700E+03, 0.75828200E+03, 0.33197800E+03, -.80179900E+03, -.38890400E+03, 0.23659700E+02, -.12465000E+02, 0.17980900E+03, -.11888500E+02, 0.28291000E+02, 0.10954400E+03, -.10282200E+03, 0.55757100E+01, -.98928700E+02, 0.14335200E+03, -.43072500E+02, 0.16905800E+02, -.10843900E+02, -.27564700E+03, -.73893000E+01, -.93543900E+02, -.11948300E+03, -.50118300E+02, -.18841600E+03, -.19527000E+02, -.17624800E+03, 0.11744000E+03, -.50236500E+04, 0.25182000E+04, 0.10299600E+04, 0.25115900E+04, 0.37289800E+03, 0.14010700E+03, 0.77821800E+03, -.68945300E+02, 0.19661900E+04, -.22109300E+02, 0.24088700E+04, -.46050300E+03, 0.22548100E+03, 0.72623900E+03, 0.23050700E+03, -.25257500E+03, -.46976400E+03, 0.24039200E+03, -.18532400E+03, -.56072300E+03, -.26617200E+03, -.45401800E+03, -.40448500E+02, 0.61615100E+02, -.23774000E+02, -.12849400E+03, 0.78521200E+02, -.98501000E+02, 0.83312200E+02, 0.47135500E+02, 0.49590900E+02, 0.79382700E+01, -.11566100E+03, 0.19556900E+03, 0.22599500E+03, 0.79603200E+02, 0.15869400E+02, -.67752000E+02, 0.46352500E+02, 0.56605400E+02, -.42507100E+02, -.72239100E+02, 0.25409700E+03, 0.58862300E+01, 0.19472900E+02, -.33948300E+02, -.15447500E+03, -.20444200E+03 },
        { 0.23170800E+00, -.35760500E+00, 0.19533200E+01, -.99935000E-01, -.13798700E+01, -.19380300E+00, -.19246500E+01, -.26249500E+00, 0.44334600E-01, -.12231100E+00, -.89203900E-02, 0.17055600E+01, -.38945400E+00, 0.28383500E+00, 0.20628400E+00, 0.18729900E+00, 0.17107900E+01, -.25484900E+00, 0.18383300E+00, -.29448700E+00, 0.33746500E+00, 0.87776100E+00, -.12896800E+00, 0.40058500E+00, 0.36953500E+00, 0.64004200E-02, 0.47031600E+00, -.11541500E+00, 0.21543500E-01, -.28264600E+00, -.20049000E+00, -.22278900E+00, 0.42990900E+00, 0.85625400E-01, -.45566500E-01, 0.12106300E-01, 0.42676000E-01, -.10106000E+00, -.30312000E+00, -.66700800E-01, 0.53560600E-01, 0.30770600E+00, 0.79762600E+00, 0.20616900E+00, -.35880000E+00, -.28328500E+00, -.67319700E+00, 0.70043000E-01, -.40039200E-01, 0.16426300E-03, -.21127800E+00, 0.24392300E-02, 0.27675700E+00, -.17902500E+00, -.71205300E-01, -.31076900E+00, 0.13538000E-01, 0.35662600E+00, -.22478100E+00, 0.25511800E-01, -.13173200E+00, 0.46861200E-01, -.48892700E-01, 0.50100800E-01, 0.29512900E-01, -.40392200E-01, 0.30281200E-01, -.21585300E+00, 0.19294100E-01, -.48120100E-03, 0.31778300E+00, -.53932900E-01, -.42242900E-02, 0.17904200E-01, -.92646100E-01, 0.17335600E-01, -.59284200E-01, -.48841900E-01, 0.13506700E+00, -.70754200E-01, 0.34889700E+01, 0.11042500E+01, -.16345400E+02, 0.59232200E+00, -.35442300E+01, 0.75756200E+00, -.12070000E+02, 0.14689300E-01, 0.43089900E+01, -.98271100E+01, -.91466500E+01, -.24172400E+01, 0.45662900E+02, 0.99992300E+02, -.23187200E+02, -.43520300E+02, -.17075300E+02, 0.78410200E+02, -.89199700E+01, -.20250900E+03, 0.99233700E+02, 0.31040200E+02, 0.10101600E+03, -.91892600E+01, 0.16577900E+02, 0.78532500E+02, 0.52204100E+02, 0.11371800E+03, 0.20165700E+02, 0.15228900E+03, -.86333800E+02, 0.41395200E+02, -.10339200E+02, 0.43181200E+02, -.36897000E+02, -.30306000E+02, 0.79156700E+02, 0.68853800E+02, 0.58472500E+02, -.33296600E+02, 0.23950700E+02, 0.12770000E+04, -.63625300E+03, -.66138700E+03, -.63853200E+03, -.20370700E+03, -.81039600E+02, -.24714000E+03, 0.52143600E+02, -.49744600E+03, -.69777900E+02, -.51683500E+03, 0.10554200E+03, -.50239600E+02, 0.39675100E+02, -.52909600E+02, 0.50069900E+02, 0.11573500E+03, -.20795100E+02, 0.13211400E+03, -.32041800E+02, 0.95102400E+02, -.40846500E+02, -.23541500E+03, 0.11415800E+03, 0.12109100E+03, 0.11875400E+03, 0.43401100E+02, -.19494800E+01, 0.79409300E+02, 0.29040800E+02, 0.61065400E+02, 0.72191500E+01, 0.73015300E+02, -.24389700E+03, 0.12150000E+03, 0.52826100E+03, 0.12172600E+03, 0.12993600E+03, 0.65376600E+01, -.15142200E+03, -.38618000E+03, 0.56598600E+01, -.60454200E+01, -.58391000E+02, -.53795500E+02, 0.23763400E+02, 0.89756500E+02, 0.27048000E+02, -.51511400E+02, -.15829000E+01, -.25618900E+02, -.12562800E+03, 0.13829500E+01, -.15056400E+02, -.40802700E+01, 0.14672000E+02, -.77959700E+01, 0.20664000E+01, -.73104300E+01, -.11365900E+02, -.18311600E+02, 0.26634500E+01, 0.15422700E+02, 0.10055000E+02, -.16458700E+02, 0.13007500E+02, -.40911100E+03, 0.20573800E+03, 0.32250300E+03, 0.20449300E+03, -.43534500E+02, -.34462100E+02, 0.92688300E+01, -.11551100E+03, 0.97782200E+02, -.61222900E+02, 0.28007300E+03, -.17538700E+03, 0.84670800E+02, 0.14704900E+03, 0.87461000E+02, 0.11185700E+03, 0.53730700E+02, -.49161300E+02, -.13074800E+03, 0.40589000E+02, 0.15572200E+02, 0.39770200E+02, -.50035400E+03, 0.25133600E+03, 0.20599800E+03, 0.25002100E+03, -.35606900E+02, -.77296300E+02, 0.66929700E+02, -.79672000E+02, 0.13658300E+03, -.82157700E+02, 0.38125900E+03, -.25037400E+03, 0.12626300E+03, -.11359300E+03, 0.12567900E+03, 0.11140300E+03, 0.98863100E+02, -.74717000E+02, -.24599900E+03, 0.42214300E+02, 0.69863300E+02, 0.97012100E+02, 0.22361600E+01, -.23368800E+00, 0.18459100E+01, -.11064400E+01, -.74099800E+00, -.17565200E+02, 0.14863800E+00, -.23376800E+01, 0.41425900E+00, -.13453100E+02, -.34788400E+01, -.19248000E+02, 0.74913600E+01, -.17692600E+02, 0.94148700E+01, -.57827700E+01, 0.32006500E+01, 0.88431100E+01, -.24124600E+02, 0.20699300E+02, 0.37279200E+00, -.24897900E+02, -.11258200E+04, 0.55798800E+03, 0.23132500E+03, 0.56295800E+03, 0.14594400E+03, 0.10240300E+03, 0.33988100E+03, 0.23664100E+03, 0.53535200E+03, 0.10800900E+03, 0.50273800E+03, 0.18856600E+03, -.91222600E+02, 0.55957200E+02, -.94333600E+02, -.57349500E+02, -.44829200E+02, -.18837300E+03, -.28413300E+03, -.17312600E+03, -.64740100E+02, -.65605400E+02, -.26346500E+01, -.23733100E+02, -.79062900E+01, -.32526500E+01, -.25651200E+02, 0.14729600E+02, -.47425800E+01, -.26308200E+02, 0.29712000E+01, 0.26277500E+02, 0.83233600E+01, -.60131300E+02, 0.40709500E+02, 0.15547400E+02, 0.27379600E+02, -.39401500E+02, -.20314100E+01, -.17677500E+02, -.35705700E+02, 0.17594200E+02, 0.38046000E+02, -.24754700E+00, 0.43719900E+01, -.71432400E+01, -.68224300E+02, -.17182900E+02 },
        { -.86324000E+00, -.37436600E+01, -.63316600E+00, -.85238000E-01, 0.19730800E+01, 0.10776900E+01, 0.27381500E+01, -.22222900E+01, 0.35218400E-01, 0.11390600E+01, -.17483000E+00, -.43200000E+01, -.70348000E+00, -.12774300E+01, -.16114500E+01, -.11904500E+01, 0.89387700E+00, 0.12858300E+00, -.12703100E+01, -.56167400E+00, 0.74553400E+00, -.47984100E+01, -.92058300E+00, -.14574100E+01, 0.35990700E+00, -.47286600E-01, -.89159800E+00, -.10683300E+01, -.16490100E+00, 0.15273900E+00, -.89680200E+00, -.60594800E-01, 0.78600500E+00, 0.62086200E+00, 0.51480500E+00, 0.58879900E+00, -.11657200E-01, 0.13480100E+01, -.18065700E+00, -.89088500E-01, -.55386900E+00, -.41531700E+01, 0.66714500E+00, 0.82064100E+00, 0.29096100E-01, -.25624400E+00, -.12167400E+01, 0.91117100E-02, -.49235200E+00, 0.98909800E+00, -.20373300E+01, 0.33782500E+01, 0.93093700E+00, -.38033800E+01, 0.43168100E+00, -.40098400E+00, -.54537300E+00, -.11535300E+01, 0.18241200E-01, -.14832000E+01, 0.22165500E+01, -.24261100E+00, 0.11305700E+01, -.12636900E+01, -.59907000E+00, -.50759200E+00, -.26855900E+00, 0.39107800E+01, -.43377800E+00, -.11508700E-01, -.67707100E+00, 0.18670300E+00, 0.49231400E+00, -.11187700E-02, -.33285600E+01, 0.21519900E+01, 0.12238200E+01, -.23229100E+01, -.24626300E+00, -.84400200E+00, -.85968400E-01, -.65239900E+03, -.11458600E+04, 0.90792600E+03, 0.61944900E+03, 0.78224200E+03, -.94584500E+03, 0.21234300E+03, -.34356800E+04, 0.16631300E+04, 0.24953700E+04, 0.17241300E+04, 0.28624900E+04, 0.56215000E+04, -.30160000E+04, -.49259100E+04, -.59950200E+03, 0.53716300E+04, 0.12027800E+04, 0.22491000E+04, -.11731100E+04, -.34822500E+03, -.11189200E+04, -.86313100E+03, -.88990000E+03, 0.14473100E+04, 0.16108300E+03, -.25455400E+04, -.65673500E+03, -.47525900E+03, -.36829400E+04, 0.18289600E+04, 0.13878100E+04, 0.18411500E+04, 0.95833300E+02, 0.17952900E+03, 0.64569300E+03, 0.58838800E+03, 0.57118000E+03, -.15437700E+03, 0.18539800E+04, 0.58221300E+04, -.30045700E+04, -.58068800E+03, -.29102600E+04, -.37029000E+04, -.26880000E+02, -.52723700E+04, -.24360600E+04, -.40419600E+04, -.72062900E+03, 0.30230700E+03, 0.10424400E+04, -.45200300E+03, 0.13611200E+03, -.51788100E+03, 0.33957900E+03, 0.27077000E+04, -.33809300E+04, 0.15667300E+03, -.85263100E+03, 0.20681900E+04, -.16284900E+03, -.19731200E+04, 0.84775500E+03, -.16798400E+03, 0.98020800E+03, 0.49767700E+03, -.75074500E+03, 0.21168700E+04, -.13849200E+03, 0.87835800E+02, -.28227200E+03, 0.71396400E+03, 0.17953700E+04, -.82857900E+03, 0.19172800E+04, -.89249200E+03, -.58178500E+03, -.59948000E+04, 0.78888200E+04, 0.23219400E+04, 0.57228100E+04, -.52473500E+04, -.23649900E+04, 0.13569200E+04, -.57363700E+03, 0.52551000E+03, -.68215000E+03, 0.20904500E+04, 0.31499400E+04, -.28193400E+04, -.44915600E+04, -.31524200E+04, 0.22677500E+04, -.17285600E+04, 0.18075000E+04, -.93221900E+03, -.13061400E+04, -.90435700E+03, -.67711700E+03, -.10846300E+04, 0.51520000E+03, 0.15217100E+04, 0.11754000E+04, -.10045300E+04, 0.81338900E+02, -.12561100E+05, 0.62810500E+04, 0.38067500E+04, 0.62820100E+04, -.24115600E+04, -.68706000E+03, 0.28984700E+04, 0.33984400E+04, 0.72417800E+04, -.25425200E+04, 0.12355000E+05, -.82785300E+03, 0.49282100E+03, 0.30704900E+04, 0.41954700E+03, 0.33731600E+04, 0.31256200E+04, -.10224600E+04, -.98210600E+03, -.12730800E+04, 0.18076500E+04, -.13819700E+04, -.48902900E+04, 0.24473400E+04, 0.64938900E+04, 0.24487700E+04, 0.13690800E+04, 0.59920200E+04, 0.84652200E+03, 0.58382000E+04, 0.58968000E+04, 0.24365900E+04, 0.99505200E+04, -.40097000E+04, 0.20346000E+04, -.74028100E+02, 0.20079900E+04, 0.21797400E+04, 0.34560600E+04, -.34125200E+03, -.22192000E+04, 0.30308700E+04, 0.28593400E+04, 0.10373600E+04, 0.98059500E+02, -.49088300E+02, 0.69917400E+02, -.49303800E+02, -.69653000E+03, -.11849900E+04, 0.10251300E+04, 0.76749000E+03, 0.82646500E+03, -.10273600E+04, 0.13011900E+03, -.14261800E+03, -.24076500E+02, -.11929600E+04, 0.76270000E+02, 0.10481900E+04, 0.12821600E+04, -.15640300E+04, -.40086000E+04, -.18220700E+04, 0.12686500E+04, -.36745700E+03, 0.10711300E+05, -.54102400E+04, -.30285300E+04, -.53567500E+04, 0.11061500E+04, -.16629500E+04, 0.31969500E+04, 0.68691300E+04, -.36498800E+03, -.54819700E+02, -.73246900E+04, -.10345300E+05, 0.52397700E+04, 0.33146700E+04, 0.51738400E+04, -.62149300E+03, 0.33030200E+04, -.32318800E+04, -.71835500E+04, 0.22709300E+04, 0.11519300E+04, 0.80509700E+04, -.58742400E+02, -.16462000E+04, -.81882400E+03, -.23020400E+03, -.80375900E+03, 0.70562400E+03, 0.36702800E+03, -.17139300E+04, 0.28641100E+02, 0.65244200E+03, 0.98168000E+03, -.17116500E+04, 0.35133600E+03, 0.12440500E+04, 0.85151600E+03, 0.10242400E+03, 0.12363800E+04, -.11261800E+04, -.50561700E+04, 0.19955300E+02, 0.41714800E+04, -.22264900E+03, 0.24374300E+03, -.52550600E+03, 0.63796100E+02, 0.16407200E+04 },
        { -.14683200E+00, 0.26568600E+00, -.30141500E+00, -.58528400E-01, 0.85657500E+00, 0.46669300E+00, 0.11282000E+01, -.22210800E+01, -.22208100E+00, 0.74963200E+00, -.27576900E-01, 0.10806800E+01, 0.19597800E+00, 0.52497200E+00, -.73907800E+00, -.38507300E+00, -.10832400E+01, 0.93257500E-01, -.36841300E+00, -.17887400E+00, -.55976400E+00, 0.22264600E+01, 0.55487200E-02, -.92909300E+00, -.73555100E-01, -.19747300E+00, -.16317400E+00, 0.41343700E+00, 0.26013000E+00, 0.25969000E-01, 0.49711600E-01, -.89133600E-01, -.38789600E+00, 0.21997600E+00, 0.39849600E-01, 0.22251800E+00, -.25256600E-01, 0.24834600E+00, 0.37670000E-01, 0.23070100E+00, 0.61023700E-01, -.17413400E+00, 0.10981100E+00, 0.29875300E+00, -.13484100E+00, 0.67399500E-01, 0.35255100E+00, -.18295100E-01, -.76644000E-01, 0.44289000E+00, 0.75142400E-01, -.51554000E-01, -.18337600E-01, 0.21285500E+01, -.40323200E-01, 0.78923000E+00, -.23291200E+00, -.31100300E-01, -.81052900E-01, -.26349100E+00, 0.22562600E+00, -.46480700E+00, 0.24684600E+00, -.65641400E-01, -.45400800E-01, -.76205200E-02, -.50923400E-01, 0.19239600E+00, 0.16645000E+00, 0.13777000E-02, -.41784600E+00, -.80628100E+00, 0.89017900E-01, -.28628800E-01, -.38810000E+00, -.36568300E+00, -.66410100E-01, 0.67415500E+00, -.14855200E+00, -.78700900E-01, -.10878900E-02, -.95906200E-01, -.13741700E+03, 0.59205600E+02, 0.20640700E+02, 0.72356800E+02, -.12414400E+03, -.15872900E+02, 0.57728300E+03, -.29570600E+03, 0.29319900E+03, -.28795600E+03, 0.19764500E+03, 0.13409700E+04, -.69485200E+03, -.88351400E+03, -.53641900E+03, 0.12499500E+04, -.59096000E+03, 0.54884700E+03, -.27867400E+03, -.22692400E+03, -.27382600E+03, -.16716100E+03, -.15392400E+03, -.17553700E+03, -.70928500E+02, -.60868100E+03, -.10228000E+03, -.22754100E+03, -.12393700E+04, 0.62015200E+03, 0.73993200E+03, 0.61965300E+03, -.32958300E+02, -.24733100E+03, 0.34686300E+03, 0.12963900E+03, 0.35585600E+03, -.24467900E+03, 0.34905600E+03, -.47278500E+03, 0.22313100E+03, 0.24011000E+03, 0.23647700E+03, -.20890800E+03, 0.44313600E+03, -.37566600E+03, 0.38137000E+03, 0.72305800E+02, 0.47594400E+03, 0.12727900E+04, 0.14532200E+03, -.62347700E+02, -.56994400E+01, -.72305000E+02, -.35763800E+02, 0.35906800E+03, -.37417000E+03, -.48756100E+02, -.11115900E+03, 0.27139700E+03, -.36322100E+02, -.46531000E+02, 0.22022900E+02, 0.78569500E+02, 0.22129100E+02, 0.28831900E+02, -.14703700E+03, 0.20715800E+03, 0.15186500E+03, -.97425400E+01, -.80166700E+02, 0.49739400E+02, 0.92656600E+02, -.42630200E+02, 0.48114400E+03, -.45784800E+02, -.98457900E+02, -.84986500E+03, 0.82873000E+03, -.47516200E+03, 0.56119500E+03, -.82367600E+03, 0.55537600E+02, 0.36020500E+02, 0.53567600E+01, 0.66736700E+02, -.18400200E+02, 0.96064600E+01, 0.45053600E+03, -.31757700E+02, 0.60695200E+01, -.19849100E+03, 0.35561700E+03, 0.98759200E+02, 0.15230000E+03, -.79429400E+02, -.18293000E+03, -.76215600E+02, 0.42029100E+02, -.71921600E+02, -.13923500E+02, 0.10463600E+03, 0.45728600E+02, -.70239200E+02, 0.14141900E+02, -.30498700E+04, 0.15238500E+04, -.20796700E+03, 0.15250800E+04, 0.57530400E+03, 0.38540100E+03, -.29743200E+03, 0.36189400E+02, 0.60821500E+03, 0.25548900E+03, 0.21805900E+04, -.16610200E+04, 0.83915600E+03, 0.97443500E+03, 0.83110500E+03, 0.15148600E+03, 0.27803000E+02, 0.62908400E+03, 0.48684100E+03, 0.67203400E+03, -.16236100E+03, 0.10278100E+04, 0.69434100E+03, -.34700300E+03, 0.16602100E+04, -.34679300E+03, 0.13499000E+04, 0.22816300E+04, -.15872700E+04, 0.44797100E+03, -.72377100E+03, 0.17639700E+04, 0.34366700E+03, 0.26961300E+03, -.13496100E+03, -.35370500E+03, -.13476100E+03, 0.90595900E+02, 0.59208800E+03, -.16960000E+03, -.55543700E+03, 0.31550600E+03, 0.44589500E+03, -.51329400E+02, 0.21290100E+02, -.11699100E+02, 0.68325700E+01, -.10674900E+02, -.75913600E+00, -.12656000E+03, 0.58393900E+02, 0.11682300E+02, 0.64220400E+02, -.11494300E+03, -.14663300E+02, -.28357600E+03, 0.13756500E+03, 0.12914700E+02, 0.14231700E+03, -.70777200E+02, -.87579700E+02, 0.18984200E+03, -.98711100E+02, 0.53010400E+02, -.40682900E+02, 0.10074700E+03, 0.18817400E+04, -.94203100E+03, 0.17752300E+03, -.94098500E+03, 0.36767600E+03, 0.10256300E+03, -.31698700E+03, -.37439300E+00, -.41036500E+03, -.51571500E+02, -.18109600E+04, -.52219300E+03, 0.26419200E+03, -.53676400E+03, 0.26122200E+03, -.14544400E+03, 0.50843800E+02, 0.24703700E+03, -.12443100E+03, 0.47099200E+03, 0.25002600E+02, 0.64520000E+03, 0.88195900E-01, 0.30927400E+01, 0.43450800E+02, -.27702200E+02, -.89364000E+01, 0.32369700E+02, -.72002800E+02, 0.71937100E+01, 0.69906300E+01, 0.20555600E+03, 0.66538400E+02, -.25086800E+03, 0.15054900E+03, 0.55556200E+02, 0.26774600E+02, -.59509600E+02, -.62942100E+02, -.84515800E+02, -.32114100E+03, 0.52639200E+02, 0.25977000E+03, -.76393800E+02, 0.28375600E+02, 0.23121000E+02, 0.20037100E+03, 0.20444600E+03 },
        { -.34673400E+00, 0.68227000E+00, -.66674000E+01, -.14248900E+01, 0.24415200E+01, 0.36277800E+00, 0.14178900E+01, -.28972600E+01, -.10220100E+01, 0.29996500E+00, 0.41171400E+00, 0.64989800E+00, 0.16482400E+00, 0.10463500E+01, -.38980400E-01, -.58898300E+00, 0.18317100E-03, 0.11442500E+00, 0.12338600E+01, -.40532000E+00, -.35979000E-01, -.44910700E+00, -.27279300E+00, 0.64537700E+00, 0.42680900E+00, 0.25058600E+00, 0.14055600E-02, 0.80158300E+00, 0.21889200E+00, -.30384600E+00, 0.69233100E+00, -.46786500E+00, -.14931600E+01, 0.66003500E+00, 0.81540300E+00, -.84571100E+00, 0.64345000E-02, 0.39574700E+00, 0.63335600E+00, -.15091800E+00, 0.47132900E+00, -.13283000E+01, -.17164000E+01, -.10382500E+01, -.19085900E+00, -.28541600E+00, 0.10043500E+01, -.29392900E-01, 0.25545400E+00, -.57507300E+00, -.13966100E+01, 0.15903100E+01, 0.73445500E-02, -.35378500E+01, -.86048000E+00, -.11399000E+00, 0.10684300E+00, 0.12850100E+01, 0.14230400E+00, -.12952400E+00, -.25998100E+00, 0.15480700E+00, 0.29182900E+00, 0.24903200E+00, -.42502900E-01, 0.53880300E+00, 0.28740100E+00, 0.10618200E+01, -.56463700E+00, -.69882100E-02, 0.72189900E+00, -.32392100E+00, -.18343100E+00, -.19582600E+00, 0.11633300E+01, -.82647000E+00, -.57529000E-01, -.51384600E+00, -.17065800E+00, 0.59769600E+00, 0.18766300E-01, 0.43125400E-01, -.92590800E+00, 0.21393500E+03, 0.21959800E+03, -.55411200E+01, -.50601100E+02, -.91698300E+02, 0.10734100E+04, -.49363500E+03, -.81191600E+03, -.53766600E+03, -.34406900E+03, -.85772000E+02, -.10693600E+04, -.12691100E+04, -.24513300E+03, 0.13165600E+03, 0.39495000E+03, 0.60230800E+03, -.28444200E+03, -.14807800E+03, -.30210600E+03, 0.14698300E+03, 0.29084400E+03, -.59950600E+03, -.45367500E+03, -.57576300E+03, 0.73838500E+02, -.12532300E+04, 0.62574000E+03, -.30593300E+03, 0.21026900E+02, -.31280000E+03, 0.25887400E+03, 0.22103000E+03, -.72333200E+03, -.66204200E+03, -.46684300E+03, 0.30068900E+03, -.68600700E+03, -.62633800E+04, 0.31400900E+04, 0.33080800E+04, 0.31315600E+04, 0.18944500E+04, 0.13941800E+04, 0.10199800E+04, -.48162000E+03, 0.16277500E+04, 0.99251800E+03, 0.33683400E+04, 0.60295300E+03, -.32788100E+03, -.58742700E+03, -.30201000E+03, -.29633300E+03, -.56192400E+03, -.42898800E+03, -.10740700E+04, -.30701600E+03, -.40665700E+03, -.21394400E+02, -.86486000E+03, 0.45697300E+03, 0.39974300E+03, 0.43346200E+03, 0.18488300E+03, -.74948100E+02, 0.63873400E+02, -.19048800E+03, 0.17855400E+03, -.12907000E+03, -.53524000E+03, 0.20751700E+04, -.10407900E+04, -.23599900E+04, -.10385300E+04, -.54870900E+03, 0.22332700E+02, 0.16142100E+04, 0.22458700E+04, -.10214600E+03, -.28062800E+02, -.53087700E+03, 0.71009100E+03, -.37802800E+03, -.14494800E+03, -.35448200E+03, 0.76376100E+02, -.10196000E+03, -.19306700E+03, 0.15953700E+03, -.47888200E+02, -.74033600E+01, -.42414600E+03, 0.17836200E+02, -.20101100E+01, -.53889500E+02, -.88208100E+01, -.15242000E+03, -.23858500E+03, 0.33663900E+03, 0.13256400E+03, -.11766900E+03, -.20643100E+03, -.10443400E+03, 0.75763800E+04, -.37919700E+04, -.32361300E+04, -.37884600E+04, -.91878500E+03, -.61558900E+03, 0.18383300E+03, 0.25462900E+04, -.25001900E+04, -.45459200E+03, -.25653000E+04, -.10612400E+04, 0.53106300E+03, 0.27716200E+03, 0.52972400E+03, 0.10446600E+03, 0.23834900E+03, -.19987300E+03, -.39622900E+03, -.47135100E+03, 0.48627600E+03, 0.77025700E+03, 0.56278400E+04, -.28195300E+04, -.35970400E+04, -.28145900E+04, -.10403800E+04, -.10431400E+04, 0.46618500E+03, 0.19654100E+04, -.20711900E+04, -.84225200E+03, -.18407900E+04, 0.50413700E+03, -.25988100E+03, -.27908600E+03, -.25130200E+03, -.11920900E+03, 0.56226100E+03, -.63692700E+03, -.81819800E+03, -.79256400E+03, 0.77027900E+03, 0.91463100E+03, 0.29466700E+02, -.16981900E+02, -.29477900E+02, -.14689800E+02, -.45200100E+01, 0.70458000E+01, 0.24003500E+03, 0.22139200E+03, -.84332200E+01, -.48371200E+02, -.95120300E+02, 0.98922200E+03, -.47767200E+03, -.30880800E+02, -.49542900E+03, 0.12117800E+03, -.14758300E+03, -.20423600E+03, 0.10646600E+03, -.11821200E+03, -.11628200E+03, -.60052200E+03, 0.87859600E+04, -.43672600E+04, -.31964800E+04, -.43927900E+04, -.93545500E+03, -.91465000E+02, -.30877600E+04, -.73582800E+03, -.28197500E+04, -.32278700E+02, -.49294500E+04, -.19033000E+04, 0.93307400E+03, 0.70299100E+03, 0.95144500E+03, -.18144900E+03, -.10796300E+04, 0.24687300E+04, 0.12771900E+04, 0.11109000E+04, -.80395900E+03, 0.15526300E+04, 0.12906900E+02, -.86410600E+02, 0.66389600E+01, -.41541500E+02, -.10689100E+03, 0.13245500E+03, -.22933100E+03, -.59223300E+02, 0.46117900E+02, -.87688900E+02, 0.23216800E+03, 0.54679500E+03, -.68839200E+02, 0.10996100E+03, 0.13707400E+03, 0.25867800E+03, -.65120600E+02, 0.40526900E+02, 0.55510100E+03, 0.22962600E+03, -.56638800E+03, -.34592500E+02, 0.57732400E+02, 0.84926300E+02, 0.26547900E+03, 0.19297800E+03 },
        { 0.56036900E+00, -.15672700E+01, -.10198200E+01, 0.99141800E-01, 0.11413300E+01, 0.58162400E+00, 0.17455400E+01, -.13724500E+01, 0.32087200E+00, 0.25774800E+00, -.28735900E+00, 0.34549100E+01, -.62946300E+00, 0.96370500E+00, -.11028400E+01, -.37066000E+00, -.24403000E+01, 0.27625500E+00, -.70530900E-01, -.21745500E-01, -.14538900E+00, 0.21902900E+01, -.23062800E-01, -.68687100E+00, -.16715800E+00, -.28670900E+00, -.25414700E+00, 0.20219400E+00, 0.33783100E+00, 0.72267800E-01, -.87294300E-01, -.13693000E+00, -.98825600E+00, 0.59622900E-01, 0.56103300E-01, -.18383000E+00, -.16790600E-01, -.49761300E-01, 0.19456800E+00, 0.66998600E-01, -.31883900E+00, 0.13852400E+01, -.10567400E+01, 0.45953300E-01, -.14266500E+01, -.37637400E+00, -.21518800E+00, -.59447500E-01, 0.17846800E+00, -.40805500E+00, 0.72942900E+00, -.12756000E+01, -.42340100E+00, -.22138000E+01, -.16420900E+01, 0.20528300E+01, 0.95677900E-02, 0.93086800E+00, -.26917700E+00, 0.13606800E+01, -.15504200E+01, -.50895600E+00, -.78941100E+00, 0.36463500E+00, 0.24259000E+00, 0.15970900E-01, -.32040300E+00, 0.75659200E+00, 0.66770200E+00, 0.20491300E-02, 0.28814600E+01, -.15013300E+01, -.20287600E+00, -.10701700E+00, -.38273400E+00, -.11211000E+01, 0.61885700E+00, 0.33178700E+00, -.66196400E+00, -.93206600E-03, -.48025400E-01, 0.21955100E+00, -.86703200E+00, 0.84615300E+00, -.23714500E+03, -.59396800E+02, 0.18012500E+02, -.92168500E+02, 0.16472500E+04, -.77090300E+03, -.53066700E+03, -.82012600E+03, 0.37344100E+03, 0.32729400E+03, -.72370300E+03, 0.71450500E+03, 0.79636400E+02, 0.31696400E+03, -.59050800E+03, 0.24263300E+04, -.11930600E+04, -.89631900E+03, -.12098500E+04, -.10936400E+03, -.27885000E+02, -.63084300E+03, -.29733800E+02, -.16380300E+04, -.17888400E+03, -.14816700E+04, 0.20295200E+03, -.94850600E+02, 0.53735600E+03, -.10169300E+03, 0.15789900E+03, -.40218500E+02, -.34126500E+03, 0.62016100E+02, -.18875200E+03, -.13318700E+03, 0.25849600E+03, -.15243000E+05, 0.76067600E+04, 0.91626300E+04, 0.76219900E+04, 0.23418600E+04, 0.11924800E+04, 0.24347900E+04, -.13732500E+04, 0.45667000E+04, 0.11046900E+04, 0.68170100E+04, -.75435900E+02, 0.33904700E+01, -.71036900E+03, 0.39635100E+02, -.80687000E+03, -.95303700E+03, -.90237100E+01, -.11628700E+04, 0.27708000E+02, -.87830400E+03, 0.29940800E+03, 0.72944700E+03, -.33319700E+03, -.58339900E+03, -.37009200E+03, -.34028000E+03, 0.47398500E+03, -.57663300E+03, -.35830000E+03, -.18278600E+03, 0.36464300E+03, 0.14919500E+03, 0.88485200E+03, -.42568300E+03, -.32631700E+04, -.43927200E+03, -.16866000E+04, -.16862600E+04, 0.25555800E+04, 0.22378500E+04, 0.11283700E+04, -.96093900E+03, -.84895700E+03, 0.37898200E+03, -.20810200E+03, -.78850000E+02, -.19159100E+03, 0.25048900E+02, 0.53119600E+03, 0.81859800E+03, 0.22799800E+04, 0.37051500E+03, 0.42022200E+03, 0.14757900E+03, -.33657400E+02, 0.23120600E+02, -.16993600E+03, 0.16483500E+02, 0.89829700E+02, 0.58243400E+01, 0.65642100E+02, -.31121500E+03, -.22330200E+03, 0.37826700E+02, -.25803800E+03, 0.51214800E+04, -.25665400E+04, -.44246700E+04, -.25598500E+04, -.29847700E+03, -.28075000E+04, 0.17169600E+04, 0.29342200E+04, -.71130000E+03, -.21378000E+04, -.55017700E+04, -.82882000E+03, 0.42600500E+03, 0.43711500E+03, 0.41764700E+03, -.85388500E+03, 0.40794800E+03, 0.66095700E+03, 0.21573400E+04, 0.36995800E+03, 0.35934200E+03, 0.94812200E+03, 0.87345400E+04, -.43761700E+04, -.28484500E+04, -.43650400E+04, -.20257200E+03, -.12961400E+04, 0.57778200E+03, 0.30202000E+04, -.22874200E+04, -.10739800E+04, -.78777100E+04, 0.22825800E+04, -.11520300E+04, 0.18272600E+04, -.11411500E+04, 0.70924100E+02, -.49522900E+03, -.62465100E+03, 0.11790800E+04, -.84539800E+03, -.28590400E+03, -.11211400E+04, -.37107000E+02, 0.14932600E+02, 0.10055400E+02, 0.18398400E+02, 0.12992000E+02, -.88279500E+01, 0.46730300E+02, -.24655200E+03, -.42013100E+02, 0.13324300E+02, -.89162600E+02, -.59089400E+03, 0.29749900E+03, 0.70833100E+03, 0.29832400E+03, -.32704200E+03, 0.82252200E+01, 0.29992800E+03, 0.45803400E+03, 0.38446600E+03, -.38984000E+00, 0.55653600E+03, 0.18897100E+05, -.94109900E+04, -.58723500E+04, -.94491700E+04, -.87372400E+03, 0.26898200E+03, -.48931900E+04, -.70578800E+03, -.71135400E+04, -.11678500E+03, -.90666500E+04, -.43222200E+04, 0.21395900E+04, 0.52867500E+03, 0.21618100E+04, 0.13128500E+03, -.92014600E+03, 0.29245100E+04, 0.17591300E+04, 0.30720500E+04, -.59626900E+03, 0.21939300E+04, 0.15444900E+02, 0.12469000E+03, 0.15136000E+03, 0.16807400E+03, 0.99850600E+02, 0.12447900E+02, 0.53075100E+02, 0.17201200E+03, -.48303300E+02, -.14397800E+03, 0.91582100E+02, 0.26023000E+01, -.74632400E+03, -.64125000E+02, -.28821000E+03, 0.14681500E+03, -.29361900E+03, 0.76275500E+02, 0.61236600E+03, -.28567300E+03, -.67204500E+03, 0.12519600E+03, -.49709000E+02, 0.28916600E+02, 0.33454900E+03, 0.27845600E+03 },
        { -.55567600E+00, -.33911600E+01, 0.10625300E+01, -.36897000E+00, 0.18786900E+00, 0.82288300E+00, -.34011800E+00, -.80173600E+00, -.31453400E+00, -.14669900E+00, 0.22843900E+00, 0.32491400E+01, 0.11080000E+00, 0.17203100E+01, -.39558300E+00, -.14913600E+00, 0.28466700E-01, 0.94317700E-01, 0.74392800E+00, -.11820100E+00, -.19789300E+00, 0.26292600E+01, -.99251200E-01, -.28524100E+01, 0.11636600E-01, 0.81567600E-02, -.13674100E+00, 0.19370300E+01, 0.20871000E+00, -.42789300E+00, -.88936300E-01, 0.17944100E+00, -.12815000E+01, 0.56312800E+00, -.19261600E+00, 0.93112900E-01, -.82096800E-01, 0.15616900E+00, -.62103200E+00, 0.12121000E+01, 0.79145600E+00, 0.92087300E+00, 0.13982600E+01, 0.80757900E+00, -.14235700E+01, 0.22438200E+00, 0.34313600E+00, -.53746900E-01, -.35160700E+00, 0.82285900E+00, -.80062400E+00, -.40248900E+00, 0.15274800E+00, 0.23782400E+01, 0.88276700E+00, 0.66434900E+00, -.69159400E+00, 0.11284600E+01, -.18706700E+00, 0.33128600E+00, -.17511900E+00, -.49843700E+00, 0.36171700E-02, -.22723000E+00, 0.12491600E-01, 0.58870600E+00, -.96281300E-01, -.26471400E+00, 0.16251400E+00, -.18334900E-02, 0.15182400E+01, 0.12449000E+01, -.10910600E+00, 0.21110400E+00, -.34056200E+00, 0.57973300E+00, 0.47239400E+00, -.30397800E-01, -.32183400E+00, -.94613700E-01, -.36154300E-01, 0.13954800E+00, -.99771400E+00, 0.40567000E+00, -.83607000E-02, 0.15396500E+03, -.69810500E+01, 0.34799000E+02, -.13889900E+04, 0.66106800E+03, 0.11920000E+04, 0.69733100E+03, -.36859700E+03, -.74933100E+03, 0.96290200E+03, 0.73976400E+03, 0.72795900E+03, -.79893300E+03, 0.16950100E+03, 0.49368900E+03, -.28238800E+03, -.93573100E+02, -.24421100E+03, -.22956000E+03, -.69789000E+02, 0.21543600E+03, -.17596200E+03, -.36807600E+03, 0.16712300E+03, 0.43542500E+03, 0.51494400E+03, -.25884200E+03, -.32391500E+03, -.25763900E+03, -.26534400E+03, -.12009000E+03, 0.28982800E+03, 0.60711300E+03, -.94109600E+02, -.13450900E+03, 0.99358500E+02, 0.41397900E+04, -.20906600E+04, -.12945400E+04, -.20695300E+04, -.11539100E+04, -.83818800E+03, 0.18571100E+02, 0.28266200E+04, -.19416600E+03, -.67007600E+03, -.23092800E+04, 0.26790100E+03, -.91739300E+02, 0.86234500E+02, -.13242100E+03, 0.71874800E+02, 0.54634000E+03, -.27938100E+03, 0.66734800E+03, -.64335100E+02, 0.43377700E+03, -.11340100E+03, 0.22200500E+03, -.12922600E+03, -.30258100E+03, -.11474400E+03, 0.40510700E+02, -.10894900E+03, 0.40021000E+03, 0.19629500E+03, -.13388900E+03, -.36858100E+02, 0.45796100E+03, -.10876900E+04, 0.54148900E+03, 0.19440000E+04, 0.54633300E+03, 0.78519300E+03, 0.33499400E+03, -.62856300E+03, -.22622000E+04, 0.59490200E+03, 0.13925100E+03, 0.41191700E+03, -.59159200E+03, 0.36078900E+03, 0.11812300E+03, 0.29413200E+03, 0.15803600E+02, -.66079100E+02, -.25595300E+03, -.11799600E+04, -.40599100E+03, 0.11799700E+03, 0.27533400E+03, -.11747600E+02, -.56257700E+01, -.13863800E+03, 0.55960300E+01, 0.83013400E+02, 0.25013200E+02, -.11668600E+03, 0.40621000E+02, 0.21586600E+03, -.11494000E+02, 0.10631500E+03, -.18644500E+04, 0.92776300E+03, -.16874100E+04, 0.93292100E+03, 0.80393400E+03, 0.24346200E+03, -.99441100E+03, -.71565400E+03, 0.10536200E+04, 0.12014700E+03, 0.10044800E+04, 0.81872800E+02, -.19999000E+02, 0.47614900E+03, -.38363600E+02, 0.55572500E+03, 0.21224000E+03, -.60964200E+03, -.48037900E+03, 0.10303700E+03, 0.12277500E+03, -.38840400E+02, 0.46775600E+04, -.23347200E+04, 0.89858900E+03, -.23370300E+04, 0.98515500E+03, 0.19233100E+04, -.23476400E+04, 0.24744500E+03, -.12000900E+04, 0.14045500E+04, -.20059300E+04, -.56803500E+02, 0.26824800E+02, 0.26559900E+03, 0.28789800E+02, 0.14333300E+03, -.20350800E+03, -.15533000E+03, 0.36064200E+03, 0.91184100E+03, -.43958900E+03, -.62610800E+03, -.13476300E+01, -.11726900E+01, 0.35081900E+02, 0.54844800E+00, 0.10151800E+02, 0.92852100E+01, -.15822400E+02, -.18129500E+02, 0.14654100E+03, 0.82093700E+01, 0.43091700E+02, -.31666800E+03, 0.13455800E+03, -.34985000E+03, 0.16063100E+03, -.17503000E+02, -.17051400E+03, 0.69892300E+02, -.43346100E+03, -.92601200E+02, -.92359700E+02, 0.96184500E+02, -.61306200E+04, 0.30381200E+04, 0.33745100E+04, 0.30648000E+04, 0.21950900E+03, -.17672600E+03, 0.17856500E+04, -.15952400E+04, 0.63566600E+03, -.25794800E+02, 0.32420500E+04, 0.30997700E+04, -.15372200E+04, -.26755300E+04, -.15493300E+04, 0.38151700E+03, 0.71611100E+03, -.17797700E+04, 0.47040400E+03, 0.50098700E+03, 0.27885900E+03, -.16538400E+04, -.36298500E+01, -.12643200E+03, 0.12210700E+03, -.11174800E+02, 0.75862500E+02, -.28995500E+02, 0.13507200E+03, -.12039700E+03, -.47335200E+02, -.66395300E+00, -.10204100E+03, -.20668400E+03, 0.49360700E+03, 0.10094000E+02, -.80156600E+02, -.23122100E+03, 0.53409600E+02, -.76656300E+02, -.54027600E+03, -.38625400E+02, 0.51505000E+03, -.13131300E+02, -.30691500E+02, 0.12332700E+03, 0.31917900E+03, 0.24167700E+03 },
        { 0.84729100E-01, -.31549500E+00, -.81200500E-01, 0.50572900E-01, -.15365600E+00, -.12697400E+00, -.32806300E+00, -.74163000E-01, 0.32511400E-01, -.26094100E+00, -.32275700E-01, 0.71815700E+00, -.14508700E+00, 0.42648300E+00, 0.24896100E+00, -.25136000E+00, 0.61695400E+00, 0.17329700E-02, 0.46848900E+00, -.44257400E+00, 0.78970600E+00, 0.77462900E+00, -.12051600E-01, -.13126200E+00, 0.61873900E-01, -.74592300E-01, -.34641200E-01, 0.17995300E+00, 0.95392700E-01, -.93808300E-01, -.26116300E-01, -.11475900E+00, -.88993600E-01, 0.14313700E+00, 0.11577300E-01, -.86772600E-02, 0.19365600E-02, -.75547200E-01, 0.63006100E-01, -.11378700E+00, 0.12067700E+00, 0.17819000E+00, -.60500700E+00, 0.10073200E+00, -.77242800E-01, 0.45368000E-01, 0.18706300E+00, -.36864700E-02, -.12607900E+00, 0.17899000E+00, -.43455600E-01, 0.22586600E+00, -.30973200E-01, 0.10191000E+00, -.79404900E-02, 0.16158300E+00, -.45367600E-01, -.12898100E+00, -.16145200E-01, 0.68690300E-01, 0.65618300E-01, -.98688700E-01, 0.60941500E-01, -.90584000E-01, -.21219700E-01, -.63034400E-01, -.68808000E-02, 0.21640600E+00, -.46944300E-03, 0.12810500E-02, -.23645900E-02, 0.16967300E+00, -.37175300E-01, -.13120800E-01, -.22364200E+00, 0.20686600E+00, 0.12222700E+00, -.29452800E+00, 0.12227400E+00, -.23194600E+00, -.10851100E-01, 0.70941400E-01, -.20679500E+00, 0.38477200E-01, -.10890500E+00, 0.14329900E+00, -.23971600E+02, -.89080300E+01, 0.30942500E+02, -.11323100E+02, 0.19154600E+03, -.14981600E+02, -.97959900E+01, 0.50789400E+02, -.69579800E+02, -.12152000E+03, -.58694500E+02, 0.17017500E+03, -.17747700E+03, 0.20619000E+03, -.97423600E+02, -.21386700E+02, -.10262300E+03, -.14566400E+02, 0.40776100E+02, -.24118200E+03, -.24575900E+03, -.34433200E+03, 0.92854100E+02, -.19624400E+03, -.35924800E+03, 0.17889400E+03, 0.28867400E+03, 0.17959200E+03, 0.26425000E+02, -.19147400E+01, -.44432900E+02, -.19339600E+03, -.11692600E+02, 0.77411200E+02, 0.12621400E+03, -.15389200E+04, 0.77082500E+03, 0.93164700E+03, 0.76952700E+03, 0.34164400E+03, 0.37914200E+03, 0.15083100E+03, -.72267400E+02, 0.43535600E+03, 0.15209500E+03, 0.71778200E+03, 0.50606300E+02, -.33135200E+02, -.12817700E+03, -.25031900E+02, -.13305200E+03, -.12760600E+03, -.30692900E+00, -.17101000E+03, -.43179000E+01, -.87835000E+02, -.19762000E+02, -.12720800E+03, 0.66047500E+02, 0.75863200E+02, 0.63101000E+02, 0.60182800E+02, 0.91210700E+02, -.14376100E+03, -.15526200E+03, -.67541600E+02, 0.10153000E+03, -.14719500E+02, -.11931100E+03, 0.63002300E+02, -.36085300E+03, 0.60109100E+02, -.22495800E+03, -.30439700E+03, 0.40937400E+03, 0.29042900E+03, 0.26218500E+03, -.30742300E+03, 0.12043900E+03, -.66723400E+02, 0.19438600E+02, -.28732200E+02, 0.33065300E+02, 0.19814300E+02, 0.12787700E+03, 0.59041600E+02, 0.91475500E+02, 0.33210100E+02, 0.19374800E+03, 0.20578300E+03, 0.37483000E+02, -.16974200E+02, -.54917300E+02, -.18790100E+02, 0.22014400E+02, 0.11635300E+02, 0.72910800E+01, 0.25646000E+02, -.61251300E+01, -.87441500E+01, -.31981300E+02, -.32639500E+03, 0.16404600E+03, -.53137200E+03, 0.16332600E+03, 0.11359500E+03, -.14651500E+03, 0.20468200E+03, 0.26935000E+03, 0.47839300E+02, -.16627100E+03, 0.18128300E+03, -.21630000E+03, 0.10480800E+03, 0.22960600E+02, 0.10860900E+03, -.39885000E+02, 0.44382600E+01, 0.20167800E+03, 0.31041800E+03, 0.89453100E+02, 0.23624800E+02, 0.16883700E+03, 0.98386000E+03, -.49274400E+03, 0.15752600E+03, -.49160900E+03, 0.24196700E+03, 0.40674900E+03, -.24189900E+03, 0.38488500E+03, -.42770000E+03, 0.26567200E+03, -.53241400E+03, 0.41907100E+03, -.20976400E+03, 0.89426600E+02, -.20948300E+03, -.10438300E+03, -.89712100E+02, 0.67746100E+02, 0.22348100E+03, -.47549100E+02, -.74843200E+02, -.15786200E+03, 0.58758300E+01, -.23709100E+01, -.30367800E+01, -.29596800E+01, 0.52615600E+01, 0.33424700E+01, -.10795100E+01, -.32382700E+01, -.29249900E+01, -.21658400E+02, -.11042500E+02, -.21009500E+02, 0.10820700E+02, 0.23581100E+02, 0.10912700E+02, -.30563900E+02, -.25786400E+02, 0.90610400E+01, -.38405700E+02, 0.47636000E+01, 0.22701000E+02, 0.83356200E+02, 0.30771600E+04, -.15346000E+04, -.76489400E+03, -.15386700E+04, -.70438000E+02, 0.28982000E+03, -.93678400E+03, -.16247600E+03, -.11361400E+04, 0.39377500E+03, -.13830400E+04, -.10180500E+04, 0.50757500E+03, 0.12630200E+03, 0.50912600E+03, 0.72827900E+02, -.26049100E+03, 0.71924000E+03, 0.40934000E+03, 0.56161200E+03, -.32784400E+03, 0.34390900E+03, 0.21681800E+01, -.11567300E+02, 0.16917700E+02, 0.19202000E+02, 0.51174700E+02, -.33668100E+02, -.90451700E+01, -.48808100E+01, 0.37613100E+01, -.29577300E+02, 0.12018300E+02, -.35796800E+01, -.16509000E+03, -.45593800E+02, -.17791900E+02, 0.62186800E+01, -.52783600E+01, 0.12877600E+02, -.14931500E+02, -.83296100E+01, -.90381200E+01, -.10075600E+02, 0.43993200E+01, 0.15037100E+02, -.16901700E+02, 0.51744300E+02 },
        { -.92984100E-01, 0.12680500E+00, -.24850400E+00, -.28885400E-01, 0.52026500E+00, 0.20013300E+00, 0.89135900E+00, -.27997800E+00, -.94435900E-01, 0.20210500E+00, 0.19281900E-01, -.81811800E+00, 0.13859900E+00, -.47009300E+00, -.31276500E+00, -.16372400E+00, -.10481200E+01, 0.68588300E-01, -.79739600E+00, 0.15501500E+00, -.63445100E+00, -.10446900E+01, 0.58671500E-03, -.18670600E+00, -.24877700E+00, -.29179500E-01, -.13431700E+00, 0.19964700E-01, -.74081500E-01, 0.23956400E+00, 0.29732400E+00, 0.18593100E+00, 0.35991100E-01, 0.12361000E+00, 0.48445000E-01, 0.15139200E+00, 0.54848200E-02, 0.54302900E+00, 0.39962700E+00, 0.23125600E+00, -.38883100E+00, -.61758700E+00, 0.13827200E+01, 0.60851000E+00, 0.51705300E+00, -.63638800E-02, -.21714900E+00, 0.90132600E-02, 0.10402800E+00, 0.21568500E+00, 0.65266500E+00, -.43984700E+00, -.25507600E+00, 0.15508500E+01, 0.24079800E+00, 0.53962300E+00, 0.41365900E+00, -.42935000E+00, 0.48914300E-01, 0.27292500E+00, -.20466700E-01, -.18408200E+00, 0.55499500E-01, -.36313100E+00, 0.13138200E-01, -.16998400E+00, 0.97087900E-01, 0.13752100E+00, -.56441900E-01, -.53646900E-03, -.56570300E-01, -.51704200E+00, 0.10138400E+00, -.40532000E-01, -.72448800E-01, 0.51766900E-01, -.33979200E-01, 0.43341700E+00, -.97573400E-01, -.19489400E+00, -.38462700E-02, 0.47702900E-01, 0.11612900E+00, -.16875600E+00, 0.33917400E-01, -.17283100E+00, 0.35521800E+00, -.39046700E+02, -.30908400E+03, 0.15954500E+03, 0.14967300E+03, 0.15448300E+03, -.42876600E+02, -.21454900E+03, 0.23089000E+03, 0.34916700E+03, 0.24125700E+03, -.23196900E+03, 0.27546100E+03, -.54860100E+03, 0.27116200E+03, 0.20931900E+03, 0.27421900E+03, 0.10011000E+03, 0.67776100E+02, 0.10933500E+03, -.88353100E+02, 0.16169500E+03, 0.12045600E+03, 0.23663300E+02, -.40379700E+03, 0.20435900E+03, 0.17928400E+03, 0.20190800E+03, 0.17119900E+02, -.89522200E+02, 0.15121700E+03, -.16849300E+01, 0.19555500E+03, -.66084200E+02, 0.65740900E+02, 0.68927900E+03, -.34577900E+03, -.61319800E+03, -.34465000E+03, -.41205000E+03, -.24527500E+03, 0.27164500E+03, 0.82826900E+03, 0.34388600E+03, -.26788500E+03, 0.35636100E+03, 0.34625000E+03, -.17047600E+03, -.42113100E+02, -.17316700E+03, -.40501200E+02, -.10390200E+03, 0.12398000E+03, 0.26561800E+03, 0.34329200E+02, -.11961300E+03, -.48869500E+02, -.56575600E+03, 0.28709700E+03, 0.18295100E+03, 0.28252900E+03, 0.15617600E+03, 0.10849400E+03, 0.13871400E+03, -.26791300E+02, 0.32763200E+02, 0.12499600E+03, 0.46160900E+02, 0.28134400E+03, -.14557900E+03, 0.40004500E+03, -.14076300E+03, 0.17851400E+03, 0.20103100E+03, -.38984300E+03, -.53470900E+03, -.56427700E+03, 0.23366700E+03, -.34622100E+03, 0.10976600E+03, -.44653200E+02, 0.70920600E+02, -.54837300E+02, 0.64478700E+02, 0.11691800E+03, -.13160800E+03, -.15566500E+03, -.17919400E+03, 0.14608400E+03, -.29953300E+02, 0.22101000E+02, -.11401500E+02, -.28528800E+02, -.11043600E+02, -.16407300E+02, -.34410000E+02, 0.25628600E+02, 0.39451000E+00, -.24418400E+01, -.48119700E+02, -.47970800E+02, 0.11024900E+04, -.55327100E+03, -.91841200E+03, -.55127000E+03, -.66908400E+02, -.43658700E+03, 0.11776700E+03, 0.84697200E+02, -.66368300E+02, -.48230500E+03, -.10035200E+04, 0.35679200E+03, -.17504300E+03, -.14919500E+03, -.17847000E+03, 0.68253800E+02, -.42954600E+02, -.22053700E+03, -.17617200E+03, -.41348500E+02, -.70800400E+02, -.88496100E+02, 0.20354900E+04, -.10177700E+04, -.46899200E+03, -.10178100E+04, -.22086100E+03, -.43477400E+03, 0.37266200E+02, 0.22767100E+03, -.45837000E+03, -.51051500E+03, -.15123200E+04, -.18889000E+03, 0.92217900E+02, -.66865400E+02, 0.94230000E+02, -.58569500E+02, -.10880800E+03, -.19125300E+02, 0.14336600E+03, 0.28031600E+03, -.20326600E+03, 0.30777200E+03, 0.53510300E+01, -.40519200E+01, 0.24104900E+01, -.26726300E+01, -.19373500E+00, 0.25512700E+01, -.27546500E+01, -.40584300E+01, -.77748800E+01, 0.42231700E+01, -.38279000E+02, -.18444800E+03, 0.92903500E+02, 0.14748500E+03, 0.92158500E+02, 0.47429800E+02, 0.23123600E+02, 0.69488200E+02, 0.10942800E+03, 0.51269300E+02, 0.23330200E+02, -.12437500E+02, -.28486100E+04, 0.14268600E+04, 0.11673900E+04, 0.14243200E+04, 0.35194300E+03, 0.14792900E+03, 0.20194700E+03, -.95801500E+03, 0.33543400E+03, 0.16542100E+03, 0.66297900E+03, 0.17199300E+04, -.86440400E+03, -.89346700E+03, -.85998500E+03, -.17291000E+03, -.15014100E+03, -.12081400E+03, 0.74544100E+03, -.63656000E+02, -.18848100E+03, -.53151700E+03, -.64352300E+01, -.79057500E+02, 0.18042000E+01, 0.75748900E+00, -.16179100E+02, -.31718100E+01, 0.29886900E+02, -.73403200E+02, -.36115300E+00, -.10250800E+02, -.11148500E+02, 0.67328200E+01, 0.17460600E+03, 0.18590900E+02, 0.24599700E+02, -.35793000E+02, 0.21333500E+02, 0.74108500E+01, 0.13203600E+02, -.12499100E+02, -.30986600E+01, 0.64276400E+01, -.43875500E+00, 0.62834500E-01, 0.18102400E+03, 0.93746700E+02 },
        { -.10095000E+00, -.13579700E-02, -.14948300E+01, -.62969000E-01, 0.38221800E+00, 0.31985900E-01, -.39366000E+00, 0.90906800E-01, -.11139600E+00, -.30036400E-01, -.69176200E-01, -.61044900E+00, 0.31366600E+00, -.41211900E-02, -.31171500E+00, 0.47626900E-01, -.64993300E+00, 0.16195500E-01, 0.28385900E+00, -.12534200E+00, -.13125100E+00, 0.53696600E+00, 0.18149500E+00, 0.52779300E-01, -.34380900E+00, -.32491000E-01, 0.24531500E+00, -.25519300E+00, 0.66545100E-02, 0.24205400E+00, 0.70720700E-01, 0.47983000E-01, -.20030400E+00, -.19647400E-01, 0.13060000E-01, 0.18135100E+00, -.10605600E-01, 0.33135700E+00, 0.11787000E+00, 0.86599400E-01, -.65925000E+00, -.17756700E+00, -.70260000E-01, 0.94319100E-01, 0.68249500E-01, -.85775300E-01, -.38177200E+00, -.10107400E-01, 0.11100500E+00, -.82285000E-01, 0.11166900E+00, -.83905600E-01, 0.12555900E+00, -.81321500E+00, -.21462300E+00, 0.63892300E-01, 0.11106600E+00, -.41399600E-01, 0.27132600E-01, -.36912200E-01, -.21609500E-01, -.56865000E-01, 0.78841800E-01, -.39285000E-01, 0.33538400E-01, 0.10091800E+00, 0.13135300E+00, 0.32916500E-01, -.10162400E+00, 0.31391200E-02, -.37582200E+00, -.12284300E+00, 0.41098500E-01, -.22078300E-01, 0.73590300E-01, -.11637200E+00, -.16900600E-01, 0.22980600E+00, 0.25202300E-01, -.14689500E-02, -.42638000E-03, -.68171800E-02, -.54428800E-01, -.78256700E-01, -.14797200E-01, 0.33127900E-01, 0.22250100E+00, 0.50477900E+00, 0.30897700E+03, -.14662900E+03, -.15045100E+03, -.15458200E+03, 0.39913000E+02, 0.22316900E+03, -.30154700E+03, -.33220400E+03, -.26426200E+03, 0.25002000E+03, -.11573200E+03, 0.37982100E+03, -.18413100E+03, -.11585800E+03, -.18997900E+03, 0.32608300E+01, -.39606300E+02, -.11666800E+03, 0.66773700E+01, -.24957500E+03, -.75201000E+02, -.23663100E+03, -.14052400E+03, 0.69821800E+02, 0.15421400E+03, 0.70263600E+02, 0.58655400E+02, -.23938300E+02, -.26600600E+02, -.36812800E+02, -.18375900E+01, -.36671200E+02, 0.64427200E+02, -.17005700E+04, 0.85202000E+03, 0.82867300E+03, 0.85027600E+03, 0.28946800E+03, 0.29553200E+03, 0.28355600E+02, -.54401900E+03, 0.34094500E+03, 0.26793400E+03, 0.86926500E+03, -.20451400E+03, 0.92306600E+02, -.58013600E+02, 0.10221300E+03, -.78228100E+02, -.11965200E+03, -.19478500E+02, -.24878300E+03, 0.29806300E+01, -.97844600E+02, 0.11298900E+03, 0.15681900E+03, -.81148400E+02, -.55810200E+02, -.78245900E+02, -.35135100E+02, 0.17622600E+02, -.16713300E+03, -.84904200E+02, 0.40158200E+00, 0.59007200E+01, -.50821900E+02, 0.12579300E+03, -.58828500E+02, -.67505100E+03, -.62951000E+02, -.23986600E+03, -.18562800E+03, 0.37885500E+03, 0.53341800E+03, 0.26774100E+03, -.13008800E+03, 0.19642100E+03, -.27623500E+03, 0.12114500E+03, -.62971600E+02, 0.13816600E+03, -.51572600E+02, -.71516700E+02, 0.25447300E+03, 0.17675300E+03, 0.13110000E+03, -.80726000E+02, 0.15672200E+03, -.20715100E+00, 0.22316100E+01, 0.42953000E+01, 0.11187300E+00, 0.26233400E+02, 0.22778300E+02, -.72615100E+01, -.16370400E+01, -.25245700E+02, 0.26737300E+02, -.25112800E+01, 0.21471900E+03, -.10695600E+03, -.18002200E+03, -.10737300E+03, 0.80132900E+02, 0.12427000E+03, -.40825100E+02, 0.37067000E+03, -.14693500E+03, 0.15421700E+03, 0.22522300E+03, -.38217200E+03, 0.18808500E+03, 0.66892000E+02, 0.19101400E+03, -.16400600E+03, -.25451200E+02, 0.25670600E+03, 0.31237200E+03, 0.12158100E+03, -.24248100E+02, 0.32167500E+03, 0.71468300E+02, -.37176600E+02, -.11748800E+03, -.35769900E+02, 0.50883800E+02, 0.24721300E+03, -.11849000E+03, 0.27443300E+03, -.11108800E+03, 0.24929100E+03, 0.21581600E+03, 0.40466000E+03, -.20109700E+03, 0.10884300E+03, -.20237100E+03, -.74312600E+02, 0.41567100E+02, -.73270100E+02, 0.13869900E+02, -.29852000E+03, 0.89843900E+02, -.69179100E+02, -.15978800E+01, 0.12402200E+01, -.51559000E+01, 0.80283900E+00, -.30142300E+00, 0.19057600E+01, 0.20034100E+01, -.30625800E+01, 0.38199100E+01, 0.78149800E+00, 0.51183700E+01, -.13383100E+03, 0.67826400E+02, 0.74678300E+01, 0.66852000E+02, -.69090800E+02, -.99135700E+02, 0.68221300E+02, -.23966500E+02, 0.79142500E+02, -.84433100E+02, 0.14543400E+03, 0.28243400E+04, -.14065100E+04, -.86907300E+03, -.14121600E+04, -.11532800E+03, -.14419600E+03, -.58239800E+03, 0.28968900E+03, -.70087200E+03, -.17091700E+03, -.14694000E+04, -.10314100E+04, 0.51347100E+03, 0.38394500E+03, 0.51569300E+03, 0.61430300E+02, 0.47433200E+02, 0.45265300E+03, -.37099600E+02, 0.22407000E+03, 0.88514500E+02, 0.60216700E+03, 0.64149900E+01, 0.58780700E+02, 0.18938900E+02, 0.40070700E+01, 0.34715000E+02, -.17650800E+02, -.29807600E+02, 0.59479000E+02, -.22080600E+01, -.10695000E+02, 0.18489900E+01, 0.40444800E+02, -.12692700E+03, -.22229900E+02, -.21274700E+02, 0.50888100E+02, -.26931300E+02, 0.12672700E+02, 0.33256800E+02, -.12334800E+02, -.55154300E+02, 0.16238200E+01, -.20018800E+01, 0.11711600E+02, -.87819800E+01, -.10185500E+02 },
        { 0.52705800E+00, -.80579600E+00, 0.53183100E+01, 0.65394200E+00, -.16795800E+01, -.76078700E+00, -.20990600E+01, 0.17168200E+00, 0.11245200E+00, -.51262800E+00, -.91328600E+00, 0.54545600E+00, 0.24796000E-01, -.14847700E+00, -.27614600E+01, -.70332600E+00, 0.75997600E+00, -.63320600E+00, -.11214000E+01, -.62629300E+00, -.11414300E+00, 0.15788100E+01, -.50197600E-01, 0.21647500E+01, 0.40153400E+00, 0.50604900E+00, 0.30978900E+01, -.10720300E+01, 0.69469100E+00, -.68613500E+00, 0.14100900E+01, -.32740300E+00, 0.13993400E+01, -.65007900E+00, 0.58323100E+00, 0.34502400E+00, 0.14624300E+00, -.55945000E-01, -.75528600E+00, -.10865400E+01, -.73116000E+00, 0.18736500E+01, 0.30878700E+00, -.67705700E+00, 0.42865700E-01, -.41445800E+00, 0.25903100E+01, 0.28502600E+00, 0.59733400E+00, -.11008300E+01, -.23134400E+00, 0.90221300E+00, 0.14479100E+01, -.75040600E+01, -.28334900E+01, -.34325000E+00, 0.94576300E+00, 0.45010300E-01, -.81811600E+00, -.22789400E+00, -.84499100E+00, -.94207500E-01, 0.53805400E+00, -.91741900E+00, 0.42289900E+00, -.15987300E+00, -.87342200E-01, -.36510200E+00, -.86515000E+00, -.87587000E-02, 0.11796300E+01, 0.13393800E+01, 0.35247300E+00, 0.18498200E+00, 0.10330600E+00, -.84586500E+00, 0.45832700E+00, -.31066900E+00, -.11339000E+00, 0.35622900E+00, -.22308400E-01, -.36835800E+00, 0.22146500E+01, 0.41923900E+00, -.35828200E+00, 0.88343100E+00, 0.72483100E-01, -.22525600E+01, -.21908400E+01, 0.87541600E+02, -.21959100E+03, 0.12332400E+01, 0.70985100E+03, 0.69841700E+03, -.71399800E+03, -.98535000E+03, -.90489100E+03, 0.92630500E+03, 0.78755300E+02, 0.43119000E+03, -.17512200E+03, -.10439400E+03, -.21452200E+03, -.23427900E+02, -.23759100E+02, 0.35613900E+03, 0.44162300E+03, -.62860100E+03, 0.23829100E+02, -.20244100E+03, -.10424700E+04, 0.52653900E+03, 0.56046000E+03, 0.52118200E+03, 0.17823100E+03, 0.37200600E+03, -.22312200E+03, -.42184000E+03, -.63442300E+02, 0.39271100E+03, 0.11096000E+04, 0.45470600E+03, -.19979300E+03, 0.12738200E+04, -.22719700E+03, 0.14326500E+04, 0.14158600E+04, -.19454000E+04, -.31924100E+04, -.21434700E+04, 0.38401400E+03, -.95075200E+03, 0.45232600E+03, -.29972200E+03, -.18362700E+03, -.22551000E+03, -.56439600E+03, -.54510200E+03, 0.27289100E+03, -.12907100E+03, -.59496100E+02, -.58391300E+03, 0.97260200E+02, -.23463000E+04, 0.11438900E+04, 0.42914600E+03, 0.11720300E+04, 0.78966900E+03, 0.10089700E+04, -.59666700E+03, -.10021000E+04, 0.24804600E+03, 0.10705600E+04, -.13100900E+03, -.12347200E+04, 0.62634100E+03, -.16064300E+04, 0.61832800E+03, -.14059200E+03, -.74499900E+03, 0.15194100E+04, 0.17398100E+04, 0.18024300E+04, -.42504300E+03, 0.22846100E+03, 0.12135700E+04, -.72177400E+03, 0.16910300E+03, -.60752600E+03, 0.63348000E+03, 0.69914300E+03, -.97166100E+02, 0.28614100E+03, -.37513000E+03, 0.38910400E+03, -.80960400E+03, 0.28484200E+03, -.12477400E+03, -.20528200E+02, -.14253700E+03, -.17843100E+03, -.11016400E+03, 0.25048800E+03, 0.41136800E+03, 0.46754900E+03, -.13574300E+03, 0.11758600E+03, -.96379000E+03, 0.48321700E+03, 0.31060700E+04, 0.48215800E+03, -.24041000E+04, -.12778300E+04, 0.28733600E+04, 0.17148900E+04, 0.16756100E+04, -.14555700E+04, 0.80370200E+04, 0.26802700E+03, -.14968700E+03, -.72682900E+03, -.13291100E+03, -.12162100E+03, 0.95955700E+03, -.11484400E+03, 0.13449900E+03, -.95400400E+03, 0.68566600E+03, -.35359500E+03, -.68915700E+04, 0.34369800E+04, -.20018800E+03, 0.34464500E+04, -.20562300E+04, -.15276700E+04, 0.43355500E+04, 0.13316100E+04, 0.41506800E+04, -.15891000E+04, 0.11662100E+05, 0.26137800E+03, -.11823600E+03, 0.10473100E+03, -.12983000E+03, -.20324200E+03, 0.17060700E+03, 0.24476900E+03, 0.60097000E+02, -.14540600E+04, 0.32442000E+03, 0.91786900E+03, -.89958700E+01, 0.49104000E+01, -.28538600E+02, 0.44452400E+01, 0.43240300E+01, -.17854300E+02, 0.15453400E+02, 0.25207700E+02, 0.42127200E+02, -.25466800E+02, -.24077200E+02, 0.46298100E+03, -.22175100E+03, 0.15891900E+03, -.23053700E+03, 0.34038900E+03, 0.55923400E+03, -.37265700E+03, -.13130700E+03, -.97893200E+02, 0.41183900E+03, -.31109200E+03, 0.12336600E+05, -.61234200E+04, -.68612000E+04, -.61684900E+04, -.16103800E+04, -.11361900E+04, -.45890700E+03, 0.44848800E+04, -.14875500E+04, 0.10215300E+03, -.42016100E+04, -.12304700E+05, 0.61269600E+04, 0.79199500E+04, 0.61525600E+04, 0.35928200E+03, 0.54637700E+03, 0.11852200E+04, -.38014400E+04, 0.19068800E+04, -.35668000E+03, 0.54045600E+04, 0.12262900E+02, -.21137300E+03, -.94848900E+02, 0.57290500E+02, 0.44553900E+02, -.14559800E+03, -.40333000E+02, -.23960700E+03, -.13226300E+02, -.12150900E+03, -.55422400E+02, -.16771100E+03, -.11227300E+04, -.92535200E+02, 0.15859800E+03, 0.11259200E+03, 0.10125700E+03, -.93445500E+02, -.11018700E+04, -.84201000E+02, 0.69793300E+03, 0.87193700E+02, -.91237500E+01, 0.71719600E+01, -.12797900E+04, -.24684500E+03 },
        { 0.18791200E+00, 0.50433200E+00, 0.10129600E+01, 0.26143700E-01, -.49514400E+00, 0.26216700E-01, 0.11136700E+01, -.28286300E+00, 0.68613800E-02, -.16259800E+00, 0.25168400E-01, 0.39339100E+00, 0.18712500E+00, 0.20589000E+00, -.30539000E+00, -.39770100E+00, 0.83361200E+00, -.24342100E+00, -.14595800E+01, -.13583900E+00, 0.47553500E-01, 0.11443600E+01, 0.63378700E-01, -.29820800E-01, -.18529800E-01, -.48760300E-01, 0.68822700E-01, 0.19043300E+00, 0.18445100E+00, 0.83688100E-01, 0.46956300E-01, -.40962100E-01, -.55334700E-01, 0.10303000E+00, -.17455500E-01, 0.13383300E+00, -.90230100E-02, 0.15045800E+00, 0.44208500E-01, 0.14796500E+00, 0.30579600E-01, 0.43955200E+00, 0.86936600E+00, 0.10596200E+00, 0.20379800E-01, 0.84745600E-01, 0.21333900E+00, -.73225600E-02, 0.29641900E-01, 0.32898800E+00, 0.51050700E+00, -.51837800E+00, -.14771700E+00, -.31265000E+00, -.15710500E+00, 0.75634400E-01, 0.49737000E+00, -.28765000E+00, 0.58562300E-01, -.96028000E-02, -.92668000E-01, -.46934700E-01, 0.10480600E+00, 0.10372200E+00, -.15791100E-01, 0.46034500E-01, -.22916200E+00, -.25153200E+00, 0.48318100E+00, -.83422300E-03, -.49344300E-01, -.13461800E+01, 0.10689100E+00, -.26858400E-01, -.22143000E-01, 0.38080100E+00, 0.15461400E+00, -.45186900E+00, 0.17870400E+00, -.84308500E-01, -.91897700E-02, 0.11684700E+00, -.17732100E+00, -.27030100E-01, -.11889100E+00, 0.40396800E-01, 0.87389800E-02, -.32538500E+00, 0.71984300E+00, -.52241900E-01, -.23577100E+03, 0.43322600E+00, -.52470900E+02, -.93030800E+02, -.10354800E+02, 0.37815100E+03, 0.48194100E+02, 0.10673500E+02, 0.17517300E+03, -.46399000E+03, 0.23220400E+03, 0.16336700E+03, 0.23239700E+03, 0.87745400E+02, -.31018200E+02, 0.34303500E+03, -.28483700E+01, 0.27694500E+03, -.17393300E+02, -.16484900E+03, -.52819500E+03, 0.26365400E+03, 0.19942700E+03, 0.26407200E+03, 0.38879600E+02, -.79269500E+02, 0.14586000E+03, -.94675400E+02, 0.22064700E+03, -.54917600E+02, 0.12677000E+03, -.76053900E+03, 0.37956300E+03, 0.60837800E+03, 0.38032600E+03, 0.16366100E+03, -.15552800E+03, 0.12755700E+03, -.16527500E+03, 0.44334000E+03, -.30464800E+03, 0.87545400E+03, 0.34782800E+03, -.17566600E+03, -.15086500E+03, -.17367900E+03, -.11796300E+03, -.15542500E+03, 0.18178700E+02, -.58971100E+02, -.54033700E+02, -.14994100E+03, -.81523300E+02, -.36240400E+03, 0.19739400E+03, -.45797400E+02, 0.18026300E+03, 0.54596500E+02, 0.14414200E+03, 0.11962000E+03, -.90173200E+01, 0.14396600E+03, 0.13229600E+03, 0.13985700E+03, 0.38473300E+03, -.19027500E+03, -.25242100E+03, -.19198800E+03, -.75617400E+02, -.11909400E+03, -.11271800E+03, 0.15113300E+03, -.34439000E+03, 0.14509100E+03, -.54454500E+03, 0.19796800E+03, -.98959600E+02, 0.19073400E+03, -.99243000E+02, 0.10810000E+03, 0.71324900E+02, -.65769000E+02, 0.82539100E+02, -.42706200E+02, 0.12137100E+03, -.17926600E+03, 0.21860200E+02, -.10662200E+02, -.92700900E+01, -.10972400E+02, -.30350600E+02, -.27056300E+02, 0.20444500E+02, -.27516400E+02, 0.24205100E+02, -.37357600E+02, 0.30068200E+01, 0.20700800E+04, -.10350900E+04, -.38476300E+03, -.10349400E+04, -.50945100E+03, -.88114200E+03, 0.47610000E+03, 0.13886700E+03, -.21708200E+02, -.91380500E+03, -.18659600E+04, 0.61320600E+03, -.30586900E+03, -.15652900E+03, -.30620600E+03, 0.47043000E+02, 0.12430200E+03, -.32457000E+03, -.14894400E+03, -.24591400E+03, 0.14516600E+03, -.46201500E+03, 0.10942100E+04, -.54712000E+03, -.11972700E+04, -.54683800E+03, -.76930900E+03, -.14635100E+04, 0.10284600E+04, 0.18433500E+03, 0.37611000E+03, -.14289800E+04, -.13741800E+04, -.99272000E+02, 0.44269400E+02, 0.11925300E+03, 0.49545600E+02, 0.39003400E+02, 0.87253800E+02, -.34490200E+03, 0.51908300E+02, -.24132400E+03, 0.13739300E+03, -.21068200E+01, -.20530700E+01, 0.10772100E+01, -.69370600E+00, 0.10074800E+01, 0.73848000E+00, -.26195800E+01, 0.59366300E+01, 0.83753200E+01, 0.37056600E+01, -.35569300E+01, -.65393700E+01, -.25433400E+03, 0.12560900E+03, 0.32455400E+03, 0.12751800E+03, 0.12380400E+03, 0.23025400E+03, -.90437300E+02, -.15894900E+02, -.30200800E+02, 0.22527400E+03, 0.60356100E+02, -.29529600E+03, 0.14808100E+03, -.14192500E+03, 0.14757000E+03, -.54068100E+02, 0.20458000E+03, 0.30535700E+03, -.85944700E+02, -.40906000E+03, 0.22579400E+03, -.52630000E+03, 0.11920200E+04, -.59691800E+03, -.38328200E+03, -.59592200E+03, -.96649700E+02, -.16010200E+03, -.53182900E+03, 0.41369400E+03, -.46634300E+02, -.15651700E+03, 0.69671200E+02, -.30522400E+01, -.11396900E+03, -.94067600E+01, 0.11962800E+02, 0.53156100E+01, 0.25676100E+00, 0.18447200E+02, -.10674600E+03, -.20834900E+01, -.45006700E+02, -.36521700E+01, 0.40641300E+02, -.13188900E+03, -.13318100E+02, -.51292700E+02, 0.32277000E+02, 0.13348200E+02, -.17656800E+02, -.16514500E+02, 0.29593800E+01, 0.21716700E+02, 0.25169200E+02, -.13301500E+01, -.45290300E+01, 0.22826300E+02, 0.76222700E+02 },
        { -.54663700E+00, 0.38530600E+00, -.36219800E+01, 0.35370000E+00, 0.26585100E+01, 0.51247500E+00, 0.37455000E+01, 0.79269000E+00, -.60812300E-01, 0.40080000E-01, 0.11748300E+00, 0.29614000E-01, 0.51400100E+00, 0.10150300E+01, -.66242900E+00, -.55631400E+00, -.32433900E+01, 0.54501200E+00, -.35149900E+00, 0.57615300E+00, -.70027000E+00, -.81385200E-01, 0.12400000E+00, -.95620200E+00, -.40137600E+00, 0.19316800E+00, -.15254900E+00, 0.18952400E+01, 0.77360000E-01, -.36833200E+00, 0.69535500E+00, 0.22324300E+00, -.14741900E+01, 0.47420300E+00, 0.29635500E-01, -.47703800E-01, 0.20186700E-01, 0.76366400E+00, 0.49570800E+00, 0.96649700E+00, 0.81492100E+00, -.59693000E+00, -.12192200E+01, -.15714000E+00, 0.62019900E-01, 0.10540200E+01, 0.28099900E+01, 0.45833400E+00, -.13913200E+00, 0.10235900E+01, 0.11792200E+01, 0.18425200E+00, -.62832300E+00, 0.36286900E+01, 0.75369600E+00, 0.14571300E+01, 0.40540100E+00, -.71159900E+00, 0.54335800E+00, 0.37128200E-01, 0.89366000E+00, -.21493300E+00, 0.20577200E-01, 0.10269000E+00, -.10806400E+00, 0.31752300E+00, -.32894000E+00, 0.20984400E+00, 0.16419000E+00, 0.48246800E+00, 0.14349500E+00, 0.13726800E+01, -.28274100E+00, -.71128500E-01, 0.71571600E+00, -.34390900E+00, 0.32403700E+00, 0.10999900E+00, -.70860800E+00, 0.20829100E+00, 0.37833700E+00, -.24944100E+00, -.72505300E+00, 0.82324700E-01, 0.10922100E+00, 0.80079800E+00, -.12790000E+01, 0.96895200E+00, -.23826000E+00, 0.18899700E+00, -.80771200E+00, -.64774200E+01, 0.20812300E+03, 0.65358000E+03, -.72766100E+03, -.11483000E+04, -.28009700E+03, 0.86026600E+03, -.53784400E+02, 0.15622500E+04, -.76477800E+03, -.40064100E+03, -.78769500E+03, -.25239300E+03, -.25507500E+03, -.21337400E+03, 0.15295800E+03, -.90470200E+03, -.33049900E+03, -.10450100E+04, -.12215400E+04, 0.61333000E+03, 0.76665300E+03, 0.60880600E+03, 0.23471400E+03, -.12294900E+03, 0.65311300E+02, -.25908700E+03, 0.19295200E+03, -.93746600E+02, 0.15221700E+03, -.40742200E+04, 0.20105300E+04, 0.25798200E+04, 0.20392900E+04, 0.66332200E+03, 0.15125300E+04, -.62845200E+03, -.16170400E+04, 0.49726000E+03, 0.12416600E+04, 0.27869100E+04, -.67361900E+02, 0.37323300E+02, -.35053500E+03, 0.30041900E+02, -.26169500E+03, -.37374400E+03, -.26601000E+03, -.64885500E+03, -.52501500E+02, -.27924100E+03, -.73359000E+02, -.24970100E+02, 0.24043200E+02, -.16959500E+03, 0.93155900E+01, -.77387500E+02, 0.92854800E+02, -.17314200E+03, -.26133100E+03, 0.40374900E+02, 0.10356100E+03, 0.14524500E+03, 0.95595800E+03, -.46371800E+03, -.17393800E+04, -.46941500E+03, -.48308200E+03, -.82842200E+03, 0.13415800E+04, 0.16998800E+04, 0.68329300E+03, -.75021300E+03, -.13340700E+03, -.12909800E+04, 0.67705700E+03, 0.20218000E+03, 0.64561000E+03, -.43449300E+03, -.51363700E+03, 0.67482900E+03, 0.50338700E+03, 0.81480600E+03, -.51337100E+03, 0.87695300E+03, 0.71716700E+02, -.38224900E+02, -.12604900E+03, -.33611900E+02, 0.13145900E+02, 0.69186800E+01, -.23069500E+02, 0.52859900E+02, 0.70164700E+02, 0.20906000E+02, -.20511200E+02, -.62175600E+04, 0.31103300E+04, 0.23742600E+04, 0.31122200E+04, 0.64212900E+03, 0.10674500E+04, 0.32371200E+03, -.84115900E+03, 0.14115000E+04, 0.84357400E+03, 0.22153800E+04, -.18544100E+03, 0.10662200E+03, 0.31636000E+03, 0.85858000E+02, -.52848900E+03, -.34775300E+03, 0.10002000E+04, 0.11508200E+04, 0.45221400E+03, -.38965300E+03, 0.12613200E+03, -.51401900E+04, 0.25681900E+04, 0.31721300E+04, 0.25757600E+04, 0.13407300E+04, 0.23157900E+04, -.32376000E+03, -.68176600E+03, 0.13817200E+04, 0.18115700E+04, 0.15132500E+04, 0.13709400E+04, -.68422100E+03, 0.42594100E+03, -.69824900E+03, -.22462600E+03, 0.11636000E+03, 0.30477600E+03, 0.57236100E+03, -.11429100E+03, 0.22726000E+03, -.68061900E+03, -.73765800E+01, 0.20462100E+01, 0.84188100E+01, 0.51522900E+01, 0.50457100E+01, 0.12731600E+02, 0.74815500E+01, 0.98864600E+01, -.69582200E+00, 0.38619000E+01, 0.76179300E+01, -.58167100E+03, 0.29654500E+03, 0.17085500E+03, 0.29034600E+03, -.25632700E+03, -.20540300E+03, 0.16621100E+03, -.10265400E+03, 0.19271000E+03, -.12406500E+03, 0.58320400E+03, 0.83263900E+04, -.41498000E+04, -.22202300E+04, -.41646200E+04, -.35509300E+03, -.46698500E+03, -.86934100E+03, 0.15462000E+04, -.20031300E+04, -.53101400E+03, -.49258800E+04, -.41461400E+04, 0.20776600E+04, 0.12125000E+04, 0.20750000E+04, 0.15323700E+03, 0.32408900E+03, 0.52552700E+03, -.93074300E+03, 0.63960100E+03, 0.47593900E+03, 0.26779900E+04, 0.32483700E+01, 0.13498300E+03, 0.67601200E+02, 0.55414100E+01, 0.10699000E+03, -.66145600E+02, -.10604800E+02, 0.11554600E+03, 0.25792200E+01, 0.73851700E+01, -.48700700E+01, 0.13283500E+03, -.45559400E+03, -.41848300E+02, -.13222100E+03, 0.12646900E+03, -.64731700E+02, 0.15557900E+02, -.41509200E+03, -.51829600E+02, 0.34127700E+03, -.42056700E+02, 0.21638700E+01, 0.12213800E+02, -.10108800E+03, 0.33333800E+02 },
        { -.74485600E-01, 0.23464200E+00, 0.69976700E+00, -.32472600E+00, -.23581200E+00, 0.55780100E-02, -.49293300E+00, -.90383400E+00, -.37071200E+00, 0.21385100E+00, 0.44899400E-01, -.66203900E+00, 0.12172800E+00, -.10277400E+00, 0.11694800E+00, -.16943200E+00, -.28808100E+00, 0.20979600E-01, 0.17498500E+00, -.30181100E-01, -.35456100E+00, -.22045800E+00, -.17898600E+00, -.11513200E+00, 0.29518800E+00, 0.53222500E-01, -.22580200E+00, 0.29756400E+00, -.20840300E+00, -.18334500E+00, 0.36842600E-01, -.60947600E-01, -.52874800E+00, 0.23127200E-01, 0.19463000E+00, -.22002700E+00, -.94994900E-02, 0.40289300E+00, 0.35500600E+00, 0.40318100E+00, 0.21293700E+00, 0.68950000E+00, 0.12937900E+01, 0.59308000E+00, -.24750900E+00, 0.21381600E+00, 0.14341700E+00, -.36617200E-01, 0.15154200E+00, 0.58460900E+00, 0.85233900E+00, -.65842400E+00, -.66328500E+00, 0.41234400E+01, -.92088600E-02, 0.11692800E+01, 0.57870500E+00, 0.11543100E+00, 0.13897900E+00, 0.41657000E+00, 0.61019600E-01, -.23335900E+00, -.13327000E-01, -.43757100E-01, 0.49525400E-01, 0.33191600E+00, 0.15788600E+00, 0.79770800E-01, 0.39947700E+00, 0.12889600E-02, -.57131000E+00, 0.11122000E+00, -.25974600E+00, -.14020200E+00, 0.36023700E+00, -.57736800E+00, -.67820300E-01, 0.39139500E+00, -.21045100E+00, 0.10950100E+00, 0.42196100E-02, -.36876400E-01, -.93214000E-01, 0.20360700E+00, -.11082000E+00, -.81719100E-01, 0.58314700E-01, -.53368100E+00, 0.22361200E+00, 0.24792100E+00, -.70136900E+00, -.12018800E+00, -.38749600E+03, -.18439500E+03, 0.34575700E+03, 0.88023900E+03, 0.36585900E+03, -.18855300E+03, -.85721000E+02, 0.14565700E+03, -.80036900E+02, 0.59539200E+02, -.72908600E+02, 0.13695400E+03, -.17834700E+03, 0.11118500E+03, -.11070900E+03, 0.16699200E+03, -.13393200E+03, -.38608700E+03, -.27936600E+03, 0.14257600E+03, 0.25252900E+03, 0.13940500E+03, 0.33356600E+02, -.20690200E+03, 0.19305000E+03, 0.32880900E+02, 0.35380300E+03, -.24115700E+03, -.74589600E+02, -.38263100E+04, 0.18926900E+04, 0.14886000E+04, 0.19135200E+04, 0.12219700E+03, -.29778200E+01, 0.10350000E+04, 0.11333000E+04, 0.25790200E+04, 0.12195700E+03, 0.28319500E+04, -.19191800E+03, 0.10745400E+03, -.89455200E+02, 0.95936600E+02, 0.39577900E+02, -.35640200E+02, -.22434500E+03, -.40872200E+03, 0.91979400E+02, -.45602700E+02, 0.59538300E+02, 0.35397100E+03, -.16114000E+03, -.27998200E+03, -.17947800E+03, -.27013500E+03, -.28677100E+03, 0.49113700E+03, 0.48979400E+03, 0.25034200E+03, -.32759600E+03, 0.37549500E+03, 0.18090200E+04, -.90082200E+03, -.91887900E+03, -.90281700E+03, -.42057600E+03, -.15784500E+03, -.56083800E+02, 0.25495100E+03, -.13702100E+04, 0.13704100E+03, -.64103000E+03, 0.69355600E+02, 0.36434800E+01, 0.18166000E+02, -.35117400E+02, 0.86309400E+01, -.10530600E+03, 0.72089900E+02, 0.52409000E+03, 0.40209500E+02, 0.82440800E+02, 0.29484200E+02, -.19053900E+03, 0.91268100E+02, -.12700100E+02, 0.95463600E+02, 0.79140500E+02, 0.47114000E+02, -.10625300E+03, -.21834900E+03, -.10712600E+03, 0.36665200E+02, 0.97268800E+00, 0.21206300E+04, -.10647200E+04, -.19441000E+04, -.10597200E+04, 0.48199700E+03, -.39073600E+03, -.63804100E+03, -.54068100E+03, -.35612600E+03, -.28162600E+03, -.46266100E+04, 0.59108100E+02, -.13473800E+02, 0.16748200E+03, -.29680900E+02, -.10289500E+03, -.53500000E+03, 0.34475100E+03, 0.35364600E+03, 0.44365900E+03, -.35837000E+03, -.10352400E+02, 0.40714100E+04, -.20368200E+04, -.93621400E+03, -.20345600E+04, 0.45202900E+03, -.34157700E+03, -.10754600E+04, -.42724000E+03, -.11265300E+04, -.35261600E+03, -.59011100E+04, 0.90600100E+02, -.52545200E+02, 0.18055100E+03, -.47103500E+02, -.29418800E+02, 0.31084600E+03, -.28631900E+03, 0.31651900E+03, 0.16062200E+03, 0.30560300E+03, -.45491300E+03, 0.64194700E+01, -.60812600E+01, 0.28164600E+01, -.30680400E+01, 0.86954400E+00, 0.13332400E+02, -.70893900E+01, -.12131000E+02, -.19183000E+02, 0.17795100E+02, 0.10758700E+02, -.87921300E+03, 0.43353800E+03, 0.60421900E+03, 0.44016900E+03, 0.20031300E+02, -.60890800E+02, 0.29231400E+03, 0.32215100E+03, 0.21610400E+03, 0.21102200E+02, 0.32984000E+03, -.22636400E+04, 0.11351300E+04, 0.22124700E+04, 0.11315100E+04, 0.32388800E+03, 0.96620100E+02, -.17929500E+03, -.25723300E+04, -.12044600E+04, -.32828900E+03, -.54980900E+03, 0.50092800E+04, -.25073100E+04, -.35742700E+04, -.25042600E+04, -.32153300E+03, -.17614600E+03, -.53077800E+03, 0.27404000E+04, -.14745100E+03, 0.15143400E+03, -.15153200E+04, -.28840900E+01, 0.35689900E+02, 0.37821200E+02, -.73701200E+00, 0.19291800E+02, 0.38877000E+02, 0.42811400E+02, 0.60944300E+02, 0.44644500E+00, 0.33261400E+02, -.66155800E+01, 0.13589100E+03, 0.20456400E+03, 0.38564700E+02, -.18251500E+03, 0.88378700E+02, -.36553800E+02, 0.17878100E+02, 0.34517000E+03, -.33181600E+01, -.20284100E+03, -.40117600E+02, -.19122300E+01, -.25827900E+01, 0.73048200E+03, 0.25133600E+03 },
        { -.40163900E-01, -.19019700E+00, 0.40917900E+00, -.16048000E+00, -.55252100E-01, -.65530500E-01, -.25549200E+00, -.11595800E+00, -.47667900E-01, -.60768100E-01, -.16141400E-01, 0.22214500E+00, -.55741700E-01, 0.74576700E-01, 0.11167700E+00, -.81327300E-01, 0.28387000E+00, -.77676900E-01, 0.25864800E+00, -.58745700E-01, 0.23884500E+00, 0.39321500E+00, 0.16651000E-01, 0.23690500E+00, 0.10465600E+00, 0.17079100E+00, 0.19615400E+00, -.73353500E-01, 0.33846400E-01, -.17564400E-01, 0.74704900E-02, 0.32586500E-01, -.14554600E-03, 0.16641600E-01, -.39335400E-01, 0.15843700E-01, 0.18944700E-02, -.18833000E+00, -.10937000E+00, -.33337400E-01, 0.35168100E-02, -.84793300E-01, -.17738900E+00, -.10754000E+00, -.78045900E-01, -.61728000E-01, -.69055600E-01, 0.71065800E-02, -.21342100E-01, -.67236600E-01, -.89546300E-01, 0.18995200E+00, 0.16994400E+00, -.23264100E+00, -.35825100E-01, -.25063100E+00, 0.11463300E-01, 0.12634500E+00, -.91432600E-02, -.36018500E-01, -.23779600E-01, 0.11463000E+00, -.29584500E-01, 0.41302200E-01, 0.31463500E-01, -.71698700E-01, -.65612400E-01, 0.59090600E-01, -.64662500E-01, 0.27733600E-03, -.48219200E-01, -.13314700E+00, 0.42930100E-01, -.82616300E-02, -.11672600E+00, 0.15312100E+00, -.50526800E-01, -.79563600E-01, -.28655400E-01, -.10392100E+00, 0.17712100E-02, -.52464900E-02, -.17427600E-01, -.21058500E-01, -.69599200E-01, 0.20538500E-01, -.20661700E+00, 0.31220000E+00, 0.43404600E+00, 0.28733100E-01, -.10549500E+00, -.38325300E-01, 0.24663800E-01, 0.11207200E+03, -.13773500E+03, -.17255500E+03, -.35645300E+02, 0.13833500E+03, 0.31333000E+02, 0.28955100E+03, -.14270000E+03, -.10201600E+03, -.14477900E+03, -.60940800E+01, -.21047900E+02, -.94470400E+02, -.54363700E+01, -.14886100E+03, -.34399600E+02, -.19236600E+03, -.24617700E+03, 0.12356200E+03, 0.11803600E+03, 0.12300200E+03, 0.66194500E+02, -.53392400E+02, 0.59307700E+02, 0.94451400E+01, 0.55499800E+02, -.51344200E+02, 0.48650100E+02, -.46294100E+03, 0.22989600E+03, 0.49668700E+03, 0.23157800E+03, 0.16680300E+03, 0.20741700E+03, -.86528900E+02, -.33912000E+03, -.80397700E+02, 0.19710300E+03, 0.30372100E+03, 0.28388100E+02, -.13941000E+02, -.41871900E+02, -.14193700E+02, -.33911900E+02, -.39199900E+02, -.10010000E+02, -.99316300E+02, -.46241800E+02, -.27738200E+02, -.21991200E+02, 0.21530800E+03, -.10055200E+03, -.17420300E+03, -.10789600E+03, -.40920900E+02, 0.67475300E+02, -.10913400E+03, -.80816100E+02, -.96794500E+02, 0.60993000E+02, -.20287800E+01, 0.35519800E+02, -.17236700E+02, -.15611000E+03, -.17232100E+02, -.38459300E+02, -.12921900E+03, 0.12916700E+03, 0.18918300E+03, 0.18497300E+03, -.12315800E+03, -.47465800E+02, -.20220100E+03, 0.10484500E+03, 0.50855500E+02, 0.10096600E+03, -.66649100E+02, -.96194100E+02, 0.41370200E+02, -.21328900E+02, 0.10339400E+03, -.91119200E+02, 0.11303700E+03, 0.28972200E+02, -.14511200E+02, -.30218500E+02, -.14429800E+02, -.34918500E+01, -.32053600E+01, 0.11342500E+01, 0.55960500E+01, -.76114400E+01, 0.13575900E+01, -.57784100E+01, -.85663900E+03, 0.42849500E+03, 0.24598300E+03, 0.42850500E+03, 0.11682300E+03, 0.98591900E+02, 0.11051000E+03, -.12096900E+03, 0.12931600E+03, 0.70798900E+02, 0.21976000E+03, 0.78300400E+02, -.37991000E+02, -.15518100E+02, -.39174800E+02, -.61728700E+02, -.11971600E+02, 0.59347700E+02, 0.13425400E+03, 0.14483300E+02, -.34830300E+02, -.51792800E+00, -.50113600E+03, 0.25049900E+03, 0.43595600E+03, 0.25092900E+03, 0.17311700E+03, 0.21931400E+03, 0.22281000E+02, -.28956100E+02, 0.34390200E+02, 0.17265400E+03, 0.21058600E+02, 0.18911300E+03, -.96520100E+02, 0.53190300E+02, -.95070100E+02, -.17079200E+02, -.16576600E+02, -.45097900E-01, 0.12846700E+03, 0.40257000E+02, -.88622300E+01, -.11069100E+03, -.17442500E+01, 0.66998700E+00, 0.18100200E+01, 0.91356700E+00, 0.82064900E+00, 0.74468200E+00, 0.38259600E+01, 0.30786400E+01, 0.12309700E+01, -.71440700E+00, -.64464300E-01, 0.62598000E+02, -.29421300E+02, -.39704600E+02, -.31120200E+02, -.27824800E+02, 0.17381200E+02, -.69433700E+02, -.10072400E+03, -.78802000E+02, 0.26355900E+02, 0.43516800E+02, 0.12869000E+04, -.64196900E+03, -.40757700E+03, -.64354700E+03, -.73907600E+02, 0.28197200E+02, -.15259000E+03, 0.37977100E+03, -.30059300E+03, -.14137400E+02, -.74802800E+03, -.51788500E+03, 0.25876500E+03, 0.11307500E+03, 0.25906000E+03, 0.14835600E+02, 0.93724800E+00, 0.70269000E+02, -.21372300E+03, 0.72324600E+02, 0.45538200E+02, 0.42853300E+03, 0.69057800E+00, 0.11026900E+02, 0.15374900E+02, 0.21216100E+01, 0.10857700E+02, -.76079700E+01, -.19509800E+01, 0.10427700E+02, 0.36594600E+00, 0.30911200E+01, 0.41605500E+01, 0.17452300E+02, -.71431500E+02, -.93015300E+01, -.23960200E+02, 0.81897400E+01, -.76108200E+01, 0.36144800E+01, -.20364000E+02, -.85676700E+01, 0.16773100E+02, 0.14966800E+01, 0.51606300E+00, 0.74645200E+01, -.37626100E+02, 0.16848600E+00 },
        { -.21566500E+00, 0.76107500E+00, 0.96068300E+00, -.17832000E+00, 0.75078800E-01, 0.47847600E+00, 0.40527000E+00, -.73304300E+00, -.23820700E+00, 0.17048200E+00, 0.83338200E-01, 0.14695800E+00, 0.35606800E+00, -.26994200E+00, -.96535700E+00, 0.46829800E-01, -.18955700E+01, 0.58477900E-01, -.91180700E+00, 0.43402700E+00, -.20128700E+01, 0.40988300E-01, -.87469900E-01, -.71257800E+00, -.61593400E-01, 0.55244400E-01, -.54909700E-01, -.14006700E+00, -.10664700E+00, 0.74472200E-01, -.77884400E-01, 0.98702600E-01, 0.47652800E+00, -.19936100E+00, 0.28917700E+00, 0.10443700E+00, -.28876500E-01, 0.35586800E+00, 0.16567900E+00, -.23069800E+00, -.49380700E+00, -.11132400E+01, 0.96160500E+00, 0.34631500E+00, 0.13216200E+00, -.10632700E+00, -.66695200E+00, -.79434200E-01, 0.81882500E-01, -.12853400E+00, -.91968800E+00, 0.38702600E+00, 0.48634800E-01, 0.10447600E+01, -.24975800E+00, 0.85726600E+00, -.23723400E+00, 0.20698000E+00, 0.31603300E-01, -.50321300E+00, 0.57954400E-01, -.54074000E+00, 0.22463100E+00, -.63375700E+00, -.54558400E-01, -.13708000E-01, 0.96886000E-01, 0.68995400E+00, 0.12419000E+00, -.55866500E-02, -.43852700E-01, -.56786800E+00, 0.30218100E-01, 0.34949800E-01, -.37726500E+00, 0.34093600E+00, -.69297900E-03, 0.92699900E-01, 0.31809300E+00, -.13001700E-01, 0.16357100E-02, 0.15647100E+00, -.51683200E+00, 0.18249600E+00, -.33644200E-01, 0.34832100E+00, 0.57707900E+00, -.10407500E+01, -.37184200E+00, -.17435100E+00, 0.33109000E+00, 0.26612500E+00, -.27694100E+00, -.11971200E+00, 0.27807200E+03, 0.69466500E+03, 0.16059200E+03, -.10232000E+03, 0.38831900E+02, -.56126300E+02, 0.29584600E+02, 0.10239200E+03, 0.28112900E+02, 0.24821700E+03, -.14092600E+03, -.35539100E+02, -.23253100E+03, 0.10168800E+03, -.68532100E+02, -.39666200E+03, -.33104700E+03, 0.16331100E+03, 0.21699400E+03, 0.16607600E+03, 0.59296600E+02, -.21319300E+02, -.45504400E+02, -.30168000E+03, 0.12837000E+03, 0.23928400E+02, 0.20534900E+03, -.41963800E+04, 0.21021400E+04, 0.12493500E+04, 0.20974900E+04, 0.60755900E+03, -.37140900E+03, 0.12209200E+04, 0.56643500E+03, 0.22576400E+04, -.30500800E+03, 0.19317700E+04, -.20155100E+03, 0.92425500E+02, 0.19169100E+02, 0.10077800E+03, -.49175800E+01, -.24490200E+03, 0.15255300E+03, -.22119000E+03, 0.80232800E+02, -.26720200E+03, 0.11887900E+03, -.42403600E+03, 0.23345300E+03, -.31692900E+01, 0.21299900E+03, 0.23185500E+02, -.16906300E+02, 0.25936300E+03, 0.23147900E+03, 0.32332000E+03, -.68745800E+02, 0.27911900E+02, 0.10310300E+04, -.51151400E+03, -.11028000E+04, -.51888600E+03, -.51510900E+03, -.12743800E+03, 0.30139900E+03, 0.88484400E+03, -.60057100E+03, 0.98843100E+02, 0.35390000E+02, 0.13345200E+04, -.68308800E+03, -.30955500E+03, -.66638500E+03, 0.46503900E+03, 0.54247300E+03, -.22972200E+03, 0.69402700E+03, -.48913200E+03, 0.52902300E+03, -.73720800E+03, -.59178900E+01, 0.48134500E+01, -.27632300E+01, 0.25937700E+01, 0.22903600E+02, 0.55857200E+02, -.17958800E+02, -.79191300E+02, -.86021500E+02, 0.37878500E+02, -.49358600E+02, 0.53198800E+04, -.26592800E+04, -.25577900E+04, -.26611300E+04, -.38049800E+03, -.71672700E+03, -.25393500E+02, 0.12399300E+04, -.87535200E+03, -.59430500E+03, -.28067000E+04, 0.22791900E+03, -.11886700E+03, -.47046200E+03, -.11379400E+03, -.14689000E+03, -.10108100E+03, 0.53545200E+02, 0.22955000E+03, -.61670000E+02, -.12414200E+02, -.11366100E+03, 0.50018300E+04, -.25010600E+04, -.27379200E+04, -.25032100E+04, -.49865100E+03, -.12508500E+04, 0.15186300E+03, 0.10062700E+04, -.92457500E+03, -.10789200E+04, -.28013000E+04, -.34489900E+03, 0.16580800E+03, -.88436400E+02, 0.17434300E+03, -.17400600E+03, -.15703900E+02, 0.16664500E+03, 0.36731300E+03, 0.12931200E+03, -.87442900E+01, 0.35579100E+03, -.29054800E+00, 0.11405200E+01, -.12481800E+02, -.12317600E+00, 0.14840600E+01, 0.24755400E+01, -.10264800E+01, -.38318900E+01, 0.24760100E+01, 0.61135500E+01, 0.10838700E+02, -.41255600E+03, 0.20709400E+03, 0.56953600E+03, 0.20513800E+03, 0.31556200E+03, 0.38182300E+03, 0.73130700E+02, 0.32316500E+03, -.11099700E+02, 0.30189000E+03, -.80178600E+02, 0.36794000E+03, -.18252600E+03, 0.14930900E+03, -.18335900E+03, -.29813100E+03, -.19725200E+03, -.80096200E+03, -.20122400E+04, -.13123500E+04, -.27192800E+03, -.41432600E+03, 0.15973000E+04, -.80065200E+03, -.10280700E+04, -.79940200E+03, -.60763300E+02, 0.10443300E+03, 0.26456700E+03, 0.18898500E+04, 0.44960400E+03, 0.14021200E+03, -.66084000E+03, 0.78802500E+01, 0.10035000E+02, -.32411500E+02, -.16595000E+02, -.84233600E+01, -.31010200E+02, 0.90843600E+01, 0.33728900E+02, -.56763600E+01, 0.80642900E+01, -.38208800E+02, 0.77873700E+02, 0.53916900E+02, 0.10531700E+02, -.58724400E+02, 0.13429800E+03, -.20001700E+02, 0.29678200E+02, 0.21264000E+03, -.44014800E+02, -.20556700E+03, 0.16388800E+01, -.54293300E+01, -.18995200E+02, 0.44779000E+03, 0.13486900E+03 },
        { 0.14212300E+00, 0.25203300E+00, 0.13297300E+01, 0.59688200E-01, -.45106400E+00, 0.54533300E-01, 0.95395800E-01, -.11604400E+01, -.32956700E+00, -.19647500E+00, 0.19083800E-01, 0.82362100E+00, 0.19105300E+00, 0.22141900E+00, -.59568400E+00, -.17407800E+00, -.31637600E+00, 0.95173700E-01, 0.11066600E+01, -.64710500E+00, 0.24392000E+00, 0.15607200E+01, 0.96776400E-01, 0.30555100E+00, -.83630600E-05, -.41132400E-02, 0.28430400E+00, 0.26041900E-01, 0.20225200E+00, 0.15115700E-01, -.13337700E-01, -.21438800E+00, 0.29706200E+00, 0.53647200E+00, -.36688100E-01, 0.10515900E-01, 0.28418200E-01, -.21770200E+00, -.10153700E-01, -.39177400E+00, -.43022800E+00, -.33070100E+00, 0.36671800E+00, 0.16752100E+00, -.72219700E-01, -.10545100E+00, -.64294800E-01, 0.19750800E-01, 0.25820500E-01, -.69273800E-01, 0.74548000E-01, 0.43916400E+00, 0.28636500E+00, -.16737500E+00, -.57218000E+00, 0.22955700E+00, -.99729800E-02, 0.33586800E+00, -.12384100E+00, 0.40428100E+00, -.27473200E+00, 0.61956600E-01, -.41255700E-01, -.15679300E+00, 0.17265900E+00, -.18657000E+00, -.14812900E+00, 0.13560700E+00, 0.10678400E+00, -.12970100E-02, 0.29393000E+00, 0.56580700E+00, -.75679400E-01, -.26160000E-01, -.24692600E+00, 0.87104900E-01, 0.18861500E+00, -.38402900E+00, -.91309900E-01, -.92047500E-01, -.12725800E-01, 0.51755500E-01, 0.48105000E-01, 0.19763900E-01, 0.79798400E-01, 0.49864200E-01, 0.59358700E-01, 0.39428300E+00, 0.15257800E+00, 0.26107900E-01, -.84724200E-01, -.28035700E-01, -.53689800E-01, 0.54256100E+00, 0.23725000E+00, -.19261300E+03, -.19551900E+02, -.22371400E+02, -.23918200E+02, 0.16977900E+03, -.84957900E+02, -.30542700E+02, -.84925300E+02, -.94606600E+02, 0.28733500E+02, -.32265000E+02, 0.16971900E+03, -.22176400E+02, 0.22926300E+02, 0.20538900E+03, 0.45217200E+03, -.22543600E+03, -.28358800E+03, -.22624900E+03, -.75396600E+02, 0.32557900E+02, -.77168900E+01, 0.22325000E+03, -.11665500E+03, 0.89861700E+01, -.10721600E+03, 0.29802200E+04, -.14876800E+04, -.12493700E+04, -.14899000E+04, -.30385700E+03, 0.24482300E+02, -.72534200E+03, -.26434500E+03, -.13518900E+04, 0.10118300E+03, -.17163400E+04, -.56772700E+02, 0.30446200E+02, 0.11647900E+03, 0.28380000E+02, 0.92621900E+02, 0.15101200E+03, 0.23496700E+01, 0.16661000E+03, 0.26990200E+01, 0.15663200E+03, 0.92498000E+01, 0.42420000E+01, -.11314900E+02, -.18736800E+02, -.23321100E+01, 0.14951500E+02, 0.91291500E+01, -.61740500E+02, -.65837300E+02, -.43087900E+02, 0.25088700E+02, 0.32835200E+02, -.82279200E+03, 0.40783900E+03, 0.73655600E+03, 0.41238900E+03, 0.36019300E+03, 0.19839700E+03, -.23658800E+03, -.60967200E+03, 0.30915600E+03, -.27396100E+00, 0.33082500E+03, -.21513500E+03, 0.10923100E+03, 0.26384100E+02, 0.10730300E+03, -.10440100E+03, -.21538200E+03, -.16776600E+02, -.27377900E+03, 0.10817800E+03, -.23986000E+03, 0.11476000E+03, -.15010300E+02, 0.74067100E+01, 0.14082600E+02, 0.76173200E+01, -.24305400E+02, -.20860200E+02, 0.24817000E+02, 0.39047000E+02, 0.37503700E+02, -.12138000E+02, 0.15848300E+02, -.22164000E+04, 0.11088300E+04, 0.96318700E+03, 0.11085500E+04, 0.37416100E+02, 0.33438100E+03, 0.23783300E+03, -.57340700E+03, 0.44309800E+03, 0.30752500E+03, 0.12835700E+04, -.46023400E+03, 0.22940400E+03, 0.20607800E+03, 0.23005700E+03, 0.11688600E+03, 0.15334300E+02, 0.73327700E+02, -.17403300E+03, 0.13150300E+03, -.28659800E+02, 0.27471100E+03, -.17800600E+04, 0.89083900E+03, 0.10297700E+04, 0.89070100E+03, 0.23024900E+02, 0.22997500E+03, 0.17811500E+03, -.51510500E+03, 0.35682600E+03, 0.26609900E+03, 0.11422700E+04, -.11168300E+03, 0.59422900E+02, -.94911200E+02, 0.55537500E+02, 0.51091800E+02, 0.34498400E+02, 0.10697500E+03, -.13925000E+03, 0.45309000E+02, -.12499800E+02, 0.66355100E+02, 0.26015900E+01, -.13348500E+01, 0.99011500E+00, -.12187500E+01, -.10797600E+01, 0.12750800E+00, -.65397100E+01, -.68634600E+01, -.40117500E+01, 0.59765400E+00, -.10618900E+01, 0.22842000E+03, -.11269400E+03, -.21502900E+03, -.11387700E+03, -.48596400E+02, -.11756200E+03, -.42884300E+02, -.67000200E+02, 0.26765900E+02, -.11642700E+03, -.60213900E+02, -.11193000E+04, 0.55809900E+03, 0.23299900E+03, 0.55946900E+03, 0.55816600E+02, -.53296400E+02, 0.65364000E+03, 0.97916800E+03, 0.93950200E+03, -.16353200E+02, 0.87462100E+03, -.87405500E+03, 0.43783400E+03, 0.47438500E+03, 0.43725100E+03, 0.94822600E+02, 0.18559800E+03, -.26630700E+03, -.10211200E+04, -.23213600E+03, 0.13890600E+03, 0.19204500E+03, 0.44751700E+00, 0.90424400E+01, -.15098900E+02, 0.32750000E+01, -.24326400E+02, 0.20841400E+02, -.87033100E+01, -.41908200E+01, 0.15790500E+01, 0.12030200E+02, 0.43633200E+01, -.76573500E+02, 0.23023500E+02, 0.81365300E+01, 0.45280300E+02, -.78499000E+02, 0.28260800E+02, -.14335100E+02, -.74114900E+02, 0.14657500E+02, 0.68710900E+02, 0.99315900E+00, 0.98604300E+00, 0.23440800E+01, -.21526800E+03, -.94533100E+02 },
        { -.24619900E+00, -.19493500E+01, 0.45590000E+00, -.21469400E+00, 0.13528400E+00, 0.32604000E+00, 0.28791700E+00, 0.41430200E+00, 0.11419400E+00, -.14969200E+00, -.27500400E-01, 0.38080600E-01, -.46159300E+00, -.24277200E+00, -.13340000E+00, -.95070900E-01, 0.74232900E+00, -.15269000E+00, 0.38315300E+00, -.51087300E+00, 0.58353500E+00, -.84088000E+00, -.33153100E+00, -.15535100E+00, 0.27705400E+00, 0.33026600E+00, 0.45553800E+00, 0.28208700E+00, 0.91570400E-01, -.27215800E+00, 0.33822600E-01, 0.21680000E-01, 0.10361400E+00, 0.37003200E+00, 0.24831200E+00, 0.40354100E+00, -.35328300E-01, 0.10692400E+01, -.19665900E+00, 0.24923000E+00, -.55034200E-01, -.24235400E+01, -.15527400E+01, -.46943200E+00, 0.11985400E+01, -.16227100E+00, -.69334300E-01, 0.42635600E-01, 0.24062100E+00, -.19699300E+00, 0.44658400E+00, 0.13664800E+00, 0.92713500E-01, 0.13111400E+01, -.82699000E-01, 0.73825600E-01, 0.46489900E+00, 0.24066400E+00, -.10062500E-01, 0.68237200E-01, 0.26247000E+00, 0.92946500E-01, -.28088700E+00, 0.41988100E+00, -.97706800E-01, 0.31715300E-01, -.20622800E+00, -.62533300E+00, 0.36766100E+00, -.42661300E-02, -.33356100E+00, -.85924000E+00, -.15750700E-01, -.75004900E-01, 0.29149600E+00, 0.19096600E+00, -.63498800E-01, -.61347400E+00, -.12396700E+00, 0.12590200E+00, 0.10156200E-01, -.81991900E-01, 0.24051300E+00, -.34118600E+00, -.21204100E+00, -.53182900E-01, -.18242500E-01, 0.27333600E-01, 0.75345800E+00, 0.13236700E+00, 0.15752200E+01, 0.89141700E-01, 0.20349800E+00, -.13550200E+00, -.28090500E+00, -.24918100E-01, 0.23195800E+03, -.11811600E+03, 0.14626500E+03, -.17660400E+03, 0.79105600E+02, 0.19625400E+02, 0.88352300E+02, 0.13502400E+02, 0.14416800E+03, -.27097600E+03, -.15451800E+03, 0.85066800E+02, 0.13219800E+02, 0.18418100E+03, 0.31466000E+03, -.14801400E+03, -.22159200E+03, -.15691900E+03, -.46748800E+02, -.45609400E+02, 0.34922400E+02, 0.99779600E+02, -.13882300E+03, -.28265300E+02, -.19575800E+03, 0.77148800E+03, -.38866400E+03, -.70971100E+03, -.38626500E+03, -.22895400E+03, -.58616600E+03, 0.46692800E+03, 0.26097200E+03, -.53588900E+03, -.19506300E+03, -.12334000E+04, -.37709400E+03, 0.20293600E+03, 0.23150600E+03, 0.18855400E+03, 0.24396500E+03, 0.15946900E+03, 0.61207300E+02, 0.94554600E+02, -.96261700E+01, 0.17761000E+03, 0.10726800E+03, 0.15354400E+03, -.12537800E+03, 0.13740700E+03, -.74219800E+02, -.84751400E+02, -.20717000E+03, 0.14871400E+03, 0.13785700E+03, 0.63509400E+02, -.25381600E+03, -.86300200E+02, -.56227200E+03, 0.27089400E+03, 0.52665300E+03, 0.27863000E+03, 0.16407200E+03, 0.23646700E+03, -.45643800E+03, -.40908900E+03, 0.35445800E+03, -.10616400E+01, 0.65584100E+03, -.90810600E+02, 0.61774800E+02, -.59271700E+02, 0.46057100E+02, -.13640500E+03, -.13100900E+03, -.54235300E+02, -.13130100E+03, 0.15819900E+02, -.15623900E+03, -.15575300E+02, 0.21105600E+01, -.41862600E+01, 0.27519100E+01, -.13294800E+01, 0.13889900E+01, 0.11621200E+02, -.24862900E+02, 0.90558700E+01, -.54422800E+02, 0.31229300E+02, 0.42211900E+01, -.19225300E+04, 0.95931600E+03, 0.38178600E+03, 0.96038200E+03, 0.77192100E+03, 0.13693100E+04, -.11041100E+04, -.71824700E+03, -.11553700E+03, 0.13286100E+04, 0.14017200E+04, -.33886700E+03, 0.17540400E+03, 0.11707700E+03, 0.16956600E+03, 0.34531200E+02, -.68358700E+02, -.58366900E+02, -.15011400E+03, 0.17943700E+03, -.50957800E+02, 0.20635400E+03, -.80749700E+03, 0.40495600E+03, 0.11174500E+04, 0.40204300E+03, 0.72175600E+03, 0.13094500E+04, -.13644500E+04, -.57312200E+03, -.49788500E+03, 0.13026600E+04, 0.86642500E+03, -.33272400E+03, 0.17880900E+03, -.14971200E+03, 0.16893100E+03, 0.62138400E+02, -.11348900E+03, 0.40515000E+02, -.13926200E+02, 0.50464500E+03, -.89526600E+02, 0.18916200E+03, 0.14879900E+01, -.22927900E+01, 0.23657100E+01, -.94528200E+00, -.14668100E+01, 0.23799500E+01, -.29317400E+01, -.96209400E+01, -.78598100E+01, 0.16116200E+01, 0.72047800E+01, 0.12139800E+03, -.62251900E+02, -.11558600E+03, -.61544000E+02, -.49442900E+02, -.13146600E+03, 0.96461100E+02, 0.10137000E+03, 0.14810200E+02, -.16270600E+03, -.15933600E+03, -.14357500E+04, 0.71274300E+03, 0.78316800E+03, 0.71833100E+03, 0.10696300E+03, 0.25210300E+03, -.16019600E+03, 0.20958800E+03, 0.10718600E+04, -.19683600E+02, 0.16457600E+04, -.36041300E+03, 0.18171700E+03, -.11587000E+03, 0.17964700E+03, 0.16048400E+03, 0.16237300E+03, 0.19544400E+03, -.64802100E+03, -.41388400E+03, 0.30684700E+03, -.51540900E+03, 0.11442000E+01, 0.96696200E+02, 0.73401900E+01, -.22356900E+02, -.45311000E+02, 0.19431800E+02, -.22209800E+02, 0.84870700E+02, 0.26854600E+01, 0.39714500E+02, 0.39684300E+02, -.17197800E+02, 0.25071900E+03, 0.28715100E+02, 0.30267000E+02, -.53055200E+02, -.29358300E+02, 0.16459400E+02, 0.76823500E+02, 0.29203000E+02, -.94893400E+01, -.14927300E+02, 0.19883100E+01, -.53115700E+01, 0.20328900E+02, -.87876200E+02 },
        { -.22259300E+00, 0.10310100E+01, -.19960600E+01, -.30399000E+00, 0.12597300E+01, 0.20215800E+00, 0.16785100E+01, -.41923600E+00, -.26763200E+00, 0.49721800E+00, 0.72615200E-01, -.13514500E+01, 0.32646000E+00, -.54959500E+00, -.15476700E-01, -.14622500E+00, -.40720600E+00, 0.17434500E+00, -.23425100E+00, 0.47709700E+00, 0.67306900E-01, -.19442900E+01, 0.15959600E+00, 0.32647900E+00, -.34620100E+00, -.11899900E-01, -.52969100E+00, -.30316100E+00, -.15666000E+00, 0.39473700E+00, 0.37957100E+00, 0.21963200E+00, -.10793900E+00, -.45313600E+00, 0.24250200E+00, -.15974800E+00, 0.15316800E-03, -.22033200E+00, 0.29482200E+00, -.46720900E+00, 0.18418600E+00, -.48476800E+00, -.19703200E+01, -.44334500E+00, 0.53337300E+00, 0.44158200E-01, 0.23699000E-01, -.29187500E-01, -.31164500E-01, -.21492400E+00, 0.14344900E+00, 0.29570500E+00, -.35072200E-01, -.27854000E+01, 0.13177000E+00, -.41435800E+00, 0.36882600E+00, -.66050000E+00, 0.21029900E+00, -.26665100E+00, 0.34603300E+00, 0.25001500E+00, -.27415600E-01, 0.55730400E-01, 0.16664700E-02, -.75419200E-01, -.16485700E+00, 0.42980600E-01, 0.38025300E+00, 0.35945900E-02, -.82466900E+00, 0.71075500E+00, -.11865700E+00, 0.31220300E-01, 0.26578700E-01, 0.27772000E+00, 0.21208500E+00, -.53040000E+00, -.11789600E+00, 0.10188800E+00, -.10833200E-01, 0.73167300E-01, -.49468700E+00, 0.20078400E+00, 0.73608700E-01, -.18177000E+00, 0.57444600E+00, -.53388800E+00, -.11610100E+01, 0.29411100E-01, -.30894700E+00, -.12031300E+00, 0.44071900E+00, 0.15989200E+01, -.54601200E-01, -.64286100E+00, -.76537300E+00, -.25089800E+03, 0.86619400E+02, -.69652100E+03, 0.33460400E+03, 0.21072900E+03, 0.34828200E+03, 0.30764400E+02, 0.19274100E+03, 0.66018000E+02, 0.22130700E+03, 0.45177200E+03, 0.16570200E+03, 0.79350800E+03, 0.73822900E+03, -.36237000E+03, -.51597000E+03, -.36890200E+03, -.20353900E+03, -.32244500E+02, 0.10697100E+03, 0.39725200E+03, -.13291400E+03, -.35022200E+02, -.83190900E+02, 0.58014700E+04, -.29016400E+04, -.32475600E+04, -.29010000E+04, -.99064100E+03, -.87710800E+03, -.64045300E+03, 0.29834000E+03, -.19917300E+04, -.37714000E+03, -.38483200E+04, -.35452700E+03, 0.19165800E+03, 0.41514900E+03, 0.17726600E+03, 0.37052000E+03, 0.33464500E+03, 0.12444600E+03, 0.48639700E+03, 0.82871700E+02, 0.34436900E+03, 0.19618000E+03, -.20989900E+03, 0.34816100E+02, 0.28851900E+03, 0.10628600E+03, 0.31448500E+01, -.26054600E+03, 0.25785400E+03, 0.13584800E+03, 0.13236300E+03, -.25379500E+03, -.21324400E+02, -.16688200E+04, 0.82474900E+03, 0.15242000E+04, 0.83311700E+03, 0.57158900E+03, 0.66718700E+03, -.83113100E+03, -.14400000E+04, 0.18437500E+03, 0.16192600E+03, 0.11357000E+04, -.95648400E+01, 0.15746200E+02, -.34664100E+03, 0.51171300E+01, -.10073400E+03, -.23065800E+03, -.47996100E+02, -.39115900E+03, -.11918100E+03, -.27733800E+03, -.14483900E+03, -.42024000E+02, 0.17631200E+02, 0.86355800E+02, 0.20871300E+02, -.21340400E+02, 0.14087600E+02, 0.11588200E+02, 0.21332700E+02, -.32046200E+02, 0.22660600E+02, 0.64193200E+02, 0.78117300E+03, -.39176600E+03, -.52409800E+03, -.39104300E+03, 0.61946000E+02, 0.93518600E+03, -.91532300E+03, -.28996000E+03, -.63012200E+03, 0.88450100E+03, 0.14649000E+04, -.77763000E+03, 0.39374200E+03, 0.43056400E+02, 0.38888200E+03, 0.12117600E+03, -.83652300E+02, -.73326000E+02, -.41932800E+03, 0.26288400E+03, -.12886600E+03, 0.55465900E+03, 0.10136100E+04, -.50453800E+03, -.39262000E+03, -.50768500E+03, -.40731900E+03, 0.29336400E+03, -.81223000E+03, -.34291200E+03, -.84180200E+03, 0.47676000E+03, 0.14553100E+04, -.75742000E+03, 0.39827300E+03, -.35900200E+03, 0.38020800E+03, 0.59890800E+02, 0.23079200E+02, -.56276400E+02, -.26582700E+03, 0.22951200E+03, -.10982400E+03, 0.58124600E+03, 0.53561700E+01, -.37956000E+01, -.92701500E+01, -.27814800E+01, -.76760500E+01, -.67361700E+00, -.12997100E+02, -.22361900E+02, -.76941600E+01, 0.21321400E+01, 0.92617500E+01, -.34225200E+02, 0.10123500E+02, -.29040200E+03, 0.16675400E+02, -.13905900E+02, -.25908300E+03, 0.17093400E+03, 0.11626400E+03, 0.19044400E+03, -.29786600E+03, -.14686900E+03, -.61149500E+04, 0.30487200E+04, 0.19068600E+04, 0.30577100E+04, 0.34547700E+03, -.14124100E+03, 0.13582900E+04, 0.60652200E+03, 0.26248000E+04, -.19409300E+03, 0.41860800E+04, 0.88645200E+03, -.43956600E+03, -.10727900E+03, -.44351500E+03, 0.14219500E+03, 0.41847600E+03, -.60358800E+03, -.11189500E+04, -.82281900E+03, 0.32908100E+03, -.13282600E+04, 0.53656300E+01, 0.66321800E+02, -.36374800E+02, -.10381200E+02, -.74754700E+02, 0.36196100E+02, -.29835600E+02, 0.53217400E+02, -.69217900E+00, 0.49009100E+02, -.18809000E+02, -.14907100E+03, 0.34370600E+03, 0.46681200E+02, 0.95135200E+02, -.15345500E+03, 0.11637300E+02, -.55074300E+01, 0.13789100E+03, 0.22358800E+02, -.11619000E+03, 0.15526500E+02, -.15474600E+01, -.14131400E+02, -.16311000E+03, -.19100800E+03 },
        { 0.51341900E-01, -.91684500E+00, -.87790800E+00, -.46143500E-01, 0.20096200E-01, -.60443100E-01, -.66177300E-01, 0.19352900E+00, -.68397300E-01, -.23527400E+00, 0.98437800E-01, 0.22512800E+01, -.42409600E+00, 0.92437200E+00, 0.11473500E+00, 0.15348000E+00, 0.31878800E+00, -.77798700E-01, 0.59653800E-01, -.43232500E-01, -.54265800E-01, -.25535800E+00, -.21895900E-01, 0.25855300E+00, 0.45242600E-01, 0.64406000E-01, 0.36683700E+00, -.29955000E+00, 0.40155300E-01, -.11709000E+00, -.12586000E+00, -.24200900E+00, 0.81657400E+00, -.16583400E+00, 0.12355200E+00, -.22016300E+00, 0.75524100E-01, -.47546900E+00, 0.74612300E-01, -.76542900E+00, -.82314800E-01, -.73588700E-01, 0.96827300E+00, 0.84855000E-02, -.56663400E+00, 0.23737500E+00, 0.90888000E+00, 0.48700800E-01, -.20009100E-01, 0.19448000E+00, -.95506600E+00, 0.76840000E+00, 0.28105200E+00, 0.43602000E+00, -.34362800E+00, -.90172800E-01, -.53742900E+00, 0.10379800E+00, -.18318600E+00, -.81244900E+00, 0.23559800E+00, -.12108200E+00, 0.15079800E+00, -.42693900E-01, -.81443900E-01, -.25448000E+00, -.18298100E+00, -.71484200E-01, 0.23619600E+00, 0.65584500E-03, 0.24025700E+00, 0.18923300E+00, -.87422100E-01, 0.20240200E+00, 0.56824400E+00, -.11315600E+00, -.19413900E+00, -.15381400E-02, 0.19561800E-02, 0.11583900E+00, 0.14993200E-01, -.97462300E-01, -.58040700E+00, 0.21189600E-01, -.63199200E-01, -.19198300E+00, 0.75724800E+00, -.42969100E+00, -.16918400E+00, -.70089700E-01, -.10142800E+00, -.63973400E-01, 0.62533500E-02, -.13871100E+01, 0.29343900E-01, -.28088800E+00, 0.30846500E+00, 0.12377600E+00, -.26988200E+03, 0.51254200E+03, -.25791900E+03, -.10065000E+03, -.25635000E+03, -.16471100E+03, -.60302600E+02, -.15377400E+02, 0.88278400E+02, -.13884600E+03, -.11007000E+02, -.97088700E+00, -.91282600E+01, 0.56030300E+01, 0.43733300E+02, 0.40828000E+01, 0.11069600E+02, -.27695300E+02, 0.74896900E+02, 0.13990200E+03, 0.41827600E+02, -.33935200E+02, 0.14878300E+03, 0.12982600E+04, -.65648400E+03, 0.51586200E+03, -.64851700E+03, 0.49249700E+01, 0.75840700E+02, -.33949300E+03, 0.18825600E+03, -.45006400E+03, 0.12703000E+03, -.88251600E+03, 0.24935000E+03, -.11572500E+03, -.56775500E+02, -.12469100E+03, -.24620900E+02, 0.20471000E+02, -.13960300E+03, -.89729200E+02, -.55294600E+02, 0.91577100E+01, -.11060500E+03, -.19464800E+02, 0.33643400E+02, -.11207500E+03, 0.79051800E+01, 0.13726100E+02, 0.21060700E+03, -.77130600E+02, -.14040700E+03, -.18034000E+03, 0.21625800E+03, 0.11461300E+03, -.35280000E+03, 0.17286300E+03, 0.24772700E+03, 0.17933200E+03, 0.27039600E+03, 0.13792100E+03, -.12664100E+03, -.46228100E+03, 0.25098100E+02, 0.65972600E+02, -.12954400E+03, -.20286300E+03, 0.13310000E+03, 0.35309200E+02, 0.10067100E+03, -.93282800E+02, -.10446200E+03, -.49723000E+02, -.23276100E+03, 0.50228700E+02, -.96350300E+02, 0.17698500E+03, 0.17881500E+02, -.10869700E+02, -.48256700E+02, -.86161400E+01, -.60907600E+01, 0.10293800E+02, -.21594700E+02, -.16726600E+02, -.16741700E+02, 0.37468700E+01, 0.16598300E+02, 0.52742200E+03, -.26604200E+03, -.48885000E+03, -.26267700E+03, -.42483900E+02, -.75537700E+02, -.25374600E+03, -.11785200E+03, -.35297400E+03, -.55194900E+02, 0.29442400E+03, -.12746400E+03, 0.72441000E+02, 0.12798200E+03, 0.63560300E+02, 0.78850100E+02, 0.82249100E+02, 0.33162700E+02, 0.21266500E+02, 0.56992900E+02, 0.35666000E+02, 0.11325800E+03, 0.11208700E+04, -.56080100E+03, -.29982200E+03, -.55844400E+03, 0.49028400E+02, 0.22799000E+03, -.52904800E+03, -.14229200E+03, -.64414800E+03, 0.23209900E+03, 0.59991300E+02, 0.14626800E+03, -.80115700E+02, 0.51380200E+02, -.75372900E+02, 0.66106400E+02, -.33757100E+02, 0.76806400E+02, 0.20161100E+03, 0.48846000E+02, -.73211100E+02, -.25735800E+03, 0.33260100E+01, -.37325200E+01, 0.21924900E+01, -.14251100E+01, 0.20777000E+01, 0.10573300E+00, -.29887900E+01, -.21664600E+01, -.29147000E+01, 0.23511800E+01, -.66321300E+01, 0.26967500E+03, -.13028400E+03, -.14313500E+03, -.13385300E+03, -.86392500E+02, 0.30803600E+01, -.81066800E+02, -.87518300E+02, -.85579400E+02, -.72706000E+01, -.50956700E+02, -.78608100E+03, 0.39615600E+03, 0.27773300E+03, 0.39250900E+03, -.10009100E+03, -.85575400E+01, 0.49398500E+03, 0.87383600E+02, 0.45365800E+02, -.10742600E+02, 0.55770200E+03, 0.10537500E+04, -.52922400E+03, -.60096000E+03, -.52622100E+03, -.69579600E+02, -.59288800E+02, -.46518600E+03, -.51942200E+02, -.67023700E+02, -.12095900E+03, -.38500100E+03, 0.88318700E+00, -.14395400E+02, 0.22606100E+02, 0.20769100E+02, 0.42876000E+01, -.98293700E+01, -.45608200E+01, -.69190700E+01, -.25034900E+00, 0.34210800E+01, -.19775200E+02, -.47700100E+02, 0.20178100E+02, 0.11246900E+02, -.42273500E+02, -.52201900E+02, -.59790600E+01, 0.51356700E+01, 0.12004500E+03, 0.41504800E+01, -.10844900E+03, 0.19745600E+02, -.74001300E+00, 0.61641500E+01, -.51984800E+02, -.89689300E+01 },
        { 0.37407500E+00, 0.28830900E+01, -.17610000E+01, 0.20108700E+00, -.45912700E+00, -.77622700E+00, -.16673200E+00, 0.17505000E+01, 0.34082900E+00, -.37569100E+00, -.86971200E-01, 0.29343400E+00, -.26137700E+00, 0.15729600E+00, 0.21651400E+00, 0.14637400E+00, 0.82162400E+00, -.10617200E+00, 0.32775900E-01, -.20571700E+00, 0.40498200E+00, 0.43739100E+00, 0.30235400E-01, 0.25000100E+01, 0.47455500E+00, -.63904400E-01, 0.85635200E+00, -.18965500E+00, 0.63360400E-01, -.50883400E+00, 0.11944700E+00, -.54450900E+00, 0.48057300E+00, 0.32215700E+00, 0.16469300E+00, -.56764000E-01, 0.67901200E-01, 0.36266800E+00, 0.32818900E+00, -.41018200E+00, 0.45299500E-01, -.58047200E+00, -.80742400E+00, -.31359200E+00, 0.35564900E+00, -.12119500E+00, -.26407100E+00, 0.76497200E-01, 0.13346300E+00, 0.20364100E+00, 0.10622900E+01, -.21630800E+00, -.34114000E+00, 0.22969700E+01, 0.12362300E+00, -.81708800E-01, 0.14004900E+00, -.82989000E-02, -.17175000E-01, 0.20535500E-01, 0.30066400E+00, 0.29492000E+00, -.33273500E+00, 0.28296000E+00, -.64312100E-01, -.30623300E+00, -.47028400E+00, -.10975800E+01, 0.11267300E+01, 0.42803000E-03, -.14867600E+00, 0.22277600E+00, -.25174100E+00, -.40465500E-02, -.49853800E-01, 0.26188700E+00, 0.11379800E+00, -.89067100E+00, 0.12493500E+01, 0.14917200E-01, 0.22935400E-02, -.52394800E-01, -.17671800E+00, -.34757500E+00, -.81846700E-01, -.28611400E+00, 0.27986300E+00, 0.52605300E+00, 0.16870800E+01, -.53642200E+00, 0.15405400E+01, -.16871400E+00, -.84077100E+00, 0.21425600E+01, 0.11584000E+01, 0.13352500E+01, 0.82127400E+00, -.52457200E+00, 0.11133000E+01, -.96187000E+03, 0.48728100E+03, 0.18370500E+03, 0.48074600E+03, -.93626100E+01, 0.27691100E+03, 0.46672100E+03, 0.31878200E+03, 0.33391800E+03, 0.18638500E+03, 0.97489100E+03, 0.52210500E+03, -.27540800E+03, -.23900500E+03, -.26159000E+03, -.22534600E+03, 0.11326400E+03, 0.27968600E+02, 0.27063200E+03, -.69413800E+02, 0.33891300E+02, 0.60086200E+02, 0.45183700E+04, -.22385900E+04, -.27941200E+04, -.22584800E+04, -.72526200E+03, 0.53516500E+03, -.13796100E+04, -.33274600E+03, -.21168800E+04, 0.23937300E+03, -.22176700E+04, -.19722100E+03, 0.84567800E+02, 0.21606400E+03, 0.98564000E+02, 0.72410400E+02, 0.27949000E+03, -.12862200E+03, 0.36953100E+03, 0.14360400E+03, 0.23924900E+03, 0.26017600E+03, -.12208400E+04, 0.55018900E+03, 0.69928400E+03, 0.60787200E+03, 0.28143400E+03, -.17823700E+03, 0.44451800E+03, 0.34954800E+02, 0.53595500E+03, -.10921200E+03, 0.24054800E+03, -.80899100E+03, 0.42066600E+03, 0.70769300E+03, 0.40775300E+03, 0.31818500E+03, 0.37280500E+02, -.22673300E+03, -.95275800E+03, 0.88800500E+02, 0.25996100E+02, 0.32559000E+03, -.35730500E+03, 0.13244800E+03, 0.18884200E+03, 0.17777800E+03, -.92527900E+02, -.23400600E+03, 0.19153000E+03, -.18260700E+03, 0.69997200E+02, -.23642000E+03, 0.27823700E+02, -.18967200E+03, 0.93115000E+02, 0.11934800E+03, 0.95218500E+02, -.32404100E+02, -.78827800E+02, 0.47145100E+02, 0.14082600E+03, 0.33503200E+03, -.75331300E+02, 0.22615600E+03, -.56304100E+04, 0.28125000E+04, 0.30359800E+04, 0.28163600E+04, -.47394900E+02, 0.85587300E+03, -.51294600E+03, -.18045000E+04, 0.15841900E+04, 0.72533600E+03, 0.55090700E+04, -.10609700E+04, 0.52486700E+03, 0.58410300E+03, 0.53023700E+03, 0.18583900E+03, -.11997400E+03, 0.67156300E+02, -.45096800E+03, 0.27909400E+03, -.11351400E+03, 0.42278200E+03, -.64044800E+04, 0.31857000E+04, 0.29018100E+04, 0.32044300E+04, 0.53672600E+02, 0.11637900E+04, -.34630600E+03, -.16639500E+04, 0.21382900E+04, 0.98954100E+03, 0.62813400E+04, -.33426900E+03, 0.18553600E+03, -.39273500E+02, 0.16548200E+03, 0.17359800E+03, 0.57898600E+03, -.56181100E+03, -.66774700E+03, -.52360000E+03, 0.57045200E+03, 0.36755900E+03, 0.12027900E+02, -.83099700E-01, -.62996700E+01, -.57355900E+01, -.54527300E+01, 0.47714400E+01, -.13597800E+02, -.20825000E+02, -.13046500E+02, 0.49934400E+01, -.31831000E+01, -.68001300E+03, 0.32970500E+03, 0.11499200E+03, 0.34108800E+03, -.58405700E+02, -.46362600E+03, 0.41572400E+03, 0.20383700E+03, 0.53466700E+03, -.39602100E+03, 0.11987100E+03, -.96748800E+03, 0.45675000E+03, 0.15550300E+03, 0.48315100E+03, 0.42943200E+03, -.24539300E+03, 0.92038800E+03, 0.18790500E+04, 0.19400400E+04, 0.94366100E+02, 0.11149500E+04, -.38914400E+04, 0.19655200E+04, 0.23673200E+04, 0.19464600E+04, -.11210100E+03, 0.10925400E+03, 0.24452300E+02, -.19666700E+04, -.17310400E+03, -.17890700E+03, 0.12288400E+04, -.57820300E+01, -.11256700E+02, -.34669000E+02, 0.15886700E+02, -.17427400E+02, 0.44212900E+02, -.60089900E+01, -.45145400E+02, 0.12703900E+01, 0.97677100E+01, 0.31845500E+02, -.12848500E+03, -.95248800E+02, 0.31618500E+02, 0.12236000E+03, -.88331700E+02, 0.56769500E+02, -.97245400E+02, -.55873800E+03, 0.55652900E+02, 0.52557800E+03, -.10188900E+02, -.74506800E+00, -.32832900E+01, -.52725000E+03, -.17515100E+03 },
        { -.60191000E-01, 0.51854700E-01, -.93121600E+00, -.47154100E-01, 0.31452700E+00, -.51650000E-01, 0.18125400E+00, 0.33511700E+00, 0.30620100E-01, -.40633200E-01, -.35725100E-01, -.56196900E+00, 0.15144800E+00, -.34409300E-01, -.39021800E-01, 0.81706600E-01, -.22931100E+00, -.75583900E-02, 0.19591400E+00, -.61620900E-01, -.26306800E+00, -.19602600E+00, 0.10305300E-01, -.15789100E+00, 0.18074100E-03, 0.72851900E-02, 0.19162800E+00, 0.74909000E-01, 0.36410800E-01, -.40049400E-01, 0.14287000E-01, 0.37165800E-01, -.11552200E+00, 0.19573700E-01, 0.19937700E-01, 0.20283000E+00, -.19743900E-01, 0.38693700E+00, -.51473600E-01, 0.28457300E+00, -.21144800E+00, -.47460700E-01, 0.17588500E+00, 0.11115500E+00, 0.42398400E+00, -.30836600E-01, 0.77690200E-02, 0.10180700E-01, 0.94975900E-01, -.12201400E+00, 0.84891900E-01, -.34073200E+00, 0.10333700E+00, 0.86440300E-01, -.68249000E-03, 0.36801500E-01, 0.16173300E-01, 0.63072200E-01, -.57352500E-01, 0.60927400E-02, -.11195500E+00, -.97189000E-01, 0.78596900E-01, -.82772900E-01, 0.16471600E-01, -.43521600E-01, 0.14775400E-01, -.59599100E-01, -.47202000E-01, -.11355700E-02, 0.33732300E+00, -.14286700E+00, 0.59058900E-01, 0.16811500E-01, -.19342100E+00, 0.42951100E-01, 0.79141100E-01, 0.18142300E+00, 0.27549800E-01, -.11289200E+00, -.83508700E-02, 0.17328000E-01, 0.22466800E+00, -.10517400E+00, -.79023800E-01, 0.13510700E+00, -.72161000E-01, 0.17204400E+00, 0.46920100E+00, -.63851900E-02, 0.33504300E+00, -.14035400E-01, -.11857000E+00, -.11344600E+00, -.10757000E+00, -.24278200E+00, 0.94253700E-01, -.10143000E+00, -.12393000E+00, -.83664400E-01, 0.31134800E+01, 0.64695100E+01, -.63705400E-01, -.26683500E+01, 0.26799100E+02, 0.17133500E+02, 0.25152900E+02, -.19171900E+02, 0.23694900E+02, 0.30666100E+02, 0.24756900E+02, -.13412300E+02, -.12415900E+02, -.12553000E+02, -.78243200E+01, 0.14843000E+02, 0.19929100E+02, 0.45228700E+02, 0.15486900E+01, 0.97587200E+01, 0.15283000E+02, 0.26876600E+03, -.13444200E+03, -.53335900E+02, -.13415300E+03, 0.72176000E+02, 0.67833300E+02, -.11815300E+03, -.10475700E+03, -.17415900E+03, 0.60062100E+02, -.19370800E+03, -.10461800E+02, 0.45239700E+01, 0.16114600E+02, 0.52149100E+01, 0.37534500E+01, 0.64922700E+01, -.55038000E+01, -.15606000E+02, -.48588000E+01, 0.59271100E+01, 0.26683600E+02, -.11393100E+03, 0.59612900E+02, 0.40553400E+02, 0.56144000E+02, 0.35407500E+02, 0.41717600E+02, -.25583100E+02, -.76969900E+02, 0.30497900E+02, 0.43541500E+02, 0.18367700E+02, -.72528100E+02, 0.37993700E+02, -.25304000E+02, 0.37321100E+02, 0.28201400E+02, -.25394300E+02, 0.72417700E+01, 0.27619900E+02, 0.69622500E+02, -.46509500E+02, 0.25576900E+02, 0.11460700E+03, -.55965800E+02, 0.39899900E+01, -.57586800E+02, 0.31011100E+02, 0.82501900E+01, -.29579500E+02, 0.39707100E+02, -.73144700E+01, -.69850100E+01, -.65195000E+02, -.18378700E+01, 0.71169200E+00, 0.21474200E+00, 0.10435100E+01, -.16741300E+02, -.15511400E+02, 0.14295900E+02, 0.15530100E+02, 0.30908400E+02, -.13262900E+02, 0.10125700E+02, -.50493100E+03, 0.25262900E+03, 0.26822900E+03, 0.25283900E+03, -.76911700E+02, 0.14281800E+02, 0.15420400E+03, -.11455000E+03, 0.21651500E+03, 0.68496800E+01, 0.29157200E+03, 0.68603900E+01, -.26287300E+01, -.39636300E+02, -.35132200E+01, 0.17051500E+02, 0.35702100E+02, 0.10093800E+02, 0.93228700E+01, 0.11333400E+01, 0.20478600E+02, -.38287600E+02, -.56514700E+03, 0.28123800E+03, 0.22695200E+03, 0.28328600E+03, -.76267900E+02, -.38808700E+02, 0.19349900E+03, -.96688500E+02, 0.27693800E+03, -.33818000E+02, 0.34106700E+03, -.50654200E+02, 0.25423000E+02, -.59501700E+01, 0.24684000E+02, -.10669300E+01, 0.49025200E+02, 0.76622100E+01, 0.35330200E+02, -.26722200E+02, 0.47852300E+02, 0.60169500E+02, 0.16395800E+00, 0.19785900E+00, -.10430200E+01, 0.86111200E-02, 0.18488100E+00, -.45766100E+00, -.33803600E+00, -.23781100E+00, -.18047600E+00, -.43775400E+00, -.35333500E+00, 0.26830100E+02, -.12062000E+02, 0.32813100E+02, -.13064500E+02, 0.31027900E+02, 0.25829000E+02, -.25038100E+02, 0.11418300E+02, 0.17251600E+01, 0.16702800E+02, -.38284000E+02, 0.28742300E+03, -.14436300E+03, -.15829100E+03, -.14390400E+03, -.67353500E+02, -.61196500E+02, 0.65595700E+02, 0.22019000E+03, 0.12526400E+02, -.31163500E+02, -.45401400E+02, -.63476800E+03, 0.31916100E+03, 0.31993500E+03, 0.31762400E+03, 0.50685400E+01, 0.45205500E+02, 0.12914800E+02, -.21146200E+03, 0.74301300E+02, 0.25110200E+02, 0.24364700E+03, -.10910700E+00, -.14224000E+02, -.95657500E+01, 0.35722100E+01, -.74338500E+01, 0.47775900E+01, 0.22898100E+01, -.17194100E+02, -.49826900E+00, -.17551100E+00, 0.75288500E+01, -.19758500E+02, -.27119300E+02, 0.16701300E+01, 0.21500600E+02, -.49523000E+01, 0.76566800E+01, -.10225600E+02, -.64606700E+02, -.39005500E+01, 0.53380500E+02, 0.12372500E+01, -.50650100E+00, -.14496100E+01, -.44602700E+02, -.57057200E+01 },
        { -.15635700E+00, 0.73980500E+00, 0.31659100E+00, -.29857300E+00, 0.33236200E+00, 0.19956700E+00, 0.52452800E+00, -.97710700E+00, -.34090300E+00, 0.15276100E+00, 0.13298300E+00, 0.36515600E+00, -.15304800E+00, -.17135400E+00, -.16964700E+00, -.39730400E+00, -.77364800E+00, 0.53080200E-01, 0.45135400E+00, 0.14149100E+00, -.65764700E+00, 0.29415400E+00, -.26341800E+00, 0.67734000E+00, 0.49229500E+00, 0.26871500E+00, 0.98695000E-01, -.69215700E+00, -.79197300E-01, -.11761600E-01, -.17162600E+00, -.28068000E+00, 0.16505200E+00, 0.37303800E+00, 0.58711300E+00, 0.70636600E-01, -.84634200E-02, 0.11813200E+01, 0.61655800E+00, -.25045800E+00, -.13199300E+00, -.14428300E+01, 0.48150100E+00, 0.12216500E+00, 0.50718600E+00, 0.27834300E+00, 0.10682000E+01, -.26540800E-01, 0.51340700E-02, 0.63109300E+00, 0.10279000E+01, 0.53864600E+00, -.67588900E-01, 0.94662600E+00, -.32736700E+00, 0.64127900E+00, 0.87567700E+00, 0.13248400E+00, 0.15996000E+00, 0.52660100E+00, 0.51948600E-01, 0.25969000E+00, 0.64408800E-01, -.46534200E+00, -.37488900E-01, -.27572900E+00, -.21290800E+00, -.84042500E-01, 0.38193700E+00, -.10102500E-01, 0.27437300E+00, -.56106200E+00, -.17417700E+00, -.16567200E+00, 0.42544100E+00, -.15028900E+00, -.65722400E-01, -.36978200E+00, -.61020200E-01, -.10310700E+00, 0.63231300E-02, -.43645800E-01, -.12997000E+00, 0.42878400E-01, -.16371000E-01, -.35423200E+00, 0.30263300E+00, 0.65957800E+00, -.91492100E+00, 0.12332300E+00, -.42934900E+00, -.13690400E+00, 0.38900400E+00, 0.51003300E+00, -.69627600E+00, -.56976600E+00, 0.97628400E-01, 0.43186300E-01, -.20660600E+00, 0.65283600E-02, 0.21854900E+00, 0.20025500E+03, -.98386100E-01, 0.87394400E+02, -.17337600E+02, -.67564800E+02, -.25503400E+03, -.11472400E+03, 0.49900800E+02, -.10267300E+03, -.27805700E+03, 0.13611200E+03, 0.13656200E+03, 0.13905800E+03, 0.10142500E+02, -.44368000E+02, 0.53868400E+02, -.28586800E+02, 0.66984200E+02, 0.15927500E+01, 0.22710700E+03, -.39585300E+03, 0.20285400E+03, 0.11366900E+03, 0.19790600E+03, 0.14807500E+03, -.29348800E+03, 0.14374100E+03, 0.47651600E+02, 0.21962500E+03, -.27499200E+03, -.71278900E+02, -.19917600E+03, 0.93721400E+02, 0.16090200E+02, 0.99551100E+02, -.79614500E+02, -.15704000E+03, 0.69761900E+02, -.81462300E+02, 0.95475500E+02, -.13164600E+03, 0.14248600E+03, -.65035200E+03, 0.33255200E+03, -.71420300E+02, 0.32474900E+03, 0.12398800E+03, 0.23612900E+03, -.72018100E+02, -.26244200E+03, 0.14673800E+03, 0.22735500E+03, 0.17955700E+03, -.29205300E+03, 0.14766800E+03, -.25588700E+03, 0.14582900E+03, 0.31486100E+02, 0.24728300E+02, 0.96520000E+02, 0.14062900E+03, 0.11137100E+03, -.13740200E+02, 0.33919300E+03, -.26035900E+02, -.18686200E+01, -.76585100E+02, 0.13067400E+02, 0.33418000E+02, -.80191800E+02, 0.13192000E+03, 0.40718600E+02, 0.30536400E+02, -.66781000E+02, 0.11953300E+02, 0.52754700E+02, -.24884700E+02, -.22226900E+02, -.26378300E+02, -.14015600E+02, -.75249500E+01, 0.15489000E+02, 0.42874400E+02, 0.93478800E+01, -.21126900E+02, -.21221200E+02, 0.10675200E+04, -.53272000E+03, -.82281200E+03, -.53382700E+03, -.23900500E+03, -.39980400E+03, 0.27440200E+03, 0.52747900E+03, -.26100900E+02, -.40201400E+03, -.91533000E+02, 0.36364700E+03, -.18652500E+03, -.32359900E+03, -.18189200E+03, -.54036800E+02, 0.37042800E+03, -.12190900E+03, 0.17122600E+03, -.11991800E+03, 0.26695100E+03, -.12958400E+03, 0.16785500E+04, -.83857000E+03, -.66733300E+03, -.83942300E+03, -.46693200E+03, -.68123700E+03, 0.26165100E+03, 0.51020300E+03, -.20988600E+03, -.63168500E+03, -.41829600E+03, 0.17849000E+03, -.91354500E+02, 0.32243500E+02, -.89295800E+02, -.13092000E+03, -.13056200E+03, 0.17137300E+03, 0.39728000E+03, -.82092700E+02, -.15717700E+03, 0.17903800E+02, 0.18205300E+01, 0.57050500E-02, -.56911800E+01, -.91312000E+00, 0.18405000E+01, -.97648400E+00, -.36681500E+01, -.10270500E+01, 0.16643700E+01, -.13278900E+00, 0.36784300E+01, -.37136400E+03, 0.18598100E+03, 0.15376400E+03, 0.18559900E+03, 0.30716000E+02, 0.94040600E+02, 0.25449700E+02, -.85933000E+02, 0.10678300E+03, 0.51304900E+02, 0.17062700E+03, 0.44766200E+03, -.22361700E+03, 0.89348500E+02, -.22379700E+03, 0.48312800E+02, 0.23257300E+03, -.18827700E+03, -.28383300E+03, -.34071700E+03, 0.27226500E+03, -.18887500E+03, 0.95512700E+02, -.48576300E+02, -.27472900E+03, -.47792400E+02, -.65577400E+02, -.14406200E+02, 0.67512500E+02, 0.35453200E+03, 0.21215600E+03, -.90582700E+02, 0.15841200E+03, 0.56292600E+01, -.93966000E+02, -.11546600E+02, 0.69669800E+01, 0.35265400E+02, -.32658900E+02, -.55825200E+02, -.89051500E+02, -.31325400E+01, -.20121800E+01, -.12178900E+01, -.14934000E+02, -.19451900E+02, -.29600000E+02, -.42629700E+02, 0.15163400E+02, 0.17933200E+02, 0.34322800E+01, -.41631200E+02, -.82917200E+01, 0.20563400E+02, 0.24436400E+02, -.31531200E+01, -.88543900E+01, 0.47140200E+02, 0.65147800E+02 },
        { -.68861100E+00, 0.44776300E+00, -.50153200E+01, 0.18241100E+00, 0.47639400E+01, 0.77215800E+00, 0.65153600E+01, -.39240900E+00, -.37970300E+00, 0.66159100E+00, 0.32432000E+00, -.48102600E+01, 0.94399400E+00, -.10400400E+01, 0.25807600E+01, -.30376700E+00, -.63780800E+01, 0.83938100E+00, -.86369300E+00, 0.19120800E+01, -.19568300E+01, -.49041500E+01, 0.79305600E+00, -.21058000E+01, -.17470000E+01, 0.13076800E+00, -.29945400E+01, 0.71943300E+00, -.25666800E+00, 0.20066400E+01, 0.13959000E+01, 0.14803400E+01, -.10169200E+01, -.76963400E+00, 0.16436500E+00, -.11353400E+01, 0.11924800E-01, -.76666800E+00, 0.21529900E+01, -.47902200E+00, 0.57279100E-01, 0.29869400E+01, 0.73404400E+00, 0.22403300E+00, -.28710200E+00, 0.10774600E+01, 0.19057900E+01, -.65810300E+00, -.45635400E+00, 0.27995700E+00, 0.21748700E+00, -.58701700E+00, -.18433700E+01, 0.49454400E+01, 0.22585500E+01, 0.97598900E+00, -.65562100E+00, -.20780700E+01, 0.11487400E+01, -.18972700E+00, 0.26887400E+00, -.39888600E+00, 0.80200300E+00, -.79946700E+00, 0.74644200E-01, -.32983400E+00, -.19469900E+00, 0.14596800E+01, -.46272000E-01, -.25211200E+00, -.69934000E+00, 0.56121700E+00, 0.39127200E-01, -.75410300E-01, -.23668900E+00, 0.29603200E+00, 0.57218700E+00, -.12387700E+00, -.37218600E-01, -.53801800E+00, 0.14544700E-01, 0.15267100E+00, -.14217100E+00, 0.69023200E-01, 0.87672800E-01, -.37832600E+00, 0.53086800E-01, -.36019600E+00, -.17756100E+00, 0.10411200E+00, -.20449900E+01, -.59516900E+00, 0.76033600E+00, 0.26925900E+01, -.52073500E+00, -.27399800E+01, -.27535000E+00, -.39899000E-01, -.14359900E+00, 0.56303600E+00, -.19177600E+01, 0.11643000E+01, -.49380800E+01, -.22604000E+03, -.56868000E+02, 0.72513400E+02, 0.15547100E+03, 0.21571700E+03, -.93951000E+02, 0.33742100E+02, 0.33111300E+03, -.15386300E+03, -.32397300E+03, -.16616100E+03, -.58663600E+02, 0.73206600E+02, -.18150200E+02, 0.37959500E+02, -.86055500E+02, 0.56611300E+02, -.35948200E+03, 0.17933800E+04, -.90796600E+03, -.87983800E+03, -.89576400E+03, -.32071600E+02, -.20987800E+03, -.51195100E+03, -.40916000E+03, -.72605300E+03, 0.42357400E+02, -.77472200E+03, 0.28634000E+03, -.12656900E+03, 0.27405700E+02, -.14350200E+03, 0.18153000E+03, 0.73706700E+02, 0.77490800E+02, 0.19799800E+03, -.93913000E+02, 0.12086500E+03, -.30700700E+03, 0.15545100E+04, -.76716100E+03, -.24222400E+03, -.78787500E+03, -.43187300E+03, -.30380400E+03, 0.27159400E+02, 0.25891500E+03, -.42287700E+03, -.26995700E+03, -.41546400E+03, 0.66476600E+02, -.48731900E+02, 0.59386400E+03, -.31567200E+02, 0.10080900E+03, -.10668900E+02, -.14229400E+03, 0.13063800E+03, 0.11835200E+03, -.21798800E+03, -.21270300E+03, 0.36888900E+03, -.14112900E+03, -.32346200E+02, -.18540300E+03, -.14337700E+02, -.60101800E+02, -.27397300E+03, 0.10469100E+03, 0.16157600E+03, -.13071500E+03, -.51849900E+02, 0.30836900E+02, -.16600600E+02, -.11454900E+02, -.14309700E+02, -.51418500E+02, -.21545800E+02, 0.57930300E+02, -.27801400E+02, -.25755000E+02, -.37785900E-01, -.58754100E+02, -.23671800E+04, 0.11863200E+04, 0.14149100E+04, 0.11844600E+04, -.18650600E+03, 0.74706000E+02, 0.13794100E+04, -.89768000E+03, 0.64280400E+03, 0.42559600E+02, -.97987300E+03, 0.35295300E+03, -.16842600E+03, -.93620500E+02, -.17816700E+03, -.24187700E+02, -.32749100E+03, 0.19189800E+03, -.77571600E+02, 0.96930900E+02, -.31133400E+03, -.25140600E+03, -.20705900E+04, 0.10445400E+04, 0.90180700E+03, 0.10360700E+04, 0.58524900E+02, -.22815900E+03, 0.15005400E+04, -.87047500E+03, 0.66900000E+03, -.21133500E+03, -.11297600E+04, -.68966400E+03, 0.34395300E+03, -.17838700E+03, 0.34368300E+03, 0.15949900E+03, 0.52496200E+02, 0.33177400E+03, -.38192000E+02, 0.46659000E+03, 0.11142000E+02, 0.11064700E+03, -.53905100E+01, -.10672900E+01, 0.98224600E+01, 0.34378400E+01, 0.16914200E+01, -.27082800E+01, -.25154100E+01, 0.73715900E+01, -.51066500E+01, -.28790500E+01, -.30186600E+01, 0.58687600E+03, -.28519500E+03, -.11193000E+03, -.29098700E+03, 0.29583500E+02, 0.73228800E+02, -.17272500E+03, 0.16976200E+03, -.89990000E+02, 0.62024000E+02, -.21591400E+03, -.24049500E+04, 0.12117700E+04, 0.48552800E+03, 0.12022100E+04, -.47469400E+03, -.93808000E+02, 0.12521500E+04, 0.51661900E+03, 0.72906800E+03, -.24432100E+03, 0.11588500E+04, 0.30530500E+03, -.15856200E+03, -.42189900E+01, -.15212100E+03, 0.48424600E+03, 0.41089100E+03, -.10463700E+04, -.60432400E+03, -.44728200E+03, 0.54073000E+03, -.45652800E+03, -.88449600E+01, 0.37672000E+02, -.47936400E+02, -.11459700E+02, -.90401700E+02, 0.33519000E+02, 0.43613700E+02, 0.18584700E+02, 0.40079700E+01, 0.85051200E+01, 0.18005900E+00, -.45692900E+02, 0.23567900E+02, 0.27962200E+02, 0.94835600E+01, -.36555500E+02, 0.26350600E+02, 0.10172500E+01, -.33785900E+02, -.12160600E+02, 0.27069600E+02, -.25138800E+02, 0.41776100E+01, -.29389100E+02, -.24388200E+02, -.39490700E+02 },
        { -.15299200E+00, -.54967200E+00, 0.18983000E+00, -.12630700E+00, 0.13079300E+01, -.80146300E-01, 0.14419200E+01, -.10118100E+01, -.88607700E-01, 0.38978000E+00, 0.75115800E-01, 0.28729600E+00, -.41612200E+00, 0.99158200E-01, 0.65822100E+00, -.80416500E+00, -.63551600E+00, -.19665300E-01, 0.10004800E+00, 0.54226100E-01, 0.62684700E+00, -.10229300E+01, -.37787300E+00, 0.49039400E+00, 0.69048200E+00, 0.22074500E+00, -.37428500E+00, -.69003500E+00, 0.19738500E+00, 0.55490000E+00, 0.18546000E-01, 0.63412100E-01, -.24189900E+00, -.29175400E+00, 0.27019000E+00, 0.50434800E+00, -.46495300E-01, 0.34191000E+00, -.65841000E-02, -.16123000E+00, 0.95548500E-01, -.53012400E+00, -.13251500E+01, -.52823200E+00, -.92264800E-01, 0.39864300E-01, 0.50994200E-01, -.66149400E-01, -.14790900E+00, 0.22481400E-01, -.90358800E+00, 0.50013000E+00, -.17179600E+00, -.22016700E+00, -.48857600E+00, 0.55234100E+00, -.43273700E+00, 0.31066700E+00, -.60312200E-02, -.24834400E-01, 0.27334700E+00, -.18541600E+00, 0.23529800E-01, -.28259300E+00, -.39845600E-01, 0.91852100E-01, -.69718900E-01, 0.46370700E+00, 0.32557100E+00, 0.57404900E-02, -.82251500E+00, 0.68727900E+00, 0.15180700E-01, 0.46291600E-01, -.20275400E+00, -.30927200E-02, 0.11753900E-01, 0.59941900E+00, -.36778900E+00, 0.24353600E-01, -.58413900E-02, -.72547400E-01, 0.42447600E-01, 0.24414800E+00, 0.14786600E-01, 0.35989000E+00, -.74458700E+00, -.96558500E+00, -.12392400E+01, 0.26330800E+00, -.46226500E-01, 0.17517600E-01, -.21159300E-01, 0.25673300E+01, -.10144700E+00, -.12122900E+01, 0.19894700E+00, 0.32657300E+00, 0.75218600E+00, 0.34621200E+00, 0.47783600E+00, 0.71260900E+00, -.48533000E-01, 0.25306200E+03, -.23508200E+03, 0.27778600E+02, 0.13407800E+03, 0.14872200E+03, -.18474600E+03, -.45482500E+03, -.17930800E+03, 0.93166000E+02, 0.13640100E+03, 0.90187500E+02, 0.32436300E+02, -.13770700E+03, -.37633800E+02, -.15885100E+03, 0.21049200E+03, -.16386200E+03, -.28079000E+03, -.40464000E+04, 0.20045900E+04, -.15916000E+03, 0.20225000E+04, -.27854900E+03, 0.15572100E+03, 0.82352000E+03, 0.46934000E+03, 0.25458200E+04, 0.12827700E+03, 0.37846600E+04, -.26235200E+03, 0.13275200E+03, -.10249900E+03, 0.13122800E+03, -.46665400E+02, -.17309100E+03, -.26917800E+02, -.17637800E+03, 0.10256800E+03, -.13802800E+03, 0.87398700E+02, 0.79168500E+01, -.88824100E+01, 0.13292900E+03, -.20846400E+01, -.12258600E+03, -.28629400E+03, 0.17566800E+03, 0.27390100E+03, 0.30709100E+03, -.30636100E+03, 0.18835300E+03, 0.18119800E+04, -.90081500E+03, -.50754400E+03, -.90931300E+03, -.68414600E+03, -.42483900E+02, 0.33408600E+03, 0.82138100E+03, -.11477700E+04, 0.15836600E+03, -.59406800E+03, -.14517400E+03, 0.82546700E+02, -.64700000E+02, 0.73439500E+02, -.51463600E+01, 0.15743400E+03, 0.29536100E+03, 0.65756200E+03, -.34574300E+02, 0.20808500E+03, 0.15349200E+03, -.12838600E+03, 0.64244600E+02, 0.60539700E+02, 0.63839500E+02, 0.10391500E+03, 0.95079900E+02, -.81573000E+02, -.17749000E+03, -.19325100E+03, 0.87533300E+02, -.88242100E+02, 0.28317200E+04, -.14143700E+04, -.15595600E+04, -.14170200E+04, 0.45602900E+03, -.11865700E+03, -.44812600E+02, 0.83547200E+03, -.43049900E+03, -.16364500E+03, -.51981900E+04, -.28030800E+03, 0.14334000E+03, 0.15494000E+03, 0.14037500E+03, -.22032400E+03, -.60725200E+03, 0.57442500E+03, 0.46011300E+03, 0.38959000E+03, -.50369600E+03, 0.25162400E+03, 0.30418300E+04, -.15161500E+04, -.12445900E+04, -.15231700E+04, 0.23084900E+03, -.60293600E+03, -.94958100E+02, 0.63116500E+03, -.59317900E+03, -.64885900E+03, -.57570200E+04, 0.26956700E+03, -.13246700E+03, 0.34579000E+02, -.13264700E+03, -.11351200E+03, 0.66618600E+02, -.58414400E+02, -.27970800E+03, -.10381300E+03, 0.90331800E+01, -.16945500E+03, 0.15929900E+00, -.17885000E+01, -.14278400E+01, -.33904600E+00, -.59819300E+01, 0.98241100E+01, -.14210700E+01, -.15998400E+01, -.50313900E+01, 0.10224000E+02, 0.16210300E+02, -.48573300E+03, 0.23640300E+03, 0.31487800E+03, 0.24186500E+03, -.51645900E+02, -.12755100E+03, 0.25167400E+03, 0.30241600E+03, 0.18907400E+03, -.56784400E+02, 0.23465400E+03, -.17174900E+04, 0.87017200E+03, 0.13997200E+04, 0.85935100E+03, 0.10431800E+04, -.38319900E+03, -.69455300E+03, -.23686700E+04, -.64999500E+03, -.53373500E+03, -.14369500E+04, 0.36233100E+04, -.18159300E+04, -.21944300E+04, -.18124000E+04, -.52536200E+03, 0.15666300E+03, 0.31763200E+03, 0.23635400E+04, -.37749900E+03, 0.37348300E+03, -.90668900E+03, -.39481700E+01, 0.13294500E+03, 0.48210200E+02, -.24008500E+02, 0.55556700E+02, 0.65556200E+01, 0.49205000E+02, 0.14241900E+03, 0.13531000E+01, -.91212400E+00, -.48569400E+02, 0.18184000E+03, 0.14286600E+03, -.27369700E+02, -.75200500E+02, 0.12912600E+03, -.84541800E+02, 0.55014000E+02, 0.26386700E+03, -.46317600E+02, -.20503900E+03, -.29491900E+02, 0.50788900E+00, 0.12915900E+02, 0.60878800E+03, 0.12240700E+03 },
        { -.32096200E+00, 0.51773200E+00, -.20591800E+01, -.44200900E+00, 0.63223500E+00, 0.24256400E+00, 0.15039300E+01, 0.22149400E+01, 0.86004600E+00, 0.71046900E-01, -.69386000E-02, -.14995900E+01, 0.43428500E-01, -.82820100E+00, 0.93072600E+00, 0.30599400E+00, -.88979000E+00, 0.32435700E+00, 0.17074900E+01, -.19958200E+00, 0.87634300E+00, -.37453200E+01, 0.43497300E-01, 0.74347500E+00, -.65974800E-01, -.89243400E-02, -.85597900E+00, -.37520700E+00, -.18582000E+00, 0.35826800E+00, 0.38544900E-01, 0.14140800E+00, 0.11056500E-01, 0.21117900E+00, -.11974300E+00, -.22236700E+00, -.18281900E-01, -.35576400E+00, 0.39083900E-01, -.29778900E+00, 0.10034300E+00, -.15001300E+01, -.23229200E+00, -.22691100E+00, 0.22299800E+00, -.87495500E-01, -.81587800E+00, -.55769900E-01, -.19375200E+00, -.62701400E-01, -.39932100E+00, 0.12889800E+01, -.40970400E-01, -.17119200E+01, 0.12629200E+01, -.11282400E+01, -.38800000E+00, -.10954600E+01, 0.47032200E+00, -.87472300E+00, 0.14215400E+01, 0.77270100E+00, -.76923100E-01, -.45143100E-01, -.46380800E+00, -.27436500E+00, 0.31704800E+00, -.45265800E+00, -.52518000E+00, 0.60264300E-02, 0.10397200E+00, 0.32676600E+01, -.36707100E-02, 0.21578800E+00, 0.52101400E+00, -.76254100E-01, -.44572100E-01, 0.36385100E+00, 0.24795700E+00, 0.20915800E+00, 0.48931100E-02, 0.27896200E-01, -.52435400E+00, -.23722900E+00, -.25738500E-01, 0.18624400E-01, 0.56694300E+00, 0.44563000E+00, -.28568300E+00, -.10779200E+00, -.67300700E+00, 0.36455700E-01, -.35481000E+00, 0.31182900E+00, -.28251100E+00, 0.37916300E+00, -.11335000E+01, 0.54031500E+00, -.27945100E+00, -.44786900E+00, 0.35654300E+00, -.16043000E+00, 0.15097800E-02, 0.10742000E+01, 0.42785600E+03, -.46380900E+03, -.63200800E+03, -.38465700E+03, 0.24979900E+03, 0.28267200E+03, -.14334800E+03, 0.67613900E+02, 0.35770300E+03, 0.71370500E+02, 0.64312000E+02, 0.83746600E+02, 0.47980100E+02, 0.78464600E+01, -.18157700E+03, 0.12943300E+03, 0.28929500E+03, -.31988100E+02, 0.45895200E+02, 0.19886800E+04, 0.16410500E+02, 0.66275400E+03, -.12595500E+03, 0.56154200E+03, 0.63140900E+02, -.98880800E+03, 0.35325900E+02, -.21149900E+04, -.40189700E+03, 0.19674400E+03, 0.24323000E+03, 0.20088500E+03, 0.16533900E+03, 0.14038700E+03, -.11690600E+03, -.36642100E+03, -.93462300E+02, 0.11007000E+03, 0.19779700E+03, 0.43887700E+03, -.23504600E+03, -.16088200E+02, -.22129100E+03, -.23425400E+02, 0.96674800E+02, -.70081900E+02, -.58894200E+02, -.31029400E+03, 0.74268800E+02, -.46928700E+03, -.11805900E+04, 0.58263900E+03, -.46516400E+03, 0.59221400E+03, 0.42168900E+03, 0.91735100E+01, -.26127600E+03, -.27017200E+03, 0.11504500E+04, -.15986800E+03, 0.93045000E+03, 0.64783700E+03, -.34866700E+03, 0.10744100E+03, -.32441400E+03, 0.15549100E+03, 0.73004300E+02, -.32289400E+03, -.21843000E+03, -.16534000E+03, 0.17763100E+02, -.46482200E+03, 0.66614900E+02, -.34177100E+02, -.96826900E+02, -.33100900E+02, -.55778300E+02, -.58637700E+02, -.10145000E+02, 0.11572000E+03, 0.84395600E+02, -.49313700E+02, 0.17356200E+03, 0.58891900E+03, -.30046700E+03, -.75214100E+03, -.29379100E+03, 0.63144200E+01, 0.46446600E+03, -.16234900E+04, 0.70225600E+03, -.61283300E+03, 0.53487900E+03, 0.48289900E+04, 0.15690500E+03, -.86349700E+02, -.16489500E+03, -.78625100E+02, 0.45352600E+02, 0.57396000E+03, -.39440100E+03, 0.92290700E+02, -.25864600E+03, 0.47883200E+03, -.15724800E+03, 0.10899700E+04, -.55809200E+03, -.16675600E+03, -.54369700E+03, 0.40090600E+03, 0.12963700E+04, -.21391700E+04, 0.65723600E+03, -.96886100E+03, 0.12368900E+04, 0.50376000E+04, -.33167300E+03, 0.16783200E+03, 0.72795500E+02, 0.16504000E+03, 0.77343200E+02, -.16657000E+02, 0.10425800E+03, 0.41336500E+03, 0.73340500E+02, 0.10124400E+03, 0.31845600E+03, 0.26541000E+01, 0.19563300E+01, -.32689400E+01, -.11762100E+01, 0.67261900E+01, -.50048400E+01, 0.70381800E+01, -.12479300E+01, 0.94161900E+01, -.81785100E+01, -.56304400E+01, 0.40958500E+03, -.19748000E+03, 0.10841100E+03, -.20428000E+03, 0.78768600E+02, 0.12974600E+03, -.58962600E+02, -.86842900E+02, -.19204800E+03, 0.30574800E+02, -.42855100E+03, 0.39973800E+04, -.20192600E+04, -.13365100E+04, -.19990500E+04, -.81198300E+03, 0.67462700E+03, -.10427700E+04, 0.11280900E+04, -.49276300E+03, 0.58053700E+03, 0.61875300E+03, -.31759000E+04, 0.15941500E+04, 0.12001600E+04, 0.15883900E+04, 0.19870900E+03, -.58620600E+03, 0.82605400E+03, -.11692800E+04, 0.94678500E+03, -.62005900E+03, 0.53413000E+03, 0.65970400E+01, -.40012100E+02, -.25819600E+01, 0.68880100E+01, -.67317400E+02, -.14215900E+02, -.61152000E+02, -.28116500E+02, -.45839200E+01, 0.53748100E+01, 0.11332300E+03, -.77096200E+02, 0.71925100E+01, 0.54302900E+02, 0.50775300E+02, -.62584000E+02, 0.36720100E+02, -.37495800E+02, -.60647700E+02, 0.15506600E+02, 0.29098500E+02, 0.28301500E+01, -.36756200E+01, 0.87675600E+01, -.26281800E+03, -.94680200E+01 },
        { 0.14789300E+00, 0.65646900E+00, 0.26318500E+00, -.15520600E+00, -.66014200E+00, -.26713300E+00, -.29608800E+00, 0.14231700E+01, 0.14436100E-01, -.44231000E+00, 0.14631900E+00, 0.47432800E+00, -.24135900E-01, 0.42179600E-02, 0.93896100E+00, 0.42380600E+00, 0.59678500E+00, -.18902000E+00, -.16483500E+00, 0.22411600E+00, -.27282800E+00, 0.83742000E-01, 0.27990400E-01, 0.37395600E-01, 0.14217500E+00, 0.11542200E+00, 0.19837000E+00, 0.30445900E-02, -.87286900E-01, -.16706300E+00, 0.94381500E-01, 0.77858600E-01, 0.40348000E+00, -.39791600E+00, -.65614200E-01, -.30659800E-02, 0.14652700E-01, -.13092300E-01, 0.14490200E-02, -.74733300E-01, -.13603500E+00, 0.30671100E+00, 0.26350600E+00, 0.10941200E-02, -.22374800E+00, 0.39355900E-01, 0.21327300E+00, 0.13654300E-01, 0.17844900E+00, -.53160300E-01, 0.10514200E+00, -.52629500E+00, -.11308100E+00, 0.57645400E+00, 0.32930300E-02, -.30270000E+00, -.90344800E-01, 0.62395000E+00, 0.97370700E-02, 0.10173600E+00, -.42013600E+00, 0.14444400E+00, -.16222300E+00, 0.27919900E+00, 0.13793800E+00, -.61704900E-01, -.19830800E+00, -.31738800E+00, 0.41562500E+00, 0.24038100E-02, 0.25340900E+00, 0.55985800E+00, -.18577600E+00, -.19244700E-01, 0.12193900E+00, -.59072200E-01, -.10624400E+00, 0.22591000E+00, -.19214000E+00, 0.11108300E+00, 0.69546500E-02, -.12685200E-01, -.53634100E+00, 0.12544200E+00, 0.11137000E+00, -.16710600E+00, 0.51040800E+00, -.35717500E+00, -.73043300E+00, -.53819400E-01, -.12469300E+00, 0.12392200E-01, 0.23380600E+00, -.49505000E+00, -.20098500E+00, -.10393500E+00, -.15202100E+00, 0.60996400E+00, 0.58463100E-01, 0.96642700E-01, 0.13662400E+01, -.10747500E+00, -.25815600E-01, 0.63235900E+00, 0.15159000E+00, -.17354700E+03, -.40552200E+03, 0.27760300E+02, 0.67019500E+02, -.51520800E+02, -.32186600E+03, 0.16204800E+03, 0.71038600E+02, 0.16102500E+03, 0.12909800E+03, 0.41274700E+01, 0.34743800E+02, -.69349700E+02, 0.18913700E+02, 0.24697800E+02, 0.22098200E+03, -.87443600E+03, 0.44481700E+03, 0.68580800E+03, 0.43709900E+03, 0.38942900E+03, -.36031600E+03, 0.42733400E+03, 0.25919200E+03, 0.21797400E+03, -.35144900E+03, 0.12468000E+03, 0.24726500E+03, -.12373600E+03, -.62874500E+02, -.12363400E+03, -.53598700E+02, -.69352500E+02, 0.10255400E+03, 0.58978300E+02, -.81174100E+02, -.77226200E+02, -.10554700E+03, 0.23155200E+03, -.60927200E+02, -.36967000E+03, -.11553800E+03, -.42643100E+00, 0.36120700E+03, -.30725700E+03, -.26815300E+03, -.32496700E+03, 0.32857500E+03, -.35686700E+02, -.13358400E+03, 0.56586200E+02, 0.10045400E+03, 0.66223100E+02, -.65140800E+02, -.13531800E+03, 0.56453800E+02, 0.16052300E+03, 0.23440600E+03, -.91825300E+02, -.20780000E+03, -.89823100E+02, 0.53649700E+02, -.79441800E+02, 0.45072300E+02, -.30892000E+02, -.48095700E+02, -.42531000E+02, -.23386500E+03, 0.10254200E+02, -.61124900E+01, 0.20842500E+02, 0.16764700E+03, -.81767700E+02, -.50637400E+02, -.83884400E+02, -.34252100E+02, -.23366900E+02, 0.22023200E+02, 0.57987200E+02, -.14682400E+02, -.35565300E+02, -.31896500E+02, 0.95237900E+02, -.48109900E+02, 0.29295900E+02, -.47818100E+02, -.13195500E+03, -.29235100E+03, 0.22178000E+03, -.81308100E+01, -.35128400E+03, -.21058500E+03, 0.13305700E+04, 0.77680500E+03, -.39199900E+03, -.43424700E+03, -.38838500E+03, -.19323800E+00, 0.35597500E+03, -.45358500E+03, -.10654500E+03, -.36262500E+03, 0.28649300E+03, -.29132300E+03, 0.16146800E+03, -.78307300E+02, -.13314500E+03, -.81120400E+02, -.31057200E+03, -.33092500E+03, 0.30531900E+03, 0.27402500E+00, -.39045800E+03, -.20429000E+03, 0.14488100E+04, 0.34160200E+02, -.34135500E+02, -.33458700E+02, -.17230600E+02, 0.31724100E+02, -.36402000E+03, 0.11223400E+03, 0.32180200E+03, 0.33765500E+03, -.36524400E+03, -.10154000E+03, -.74992400E+01, 0.26805000E+01, 0.32572600E+01, 0.37047700E+01, 0.14598700E+01, -.10989800E+02, 0.89333000E+01, 0.14505900E+02, 0.10227300E+02, -.85194100E+01, -.51990400E+01, 0.19374600E+03, -.82794500E+02, -.17897100E+03, -.97059900E+02, -.68018500E+01, 0.20749700E+03, -.19672600E+03, -.24436200E+03, -.22976700E+03, 0.17096000E+03, 0.14674600E+02, 0.11583300E+03, -.51256200E+02, -.37256900E+03, -.57812400E+02, -.37012700E+03, 0.56425900E+03, -.19348700E+03, -.37578800E+03, -.23971600E+03, 0.53597100E+03, 0.23402400E+03, 0.73026200E+03, -.37405600E+03, -.11758800E+03, -.36525900E+03, 0.15703000E+03, -.32648800E+03, -.70641600E+02, 0.26552600E+03, -.75806500E+01, -.32856900E+03, -.12781900E+03, 0.42986900E+01, -.11441400E+03, 0.81240800E+01, -.57990600E+00, -.95842100E+00, -.20031200E+02, -.42824800E+02, -.10305500E+03, -.26009500E-02, -.80747300E+01, 0.15476400E+02, -.19203300E+02, -.68371300E-01, -.12059100E+02, -.44455300E+02, 0.99565300E+01, -.88956300E+01, 0.22261800E+01, 0.46647500E+02, 0.87016800E+01, -.45723300E+02, 0.43313600E+02, 0.16675400E+01, -.78138500E+01, 0.85449400E+00, 0.47926800E+02 },
        { 0.32110400E+00, -.14060600E+01, -.27081800E+01, -.18855600E+00, 0.12097500E+01, 0.67093400E+00, 0.10410700E+01, -.26673900E+01, -.24197500E+00, 0.10337100E+01, 0.72084700E+00, 0.21072300E+01, -.12181900E+01, 0.27272000E+00, 0.11287300E+01, 0.37396500E+00, 0.52801100E+00, 0.11513500E+00, -.98418900E-01, 0.67108900E-01, -.58139800E+00, -.25082500E+01, -.66059700E+00, 0.61121300E-01, 0.41288300E+00, 0.35290800E+00, 0.12728700E+00, 0.25585900E+00, -.23946300E+00, -.57340900E-01, -.29444900E+00, -.33849500E+00, 0.15130000E+01, 0.37468100E+00, 0.26333600E+00, -.21463100E+00, 0.61136400E-01, 0.39225500E+00, 0.52522800E+00, -.92700300E+00, -.57345600E+00, -.24785400E+01, -.10454300E+00, 0.10007700E+01, 0.47702800E+00, 0.16248300E+00, 0.54945200E-01, 0.35308700E-01, 0.10792400E+00, 0.49695200E+00, -.18702500E+00, 0.86633000E+00, 0.97063000E+00, 0.28741000E+01, -.11244300E+01, 0.63020400E+00, -.15582400E+00, 0.58031300E+00, -.30359700E+00, -.25271800E+00, 0.22568700E+00, -.46088800E+00, 0.14740500E+00, -.55586300E+00, 0.88122600E-01, -.51915500E+00, 0.13171900E-01, 0.45546500E+00, 0.69056300E+00, 0.33936300E-02, -.25892700E+00, -.88364000E+00, -.13692300E+00, -.13629700E+00, -.54520600E+00, -.27433100E+00, -.26223500E+00, 0.22399800E+00, 0.48512000E-01, -.66090000E+00, 0.47983500E-02, 0.28335600E-01, -.95557100E+00, 0.22875300E+00, -.52264900E-01, 0.79049500E-01, -.63042500E-01, 0.44470600E+00, 0.93703700E+00, 0.95441200E-01, -.21015000E+01, -.19217900E+00, 0.15327400E+00, 0.50947500E+00, -.76019200E-01, -.19301900E+01, -.43590300E-01, -.34180400E+00, 0.82042000E+00, 0.60723100E+00, -.16152300E+01, 0.10398600E+01, -.55509100E-02, -.54332300E+00, -.49990800E+00, 0.15870500E+01, 0.51755500E+03, 0.22565500E+02, -.15854500E+03, -.28174900E+03, -.41091500E+02, 0.31242600E+02, 0.19672300E+03, 0.20397100E+02, -.18675100E+03, -.23598500E+03, 0.17124700E+03, 0.10388700E+03, 0.20510900E+03, -.21882700E+03, -.75040700E+03, 0.13757900E+04, -.71101100E+03, -.11689500E+04, -.68770600E+03, -.67022100E+03, 0.80166700E+03, -.54477500E+03, -.36599400E+03, -.20868100E+03, 0.10308700E+04, 0.49314400E+03, -.38279600E+03, 0.20381500E+03, 0.15289100E+03, 0.19141300E+03, 0.23933200E+03, 0.13296500E+03, -.11979400E+03, -.19793300E+03, -.28999900E+02, 0.19915200E+03, -.37520500E+01, 0.67051100E+03, -.44912900E+03, 0.43902700E+03, -.33510300E+03, -.29592200E+03, -.79475800E+03, 0.50098600E+03, 0.60084600E+03, 0.31851600E+03, -.74364000E+03, -.13428000E+03, 0.67397200E+03, -.33173400E+03, 0.27704500E+03, -.33607500E+03, 0.16563600E+03, 0.23994300E+03, -.34846600E+03, -.45696100E+03, -.60992300E+03, 0.41477500E+02, 0.13069500E+03, 0.49813200E+03, -.24223800E+03, 0.37824500E+03, -.24933900E+03, 0.66034600E+02, 0.14605500E+03, -.24784600E+03, 0.50121900E+03, 0.24585600E+02, 0.51734500E+02, -.96793800E+02, -.31829700E+03, 0.15455900E+03, 0.20733000E+02, 0.15924600E+03, 0.60774600E+02, 0.58049300E+02, -.59779900E+02, -.22504200E+03, -.13147400E+03, 0.10127900E+03, 0.43469700E+02, -.53961000E+03, 0.27219600E+03, -.57461800E+03, 0.27012400E+03, 0.71682700E+03, 0.61673500E+03, -.34710100E+02, -.10848400E+03, 0.56887000E+03, 0.44922200E+03, -.49346400E+04, -.13168900E+04, 0.66833000E+03, 0.83268400E+03, 0.65843600E+03, -.38336000E+02, -.10711400E+04, 0.99638100E+03, 0.34854700E+03, 0.89466900E+03, -.94429400E+03, 0.55244300E+03, 0.12457600E+04, -.62075800E+03, 0.46832600E+03, -.62226300E+03, 0.92989700E+03, 0.18252700E+03, -.46223500E+03, 0.59576100E+02, -.12128400E+03, 0.26547200E+02, -.62546700E+04, -.40609400E+03, 0.23806400E+03, 0.41057700E+02, 0.20396800E+03, 0.36300900E+01, 0.55003400E+03, -.73723600E+02, -.51088500E+03, -.15844600E+03, 0.48220800E+03, 0.16105800E+03, 0.12259300E+02, -.68649100E+01, 0.19206100E+01, -.60574000E+01, 0.15975700E+01, 0.25026800E+02, -.10642100E+02, -.23806900E+02, -.21179000E+02, 0.19795500E+02, 0.14955900E+02, 0.15404000E+03, -.10141500E+03, 0.53864200E+03, -.76705400E+02, 0.66178600E+02, -.23595200E+03, 0.14543500E+03, 0.44836600E+03, 0.17625100E+03, -.17531600E+03, -.32443900E+03, -.15789600E+04, 0.78489900E+03, 0.15207100E+04, 0.78931500E+03, 0.73950900E+03, -.79982200E+03, 0.35013900E+03, 0.36593900E+03, 0.37689200E+03, -.11590900E+04, -.50446400E+03, 0.40925100E+03, -.19427000E+03, -.13824000E+04, -.20442000E+03, -.16030200E+03, 0.53702000E+03, -.34424400E+02, -.59148500E+02, -.19678400E+03, 0.92456700E+03, -.36264100E+03, -.11244100E+02, 0.30671200E+03, -.30690600E+01, -.26834300E+02, -.42482100E+02, 0.55991100E+02, 0.13432800E+03, 0.29181100E+03, 0.31992800E+01, 0.16852800E+02, 0.84047000E+01, 0.14610300E+03, 0.17440400E+03, 0.16077700E+02, 0.64659400E+02, -.43246300E+02, 0.86180600E+01, 0.21043000E+02, 0.17122100E+03, -.50399600E+02, -.97923000E+02, -.97086300E+02, -.88062400E-01, 0.22843800E+02, 0.25354700E+03, -.40213700E+02 },
        { -.19322600E+00, 0.17326900E+00, -.29850400E+01, -.16199100E+00, 0.96573400E+00, -.22288300E+00, -.61021600E+00, 0.76376700E+00, -.17949400E-01, 0.53525900E-01, 0.79383600E-01, -.15201900E+01, 0.27217900E+00, -.15388700E+00, 0.43426400E+00, 0.21872200E+00, 0.77753600E+00, -.70935700E-01, 0.14333200E+00, 0.22726200E+00, -.43908200E-01, 0.52534900E+00, 0.17725400E+00, -.49984400E+00, -.12070600E+00, -.10968400E+00, -.18874100E+00, -.18190500E+00, 0.22975500E+00, 0.43054900E+00, -.12895700E+00, 0.22196600E+00, 0.11244700E-01, -.37258400E+00, 0.27779600E+00, 0.33229100E+00, -.48050700E-01, 0.57285100E+00, 0.13960500E+00, 0.40262400E+00, -.18172500E+00, 0.69349200E-02, -.20689300E+00, -.41028700E+00, 0.81160400E+00, 0.18976800E+00, 0.65455200E+00, -.24497400E-01, 0.29274200E+00, -.57040100E-01, 0.35920800E+00, -.66385400E+00, -.39304900E+00, -.40898900E+00, -.59589300E+00, 0.11364200E+01, 0.34247500E+00, -.16334500E+00, -.21239700E-02, -.73692600E-01, -.59889300E-01, -.33828800E+00, 0.19600300E+00, -.39035800E+00, -.57608600E-01, -.71762100E-01, 0.69398900E-01, 0.20704400E+00, 0.18207100E+00, -.10851100E-02, 0.56078800E+00, -.42822500E+00, -.36401500E-01, 0.43693100E-01, 0.50616500E-01, -.33524600E+00, 0.19500500E+00, 0.53445700E+00, -.25175500E+00, -.14772100E-01, -.17615800E-01, 0.39740700E-01, -.25576400E+00, 0.33303700E-02, -.41872200E-01, 0.30540500E+00, -.12549300E+00, -.20041800E+00, 0.94356300E+00, 0.20209200E+00, -.25957500E+00, -.76381700E-01, 0.38060400E+00, -.61020500E+00, 0.48374400E+00, 0.42230800E+00, 0.28739000E+00, -.52856300E+00, -.96469700E-01, 0.26639600E+00, -.59022900E+00, -.18736800E+00, 0.15775400E-01, -.17222200E+00, -.76730100E-01, 0.65375100E+00, 0.18042600E+00, -.16893500E+03, 0.42634900E+02, -.23638900E+03, -.33864700E+03, 0.17356900E+03, 0.20315700E+03, 0.16904600E+03, 0.92561900E+01, -.12637600E+03, 0.10376000E+03, -.15675600E+02, 0.12286800E+03, -.54362600E+02, -.18894900E+02, 0.25726800E+03, -.14707200E+03, 0.93177400E+02, -.12827900E+03, -.25510600E+02, 0.55543200E+02, -.15562400E+03, -.13494400E+03, 0.51626000E+02, 0.74322700E+02, 0.17212700E+03, 0.21839000E+03, -.97944100E+02, -.11941200E+03, -.10920600E+03, -.96742200E+02, -.12798300E+03, -.10965300E+02, -.62032000E+02, -.42964500E+02, -.89232700E+02, -.40553100E+02, -.16748200E+03, 0.85434900E+02, 0.94855400E+02, 0.82685300E+02, 0.95021600E+02, 0.86689400E+02, -.16884800E+03, -.26361800E+03, 0.88887200E+01, 0.11893800E+03, -.24331900E+02, -.28405900E+02, 0.16559700E+02, -.55576400E+02, 0.15916000E+02, 0.64117000E+02, 0.19588600E+02, -.14181500E+02, -.84331100E+01, -.99862600E+02, -.48509900E+02, -.22650900E+02, -.52339500E+02, 0.63388000E+02, -.10725200E+03, 0.25729400E+02, -.14096700E+02, 0.22347800E+02, 0.22414700E+02, 0.37417200E+01, 0.19948200E+02, -.10286800E+02, 0.78629100E+02, 0.24301700E+02, -.15102400E+02, -.23333400E+02, -.11969500E+02, -.81012800E+01, -.76709900E+01, 0.34586900E+00, -.19396900E+02, -.26825300E+02, -.47090600E+01, -.47086400E+02, 0.89618900E+03, -.44861300E+03, -.59520400E+03, -.44749400E+03, -.79727400E+02, -.34667400E+03, 0.26041100E+03, 0.34073000E+03, -.59530100E+02, -.36701100E+03, -.18878700E+04, 0.32755500E+03, -.15047800E+03, -.18405300E+03, -.16387100E+03, -.35363100E+02, 0.60433100E+02, -.23492500E+02, 0.20974000E+03, -.10684000E+02, 0.96972600E+00, -.21559900E+03, 0.11207100E+04, -.55893400E+03, -.42579800E+03, -.55919200E+03, -.19918900E+03, -.37967300E+03, 0.23294400E+03, 0.39238800E+03, -.14508800E+03, -.39667700E+03, -.21908400E+04, 0.25256200E+03, -.12510900E+03, 0.27630700E+02, -.12762000E+03, -.11799100E+03, -.75101000E+01, -.43536100E+02, 0.22892400E+03, -.12010200E+03, -.64875800E+02, -.51765100E+02, 0.34647700E+00, -.26394800E+01, -.12917800E+01, -.39771300E-01, 0.66199100E+00, 0.23568800E+01, 0.11065300E+01, 0.19775700E+01, 0.17794400E+00, 0.12448600E+01, 0.22441800E+01, 0.27098300E+02, -.13757700E+02, -.31452400E+02, -.13002400E+02, 0.17019200E+02, 0.39475200E+02, -.93892700E+02, -.10689700E+03, -.45486700E+02, 0.34677800E+02, 0.28131700E+01, 0.38912600E+02, -.14022900E+02, 0.77515400E+02, -.19767900E+02, 0.18404600E+03, 0.40732300E+02, 0.29304400E+02, 0.23567000E+02, -.25184700E+03, -.17578200E+02, -.57632600E+03, 0.54680100E+03, -.27224500E+03, -.30206000E+03, -.27301800E+03, -.15679700E+03, -.82986000E+02, 0.72865600E+01, 0.21728200E+03, 0.18816600E+02, -.15444500E+02, 0.15750300E+03, -.12940000E+01, -.26169800E+02, -.63756100E+01, 0.21684100E+01, 0.26752200E+02, -.15461000E+02, 0.16365000E+02, -.23561700E+02, -.16060600E+01, -.28155600E+01, -.15382700E+02, 0.42613600E+02, -.14802500E+02, -.28735100E+02, 0.47359400E+02, -.96300900E+01, -.59804800E+01, 0.62365200E+01, 0.44316200E+02, -.30090300E+02, -.45845000E+02, 0.10936000E+02, -.17924100E+01, -.31133000E+01, 0.69319900E+02, 0.57411000E+02 },
        { 0.93876200E-01, 0.34949400E+00, -.47676900E-01, 0.23175300E+00, -.45644900E+00, -.14533800E-01, -.38781700E+00, 0.59840800E+00, 0.17578700E+00, -.11240600E+00, -.41157000E-01, 0.23617300E+00, 0.18996400E-01, 0.21548400E+00, -.41340200E+00, 0.23601300E+00, 0.49109700E+00, -.44628700E-01, -.12513700E+00, -.13127800E+00, 0.60693800E-01, 0.38521900E+00, 0.94560400E-01, -.88074400E-01, -.14368400E+00, -.13983400E+00, 0.26628000E+00, 0.13352400E+00, 0.27224100E-01, -.19287600E+00, -.94138300E-01, -.98478800E-01, 0.79338600E-01, 0.19133600E+00, -.58456400E-01, -.48273400E-01, 0.14298400E-01, -.13579700E+00, -.10128300E+00, -.70534900E-01, -.74640500E-01, -.16548300E+00, 0.13540500E-01, 0.49139500E-01, -.37661900E+00, 0.82835400E-03, 0.20840600E+00, 0.17353900E-01, 0.89651900E-01, 0.21591100E+00, 0.37100300E-01, 0.50422600E-01, 0.15244800E+00, -.34472100E+00, -.26690800E+00, -.11797600E+00, 0.47376000E-01, 0.38601800E+00, -.36249700E-01, 0.27890200E-01, -.24292400E+00, 0.89443500E-01, -.97930600E-01, 0.17410500E+00, 0.43651500E-01, 0.94333000E-01, 0.35050300E-01, -.83064400E-01, -.21673500E+00, -.31357900E-02, -.16834200E-01, -.25209700E+00, 0.98052500E-02, -.10560800E-01, 0.28427500E-01, 0.27456600E-01, -.12489000E+00, -.12814400E+00, 0.27429800E-01, -.29847100E-01, 0.94004600E-02, 0.42282400E-02, -.48552000E-01, -.12902800E+00, -.10830100E+00, -.37865000E-01, 0.20946900E+00, 0.55676400E+00, 0.10888600E+01, -.12404400E+00, 0.13694700E+00, 0.27497300E-01, -.21651700E+00, -.39764000E+00, 0.14041200E+00, 0.13165900E+00, 0.27611900E+00, -.22944400E+00, 0.11386900E+00, -.17513500E-01, -.43243300E+00, -.30102900E+00, 0.20677600E-01, 0.64597000E-01, 0.20044100E+00, -.57798000E+00, -.19981700E+00, -.39553400E+00, 0.56315400E+02, -.59088600E+02, -.15724600E+03, 0.83008800E+02, -.42904500E+00, 0.78411300E+02, -.10294500E+02, -.64814900E+02, 0.10839100E+03, 0.81274800E+02, 0.74847800E+02, -.29138700E+02, 0.42044200E+02, 0.12935300E+04, -.65877800E+03, -.31304500E+03, -.64649100E+03, 0.64561300E+02, -.83155300E+01, -.35870100E+03, -.19187100E+03, -.54615400E+03, 0.93858500E+01, -.57849300E+03, 0.24245000E+03, -.11217300E+03, -.39396500E+02, -.12124300E+03, -.67767000E+02, -.50110100E+02, 0.93724400E+02, 0.75209200E+02, -.60261400E+02, -.28918900E+02, -.72790400E+02, -.11455200E+03, 0.83926200E+02, -.14000900E+03, 0.56533800E+02, 0.81465800E+02, 0.24236200E+03, -.21116200E+03, -.30075700E+03, -.87295600E+02, 0.25489200E+03, 0.65401200E+02, -.35964500E+03, 0.17701300E+03, 0.37899300E+03, 0.18113700E+03, 0.16096300E+03, 0.17679200E+02, -.11553400E+03, -.24745700E+03, 0.87713500E+02, -.53097600E+02, -.12872100E+03, 0.11369500E+03, -.22723300E+02, 0.52448000E+01, -.57183100E+02, 0.26805100E+02, -.48407000E+02, -.10812400E+03, -.95423000E+02, 0.36894000E+02, -.64975100E+02, -.37776600E+02, 0.52830500E+02, -.27620600E+02, -.27119800E+02, -.26275600E+02, -.42188900E+02, -.27242900E+02, 0.42347800E+02, 0.13379800E+02, 0.91650800E+01, -.25709700E+02, -.35334700E+02, -.37595000E+03, 0.18848600E+03, 0.15519000E+03, 0.18843500E+03, -.26698500E+03, -.38289100E+03, 0.76930200E+03, -.19787900E+03, 0.22811400E+03, -.39525100E+03, -.61178100E+03, 0.27103300E+03, -.12650800E+03, -.16455400E+03, -.13560100E+03, 0.74781400E+02, 0.15902900E+03, -.17986500E+03, -.97901700E+02, -.10177900E+03, 0.89967100E+02, -.15584000E+03, -.49828100E+02, 0.28803200E+02, 0.38279100E+02, 0.25806000E+02, -.44311100E+03, -.75936800E+03, 0.93166700E+03, -.57868400E+02, 0.17340000E+03, -.66568400E+03, -.80879000E+03, 0.30837000E+02, -.21711500E+02, -.84931900E+01, -.16526800E+02, -.71756200E+00, -.47286100E+02, -.23427700E+02, 0.14896800E+03, 0.51100100E+01, -.10832200E+03, -.45060100E+02, -.13831800E+01, -.18265100E+01, 0.62721800E-01, 0.79413900E+00, 0.16675400E+01, -.22571700E+01, 0.16028800E+01, 0.35133600E+01, 0.15700100E+01, -.12903600E+01, -.37444100E+01, 0.20501400E+03, -.97549700E+02, -.49851100E+02, -.10210400E+03, 0.60382300E+02, 0.16170700E+03, -.22670700E+03, -.18052900E+03, -.13672500E+03, 0.13641200E+03, -.43898200E+02, -.57906800E+03, 0.29699100E+03, -.37675000E+02, 0.28929400E+03, -.21213500E+02, 0.10803500E+03, 0.45261500E+03, 0.39388100E+03, 0.14769600E+03, 0.10241600E+03, 0.10765500E+03, 0.12563700E+03, -.65856700E+02, 0.10011400E+02, -.62522900E+02, -.26748700E+02, 0.54199900E+01, -.32912900E+03, -.25107200E+03, -.72617500E+02, 0.10079000E+02, 0.19862900E+03, 0.93290900E+00, -.65183700E+02, -.20757100E+02, 0.10205000E+02, 0.16524100E+01, -.11590800E+01, -.96412200E+00, -.65183200E+02, -.29879200E+00, -.34750900E+01, -.66226000E+01, -.26303300E+02, -.29165300E+02, -.30012500E+02, 0.22610900E+02, -.39047700E+02, 0.25842000E+02, -.68840300E+01, -.96355900E+01, -.36212300E+01, 0.39020600E+01, 0.26840000E+02, -.78976900E-01, -.52418200E+01, -.71648900E+02, 0.63649000E+01 },
        { -.17763300E+00, -.34642200E+00, -.30252500E+00, 0.56849500E-02, -.47541300E-01, -.82113600E-01, -.19962100E+01, 0.42832600E+00, 0.80450000E-01, -.39632700E-01, 0.12287600E-01, -.70560500E+00, -.84458900E-01, -.25932300E+00, 0.19477300E+00, 0.20063100E+00, -.19521800E+00, 0.11073500E-01, 0.68313800E+00, -.11762100E+00, -.85494600E-02, 0.26141900E+00, -.18812500E-01, -.40762900E-01, 0.12773800E+00, 0.42300300E-01, 0.24032100E-01, -.50716100E+00, 0.11669300E-01, 0.28339400E-02, -.36373700E+00, -.28810300E-01, 0.19869200E+00, 0.82385400E-01, 0.36878200E-01, 0.23242700E-01, 0.60390500E-02, 0.48502600E-01, -.25011700E-01, -.10728000E+00, -.31870000E+00, -.38474000E-01, 0.79517300E-01, -.17956900E-01, 0.18181900E+00, -.12162900E+00, -.13648000E+00, 0.11144300E-01, 0.40685400E-01, -.89819100E-01, -.45831100E-02, 0.46234200E-01, 0.23324800E+00, -.62712300E+00, -.14546000E+00, -.41198000E+00, 0.77292600E-01, -.16160800E+00, -.15128600E-02, -.23104600E+00, -.67557300E-01, 0.21525900E+00, 0.13101700E+00, -.20906400E+00, 0.81217400E-01, -.28972800E+00, 0.10831900E-01, -.59735800E+00, 0.19217000E+00, -.88610400E-03, 0.93351100E-01, -.32607500E+00, 0.52854900E-01, -.88461200E-01, -.16111800E+00, 0.40591400E-01, -.12207100E+00, 0.43145900E-01, 0.62216000E-01, 0.19291300E+00, 0.12214500E-01, 0.70546600E-02, -.24064600E-01, -.77112700E-01, -.23709000E-01, -.10399500E+00, -.14295500E+00, 0.10165600E+00, 0.26299300E+00, 0.35864600E-01, -.39309300E+00, 0.58720100E-01, 0.20891800E+00, -.11721300E+01, -.32856500E+00, -.11953500E+01, 0.32872000E-01, 0.21562200E-01, -.46947500E+00, -.12823200E+00, 0.93922700E+00, 0.13347100E+00, -.63612700E-02, -.26520700E+00, -.22893500E+00, -.49843000E+00, -.29623500E+00, -.48401900E+00, 0.18299800E+00, -.19582800E+03, -.26349800E+03, 0.13549200E+03, 0.19737500E+03, 0.13165100E+03, 0.22395400E+02, -.12020200E+03, 0.12448200E+03, 0.42443200E+02, 0.10497300E+03, -.77443600E+02, -.13591000E+03, 0.13704600E+04, -.68721100E+03, -.26067600E+00, -.68511200E+03, -.65069700E+02, 0.19703800E+03, -.37421400E+03, -.18698000E+03, -.67626300E+03, 0.25621000E+03, -.53569600E+03, 0.78300900E+02, -.33362300E+02, 0.47375300E+02, -.39139800E+02, 0.76793300E+02, 0.50737700E+02, -.44133600E+02, -.33202900E+02, -.95646200E+02, 0.55280400E+02, -.79509300E+02, 0.70028700E+03, -.35146100E+03, -.13359300E+03, -.35046500E+03, -.98956900E+02, -.12815600E+02, -.14014200E+03, -.50134000E+02, -.24557800E+03, 0.10952400E+02, -.26999200E+03, -.27330700E+03, 0.13231900E+03, 0.41480900E+03, 0.13725000E+03, 0.27055400E+03, 0.10428500E+03, -.22263700E+03, -.45103500E+03, 0.95272200E+02, -.38571700E+01, 0.33116500E+02, 0.23962500E+03, -.10496200E+03, 0.11498100E+03, -.11997100E+03, 0.53916700E+02, 0.86407000E+02, -.25867900E+03, -.18592200E+03, -.87948700E+02, 0.49041600E+02, -.10713600E+03, -.16017500E+02, 0.67749100E+01, -.38874500E+02, 0.80713300E+01, -.17487200E+01, 0.54337400E+01, -.28238500E+02, -.47514100E+02, -.57003400E+02, 0.20603900E+02, 0.24134500E+02, 0.47942600E+03, -.24118900E+03, -.52800400E+03, -.23950300E+03, 0.16308100E+03, -.30931400E+02, -.15723600E+03, 0.21109400E+03, -.13304900E+03, -.64410000E+02, -.91974600E+03, 0.44907600E+02, -.19026400E+02, 0.49271100E+02, -.22464100E+02, 0.68487300E+02, -.65652500E+02, -.32646700E+02, -.15746300E+02, 0.77143800E+01, -.11596900E+03, 0.73059500E+01, 0.12623000E+04, -.63209000E+03, -.21508200E+03, -.63074300E+03, 0.12923900E+03, -.12912000E+03, -.35873300E+03, 0.27144700E+03, -.48914000E+03, -.13494500E+03, -.13141600E+04, -.17025100E+03, 0.85519100E+02, 0.13407200E+01, 0.84865300E+02, 0.39369600E+02, -.30563700E+02, 0.79349500E+02, 0.73396200E+02, 0.10087700E+03, -.88287900E+02, 0.22417900E+02, 0.41829700E+01, -.29674700E+01, 0.18283800E+01, -.20451300E+01, 0.28521200E+01, 0.36848800E+01, 0.41766700E+00, -.78907700E+00, -.13123200E+01, 0.18637600E+01, -.17008800E+01, 0.49206700E+03, -.24438300E+03, -.13141300E+02, -.24581700E+03, 0.55486700E+02, 0.99972800E+02, -.21395000E+03, -.13007000E+03, -.22897500E+03, 0.89679600E+02, -.30009600E+03, -.32781800E+03, 0.16279200E+03, 0.15430000E+03, 0.16380100E+03, 0.11378800E+03, 0.13730900E+03, 0.24782000E+03, 0.50897900E+03, 0.11864000E+03, 0.28570500E+02, -.89202100E+02, 0.41074500E+03, -.20578300E+03, -.48213600E+03, -.20524100E+03, -.74022100E+02, -.14390900E+03, -.16201600E+03, -.23594600E+03, -.43187300E+02, -.29209700E+02, 0.51970600E+01, -.28578900E+01, 0.31044000E+02, -.48506500E+01, -.68534200E+01, -.25129200E+02, 0.23657100E+01, 0.32178100E+02, 0.36467000E+02, 0.58282700E+00, -.65904700E+00, 0.26550500E+01, 0.33984700E+02, 0.13719300E+02, 0.69505000E+01, 0.45158800E+02, -.54965400E+02, 0.17314300E+02, 0.45210400E+01, 0.11286100E+03, -.20114900E+02, -.88651700E+02, 0.14970300E+01, 0.80563100E-01, 0.76535400E+01, -.58023100E+02, -.19572100E+02 },
        { -.14319600E+00, -.70776500E+00, -.14185500E+01, -.21464200E-01, 0.46241600E+00, 0.26293500E+00, -.10130200E+00, -.71827700E+00, -.34372400E-01, 0.25755200E+00, -.24484600E+00, -.13969000E+01, 0.40470400E+00, -.25471800E+00, -.13143500E+01, 0.75018400E-01, -.12608200E+01, 0.80933500E-01, 0.42527000E-01, -.33644800E+00, -.68617600E+00, 0.71891900E+00, 0.22092500E+00, -.62256400E+00, -.74918500E+00, -.70144600E-01, 0.52460600E+00, -.30636600E+00, -.65044300E-01, -.43650700E-01, 0.15623500E+00, 0.19136500E-01, 0.22299700E+00, -.21088000E+00, -.40971700E-01, 0.18346200E+00, 0.34507900E-01, 0.70761700E-03, -.33216700E+00, 0.11852600E-01, -.65469300E+00, -.21552000E+01, -.60166100E+00, -.56075600E-01, -.23025300E+00, -.23523500E+00, -.21042200E+00, 0.79289200E-01, 0.38189800E+00, -.25678400E+00, -.40676300E+00, 0.98666800E+00, 0.44023400E+00, 0.41562600E+00, -.24144300E+00, 0.36395000E+00, -.26972400E+00, -.30441700E-01, -.14116400E+00, -.52016500E+00, 0.58787800E+00, -.11063700E+00, 0.12128900E+00, -.27686100E+00, -.63607000E-01, -.30020500E+00, -.11736800E+00, 0.44150100E-01, 0.28291800E+00, 0.71174100E-03, 0.36450600E+00, 0.21146200E+00, 0.58153400E-02, 0.11465900E+00, -.15757900E+00, 0.23621000E+00, 0.15877400E+00, -.44170200E+00, 0.26291700E+00, 0.71796700E-01, -.66570600E-02, 0.12292800E+00, -.58428600E+00, 0.84213100E-01, -.46439300E-01, -.26309800E+00, 0.43699600E+00, -.14921900E-01, 0.57859000E+00, -.26669900E+00, -.20156700E+00, -.20748300E+00, -.24338600E+00, 0.40691800E+00, 0.39963800E+00, -.19459500E+00, -.25104800E-01, -.11759100E+00, 0.86344800E+00, 0.34123800E+00, -.23654700E+01, 0.34247200E-01, 0.35124100E-01, -.26623300E+00, -.78803000E-01, -.40029800E+00, -.10635500E+00, 0.15643100E+00, 0.31736500E+00, -.13666200E+00, -.20451400E+03, 0.10613100E+03, 0.10599700E+03, 0.10196400E+03, -.52611000E+02, -.12366800E+03, 0.20504500E+03, 0.23200700E+03, 0.14910600E+03, -.13659400E+03, -.64094000E+02, 0.15966300E+04, -.80177500E+03, -.76411300E+03, -.79793600E+03, -.19997500E+03, 0.16483500E+03, -.28280100E+03, 0.35154100E+03, -.67230200E+03, 0.20033200E+03, -.50307800E+03, -.13388700E+03, 0.68010800E+02, 0.10273900E+03, 0.66930700E+02, 0.10764100E+02, 0.23801700E+02, 0.81023900E+02, 0.12401000E+03, 0.36976300E+02, 0.29291700E+02, 0.40239200E+02, 0.24479600E+03, -.14053000E+03, -.13438700E+03, -.12389600E+03, -.25903600E+02, 0.28822200E+02, -.49268500E+02, -.45585000E+02, -.35149300E+02, 0.22662800E+02, 0.15194700E+02, -.21611200E+03, 0.10696500E+03, 0.28695800E+03, 0.10986800E+03, 0.30372900E+03, 0.38269300E+02, -.28414500E+03, -.74183400E+03, 0.11842600E+03, -.18441400E+02, 0.31453200E+03, 0.19711200E+03, -.10249700E+03, 0.16708700E+03, -.99030600E+02, 0.11721000E+03, 0.15635200E+02, -.18694000E+03, -.22230700E+03, 0.25747900E+02, 0.30474400E+02, -.74613300E+02, -.48093500E+02, 0.24192400E+02, -.22472300E+01, 0.24239200E+02, 0.79835800E-01, -.72458400E+01, 0.14781800E+02, -.52571400E+01, 0.28749800E+01, 0.39454500E+01, 0.28268900E+02, -.12171600E+04, 0.61031700E+03, 0.25425700E+03, 0.60921400E+03, 0.19750200E+03, -.98655200E+01, 0.29994800E+03, -.27582100E+03, 0.37067400E+03, -.31003000E+01, 0.13547500E+03, -.30073800E+03, 0.14948000E+03, 0.19884000E+03, 0.15027200E+03, 0.20010500E+03, 0.20618600E+02, -.49779700E+02, -.20889900E+03, 0.93689400E+02, -.14390800E+02, 0.23338500E+03, -.33599000E+03, 0.17086100E+03, 0.59180700E+03, 0.16922600E+03, 0.20154100E+03, 0.79263900E+01, 0.21291400E+03, -.67696300E+02, 0.83351500E+02, 0.14431500E+02, -.33439700E+03, -.19988800E+03, 0.10563300E+03, 0.17618600E+02, 0.98840700E+02, 0.11127600E+03, 0.90368700E+02, -.53467000E+02, -.75197700E+02, -.22359300E+02, 0.60826100E+02, 0.10471500E+03, 0.38826000E+01, -.21520000E+01, 0.16823200E+01, -.17997200E+01, 0.52509200E+01, 0.45562400E+01, -.50281400E+01, -.10190100E+02, -.42999500E+01, 0.43000000E+01, 0.36595000E+01, 0.50841000E+01, -.77894400E+01, 0.16116800E+03, -.19694200E+01, 0.77966500E+02, 0.39431700E+02, -.86538900E+02, -.15066300E+03, -.35731100E+01, 0.43496500E+02, 0.16732700E+02, -.91355500E+03, 0.45838600E+03, 0.63746000E+03, 0.45644700E+03, 0.14038800E+03, 0.26540800E+02, 0.33052600E+03, 0.93181800E+02, 0.38872600E+03, -.26494300E+02, 0.20557800E+03, -.21121700E+03, 0.10520900E+03, -.15805400E+03, 0.10601500E+03, 0.60471400E+02, 0.20189500E+02, -.73855700E+02, -.11041700E+03, 0.61117000E+02, 0.67648900E+02, 0.63931800E+02, 0.11162300E+01, 0.31476200E+02, -.36285500E+02, -.14062000E+02, -.99448900E+01, 0.85631800E+01, 0.13703900E+02, 0.33889500E+02, 0.15404900E+01, -.22099600E+01, 0.59375000E+01, -.16301700E+02, 0.11618800E+03, -.14848200E+02, 0.16883600E+02, -.62841100E+02, 0.70598300E+02, -.53246600E+01, -.27249300E+02, 0.11573700E+02, 0.30879200E+02, 0.37613600E+01, 0.63400000E+00, 0.17881200E+01, -.40290300E+01, -.49831200E+01 },
        { 0.21293600E+00, -.48198900E+00, 0.23666100E+01, -.23999100E+00, -.67971200E+00, -.33105200E+00, -.87803000E+00, -.89917000E+00, -.82152200E-01, 0.90929600E-01, 0.17359100E+00, 0.12366200E+01, -.64497000E+00, -.24873900E+00, -.18138900E+00, -.12406700E+00, 0.10049100E+01, -.18343300E+00, 0.74383700E+00, -.25890200E+00, 0.64697500E+00, 0.51613600E+00, -.33091300E+00, 0.14978000E+01, 0.10233500E+01, 0.34711600E+00, 0.60898300E+00, -.56393200E+00, -.48270200E-01, -.16056700E+00, -.22881600E+00, -.24976400E+00, 0.99598900E+00, 0.68748200E-01, -.33163000E+00, 0.10097100E+00, 0.37479000E-01, 0.24964100E+00, -.37350000E+00, 0.13525900E+00, 0.30541900E+00, 0.12575400E+01, 0.20560600E+01, 0.35429600E+00, -.52583900E+00, -.27496200E+00, -.15343100E+01, 0.54871100E-01, 0.75963500E-01, -.16832300E+00, -.78787800E+00, -.40739500E+00, -.12496100E+00, 0.81347500E+00, 0.11386900E+01, -.71170100E+00, -.14775300E+00, 0.48260200E+00, -.30756200E-01, -.29337900E+00, 0.22684600E+00, 0.29396000E+00, -.17014200E-01, 0.13440500E+00, -.60724400E-01, 0.13874800E+00, 0.93322800E-01, -.23366000E+00, -.61246300E-01, 0.70574900E-03, -.13384600E+00, 0.50563700E-01, -.21993300E-01, -.47426100E-01, 0.21287700E+00, -.33242600E-01, -.34758600E+00, -.31744600E+00, 0.17508700E+00, 0.53082700E+00, 0.36219800E-01, -.81360200E-01, -.17942400E+00, 0.72630600E-02, -.16723000E-01, 0.12221700E+00, -.26392500E+00, -.76506400E+00, 0.33063100E+00, 0.33949800E-01, 0.41873200E+00, 0.36842100E+00, 0.86368500E-01, -.21075400E+01, 0.59268800E-01, 0.92557500E+00, 0.24258400E+00, -.13649800E-02, -.32786800E+00, -.20586000E+00, 0.10996900E+01, -.62555700E+00, -.37483000E-01, 0.34279500E+00, 0.15865200E+00, 0.66515400E+00, -.67531300E-03, 0.72651200E-01, -.26589100E+00, 0.22635700E+00, 0.59085100E+00, -.83769700E+01, -.34507400E+02, 0.60221300E+00, 0.18688300E+02, 0.42243900E+02, -.10776300E+03, -.20226700E+03, -.74965300E+02, 0.80274600E+02, 0.12061300E+03, -.75587100E+03, 0.39478400E+03, 0.53370000E+03, 0.37716100E+03, 0.79052100E+02, -.22219100E+03, 0.10995500E+03, -.41082800E+03, 0.29542000E+03, -.23763000E+03, 0.22209800E+02, 0.15704200E+03, -.88636400E+02, -.90739100E+02, -.78494900E+02, -.39802800E+02, -.41221500E+02, -.11773400E+02, -.48421600E+02, -.31431900E+02, -.43710900E+02, -.50584900E+02, -.14807700E+03, 0.10045100E+03, 0.14366000E+03, 0.76869700E+02, 0.13000600E+01, -.91385300E+01, 0.74518200E+02, 0.55124200E+02, -.38380300E+02, 0.13048100E+02, -.11800800E+03, -.10323100E+03, 0.52490600E+02, -.10191700E+03, 0.47891900E+02, -.17027900E+03, 0.37267700E+02, 0.18091500E+03, 0.42851000E+03, -.61995800E+02, 0.68971500E+02, -.18851700E+03, -.18860200E+03, 0.72291400E+02, -.13707300E+02, 0.95267100E+02, -.86789300E+02, -.10974100E+00, 0.13815900E+03, 0.12557300E+03, -.33896900E+02, -.18429100E+02, 0.71278300E+02, 0.61459800E+02, -.28436700E+02, -.13669600E+02, -.31124900E+02, -.46335800E+01, 0.95412200E+01, -.60681300E+01, 0.19703000E+01, -.12617200E+02, -.30900900E+00, -.24479900E+02, 0.17643600E+04, -.88261800E+03, -.53793100E+03, -.88348700E+03, -.25204700E+03, -.61850500E+02, -.28092600E+03, 0.35514100E+03, -.53024300E+03, -.94995100E+02, -.15360100E+03, 0.21518900E+03, -.11583000E+03, -.10758600E+03, -.10739400E+03, -.14655700E+03, 0.77961400E+02, -.40938400E+02, 0.92458100E+02, -.15016500E+03, 0.10368800E+03, -.20308500E+03, 0.94457600E+03, -.47513300E+03, -.88997100E+03, -.47481900E+03, -.26888800E+03, -.21828700E+03, -.11145100E+03, 0.23386600E+03, -.27766800E+03, -.20080000E+03, 0.26806000E+03, 0.22002700E+03, -.11839500E+03, -.84277000E+01, -.10776000E+03, -.11652600E+03, -.10233200E+03, 0.76507500E+01, 0.10041800E+02, -.51048000E+02, -.79366300E+02, -.96547600E+02, -.26434600E+01, 0.34256700E+01, -.24002800E+01, 0.10311700E+01, -.31820300E+01, -.29824800E+01, 0.47887300E+01, 0.79691900E+01, 0.45078700E+01, -.34781600E+01, -.44130500E+01, 0.11244700E+03, -.52370900E+02, -.13813100E+03, -.57405500E+02, -.92311500E+02, -.28431700E+02, 0.64774900E+02, 0.13335300E+03, -.16680100E+00, -.37630800E+02, -.61727200E+02, 0.67884800E+03, -.34487200E+03, -.54748700E+03, -.33874600E+03, -.64614600E+02, -.32037900E+02, -.14206500E+03, 0.18091400E+03, -.18439400E+03, 0.25221600E+02, -.11215900E+02, 0.26577400E+03, -.13270500E+03, 0.93421100E+02, -.13372100E+03, -.97000300E+02, 0.30478000E+02, -.43393500E+02, -.11537000E+03, -.95638900E+02, -.51894400E+02, -.74088000E+02, 0.37269000E+00, -.26092800E+02, 0.34393600E+02, 0.15495600E+02, 0.11410500E+02, -.18850300E+02, -.20356500E+02, -.28729500E+02, -.18288700E+01, 0.37060000E+01, -.18357100E+02, 0.16691100E+02, -.10988300E+03, -.51827200E+00, -.31047800E+02, 0.36156200E+02, -.47571200E+02, 0.88220000E+01, 0.60066900E+02, 0.55648800E+00, -.59796200E+02, -.17952300E+01, -.94778700E+00, 0.13455500E+01, -.56382800E+02, -.20073300E+02 },
        { -.49525200E+00, 0.54420100E+00, -.26305100E+00, -.37238500E+00, -.33095700E+00, 0.44939100E-01, -.11167600E+01, 0.12791700E+00, -.33478500E+00, -.50683000E+00, 0.15016000E+00, 0.15347100E+01, 0.53690700E+00, 0.17512300E+01, -.77970200E+00, -.43674600E+00, 0.89801600E+00, 0.13550200E+00, 0.55503500E+00, 0.51518400E+00, 0.32534900E+00, 0.18117100E+01, 0.87444000E-01, -.92771900E+00, 0.56211800E+00, -.26993800E+00, -.34328000E+00, 0.11707200E+01, 0.16865100E+00, -.44957100E+00, -.98079500E+00, -.30665400E+00, -.17955100E+01, 0.13491500E+01, 0.37202400E+00, 0.41334900E+00, -.11073600E+00, 0.15929100E+01, 0.86566000E-01, 0.15600700E+01, 0.95230200E+00, -.17989000E+00, -.44824000E+00, 0.62364000E+00, -.14240100E+01, 0.76381700E+00, 0.23154500E+01, -.67824100E-01, -.55349900E+00, 0.21770300E+01, 0.40489600E+00, 0.83257400E+00, 0.18120500E+00, 0.12237200E+01, -.59452100E-01, 0.96279000E+00, 0.61179400E+00, -.36710100E+00, 0.82805300E-01, -.22068500E+00, 0.94469100E+00, -.21366700E+00, 0.24150300E+00, -.26346100E+00, -.14508300E+00, 0.12817800E-01, -.91391800E-01, 0.66219500E+00, 0.49399900E+00, 0.39000800E-02, -.12638600E+01, -.21135600E+01, -.12926500E+00, -.23769800E+00, 0.80974600E+00, -.13823900E+00, -.23271500E+00, -.45524100E+00, -.18006600E+00, 0.10771200E+00, 0.19267500E-01, -.78308800E-02, -.16913600E+01, 0.18336900E+00, 0.26401400E+00, -.24548000E+00, 0.71260000E+00, 0.12940100E+01, -.62337800E+00, -.25206800E+00, -.74403200E+00, -.67536400E-02, 0.73837700E-01, 0.27376900E+01, 0.42151400E-01, 0.84291900E+00, -.44243600E+00, 0.26323000E+00, 0.76974200E-01, 0.57755600E+00, -.31840800E+01, 0.10183400E+01, -.16204800E-01, 0.19816600E+00, 0.86937800E-01, 0.18679600E+00, 0.10757500E+00, -.86431800E+00, -.24908200E+00, 0.13937100E+01, -.22427600E+00, -.95204500E+00, -.30885700E+03, 0.50256900E+00, 0.50919000E+02, 0.18776100E+03, -.23267200E+03, -.43172200E+03, -.15115200E+03, 0.20878500E+03, 0.33397400E+03, -.48833800E+04, 0.24232800E+04, 0.13698000E+04, 0.24410500E+04, 0.51565200E+03, -.75108600E+03, 0.96928500E+03, -.63463700E+03, 0.22705700E+04, -.68863600E+03, 0.18978000E+04, 0.38292700E+03, -.18335300E+03, -.38713600E+03, -.19145800E+03, -.21527000E+03, -.30895200E+03, 0.70737100E+02, -.11662000E+03, -.13790800E+01, -.25510600E+03, -.96819300E+02, -.11925900E+04, 0.62661800E+03, 0.65632100E+03, 0.59938000E+03, 0.15059900E+03, 0.12754400E+03, 0.24221300E+02, -.20054800E+03, 0.17251500E+03, 0.11304800E+03, 0.24597800E+03, 0.76280600E+03, -.37877000E+03, -.14506700E+04, -.38449700E+03, -.94493700E+03, -.38778300E+03, 0.86008600E+03, 0.20649400E+04, -.28815000E+03, -.21235200E+03, -.37517200E+03, -.40093400E+03, 0.23638700E+03, -.28305500E+03, 0.20127400E+03, -.27247500E+03, -.20342800E+03, 0.64044800E+03, 0.88290700E+03, 0.34469200E+03, -.18971100E+03, 0.28176700E+03, 0.20524400E+03, -.10368400E+03, 0.10127200E+02, -.10295000E+03, -.68818400E+02, -.23765000E+02, 0.67627100E+02, 0.65199000E+02, 0.32009500E+02, -.51776000E+02, -.11315700E+03, 0.31543200E+04, -.15752100E+04, -.56918700E+03, -.15782500E+04, -.11474900E+04, -.32086500E+03, 0.40544300E+03, 0.57761000E+03, -.51312600E+03, -.30568500E+03, -.37699000E+03, 0.53145800E+03, -.25458800E+03, -.50940200E+03, -.26558700E+03, -.42704300E+03, 0.45151700E+02, 0.23456700E+03, 0.62476500E+03, -.14845400E+02, 0.18301600E+03, -.52109400E+03, 0.70049300E+03, -.34437800E+03, -.17457500E+04, -.35235500E+03, -.10327900E+04, -.41010500E+03, 0.10400000E+04, 0.41303300E+03, 0.52350400E+03, -.36332300E+03, 0.77235300E+03, 0.51882800E+03, -.26574200E+03, -.16352900E+02, -.25764100E+03, -.25976400E+03, 0.48084000E+02, -.45139200E+02, 0.16081900E+03, -.12697800E+03, 0.16646400E+03, -.84296100E+02, -.19834700E+02, 0.70661100E+01, -.44286400E+01, 0.96760900E+01, -.84175900E+01, -.12827400E+02, 0.10230300E+02, 0.18991600E+02, 0.11662200E+02, -.10620800E+02, 0.12311000E+01, -.37771300E+03, 0.19344200E+03, -.79146600E+02, 0.18784200E+03, -.20760800E+03, -.88428700E+02, 0.29169700E+03, 0.46498200E+03, 0.29539100E+03, -.10523000E+03, 0.33773700E+03, 0.21181200E+04, -.10445900E+04, -.11513800E+04, -.10585000E+04, -.55253500E+03, -.40004000E+03, -.59557500E+03, -.87179900E+03, -.13874900E+04, -.29950100E+03, -.29002300E+03, -.49129100E+02, 0.22099700E+02, 0.78783600E+03, 0.23874100E+02, 0.11457200E+03, 0.48056400E+03, 0.79846700E+02, 0.68100000E+03, 0.29255200E+03, 0.31905600E+03, -.34213700E+03, 0.66928900E+01, -.12152100E+03, 0.42844000E+02, 0.28540000E+02, 0.24249400E+02, -.20631000E+02, -.33759500E+02, -.13047000E+03, -.43175900E+01, 0.28826400E+01, -.24929600E+02, 0.99796300E+01, -.21385200E+03, -.24345100E+02, -.34140500E+02, 0.18933700E+03, -.13291700E+03, 0.52078100E+01, -.13730100E+03, -.18572600E+02, 0.64843000E+02, -.90917900E+01, -.13750300E+01, -.29613800E+02, 0.26281100E+03, 0.13891100E+03 },
        { -.24191700E+00, 0.45619400E+00, -.25319200E+01, 0.13961300E+00, 0.15504700E+01, 0.93486600E-01, 0.25428900E+01, 0.13209300E+01, 0.23075800E+00, -.73320400E-01, -.96588100E-01, -.18983600E+01, 0.48809700E+00, -.16174300E+00, -.77069200E+00, -.21152400E+00, -.21350500E+01, 0.20963200E+00, -.38130200E+00, 0.55277800E-01, -.62537000E+00, 0.32232500E-01, 0.12640700E+00, -.62851000E+00, -.30271100E+00, 0.40332800E-02, 0.14539700E+00, 0.73147900E+00, 0.98657300E-01, -.20916100E+00, 0.30839200E+00, 0.19523100E+00, -.55435000E+00, 0.22041600E+00, -.19133300E+00, 0.30980300E+00, -.57915000E-01, 0.57308100E+00, -.91042500E-01, 0.70739100E+00, -.12214000E+00, -.79917900E+00, -.51889500E+00, -.18132900E+00, 0.10168900E+01, 0.11840400E+00, 0.30335400E+00, -.84710800E-02, 0.18412300E+00, -.34097800E+00, 0.41029000E+00, -.47589600E+00, -.49583900E-01, 0.89772300E+00, 0.13280500E+00, 0.27678900E+00, -.37213900E-01, -.58625500E-01, 0.64685100E-02, 0.48780900E-01, -.49437500E-01, -.14827700E+00, -.59948300E-01, 0.11828000E+00, -.11830800E-01, 0.62007000E-01, -.10892400E+00, -.31318100E+00, -.96948600E-01, -.60142000E-02, 0.37827700E+00, 0.52350100E-01, 0.14344500E+00, 0.78607100E-01, -.77701100E-01, 0.21538200E+00, 0.18645600E+00, 0.11068700E+00, -.54298900E-02, -.28507300E-01, -.13379000E-01, -.16881700E-01, 0.45775100E+00, -.17745800E+00, -.10819200E+00, 0.28864600E+00, -.41581600E+00, 0.22277700E+00, 0.44380800E+00, -.18130000E-01, 0.95134000E+00, -.53594600E-02, -.52002400E+00, 0.77424000E+00, -.48883000E-01, -.30047000E+00, 0.21555400E+00, -.17184700E+00, 0.10844300E+00, 0.22912200E-01, 0.74353600E+00, 0.31455500E+00, 0.40032500E-02, -.14300300E+00, -.21922600E+00, 0.28882300E+00, 0.29208100E+00, 0.15228000E+00, -.70413900E+00, -.33310200E+00, -.21547300E+00, -.26309100E+00, -.81134000E-01, 0.35335700E+01, 0.14561900E+02, 0.26314800E+02, -.33908400E+02, -.31583000E+02, -.25954900E+02, 0.32481800E+02, 0.48393000E+02, -.75420500E+03, 0.37151900E+03, 0.63426200E+03, 0.37703800E+03, 0.15470300E+03, -.67534800E+02, 0.21658600E+03, -.38138000E+00, 0.29746500E+03, -.43395000E+02, 0.12254400E+03, -.57176800E+02, 0.32102600E+02, -.13843600E+02, 0.28567400E+02, -.11211500E+02, -.23442000E+02, -.17931500E+02, -.11757400E+03, -.52683900E+01, -.23431200E+02, 0.28057500E+02, 0.19749700E+03, -.69489400E+02, 0.61605100E+01, -.99116200E+02, -.14943100E+02, 0.30404800E+02, -.96506700E+02, -.30159300E+02, -.94034700E+02, 0.22445200E+02, -.12525500E+03, 0.34565600E+02, -.16385000E+02, -.26903200E+03, -.17620200E+02, -.56939600E+02, -.12813400E+02, 0.51957200E+02, 0.18771700E+03, 0.10317600E+02, -.11325300E+02, -.43700100E+02, 0.17366100E+03, -.65476500E+02, -.46584000E+02, -.86731500E+02, 0.55439200E+02, 0.66638200E+02, -.90581100E+01, 0.14395300E+03, -.23700500E+02, 0.64251300E+02, -.87746800E+02, 0.29273000E+02, -.15502300E+02, -.97981300E+01, -.14671600E+02, -.41994500E+01, 0.52320300E+01, -.11024900E+02, -.57713100E+01, -.67626900E+01, 0.32153700E+01, -.16842400E+02, 0.49761000E+03, -.25019800E+03, -.97770800E+02, -.24892500E+03, 0.62657200E+01, 0.13055600E+03, -.18200200E+03, 0.69883600E+02, -.13906200E+03, 0.12653800E+03, 0.19364200E+02, 0.11928100E+03, -.53849400E+02, -.67434500E+02, -.59658100E+02, -.22169000E+02, 0.79389300E+02, -.30009900E+02, 0.69393200E+02, -.58692600E+02, 0.94375800E+02, -.11546800E+03, 0.67325200E+02, -.34254200E+02, -.25168200E+03, -.33897600E+02, -.12298700E+02, 0.63218000E+02, -.98900800E+02, 0.40143100E+02, 0.29707800E+02, 0.82655500E+02, 0.23124200E+03, 0.12421800E+03, -.69624600E+02, 0.36242800E+02, -.62806300E+02, -.48149200E+02, -.34078800E+02, 0.34915300E+02, 0.11819000E+03, 0.41828300E+01, -.26392400E+01, -.82918500E+02, -.31069500E+01, 0.35261300E+00, -.75677400E+00, 0.15271700E+01, 0.76170100E+00, -.16867100E+01, 0.30379700E+01, 0.37790600E+01, 0.30500600E+01, -.19958300E+01, -.15813600E+01, 0.10256500E+03, -.46010100E+02, 0.25249800E+02, -.51429100E+02, 0.16367900E+02, 0.76520900E+02, -.51218400E+02, 0.11822100E+02, -.69685100E+02, 0.63135900E+02, -.41009900E+02, 0.69374300E+03, -.34356500E+03, -.30335200E+03, -.34681100E+03, -.13276300E+03, -.53054000E+02, -.16897900E+03, -.78088900E+02, -.32872500E+03, -.70016900E+02, -.49927400E+02, -.23934700E+02, 0.10652900E+02, 0.39181400E+02, 0.11894700E+02, 0.10231700E+02, 0.24529300E+02, 0.38164100E+02, 0.60781200E+02, 0.72338000E+02, 0.35322900E+02, -.79492700E+02, 0.25590800E+01, -.80001100E+01, 0.77789800E+00, 0.68471500E+01, 0.27825200E+01, -.32590600E+01, -.16270000E+01, -.52222100E+01, -.93030300E+00, 0.10976400E+00, -.40873700E+00, -.10372600E+01, -.15390600E+02, -.98142100E+00, 0.68105400E+01, 0.14826700E+02, -.80063100E+01, 0.38702100E+01, 0.10379300E+01, -.24770500E+01, -.22564500E+01, -.76202300E+00, -.37710800E+00, -.34914300E+01, 0.33106000E+02, 0.12999100E+02 },
        { -.73657400E+00, 0.22279700E+01, -.59893300E+01, -.86411900E+00, 0.16132700E+01, 0.82758400E+00, 0.15385900E+01, -.15310100E+01, -.63004700E+00, 0.20965500E+00, 0.12311200E+01, 0.10850000E+00, 0.18706200E+00, 0.65242900E+00, 0.77775400E+00, 0.15251900E+00, -.10581100E+01, 0.25716500E+00, -.94119800E+00, 0.65188700E+00, -.18895800E+01, 0.34307600E+01, 0.30446900E-01, -.27215700E+01, -.15635000E+00, -.13864200E+00, -.13591800E+01, 0.55145400E+00, -.70675400E-02, 0.69549100E+00, -.91235200E+00, -.13544400E+00, 0.12945500E+01, 0.27485200E+00, 0.79856000E+00, -.27893400E+00, 0.33521100E-01, 0.67141700E+00, 0.12828300E+01, -.94985400E+00, -.58788400E+00, -.24974100E+01, -.52255100E+00, 0.50478300E+00, -.71680200E+00, 0.13685600E+01, 0.29551600E+01, -.90484800E-01, -.46337300E+00, 0.24417700E+01, -.45895200E+00, 0.24088100E+01, 0.85992600E+00, 0.12893500E+01, -.17556900E+01, 0.31789100E+00, 0.12403100E+00, -.11690100E+01, 0.13640000E+00, -.12620900E+01, 0.10866700E+01, -.10961100E+00, 0.57206100E-01, -.14070000E+00, -.71624600E-01, -.46787200E+00, 0.14013200E+00, 0.19721200E+01, -.56687500E+00, -.55030700E-02, -.19541400E+01, -.42174700E+00, -.53901500E-01, 0.56361600E-01, 0.24828400E+00, 0.41740300E+00, -.70002700E+00, -.11735300E+01, 0.28192900E+00, 0.43243000E+00, 0.65050500E-01, -.28967600E-01, -.27997300E+00, 0.45725500E+00, -.26859200E+00, -.11516700E+00, 0.10536200E+01, -.20833200E+01, -.14468300E+01, 0.64983200E-01, -.11843400E-01, 0.53669100E+00, 0.58517200E+00, -.16368700E+01, -.31260200E+00, -.71001200E+00, -.11370300E+01, 0.15214500E+01, 0.18081600E+00, -.36660500E+00, -.39530200E+00, -.17791600E+00, -.57033300E-01, -.10007700E+00, 0.22401000E+00, 0.92098600E+00, 0.81805600E+00, -.10043400E+01, -.70819500E-02, -.31941500E+01, 0.29723900E+01, 0.12387800E+01, -.14976200E+00, 0.29099300E+00, 0.27523800E+03, 0.13429900E+03, -.37791300E+03, -.58464400E+03, -.22958500E+03, 0.26563500E+03, 0.30686900E+03, -.35225200E+04, 0.17604900E+04, 0.35711500E+04, 0.17599300E+04, 0.75341800E+03, -.19003700E+03, 0.30915600E+03, -.19162300E+04, 0.10298400E+04, -.21205700E+03, 0.58962400E+03, 0.52794700E+03, -.24803300E+03, -.23441900E+03, -.26389300E+03, 0.98246900E+01, -.23080400E+02, -.35605100E+03, -.70252300E+03, -.43237200E+03, -.36170800E+02, -.13789700E+03, 0.13942900E+04, -.61462600E+03, 0.24589400E+02, -.69246300E+03, -.73518700E+02, 0.41175600E+02, -.52817700E+03, -.14921200E+03, -.76062700E+03, 0.13304000E+03, -.12304100E+04, -.89424700E+02, 0.37789300E+02, -.40561500E+03, 0.38418500E+02, -.42873300E+03, -.10635400E+03, 0.70398500E+03, 0.19261100E+04, 0.16936500E+03, -.11424900E+03, -.11171900E+04, 0.20509100E+03, -.27165500E+02, -.31649400E+03, -.10088600E+03, -.99739600E+02, 0.28697900E+03, -.48420200E+02, 0.44858500E+03, -.31192800E+03, 0.98411300E+02, -.17270800E+03, 0.22785500E+03, -.11846400E+03, -.75105900E+02, -.11459900E+03, -.54699300E+01, 0.67235800E+02, -.10174300E+03, -.52981900E+02, -.16951800E+03, 0.56235400E+02, -.15455800E+03, 0.66219700E+04, -.33214400E+04, -.21568100E+04, -.33131900E+04, -.35654400E+03, 0.13458000E+03, -.11079400E+04, 0.20927400E+04, -.16387500E+04, -.34056000E+02, -.30361700E+04, 0.13721000E+04, -.66796700E+03, -.78830000E+03, -.68566700E+03, -.49303900E+03, -.41641900E+02, 0.58974700E+02, 0.77042000E+03, -.54589900E+03, -.52796800E+02, -.10024400E+04, 0.39535200E+04, -.19882700E+04, -.32343900E+04, -.19810200E+04, -.54620500E+03, -.53944400E+03, -.83087100E+03, 0.15675800E+04, -.79160800E+03, -.51600100E+03, -.17043000E+04, 0.65841600E+03, -.35314500E+03, -.16490100E+03, -.32561000E+03, -.51824700E+03, -.47388900E+03, 0.50107300E+03, 0.58100300E+03, 0.16510000E+03, -.46293200E+03, -.34532600E+03, -.10758700E+02, 0.23618700E+01, -.44921000E+01, 0.48861300E+01, -.10551600E+02, -.13551700E+02, 0.24551500E+02, 0.42984900E+02, 0.21448400E+02, -.17018400E+02, -.21855700E+02, 0.12257800E+04, -.58560400E+03, -.41067800E+03, -.61480400E+03, -.59301600E+02, 0.32000900E+03, -.41099900E+03, -.36666300E+01, -.72571000E+03, 0.24505500E+03, -.73602300E+03, 0.48153100E+04, -.24134900E+04, -.31160900E+04, -.24065000E+04, -.37191100E+03, 0.86252000E+02, -.10607300E+04, 0.94395800E+03, -.18173200E+04, 0.12791400E+03, -.13952300E+04, 0.65105500E+03, -.32642000E+03, 0.30283900E+03, -.32694900E+03, -.31484900E+03, -.10205400E+03, 0.20610700E+03, 0.20459500E+02, -.11729100E+03, -.12409000E+03, 0.37450400E+02, -.63378700E+01, -.64571400E+02, 0.99313100E+02, 0.42492900E+02, -.24682100E+00, -.48849700E+02, 0.53105400E+02, -.59967300E+02, -.57491500E+01, -.35140200E+01, -.15810800E+02, 0.65768400E+02, -.46499000E+03, 0.32741900E+02, 0.11590900E+03, 0.11033200E+03, -.16185000E+03, 0.60331800E+02, 0.22602500E+03, -.11869800E+03, -.22433500E+03, -.50605500E+01, -.23513200E+01, 0.69522900E+01, -.14993300E+03, -.46433300E+02 },
        { 0.16751200E+00, 0.64541400E+00, -.79212300E+00, 0.51590700E+00, -.33930100E+00, 0.10283300E+00, 0.81455300E-01, 0.88352400E+00, 0.24292500E+00, -.15566300E+00, -.16637100E-01, 0.72432100E-01, 0.79199800E-01, 0.16263700E+00, -.98652300E+00, 0.34826000E+00, -.23301300E-01, 0.30905700E-01, -.20595100E+01, 0.11349700E+01, -.53863700E+00, 0.54649600E+00, 0.24726700E+00, -.88303400E+00, -.47265200E+00, -.52429000E+00, -.43930700E+00, 0.34895900E+00, -.18054300E+00, -.10163100E+00, 0.26951900E-01, -.42962000E-01, -.23995900E+00, -.20439500E-01, -.59125600E-01, 0.98315900E-02, -.71771100E-02, 0.38748100E+00, 0.29194800E+00, 0.65489100E-01, -.70773100E+00, -.10861500E+01, 0.12571900E+01, 0.72193500E+00, -.47392200E+00, 0.21942100E+00, 0.12423700E+00, -.48674100E-01, -.10855000E+00, 0.77452600E+00, -.68373100E-01, -.27033800E+00, 0.35794500E+00, -.12276800E+01, -.15672500E+00, 0.48235000E+00, -.30261100E+00, 0.10055000E+01, -.14926000E+00, -.30127100E+00, -.40002900E+00, -.12635600E+00, 0.17878400E-01, 0.19132100E+00, 0.22295000E+00, 0.35145200E+00, -.41508000E-01, -.38049600E+00, 0.50900900E+00, -.87102000E-02, 0.99164100E+00, 0.47185800E+00, -.79499200E-01, -.49863800E-01, 0.16520800E+00, -.53998400E+00, 0.17681700E-01, 0.49796000E+00, -.36330900E+00, 0.17254200E+00, -.43348800E-03, -.60870500E-02, -.20810200E+00, 0.24356400E+00, 0.23828400E+00, -.74811000E-02, -.11676500E+01, -.12928600E+01, -.20109500E+01, 0.27635100E+00, -.93682100E+00, -.76933800E-02, 0.31713200E+00, 0.52977700E+00, -.55056300E+00, -.11257200E+01, 0.20017800E+00, 0.36361400E-02, -.17611300E+00, 0.16528200E+00, 0.76504900E-01, 0.61963900E+00, -.37476200E-02, 0.64807600E+00, -.10807500E+00, 0.44368600E+00, -.94136300E-01, 0.81431400E+00, -.31483900E+00, 0.25977000E+00, -.16761900E+00, 0.34858300E+00, -.45656300E+00, -.32321600E-01, 0.10985300E+00, 0.11409800E+03, -.53904800E+02, -.12677700E+03, 0.27564700E+02, 0.68472000E+02, -.46289800E+02, -.16898100E+04, 0.84091700E+03, 0.18922400E+03, 0.84522100E+03, 0.25040100E+03, 0.36307600E+03, 0.16248200E+03, 0.31676300E+03, 0.87179000E+03, 0.30829300E+03, 0.94105500E+03, 0.13325900E+03, -.66790700E+02, -.62954300E+02, -.66683500E+02, 0.21977700E+02, -.30944600E+02, 0.56469900E+01, -.10365000E+02, -.54391800E+02, -.21708100E+02, -.15423300E+03, -.60161800E+03, 0.29503100E+03, 0.50435300E+02, 0.29964500E+03, -.89879100E+02, -.16795500E+03, 0.50122000E+03, 0.37585900E+03, 0.41053200E+03, -.16784400E+03, 0.49201400E+03, 0.90099500E+03, -.44801400E+03, -.60029000E+03, -.44907500E+03, -.44807900E+03, -.32381500E+03, 0.44921100E+03, 0.53118600E+03, -.20975000E+03, -.20185900E+03, -.45899600E+02, 0.23926400E+03, -.12293700E+03, 0.15948800E+02, -.12000900E+03, -.29547300E+02, -.23180700E+03, 0.19265500E+03, 0.56427700E+03, 0.36771900E+03, -.15715100E+03, -.78784400E+02, -.92420800E+02, 0.46047700E+02, 0.68132800E+01, 0.46364600E+02, 0.18581700E+02, -.11111500E+02, 0.36283700E+02, -.24219500E+02, 0.37408100E+02, -.37687600E+01, 0.39407900E+02, 0.10386800E+03, -.49969500E+02, -.23364100E+03, -.51440300E+02, -.15885000E+03, -.50627200E+03, 0.56544400E+03, 0.21507200E+02, 0.43723000E+03, -.37553300E+03, -.26170400E+03, -.46763700E+03, 0.23516800E+03, 0.19086000E+03, 0.23368400E+03, -.94826000E+02, -.30846100E+03, 0.37256600E+03, 0.19972900E+03, 0.38126100E+03, -.19179400E+03, 0.21825500E+03, 0.70094800E+03, -.34816200E+03, -.21024900E+03, -.34952300E+03, 0.62995700E+03, -.44950100E+02, 0.43303900E+03, 0.16165600E+03, 0.33418600E+03, -.59244800E+02, -.52054100E+03, -.64322600E+03, 0.32407900E+03, 0.61332600E+02, 0.32076500E+03, 0.33440700E+03, 0.51169600E+03, -.27522200E+03, -.38662000E+03, -.11530500E+03, 0.53249300E+03, 0.21060200E+03, -.29619000E+01, 0.14375100E+01, 0.25045800E+01, 0.15934000E+01, 0.20884300E+00, 0.48161400E+01, -.28286500E+01, -.58881600E+01, -.41349800E+01, 0.69687900E+01, 0.52749300E+01, -.10208500E+04, 0.50563500E+03, 0.43491900E+03, 0.51078700E+03, 0.32456800E+02, -.84918500E+02, 0.42116900E+03, 0.33575100E+03, 0.49972200E+03, -.38678700E+02, 0.44668200E+03, 0.10650600E+04, -.53090100E+03, -.12662100E+03, -.53279500E+03, -.60008400E+03, -.45117900E+03, -.88292200E+02, -.79124200E+03, -.10045800E+04, -.42053300E+03, -.37085100E+03, -.69765700E+03, 0.34986100E+03, 0.14377000E+03, 0.34915700E+03, 0.41233200E+03, 0.15579300E+03, 0.35513900E+02, 0.66200500E+03, 0.78233600E+03, 0.14979700E+03, -.17060500E+03, 0.27756400E+01, 0.12007400E+02, -.43331000E+02, -.65117700E+01, -.49474600E+02, 0.19926200E+02, -.12412400E+02, 0.17306200E+02, 0.12704700E+01, 0.66418400E+01, 0.52200800E+01, 0.13816500E+02, -.22336500E+01, 0.40816800E+02, -.90179500E+02, 0.71865100E+02, 0.20770000E+02, -.10547000E+02, -.14304600E+03, 0.17704100E+02, 0.11489900E+03, -.17484000E+02, 0.88602700E+00, -.34000600E+02, 0.22699700E+03, 0.12556800E+03 },
        { -.65179900E+00, 0.23258000E+01, -.91903500E+01, -.15061700E+01, 0.27341400E+01, 0.31444600E+00, 0.21995600E+01, -.12289900E+01, -.12714500E+01, 0.22818700E+00, 0.13419200E+01, -.11112200E+01, 0.64888900E+00, 0.42438300E+00, 0.86038300E+00, 0.30638000E+00, 0.40238300E+00, 0.28906100E+00, 0.89121200E+00, 0.48670500E+00, 0.18598200E-01, -.45347400E+01, 0.16288200E-01, 0.93785100E+00, 0.16241800E+00, 0.14229200E+00, -.23746000E+00, 0.17583600E+01, -.28290900E+00, -.24947300E+00, 0.10482200E+01, 0.24072100E+00, -.28064400E+01, 0.65845000E+00, 0.10508200E+01, -.11334100E+00, -.15397800E+00, 0.14818600E+01, 0.32341800E+00, 0.78275700E+00, 0.78621900E+00, -.51834100E+01, -.78436800E+01, -.32524600E+01, 0.31698500E+01, -.83228800E+00, -.39768700E+00, -.74151200E-01, 0.84170200E+00, -.24172200E+01, 0.47728600E+00, 0.43174200E+00, -.15440000E+00, -.46340600E+01, -.38875800E+00, -.55594100E+00, 0.13004900E+01, 0.78089100E+00, 0.54510200E+00, 0.25377000E-01, 0.59412600E+00, 0.59223400E+00, -.20945100E-01, 0.44766000E+00, -.48780800E-01, 0.72211900E+00, -.21089200E-01, -.41847600E+00, 0.89288200E+00, 0.10770600E-03, -.13700100E+01, -.17033800E+01, -.19821500E+00, -.56544800E+00, 0.70528800E+00, -.59483500E+00, -.13527100E+00, -.22427300E+00, -.59916600E+00, 0.86299200E+00, 0.25157400E-01, -.88115200E-01, -.35257300E+00, 0.97667900E+00, 0.29784800E+00, 0.29564400E+00, -.26769500E+01, 0.41446100E+00, -.15558300E+01, 0.18576600E+00, 0.11549800E+01, 0.23042700E+00, -.48143100E+00, 0.46380400E+01, 0.61462100E+00, 0.30533800E+01, 0.68246000E+00, -.26057400E+00, -.93310000E+00, -.14147200E+00, 0.97806100E+00, -.69815000E+00, -.30961600E-01, 0.13073400E+01, 0.14710800E+00, 0.33696300E+00, -.84304700E+00, 0.14517300E+01, -.26443900E+01, 0.20158900E+00, 0.37380000E+00, 0.45233800E+00, -.65681300E+00, -.11725100E+00, -.75978200E+00, 0.77737200E+00, -.30351000E+03, -.61760400E+03, -.16418100E+03, 0.14684500E+03, 0.19332800E+03, -.52948300E+04, 0.26136900E+04, 0.35221100E+04, 0.26467000E+04, 0.85486700E+03, -.15842600E+03, 0.48093900E+03, -.21698900E+04, 0.19662400E+04, -.31010100E+02, 0.15463900E+04, -.92253500E+02, 0.69603800E+02, -.19061200E+03, 0.46169500E+02, 0.17897800E+01, -.64945300E+02, -.39787000E+03, -.94147700E+03, -.16372900E+03, -.18162600E+01, 0.11517100E+03, 0.15169800E+04, -.72233300E+03, 0.25494300E+03, -.75562600E+03, -.19198200E+03, -.59219600E+02, -.68137700E+03, -.37608200E+03, -.65662000E+03, 0.14904700E+02, -.85142400E+03, 0.45842500E+03, -.22243300E+03, -.83772300E+03, -.23254700E+03, -.88197100E+03, -.25759000E+03, 0.97499100E+03, 0.25407000E+04, -.34889900E+03, -.29274700E+03, -.14941800E+04, 0.17174200E+03, 0.99336200E+01, -.43902600E+03, -.84965000E+02, -.85823800E+02, 0.35819000E+03, 0.28856900E+03, 0.10727100E+04, -.22849600E+03, 0.21072800E+03, -.64206000E+02, 0.81004800E+02, -.48034000E+02, -.12878400E+02, -.40860100E+02, -.27654300E+01, 0.86932800E+02, -.11993800E+03, -.15905900E+03, -.15050100E+03, 0.75737000E+02, -.10048300E+03, 0.61223600E+04, -.30685600E+04, -.23311500E+04, -.30623400E+04, -.54425200E+03, 0.12786900E+03, -.96018300E+03, 0.14812900E+04, -.15817500E+04, 0.10242400E+01, -.41854800E+04, 0.12185600E+04, -.57790600E+03, -.63573300E+03, -.60908600E+03, -.65771200E+03, -.69981500E+02, 0.32320800E+03, 0.11173300E+04, -.27774700E+03, -.26974100E+02, -.99719200E+03, 0.41103300E+04, -.20614200E+04, -.29307700E+04, -.20574200E+04, -.13941100E+04, -.86602800E+03, -.74907100E+03, 0.94502200E+03, -.98920300E+03, -.74087900E+03, -.33912600E+04, 0.13088600E+04, -.66278000E+03, 0.21751200E+03, -.65345600E+03, -.55907900E+03, -.43032600E+03, 0.25004500E+03, 0.73730700E+03, -.13179600E+03, -.41359700E+03, -.10712200E+04, -.12051200E+02, 0.95013900E+00, -.62426200E+01, 0.57630100E+01, -.91996600E+01, -.88895300E+01, 0.26705400E+02, 0.43401700E+02, 0.15272800E+02, -.11810000E+02, -.19317700E+02, 0.99390400E+03, -.48947400E+03, -.19354700E+03, -.49795100E+03, -.16721000E+03, 0.16745900E+03, -.30903900E+03, 0.10308000E+03, -.49705300E+03, 0.12680200E+03, -.58592200E+03, 0.45422400E+04, -.22645300E+04, -.22969500E+04, -.22705100E+04, -.87086100E+02, -.12993400E+03, -.10724900E+04, 0.50460500E+03, -.19440200E+04, -.30477000E+03, -.12901500E+04, 0.14817600E+04, -.73832300E+03, -.63343600E+03, -.74163700E+03, -.40920100E+03, 0.67996100E+02, 0.12932900E+03, 0.38021900E+03, -.32961500E+03, 0.20462900E+03, -.58562600E+03, -.61098200E+01, 0.95412700E+01, 0.12655200E+03, 0.78464500E+02, 0.67815800E+02, -.29223200E+02, 0.29294800E+02, 0.10880100E+02, -.54169500E+01, 0.63251400E+01, -.13978400E+02, 0.13239700E+03, -.46058700E+03, -.20857500E+02, 0.77341600E+02, 0.15630200E+03, -.22417000E+03, 0.45275500E+02, 0.37242800E+03, -.11284700E+03, -.32027500E+03, -.90164500E+01, -.24431500E+01, 0.19872000E+02, 0.60641500E+02, -.26118700E+02 },
        { 0.50031300E-01, 0.18008100E-01, 0.51199000E+00, 0.22471800E-01, -.14182900E+00, 0.30584900E-01, 0.34539200E+00, -.14049000E+00, -.34842400E-02, 0.20278400E-01, -.25984500E-02, 0.30138800E+00, -.57384000E-01, 0.55466300E-01, -.35892900E-01, -.40897100E-01, 0.51264300E-02, 0.11165500E-01, -.51160500E-02, -.27921900E-01, 0.49670200E-01, -.18104500E-01, -.26667900E-01, 0.59213400E-01, 0.45395000E-01, -.17642000E-02, 0.18191000E-01, 0.56322000E-01, -.17082100E-01, -.55561800E-01, -.25276200E-01, -.33626900E-01, -.11396100E-01, 0.59241200E-01, -.10938500E-01, -.41864200E-01, 0.40933300E-02, -.47782600E-01, -.27648100E-01, -.64761000E-02, 0.66517400E-01, 0.22459900E-01, 0.52059800E-01, -.19641800E-01, -.13514200E+00, 0.31978800E-02, 0.17857400E-01, 0.25974900E-02, -.99426900E-02, 0.72212100E-02, -.14382600E-01, 0.37384000E-01, -.14622700E-02, 0.14810800E+00, 0.36429300E-02, -.15476700E-01, -.54210000E-02, 0.48113600E-01, -.55097800E-02, 0.28327800E-01, 0.17606600E-02, 0.65815600E-02, -.10132600E-01, 0.28984800E-01, -.12367900E-02, 0.17069900E-01, -.53079200E-02, -.18012000E-02, -.89566600E-02, -.10104800E-03, -.36463200E-01, -.41558500E-01, 0.32143500E-02, -.41573200E-02, 0.40725100E-01, 0.29212200E-01, -.14806600E-01, -.59859200E-01, 0.22707500E-01, 0.20892800E-03, 0.14483900E-02, 0.53903300E-02, -.26865800E-01, 0.23801000E-01, 0.22251800E-01, -.23001200E-01, -.46828000E-01, 0.31682500E-01, -.19516300E+00, -.34493700E-01, 0.50221400E-01, 0.12886400E-01, -.84396400E-01, 0.22376300E+00, 0.67371200E-01, 0.17537700E+00, -.99707100E-01, 0.16463200E-01, 0.51775400E-01, 0.98799600E-01, -.52374900E+00, 0.54999800E-01, -.18640400E-02, 0.33525000E-01, 0.13518200E-01, 0.16994500E+00, 0.81154000E-01, 0.25478400E-01, -.17983400E+00, -.69656400E-01, 0.80382600E-01, -.11195600E+00, 0.75535500E-01, 0.99862200E-02, 0.18186600E-01, -.35975400E-01, -.43266200E-01, -.16380700E+02, -.95447000E+01, 0.86507400E+01, 0.10343600E+02, -.74414600E+02, 0.36074300E+02, 0.18242200E+03, 0.37167000E+02, 0.54548200E+02, -.41073400E+02, 0.18558400E+02, -.99950100E+02, -.12951200E+02, -.20823000E+02, -.78706000E+02, -.22846300E+02, 0.12346600E+02, 0.75824300E+01, 0.11423100E+02, 0.77027800E+01, 0.39562300E+01, 0.15928300E+01, -.41985700E+02, -.91909200E+01, 0.37844400E+01, 0.74494300E+01, 0.10412400E+03, -.46418400E+02, -.83705900E+01, -.51823300E+02, -.92870200E+01, 0.17229300E+02, -.60065900E+02, -.33646700E+02, -.43209300E+02, 0.16927100E+02, -.48732600E+02, -.51451400E+02, 0.25808000E+02, 0.93782900E+00, 0.25532100E+02, -.10587700E+02, 0.14142300E+02, -.31302000E+02, 0.65364800E+02, 0.25155700E+02, 0.10118600E+01, -.54434200E+02, 0.19783400E+02, -.50119500E+01, -.10614800E+02, -.98395600E+01, 0.51357700E+01, 0.23111500E+02, -.34669500E+01, 0.24539100E+02, -.18848100E+02, 0.14867200E+02, -.10564200E+02, 0.80463500E+01, -.42189900E+01, -.22198300E+01, -.40437500E+01, 0.79771500E+00, 0.64330800E+01, -.90184200E+01, -.74829800E+01, -.89199200E+01, 0.71279700E+01, -.89832800E+01, 0.80717700E+02, -.40641000E+02, -.12559500E+02, -.40426700E+02, 0.29540400E+02, 0.67481900E+02, -.60207000E+02, -.19360200E+02, -.48837400E+02, 0.60410700E+02, -.12721300E+03, 0.91007200E+02, -.44181700E+02, -.51413500E+02, -.45495700E+02, -.13551000E+02, 0.35047000E+02, -.23194400E+02, 0.13299800E+02, -.34882700E+02, 0.30900000E+02, -.70520200E+02, 0.62198500E+01, -.31978000E+01, -.43929500E+02, -.32416300E+01, -.19828400E+02, -.19160400E+02, -.41004200E+02, -.32779700E+02, -.24101200E+02, -.38670800E+01, -.99652100E+02, 0.45500000E+02, -.24261100E+02, 0.10663100E+02, -.22661100E+02, -.18016000E+02, -.38022900E+02, 0.18749700E+02, 0.53505200E+02, 0.56813600E+01, -.32329800E+02, -.60739100E+02, -.25593300E+00, -.13382700E+00, -.38892200E+00, 0.11280700E+00, 0.23066900E-01, -.56583400E+00, -.22731200E+01, 0.21189300E+01, 0.52313600E+00, -.80258400E+00, -.18376800E+01, 0.93802900E+02, -.45812600E+02, -.26016300E+02, -.46964600E+02, -.86233700E+00, 0.30910100E+02, -.40042100E+02, -.87756800E+01, -.46591200E+02, 0.23639500E+02, -.45926300E+02, 0.16386100E+03, -.81419600E+02, -.12109300E+03, -.81895400E+02, -.24429800E+02, 0.47165500E+01, -.43979100E+01, 0.10612300E+03, -.20185000E+02, -.72896100E+01, 0.27113800E+02, -.10678300E+02, 0.51543100E+01, 0.70194900E+01, 0.52957600E+01, -.77279200E+01, 0.14606200E+02, -.23520800E+02, -.77193000E+02, -.50101300E+02, 0.20895000E+02, -.16458300E+02, -.21378700E+00, 0.16858500E+00, 0.33675000E+01, 0.59746900E+01, 0.32624200E+01, -.36092200E+01, -.25320200E+01, -.38493100E+00, -.17942800E+00, 0.80620700E+00, -.21036600E+01, -.25524800E+01, -.18305800E+02, -.38576000E+01, 0.52884800E+01, -.93105000E+00, -.53296600E+01, 0.35342000E+01, 0.21132200E+02, -.10119000E+01, -.14816100E+02, 0.11731300E+01, -.19872800E+00, -.21123200E+00, -.19866600E+02, -.13499700E+02 },
        { -.14812100E+00, 0.47143400E+00, 0.81102200E+00, -.31002000E+00, 0.73135500E-01, 0.90856200E-01, 0.51536200E-01, -.66491500E+00, -.41492800E+00, 0.47540600E+00, 0.16832500E+00, -.44970900E+00, -.11840700E+00, -.51199700E+00, 0.18415900E+00, 0.27595600E+00, -.11466200E+01, -.90609200E-01, 0.12605300E+00, -.47864300E-01, -.10608400E+01, 0.34120300E+00, -.19107800E+00, 0.93000300E-01, 0.26416700E+00, 0.24694700E+00, 0.42313900E+00, -.46419000E+00, -.23871600E+00, -.49823600E-01, -.23909400E-01, 0.91000900E-01, 0.74658500E+00, -.45496700E+00, 0.71549900E-01, 0.10471700E+00, 0.14464300E-01, 0.47255300E+00, 0.39375600E-01, 0.11994500E+00, -.45698800E+00, 0.13762900E+01, 0.21881700E+01, 0.63983400E+00, 0.23735900E-01, -.11122500E-01, -.15584800E+00, 0.14427400E-01, 0.25950500E+00, -.39957700E+00, 0.24887100E+00, -.72919200E+00, -.18557100E+00, 0.17357900E+01, 0.14722800E+00, -.28098100E+00, 0.28853600E+00, 0.55639600E-01, 0.74492600E-01, -.97821100E-01, -.15003200E+00, 0.99112400E-01, -.11990400E+00, 0.27712300E+00, 0.20378200E-01, 0.13588500E+00, -.10325100E+00, -.45575200E+00, 0.31543400E+00, 0.37726500E-03, -.50261900E+00, -.92394600E+00, -.77826000E-01, -.37567900E-01, 0.72953700E-01, -.93242700E-01, -.11961800E+00, -.86052900E-01, -.15249000E+00, 0.16939300E+00, 0.11212900E-01, -.68603100E-01, 0.20908700E+00, -.43773900E-02, 0.65003000E-01, -.11821200E+00, -.32841400E+00, -.17310700E+00, 0.49718200E-01, 0.21716100E-01, 0.32355900E+00, 0.67517800E-01, 0.23837900E+00, -.55328400E+00, 0.16597600E-01, 0.79793500E+00, -.24185700E+00, -.18847200E-01, -.55013500E+00, -.23132300E+00, -.12276300E+01, -.41191600E+00, 0.19959900E-01, -.86537300E-01, 0.15289700E+00, -.29984400E+00, -.57457800E-01, -.78120800E+00, 0.68247800E+00, -.42658000E+00, 0.17543500E+00, -.77616500E-01, 0.27970200E-02, -.24444100E-01, -.48884700E-01, -.55104800E+00, 0.86822200E-01, 0.38264400E+01, 0.62737800E+02, -.34385500E+02, -.29460200E+02, -.48722000E+03, 0.24230000E+03, -.64611800E+03, 0.24403800E+03, -.42575700E+02, 0.56138400E+02, 0.12460800E+03, 0.60983200E+03, 0.62043700E+03, 0.52394600E+02, 0.31616800E+03, 0.17996300E+03, -.85685400E+02, -.65848100E+02, -.90007500E+02, 0.35119900E+02, -.39015300E+02, -.79777600E+02, 0.14711100E+03, 0.14221700E+02, -.41094900E+02, -.99216500E+02, -.69807800E+03, 0.31904100E+03, 0.15936200E+03, 0.34740200E+03, -.28528100E+01, -.12967300E+03, 0.43217000E+03, 0.17776800E+03, 0.32072800E+03, -.13006500E+03, 0.36011000E+03, 0.47203400E+03, -.23537100E+03, -.21681300E+03, -.23399300E+03, -.20572800E+03, -.11926400E+03, 0.29974600E+03, 0.41749000E+02, -.28532900E+03, -.39552000E+02, 0.32015900E+03, 0.20655400E+01, 0.13051000E+01, -.12475900E+03, -.15684300E+01, -.83407300E+02, -.15729100E+03, 0.12522600E+03, 0.15337400E+03, 0.15033400E+03, -.96900600E+02, 0.42190800E+01, -.87609600E+02, 0.41470300E+02, 0.18364100E+02, 0.44021000E+02, 0.23036500E+02, -.91888000E+01, 0.16654200E+02, 0.29288900E+00, 0.19819600E+02, -.10843000E+02, 0.60704100E+02, 0.82865000E+03, -.41534900E+03, -.70325600E+03, -.41361700E+03, -.11750400E+02, -.32308600E+03, -.12943800E+03, 0.42676900E+03, 0.59809700E+02, -.24863700E+03, -.63422600E+02, -.25138500E+03, 0.12997600E+03, 0.12254400E+03, 0.12557100E+03, -.43450900E+02, -.21876800E+03, 0.21135200E+03, 0.18017100E+03, 0.30719200E+03, -.18475800E+03, 0.18927500E+03, 0.14703400E+04, -.73828600E+03, -.36396400E+03, -.73380100E+03, 0.59751500E+03, 0.38672500E+03, -.42431400E+03, 0.48130400E+03, -.19112800E+03, 0.26742200E+03, -.34376800E+03, -.54915500E+03, 0.28332000E+03, -.27534400E+02, 0.27352600E+03, 0.23098500E+03, 0.30145900E+03, -.15277800E+03, -.22808400E+03, 0.53149400E+02, 0.27799700E+03, 0.38550500E+03, 0.11973600E+01, -.36241500E+00, 0.25789400E+01, -.43991900E+00, -.14537900E+01, 0.44673600E+01, 0.73741500E+01, -.95330100E+01, -.49190600E+01, 0.55269200E+01, 0.10356300E+02, -.67966500E+03, 0.33622900E+03, 0.12959900E+03, 0.34044500E+03, -.21231600E+02, -.20112200E+03, 0.37634800E+03, 0.23421700E+03, 0.37365100E+03, -.16075600E+03, 0.23710900E+03, -.84749600E+03, 0.41832500E+03, 0.78135500E+03, 0.42337700E+03, -.11701500E+03, -.20801000E+03, -.27801500E+02, -.93766700E+03, -.24441000E+03, -.18857200E+03, 0.35890000E+03, 0.34760900E+03, -.16851100E+03, -.28555600E+03, -.17334700E+03, 0.12228400E+03, 0.12975800E+02, 0.98615900E+02, 0.70544100E+03, 0.47832500E+03, -.18329200E+02, -.42368400E+03, -.62964300E+00, 0.27110100E+02, -.17737000E+02, -.28808000E+02, -.42622200E+02, 0.16005700E+02, -.33479500E+01, 0.33869800E+02, 0.72198700E+00, 0.13451200E+01, -.53998600E+00, 0.29332000E+02, 0.10016400E+03, 0.58850000E+02, -.42895100E+02, 0.42965200E+02, -.12337000E+02, -.82432800E+01, -.85548700E+02, 0.51552200E+01, 0.65011200E+02, -.47199400E+01, 0.49654200E+00, -.15849100E+02, 0.22398800E+03, 0.10750900E+03 },
        { -.68165600E+00, 0.31003200E+00, -.52072000E+01, -.34207500E+00, 0.23153000E+01, 0.11337900E+01, 0.32256200E+01, -.33661300E+01, -.32234300E+00, 0.13742800E+01, 0.75872100E+00, -.38287500E+01, -.16927700E+00, -.13586800E+01, 0.47801900E+00, -.41856500E+00, 0.11783300E+00, 0.41255500E+00, -.27553100E+01, 0.26168700E+00, -.14580700E+01, 0.77122700E+00, -.36078500E+00, -.32491000E+01, -.10743400E+01, -.59939600E+00, -.20772300E+01, 0.76441000E+00, -.16246200E+00, 0.18796400E+00, -.14744700E+01, -.16764800E-01, 0.40580300E+00, 0.19869000E+01, -.70045600E+00, 0.79118500E+00, -.13557400E+00, 0.35407400E+01, 0.75093500E+00, 0.20390400E+01, -.65656900E+00, -.49461200E+01, -.13786500E+01, 0.73499900E+00, 0.47131100E+01, 0.75446900E+00, -.21412500E+01, -.96208600E-02, 0.29227200E+00, -.13102500E+00, 0.14577200E+01, -.67829200E+00, 0.84296200E+00, -.22851200E+01, 0.35242200E+00, 0.36154000E+00, 0.30968100E+01, -.94508200E+00, 0.16012500E+00, 0.23709200E+00, 0.10412500E+01, -.78243800E+00, 0.17767200E+01, -.31818600E+00, 0.52823900E-01, 0.33721900E+00, 0.66050200E+00, 0.88429100E+00, 0.48632700E+00, -.15580400E-02, -.35803500E+01, -.29998800E+01, -.63767100E-02, -.49125900E+00, -.13738200E+01, 0.63940900E+00, 0.30104700E+00, -.15280400E+00, 0.81529900E+00, -.72146400E+00, -.27936000E-01, 0.57610200E+00, 0.40071200E+00, -.84542900E+00, -.58352800E+00, -.14361700E+00, 0.19758000E+01, 0.10768100E+01, 0.31062500E+01, -.62754000E+00, 0.16533000E+01, 0.11419100E+00, -.82955100E+00, 0.45524000E+00, 0.12024400E+01, 0.14686600E+01, -.18671900E+01, 0.72011000E+00, -.20703200E-01, -.20835500E+00, -.39270200E+01, -.96957700E+00, 0.95992000E-01, -.17344900E+00, 0.55168700E+00, 0.43127700E+00, 0.53065200E+00, -.10781400E+01, -.17923800E+01, -.13671000E+01, 0.78535900E+00, -.18076200E+01, 0.70765800E+00, 0.80318300E-02, -.91917400E-01, -.10208300E+01, 0.16259600E+00, 0.84868600E+01, 0.72477800E-01, 0.99206300E+02, -.19473700E+03, 0.41742800E+03, -.20118200E+03, 0.64343200E+01, -.20810200E+03, -.14931400E+03, -.28109900E+03, 0.37607800E+03, 0.10032500E+04, 0.13828300E+03, -.23703900E+03, -.57072300E+03, 0.59998000E+03, -.29348300E+03, -.18145400E+03, -.30009700E+03, -.20779900E+03, -.67443400E+02, 0.51051100E+02, 0.24479200E+03, -.13215600E+03, -.16852500E+02, -.27462000E+03, -.18511200E+04, 0.98930500E+03, -.14753400E+02, 0.92453000E+03, 0.30134700E+03, 0.26533700E+03, 0.44810100E+03, -.27636500E+03, 0.42711100E+03, 0.28965300E+03, 0.30724800E+03, -.26155400E+03, 0.12261900E+03, 0.35426100E+03, 0.13355900E+03, 0.25815600E+03, 0.17192600E+03, -.15650000E+03, -.66016700E+03, -.17293700E+03, 0.72853800E+02, -.16497500E+03, 0.25951100E+03, -.99810800E+02, 0.13067500E+03, -.13048600E+03, -.21473900E+03, -.46388700E+03, -.14204900E+03, 0.12355700E+03, 0.42663700E+03, -.44859900E+03, 0.19715900E+02, 0.38560100E+02, -.20816300E+02, -.67594300E+02, -.18978900E+02, -.74974600E+02, -.90489600E+02, 0.10883000E+03, 0.62672000E+02, 0.12518100E+03, -.92768600E+02, 0.15983600E+02, -.23725500E+04, 0.11836800E+04, 0.15076400E+04, 0.11872400E+04, -.17324300E+02, -.67259400E+01, 0.67711700E+03, -.88406200E+03, 0.10398900E+04, -.12200900E+03, 0.10616600E+04, 0.10959300E+04, -.54082000E+03, -.28375900E+03, -.54823100E+03, 0.57642800E+02, 0.25559300E+03, -.50911500E+03, -.33015700E+03, -.42883500E+03, 0.23571700E+03, -.81246600E+03, -.25061700E+04, 0.12502400E+04, 0.91128100E+03, 0.12549500E+04, 0.69192300E+03, -.28030000E+03, 0.10436900E+04, -.53552000E+03, 0.14733300E+04, -.35464400E+03, 0.14154200E+04, -.62242500E+02, 0.13332900E+02, 0.88124800E+02, 0.29977100E+02, 0.97194700E+02, 0.17538200E+03, -.19143000E+03, -.22260900E+03, -.37491000E+03, 0.20413100E+03, 0.14126300E+03, -.68139800E+01, 0.24597100E+01, 0.59589500E+01, 0.36265200E+01, 0.19357300E+01, -.41028700E+01, 0.29227100E+02, 0.67017500E+01, 0.48510800E+01, -.26698300E+01, -.72532200E+01, 0.89541900E+02, -.31048700E+02, -.20237300E+03, -.44064400E+02, -.87972000E+02, -.85882700E+02, 0.95300800E+02, 0.27757300E+03, 0.28572900E+03, -.92822300E+02, -.61918500E+02, -.10922400E+04, 0.53863300E+03, 0.12947100E+03, 0.54560400E+03, -.12295800E+03, 0.11087800E+03, 0.32121600E+03, -.53444200E+03, 0.95992900E+02, 0.41160700E+02, 0.16324600E+04, -.49689500E+03, 0.24748000E+03, 0.40641500E+03, 0.24909000E+03, 0.59656300E+01, 0.42217600E+02, -.40083800E+03, -.18286500E+03, 0.24492100E+03, 0.83767700E+02, -.47655400E+03, 0.13562500E+01, -.10255100E+03, -.38909600E+02, 0.63527000E+01, -.14508700E+02, 0.30677800E+02, -.13709400E+02, -.10594400E+03, -.96454600E+00, -.50915000E+01, 0.72843700E+01, 0.20331600E+02, 0.20559000E+03, -.15177200E+02, -.59869700E+02, -.48968900E+02, 0.47673600E+02, -.37369100E+02, -.35353600E+03, 0.47048600E+02, 0.34746200E+03, 0.23676100E+02, 0.11833300E+01, -.35102100E+02, 0.12079000E+03, 0.94881500E+02 },
        { 0.25382600E+00, 0.97100900E+00, -.93437500E+00, 0.83991200E+00, -.60224300E+00, 0.10215200E+00, -.15924700E+00, 0.14044400E+01, 0.41198500E+00, -.48841000E-01, 0.53625700E-01, -.63159600E-01, -.86281400E-02, 0.14582800E+00, -.70990700E+00, 0.43238800E+00, 0.67065200E+00, 0.15229100E+00, -.13741400E+01, 0.42929600E+00, -.51037100E+00, -.27987700E+01, 0.10443900E+00, 0.10622300E+00, -.49782400E+00, -.55241200E+00, -.20477100E+00, 0.65835900E+00, -.41119500E+00, -.76489800E+00, -.28534000E-01, -.41727300E+00, 0.53380200E+00, 0.30975500E+00, 0.70093300E-01, -.38585100E+00, 0.54378100E-01, 0.23881300E+00, 0.41567600E+00, -.62389600E+00, 0.44501500E+00, -.11483000E+01, -.21650100E+01, 0.75626900E-01, 0.75557000E+00, 0.28555000E+00, 0.86036600E+00, 0.57905400E-01, 0.46060600E+00, 0.85219700E-01, 0.15869400E+00, -.17287200E+00, 0.32076800E-02, -.19761100E+01, -.71886700E+00, 0.14421900E+00, 0.27414000E+00, 0.19990700E+00, -.66002100E-01, -.91149800E+00, -.10924900E+00, -.86161600E-01, 0.26213600E-01, 0.38669700E+00, -.12570800E+00, 0.20705200E+00, -.15785500E+00, -.76058200E+00, 0.81716000E+00, -.53959100E-02, 0.81085900E+00, -.80000500E+00, -.26077500E+00, 0.25145000E-01, 0.45567900E+00, -.83525400E+00, -.36421000E-01, -.17993300E+00, 0.84125600E-01, 0.54538200E+00, 0.14843500E-01, -.49677900E-01, -.11230200E+00, 0.31280600E+00, 0.10945000E+00, -.23040000E+00, 0.65378500E+00, -.68107300E+00, -.48174900E+00, -.36225200E+00, 0.12997100E+01, 0.95322900E-01, -.64360000E+00, -.26249200E+01, 0.80481500E+00, 0.17895800E+01, 0.30194500E+00, -.20033100E+00, 0.92886100E+00, 0.16027300E+00, -.17218500E+01, -.53627600E+00, 0.23776700E-01, 0.79420300E+00, 0.64591100E+00, -.13479900E+01, -.74436500E+00, -.34092000E+00, 0.89400700E+00, 0.53593700E+00, 0.11619300E+01, -.95127200E-01, 0.44858700E+00, -.96401800E-02, 0.20779400E+00, -.10356100E+00, -.11246900E+00, 0.26727900E+01, 0.42032900E+00, -.25720800E-01, -.21350200E+03, 0.12391700E+04, -.61662000E+03, -.61933800E+03, -.61937000E+03, -.16704800E+03, 0.17191900E+03, -.27834000E+03, 0.41013300E+02, -.62431800E+03, 0.10483400E+03, -.37586000E+03, -.17179400E+03, 0.79439800E+02, 0.89884900E+02, 0.85888700E+02, 0.51390400E+02, 0.13996000E+03, 0.43551300E+02, 0.85293600E+02, 0.70309000E+02, 0.11492100E+03, -.20861500E+01, 0.31984800E+03, -.17198600E+03, -.26707100E+03, -.16060600E+03, -.87121400E+02, -.10928200E+03, 0.46835200E+02, 0.23765400E+03, 0.36586800E+02, -.12412900E+03, 0.15595600E+03, -.69738600E+02, 0.36688300E+02, 0.48527100E+03, 0.35892400E+02, 0.20152700E+03, 0.30929300E+02, -.10909700E+03, -.36691200E+03, 0.47922200E+02, 0.39296900E+02, -.25923500E+03, 0.13276800E+02, -.30949500E+02, -.20258400E+02, -.69056800E+01, 0.52620600E+02, 0.74173500E-01, -.79030700E+02, -.19087300E+03, -.22219300E+02, 0.41362400E+02, 0.71374800E+01, -.48358800E+02, 0.26257300E+02, 0.77139400E+01, 0.24288100E+02, -.51080600E+01, -.19816600E+02, 0.99238200E+01, -.21813200E+02, 0.33195800E+02, -.11989700E+02, 0.25705500E+02, -.27635700E+04, 0.13848600E+04, 0.12107100E+04, 0.13821400E+04, 0.12831100E+03, -.19528400E+03, 0.57230700E+03, -.86355300E+03, 0.56466600E+03, -.11115800E+03, 0.19027800E+03, -.20013200E+03, 0.93501900E+02, 0.28026000E+03, 0.10001000E+03, 0.13430000E+03, 0.20207800E+01, -.89862000E+02, -.27537200E+03, -.16495300E+02, 0.28475600E+02, 0.67120400E+02, -.21817000E+04, 0.10944700E+04, 0.14036800E+04, 0.10915500E+04, -.36327500E+02, -.22469000E+03, 0.56902800E+03, -.71929000E+03, 0.34919000E+03, -.14874800E+03, -.65141200E+02, -.20780600E+01, 0.37242300E+01, 0.98198700E+02, 0.39288100E+00, 0.10554000E+03, -.42563500E+02, -.83071200E+02, -.15122200E+03, 0.89807000E+01, -.20719800E+02, -.23375300E+03, 0.20062400E+01, -.29356700E-02, 0.62278400E+01, -.92317900E+00, 0.24284000E+01, 0.15371000E+01, 0.45768300E+01, 0.34028900E+00, -.30887800E+01, 0.11737100E+01, -.62042300E+01, -.22773000E+02, 0.67079200E+01, -.80906800E+02, 0.11708600E+02, 0.69444500E+02, 0.43103300E+02, -.90811900E+02, -.15491000E+03, -.44449700E+02, 0.68745300E+02, 0.69686600E+02, -.49299000E+03, 0.24825400E+03, 0.14851800E+03, 0.24630800E+03, 0.23025300E+02, 0.11784400E+03, 0.25739200E+03, 0.45838300E+03, 0.51193300E+03, 0.86432600E+02, 0.15917600E+03, -.50982700E+03, 0.25415100E+03, 0.91900000E+02, 0.25514300E+03, 0.98420600E+02, -.16641300E+03, -.94564800E+02, -.61520000E+03, -.14930500E+03, -.74936900E+02, 0.16925400E+03, -.35274400E+01, 0.50975200E+01, -.23137600E+02, 0.57338400E+01, 0.10285200E+02, 0.16505900E+02, 0.80544300E+01, 0.22134200E+01, 0.33176200E+01, 0.41400800E+01, 0.16446700E+02, 0.16480000E+02, 0.16589100E+02, -.34528000E+00, -.37887000E+02, -.39759700E+02, 0.39760400E+02, -.19678300E+02, 0.23985100E+02, 0.26383400E+02, 0.61709600E+01, -.16993500E+01, 0.30628400E+01, 0.54991500E+01, -.12121100E+03, -.50506500E+02 },
        { -.15410900E+00, 0.42750400E+00, -.63341600E-02, -.19092000E+00, 0.41531500E+00, 0.15159400E+00, 0.70745000E+00, -.67645400E+00, -.29603000E+00, 0.39612800E+00, 0.94041500E-01, -.79777800E+00, 0.15389300E+00, -.53133400E+00, 0.36681700E-01, 0.83195000E-01, -.98497400E+00, 0.11050400E+00, 0.15222200E+00, 0.11875400E+00, -.35340200E+00, -.14339700E+01, 0.85578000E-01, 0.43523700E-01, -.29016900E+00, 0.27908900E-01, -.65323800E-01, -.50232900E+00, -.25717600E+00, 0.46110000E+00, 0.18641300E+00, 0.32820200E+00, 0.61836900E+00, -.73719800E+00, 0.78498400E-01, -.12053200E+00, 0.17944200E-01, -.41699100E+00, 0.96962000E-01, -.20601800E+00, -.52361600E+00, 0.85638900E+00, 0.18565500E+01, 0.23643900E+00, -.69483000E+00, -.91581800E-01, -.36150000E+00, -.40691600E-01, 0.39322600E-01, -.31072200E+00, -.12517300E+00, 0.56153800E-01, -.25921600E+00, 0.26408200E+01, 0.96744400E-01, 0.13980000E+00, -.33590800E+00, -.25309100E+00, 0.13347900E+00, -.15745100E+00, 0.19158200E+00, -.12405200E+00, 0.34538900E-01, -.57808600E-01, -.56961300E-01, -.31362800E-01, -.71002000E-01, 0.48700400E+00, 0.20717300E+00, 0.30767900E-02, -.64395600E+00, -.31695400E+00, -.78313900E-01, -.30009200E-01, 0.76981400E-01, 0.10521200E+00, -.13936900E+00, 0.11852900E-01, -.10095200E+00, 0.50237700E-01, 0.96154100E-02, -.53176200E-01, -.13456100E+00, -.72856300E-02, 0.61131300E-01, -.13454100E-01, -.21732500E-01, -.23744500E+00, -.35786700E+00, 0.84053100E-01, -.69620700E-01, 0.88973700E-01, 0.39883100E+00, -.29198200E+00, -.14684800E+00, 0.15334400E+00, 0.20512300E-01, 0.38129900E+00, -.26351600E+00, -.25005400E+00, 0.21062000E+01, -.53102700E+00, -.25075800E-01, 0.23997300E+00, -.84396700E-02, 0.37199600E+00, -.13623100E+00, -.47701300E-02, -.45862800E+00, -.85937300E-01, 0.40641900E+00, 0.50612800E+00, -.21702200E-01, -.15489600E-01, -.13902800E+00, -.10012100E+00, 0.18775600E+00, -.83918700E+00, -.43351800E-01, 0.40877100E-01, -.12147900E+00, 0.95752600E+03, -.47478000E+03, -.33428300E+03, -.47872700E+03, -.36417300E+02, 0.11274300E+03, -.32587700E+03, -.21061800E+03, -.53598500E+03, 0.98523100E+02, -.51554000E+03, 0.61407200E+02, -.31917200E+02, 0.26224700E+02, -.30710500E+02, 0.16814600E+02, 0.26530800E+02, 0.69447300E+01, 0.40088900E+02, -.34597100E+02, 0.34800400E+02, -.53406000E+02, -.40088700E+02, 0.98576700E+01, -.81812700E+02, 0.19883000E+02, 0.45195300E+01, -.21675300E+02, 0.56191700E+02, 0.88773500E+02, 0.55402800E+02, -.14026400E+02, 0.60795900E+02, -.24464100E+03, 0.12111900E+03, 0.24582400E+03, 0.12248500E+03, 0.13840700E+03, 0.37446900E+02, -.70736800E+02, -.21589100E+03, 0.14950600E+03, 0.18709300E+02, 0.13262700E+03, -.18944000E+02, 0.15361200E+01, 0.31884700E+02, 0.94308500E+01, -.71078400E+00, -.64642400E+02, -.47129600E+02, -.15393900E+03, 0.40827000E+02, -.54048900E+02, 0.68858300E+01, -.25582200E+02, 0.13071400E+02, -.17821400E+01, 0.12808800E+02, 0.11261400E+02, 0.25480800E+01, 0.23356800E+00, 0.12390600E+01, 0.20627000E+01, 0.81923900E+01, 0.17532400E+02, 0.17191900E+03, -.85923700E+02, -.18868900E+03, -.85902000E+02, -.40382000E+02, -.26131100E+03, 0.84330700E+02, 0.19430100E+03, 0.87776100E+02, -.24688000E+03, -.28952700E+02, -.20670400E+03, 0.10085200E+03, 0.13293800E+03, 0.10333500E+03, 0.64253700E+02, 0.16605600E+02, -.27248000E+01, -.50939200E+02, 0.46174300E+02, -.10116900E+01, 0.14184300E+03, 0.57325500E+03, -.28720000E+03, -.14109400E+03, -.28651700E+03, 0.11498800E+03, -.15145300E+03, -.10511700E+02, 0.23114800E+03, -.62103000E+02, -.16189100E+03, -.19151000E+03, -.24211800E+03, 0.12364000E+03, -.23027100E+02, 0.12106100E+03, 0.10919200E+03, 0.83324700E+02, -.14097300E+02, -.75102300E+02, -.16220600E+02, 0.48138100E+02, 0.12021200E+03, 0.30008600E+01, -.97643200E+00, 0.83433200E+00, -.14875100E+01, 0.14515600E+01, 0.17760400E+01, -.53986300E+01, -.30028100E+01, -.10363200E+01, 0.14959300E+01, -.17587100E+01, -.12936600E+03, 0.64965200E+02, 0.28409200E+02, 0.64724900E+02, 0.42094300E+02, 0.16510700E+02, -.78232500E+01, -.95342300E+02, 0.22911200E+02, 0.22649300E+02, 0.59710000E+02, -.23562400E+01, -.11182700E+01, -.36613400E+02, 0.11476900E+01, -.46113000E+02, 0.70185000E+02, 0.19427200E+03, 0.37877900E+03, 0.93985700E+02, 0.90730900E+02, 0.22459000E+01, -.19075700E+03, 0.96033500E+02, 0.74151900E+02, 0.95416500E+02, 0.77593100E+02, -.40096100E+02, -.10928000E+03, -.20650400E+03, 0.10014100E+03, -.65007700E+02, 0.10495400E+03, -.64032100E+00, 0.31288200E+01, -.19491200E+02, -.50969000E+01, -.13118100E+02, -.43029200E+01, -.22484700E+01, 0.50194300E+01, 0.71137700E+00, 0.16185100E+01, -.32764200E+01, -.80720500E+01, -.33841400E+02, 0.38596200E+01, 0.20363100E+01, -.22277500E+02, 0.32068000E+02, -.84354300E+00, -.14187400E+02, 0.35713800E+01, 0.77628100E+01, 0.43745500E+01, 0.18939100E+00, -.23807300E+01, -.88786400E+02, -.15876200E+02 },
        { -.46908100E+00, -.26153900E+01, 0.81352600E+00, -.37842300E+00, 0.10623500E+01, 0.29108100E+00, 0.36951900E+00, -.55227200E+00, -.64224000E+00, -.10104600E+00, 0.38617000E+00, -.48326900E+00, -.74092500E+00, -.55652500E+00, -.12120100E+01, -.72051400E+00, 0.10236100E+01, -.87868900E-01, 0.88227900E+00, -.70448600E+00, 0.19248600E+01, -.11016200E+01, -.40747100E+00, -.10123800E+01, 0.11690100E+00, 0.18289900E+00, -.15449500E+00, -.10838300E+01, -.24766200E-01, 0.57181500E+00, -.83216100E+00, 0.21905100E+00, 0.35612500E+00, -.40165600E+00, 0.62075300E+00, 0.67099700E+00, -.40105300E-01, 0.76889100E+00, -.27474300E+00, -.13204800E+00, 0.14671700E+00, -.12578400E+01, -.12469800E+01, -.99366200E+00, -.34475800E+00, -.66482100E-01, -.12766600E+00, -.32957400E-01, -.12488500E+00, 0.90994000E-01, -.96437100E+00, 0.10930200E+01, -.10398400E+01, 0.91089700E+00, 0.64871600E+00, 0.14245200E+01, 0.80435400E+00, 0.45891500E+00, 0.18547600E+00, 0.92998800E+00, 0.39799600E+00, -.12190600E-01, 0.10505600E+00, 0.26642500E-01, -.13072600E+00, 0.66924700E+00, -.20834800E-01, -.13087900E+00, 0.41687100E+00, -.94827100E-03, -.19768800E+01, -.21889100E+01, -.34351200E-01, -.28433400E+00, 0.11701100E+01, 0.26998600E-01, -.33508000E+00, -.72582900E+00, -.84820800E+00, 0.45324200E+00, 0.32587300E-01, -.28168100E-01, -.63784800E+00, -.43077400E+00, -.73218600E-01, -.89048400E+00, 0.18217200E+01, 0.45031700E+00, 0.11512000E+01, 0.19696100E+00, 0.90141300E+00, 0.11894700E+00, 0.17809900E+01, -.27187500E+01, -.56491800E+00, 0.87487100E+00, 0.18012600E+01, 0.26602300E+00, -.71023500E+00, -.30600800E+00, -.14494200E+01, -.95630800E+00, 0.35295700E-01, 0.29985500E+00, 0.56393500E+00, -.93568500E+00, -.94345000E+00, -.68745200E+00, 0.12712400E+01, 0.18043500E+01, 0.64342300E+00, 0.18018900E+01, 0.32618200E+00, -.38257100E+00, -.20322500E+00, -.95772600E-01, -.20858900E+00, 0.17850100E+01, 0.60585100E+00, -.10688500E-01, 0.20385500E+00, -.69575700E+00, -.27739200E+02, -.38581000E+03, 0.11213500E+01, -.79317900E+02, 0.11815600E+03, -.22754700E+03, -.37764000E+03, -.13430000E+03, 0.79558200E+02, 0.65219600E+03, 0.10267200E+03, -.27008300E+02, -.72586900E+02, -.51362900E+02, -.10848900E+03, -.75842900E+02, 0.53612200E+02, 0.83093500E+01, -.18002500E+02, -.12162900E+02, -.32708900E+01, -.67887300E+03, 0.28159900E+03, -.11293100E+03, 0.33573100E+03, 0.19527100E+03, 0.15451100E+02, -.19643800E+01, -.13741000E+03, 0.20304300E+03, 0.34581400E+02, 0.25960600E+03, 0.14208100E+03, -.78833700E+02, 0.80430200E+02, -.65603100E+02, -.63777200E+02, -.13238000E+03, 0.51809900E+02, 0.24147600E+03, 0.92876900E+02, -.15557100E+03, -.16311600E+03, -.30473800E+03, 0.21931400E+03, -.14949800E+03, 0.15098300E+03, -.10679100E+03, -.15811000E+03, 0.44669900E+02, -.40540200E+02, 0.13162500E+03, -.19090700E+03, 0.21234300E+03, 0.38874400E+02, -.25270900E+02, 0.27394400E+01, -.18862700E+02, -.17377800E+02, -.15329700E+02, 0.46562300E+02, 0.27394000E+02, -.88919500E+01, -.14389500E+02, -.45990100E+02, 0.11615900E+03, -.59751600E+02, 0.20411800E+02, -.56171200E+02, -.44366700E+03, -.41745500E+03, 0.92205800E+03, 0.28500300E+03, 0.20891200E+03, -.44931600E+03, -.84862300E+03, 0.82287600E+02, -.22812000E+02, -.96502200E+02, -.41428700E+02, -.72916500E+02, -.16281200E+03, 0.15157700E+03, 0.87858800E+02, 0.47111100E+01, -.21759100E+03, 0.66563600E+02, 0.21060600E+03, -.10316600E+03, -.19623200E+03, -.10159800E+03, -.67633400E+03, -.66174700E+03, 0.99268800E+03, 0.17545400E+03, 0.21412500E+03, -.64195900E+03, -.97043900E+03, 0.35286400E+03, -.16139300E+03, -.35775300E+02, -.18048100E+03, -.18806500E+03, -.40229300E+02, 0.13087200E+03, 0.71776600E+02, -.12433200E+03, -.10967100E+03, -.53509800E+02, -.31871900E+00, -.44307500E+01, -.15666100E+01, 0.58225400E+00, -.26609100E+01, -.24586200E+01, -.62954500E+01, 0.14293600E+01, 0.21118300E+00, -.11380900E+01, 0.18296200E+01, -.27079500E+03, 0.12458900E+03, -.26669600E+02, 0.13715800E+03, -.21065100E+02, -.79680000E+02, -.25921400E+02, -.11682500E+03, 0.58531100E+02, -.71182700E+02, 0.22802000E+03, -.91882200E+02, 0.51563100E+02, -.16070000E+03, 0.44953800E+02, 0.17651400E+03, 0.64024700E+02, 0.19112600E+03, 0.13920100E+03, 0.71748600E+02, 0.10970200E+03, -.69120000E+03, -.12413500E+03, 0.62070000E+02, 0.20092100E+03, 0.63279200E+02, -.95584200E+01, 0.12346600E+03, -.15899900E+03, 0.75022000E+02, -.13794200E+03, 0.10620700E+03, 0.48758300E+03, -.27185500E+01, -.19914200E+02, 0.72912800E+01, -.35238300E+01, 0.46344000E+02, 0.16630900E+01, 0.19139600E+02, -.27359800E+02, 0.21565100E+00, -.30679000E+01, 0.81466900E+01, -.12107800E+02, -.57759000E+02, -.48737300E+02, 0.14409200E+02, 0.32698900E+01, 0.34212800E-01, 0.44899200E+01, -.34116300E+02, -.33542200E+02, -.58621600E+01, -.28284500E+01, -.12489300E+00, 0.69704700E+01, -.29814900E+02, 0.25798400E+01 },
        { 0.12723000E+00, -.44649500E+00, -.12443900E-01, 0.12700900E+00, -.32690500E+00, -.12313300E+00, -.43071300E+00, 0.41246000E+00, 0.10977200E+00, -.46529900E+00, -.40924700E-01, 0.11663000E+01, -.14595900E+00, 0.59188200E+00, -.38570900E+00, -.91129000E-01, 0.80886500E-02, -.33384900E-01, -.15612900E+01, 0.91405700E+00, -.10667800E+00, 0.77726200E+00, 0.50366700E-01, -.46085500E+00, -.11496800E+00, -.12855900E+00, -.33286800E+00, 0.45171700E+00, 0.51955300E-01, -.36171500E-01, 0.17062700E+00, -.43333600E-01, -.44086800E+00, 0.67409300E-01, 0.33223200E-02, -.41505700E-01, -.11111600E-01, -.15874900E+00, 0.10695800E+00, -.94173400E-01, 0.21288200E+00, -.72045700E-01, -.52830400E+00, 0.11528800E+00, -.47646600E+00, 0.28391100E-01, 0.46895700E-01, -.41129300E-01, -.21513000E+00, 0.32443800E+00, -.39321200E+00, 0.35126000E+00, -.16187900E-01, 0.34694400E+00, -.10436200E+00, 0.35903600E+00, -.55508500E+00, 0.96077800E-01, -.35139800E-01, -.63044300E-01, -.99147800E-02, -.18408100E+00, 0.61287200E-01, -.36296500E-01, -.31262600E-02, 0.31589000E-01, -.75191100E-02, 0.31631000E+00, -.38490900E-02, 0.65831500E-03, 0.11249500E+00, -.11944500E+00, 0.30443400E-01, -.24101600E-02, -.12967900E+00, -.40604600E+00, -.79168400E-01, 0.56620000E+00, -.15098600E+00, 0.64866600E-01, 0.30247100E-02, -.66808800E-01, 0.48848100E+00, 0.11359200E+00, 0.57517100E-01, -.62049500E-01, 0.97964400E-01, -.46377700E+00, -.27286200E+00, 0.53746600E-01, -.37066200E-01, 0.30596400E-01, 0.34178200E+00, -.10860900E+01, -.87085800E-01, 0.36798500E+00, 0.31198300E-01, 0.20630900E+00, -.56633300E-01, -.20283300E+00, 0.14669300E+01, -.36994000E+00, -.12594100E-01, 0.21235300E+00, 0.49915800E-01, 0.29829800E+00, -.21182300E+00, 0.48545100E+00, -.25365700E+00, -.13569700E+00, 0.48668200E+00, 0.52244300E+00, -.13856600E+00, 0.15947700E-01, 0.41428300E-01, 0.30818500E+00, 0.46742800E-01, -.16498500E+01, -.63891600E+00, -.15795000E+00, 0.19432100E+00, 0.40028700E+00, -.71112100E-01, -.58820000E+03, 0.24940600E+00, -.12928900E+03, -.11607300E+03, 0.93141000E+02, 0.29041500E+03, 0.18093400E+03, -.13852500E+03, 0.29085900E+02, 0.14813500E+03, -.68215100E+02, -.70765300E+02, -.74089000E+02, -.69479100E+02, -.92264400E+02, 0.31943600E+02, 0.16542900E+03, 0.16404800E+02, -.77312900E+02, -.43281000E+02, -.90529400E+03, 0.43117400E+03, 0.19006500E+03, 0.45210000E+03, 0.14740100E+03, 0.60755900E+02, 0.21663700E+03, -.12907700E+03, 0.22718600E+03, 0.56838200E+02, 0.20009700E+03, 0.28183000E+02, -.15929500E+02, -.13489000E+03, -.12917700E+02, -.10192100E+03, -.69432500E+02, 0.11673900E+03, 0.54691400E+02, -.13910400E+02, -.46971700E+02, 0.24712900E+03, -.17514700E+03, 0.97125000E+02, 0.37488500E+02, 0.87267000E+02, -.12959000E+03, -.15491400E+03, 0.80056300E+02, 0.47757900E+02, 0.11642300E+03, -.14529200E+03, 0.10886800E+03, -.11327200E+01, -.18027700E+01, 0.94017100E+00, 0.69183300E+00, -.64445800E+01, -.13382800E+02, 0.27652000E+02, 0.45212700E+02, 0.30181800E+02, -.13700700E+02, 0.22443900E+02, -.37119800E+03, 0.18419900E+03, 0.99379500E+02, 0.18600900E+03, 0.33220600E+02, 0.19612300E+03, -.14317200E+03, -.12058700E+02, 0.10794200E+03, 0.25222500E+03, 0.80882700E+03, 0.14296800E+03, -.66550100E+02, -.11081200E+03, -.71564700E+02, -.64446300E+02, -.72208300E+02, 0.40792000E+02, 0.69121500E+02, 0.79032300E+02, -.70433600E+02, -.53301900E+02, -.27337400E+03, 0.13362200E+03, 0.20584000E+03, 0.13748000E+03, 0.33718200E+03, 0.48181800E+03, -.23920500E+03, -.30359700E+01, 0.97115900E+02, 0.46452500E+03, 0.83907500E+03, 0.78915000E+01, 0.20638100E+01, -.10814400E+02, -.44185700E+01, -.32118300E+02, 0.63457600E+02, -.35023600E+02, -.36036700E+02, -.54200900E+02, 0.77235300E+02, 0.17754200E+03, 0.29382800E+00, -.20554600E+00, -.92436900E+00, -.54913400E-01, -.18762500E+01, -.39610600E+00, 0.33551200E+01, -.51139300E+01, -.20012600E+01, 0.47253600E+00, 0.43760800E+01, -.15316300E+03, 0.75127900E+02, -.36091300E+02, 0.76927000E+02, -.94612200E+02, -.17047000E+03, 0.19092700E+03, 0.19567400E+03, 0.19109500E+03, -.16138600E+03, 0.44927900E+02, -.64318100E+03, 0.31504600E+03, 0.44597100E+03, 0.32137600E+03, 0.11692000E+03, -.72810800E+02, -.66281600E+01, -.33638800E+03, 0.12552200E+03, 0.22411100E+02, 0.44362400E+03, -.15388500E+03, 0.81423800E+02, 0.10460100E+03, 0.77208200E+02, -.56473700E+02, 0.98235900E+02, 0.98161100E+02, 0.18526900E+03, 0.86045100E+02, 0.21183200E+02, -.12335100E+03, -.34940400E-01, 0.45221000E+01, 0.12184200E+02, -.93470100E+01, 0.44977000E+01, 0.31382900E+01, -.94544900E+01, 0.14465800E+01, -.64259000E+00, -.22106600E+01, 0.29925500E+00, 0.38357200E+01, 0.44099100E+02, -.14108000E+01, -.16310700E+02, 0.18863000E+02, -.15580300E+02, -.18797500E+01, -.74669100E+02, 0.64907300E+01, 0.63618100E+02, -.15782000E+00, -.55499500E+00, -.58194800E+01, 0.62480000E+02, 0.36283300E+02 },
        { 0.71656700E+00, -.10396300E+01, 0.76230100E+01, -.73911200E-01, -.43797000E+01, -.45887500E+00, -.54739400E+01, -.54479500E+00, 0.12193800E+00, -.90667500E+00, 0.22200700E-01, 0.64468600E+01, -.61207100E+00, 0.12646700E+01, 0.59777000E+00, 0.60300400E+00, 0.25145500E+01, -.57975300E+00, 0.85928200E+00, -.43040700E+00, 0.18121600E+00, 0.54801200E+01, -.67024600E-01, 0.45579900E-01, 0.85976400E+00, 0.21517600E-01, 0.11168500E+01, 0.13109500E+00, 0.41927600E+00, -.54056600E+00, 0.92525800E-01, -.31782300E+00, 0.13020900E+01, -.66460100E+00, -.21589900E+00, 0.23269000E+00, 0.87142200E-01, -.48112400E+00, -.66247200E+00, -.37947800E+00, -.24440400E+00, 0.74310800E+00, 0.34939500E+01, 0.19683100E+00, -.15824100E+01, -.42897800E+00, -.62095000E+00, 0.10034500E+00, 0.39890500E+00, -.92934900E-01, -.77453700E+00, -.35459200E+00, -.73199800E+00, 0.37327400E+00, -.80745700E-01, 0.34162900E+00, -.85665400E+00, 0.93494200E+00, -.20048300E+00, -.12950000E+01, -.18907800E+00, -.24530600E+00, -.71915300E+00, 0.10698600E+01, -.34782100E+00, 0.45385700E+00, -.14362100E-01, -.50751100E+00, -.37501100E+00, 0.27157000E-03, 0.56326400E+00, 0.27815600E-01, 0.27202600E+00, 0.53413000E+00, 0.27817900E+00, -.43826900E+00, -.40497700E+00, 0.85206300E+00, 0.86893200E-01, -.12425800E+00, 0.20846600E-01, -.11743100E+00, 0.47343400E+00, -.13230300E-01, 0.52380600E-02, 0.42039200E+00, -.13918700E+00, -.10779700E+01, 0.92533500E+00, 0.14723400E+00, 0.42592300E+00, 0.40172700E+00, 0.52367400E+00, -.28445500E+01, 0.22206900E+00, 0.15035100E+01, 0.83797800E+00, -.44476700E+00, -.10300900E+01, -.11174600E+00, 0.23509400E+01, -.54434100E+00, -.55171100E-01, 0.43059900E+00, 0.71792800E-01, 0.10803600E+01, 0.96488700E-02, -.46873200E+00, -.80760000E-01, 0.12574600E+00, 0.87056300E+00, 0.90904600E+00, -.16097500E-01, -.49856900E-01, 0.43956400E-01, -.48600900E+00, 0.22683300E+00, 0.24692400E+01, 0.13712000E+01, 0.29029600E+00, 0.20403200E+00, 0.13473700E+00, -.13965600E-01, -.31987500E+00, 0.34391300E+01, -.17112400E+03, 0.18742100E+03, -.55795800E+02, -.12438100E+03, -.11243400E+03, 0.12764500E+03, 0.10201900E+03, -.35243600E+01, -.38499300E+01, -.22638200E+02, 0.18063900E+01, 0.22377900E+02, 0.55444800E+02, 0.43936900E+02, -.37237600E+02, -.15631200E+02, 0.59338900E+02, -.26667300E+02, -.38869700E+03, 0.17096700E+03, 0.11140100E+03, 0.19490900E+03, 0.70736400E+02, -.67373000E+02, 0.70915900E+02, 0.19793200E+03, 0.18022500E+03, -.69579400E+02, 0.20072600E+03, -.98671800E+02, 0.44875400E+02, 0.17304400E+03, 0.49223100E+02, 0.76914400E+02, 0.32062300E+02, -.20707900E+03, -.19160700E+03, 0.78735700E+02, 0.83166900E+02, 0.46417400E+02, -.43102100E+03, 0.19095000E+03, 0.18965700E+02, 0.21553300E+03, -.14521500E+03, -.11110800E+03, 0.10669300E+03, -.17772100E+03, 0.12850800E+03, -.10166300E+03, 0.21665400E+03, 0.21088800E+02, -.71397800E+01, 0.27826800E+01, -.10558600E+02, 0.10221000E+02, 0.48131400E+01, 0.31414900E+01, -.38387300E+01, -.33591600E+02, 0.10181700E+01, -.37776100E+02, 0.95165700E+03, -.47211200E+03, -.31924500E+03, -.47586400E+03, -.31389800E+03, -.53976700E+03, 0.40821100E+03, 0.25456500E+03, -.32070300E+03, -.51387200E+03, -.74190200E+03, -.78338300E+03, 0.37988200E+03, 0.35737500E+03, 0.39176000E+03, 0.10921700E+03, -.88899000E+02, 0.13132600E+03, -.11025400E+03, 0.13936700E+03, -.56141500E+02, 0.43825200E+03, 0.75746400E+03, -.37155400E+03, -.53689100E+03, -.37879600E+03, -.53816900E+03, -.65323100E+03, 0.52437100E+03, 0.15145500E+03, -.34019200E+03, -.60614400E+03, -.74387200E+03, -.48319300E+02, 0.30051100E+02, -.94975700E+02, 0.24544000E+02, 0.31877600E+02, 0.65156400E+02, -.35092900E+02, -.26956600E+03, -.76134100E+02, 0.55077400E+02, 0.69076900E+02, 0.13370900E+00, 0.14752300E-02, -.47520700E+00, -.76371900E-01, -.94648500E+00, 0.18536200E+01, -.18043700E+02, -.39116900E+01, 0.18998400E+01, 0.24242100E+01, 0.17935700E+01, -.19141400E+03, 0.89986500E+02, -.59359000E+02, 0.95753200E+02, -.53904700E+02, -.93295400E+02, 0.35182000E+02, -.47071300E+02, 0.99330300E+02, -.72963100E+02, 0.18462300E+03, 0.15485100E+03, -.67068500E+02, -.18000200E+03, -.77401300E+02, 0.98337600E+02, 0.49077100E+02, 0.45151800E+02, 0.75500800E+01, -.10346700E+03, 0.41949600E+02, -.49527800E+03, 0.51552200E+03, -.26518500E+03, -.22251400E+03, -.25779400E+03, 0.65636800E+02, -.72992400E+02, -.15225800E+03, 0.12990700E+03, -.46654400E+02, -.56325700E+02, 0.18057100E+03, 0.35564800E+01, 0.25678200E+01, 0.34233200E+01, -.10662600E+02, 0.78471000E+01, -.69088800E+01, 0.12380900E+02, 0.43468700E+01, 0.79501700E+00, -.16432300E+01, -.19878200E+01, -.72907900E+00, -.14228300E+02, -.10046600E+02, 0.76130100E+00, -.10204300E+02, -.83556300E+01, 0.64135100E+01, 0.10462300E+03, 0.49609700E+00, -.11609100E+03, -.10178200E+02, -.48348400E-03, 0.28292600E+01, -.19094200E+02, -.28617800E+01 },
        { -.19905200E+00, 0.69689600E-01, -.24738200E+01, -.12372800E+00, 0.80232300E+00, -.16292100E+00, -.17310800E+01, 0.51095200E-02, -.26617600E+00, -.14138600E+00, 0.70785900E-01, -.80279600E+00, 0.42846600E+00, 0.94041600E-01, 0.90525200E-01, 0.13717500E+00, -.78925700E+00, 0.69912600E-01, 0.17463400E+00, -.20446000E-01, -.10887300E+00, 0.68517200E+00, 0.26089000E+00, -.52187900E+00, -.41875800E+00, -.17559800E+00, -.17069700E+00, 0.22849500E+00, 0.14101500E+00, 0.50196100E+00, 0.51012000E-01, 0.24371000E+00, -.31013700E+00, -.27654700E+00, -.16140600E+00, 0.25384400E+00, -.40563700E-01, -.16825200E+00, 0.13551400E+00, 0.33685700E+00, -.51201700E+00, 0.10435400E+01, -.19144500E+00, 0.28938000E+00, -.30824900E-01, 0.55522200E-01, -.35661700E+00, -.64629400E-01, 0.72806400E-02, -.57033000E-03, 0.15242700E+00, -.57166000E+00, -.46982600E+00, 0.16334200E+01, -.23582400E+00, 0.12266100E+01, -.34388700E+00, -.26242400E+00, 0.34821400E-02, 0.68445100E-01, -.32057000E-01, -.31819800E+00, -.12614300E+00, 0.30340900E-01, 0.10494600E+00, 0.99826800E-01, 0.26153400E+00, 0.16053200E+00, -.10185200E+00, 0.81595300E-02, -.38773000E+00, 0.88774700E+00, -.65390100E-01, 0.20416400E-01, -.23204300E+00, -.18486500E+00, 0.20519900E+00, 0.37753800E+00, -.19130100E+00, -.39950700E-04, -.18169100E-01, 0.11972900E-01, -.43243500E-01, 0.16304900E-01, 0.55452300E-01, 0.29455400E+00, 0.35909100E+00, -.62702700E+00, 0.35760300E+00, 0.16908200E+00, -.11697600E+00, 0.15569400E-01, 0.41071600E+00, 0.73269300E+00, 0.52860000E+00, 0.78992300E+00, -.22139700E+00, 0.23018800E+00, 0.17890200E+00, -.13232100E+00, -.20605100E+00, -.68485500E+00, 0.46041100E-02, 0.35197900E-01, 0.15120800E+00, -.54816400E+00, -.14597900E+00, 0.21022900E+00, 0.33486400E+00, -.24937400E-01, 0.86485300E-01, 0.33373100E+00, -.83556700E-01, 0.39894800E-01, 0.13557000E-01, 0.43216900E-01, -.13627500E+00, -.16308200E+01, 0.11041400E+00, -.10055200E+00, -.16766000E+00, -.13898000E+00, 0.20419200E+00, 0.12184300E+00, -.15663900E+00, -.12581600E+03, 0.27478000E+02, -.46464400E+02, -.15125300E+03, -.30735700E+02, 0.34351000E+02, 0.58398900E+02, -.13067800E+03, 0.60721300E+02, 0.62468000E+02, 0.65352700E+02, 0.31113900E+02, 0.81955400E+02, -.42492800E+02, -.44030800E+02, 0.27110300E+02, 0.69391800E+02, 0.80066600E+02, 0.23857700E+03, -.99169400E+02, -.19380000E+02, -.11728400E+03, -.29321500E+01, 0.39063100E+02, -.15322900E+03, -.30662000E+02, -.77029900E+02, 0.31154500E+02, -.97756900E+02, -.64603700E+02, 0.36086100E+02, 0.15875900E+03, 0.29681300E+02, 0.11422300E+03, 0.75891300E+02, -.84692300E+02, 0.16006600E+02, -.56058900E+02, 0.54490100E+02, -.16991800E+03, -.16536800E+03, 0.74749500E+02, -.77470100E+01, 0.83367700E+02, -.18844400E+02, 0.15353400E+02, 0.43945700E+02, -.10672700E+03, -.59933700E+02, 0.10256800E+02, 0.67386000E+02, 0.12608900E+02, -.49633600E+01, 0.12455100E+02, -.65823900E+01, 0.61264200E+01, 0.75143500E+01, -.35413900E+02, -.55084000E+01, 0.35468800E+01, 0.41382000E+01, -.26657300E+01, -.95833400E+03, 0.47989500E+03, 0.62297900E+03, 0.47824800E+03, 0.23781800E+03, 0.36418200E+03, -.33994500E+03, -.42616100E+03, 0.17818400E+02, 0.32949100E+03, 0.35430100E+03, -.23037200E+03, 0.11331600E+03, 0.79363800E+02, 0.11531900E+03, 0.25663800E+02, 0.50974900E+02, 0.88913700E+02, 0.27762700E+02, 0.22588300E+02, 0.48595800E+02, 0.73197000E+02, -.13456600E+04, 0.67396800E+03, 0.52377300E+03, 0.67104800E+03, -.19062600E+02, 0.23675900E+03, -.28278500E+03, -.49909000E+03, 0.18052600E+03, 0.23737200E+03, 0.55905500E+03, 0.15320000E+03, -.82192700E+02, -.23349900E+02, -.74797100E+02, -.42955600E+02, -.11740100E+03, 0.52171900E+02, 0.66644500E+02, 0.23811900E+02, -.10205000E+03, -.13821400E+03, -.48131400E+00, 0.53003100E+00, -.19984500E+00, 0.36105600E-01, -.11750100E+01, -.18426300E+01, -.44379500E+01, 0.35482600E+01, 0.72544400E+00, -.15724800E+01, -.23660500E+01, 0.13903100E+03, -.67374700E+02, -.11257600E+03, -.70355000E+02, -.20491800E+02, 0.12428500E+02, -.66867800E+02, -.72485700E+02, -.91226200E+02, 0.90248700E+01, -.47398900E+02, -.20460800E+03, 0.10557200E+03, -.94715600E+02, 0.10278100E+03, 0.14405300E+03, 0.77621100E+02, -.55333000E+02, 0.94715300E+02, 0.22863100E+03, 0.43140500E+02, 0.30322200E+02, 0.34282500E+03, -.17293900E+03, -.34541200E+01, -.17199900E+03, -.82233600E+02, -.12398800E+03, 0.55261700E+02, -.10520400E+03, -.32979300E+03, -.80017800E+02, -.57353200E+02, -.70010400E+00, -.17641800E+02, 0.91748200E+01, 0.63629300E+01, 0.16541900E+02, -.17013600E+01, 0.28303300E+00, -.19617900E+02, 0.62820800E+00, -.56562400E+00, 0.11269300E+01, -.13378200E+01, -.50184600E+01, -.74570500E+01, 0.13381600E+02, -.67087700E+01, -.44028100E+01, -.20212200E+01, 0.22319800E+02, -.59989800E+01, 0.28596300E+01, 0.52272200E+01, 0.55956700E+00, 0.20121800E+01, -.33273900E+02, -.32859600E+02 },
        { -.93434200E-01, -.15587200E+00, -.10990000E+01, 0.61721600E-01, 0.60873800E+00, 0.29586200E-01, 0.84714400E+00, 0.16757700E-02, 0.84545800E-01, 0.85407900E-01, -.11182100E+00, -.99923600E+00, 0.16195000E+00, -.14883600E+00, -.30599100E+00, 0.34311400E-01, -.10735100E+01, 0.44203000E-01, -.91302300E-01, -.11573100E+00, -.52598500E+00, -.10226700E+01, -.58407900E-01, -.27774600E+00, -.45258800E-01, -.77646600E-02, 0.30363600E+00, 0.19126000E+00, 0.75900500E-01, -.98782800E-01, 0.19584800E+00, 0.72065400E-01, -.18077700E+00, -.96163700E-01, 0.12424700E+00, 0.28320300E+00, -.25566200E-01, 0.55779800E+00, -.19978100E+00, 0.45677500E+00, -.49367000E-01, -.14061900E+00, 0.69189700E+00, 0.15686300E+00, 0.24579000E+00, -.23796700E-01, 0.44398600E+00, 0.25992200E-01, 0.17541200E+00, -.11553100E+00, 0.16444800E+00, -.39166200E+00, 0.30442100E+00, 0.34200300E-01, -.89676100E-01, -.50708500E-01, 0.21339700E+00, 0.11169100E+00, -.86567700E-01, -.22536200E+00, -.28781100E-01, -.11126600E+00, 0.31694300E-01, 0.13575200E+00, 0.41407000E-01, 0.17569900E-01, -.56101800E-01, -.32091700E+00, 0.18649400E+00, 0.22446300E-03, 0.29680600E+00, 0.42935000E-01, 0.35562100E-01, 0.65163200E-01, 0.96642800E-01, -.34037100E-01, 0.13336400E-01, 0.36263900E+00, -.25300100E-01, 0.87294600E-01, -.16423300E-02, 0.14319100E-01, -.22615500E+00, -.35747900E-02, -.54011000E-01, -.19148500E-01, 0.82295500E-01, -.14243200E+00, -.20211800E+00, -.88208000E-01, 0.33364400E+00, -.48973900E-01, -.27990100E-01, 0.38654300E+00, -.19244900E+00, -.55660500E+00, -.18641800E+00, 0.24419700E+00, 0.49604100E-01, 0.84943700E-01, 0.45043900E+00, 0.36883400E+00, -.89899000E-02, 0.98669800E-01, -.84688600E-01, 0.51726900E+00, 0.18450100E+00, -.30916400E-01, -.55381300E+00, -.16462300E+00, 0.30074900E+00, -.30141000E+00, -.11026700E-01, 0.33585100E-01, 0.13886300E+00, 0.19908700E+00, 0.30758000E-01, -.92123500E+00, -.11404100E+00, 0.77607900E-01, -.26480400E+00, 0.25514100E+00, 0.13789400E+00, -.15710400E+00, -.31745200E-01, 0.28758300E+00, -.24380800E+03, 0.15763900E+03, 0.14789500E+03, 0.78857600E+02, -.21421700E+03, -.23170300E+03, -.67804700E+02, 0.33878900E+02, 0.50590900E+00, 0.33905200E+02, -.32621000E+01, -.81952200E+01, 0.51415800E+02, 0.64250600E+02, 0.78549500E+02, -.24591700E+02, 0.19740800E+02, 0.13405200E+02, 0.45202800E+01, 0.45308400E+02, -.66540700E+01, -.13231900E+02, 0.34184100E+02, -.42766500E+02, -.45976600E+02, -.43548800E+02, 0.20712300E+02, 0.32629000E+02, -.78149400E+02, 0.39676100E+02, -.91324400E+02, 0.39298400E+02, -.76356400E+02, 0.51411300E+02, -.20045000E+02, -.95682200E+01, -.39339100E+02, 0.71077900E+02, 0.81119500E+02, 0.72639600E+01, -.49323500E+00, -.52823700E+02, -.36951100E+01, 0.22745700E+01, 0.45249200E+02, 0.41788500E+02, 0.20693400E+02, -.58708900E+02, 0.59070000E+02, -.20407300E+02, 0.10338300E+02, -.50844500E+01, 0.39668100E+01, -.51453400E+01, -.41842800E+01, 0.34411900E+00, -.10164600E+01, 0.83908800E+00, 0.14386600E+02, -.14787600E+01, 0.16148200E+02, -.22162400E+03, 0.11090900E+03, 0.11765600E+03, 0.11089100E+03, -.19141400E+02, 0.11520800E+03, -.11643400E+03, -.21419400E+03, -.57578100E+02, 0.16140900E+03, 0.62190400E+03, 0.12285100E+03, -.60649100E+02, -.50253200E+02, -.61430100E+02, -.87195800E+01, 0.10480900E+03, -.12692900E+03, -.75597200E+02, -.66961200E+02, 0.11728300E+03, -.64746300E+02, -.35551000E+03, 0.17790300E+03, 0.13366900E+03, 0.17790800E+03, -.68958800E+02, 0.19976800E+03, -.96030800E+02, -.19862400E+03, -.39738600E+02, 0.22990600E+03, 0.72485900E+03, 0.78598900E+02, -.41664600E+02, 0.57137700E+02, -.39411700E+02, 0.13731100E+02, -.42847800E+02, -.77601400E+02, -.11743300E+02, -.20167700E+02, -.11911300E+02, -.56339200E+02, 0.25002500E+00, -.24284000E+00, -.95907600E+00, -.10743200E+00, 0.42268000E-01, 0.20945500E-01, 0.55079900E+00, -.10280100E+01, -.10469700E+01, -.12933200E+00, -.53932100E+00, 0.15059600E+03, -.72750400E+02, -.14037800E+03, -.75220400E+02, -.45292800E+02, -.28431300E+02, 0.17699900E+02, 0.76895700E+02, 0.95712700E+01, -.30739100E+02, -.57761900E+02, -.22941200E+03, 0.11603300E+03, 0.15027200E+03, 0.11466500E+03, -.36898800E+02, -.49455000E+02, 0.16779200E+02, -.24416500E+02, 0.17569100E+03, -.37835600E+02, 0.40993000E+03, -.18786200E+03, 0.93992400E+02, 0.10329300E+03, 0.93981100E+02, 0.65663700E+01, 0.65246200E+02, 0.12682800E+02, -.18835600E+03, -.36488300E+02, 0.36464000E+02, -.90692200E+02, 0.96982400E+00, 0.94003200E+01, 0.64322500E+01, 0.63601500E+01, 0.58023100E+01, -.65636600E+01, -.19975900E+02, 0.79674100E+01, -.49190600E+00, 0.15723800E+01, -.96813900E+01, -.21355400E+00, 0.17849700E+02, 0.37220100E+00, -.13028700E+02, 0.61789000E+01, -.19304200E+02, -.33783900E+01, 0.17628000E+02, 0.19961700E+02, -.14791100E+02, 0.35946300E+01, -.45823200E+00, -.22261200E+01, -.95331800E+01, -.16080200E+02 },
        { 0.19227400E+00, 0.13501400E+00, 0.23470100E+01, 0.99472200E-01, -.89772900E+00, 0.86009100E-01, 0.17843800E+00, -.56079600E+00, -.19381600E-01, -.11220900E+00, -.42645000E-02, 0.19716500E+01, -.58419600E-01, 0.62186200E+00, -.25893500E+00, -.20201500E+00, -.35438800E-01, -.69635600E-01, -.71725000E+00, 0.42688800E-01, -.52788600E-01, 0.14276800E+01, -.23342300E-01, -.21423900E+00, 0.11548500E+00, -.20790100E-01, 0.43970600E-01, 0.56247400E+00, 0.14061800E+00, -.23342200E+00, 0.41206200E+00, -.89105900E-01, 0.14096600E+00, -.75212700E-01, -.25508800E-01, -.12132800E+00, 0.26231200E-01, -.34821900E+00, -.92351500E-01, -.31643000E+00, 0.47338600E+00, -.78226000E+00, -.32431300E+00, -.29135400E+00, -.63959700E+00, 0.79426700E-01, 0.40465500E+00, 0.10014200E-01, 0.24589600E-01, 0.18049000E+00, -.11888300E+00, 0.44817300E+00, -.19402700E+00, 0.22590500E-01, -.86269300E-01, -.32779600E-01, -.87409900E-01, -.89362600E-01, 0.65743100E-01, -.51475400E+00, 0.34574800E+00, 0.59229500E-01, -.28709400E+00, 0.50668800E+00, -.17833900E+00, 0.70209300E-01, -.11169500E+00, 0.34179900E+00, 0.23661900E-01, -.48710200E-03, -.26426600E+00, -.47212100E+00, 0.32511200E-01, 0.73520400E-01, 0.25860800E+00, -.85128000E-01, -.19502700E+00, -.16338800E+00, 0.52997800E-01, 0.12028000E-01, 0.14807000E-01, -.27955600E-01, -.13700400E+00, 0.67740000E-01, 0.95625200E-01, -.15392400E+00, 0.65551900E-01, -.22918400E+00, -.20253400E-01, -.70865700E-01, 0.40721200E+00, 0.11984000E+00, 0.18119000E+00, -.56295700E+00, -.12832900E-01, 0.97525500E+00, 0.16988400E+00, -.42641700E-01, -.32483000E+00, 0.12110700E+00, -.88119700E+00, -.16064200E+00, -.66384600E-02, 0.29171000E+00, 0.31757900E+00, 0.65777100E+00, 0.23345200E+00, -.37905800E+00, 0.36819200E+00, -.31974700E+00, -.10208800E+00, 0.24342400E+00, 0.19961200E+00, -.78412600E-01, 0.37208400E-02, -.32644300E+00, -.52101100E-01, 0.98036800E+00, 0.31180500E+00, 0.49924200E-01, 0.13611100E+00, -.55898100E+00, 0.41811100E-01, -.10870200E+00, 0.75263000E-01, -.18424100E+00, -.53538900E+00, 0.15292900E+03, 0.14814600E+03, -.30441800E+02, 0.12490800E+02, -.28504700E+03, -.83113100E+02, 0.41146200E+02, 0.44973000E+02, 0.41552200E+02, 0.32012100E+02, -.24086600E+01, 0.27400400E+02, 0.13326500E+01, 0.50308100E+02, 0.47317400E+01, -.12807500E+02, 0.14210000E+03, -.76657100E+02, -.88210200E+02, -.71683600E+02, -.37866600E+02, 0.12097400E+02, -.60544000E+02, 0.10603800E+02, -.38668000E+02, 0.11186300E+01, 0.45559500E+02, -.86053800E+02, 0.41947700E+02, 0.61536800E+02, 0.43931300E+02, 0.43321000E+02, 0.59979500E+01, -.85345000E+02, -.72527900E+02, 0.77259200E+02, 0.74643400E+01, 0.73328600E+02, 0.51192700E+02, -.29558700E+02, -.11054800E+03, -.25825300E+02, 0.93633600E+01, 0.29014300E+02, -.39469300E+02, -.66515500E+02, -.20310500E+02, 0.38440000E+02, -.15720300E+02, -.13615600E+02, 0.73118100E+01, 0.21563200E+01, 0.69032200E+01, 0.87424500E+01, 0.56650100E+01, -.67243400E+01, -.79076400E+01, -.68537100E+01, 0.10334200E+02, 0.12023700E+02, 0.42507500E+03, -.21207600E+03, -.30254700E+03, -.21222000E+03, -.30724900E+02, -.23261600E+03, 0.63744800E+02, 0.22509400E+03, -.51961000E+02, -.18394500E+03, -.13811500E+03, -.97179200E+01, 0.28354700E+01, 0.29659900E+02, 0.48113100E+01, 0.34659200E+02, 0.47531400E+02, -.30272400E+02, -.33203400E+01, 0.11607100E+02, 0.33429100E+02, 0.28434000E+02, 0.70964200E+03, -.35381900E+03, -.21686400E+03, -.35420400E+03, 0.56126200E+02, -.29357000E+02, -.42268600E+02, 0.22822600E+03, -.19963500E+03, -.35213600E+02, -.26061400E+03, -.81477300E+02, 0.42896000E+02, 0.12295300E+02, 0.39769300E+02, 0.72863800E+02, -.17890600E+02, 0.55822500E+02, 0.46622100E+02, 0.33661600E+02, -.21010200E+02, -.19403800E+02, 0.13012400E+01, -.69735600E+00, 0.16171500E+01, -.58035600E+00, 0.16229200E+01, 0.80791700E+00, -.42745800E+01, -.35470900E+00, -.45323300E+00, 0.57847500E+00, -.20042400E+01, 0.73520700E+02, -.35983900E+02, -.10279400E+03, -.36466600E+02, 0.99816700E+01, 0.22167800E+02, -.47397100E+02, -.56467600E+02, -.24749400E+02, 0.22857700E+02, 0.58795600E+01, -.90262400E+02, 0.47070200E+02, 0.10357000E+03, 0.44967100E+02, -.22183100E+02, -.11132000E+02, -.37707100E+02, -.10197600E+03, -.29502800E+02, -.77347500E+01, 0.32687600E+03, -.86115500E+02, 0.41978000E+02, 0.12234600E+02, 0.43259100E+02, 0.70059700E+02, -.24633400E+01, -.85052800E+01, -.34555800E+02, 0.14700500E+03, -.87592600E+01, -.12123900E+03, -.88122400E+00, 0.18238900E+02, -.11275300E+02, -.18812300E+01, -.10723000E+01, -.50787300E+01, -.34424400E+01, 0.22613800E+02, 0.58493200E+00, -.17657500E+00, -.18204500E+01, -.26535800E+01, 0.30983900E+02, 0.11616800E+01, -.88442000E+01, -.71752700E+01, 0.42168300E+01, 0.17882600E+01, 0.22103000E+02, 0.15332500E+01, -.26187400E+02, 0.61860800E+01, 0.30984600E+00, -.19616800E+01, 0.44121100E+01, 0.79338700E+00 },
        { -.94260400E+00, -.67170600E+01, 0.46205800E+01, -.33342600E+00, 0.29692300E+00, 0.16338300E+01, 0.46213900E-02, -.12918700E+01, -.20686200E+00, 0.73484300E-01, 0.38614900E+00, 0.35473800E+00, 0.43280900E+00, 0.49845200E+00, -.12735000E+00, -.27783400E+00, -.17269600E+01, 0.12321700E+00, -.43671400E+00, 0.36167700E+00, -.98078100E+00, 0.25041600E+01, -.23000900E-01, -.68249500E+01, -.65506100E+00, 0.14212500E+00, -.18596600E+01, 0.15387300E+01, -.84491500E-01, 0.43160700E+00, -.48202500E+00, 0.11651300E+01, -.93947600E+00, -.27365400E+00, -.66324000E+00, 0.90577400E-01, -.13446800E+00, -.69256500E+00, -.11031100E+01, 0.11909700E+01, 0.25860100E+00, 0.12104600E+01, 0.90671900E+00, 0.46652500E+00, -.13096500E+01, 0.60135500E+00, 0.16838800E+01, -.10942700E+00, -.47916000E+00, 0.37077300E+00, -.22138500E+01, 0.86406400E+00, 0.96911300E+00, -.62728300E+01, 0.42803600E+00, -.11307600E+01, -.10531400E+01, -.26588600E+00, 0.32852400E-01, -.12744200E+01, 0.40718100E-01, -.12054000E+00, 0.81234200E+00, -.57050900E+00, 0.10490700E+00, 0.29047800E+00, 0.50080700E+00, 0.10424300E+01, -.19621900E+01, -.58038000E-02, 0.52091500E+00, 0.22829800E+01, 0.61746200E+00, 0.29265300E+00, -.46150500E+00, 0.33604400E+00, 0.16429300E-02, 0.11476600E+01, -.10200400E+01, 0.33241200E+00, -.36882300E-02, 0.15881100E+00, 0.35425000E+00, 0.74513300E+00, 0.69468900E-01, 0.65098100E+00, -.58157400E+00, -.17647200E+01, -.28660200E+01, 0.81617000E+00, -.34662200E+01, 0.29711500E+00, 0.17558600E+01, -.62831800E+01, -.29334800E+01, -.49009100E+01, -.15081000E+01, 0.15528400E+01, -.25106300E+01, -.15613100E+01, 0.13988400E+02, 0.28893200E+00, -.16573600E+00, -.33602600E+00, -.10447200E+01, 0.40663300E+01, 0.15614900E+01, 0.12616900E+00, -.13504300E+01, -.15310100E+01, -.73313400E+00, 0.11672500E+01, -.75511000E+00, 0.22498000E+00, 0.28821100E+00, -.25407200E+00, 0.17558100E+00, -.58559700E+01, -.18883500E+01, -.23799000E+00, -.36172000E+00, 0.21571300E+01, -.52583100E+00, -.28871900E+00, 0.27364000E+00, 0.35444800E+01, 0.28874900E+01, 0.35634300E+01, 0.17355000E+04, 0.78494300E+03, -.80554700E+01, 0.71819600E+03, 0.13288000E+04, -.61644900E+03, -.50583000E+03, -.66453300E+03, -.27649900E+03, -.38603900E+03, -.20924900E+02, 0.39630400E+03, -.38381000E+03, -.33231200E+03, -.62923700E+03, -.21033900E+04, 0.86963400E+03, 0.34295300E+02, 0.10421900E+04, 0.13279200E+03, -.31732700E+03, 0.15839600E+04, 0.54703700E+03, 0.61558700E+03, -.22081300E+03, 0.62232300E+03, 0.81711100E+03, -.43375400E+03, -.98096100E+03, -.39863900E+03, -.26183400E+03, -.32302800E+03, 0.62683000E+03, -.85461900E+03, -.19308300E+03, -.25923000E+03, 0.10879900E+04, 0.73920700E+03, -.28542300E+03, 0.36291400E+03, -.37217200E+03, 0.71236700E+01, -.55415600E+03, -.17867000E+03, 0.58566700E+03, 0.77087500E+03, -.47628200E+03, -.20235400E+03, -.71604300E+02, 0.17671100E+02, -.11181500E+03, 0.36857700E+02, -.18649400E+02, -.59796100E+02, 0.19212800E+03, 0.55961200E+02, -.43503300E+02, -.63745200E+02, 0.21552600E+02, 0.65708300E+04, -.33005900E+04, -.40247100E+04, -.32819500E+04, -.85537900E+03, -.15227100E+04, 0.64312200E+03, 0.24754400E+04, -.52011400E+03, -.15324400E+04, -.17769400E+04, 0.58422200E+03, -.25850500E+03, -.62056000E+02, -.29273300E+03, -.12776800E+03, -.62931400E+03, -.27184500E+02, 0.35153000E+02, 0.22624200E+03, -.54551800E+03, -.21927200E+02, 0.87392800E+04, -.43936700E+04, -.35539500E+04, -.43629200E+04, 0.14081700E+04, -.24870000E+03, 0.18296700E+03, 0.30122500E+04, -.12751200E+04, -.53200700E+03, -.28250400E+04, -.94105300E+03, 0.51386200E+03, 0.64643700E+02, 0.46380100E+03, 0.25250000E+03, 0.93470600E+03, -.43261200E+03, -.60536400E+03, -.17811500E+03, 0.85324700E+03, 0.91516300E+03, -.39069900E+01, -.16916100E+00, 0.64934000E+01, 0.27286000E+01, 0.34498000E+01, 0.94251800E+01, 0.42119100E+02, -.28669500E+02, -.33799900E+01, 0.10183100E+02, 0.24804600E+02, -.18042600E+04, 0.87727100E+03, 0.10810800E+04, 0.90515200E+03, 0.86790600E+02, -.23126300E+03, 0.82224800E+03, 0.49335700E+03, 0.82600100E+03, -.18158000E+03, 0.77086500E+03, -.40099300E+03, 0.14870400E+03, 0.12152100E+04, 0.19868500E+03, -.59711200E+03, -.20929000E+03, 0.41552100E+03, -.18895500E+04, -.17905900E+04, -.14943700E+03, -.29010700E+02, 0.12314900E+04, -.59249700E+03, -.12764700E+04, -.61350900E+03, 0.24946100E+03, 0.20995900E+03, -.46688800E+03, 0.22201400E+04, 0.18855000E+04, 0.49945300E+02, -.10794600E+04, 0.99536400E+01, -.17742300E+02, -.53551600E+02, -.61147300E+02, -.11031400E+03, 0.52047300E+02, 0.26206700E+02, 0.10781200E+02, -.24427800E+01, 0.15268300E+01, -.44642800E+01, 0.26018100E+02, 0.25465400E+03, 0.85192200E+02, -.15504500E+03, 0.10757100E+02, 0.10741500E+03, 0.12897700E+02, -.22675500E+03, 0.28477700E+02, 0.89847700E+02, -.41897500E+02, -.96937700E+00, -.22096700E+02, 0.56378900E+03, 0.39420300E+03 },
        { -.44056600E+00, 0.77451000E+00, -.38295000E+01, -.61978200E+00, 0.80347300E+00, 0.56413300E+00, 0.66512500E+00, -.96727100E+00, -.43381600E+00, 0.14177000E-01, 0.73395100E+00, 0.26437400E+01, 0.92256200E-02, 0.12415100E+01, 0.52582700E+00, 0.34089800E+00, 0.19771200E+00, 0.10794500E+00, -.13566600E-01, -.36272500E-01, -.39401100E+00, 0.73448400E+01, 0.21932800E+00, -.22281200E+01, -.94416500E-01, -.50136800E+00, -.11766000E+01, 0.10391900E+01, 0.34340100E+00, 0.39757900E+00, -.23762800E+00, -.94415100E-01, -.45245000E+00, -.38885700E+00, 0.51772500E+00, -.79338900E+00, 0.40845500E-01, -.14009100E+01, 0.26909800E+00, -.10249300E+01, 0.74458800E+00, 0.25034400E+01, -.47412700E+00, 0.14854600E+00, -.24327600E+01, 0.43115300E+00, 0.10924500E+01, -.95507700E-01, -.70749500E+00, 0.20487400E+01, 0.11394400E+01, -.37050400E+00, 0.21386300E+00, 0.32380700E+01, -.17320800E+00, -.32629400E+00, 0.95416900E+00, -.51652500E+00, 0.17405200E+00, 0.77037000E+00, -.22610400E+00, 0.44646000E+00, -.55698900E+00, 0.80130000E-01, 0.33469400E+00, -.44522900E+00, 0.98740300E-01, 0.15693200E+00, -.23868700E+00, -.10810100E-02, -.31212100E+00, 0.19140000E+01, -.53881000E+00, -.14110200E-01, -.17469200E+00, 0.88258300E+00, 0.40918100E+00, -.15798100E+01, -.36273000E-02, -.68338300E-01, -.20892300E-01, 0.12656600E+00, -.24538100E+00, -.13477200E+00, -.15920300E+00, -.15195100E+00, -.12469700E+00, 0.14554500E+00, -.30497300E+00, 0.15307700E+00, 0.44564500E+00, -.21595000E+00, 0.17110500E+00, 0.25974400E+01, -.29384100E+00, -.13658000E+01, -.35846500E+00, 0.54421700E+00, -.62195200E-01, -.15372900E+00, -.21138800E+00, 0.54014400E+00, 0.16649600E-01, -.78691300E+00, -.48015100E+00, -.20046400E+00, 0.30207800E+00, 0.33125400E+00, -.78794700E+00, -.61979400E+00, -.93164900E+00, -.39601300E+00, -.69627500E+00, 0.25776800E-01, -.50970500E-01, 0.30102600E+00, -.18292200E+00, -.23508900E+00, -.65660700E+00, 0.90584900E-01, -.50928300E+00, -.87522100E+00, 0.51329900E+00, -.31220500E+00, -.15822300E+00, 0.35341200E-01, 0.59357400E+00, -.91514300E+00, -.44571600E-01, 0.22679100E+03, 0.86391300E+02, -.83812900E+03, -.26543400E+02, 0.13855300E+02, 0.41731000E+01, 0.13280700E+02, 0.44617400E+02, -.26003000E+02, -.59355100E+02, -.31042800E+01, 0.82819700E+02, -.14549700E+02, -.56527700E+02, 0.28216100E+03, -.12973100E+03, 0.11799900E+03, -.14016800E+03, -.97075500E+02, 0.43916600E+01, -.47744800E+02, -.39779600E+02, -.11739100E+03, -.10521700E+02, -.65669500E+02, -.29752700E+03, 0.15210400E+03, -.16030500E+03, 0.14734200E+03, 0.35567100E+02, -.27537200E+02, 0.16462500E+03, 0.62869300E+02, 0.51872800E+02, -.71816900E+02, 0.39460100E+03, 0.29281400E+03, -.14404700E+03, -.12843600E+03, -.14604000E+03, 0.47770200E+02, 0.77803700E+02, -.12194700E+01, 0.12946800E+03, -.70691500E+01, 0.92405200E+02, -.11202000E+03, -.91624600E+01, 0.36599200E+01, -.11040600E+02, 0.44306000E+01, 0.49626300E+01, 0.29125300E+01, -.33381900E+02, -.17902800E+02, -.22850200E+02, 0.97695800E+01, 0.14075000E+02, 0.15350400E+04, -.76945400E+03, -.82220800E+03, -.76801800E+03, 0.52897000E+02, -.21574600E+01, -.67358400E+03, 0.41117400E+03, -.58241100E+03, 0.58046200E+02, -.96793600E+02, -.81842200E+02, 0.44001400E+02, 0.98925500E+02, 0.40997100E+02, 0.13774300E+02, 0.36080300E+02, 0.11197700E+03, 0.30959900E+03, 0.23630900E+03, 0.75480900E+02, -.38810100E+02, 0.14946000E+04, -.75078000E+03, -.65839200E+03, -.74826700E+03, 0.53089100E+03, 0.67094300E+03, -.89903500E+03, 0.41764200E+03, -.61358200E+03, 0.57018800E+03, -.99516000E+02, -.25192800E+03, 0.12426700E+03, 0.41137900E+02, 0.12651600E+03, 0.17019800E+03, 0.11773100E+03, -.21610300E+02, 0.14182200E+03, 0.13603600E+03, 0.14332600E+03, 0.13220500E+02, -.28839400E+01, 0.15633000E+01, 0.45990200E+01, 0.13311400E+01, 0.26033100E+01, 0.98435400E+00, 0.67486300E+01, 0.73666000E+00, 0.90116200E+00, -.11038600E+01, -.69446200E+00, 0.21999000E+03, -.10327200E+03, -.11321300E+03, -.11045000E+03, 0.22539200E+01, 0.30107700E+02, 0.12195500E+02, 0.70531300E+02, -.56846800E+01, 0.31875300E+02, -.89608900E+02, -.33521200E+03, 0.16681800E+03, 0.56311800E+03, 0.16786500E+03, 0.26145200E+02, 0.89469500E+02, -.88873100E+02, -.27863300E+03, -.43156200E+03, 0.52689700E+01, 0.93800700E+03, 0.13137300E+04, -.65466700E+03, -.61281500E+03, -.65718400E+03, -.99072500E+02, -.22014800E+03, 0.56425200E+01, 0.47336100E+03, 0.21227800E+03, -.17415200E+03, -.97639400E+03, 0.19309700E+00, -.41639200E+01, -.21263100E+02, -.63016200E+01, -.31370200E+02, 0.44254800E+01, 0.11071200E+02, 0.96866700E+01, 0.12587300E+00, -.21819900E+00, -.46894500E+01, 0.17252100E+02, 0.10006200E+02, 0.28817200E+02, 0.90866900E+01, 0.12467500E+02, -.67050800E+01, 0.25238200E+01, 0.73014700E+02, -.75037700E+01, -.52467500E+02, 0.41118600E+01, 0.72104100E+00, -.11078000E+02, 0.14136300E+03, 0.89717900E+02 },
        { -.34838400E+00, 0.67513300E+00, -.22767800E+01, -.30539400E+00, 0.83688900E+00, 0.39371800E+00, 0.36149800E+01, 0.21809000E+01, 0.13651600E+01, 0.64065700E+00, -.11091400E+00, -.23098600E+01, -.25189300E+00, -.11198500E+01, 0.22721000E+00, 0.37863500E-01, -.42360400E+00, 0.45002700E-01, -.10740600E+01, -.12275200E+00, -.17276800E+00, -.25090400E+01, -.27521000E+00, -.36834400E+00, -.33005400E-01, -.99019200E-01, -.49691800E+00, -.38673100E+00, -.10876700E+00, -.22204100E+00, 0.58458100E+00, 0.20052600E+00, 0.15896800E+01, -.93546800E+00, -.28473200E+00, -.77334200E-01, 0.84788600E-01, -.48549900E+00, -.11849300E+00, -.83176100E+00, -.73709500E+00, 0.12883900E+00, 0.44345900E+01, 0.73906700E+00, -.10606800E+01, -.20945700E+00, -.95213400E+00, 0.15157300E-01, -.75431100E-01, 0.24097500E+00, -.89020300E+00, 0.12085700E+01, -.33211500E-01, -.45192300E+01, -.17826900E+00, -.11765800E+01, -.61711900E+00, -.53283600E+00, 0.15103700E+00, -.12640600E+01, 0.47072500E+00, 0.27970100E+00, -.71501900E-01, 0.10487500E+00, -.34132300E+00, 0.16505700E+00, 0.15623100E+00, 0.87572000E+00, -.43774000E+00, -.42302200E-02, -.24939900E+00, 0.22529700E+01, 0.39304200E+00, 0.51901800E+00, -.11330300E+01, 0.12684000E+00, -.25467000E+00, 0.11635700E+01, 0.37753000E+00, -.35043200E+00, 0.73668300E-02, 0.18277500E+00, 0.52281300E+00, -.56424200E-02, -.29698800E+00, 0.66914800E-01, 0.11020700E+01, -.98747000E+00, 0.73577500E+00, -.36692400E-01, -.62410400E+00, 0.21313800E+00, 0.83292700E+00, -.23051400E+01, 0.20643300E+00, -.19469600E-02, -.38197200E+00, 0.58993500E+00, -.72273900E+00, -.55207400E+00, 0.37874300E+01, -.66372100E+00, -.25766900E-01, -.26292000E+00, -.41648700E+00, 0.94309700E+00, 0.13608600E+00, -.38481300E+00, -.71811600E+00, -.33256000E+00, 0.17367900E+01, 0.12839500E+01, -.49567200E+00, 0.34861200E-01, 0.33656000E+00, 0.53981200E+00, 0.25985100E+00, -.27975900E+01, -.59094400E+00, 0.16601900E+00, -.92693200E+00, 0.18000700E+01, 0.11253900E-01, 0.94159200E+00, 0.69295000E-01, 0.13112800E+01, 0.53042400E+00, 0.21341300E+00, 0.11268600E+00, 0.47659100E+00, -.11169800E+03, 0.37922500E+03, -.52942800E+02, 0.17528100E+02, -.85882300E+02, 0.26458600E+02, -.74950700E+02, 0.69472500E+02, 0.89980000E+02, 0.46747000E+02, 0.36556800E+02, 0.22065300E+02, 0.94725100E+02, -.43082400E+03, 0.21037400E+03, 0.14046400E+03, 0.21285000E+03, 0.14598900E+03, -.37822200E+02, 0.10696300E+02, 0.57584300E+02, 0.14146400E+03, -.42849800E+02, 0.22972600E+03, 0.21457300E+02, -.98816700E+01, -.30754600E+02, -.68745000E+01, -.14205200E+03, 0.28551300E+02, -.85638500E+02, -.16109300E+03, -.11791900E+03, 0.15312300E+03, -.13853600E+03, -.54323100E+03, 0.24690200E+03, 0.47681300E+02, 0.27061800E+03, -.82245400E+02, -.39634900E+02, 0.21322700E+03, -.11389700E+03, 0.19027800E+02, 0.72659500E+01, 0.22630700E+03, 0.94354400E+01, -.86447200E+00, 0.27128800E+02, -.43099400E+01, -.98557000E+01, -.19661000E+02, 0.47010900E+02, 0.13943600E+02, 0.48852800E+02, -.36081900E+02, -.14050500E+02, -.12291700E+04, 0.61966000E+03, 0.70831600E+03, 0.61593500E+03, -.31343100E+03, -.29047100E+03, 0.66158500E+03, -.55704400E+03, 0.18341400E+03, -.25595800E+03, 0.55262300E+03, -.30206800E+03, 0.14065600E+03, 0.14369300E+03, 0.15084500E+03, 0.52669700E+02, 0.52910700E+02, -.22529800E+03, -.34673000E+03, -.11850800E+03, 0.11816400E+03, 0.21880000E+03, -.16675300E+04, 0.84159800E+03, 0.67342500E+03, 0.83639000E+03, -.10283600E+04, -.78199900E+03, 0.10134700E+04, -.54941900E+03, 0.27401600E+03, -.63107300E+03, 0.66953000E+03, 0.46440600E+03, -.23136200E+03, 0.44063200E+02, -.23484600E+03, -.14314800E+03, -.91410400E+02, -.31874100E+03, -.30172500E+03, -.18147300E+03, -.51941200E+02, -.15369700E+03, -.37476100E-01, 0.51665900E+00, -.42272700E+01, 0.31903300E+00, -.23455400E+01, 0.96293900E+00, -.26355700E+01, -.49817400E+01, 0.74709400E+00, 0.23123600E+01, 0.31257700E+01, -.23224500E+03, 0.10904000E+03, -.52406300E+02, 0.11737700E+03, -.71465800E+02, -.12155200E+03, 0.50706200E+02, -.42451000E+02, 0.82348100E+02, -.97167100E+02, 0.19407700E+03, 0.81168800E+03, -.39558400E+03, -.46220100E+03, -.40654400E+03, -.30072900E+02, -.67967600E+02, -.66271600E+02, 0.17745200E+03, 0.90044800E+02, -.38717700E+02, -.88292400E+03, -.94642700E+03, 0.46775000E+03, 0.37588300E+03, 0.47407400E+03, 0.93399700E+02, 0.61001100E+02, 0.14733700E+03, -.19644200E+03, -.55016400E+02, 0.62073700E+02, 0.81683900E+03, 0.59930000E+01, -.49420800E+01, 0.29309100E+02, 0.88998000E+01, 0.47949800E+02, 0.95391700E+00, -.17014800E+02, -.13091400E+02, -.34502800E+00, 0.34873300E+00, 0.54763000E+01, 0.97808700E+01, -.31563500E+02, -.24718100E+02, 0.65604100E+01, 0.57943700E+01, -.29713200E+02, -.16157500E+02, 0.48032800E+01, 0.35907500E+02, -.16163100E+02, -.80486200E+01, -.63878800E+00, 0.15493400E+02, -.73007400E+02, -.48247100E+02 },
        { 0.12780200E+00, 0.50203000E+00, -.61449800E+00, 0.28909500E+00, -.43911800E+00, 0.59641900E-01, -.30859500E+00, 0.54559100E+00, 0.12970700E+00, -.17320000E+00, -.20149600E-01, 0.32268300E+00, 0.97739400E-01, 0.21736100E+00, -.69175100E+00, 0.28885100E+00, 0.19051100E+00, 0.22066600E-01, -.14405800E+01, 0.90888300E+00, -.45337900E+00, 0.82447800E+00, 0.23924100E+00, -.65508000E+00, -.43995600E+00, -.37195800E+00, -.42833400E+00, 0.40533900E+00, -.70957500E-01, 0.18876400E+00, 0.18306000E+00, 0.35833200E-01, -.23874900E+00, 0.11408400E+00, -.96285500E-01, -.94057100E-01, -.16295700E-01, 0.66269400E-01, 0.17156300E+00, 0.11936100E+00, -.50887300E+00, -.35558600E+00, 0.72850400E+00, 0.56862500E+00, 0.57056200E-01, -.21829700E+00, -.10704700E+01, -.48396600E-01, -.19627600E+00, 0.36051900E-01, -.40948200E+00, -.17488200E+00, 0.28240700E+00, -.11444400E+01, 0.33667100E+00, 0.28333400E+00, -.61367200E+00, 0.34278000E+00, -.13314400E+00, -.59459100E-01, -.23488400E+00, -.24572100E+00, -.93873300E-01, 0.17217000E-01, 0.12052600E+00, 0.20956900E+00, 0.14985500E+00, 0.92651500E-01, -.22273900E+00, -.55724100E-02, 0.29005400E+00, 0.40583500E+00, 0.12265100E+00, 0.78048600E-01, 0.91018700E-01, 0.12118500E-01, -.35214200E-01, 0.66744300E+00, -.10736100E+00, 0.50168900E-01, 0.25409100E-03, 0.18195600E-01, -.11920200E+00, -.12263400E-01, 0.25013800E+00, -.73107300E-02, -.22401100E+00, 0.40942600E+00, -.80315900E+00, -.12519200E+00, 0.24045000E-01, 0.10643900E+00, -.21273600E+00, -.10445700E+00, -.10422400E+00, 0.97590800E-01, -.19040000E+00, 0.23171100E+00, 0.44510000E-01, 0.21675900E-02, 0.11343500E+01, 0.39463400E-01, -.14752500E-01, 0.54488300E+00, 0.91163800E-01, 0.62510400E+00, 0.10305700E+00, 0.87333200E+00, -.76590700E+00, -.38658200E+00, -.41442800E+00, 0.11956700E+00, -.18438200E+00, 0.40587700E-01, 0.16053800E-01, 0.42290300E+00, -.90947900E-01, -.12589200E+01, -.96438200E+00, -.63111700E-01, -.67715000E-01, 0.62736200E+00, 0.87522000E-01, 0.65829400E-02, -.14065000E-01, -.90432900E+00, -.58486000E-01, 0.33760900E+00, 0.47586100E-01, -.13113100E-01, -.29498900E+00, -.34277700E+03, -.30180800E+03, 0.14332000E+03, 0.12105400E+03, 0.15089700E+03, 0.11190100E+03, 0.17470900E+03, -.74003100E+02, -.47604700E+02, 0.34601300E+02, 0.11198000E+03, 0.17705800E+03, 0.20443200E+03, -.89886300E+02, 0.19579700E+03, -.99878100E+02, -.64064200E+01, -.73016200E+02, -.60934100E+02, 0.68154300E+02, 0.73492600E+01, -.80669000E+02, -.15262200E+03, -.20565300E+03, 0.11125900E+03, 0.72789900E+01, 0.10052600E+03, 0.37589100E+02, 0.33908900E+02, 0.35931800E+02, -.78006800E+02, -.61538100E+01, 0.70853000E+02, 0.11219700E+03, -.30359800E+02, -.31492200E+01, -.14258400E+03, 0.15773100E+02, -.21963200E+01, 0.51976500E+02, 0.58021600E+02, -.66394900E+02, -.85729400E+02, 0.69879200E+02, -.37564600E+02, -.87212700E+01, 0.59654400E+01, 0.40609300E+02, 0.41182900E+01, 0.12035800E+02, -.67691400E+01, -.11606500E+02, 0.17285000E+02, 0.57429800E+02, -.12495400E+02, 0.54222900E+02, -.21239400E+04, 0.10641700E+04, 0.12304000E+04, 0.10611600E+04, 0.65490500E+03, 0.58526900E+03, -.42921000E+03, -.78708300E+03, 0.31351500E+03, 0.62094400E+03, 0.19858400E+04, -.57344800E+03, 0.28408600E+03, 0.14053800E+03, 0.28681700E+03, 0.85133000E+02, 0.75928400E+02, 0.40016500E+02, -.27815600E+02, 0.12528900E+03, 0.10063700E+03, 0.30454900E+03, -.26901600E+04, 0.13465700E+04, 0.10946200E+04, 0.13435100E+04, 0.13411200E+03, 0.47501600E+03, -.31029100E+03, -.80866700E+03, 0.57400900E+03, 0.53657800E+03, 0.24358400E+04, -.49971400E+02, 0.22823700E+02, -.56469300E+02, 0.27002600E+02, 0.42196700E+01, -.81423000E+02, -.60335200E+02, -.68018300E+02, 0.55907400E+02, -.24471900E+02, 0.57979500E+02, -.21916500E+01, 0.21955600E+01, -.29736600E+01, 0.91701800E+00, -.13593700E+01, -.15106500E+01, 0.54561600E+01, -.32156500E+01, 0.26561200E+01, -.18972100E+00, 0.17847200E+01, 0.34327400E+02, -.18101000E+02, -.10584100E+03, -.17942000E+02, -.14989200E+02, -.72883100E+02, 0.48696900E+02, 0.53715400E+02, 0.36352200E+02, -.70277500E+02, -.10146300E+03, 0.67278900E+03, -.33374400E+03, -.44531500E+03, -.33597800E+03, -.21555300E+03, -.12417300E+03, -.18935200E+03, 0.20339800E+03, 0.12259000E+03, -.15713700E+03, 0.17262100E+03, -.93236400E+03, 0.46777300E+03, 0.60868300E+03, 0.46567200E+03, 0.25031900E+03, -.63475700E+02, 0.32876400E+03, -.40377300E+03, -.22812500E+02, -.67626600E+01, 0.12363100E+03, 0.65471400E+01, -.58155400E+01, -.64669500E+01, -.22804400E+01, -.61999000E+01, 0.46320100E+01, -.11583000E+02, -.67837200E+01, -.66921700E+00, -.30486500E+01, 0.72006000E+01, 0.11602900E+02, 0.45303200E+01, 0.30283000E+02, 0.48918800E+02, 0.72418800E+01, -.15315600E+02, -.17769600E+02, -.82177300E+02, 0.65899400E+01, 0.97449900E+02, 0.64671900E+00, -.13349700E+00, -.81452700E+01, -.42929500E+02, -.46064400E+02 },
        { -.11596000E+01, 0.15715600E+01, -.97271600E+01, 0.37380300E+00, 0.55763500E+01, 0.12212100E+01, 0.79538100E+01, 0.28724800E+01, -.55953100E-01, 0.30618600E+00, 0.29883900E+00, -.86903500E+01, 0.24369600E+01, -.16357200E+01, 0.23730200E+01, 0.96264800E+00, -.92761900E+01, 0.91869200E+00, -.29278800E+01, 0.25011600E+01, -.47595700E+01, -.38401000E+01, 0.10957600E+01, -.38476200E+01, -.37057700E+01, 0.10661900E+01, -.15942800E+01, 0.16246200E+01, -.46208800E+00, 0.90757500E+00, 0.21619600E+01, 0.16127800E+01, -.11481800E+01, -.99655600E+00, -.52204000E+00, -.26350400E+00, -.10125500E+00, 0.83916700E+00, 0.22599400E+01, 0.34582100E+00, -.24898600E+01, -.95968900E+01, -.10059500E+02, -.22804100E+01, 0.33831800E+01, 0.24895800E+01, 0.67216500E+01, -.39764300E-01, 0.15488500E+01, -.48207200E+00, 0.67089000E+00, 0.25637500E+01, -.12203500E+01, 0.33622300E+01, -.75242100E+00, 0.23572000E+01, -.18710600E+01, -.10837500E+01, 0.13138900E+01, -.14593300E+01, 0.14334200E+01, -.36746500E-02, -.43733700E+00, 0.48045100E+00, -.20643400E+00, -.43491900E+00, -.10775000E+01, 0.13153700E+01, 0.53713200E+00, 0.46690300E+00, 0.23430100E+00, 0.27505100E+01, -.19766400E+00, 0.24024700E+00, 0.98355500E+00, -.16277700E+00, 0.26626900E+00, -.26915100E+00, -.36873900E+00, 0.11482400E+01, -.97170700E-01, -.29334400E+00, -.15092300E+01, 0.99036200E+00, 0.22350700E+00, 0.72265500E+00, -.20118200E+01, -.14839000E+01, -.13391300E+01, 0.20579400E+00, -.95925200E+00, -.78609600E+00, -.12494400E+01, 0.87239500E+01, 0.16824500E+01, 0.20366200E+01, 0.46922400E+00, -.75977500E+00, 0.33547600E+01, 0.15302400E+01, -.41498400E+01, 0.51806400E+00, -.69395000E+00, -.94723700E+00, -.19283700E+01, 0.31763100E+01, 0.10349000E+01, 0.27973800E+01, -.70653200E+01, 0.91743100E+00, -.11830400E+01, -.34793100E+01, 0.23479600E+00, -.29005500E-01, -.13614100E+01, 0.13925200E+01, 0.13518000E+01, -.24049300E+01, -.33812500E+01, 0.84437200E+00, -.21856300E+01, 0.29996800E+01, -.88764600E+00, 0.25654000E+01, 0.29249900E+00, 0.10300300E-01, 0.14222200E+01, 0.49531800E+00, 0.19402900E+00, 0.15016600E+01, 0.28097400E+00, -.55317700E+01, -.23474500E+04, 0.11205200E+04, 0.10530300E+04, 0.11731800E+04, 0.94079500E+03, 0.11572900E+04, -.45879500E+03, -.67237000E+03, 0.23439400E+03, 0.70984400E+03, 0.14154300E+04, 0.50484700E+04, -.23619300E+04, 0.11411500E+03, -.25270600E+04, -.74129300E+03, -.10966200E+04, -.56077000E+03, 0.14546700E+04, -.80753200E+03, -.10768500E+04, -.22062700E+04, -.11168300E+03, 0.98499300E+02, 0.92694200E+03, 0.44491000E+02, 0.75212200E+03, 0.43049600E+03, 0.21004600E+02, -.11886800E+03, -.29060500E+03, 0.53480500E+03, -.74951300E+03, 0.49444000E+03, -.34038100E+03, -.10665300E+04, -.24501100E+03, 0.77029500E+03, 0.11235300E+04, -.17268400E+03, -.64671400E+03, -.15315300E+04, 0.11074900E+04, -.81901600E+03, 0.36574200E+02, -.26193400E+01, 0.24171000E+03, -.19383800E+02, 0.91836300E+02, 0.30704100E+02, -.11236000E+03, -.52919000E+02, 0.72694600E+02, -.22048000E+02, 0.46704700E+02, -.95691500E+04, 0.48025500E+04, 0.62772600E+04, 0.47804800E+04, 0.36581300E+04, 0.26719800E+04, -.90775000E+03, -.31965300E+04, 0.13109700E+04, 0.25834600E+04, 0.37334000E+04, -.32092700E+04, 0.15803600E+04, 0.68758000E+03, 0.16051000E+04, 0.48752300E+03, 0.34708300E+03, 0.41955100E+03, -.35775100E+03, 0.21796700E+03, 0.33595100E+03, 0.15576400E+04, -.13598700E+05, 0.68214000E+04, 0.50896900E+04, 0.67912500E+04, -.94492700E+03, 0.13925400E+03, 0.39808800E+03, -.39220100E+04, 0.26858200E+04, 0.61064800E+03, 0.59853300E+04, -.15575500E+03, 0.37489000E+02, -.77846100E+03, 0.86393300E+02, -.60475900E+03, -.13384500E+04, 0.79643800E+03, 0.21132600E+03, 0.13156300E+04, -.11562700E+04, 0.15739200E+03, -.13795300E+02, 0.11261400E+02, -.15859000E+02, 0.60736800E+01, -.82718900E+01, -.12863900E+02, 0.39191200E+02, 0.72501300E+01, 0.20866000E+02, -.84028600E+01, 0.15921700E+02, -.58058900E+03, 0.29346600E+03, 0.35317200E+03, 0.28841600E+03, 0.56413800E+03, 0.39405700E+03, -.22618500E+03, -.55880400E+03, -.58736200E+03, 0.32094700E+03, -.48561100E+03, 0.20712400E+04, -.99863200E+03, -.31176900E+04, -.10336800E+04, -.11485800E+04, -.92023800E+03, -.73674800E+03, 0.10085100E+04, 0.18056800E+04, -.11514100E+04, -.14935200E+04, -.39795300E+04, 0.19821900E+04, 0.29069000E+04, 0.19875000E+04, 0.13588100E+04, -.29745200E+03, 0.15501600E+04, -.24584500E+04, -.12375200E+04, 0.17353500E+03, 0.21855400E+04, 0.23754700E+02, 0.22493200E+02, -.49125700E+02, -.29745500E+02, -.24443900E+02, 0.11330800E+02, -.56239000E+01, 0.67847200E+01, -.56168600E+00, 0.51380100E+01, 0.42917400E+02, -.11293600E+01, 0.10018200E+03, 0.20395500E+03, 0.24436800E+03, 0.50957900E+01, -.58575000E+01, -.40306500E+02, -.82832000E+02, -.56118700E+02, 0.13923700E+03, -.45878500E+02, 0.28980200E+01, -.10057700E+02, -.36152500E+03, -.45547800E+03 },
        { -.66905300E+00, 0.22039900E+01, 0.10730800E+00, -.89678800E+00, -.87988500E+00, -.82331200E+00, -.22827800E+01, 0.12831000E+01, -.10638800E+01, -.83412100E+00, 0.64342900E+00, -.34817100E+01, 0.14832400E+01, 0.71076200E-01, 0.38012300E+00, 0.67176900E-01, 0.22308100E+01, -.15147200E+00, 0.17314800E+01, 0.89806200E+00, 0.14537700E+00, 0.19853500E+01, 0.11635200E+01, -.89681200E+00, -.59621700E+00, -.30014100E+00, -.83628100E+00, -.99060500E-01, -.63015900E+00, 0.49147500E+00, 0.95450800E-01, 0.58531200E+00, 0.11453400E+00, -.62386300E+00, 0.39595200E+00, -.25731000E+00, -.72997500E-02, 0.14497700E+00, 0.23526800E+00, -.11203700E+00, -.41510900E-01, -.69536600E+00, -.88192800E+00, -.18190200E+00, 0.30847000E+00, 0.11969700E+00, -.38380400E+00, -.43388600E-01, 0.98897300E-01, -.26131200E-01, -.14960500E+00, 0.11439300E+01, -.31417100E+00, -.34364500E+01, -.78399900E+00, 0.91169500E+00, -.91071300E-01, 0.31444100E+00, 0.97906800E-01, -.35242400E+00, 0.54171800E+00, 0.37410800E-01, 0.75349400E-01, -.91890100E+00, -.17501400E+00, 0.38119700E+00, 0.11727600E+00, 0.11430800E+01, 0.41154900E+00, -.33240200E-02, -.65782300E+00, 0.13331000E+01, -.24241200E+00, -.64810300E-01, -.19414900E+00, 0.24464800E+00, 0.24175900E+00, -.12349300E+01, -.22290400E+00, 0.52730100E+00, -.64692400E-04, 0.20267400E+00, -.11589300E+01, 0.65217200E+00, 0.76970200E-01, 0.88757800E-01, 0.38300800E+00, -.11509300E+01, -.21942500E+01, 0.15169600E+00, -.28360500E+01, -.35414400E-01, 0.84140900E+00, 0.21919200E+01, -.17113400E+00, -.39055000E+01, -.14806200E+01, 0.10052100E+01, -.85237700E+00, 0.11422600E-01, -.10862100E+01, 0.86044900E+00, 0.10648600E-01, -.70361600E+00, -.41452500E+00, -.44416200E+00, 0.36447100E+00, -.20947500E+01, 0.20873200E+01, 0.28331700E+00, -.50742400E-01, -.41493100E+00, 0.50966200E+00, -.59973400E-01, -.12403900E+00, -.20507300E+01, -.14150700E+00, 0.76843800E+01, 0.26756700E+01, 0.27973100E+00, 0.49744400E+00, 0.90742000E+00, -.19280200E+00, -.16358600E+01, 0.31813000E-01, 0.31135300E+00, -.11952200E+01, -.14363000E+01, -.21918300E+00, -.72145900E-01, 0.45696400E+00, 0.88121900E+00, -.22261500E+00, 0.18921300E+02, 0.69752700E+02, -.14479700E+00, 0.14207000E+02, -.21145900E+03, 0.73440100E+02, -.72379500E+02, -.52562600E+01, -.15651500E+03, -.44479700E+02, 0.24982100E+03, -.16626800E+03, -.14691100E+03, -.13003200E+03, -.16097200E+03, -.13811900E+03, 0.25199600E+03, 0.28574200E+03, 0.49762600E+02, -.12218500E+03, -.16229600E+03, 0.55474300E+02, -.40226600E+02, -.42686000E+03, -.25011200E+02, -.94647300E+02, -.20660300E+03, 0.19801600E+03, 0.19224800E+03, 0.28994000E+03, -.25189800E+03, 0.41457100E+03, 0.67423000E+03, -.29099300E+03, 0.10151800E+02, -.33798500E+03, 0.16632500E+03, -.45612000E+02, -.86373700E+02, 0.37038600E+03, 0.39072300E+02, -.10097700E+03, -.37766400E+03, 0.22049400E+02, -.17033100E+02, -.20880800E+02, -.10712500E+02, -.18797100E+02, -.12459400E+02, 0.46247700E+02, 0.17704100E+02, -.34892800E+02, 0.39676100E+01, 0.86698700E+01, 0.23494200E+04, -.11804400E+04, -.10751700E+04, -.11737800E+04, -.28226200E+03, -.38861200E+03, 0.50952400E+03, 0.10148700E+04, -.26255500E+03, -.21542400E+03, -.53297300E+03, -.34257100E+03, 0.18283000E+03, -.36209300E+02, 0.17112600E+03, -.85582500E+02, -.26436700E+03, 0.34518200E+03, 0.29345200E+03, 0.30813100E+03, -.28462000E+03, 0.25309000E+03, 0.24623700E+04, -.12391700E+04, -.14631200E+04, -.12294100E+04, 0.23218500E+03, -.34750000E+03, 0.49305400E+03, 0.90116600E+03, -.27850500E+03, -.17177000E+03, -.49188800E+03, -.39841100E+03, 0.21195900E+03, -.18047700E+03, 0.19684200E+03, -.17868500E+01, 0.35579900E+03, 0.98186100E+02, -.98650400E+02, -.89775600E+02, 0.32841000E+03, 0.35409400E+03, -.28548200E+01, -.16120700E+00, -.48030600E+01, 0.16535200E+01, -.11579200E+01, 0.45721800E+00, 0.30215100E+01, -.79652300E+01, 0.17500600E+01, 0.13188100E+01, 0.71694400E+01, -.44541800E+03, 0.22023900E+03, 0.52667000E+03, 0.22398300E+03, 0.74863500E+02, -.65002400E+00, 0.22130300E+03, 0.24651500E+03, 0.26395700E+03, -.24866400E+02, 0.51115300E+02, 0.69856700E+03, -.36369300E+03, -.22000000E+03, -.34980800E+03, -.22439400E+03, -.15933300E+03, 0.80716800E+02, 0.42613100E+02, -.49785300E+03, -.86345700E+02, -.27612500E+03, -.51939100E+03, 0.26564900E+03, 0.31437400E+03, 0.26036500E+03, 0.26432600E+03, 0.26812400E+03, -.14335700E+03, 0.10142800E+03, 0.47499800E+03, 0.22593200E+03, 0.89906000E+02, 0.61293600E+01, 0.30128900E+02, -.37657200E+02, -.92517400E+01, -.52676600E+02, 0.59384400E+01, 0.86029700E+01, 0.30482800E+02, -.32903800E+01, -.39544500E+01, -.34543100E+01, -.58504000E+01, -.19288800E+02, 0.11642500E+02, -.40052000E+02, 0.12223800E+02, 0.42509100E+02, 0.68244400E+01, 0.41417400E+01, -.34108100E+02, -.56659800E+02, -.15685600E+02, -.27098900E+01, -.21438200E+02, 0.58277700E+02, 0.68336300E+02 },
        { 0.36594800E+00, -.95455500E+00, 0.39879900E+01, 0.36623600E+00, -.10000300E+01, -.52978100E+00, -.10400000E+01, -.69240200E-01, 0.14876800E+00, -.21359800E+00, -.63590300E+00, 0.16358000E+01, -.40987600E+00, 0.61236400E+00, 0.40942200E+00, -.83303900E+00, 0.12811200E+01, -.21461200E+00, 0.48603400E+00, -.21565800E+00, 0.17325600E+01, 0.20538600E+01, -.46658500E-01, 0.11300900E+01, 0.45961700E+00, 0.11942400E+00, -.76321900E+00, 0.80282900E-01, 0.15936600E+00, 0.11427000E+00, 0.27073100E+00, -.13720500E+00, -.92378400E+00, 0.10103100E+01, -.10311700E+01, -.38384100E+00, -.76253800E-01, -.77487700E+00, 0.26908300E+00, 0.46047900E-01, 0.95192500E+00, 0.52048500E+01, 0.32180200E+01, 0.81494400E+00, -.16843700E+00, -.88267500E-01, -.14436700E+01, -.19446900E+00, -.67722800E+00, 0.24842600E-01, 0.68698700E+00, -.22652200E+01, -.17015300E-02, -.69059700E+00, 0.11967300E+00, 0.12803400E+00, 0.78094000E+00, 0.23325100E+00, 0.51996100E-01, 0.97693200E+00, -.12800000E+01, -.23907400E+00, 0.20535200E+00, 0.33496600E-01, 0.33631500E+00, 0.33504800E+00, 0.55151200E+00, 0.10992300E+00, -.82684900E+00, -.18541600E-02, -.40739800E+00, -.61974500E+00, 0.56882300E-01, -.81785700E-01, -.52734600E+00, 0.16081600E+00, 0.15535300E+00, 0.62664700E+00, 0.60845100E-01, -.55202500E+00, -.23498000E-01, 0.26414100E+00, -.52097000E-01, -.76775700E+00, 0.96333400E-01, -.29047300E+00, 0.18004200E+01, 0.20329800E+01, 0.24316900E+01, -.23683700E+00, -.11815300E+01, -.17716300E-01, 0.76020400E+00, -.84855600E-01, -.16538400E+00, -.86432300E+00, -.12327800E+01, 0.45141300E+00, -.21498300E+01, -.32952700E+00, -.12087100E+01, 0.26861900E+00, 0.66343700E-01, -.14655000E+01, -.67305100E-01, -.91061000E+00, 0.79025000E-01, -.19422200E+01, 0.12892000E+01, 0.13671100E+01, -.46833800E+00, -.93529700E+00, 0.41619200E+00, 0.29348800E-01, 0.43698900E+00, -.34951500E+00, -.51036900E+00, -.52069800E-01, 0.51557300E+00, 0.22967400E+00, -.61929500E+00, -.12177300E+01, 0.64559500E+00, -.19776100E+00, -.19420400E+00, 0.44615700E+00, 0.13803200E+01, -.10826100E+01, -.15994000E+00, 0.41882100E-01, -.11756300E+00, -.23618900E+00, -.94081900E-02, -.23424100E+00, -.10659500E+03, -.55802400E-01, -.25305100E+02, -.23960200E+02, -.62242100E+02, -.93718200E+02, -.23367200E+02, 0.56221300E+01, -.22507600E+02, -.26146800E+03, 0.11456000E+03, 0.15845100E+03, 0.12994600E+03, 0.85438700E+02, -.48350000E+02, 0.87312500E+02, 0.11403700E+03, 0.11266500E+03, -.46050800E+02, 0.84966700E+02, -.14792700E+03, 0.75177100E+02, -.61895900E+02, 0.74642000E+02, 0.48618600E+02, 0.67394500E+02, -.13152700E+03, -.14431000E+03, 0.22608300E+02, 0.77550300E+02, 0.20926700E+03, 0.81415800E+02, -.48230000E+02, -.29046500E+03, -.40920300E+02, 0.10603600E+03, 0.80011100E+02, 0.15035200E+02, 0.14515000E+03, 0.15876000E+03, 0.65035800E+02, 0.12885100E+03, 0.14272000E+02, -.75155500E+01, -.11458100E+02, -.70572100E+01, 0.57447400E+01, -.11098500E+02, -.14417100E+00, -.92027000E+01, -.13573700E+02, -.95890700E+01, -.23694900E+02, 0.14753800E+04, -.73796900E+03, -.51198000E+03, -.73746000E+03, -.97966600E+02, -.49648000E+03, 0.54081100E+02, 0.34852600E+03, -.35885700E+03, -.47449400E+03, -.47905300E+03, -.14076500E+03, 0.70065000E+02, 0.23836800E+03, 0.70317100E+02, 0.89687600E+02, 0.72040700E+02, -.27404500E+01, 0.11062100E+02, 0.19272900E+02, 0.98589800E+02, 0.42348400E+02, 0.11437800E+04, -.57273900E+03, -.78790300E+03, -.57145400E+03, 0.28812900E+02, -.35765200E+03, 0.11632900E+03, 0.25703700E+03, -.28016100E+03, -.38602200E+03, -.37570000E+03, 0.26604700E+02, -.86351400E+01, 0.79866800E+02, -.14070100E+02, 0.47601300E+01, 0.74866400E+02, 0.24253400E+02, -.78612000E+02, -.11908800E+03, 0.94148400E+02, -.28779700E+02, -.12191600E+01, 0.99435000E+00, 0.31143300E+01, 0.66622900E+00, 0.27160800E+01, 0.16537600E+01, -.63514300E+01, -.79387500E+00, 0.17566100E+01, -.26443700E-01, -.53127500E-01, 0.85690800E+02, -.46095500E+02, -.16365400E+03, -.42544400E+02, 0.17940600E+02, -.12440600E+02, -.18181200E+02, 0.29958300E+02, 0.59274200E+02, -.19117400E+01, 0.36974700E+03, -.33885800E+03, 0.16722000E+03, 0.30351600E+03, 0.16929700E+03, 0.15027700E+03, 0.89075200E+02, 0.19777100E+03, -.12238100E+03, -.11268400E+03, 0.84810300E+02, 0.20158000E+02, 0.80561600E+03, -.40116400E+03, -.43658700E+03, -.40263800E+03, -.11531800E+03, -.78104700E+02, -.34503000E+03, 0.20507800E+03, 0.78810700E+02, -.76559900E+02, -.12785200E+03, 0.38308600E+00, -.35346600E+01, -.34067300E+02, -.12003200E+02, 0.22598200E+02, -.32562700E-01, 0.13961100E+02, 0.52802800E+00, 0.45478600E+00, 0.44222100E+01, -.30830000E+01, 0.12471600E+02, -.20293900E+01, 0.13486400E+01, 0.60402100E+01, -.48048100E+01, 0.39481800E+02, -.68304400E+00, 0.33931200E+02, 0.64700400E+01, -.39107500E+02, -.20744200E+02, 0.37920700E+00, 0.12920700E+02, 0.33647000E+02, 0.50414600E+02 },
        { -.67801900E+00, 0.96293900E+00, -.51309000E+01, 0.43412300E+00, 0.41298800E+01, 0.72748500E+00, 0.65171300E+01, 0.35596700E+00, -.22397300E+00, 0.34629800E+00, 0.32674800E+00, -.39687500E+01, 0.10220200E+01, -.80886500E+00, -.16073800E+00, -.30171100E+00, -.56553900E+01, 0.79267400E+00, -.11130600E+01, 0.12503100E+01, -.15445800E+01, -.25520100E+01, 0.48362300E+00, -.12912900E+01, -.10505900E+01, 0.16598100E+00, -.14598200E+01, 0.11680000E+01, -.32376400E-03, 0.76431600E+00, 0.95847500E+00, 0.77449500E+00, -.14090600E+01, -.19969200E-01, 0.10170500E+00, -.11717900E+00, -.13884000E+00, 0.49192900E+00, 0.12545400E+01, 0.26964200E+00, 0.19683300E+00, -.11455900E+01, -.35386700E+01, -.85225900E+00, 0.15220500E+01, 0.10951800E+01, 0.25647900E+01, -.21432800E+00, 0.87731600E-01, 0.10523500E+00, 0.77840600E+00, -.19702000E+00, -.99425500E+00, 0.23211700E+01, 0.38122900E+00, 0.13169300E+01, -.10660100E+00, -.10814400E+01, 0.66972000E+00, -.43841900E-01, 0.50467200E+00, -.24321000E+00, 0.37239700E-01, -.12183000E+00, -.46917600E-01, 0.23598000E+00, -.13143500E+00, 0.63038200E+00, -.55529800E-01, 0.77255400E-02, -.12756400E+01, -.12528100E+00, 0.16412000E-01, -.72419400E-01, 0.50793500E+00, -.10961100E+00, 0.47058300E-02, 0.29210400E+00, -.26004300E+00, 0.48431600E+00, 0.46326700E-02, -.14311700E+00, -.11041900E+00, 0.80127200E-01, -.33531500E-01, 0.38419600E+00, -.11366200E+00, -.71492100E+00, 0.82173500E+00, 0.34200600E+00, 0.78442300E-01, 0.10141600E+00, 0.57757400E+00, -.24273000E+00, -.64647600E-01, 0.34482000E+00, 0.86183600E+00, -.20037900E+00, -.12395400E+00, -.15757800E+00, 0.26216000E+01, -.22763100E+00, -.43911300E-01, 0.17165800E+00, -.28988000E+00, 0.14596100E+01, 0.37742200E+00, 0.84289000E+00, -.20276500E+01, -.74898100E+00, -.67009300E+00, 0.59232800E-01, -.28486800E+00, -.48731900E-01, -.28203100E+00, 0.48755300E+00, 0.23593500E+00, -.16323700E+01, -.21856600E+01, 0.17146000E+00, -.63644100E+00, 0.15339200E+01, -.18904300E-01, 0.13461700E+01, 0.11317000E+00, 0.10474600E+01, 0.16516600E+01, -.93104300E-01, 0.19495900E+00, 0.41353900E+00, -.74623300E+00, -.96761100E+00, 0.23601900E+00, -.16504200E+00, 0.15546100E+00, 0.35824500E+01, -.87845700E+01, -.56063600E+01, 0.63713400E+02, 0.49310800E+02, 0.23539900E+02, -.98884100E+01, -.15218800E+02, 0.49668000E+03, -.25775500E+03, -.23368600E+03, -.25368000E+03, -.10860800E+03, -.11533500E+03, 0.11891600E+02, 0.17483700E+03, -.14085400E+03, -.10117700E+03, -.43092400E+01, 0.67863400E+02, -.40639500E+02, -.17266800E+03, -.27207300E+02, -.11545100E+03, -.10493400E+03, 0.14525700E+03, -.59020100E+02, 0.87093800E+02, -.44640200E+02, 0.22154300E+03, 0.17296600E+03, -.85663100E+02, -.15998000E+02, -.88062600E+02, 0.69766100E+02, 0.34356800E+02, -.61622500E+02, 0.27096700E+02, 0.12638600E+02, 0.54926000E+02, -.12959900E+03, -.18174800E+02, 0.10663200E+02, -.47746800E+01, 0.97760700E+01, -.85587300E+00, -.50868500E+01, 0.52494000E+02, -.14108700E+02, -.20401600E+02, -.80042200E+01, 0.42085100E+01, 0.20145100E+04, -.10052800E+04, -.12007300E+04, -.10048700E+04, -.67868900E+03, -.94319900E+03, 0.82501800E+03, 0.76317900E+03, -.19025700E+03, -.90442100E+03, -.86066800E+03, -.24790200E+03, 0.11808900E+03, 0.11483000E+03, 0.12364600E+03, -.74379200E+01, -.13945300E+03, -.57287900E+02, -.97399200E+02, 0.39946700E+02, -.10337800E+03, 0.26814600E+03, 0.25790500E+04, -.12853000E+04, -.10772500E+04, -.12848700E+04, -.68140400E+03, -.86740000E+03, 0.80315500E+03, 0.82117500E+03, -.52417800E+03, -.84790600E+03, -.12166400E+04, -.69026300E+02, 0.38501100E+02, -.32634700E+02, 0.27397500E+02, 0.26418000E+02, 0.93783900E+02, -.13052300E+03, -.19021200E+03, -.23854500E+02, 0.53535700E+02, 0.90346600E+02, -.56548800E-01, -.63389200E+00, -.13829400E+01, 0.53900700E+00, 0.14429700E+01, 0.42798900E+01, 0.65516300E+01, -.82751400E+01, 0.43791500E+00, 0.43897600E+01, 0.72860400E+01, -.12335800E+03, 0.60611600E+02, 0.12696400E+03, 0.63506800E+02, 0.26228700E+02, -.62931300E+01, -.63198100E+01, -.44222800E+02, 0.36793800E+02, 0.31605700E+01, 0.56473300E+02, 0.55078200E+03, -.26814100E+03, -.76731200E+02, -.27658500E+03, -.21869400E+03, -.15381900E+03, 0.10467100E+03, -.39347400E+02, -.39981300E+03, -.16219900E+03, -.41591900E+03, -.39140800E+03, 0.19059600E+03, -.23248000E+02, 0.19714600E+03, 0.25828000E+03, 0.14869300E+03, -.10195200E+03, 0.11235100E+03, 0.48140500E+03, 0.13307300E+03, 0.23494900E+03, 0.54704100E+01, 0.41052700E+02, -.10822300E+02, -.11327400E+02, -.15095400E+02, 0.10650600E+01, 0.69656600E+01, 0.47073600E+02, -.67978500E+00, -.83510500E+00, -.22293500E+01, 0.10069300E+01, -.73122700E+01, 0.49931200E+01, -.12525700E+02, 0.11023000E+02, 0.82596300E+01, 0.35270900E+00, 0.28567800E+02, 0.81679000E+00, -.82767200E+02, -.50070300E+01, -.60103000E+00, -.16186400E+01, 0.40572300E+02, 0.29876700E+02 },
        { 0.97605300E-01, -.53524500E+00, -.49147300E+00, 0.63890000E-01, -.12703800E+00, -.10474800E+00, -.76884600E-01, 0.51701900E+00, 0.87064800E-01, -.67409000E+00, -.47482700E-01, 0.37121900E+00, 0.74559400E-01, 0.26544400E+00, -.27557800E+00, -.19269500E+00, 0.10899600E+00, 0.10477100E+00, 0.25436900E+00, 0.17818200E-01, 0.58442100E+00, -.52193300E+00, 0.86877200E-01, 0.40763100E+00, -.11683800E-01, -.91036100E-01, -.39529100E-01, 0.22588700E+00, 0.15715800E+00, -.36506100E-01, 0.26229900E-01, -.10716900E+00, -.18775400E+00, 0.27777200E+00, 0.43357200E-01, 0.14620700E+00, -.12373700E-01, 0.23735400E+00, 0.72740800E-01, 0.42459600E-01, -.90018700E-01, -.59201200E+00, -.30997100E+00, 0.22756000E+00, 0.13295200E-01, 0.20042700E-01, 0.17522800E+00, -.71678400E-02, -.14088400E+00, 0.27832200E+00, -.19073100E+00, 0.44986900E+00, 0.16798000E+00, 0.34714000E+00, -.19041200E+00, 0.52687700E+00, -.39411700E+00, 0.10925900E-01, -.12130500E+00, -.10261700E+00, 0.21793100E+00, -.29563100E+00, 0.17152400E+00, -.21179800E+00, -.49746500E-01, -.10743300E+00, -.21315100E-01, 0.42849600E+00, 0.14718900E-02, 0.57216000E-03, 0.12394800E+00, 0.11417100E+00, 0.57194100E-01, 0.77400800E-02, -.23182000E+00, -.11143200E+00, 0.73560900E-01, 0.24198300E+00, -.27237800E-01, -.11087800E+00, -.85824700E-02, -.48276600E-02, 0.30620700E+00, 0.55262800E-01, 0.16370300E-01, 0.29858800E-01, 0.19194000E+00, 0.26362500E-01, -.43372600E+00, -.21688000E-01, -.10121700E+00, -.45311600E-01, -.17079400E+00, 0.65397700E+00, -.10162500E+00, -.47448100E+00, -.13094900E-02, 0.23443300E+00, 0.32962600E+00, -.13065600E-01, 0.10999500E+01, 0.16562200E+00, -.11640900E-01, 0.13495400E+00, -.37017200E-01, -.17790000E-01, -.10194800E+00, 0.22041100E+00, -.59744800E+00, 0.24045900E+00, -.93463700E-01, -.96614900E-01, 0.65004500E-01, 0.66014600E-02, -.10779100E+00, 0.78265200E-01, 0.58303800E-01, -.13236000E+01, -.13397700E+00, 0.44381000E-01, -.38774600E-01, 0.40065000E+00, -.43952100E-01, -.27281200E+00, -.18452800E-01, -.15068500E+00, -.31291200E+00, -.11789300E+00, -.40585800E-01, -.88279300E-01, -.25498600E+00, -.26277800E+00, 0.17577400E-01, -.72996600E-01, 0.25917600E+00, 0.23006000E-02, -.37976600E+02, -.21542900E+01, 0.69102300E+02, 0.52837900E+02, 0.16073400E+02, -.20367300E+02, 0.24184000E+02, -.71508100E+02, 0.37726100E+02, 0.29677700E+02, 0.35937900E+02, 0.22013500E+02, 0.38049200E+02, -.15340000E+02, -.48462400E+02, 0.32982800E+01, 0.31677000E+02, 0.15453000E+02, -.11162800E+02, 0.52965400E+01, -.95954100E+02, 0.59170800E+01, -.83090200E+02, -.51734600E+02, 0.57859700E+02, 0.24320000E+02, 0.20454200E+02, -.33372900E+02, -.27216900E+02, -.11281700E+03, 0.58172700E+02, 0.15304100E+03, 0.56330900E+02, -.42121000E+02, -.41584800E+02, 0.57224000E+02, 0.67961400E+01, -.10248900E+02, -.34476300E+02, 0.10308200E+02, 0.11770100E+01, -.41390800E+00, 0.75677300E+01, -.55449600E+00, -.90756900E+01, -.76219900E+01, 0.23762800E+02, 0.18093300E+02, 0.32839400E+02, -.94363100E+01, 0.51579600E+01, -.12770200E+04, 0.63922500E+03, 0.60060200E+03, 0.63863200E+03, 0.38890500E+02, 0.19220700E+03, 0.19877200E+03, -.42318800E+03, 0.25482400E+03, 0.24755000E+03, 0.68192300E+03, -.11441100E+03, 0.57181300E+02, -.36445500E+02, 0.57190400E+02, -.16561500E+02, -.23861400E+02, -.12653500E+02, -.48048800E+02, 0.35118600E+02, 0.68847500E+01, 0.79354500E+02, -.13266500E+04, 0.66429500E+03, 0.62947500E+03, 0.66356000E+03, -.13318200E+03, 0.51264900E+02, 0.28756300E+03, -.37952300E+03, 0.29251400E+03, 0.14539900E+03, 0.72667600E+03, 0.16391700E+03, -.82373200E+02, 0.10787900E+01, -.82059100E+02, -.57867400E+02, -.16662700E+01, -.14211900E+03, -.75020700E+02, -.69115500E+02, 0.27034700E+02, -.52876100E+02, -.38201900E+00, 0.12840700E+00, -.31849200E+01, 0.21630500E+00, -.14839000E+01, -.37505900E+00, 0.21753400E+01, -.31378600E+01, -.60109800E+00, 0.10175800E+01, 0.50631900E+00, 0.10188400E+02, -.65522300E+01, 0.44470500E+02, -.50179600E+01, -.47022200E+02, -.41532700E+02, 0.32910000E+02, 0.60102800E+02, 0.30427300E+02, -.43220400E+02, -.82467600E+02, 0.46563800E+03, -.23249100E+03, -.23845000E+03, -.23287800E+03, -.61900400E+02, -.78885900E+02, -.77255600E+02, 0.10930500E+03, 0.69114900E+01, -.64787000E+02, -.13407800E+03, -.71483200E+03, 0.35737600E+03, 0.34152000E+03, 0.35748700E+03, 0.65324800E+02, 0.63123900E+02, 0.17080800E+03, -.12016200E+03, 0.11467000E+02, 0.60278000E+02, 0.24089900E+03, 0.34152900E+01, -.55602900E+00, 0.17032800E+02, 0.10551200E+02, 0.89914500E+01, 0.17935200E+01, -.10256100E+02, -.49161800E+01, -.89527900E+00, -.31367400E+01, 0.36532100E+01, 0.10967200E+01, -.46626800E+01, -.14215200E+02, -.48077700E+01, 0.43510300E+01, -.14513300E+02, -.54219600E+01, -.29341500E+02, 0.10475500E+02, 0.25076600E+02, 0.24931700E+01, -.84744000E+00, -.16809300E+01, -.19396800E+02, -.16443900E+02 },
        { 0.70777000E+00, -.60182800E+00, 0.16360600E+00, 0.17239600E+00, 0.25166400E+00, -.62517800E-01, 0.74238400E+00, -.13317900E+00, 0.20492200E+00, 0.36566000E+00, -.10553400E+00, -.16521300E+01, -.38464900E+00, -.18697900E+01, 0.50622300E+00, 0.32173300E+00, -.67043300E+00, -.25316300E+00, -.43059200E+00, -.11011300E+01, -.51389400E+00, -.89145700E+00, 0.82352900E-01, 0.89703400E+00, -.10828300E+01, 0.41030500E+00, 0.71469700E+00, -.11589600E+01, -.25511800E+00, 0.75717000E+00, 0.16106400E+01, 0.59866500E+00, 0.22373300E+01, -.15285200E+01, -.63895700E+00, -.50526300E+00, 0.13296900E+00, -.22202000E+01, -.44487200E+00, -.18868900E+01, -.11092200E+01, 0.15001800E+01, 0.18367600E+00, -.88677500E+00, 0.17585600E+01, -.11415900E+01, -.29048100E+01, 0.11576800E+00, 0.74461100E+00, -.31501000E+01, 0.41724000E+00, -.19369900E+01, 0.26829100E-01, -.43841200E+00, -.28130200E+00, -.18965500E+01, -.48287400E+00, 0.75677900E+00, -.18173900E+00, 0.19187700E+01, -.20975800E+01, 0.58893400E+00, -.86511400E+00, 0.60506200E+00, 0.48636900E+00, 0.31918900E+00, 0.21860000E+00, 0.13678900E+00, -.10281500E+01, -.41518700E-02, 0.18214300E+01, 0.27978200E+01, -.20727600E+00, 0.47824000E-01, -.50144600E+00, 0.37028200E+00, 0.12136500E+00, -.56209400E+00, 0.33146900E+00, -.10393600E+00, -.54600300E-02, -.52679600E-01, 0.16220200E+01, -.28621800E+00, -.39336300E+00, -.91337400E-01, -.59309500E+00, -.16634100E+01, 0.18149200E+01, 0.11165300E+00, 0.20043400E+01, -.52444900E-01, -.65956500E-01, -.51165700E+01, -.40048000E+00, -.68969500E+00, 0.16354800E+01, -.60587900E+00, 0.35742500E+00, -.49512700E+00, 0.36059800E+01, -.13567000E+01, 0.24622300E-01, -.85359800E-01, -.20470200E+00, 0.32560000E+00, -.34752500E+00, 0.88638800E+00, -.16803700E+00, -.19305000E+01, 0.75616300E-01, 0.83593700E+00, -.11891800E+01, -.10867100E+00, -.19801900E+00, -.26512300E+00, 0.35691700E+00, -.11372900E+01, 0.29885700E+00, 0.17089600E+00, -.18461300E+00, 0.93395800E+00, -.16957500E-01, -.39925000E+00, 0.11846700E+00, 0.77688900E+00, 0.76605100E+00, -.21658200E+01, -.11411000E+00, -.33406800E+00, -.81900300E+00, 0.99630100E+00, -.25507400E+00, -.15653500E+00, 0.29066700E+00, -.55792800E-01, 0.51812300E+00, -.20839400E+03, 0.26945100E+03, -.92393700E+01, 0.57555800E+02, -.21073200E+03, -.11025100E+03, 0.70723000E+03, -.38514100E+03, -.34836500E+03, -.36458700E+03, -.23843700E+03, -.20582700E+03, 0.15973400E+03, 0.41106100E+03, -.13525000E+03, -.19572800E+03, 0.11773100E+03, 0.72360300E+02, -.45253200E+02, -.27612900E+03, -.26747800E+02, 0.44645400E+02, -.16257200E+03, 0.25666100E+03, 0.46971300E+02, 0.39064700E+03, -.85124200E+02, 0.34632800E+03, 0.52016600E+03, -.26815100E+03, 0.14761300E+02, -.26271400E+03, 0.26340500E+03, 0.20513600E+03, -.26116200E+03, 0.65939900E+02, -.90251600E+02, 0.22388000E+03, -.25767200E+03, -.34726900E+02, 0.19847200E+02, -.19277900E+02, 0.18389700E+02, 0.26609400E+02, 0.52522700E+02, 0.49639800E+02, -.10839300E+03, -.17478800E+03, 0.65778200E+02, -.84081100E+02, 0.55926900E+04, -.27909300E+04, -.31241800E+04, -.27930700E+04, -.86646700E+03, -.17537000E+04, 0.15447300E+04, 0.21099600E+04, -.96105400E+03, -.16115100E+04, -.45227600E+04, -.69808900E+03, 0.34064700E+03, 0.26312100E+03, 0.34854400E+03, 0.11167200E+03, -.13545600E+03, 0.18151900E+03, 0.25912100E+02, 0.18084800E+03, -.86893900E+02, 0.48853800E+03, 0.66378700E+04, -.33093900E+04, -.29164000E+04, -.33126100E+04, -.56399200E+03, -.14533300E+04, 0.14080200E+04, 0.20504600E+04, -.17379700E+04, -.13883000E+04, -.54016100E+04, -.34361900E+03, 0.18169500E+03, -.10509300E+03, 0.16378500E+03, 0.26692400E+02, 0.17854000E+03, 0.16537800E+03, -.10902400E+03, 0.11628400E+03, 0.13175100E+03, 0.18191600E+03, 0.93165700E+00, -.10642200E+01, -.34808100E+00, 0.28530900E+00, 0.67002400E+01, 0.92738700E+01, -.22515800E+01, -.11576000E+02, 0.55796900E+00, 0.73444900E+01, 0.74983100E+01, -.27598000E+03, 0.12932000E+03, 0.42526000E+03, 0.14152600E+03, 0.20513400E+03, 0.22745300E+03, -.10526800E+03, -.17747800E+03, -.42202400E+02, 0.22758000E+03, 0.15916100E+03, 0.42387000E+03, -.20440700E+03, 0.25569600E+03, -.21368400E+03, -.21356600E+03, -.27656800E+03, 0.23660000E+03, -.40182500E+03, -.82561000E+03, -.20501000E+03, -.70333100E+03, 0.92281200E+03, -.46629300E+03, -.91662700E+03, -.45922900E+03, 0.24412600E+03, 0.20755900E+03, -.34164900E+03, 0.72815000E+03, 0.61944400E+03, 0.16000000E+03, -.24093200E+03, 0.55001800E+01, 0.15507800E+03, -.39699300E+02, -.17602200E+02, -.25818500E+02, -.22333300E+02, 0.33519700E+02, 0.17295500E+03, -.22101600E+00, 0.57453600E+01, -.18764900E+02, -.26421500E+02, -.16301900E+02, -.21411700E+01, -.67867300E+02, 0.12880100E+02, 0.55648000E+02, 0.48535700E+02, 0.32722300E+03, -.24126200E+02, -.41929600E+03, -.23981700E+02, -.65045500E+00, 0.76461900E+01, 0.10147800E+03, 0.46930400E+02 },
        { -.33942100E+00, -.14874000E+01, -.78833200E-01, 0.36700400E+00, 0.90878600E+00, 0.40523000E+00, 0.21764200E+00, -.22261000E+01, 0.21351300E+00, 0.77681700E+00, -.33969400E+00, -.21216600E+01, -.21050200E+00, -.62792900E+00, -.14129700E+01, -.35847700E+00, -.22224500E+01, 0.25051100E+00, -.18831000E+00, -.14194400E+00, -.27040300E+00, -.50043500E+00, -.14315200E+00, -.59497000E+00, -.28175000E+00, -.21821200E+00, -.33745600E+00, -.79244100E+00, 0.11913700E+00, 0.13675200E+00, -.58310500E+00, -.20821800E+00, -.45830200E+00, 0.63478000E+00, 0.42175100E+00, 0.18188900E+00, -.25259800E-01, 0.10092100E+01, -.70463000E-01, 0.32882600E+00, 0.13373500E+00, -.34648000E+01, -.25874100E+01, -.54019500E+00, 0.88396700E+00, 0.32876400E+00, 0.13478500E+01, 0.60438200E-01, -.56318100E-01, 0.41298600E+00, -.20495300E+00, 0.21781400E+01, 0.11772600E+01, -.24780800E+01, -.36327400E+00, -.23224200E+00, 0.94623500E+00, -.17033400E+01, 0.27769800E-02, -.15737400E+01, 0.19542900E+01, 0.14852600E+00, 0.43365500E+00, -.42753300E+00, -.23352800E+00, -.46972600E+00, 0.19148000E+00, 0.31408900E+00, -.40551200E+00, 0.72570800E-03, -.11486300E+01, 0.28509300E+00, 0.33494900E+00, 0.96869900E-01, -.10190200E-01, 0.42250100E+00, 0.13069500E+00, -.88114800E+00, 0.43406400E+00, 0.25219700E+00, 0.22953100E-02, 0.20114500E+00, -.14501000E+00, -.55237500E-01, -.18982200E+00, -.73516600E+00, 0.30761100E+00, -.28924600E+00, -.16202400E-01, -.18834900E+00, -.69049300E+00, -.26645500E+00, 0.46366400E+00, 0.26720200E+00, -.45774300E+00, -.22789900E+01, -.82551000E+00, 0.37889700E+00, -.43702400E+00, 0.68203600E-01, -.37710600E+01, 0.67787400E+00, 0.60570300E-01, -.11189800E+01, -.19359900E+00, -.11859900E+01, 0.20127000E+00, -.15545300E+01, 0.15593200E+01, 0.62287500E+00, 0.57986300E+00, 0.22598400E+00, 0.97424300E-01, -.15056100E+00, 0.34082300E+00, -.47414900E-01, -.34888900E+00, -.10470300E+01, 0.28660200E+00, -.34989300E-01, -.72173600E+00, -.88978600E+00, 0.54643100E+00, -.90948000E+00, 0.15651900E+00, -.15105300E+00, 0.68002900E+00, 0.54242500E+00, 0.65799800E-01, 0.14340300E-01, 0.30283100E+00, 0.85594700E+00, -.31650000E-01, 0.93730600E-01, 0.35946200E-01, -.47495200E-02, 0.25332900E+01, 0.33978600E+00, -.32913100E+03, -.17413300E+03, 0.31434600E+02, 0.84455700E+02, -.21775400E+02, -.13967900E+03, 0.10060700E+03, -.78733000E+02, 0.72186700E+02, 0.61374000E+02, 0.21872100E+03, -.18057400E+03, -.34083800E+03, -.35133400E+02, 0.20382900E+03, 0.39919000E+02, 0.84452400E+02, -.32336800E+02, 0.41755800E+03, -.45178000E+02, 0.27093800E+03, 0.17136300E+03, -.20984500E+03, 0.16329900E+03, -.27030000E+03, 0.23717400E+02, -.50094700E+03, 0.13903600E+03, -.66041500E+02, -.32802000E+03, -.68720300E+02, 0.55485500E+02, 0.89790200E+02, -.65463500E+02, 0.12017200E+02, -.29626600E+02, 0.57602500E+02, 0.78441300E+02, -.16038700E+02, 0.54967800E+01, -.21983300E+02, 0.77027000E+01, -.31420400E+01, -.89674900E+01, -.10473400E+03, -.34951300E+01, 0.24967900E+02, -.30508400E+01, 0.30925700E+02, -.10125900E+04, 0.50088100E+03, 0.52927000E+03, 0.50526300E+03, 0.39790600E+03, 0.54057300E+03, -.12244500E+04, -.26552300E+03, 0.12151800E+03, 0.35444200E+03, -.14844600E+02, 0.14268500E+04, -.70460100E+03, -.21436500E+03, -.71328400E+03, -.60974700E+02, 0.29870000E+03, -.82492600E+02, 0.31035500E+03, -.31777300E+03, 0.14496900E+03, -.10011500E+04, -.94661700E+03, 0.46371800E+03, 0.70840300E+03, 0.47131200E+03, 0.10608400E+04, 0.10904600E+04, -.15993300E+04, -.23905000E+03, 0.30344100E+03, 0.76866200E+03, 0.61850800E+02, 0.10820300E+03, -.62840600E+02, 0.22845700E+03, -.51938100E+02, 0.11887500E+03, -.16786200E+03, 0.38438700E+03, 0.63965400E+03, 0.10549300E+03, -.21967600E+03, -.35721800E+03, 0.31437400E+01, -.86632400E+00, 0.13802900E+02, -.18044600E+01, 0.26016100E+01, -.55519900E+01, -.23975900E+01, 0.24564800E+02, -.32149700E+01, -.97509900E+01, -.15967000E+02, 0.33221700E+03, -.15224900E+03, -.34055200E+03, -.16714700E+03, 0.53538400E+02, 0.14672200E+03, -.17384900E+03, -.17833000E+03, -.22711200E+03, 0.14162600E+03, 0.70570600E+02, -.18312900E+04, 0.90699400E+03, 0.91933200E+03, 0.91618500E+03, 0.64575900E+03, 0.54998300E+03, 0.97196100E+01, -.10695500E+03, 0.58583300E+03, 0.49007200E+03, 0.10266100E+04, 0.15681000E+04, -.77827300E+03, -.55199800E+03, -.78471900E+03, -.70123600E+03, -.37251700E+03, -.21198000E+03, -.53812800E+02, -.57352700E+03, -.34288100E+03, -.70146400E+03, -.23587400E+02, -.84630300E+02, -.87931500E+01, 0.72152600E+01, 0.25641800E+02, 0.54212800E+01, 0.15807500E+02, -.84434900E+02, 0.40861900E+01, 0.96268700E+01, 0.68699300E+01, 0.19418100E+00, 0.10103500E+02, 0.28300500E+01, -.54690800E+01, -.27258700E+02, 0.16372300E+02, -.12731500E+02, -.76202000E+02, -.23610900E+02, 0.16815900E+03, 0.24478200E+02, 0.39449600E+01, 0.16172300E+02, -.14008500E+02, 0.21059500E+02 },
        { -.18214600E+00, -.66035300E+00, 0.95301300E+00, -.72146400E+00, 0.21506000E+00, -.18020500E+00, -.51341800E+00, -.11768000E+01, -.50956000E+00, -.15499900E-02, 0.17908300E+00, 0.28386700E+00, -.30424500E+00, -.15664500E+00, 0.45084300E+00, -.13813600E+00, 0.35967300E+00, -.12786900E+00, 0.14932000E+01, -.16099700E+00, 0.25592400E+00, 0.12148500E+01, -.28651200E+00, 0.49150800E+00, 0.77927300E+00, 0.76238200E+00, 0.48110900E+00, -.78568800E+00, -.87402100E-01, -.10140400E-01, -.36514700E+00, -.61118200E-01, 0.12242400E+01, -.51095800E+00, -.34044000E-01, 0.22644500E+00, 0.39276700E-01, -.30950700E+00, -.30825600E+00, -.51883800E+00, -.25714800E+00, 0.36430000E+00, -.33620100E+00, -.14827500E+00, -.46606600E+00, -.21267800E-01, -.24701200E-01, 0.24955300E-01, 0.36614100E-01, -.49517700E+00, -.12020600E+01, 0.10248900E+01, 0.21304900E+00, 0.24681000E+00, -.20253500E+00, -.54086200E+00, -.65375200E+00, -.60138500E-01, -.47160500E-01, -.36070400E+00, 0.49469700E+00, 0.11833800E+00, 0.63909100E-03, 0.74394200E-01, -.12842900E+00, -.42257500E+00, -.37321600E+00, -.13169000E+00, 0.64330300E+00, 0.33888700E-02, 0.17833400E-01, 0.12831500E+00, -.13722200E+00, 0.14341600E+00, -.54922000E-01, 0.20567000E+00, -.31139000E-01, -.67157500E+00, 0.64807000E-02, 0.21951900E+00, 0.88443000E-02, -.21324400E-01, -.83344800E+00, 0.12235300E+00, 0.94570700E-01, 0.10013300E+00, 0.30332400E+00, -.39678900E+00, -.32755000E+00, -.15119000E+00, 0.85325200E+00, 0.13089800E+00, -.86069700E+00, 0.66748400E+00, 0.10625500E+01, 0.19881700E+01, -.78212400E-01, 0.17123200E+00, 0.15416600E+01, 0.32696900E+00, -.28598400E+01, -.57681300E+00, 0.42017900E-04, 0.52308400E+00, 0.22010800E+00, 0.49962100E+00, 0.10604000E-01, 0.56465700E+00, -.12588900E+01, -.41221900E+00, 0.11964500E+01, -.13050200E+00, 0.30231300E+00, 0.44403100E-01, -.18645200E+00, -.54393700E+00, 0.17868600E+00, 0.32632000E+01, 0.10933100E+01, 0.16326700E+00, 0.95946800E-01, 0.13935900E+00, 0.41355700E-01, -.77901500E+00, -.13174600E+00, -.92548200E+00, -.19105200E+01, -.97731300E-01, -.11587400E+00, -.17791400E+00, 0.36375300E+00, 0.11798400E+01, -.81929600E-01, 0.39226300E+00, 0.22026200E+00, 0.12101800E-01, 0.47217000E+00, 0.45826400E-01, -.27153400E-01, 0.44553300E+02, 0.45987300E+02, -.11812000E+02, -.22436000E+02, 0.46644800E+03, -.17773100E+03, -.21989300E+03, -.23023900E+03, -.66832300E+02, 0.85573800E+02, -.19109500E+03, -.16808700E+03, -.22993800E+03, 0.70753900E+02, -.16557400E+03, 0.73397800E+02, -.34030000E+02, 0.15760200E+03, -.41524700E+02, 0.33891300E+02, 0.87889900E+02, -.75628900E+02, 0.63010000E+02, -.14817500E+03, 0.43985100E+02, -.26148400E+03, -.89159800E+02, 0.59043900E+02, 0.98069100E+02, 0.45844400E+02, -.34914700E+02, 0.42693600E+02, -.45860500E+02, -.81972000E+02, -.13936200E+03, 0.57868700E+02, 0.22520400E+02, -.13317600E+02, 0.64184100E+01, -.14088100E+02, 0.61447500E+01, 0.11703100E+02, 0.33786200E+02, -.68780900E+02, -.33484300E+02, -.34637000E+02, 0.37257200E+02, -.38878900E+02, -.69944400E+03, 0.34696100E+03, 0.14035700E+03, 0.34803300E+03, 0.18655200E+03, 0.61288200E+03, -.78552200E+03, -.40980100E+03, -.15468700E+03, 0.54229200E+03, -.72734100E+03, 0.59206200E+03, -.29083600E+03, -.15811000E+03, -.29576700E+03, -.57559400E+02, 0.10080700E+03, -.10237100E+03, -.54353600E+02, -.20907800E+03, 0.10004200E+03, -.47147800E+03, -.53574800E+03, 0.26521000E+03, 0.55639200E+03, 0.26460100E+03, 0.43432000E+03, 0.74665800E+03, -.95643100E+03, -.35144400E+03, -.24534300E+03, 0.65675100E+03, -.93489600E+03, 0.23258500E+03, -.13309400E+03, 0.99226800E+02, -.11314800E+03, -.33318300E+02, -.17861500E+03, 0.11405600E+03, 0.25817300E+03, 0.14329400E+03, -.16128500E+03, -.27359900E+03, 0.35445500E+01, -.23972700E+01, 0.32402500E+01, -.21500600E+01, 0.24911900E+00, -.10358600E+00, -.40272700E+01, 0.82021600E+01, -.43238900E+01, -.20242800E+01, -.59977600E+01, 0.45690300E+03, -.21533800E+03, -.24313100E+03, -.23002000E+03, -.17594700E+02, 0.11122100E+03, -.17845100E+03, -.10037400E+03, -.29577600E+03, 0.10543900E+03, -.23963400E+03, -.76420500E+03, 0.38310100E+03, 0.44872200E+03, 0.38298400E+03, 0.33636100E+03, 0.14026400E+03, -.33491500E+02, 0.12194000E+02, 0.34116900E+03, 0.12643800E+03, 0.21000700E+03, 0.98498500E+03, -.49437800E+03, -.59958900E+03, -.49357900E+03, -.45576200E+03, -.14302900E+03, -.58700100E+01, 0.42968900E+02, -.47446700E+03, -.13189100E+03, -.29969300E+03, -.83061100E+01, 0.46507200E+01, 0.30177000E+02, 0.17890500E+02, 0.14367000E+02, -.75342400E+01, -.79466200E+01, 0.37977800E+01, 0.21303400E+01, 0.69727800E+01, -.33507900E+01, -.10444000E+02, 0.12962300E+01, -.85338600E+01, -.13135700E+02, -.88547200E+01, -.24192500E+02, 0.16321100E+02, 0.12096100E+03, 0.16242100E+02, -.60764000E+02, 0.89584200E+01, 0.14462000E+01, 0.35705900E+01, -.28332700E+02, -.33604100E+02 },
        { 0.71698400E+00, 0.50451100E+01, 0.38070700E-01, 0.27635600E+00, -.16224900E+01, -.11496500E+01, -.15878500E+01, 0.10890900E+01, 0.20312100E+00, -.86687500E+00, -.19167500E+00, 0.28643200E+01, 0.11186400E+01, 0.15208400E+01, -.12458600E+00, 0.33295700E+00, -.23082200E+01, 0.47400200E-01, -.30205300E+00, 0.51613700E+00, -.17420600E+01, 0.67410400E+01, 0.78633700E+00, 0.22330300E+00, -.16273500E+00, -.58666400E+00, 0.57393200E+00, 0.84625600E+00, 0.50223100E+00, -.37784700E+00, 0.78962100E+00, -.21788800E+00, -.17863500E+00, -.70303000E+00, -.89444500E+00, 0.19987500E-02, 0.59384700E-01, -.13375700E+01, -.11622000E+00, 0.33467300E+00, -.26715000E+00, 0.34402700E+01, 0.53434900E+01, 0.93350700E+00, -.20061200E+01, 0.39169000E+00, 0.14196800E+01, 0.18485400E-01, 0.26175100E+00, 0.39073900E+00, 0.39488200E+00, -.12746100E+01, -.10075600E+01, 0.19198900E+00, 0.38876600E-01, 0.57283500E+00, -.97363900E+00, 0.15569200E+00, 0.12308700E-03, -.95247900E+00, -.72547200E+00, -.33966500E+00, -.52704500E+00, 0.12185300E+01, -.17403800E+00, 0.44332600E+00, 0.10819400E+00, -.53985700E+00, -.10797500E+01, 0.17741600E-02, 0.63069900E+00, 0.11952900E+01, 0.39475000E+00, 0.69326000E+00, 0.59760400E+00, -.65211900E+00, -.31878200E+00, 0.19496500E+01, 0.35599400E+00, -.37804800E+00, 0.47466400E-02, -.17371600E+00, 0.55557700E+00, -.11857300E+00, -.11085500E+00, 0.43826100E+00, -.61261900E-01, 0.80522700E+00, 0.16124200E+01, -.27964700E+00, -.29380200E+00, -.12928400E-01, -.69837800E+00, 0.65154500E+00, 0.46995500E+00, 0.86742400E+00, -.87132500E+00, -.42834000E+00, -.33794000E+00, -.11849600E-01, 0.11915500E+01, -.13725800E+00, -.19913900E-02, -.12605300E-01, -.58359200E-01, 0.93714900E+00, 0.49725100E+00, -.29247900E+00, -.10735200E+01, -.75253700E+00, -.16109900E+00, -.16518600E+01, 0.60472700E-01, 0.20406900E+00, -.37582500E-02, -.93327800E-01, 0.45135400E+00, 0.55131800E+00, -.38231300E+00, 0.42800500E+00, -.64302700E+00, 0.14362900E+01, -.10082200E+01, 0.11515200E+01, 0.84237300E-01, 0.14612800E+01, 0.25192200E-01, 0.54673600E+00, 0.82410100E-01, -.20262100E+00, 0.28141400E+00, 0.12893600E+00, -.38313600E-02, 0.39914900E+00, 0.78661700E+00, 0.35558300E-01, -.25323600E+00, -.28851100E+00, -.60326500E+00, -.48134200E+00, 0.15348000E+03, 0.15679100E+02, -.61847800E+02, 0.43542900E+03, -.14939400E+03, -.44957400E+03, -.21791600E+03, -.12367100E+03, -.37095000E+00, -.16530700E+03, -.61610600E+02, -.17527800E+03, -.13614300E+02, 0.13599600E+03, 0.25724100E+03, -.13148400E+03, 0.54744800E+03, -.12889800E+03, 0.13300300E+03, 0.93720000E+02, -.53402100E+02, 0.14731500E+03, -.23620200E+03, 0.43674100E+02, -.65142300E+03, -.22682100E+03, 0.14258600E+03, -.18804600E+03, 0.11354600E+03, -.41075300E+02, 0.12340200E+03, -.79086100E+02, -.26200800E+03, -.26963000E+03, 0.14778500E+03, 0.57872800E+02, 0.37349400E+00, 0.18074200E+01, -.26657700E+02, -.22888400E+00, 0.80010100E+01, 0.26963200E+02, -.55558400E+02, -.64655800E+02, -.76167500E+02, 0.24339900E+02, -.89456300E+02, 0.40029700E+02, -.20345500E+02, -.33623200E+03, -.20096600E+02, -.36298500E+03, -.28198600E+03, 0.17403000E+03, -.14829400E+02, -.28945200E+03, -.47154500E+03, -.27244500E+04, 0.97748700E+03, -.48732900E+03, -.12140300E+03, -.48864200E+03, -.63125400E+02, 0.13664400E+03, -.16941900E+03, -.44949500E+02, -.37191600E+03, 0.52668800E+02, -.67655200E+03, 0.71166600E+03, -.35155100E+03, 0.24406200E+03, -.35597300E+03, -.26156200E+03, -.35441900E+02, -.74292100E+02, 0.74343200E+02, -.64089000E+03, -.28400200E+03, -.33916800E+04, 0.32966500E+03, -.18630100E+03, 0.14759000E+03, -.16559300E+03, 0.80166100E+01, -.35023000E+03, 0.28502300E+03, 0.49803000E+03, 0.34022300E+03, -.42725100E+03, -.48560700E+03, 0.47532000E+01, -.48511900E+01, 0.10535300E+02, -.24049000E+01, 0.19327400E+01, -.78377500E+00, -.17516100E+01, 0.19212100E+02, -.56812700E+01, -.43225900E+01, -.10000600E+02, 0.13396100E+03, -.51698700E+02, -.31787900E+03, -.67115300E+02, 0.81385200E+02, 0.22876400E+03, -.27841100E+03, -.39470400E+03, -.39792900E+03, 0.23175600E+03, -.10242900E+03, -.17780900E+04, 0.90741900E+03, 0.83486200E+03, 0.88911400E+03, 0.47597400E+03, 0.33414000E+03, 0.13008600E+03, -.11590800E+03, 0.64973700E+03, 0.23932200E+03, 0.20044700E+03, 0.17867000E+04, -.90459500E+03, -.94975000E+03, -.89344700E+03, -.55465400E+03, -.26141800E+03, -.23257100E+03, -.32297300E+02, -.71699700E+03, -.22223800E+03, -.20667300E+03, -.19370300E+02, -.82077600E+01, 0.34177100E+02, 0.10739300E+02, 0.35113500E+02, -.12349600E+02, 0.13526000E+02, -.75612700E+01, 0.49696100E+01, 0.11818700E+02, -.27552600E+01, -.22796000E+02, 0.48010800E+01, -.14949800E+02, -.71260300E+02, -.17369900E+02, -.46274500E+02, 0.21729100E+02, 0.22177500E+03, -.91204200E+01, -.16275100E+03, 0.18423200E+02, 0.40596400E+01, 0.15736100E+02, -.47500300E+02, -.53806900E+02 },
        { -.86836400E-01, 0.10646000E+00, -.23829900E+00, -.27714800E-01, 0.49555400E+00, 0.14175000E+00, 0.82047400E+00, -.10259400E+00, -.75279300E-01, 0.29385700E+00, 0.31114300E-01, -.11421900E+01, 0.10099700E+00, -.62536100E+00, -.94994200E-01, 0.38189800E-02, -.92104900E+00, 0.41474600E-01, -.73782200E+00, 0.18947900E+00, -.58236800E+00, -.14936900E+01, 0.99919600E-03, -.56030900E-01, -.23909700E+00, 0.12264900E-01, -.89468400E-01, -.77437300E-01, -.12998000E+00, 0.21473000E+00, 0.29089300E+00, 0.22091000E+00, 0.24437300E+00, -.13902000E+00, 0.98459200E-02, 0.85039900E-01, 0.21090100E-01, 0.26124700E+00, 0.28391600E+00, 0.69334600E-01, -.28298100E+00, -.17958200E-01, 0.40983100E+00, 0.35381300E+00, 0.48126200E+00, -.37177600E-01, -.25547400E+00, 0.27520600E-01, 0.19889400E+00, -.12717800E+00, 0.48148200E+00, -.59998300E+00, -.25949800E+00, 0.10914600E+01, 0.25288300E+00, 0.32529000E-01, 0.37197600E+00, -.38862400E+00, 0.60864400E-01, -.21824100E-02, -.31275600E-01, -.64300500E-01, -.62919000E-01, -.13594100E+00, 0.17904700E-01, -.11310900E+00, 0.34487000E-01, -.54555800E-01, 0.47077600E-01, 0.16952900E-02, -.36547400E+00, -.70163100E+00, 0.89472200E-01, 0.44563100E-02, -.11277500E+00, 0.22274200E+00, -.11425800E+00, 0.29067300E+00, -.49420700E-01, -.13121900E+00, 0.33314200E-02, 0.25538200E-01, -.43489100E-01, -.11015400E+00, 0.61410900E-01, -.56041900E-01, 0.37923700E+00, 0.67695700E+00, -.25343300E-01, -.19714400E-01, -.25773100E-01, 0.10100700E+00, 0.63051500E-01, -.71571500E+00, 0.80742800E-01, 0.24690200E+00, -.76221300E-01, 0.84027500E-01, -.15111400E+00, -.10145000E+00, 0.57777300E+00, -.34945900E+00, -.11791900E-01, 0.21755200E-01, 0.19230100E-02, 0.77901800E-01, -.61479000E-01, -.14657000E+00, 0.18105400E+00, -.32397100E-01, 0.42687000E+00, 0.33762100E+00, 0.67626600E-02, 0.16703400E-01, 0.38241100E-01, -.56632600E-02, 0.68138000E-01, -.82076800E+00, -.24134000E-01, -.38379000E-01, -.64704800E-01, 0.38094800E+00, 0.19324900E-01, -.16490100E-01, 0.17065000E-02, -.50108500E-01, 0.23600000E+00, -.63642800E-01, -.18088800E-01, -.79137300E-01, -.17270300E-01, 0.25992100E+00, -.37956100E-01, -.19674400E-02, -.73440900E-01, -.72494600E-02, -.55627700E+00, 0.17328700E-01, -.30143100E-02, 0.11304800E+00, -.11313200E-01, -.17456100E+02, 0.18541000E+02, -.15503900E+03, 0.58251700E+02, 0.58254400E+02, 0.76756400E+02, 0.33597400E+02, 0.90677400E+00, 0.44683000E+02, 0.42842600E+01, 0.60805700E+02, 0.75054700E+01, 0.44111100E+02, -.82719300E+01, 0.46084400E+01, -.17063800E+02, 0.49966800E+01, 0.47207000E+01, -.67423200E+01, 0.20586400E+02, -.16295600E+00, 0.93365700E+01, 0.50564300E+01, -.24028100E+01, -.29640700E+02, 0.10095000E+02, 0.74018900E+01, 0.14576300E+02, -.46184800E+01, 0.13521800E+01, 0.13105000E+02, -.79103800E+01, -.13919100E+02, 0.13005800E+02, -.15083700E+01, -.35279700E+01, 0.15050600E+01, 0.64323600E+01, 0.18581900E+01, -.21497900E+01, -.44963600E+01, 0.93882300E+01, 0.56366900E+01, 0.14581400E+02, -.56286200E+01, 0.63260500E+01, -.31421900E+03, 0.15767300E+03, 0.18507600E+03, 0.15740800E+03, 0.39912900E+02, 0.10706400E+02, 0.76478400E+02, -.63003700E+02, 0.82753000E+02, 0.24235700E+02, 0.19662400E+03, -.84872500E+02, 0.41902000E+02, 0.13135200E+02, 0.42389300E+02, 0.24290700E+02, 0.24073700E+02, -.10969000E+02, -.72614300E+01, 0.18080800E+02, 0.31154800E+02, 0.43859200E+02, -.40751600E+03, 0.20383800E+03, 0.16551000E+03, 0.20433400E+03, -.23345000E+02, -.52054700E+02, 0.12817800E+03, -.72786200E+02, 0.11431200E+03, -.27724100E+02, 0.25291900E+03, -.90634300E+01, 0.96563400E+01, -.19304900E+02, 0.40061700E+01, -.12024000E+02, 0.44693900E+01, -.28822600E+02, -.16984000E+02, 0.41942500E+01, 0.10419600E+02, 0.26850700E+02, -.20802300E+00, 0.44106700E+00, -.78581100E+00, 0.17287300E+00, -.26868900E+00, -.18541300E-01, 0.20899700E+01, -.70230400E+00, 0.66609100E+00, 0.15093300E+00, 0.41440500E+00, -.81112200E+02, 0.36175100E+02, 0.40389800E+02, 0.40884000E+02, 0.51789600E+01, -.12123200E+02, 0.29655900E+02, 0.95219900E+01, 0.35861500E+02, -.85356800E+01, 0.32986400E+01, 0.18504000E+03, -.94285300E+02, -.12174900E+03, -.92680400E+02, -.19520900E+02, -.30271600E+02, -.23402400E+02, 0.27553800E+02, 0.47602900E+01, -.24594900E+02, -.48430900E+02, -.27567000E+03, 0.13955200E+03, 0.14894200E+03, 0.13803500E+03, 0.27128900E+02, 0.40362700E+01, 0.59471300E+02, -.33002500E+02, 0.31793100E+02, 0.33148600E+01, 0.77969100E+02, 0.11668700E+01, -.11912500E+01, 0.38809600E+00, 0.57980700E+00, 0.21357600E+00, 0.67615900E+00, 0.66757800E+00, -.20775500E+01, -.31786800E+00, -.51538500E+00, 0.19352700E+01, 0.16104800E+01, 0.22168200E-01, 0.56447000E+01, 0.64572000E+01, 0.16951300E+01, -.36625300E+01, -.39135400E+01, -.21439200E+02, -.12223900E+00, 0.17770500E+02, 0.85969700E+00, -.19529100E+00, 0.90635100E+00, -.92676600E+01, -.60520300E+01 },
        { -.64681300E+00, 0.25953000E+01, -.88838400E+01, -.13143900E+01, 0.28969900E+01, 0.40205300E+00, 0.21669000E+01, -.16481300E+01, -.10894800E+01, 0.10241700E+00, 0.12424300E+01, -.55418900E+00, 0.68233100E+00, 0.54710600E+00, 0.96365400E+00, -.34356500E-01, -.16725000E+01, 0.20004600E+00, 0.14400100E+00, 0.24850100E+00, -.95611300E+00, -.29760700E+00, 0.22671800E+00, 0.29860100E+00, -.47102200E+00, 0.16503300E+00, -.25781700E+00, 0.74621700E+00, 0.14890800E+00, 0.16599700E+00, 0.78015900E+00, -.11837500E+00, -.15921500E+01, 0.63670400E+00, 0.92933500E+00, -.83733200E+00, -.27271300E-01, 0.31334200E-01, 0.11232800E+01, -.92620400E+00, -.91740000E-01, -.31434200E+01, -.74455700E+01, -.16422200E+01, 0.14296900E+01, 0.10489800E+00, 0.82917800E+00, -.10225500E+00, 0.59176400E-01, -.49862700E+00, -.41535700E+00, 0.15929300E+01, 0.64533700E+00, -.76555200E-01, -.17744100E+01, 0.14394100E+00, -.41118200E+00, -.32156800E+00, 0.11736100E+00, -.14449100E+00, 0.26708900E+00, 0.11477200E+00, -.39292800E+00, -.39228300E+00, 0.54727600E-01, -.19688100E+00, 0.30050700E+00, 0.78946400E+00, -.89115400E+00, -.38015300E-02, 0.70350600E+00, 0.12057200E+01, -.11559100E+00, -.58212300E-01, 0.57981400E+00, -.30109500E+00, 0.14615900E+00, -.69491200E+00, -.26893100E+00, 0.25915500E+00, -.20448600E-02, -.21196600E+00, 0.58751500E+00, 0.71911400E+00, 0.97113200E-01, 0.45015600E+00, -.67548400E+00, -.67761300E+00, 0.21337900E+00, 0.28475100E+00, 0.34112100E+00, 0.44555000E-02, 0.49704800E-01, -.12358800E+01, 0.42895500E+00, -.11127800E+00, 0.57066200E+00, -.29702100E+00, 0.10774500E+01, 0.17259900E+00, 0.64610200E+00, -.10652600E+00, -.22554300E-01, -.73321100E+00, -.31731900E+00, 0.85163700E-01, 0.70157100E+00, 0.68670000E+00, 0.16312800E+01, -.26103800E+01, -.79854900E+00, 0.61403200E+00, -.40864300E+00, 0.13429500E+00, 0.27534100E+00, -.37241700E+00, -.53018000E+00, -.54194300E+01, -.10344900E+01, -.72084900E+00, 0.20603300E+00, 0.29707600E+00, 0.26671600E+00, -.76414000E+00, -.59225600E-02, -.95968800E+00, -.35774000E+00, 0.54692900E+00, 0.83385800E-01, 0.32259400E+00, -.70417800E+00, 0.66532300E+00, -.81157800E-01, -.17621600E+00, -.75306500E+00, -.41845300E-01, 0.28391600E+00, -.25094700E+00, 0.32284900E+00, -.79244900E+00, -.34337100E+00, 0.33676400E+01, -.91840200E+02, 0.14062200E+04, -.57968100E+03, -.50529500E+03, -.70387800E+03, -.22315800E+03, 0.34867900E+01, -.26750100E+03, 0.92308900E+01, -.57400300E+03, -.11814600E+02, -.41290200E+03, 0.12213600E+02, -.70183500E+01, 0.24909500E+03, -.86014500E+01, 0.16512900E+03, 0.16833700E+03, -.11456900E+03, -.13555400E+03, -.12042400E+03, 0.18590800E+03, -.19083400E+03, -.91930200E+02, 0.82108200E+02, 0.11667600E+03, 0.46549600E+02, 0.71106000E+02, 0.12405500E+03, -.21176600E+03, -.19315400E+03, -.11480000E+03, 0.12432900E+03, 0.11204200E+03, 0.11759800E+01, 0.11399500E+01, -.38853400E+02, -.84176100E+00, 0.44854300E+02, 0.66137500E+02, -.76232000E+02, -.72275800E+02, -.10723100E+03, 0.64444200E+02, -.97685400E+02, 0.15721000E+03, -.80036100E+02, -.31734600E+03, -.79491800E+02, 0.28871600E+03, 0.28409000E+03, -.54986400E+03, 0.50480100E+02, -.18119100E+03, 0.13226700E+03, -.19816100E+04, 0.14862100E+03, -.68278900E+02, 0.78925700E+02, -.74214000E+02, 0.17187800E+00, 0.33286200E+02, -.15512300E+02, -.12991000E+03, -.24523000E+03, 0.40475700E+02, -.67338800E+02, 0.56390200E+03, -.27953900E+03, 0.81886100E+02, -.28368600E+03, 0.62336400E+03, 0.44246400E+03, -.78090200E+03, 0.57927900E+02, -.44195000E+03, 0.25661700E+03, -.23930300E+04, 0.36662400E+03, -.21785000E+03, 0.68679700E+02, -.18290000E+03, -.93091300E+02, -.27749900E+03, 0.32365500E+03, 0.25319200E+03, 0.18822500E+03, -.26686900E+03, -.46478900E+03, 0.31919500E+01, -.38256300E+01, 0.43401700E+01, -.17846700E+01, 0.40561700E+01, 0.17722900E+01, -.32953500E+01, 0.44204400E+01, -.37686100E+01, -.40122700E+00, -.61954900E+01, 0.91165200E+03, -.43778200E+03, -.38361400E+03, -.45646800E+03, -.31398300E+02, 0.17536000E+03, -.39029500E+03, -.29446100E+03, -.53526600E+03, 0.18251200E+03, -.13236600E+03, -.10123200E+04, 0.51848000E+03, 0.53492300E+03, 0.50660200E+03, 0.28915500E+03, -.12298000E+02, 0.96326900E+02, -.15141700E+03, 0.31373000E+03, -.15073200E+02, 0.15531600E+03, 0.14502700E+04, -.73424000E+03, -.96171000E+03, -.72566700E+03, -.41544000E+03, -.10767000E+03, -.15724600E+03, 0.89340700E+02, -.46511300E+03, -.11453400E+03, -.41221400E+03, -.60875500E+01, 0.58834800E+02, 0.36262400E+02, 0.10097200E+02, 0.35392900E+02, -.16789100E+02, 0.81030700E+01, 0.62737300E+02, 0.34378800E+01, 0.95259700E+01, -.50721900E+01, -.15347000E+02, 0.17488100E+02, -.22327400E+02, -.56794700E+02, -.12541800E+02, 0.21661700E+02, 0.42699400E+02, 0.14960600E+03, 0.14988900E+00, -.11692700E+03, -.45199000E+01, 0.26953100E+01, 0.25563000E+02, -.14497100E+02, -.47557200E+02 },
        { -.14431800E+00, 0.93228100E+00, -.16852000E+01, -.34813400E+00, 0.63661000E+00, 0.96695300E-01, 0.16284400E+01, 0.69558400E+00, 0.27986900E+00, 0.16109300E+00, -.39482900E-01, -.13633100E+01, 0.15876100E+00, -.73867200E+00, -.42710600E-01, 0.69793300E-01, -.68179200E+00, 0.37409600E-01, -.38521800E+00, 0.13986900E+00, -.48587600E+00, -.13344800E+01, 0.69059300E-02, -.43067800E-01, -.29637800E+00, 0.33808900E-01, -.10901400E+00, -.30688300E+00, -.11412300E+00, 0.22616100E+00, 0.31543700E+00, 0.22129700E+00, 0.23503800E+00, -.38546300E+00, 0.25854000E-01, 0.18360600E+00, -.10290200E-01, 0.21966900E+00, 0.46479100E-01, -.77190000E-01, -.16549300E+00, -.72926100E+00, -.83277200E+00, -.31504700E+00, 0.88020800E+00, 0.16594000E-01, 0.12091100E+00, 0.14081000E-01, 0.24769800E+00, -.38966000E+00, 0.19895900E+00, -.38866600E+00, -.16785000E-01, -.15689300E+00, -.17640300E-01, -.31895400E+00, 0.26527400E-01, -.16903300E+00, 0.58539700E-01, -.21845500E-01, -.95760700E-01, 0.68951000E-01, -.23275700E+00, 0.21587700E+00, 0.54480900E-02, 0.10484400E+00, -.25542000E-01, 0.83859900E-01, -.46682900E-01, 0.67750400E-03, -.25238700E+00, 0.29641800E-01, 0.52856600E-02, 0.28501100E-01, -.16003200E-01, 0.16390300E+00, -.12766300E+00, -.74815600E-01, -.12376400E-01, 0.12975800E+00, 0.11399800E-01, 0.74884400E-02, -.19930000E+00, 0.66620500E-01, -.18115300E-01, 0.76606500E-01, 0.31976600E+00, -.42459600E+00, -.47191800E-01, -.21533100E-01, 0.16913200E+00, 0.16454200E+00, 0.10893800E+00, 0.54142200E-01, 0.22906100E+00, -.16882900E+00, -.89499600E-01, 0.29803200E+00, -.14190100E+00, -.55039000E-01, 0.29689000E-01, -.17296800E+00, -.10719200E-01, 0.15174900E-02, -.60412500E-01, 0.98788500E-01, 0.49472900E-01, -.47474100E+00, -.22384200E-01, -.19152100E+00, 0.20590200E+00, 0.51384200E-02, 0.51879000E-01, -.32687800E-03, -.16860800E-01, -.29029600E+00, 0.10855200E+00, 0.33562700E+01, 0.48102000E+00, 0.75368300E-02, 0.11382500E+00, 0.67685300E+00, -.97507200E-01, 0.88335300E-01, 0.31235600E-01, 0.87854800E+00, -.19870400E-01, 0.51121700E+00, 0.12270500E+00, -.28403200E-01, 0.38387400E+00, -.19443400E+00, 0.17182500E-01, 0.10959300E+00, 0.97698800E-01, 0.12046000E-01, 0.26613600E+00, 0.39025700E-01, 0.16510100E+00, -.15105700E+00, -.14109000E+00, -.34976600E+00, -.20418400E+00, 0.46849700E+03, -.17139900E+03, -.98803600E+02, -.23292800E+03, -.95767100E+02, -.10781800E+02, -.94238800E+02, -.62052500E+02, -.18458400E+03, -.33870200E+01, -.21991500E+03, 0.73155700E+02, -.38314100E+02, 0.12054600E+02, -.38586700E+02, 0.11408800E+02, -.12764300E+02, 0.69610800E+02, 0.93962300E+02, -.14463200E+02, -.34451300E+02, -.10919400E+03, 0.43332700E+02, -.11041000E+01, 0.60823000E+02, -.21134100E+02, -.30382900E+02, 0.41387100E+01, -.71499600E+02, 0.13058700E+02, -.24647900E+02, -.33264800E+01, -.37951100E+02, 0.93537400E+01, -.35185700E+01, -.11857200E+02, -.48932500E+01, -.64341800E+01, 0.60522000E+01, -.11771200E+01, -.55803200E+01, -.10004600E+02, 0.68415200E+01, -.25456200E+02, -.57675900E+03, 0.28825400E+03, 0.23574500E+03, 0.28768000E+03, 0.21840800E+01, 0.17978400E+03, 0.58815700E+02, -.15848700E+03, 0.13564300E+03, 0.10999900E+03, -.33843000E+03, 0.27359500E+03, -.13481300E+03, -.10120800E+03, -.13666400E+03, -.34106500E+02, -.18883800E+01, -.29074300E+02, 0.34021000E+01, -.10017200E+03, -.16459800E+02, -.17694700E+03, -.48732100E+03, 0.24580900E+03, 0.30899200E+03, 0.24230800E+03, 0.67534000E+02, 0.18025100E+03, 0.28483100E+02, -.96487800E+02, 0.13571100E+03, 0.11116400E+03, -.41377000E+03, 0.66925800E+02, -.50350600E+02, 0.24989200E+02, -.32114800E+02, -.20524900E+02, -.45076600E+02, 0.74555900E+02, 0.10109000E+03, 0.45381300E+02, -.52205800E+02, -.59993800E+02, -.12804000E+00, -.12279000E+01, 0.10840900E+01, -.94385200E-01, 0.70472700E+00, -.30963000E+00, 0.70761200E+01, 0.37910100E+01, -.68934500E+00, -.98982800E+00, -.15049800E+01, 0.25292200E+03, -.11570600E+03, -.56157800E+02, -.12712900E+03, -.17484500E+02, 0.38652200E+02, -.96656300E+02, -.18868400E+02, -.12324500E+03, 0.38137200E+02, -.16279900E+03, -.39676400E+03, 0.20658900E+03, 0.23794800E+03, 0.19875200E+03, 0.93227300E+02, 0.16872600E+02, 0.29729700E+02, -.40963600E+00, 0.15137800E+03, 0.17568200E+02, 0.76647900E+02, 0.20077900E+03, -.10601400E+03, -.14551400E+03, -.10084800E+03, -.12196100E+03, 0.14688600E+02, -.12485600E+01, -.48690800E+02, -.17042500E+03, 0.70291300E+01, -.11319900E+01, -.28293700E+01, 0.54563900E+01, 0.12183900E+02, 0.23741000E+01, -.78161300E+01, -.17125800E+01, 0.82808200E+01, 0.29427900E+01, 0.35800100E+00, 0.16782700E+00, 0.53452900E+00, -.33606200E+01, -.12766200E+00, -.18503800E+01, 0.20261700E+01, 0.16704100E+01, -.14990600E+02, 0.69997400E+01, -.45874800E+01, -.76755200E+01, 0.98873900E+01, 0.26456200E+01, 0.58105300E+00, -.26127200E+01, -.56379500E+01, -.11383000E+02 },
        { -.17873900E+00, -.36898000E+00, -.18886100E-01, -.25635600E+00, 0.99561400E+00, 0.32284300E-01, 0.12051700E+01, -.66008900E+00, -.29942800E+00, 0.17527700E+00, 0.13915300E+00, -.10960000E+01, 0.25012600E-01, -.57780500E+00, -.14698100E+01, -.42120700E+00, -.68270900E+00, 0.15544200E+00, 0.65179100E+00, -.73217400E-01, 0.37765200E+00, 0.44549200E+00, 0.73657500E-01, -.11285000E+00, 0.22705900E+00, -.18532100E+00, -.36907600E+00, -.41018800E+00, -.24858400E-01, 0.47968400E+00, -.19164000E+00, 0.12542700E+00, 0.40810300E+00, 0.14210200E+00, -.11347000E+00, 0.50954700E-01, -.44178300E-02, 0.32448100E+00, -.16096200E+00, 0.35219200E+00, 0.33672900E+00, 0.19165900E+01, 0.25312200E+01, 0.95137800E+00, -.85990500E+00, -.29191000E+00, -.16954500E+01, -.17486400E-01, -.10575200E-01, 0.30160800E+00, -.81922700E-01, -.10219800E+01, -.32651100E+00, 0.27936000E+01, 0.14987600E+01, 0.11876500E+00, -.19280100E+00, 0.11075200E+00, 0.79536700E-01, 0.46327200E-01, 0.30976700E+00, -.17899200E-01, 0.27255700E-01, -.26612600E+00, -.68807000E-02, 0.82072000E-01, 0.13534200E+00, 0.38160600E+00, -.18011700E+00, 0.40326500E-02, -.78989400E+00, -.42005200E+00, 0.14461300E+00, -.46385500E-01, -.10539500E+00, 0.34851400E+00, -.31535800E+00, -.17747200E-02, 0.75303100E-01, -.10683900E+00, 0.19543400E-01, 0.18454100E-04, -.81877400E-01, -.13025800E+00, 0.11688000E-01, -.20688900E+00, 0.78752200E-01, 0.22178900E+00, 0.66125200E+00, -.11463400E+00, -.46339400E+00, 0.89300800E-01, 0.23811100E+00, -.90267100E+00, -.33182600E+00, -.85889600E+00, -.66220000E-01, 0.12522900E+00, -.63476000E-01, 0.11590200E+00, -.28501500E+00, -.58825300E-01, -.15090800E-01, -.10909900E-01, 0.68743700E-01, 0.55735300E+00, 0.28698900E+00, -.46672300E+00, 0.73232000E+00, -.19060100E+00, -.19426900E+00, 0.22353000E+00, 0.14824600E+00, -.90304200E-02, -.94094900E-02, -.34291000E+00, -.15251100E+00, 0.10972200E+01, 0.19699700E+00, -.17375400E-03, 0.17516100E+00, 0.27922400E+00, -.48065400E-01, -.37309000E+00, 0.22687700E-01, -.70965800E+00, 0.26218300E-01, -.49919500E+00, -.12520600E+00, 0.59917100E-01, -.21354500E+00, -.30377000E+00, 0.12246100E-01, 0.16784700E+00, -.16868300E+00, 0.32778400E-02, -.17285200E+00, -.18735500E+00, -.14040400E+00, -.10402300E+00, 0.44427700E-01, 0.19990200E+00, 0.12916200E+00, 0.79053700E+00, -.79561300E+02, 0.61749900E+02, -.18272800E+01, 0.97536700E+01, -.18070300E+02, 0.84216600E+01, 0.21958800E+02, -.15150800E+02, -.61697200E+01, 0.39900300E+02, -.99070100E+02, 0.51311300E+02, -.55515000E+02, 0.52395000E+02, 0.61327700E+01, -.34443900E+01, -.36880000E+02, -.67695500E+02, 0.84321600E+02, 0.67873800E+01, 0.14290100E+03, 0.20286700E+03, -.12915800E+03, -.16258700E+03, -.10216800E+03, 0.10782600E+03, 0.10077700E+03, -.32013900E+02, 0.29089900E+02, -.70449500E+01, 0.82084100E+02, -.35036700E+02, -.11672600E+02, 0.46299700E+01, 0.14050600E+02, 0.61409000E+01, 0.30553900E+00, -.13953800E+02, 0.20875800E+02, 0.81788000E+01, 0.14868600E+02, -.12082600E+02, 0.44479700E+02, 0.11305700E+04, -.56404200E+03, -.49266500E+03, -.56428700E+03, -.96870700E+02, -.43121400E+03, 0.19926800E+03, 0.45016700E+03, -.18298700E+03, -.34017200E+03, 0.37958700E+03, -.15206300E+03, 0.73317700E+02, 0.48494600E+02, 0.75846600E+02, 0.53621700E+02, 0.54563600E+02, 0.84109900E+01, 0.33915200E+02, 0.59263200E+02, 0.51578400E+02, 0.12436700E+03, 0.10711800E+04, -.53668000E+03, -.61169700E+03, -.53365300E+03, -.85762700E+02, -.28515500E+03, 0.19132600E+03, 0.38850200E+03, -.21816600E+03, -.24060200E+03, 0.48615000E+03, -.13417800E+03, 0.88741100E+02, -.37547200E+02, 0.64752100E+02, 0.37647900E+02, 0.43508300E+02, -.36203200E+02, -.10471300E+03, -.56983000E+02, 0.46912900E+02, 0.10840400E+03, -.65179400E-01, 0.16819700E+01, -.27687200E+00, 0.25612300E+00, 0.48030500E+00, -.24300200E-01, -.37197300E+01, -.28988900E+01, 0.20662700E+01, 0.51481800E-01, 0.41363200E+00, -.26202300E+02, -.24170200E+01, -.12787700E+02, 0.13996800E+02, 0.34202600E+02, -.10221900E+02, 0.25119800E+02, 0.16581400E+02, 0.73692600E+02, -.15406600E+02, 0.11779600E+03, 0.52614900E+03, -.27359000E+03, -.23720000E+03, -.26359700E+03, -.82626700E+02, -.35033300E+02, -.52291000E+02, -.13042900E+03, -.32238300E+03, 0.79546800E+00, 0.14939700E+02, -.31994600E+03, 0.16707600E+03, 0.22014900E+03, 0.16061800E+03, 0.12363900E+03, -.55409300E+01, 0.39253200E+02, 0.19844700E+03, 0.35299900E+03, -.21192900E+02, -.97823600E+02, 0.16622700E+01, -.37900400E+01, -.27585800E+02, -.34004300E+01, 0.33724400E+00, 0.12275200E+01, -.13685300E+01, 0.19484900E+01, -.62515700E+00, -.61965600E+00, -.19827500E+01, 0.43482100E+01, 0.19607400E+01, 0.34894500E+01, 0.14348200E+02, -.30635700E+01, 0.29183200E+02, -.10395300E+02, -.13277800E+02, 0.45116500E+00, -.11843900E+02, -.31322400E+01, -.55417400E+00, 0.18078100E+01, 0.28980500E+02, 0.32275000E+02 },
        { -.59941700E+00, 0.73815300E+00, 0.17192300E+00, -.23075800E+00, 0.70023700E+00, 0.76309100E-02, 0.10685100E+01, 0.16497400E+00, -.67083200E+00, -.38544200E+00, 0.54571500E+00, -.81608800E+00, 0.85877900E+00, -.40702900E+00, -.10890300E+01, 0.14070500E+00, -.71760000E+00, 0.20426000E+00, 0.51711300E+00, 0.27197300E+00, -.61253000E-01, 0.57496100E+00, 0.48054800E-01, 0.41901600E+00, 0.83207400E+00, -.62491700E-01, -.33588800E+00, 0.59631800E+00, 0.52837300E+00, 0.21567100E+00, -.10180500E+00, -.32834600E-02, -.31877600E+00, 0.88602300E+00, -.11180500E+00, 0.14428400E+01, -.84283400E-01, 0.58980800E+00, 0.45723000E-01, 0.22058500E+00, 0.34848500E+00, 0.65524400E+00, 0.29322300E+00, 0.86976300E+00, -.45841600E+00, -.11398000E+00, -.80128700E+00, -.10015800E+00, -.29102400E+00, 0.81781700E+00, -.20248100E+00, -.92830700E+00, -.86216800E-01, 0.27702300E+01, 0.97982800E+00, 0.11826900E+00, 0.24649000E+00, 0.66486800E+00, 0.16522700E+00, 0.79489300E+00, -.32259100E+00, 0.43308500E-01, -.40571300E+00, 0.13197300E+00, 0.10089900E+00, 0.13449000E+00, 0.45661800E-01, 0.51254500E+00, -.29254800E+00, 0.84546600E-02, -.20317600E+01, -.21950300E+01, 0.14712200E+00, -.33594900E+00, -.30646900E+00, 0.59424800E+00, -.55408900E+00, -.75048500E-01, 0.11608000E-01, -.17019300E+00, 0.34528300E-01, -.13568700E-01, -.80361800E-01, -.17284700E+00, 0.10461400E+00, 0.17857000E+00, 0.12764100E+00, -.67302100E+00, -.63701600E+00, 0.33486900E+00, -.89531200E+00, 0.55914900E+00, 0.12468100E+01, -.20934200E+01, -.78238500E+00, -.99843700E+00, -.59827000E-01, 0.36969100E+00, -.21117000E+01, -.90180100E+00, 0.50085100E+01, 0.70494900E-01, -.97786600E-01, -.44109300E+00, -.31873700E+00, 0.17392700E+01, 0.56203900E+00, -.14956900E+00, -.88288200E+00, -.58622900E+00, -.15414000E+01, 0.53505900E+00, -.41155500E+00, 0.54301700E-01, -.19684800E+00, -.21608100E+00, -.63116600E-01, 0.10643700E+01, -.38549300E+00, 0.82232400E-01, -.17163900E+00, 0.11745000E+01, -.20922100E+00, 0.66574500E+00, -.83212400E-01, 0.11078000E+01, 0.83041800E+00, -.14637800E+01, -.65241900E-01, 0.17979400E-01, -.83916100E+00, -.48020300E+00, -.38755200E-01, 0.12632200E-01, -.23487000E-01, 0.34383000E-02, -.12979600E+01, -.34880400E+00, -.72436200E+00, 0.62094300E+00, 0.26756100E+00, -.12288200E+00, -.13336800E+00, 0.10694000E+01, 0.14807300E+01, -.52585400E+03, -.64557400E+01, -.49434400E+01, -.42517500E+02, 0.61536100E+02, 0.19073500E+03, 0.74849400E+02, -.48179000E+02, 0.22108500E+03, -.35217300E+02, 0.10504600E+02, -.20032300E+03, 0.25052200E+02, -.34353400E+02, -.84050600E+02, 0.12193900E+03, -.16966400E+03, 0.12003200E+03, -.14384600E+02, 0.40436300E+03, 0.45321200E+02, -.15397200E+02, -.19623500E+03, -.24691600E+02, 0.86716300E+02, -.43381000E+02, -.10149400E+01, -.80322000E+02, 0.79991100E+02, -.25972700E+02, -.26540500E+02, 0.12683300E+02, -.46184200E+01, 0.41735200E+00, -.55408600E+01, 0.40909900E+01, -.19029900E+02, 0.63605900E+02, 0.11235100E+02, 0.89038900E+00, -.26933300E+02, 0.10735500E+02, 0.18486600E+04, -.92289000E+03, -.94399800E+03, -.92173400E+03, -.46925500E+03, -.94737600E+03, 0.81919600E+03, 0.79254900E+03, -.60701300E+02, -.90498200E+03, -.12035500E+03, -.51468300E+03, 0.25114000E+03, 0.15087600E+03, 0.25701100E+03, 0.21355000E+02, -.13653900E+03, -.22803300E+02, -.83655400E+02, 0.74750900E+02, -.11286400E+03, 0.57745100E+03, 0.21502500E+04, -.10715700E+04, -.10784400E+04, -.10701000E+04, -.68952500E+03, -.93399700E+03, 0.89803800E+03, 0.78973100E+03, -.21804300E+03, -.90085900E+03, -.24933400E+03, -.30506000E+02, 0.18227600E+02, -.88868900E+02, 0.93038600E+01, -.41160000E+02, 0.81409700E+02, -.52494000E+02, -.14686000E+03, -.76064500E+02, 0.44850000E+02, 0.12911800E+03, -.18501500E+01, 0.60977800E-01, -.31672800E+01, 0.15131200E+01, 0.93850500E+00, 0.30591900E+01, 0.61330000E+01, -.12273400E+02, 0.23581000E+01, 0.43743700E+01, 0.10347900E+02, -.35982800E+03, 0.18007400E+03, 0.42868300E+02, 0.18267900E+03, -.54162000E+01, -.11215700E+03, 0.95826400E+02, -.66807000E+02, 0.19898400E+03, -.92367400E+02, 0.27857400E+03, 0.88423800E+03, -.43374600E+03, -.41768100E+03, -.44348700E+03, -.36517500E+03, -.21480600E+03, 0.81863700E+02, 0.27398700E+02, -.38256600E+03, -.22402100E+03, -.54409000E+03, -.90857700E+03, 0.44875600E+03, 0.44865800E+03, 0.45598200E+03, 0.48085600E+03, 0.18069500E+03, -.63355600E+02, -.81426800E+02, 0.57958000E+03, 0.16210900E+03, 0.46231200E+03, 0.97935000E+01, 0.21612300E+02, -.25508100E+02, -.22216500E+02, 0.62378400E+01, 0.38846200E+01, 0.40508000E+01, 0.26030400E+02, -.15469700E+01, -.62525600E+01, 0.16078000E+01, 0.10409700E+02, -.18533300E+01, 0.12183200E+02, -.52581600E+02, 0.10152800E+02, 0.36900900E+02, -.60505600E+01, -.72096800E+02, -.14311000E+02, 0.46455000E+00, -.54056800E+01, -.12113000E+01, -.35053500E+00, 0.27180000E+02, 0.29252200E+02 },
        { 0.11269600E+01, -.64779000E+00, 0.71793600E+01, 0.11439800E+01, -.24980100E+01, -.65233100E+00, -.13036500E+01, 0.60583200E+00, 0.84930600E+00, 0.47391800E+00, -.13555700E+00, -.42054200E+01, -.85087400E+00, -.35357400E+01, 0.23665800E+01, 0.92089000E+00, 0.82580200E+00, -.44622700E+00, -.15373100E+01, 0.55009700E+00, 0.56913300E-01, -.56061500E+01, -.12687900E+00, 0.16555400E+01, -.45821300E-01, 0.57791800E+00, -.36736600E+00, -.33526100E+01, -.72171600E+00, 0.10399900E+01, -.27185400E+00, 0.64512200E+00, 0.31917800E+01, -.20409900E+01, -.55316200E+00, -.35603300E+00, 0.16451700E+00, -.14881500E+01, 0.15257900E+00, -.18069700E+01, -.17974800E+01, 0.11245500E+01, 0.21388800E+00, -.13141700E+01, 0.17127000E+01, -.75087200E+00, -.23635900E+01, 0.27368900E+00, 0.57215700E+00, -.29775700E+01, -.15080300E+01, 0.16473000E+00, -.51713100E+00, -.78296100E+01, -.56394500E+00, -.19963200E+01, -.13153500E+01, -.12573000E+01, 0.25127300E+00, -.14666700E+01, -.45987000E+00, 0.57437100E+00, 0.34698600E+00, -.31833800E+00, -.97457700E-01, -.81291600E+00, 0.15221200E-01, -.71563400E+00, 0.54363900E+00, 0.20932400E+00, 0.78585100E+00, 0.12316800E+01, 0.10143400E+00, 0.28936400E+00, -.42556700E+00, -.61642100E+00, -.13154500E+00, 0.11902500E+01, 0.15765500E+00, 0.10070600E+01, 0.18948100E+00, 0.77881700E-01, -.16025700E+00, 0.16324300E+00, 0.24217900E+00, -.24576500E+00, 0.92872800E+00, -.17337600E+01, -.47987500E+00, 0.15162700E+00, -.13515600E+01, 0.86723500E+00, 0.11181700E+01, -.76698200E+01, 0.24118700E+00, 0.54004100E+00, -.30194500E+00, 0.51546900E+00, -.17122100E+01, -.10600800E+01, 0.87072500E+00, -.21156100E+01, 0.21898600E-01, 0.95128600E+00, 0.12097700E+01, -.10942200E+01, -.88725200E+00, -.13323500E+01, 0.47773500E+01, -.37022700E+00, 0.35536400E+01, 0.41535600E+01, 0.70540100E-01, -.44644800E+00, 0.48989700E+00, -.15207000E+01, -.47505800E+00, 0.34757900E+01, 0.30399200E+01, -.47907500E+00, 0.16140500E+01, -.13182000E+01, -.70499500E-01, -.11557000E+01, 0.56425400E+00, 0.84710700E+00, -.10241700E+01, -.58821200E+00, -.77036000E-01, -.11788200E+01, -.38192800E+00, 0.19523500E+01, -.33180100E+00, 0.76506600E+00, 0.31776600E+00, -.43589000E-01, 0.17030100E+01, -.27679100E+00, 0.30797900E+00, 0.12982500E+01, -.27375700E+00, -.27988400E+01, -.57236800E-01, 0.39477900E+00, 0.14319000E+01, 0.12527000E+00, -.17642200E+02, 0.63944600E+02, -.16267200E+03, 0.76400900E+02, 0.26458000E+02, 0.23678600E+02, -.10133100E+03, 0.14229700E+03, 0.21745000E+03, -.11314100E+03, 0.71313700E+02, -.89895500E+02, -.23979200E+02, -.12918200E+03, 0.17543700E+03, 0.10458100E+03, 0.21585300E+02, -.83803900E+02, -.82101900E+02, -.17381700E+03, 0.10339800E+03, 0.89287600E+01, 0.81815600E+02, -.27881500E+02, 0.62950400E+02, -.10596800E+03, -.13219000E+03, -.55982900E+02, 0.11257500E+03, 0.82739800E+01, -.37088800E+02, 0.19913100E+02, 0.57458600E+01, 0.20570400E+02, 0.21904200E+02, 0.10432600E+02, 0.36515000E+02, -.40415400E+02, -.41671400E+02, 0.87984200E+01, -.15451500E+02, 0.17986400E+04, -.89746200E+03, -.11334100E+04, -.89274800E+03, -.41586900E+03, -.95587300E+03, 0.90640000E+03, 0.96685600E+03, 0.12602900E+03, -.11235500E+04, -.20175700E+04, 0.55145000E+03, -.27859400E+03, -.17806100E+03, -.27670900E+03, -.27967600E+02, -.11296900E+03, -.19946600E+03, -.42979300E+02, -.19823400E+03, -.14921100E+03, -.74949300E+02, 0.25109600E+04, -.12514500E+04, -.85159300E+03, -.12427700E+04, -.60387600E+03, -.95423600E+03, 0.83637100E+03, 0.10096100E+04, -.24454900E+03, -.11302200E+04, -.25200600E+04, -.43959500E+02, 0.21072400E+02, 0.80885500E+02, 0.83574000E+01, -.49507700E+01, -.94949500E+02, 0.15931900E+03, 0.19182900E+03, 0.18568200E+03, -.21948000E+03, 0.41035000E+02, 0.16905100E+01, -.20161400E+01, 0.25240700E+01, 0.64104000E+00, 0.31972500E+01, 0.31309300E+01, 0.10812600E+02, 0.28415500E+01, 0.84754100E+00, 0.14290100E+01, 0.36154500E+01, -.56412800E+03, 0.28221800E+03, 0.34623600E+03, 0.28872100E+03, 0.10420100E+03, 0.47722400E+02, -.31823900E+02, -.27425200E+03, -.17640300E+02, 0.90583900E+02, 0.71440700E+02, -.37140200E+03, 0.19704700E+03, 0.29230000E+03, 0.18223700E+03, -.80632600E+02, 0.51718400E+01, 0.17918800E+03, -.20357300E+03, -.10369200E+03, -.15409800E+02, -.12599000E+03, -.96103000E+02, 0.42697800E+02, -.19400400E+03, 0.52340700E+02, 0.25363700E+03, 0.11203000E+03, -.13221000E+03, 0.21630300E+03, 0.29735000E+03, 0.90855800E+02, 0.15478600E+03, -.48917000E+01, 0.55773000E+02, 0.14227200E+02, -.24614200E+02, 0.18481700E+01, -.46432300E+01, 0.40218000E+02, 0.61019900E+02, 0.10097400E+01, 0.16853200E+01, 0.21697700E+01, -.10510500E+02, -.27130200E+01, 0.91802400E+01, 0.58582900E+02, 0.11482400E+02, -.25174300E+02, 0.11779100E+02, -.49968300E+02, -.39964100E+02, -.14073200E+02, 0.17014400E+01, 0.11282100E+01, 0.14539900E+02, 0.15004200E+02, -.10687600E+02 },
        { -.20824500E+00, -.77852600E+00, 0.20696500E+00, -.47613800E+00, 0.94822400E+00, -.80748500E-02, 0.78496100E+00, -.83906300E+00, -.28051000E+00, 0.90998900E-01, 0.10065100E+00, 0.20309800E+00, -.52767000E-01, -.15531100E-01, 0.14320300E+00, -.74314900E+00, -.58839400E+00, 0.24349400E-01, -.27688100E-01, 0.10376800E+00, 0.96643100E-01, 0.23975300E+00, -.66911500E-01, -.39028000E-01, 0.15882000E+00, 0.36583000E+00, -.23103800E+00, 0.31193000E+00, -.26204400E-01, 0.96491100E-01, 0.53830200E+00, 0.26038700E+00, -.34187600E+00, -.21599400E+00, -.30747400E-01, 0.52596800E-01, -.30992000E-01, -.45766600E-01, -.17246700E-01, 0.43724900E-01, 0.24581300E+00, -.39020200E+00, -.10878300E+01, -.42639300E+00, 0.79179100E+00, -.91537300E-01, -.23040800E+00, -.12783400E-01, -.10925600E+00, -.31314000E+00, 0.23260600E+00, 0.12099500E+00, -.14597600E+00, -.75562400E+00, 0.14027800E+00, 0.13691600E+00, 0.22376500E-01, -.19907200E+00, 0.37208300E-01, 0.89731800E-01, 0.26582200E+00, 0.79344100E-01, -.28499800E-02, -.33680900E+00, 0.34251900E-01, -.12477900E+00, -.11434000E+00, 0.69127800E-01, 0.24906100E+00, 0.61470200E-02, 0.20449700E+00, 0.10444300E+01, -.29109600E-01, -.32324000E-02, -.24814300E+00, 0.20655800E+00, 0.23049200E+00, -.83735000E-01, -.14820700E+00, 0.28433600E-01, -.16649600E-01, -.22059200E-01, 0.22717800E+00, 0.18601300E+00, 0.87675200E-01, 0.16138600E+00, -.74814500E+00, -.90869500E+00, -.21683100E+01, 0.38298800E+00, -.39850200E+00, -.60536800E-01, 0.47371000E+00, 0.25556600E+01, -.38560100E+00, -.97011800E+00, -.36539600E+00, 0.60364500E+00, -.25945600E+00, -.76297100E-01, 0.17703500E+01, 0.38187600E+00, -.46546400E-01, 0.49627800E+00, -.15811300E+00, -.99454100E-01, -.12484100E+00, 0.31407700E+00, -.81114500E+00, 0.32411700E+00, -.37585200E+00, 0.16793000E+00, -.58657800E-01, -.53581000E-01, -.25207400E+00, -.16484400E+00, 0.29720300E-01, 0.86081800E+00, -.40027000E+00, 0.60273100E-01, 0.73945200E-01, 0.40818600E+00, -.11705700E+00, 0.12141700E+00, 0.62931000E-01, -.31674600E+00, -.80675600E-01, 0.58558400E-01, 0.10021600E+00, 0.40938700E+00, -.48043200E-01, -.56635600E+00, 0.71769800E-01, -.21896200E+00, -.34326500E+00, 0.65220400E-04, -.11669800E+01, -.24728400E+00, -.23383800E+00, -.71824200E+00, 0.88392000E-01, 0.70728700E+00, 0.34809700E-01, 0.63430800E+00, 0.16778200E+00, -.18601700E-02, -.31292600E-01, 0.40171500E+02, 0.80346100E+02, -.97987500E+02, -.43822700E+02, -.18640800E+02, 0.53321000E+02, 0.41148200E+02, -.33296400E+02, 0.19161100E+02, -.64195800E+01, 0.16429800E+02, -.15280900E+02, -.18747500E+02, -.30006000E+02, 0.36255600E+02, 0.11641100E+02, -.22240900E+02, -.44038200E+02, -.16519600E+03, 0.80387900E+02, 0.58464100E+02, 0.82633100E+02, -.96798800E+01, -.25926100E+02, 0.88858600E+02, -.33666600E+02, 0.31063200E+01, -.31771300E+02, 0.93202000E+02, 0.27686300E+01, -.20462000E+01, 0.60604200E+01, -.14041000E+01, 0.76156900E+01, 0.11946300E+02, -.27743600E+02, -.68666500E+01, -.87306600E+01, 0.16442300E+02, -.37529600E+01, -.54091800E+03, 0.26927300E+03, 0.25291900E+03, 0.27037800E+03, 0.18571800E+03, 0.34151800E+03, -.31112600E+03, -.28766400E+03, -.55243600E+02, 0.43578700E+03, 0.14618900E+03, -.14732100E+03, 0.75366200E+02, 0.10115800E+02, 0.73663800E+02, -.17411300E+02, -.46889900E+02, 0.11299000E+03, 0.36948800E+02, 0.81074900E+02, -.24607000E+02, 0.58586800E+02, -.60644100E+03, 0.30069200E+03, 0.28978600E+03, 0.30306000E+03, 0.12595300E+03, 0.34374000E+03, -.34861900E+03, -.34742700E+03, -.43901600E+02, 0.45194800E+03, 0.18711800E+03, 0.13239100E+03, -.66225900E+02, -.48277600E+00, -.66358200E+02, -.47709800E+02, -.36087800E+02, 0.53540900E+00, 0.30812700E+02, 0.11390900E+02, -.23725700E+01, -.10919500E+03, 0.37676100E+00, 0.18647900E+00, -.89450900E+00, -.20352500E+00, -.14485600E+01, -.52992700E+00, -.88961800E+01, -.14283400E+01, -.22654500E+01, 0.43658900E+00, -.99458800E+00, 0.89279200E+02, -.42928900E+02, -.55121200E+02, -.44658300E+02, -.36295300E+02, -.17725600E+02, -.14958600E+00, 0.10746400E+02, -.21528400E+02, -.26354400E+02, 0.19914200E+02, 0.19814500E+03, -.10323000E+03, -.13770400E+03, -.99036700E+02, -.77747300E+02, -.23108000E+02, -.36611200E+02, 0.10249600E+03, 0.37350700E+02, -.15120100E+02, -.62391700E+02, -.65164500E+02, 0.35099300E+02, 0.48020900E+02, 0.32542100E+02, 0.31435600E+02, 0.70185800E+01, 0.23589200E+02, -.10086300E+03, -.13072100E+03, 0.32031600E+02, 0.29764500E+02, 0.66411500E+00, 0.11518200E+02, 0.89586400E+01, 0.96680300E+01, 0.17350800E+02, -.11331200E+01, -.69150400E+01, 0.84037400E+01, 0.28984700E+00, -.99423200E+00, 0.57717300E-01, -.66241100E+01, -.69288600E+01, -.87054900E+01, -.12465100E+01, -.18753300E+01, 0.17279600E+01, 0.50575100E+01, 0.62687000E+02, 0.47583700E+01, -.43249200E+02, -.10350500E+01, -.16406100E+00, 0.31755000E+01, -.17360200E+02, -.14945300E+02 },
        { -.19563700E+00, 0.33978500E+00, -.33108300E+00, -.12337800E+00, 0.90266100E+00, 0.35054200E+00, 0.16226500E+01, -.93330900E+00, -.34777800E+00, 0.34951900E+00, 0.65713300E-01, -.14592800E+01, 0.43018100E+00, -.52193400E+00, -.11125900E+01, -.41898800E+00, -.18179000E+01, 0.27667500E+00, -.45261100E+00, 0.22649400E+00, -.72551400E+00, -.93271000E+00, 0.19084300E+00, -.51452000E+00, -.39728400E+00, -.34925100E+00, -.57294800E+00, -.21136800E+00, -.15380600E+00, 0.61463700E+00, 0.10906900E+00, 0.22079800E+00, -.56153200E-01, 0.97367400E-01, 0.20861200E+00, 0.78657900E-01, -.91311000E-02, 0.49799700E+00, 0.57182400E+00, 0.23216200E+00, -.64452400E+00, 0.12249000E+00, 0.28020500E+01, 0.11024000E+01, -.45128900E+00, 0.28996200E-01, -.48847400E+00, -.58198600E-01, -.12611900E+00, 0.74157200E+00, 0.62606300E+00, -.13280600E+00, -.24104000E+00, 0.41146200E+01, 0.14881600E+00, 0.14601900E+01, -.40712700E+00, -.49504700E+00, 0.21294900E-01, 0.21295200E+00, 0.60379400E+00, -.45323100E+00, 0.21702200E+00, -.92207200E+00, -.96744500E-01, -.29752600E+00, 0.11543600E+00, 0.12770200E+01, -.56920400E-01, 0.63044100E-02, -.79636800E+00, -.57479300E-01, 0.14580600E+00, -.45607600E-01, -.44945500E+00, 0.34062100E+00, -.12214900E+00, 0.44694000E+00, 0.76234500E-01, -.39919400E+00, -.18977400E-02, 0.11578700E+00, -.11049600E+00, -.16026700E+00, 0.12075600E+00, -.29383100E+00, 0.32826400E+00, 0.16650600E+01, 0.72076300E+00, -.24328400E+00, -.10876200E+01, -.77294400E-01, -.25276700E+00, 0.60218300E+00, 0.22310600E+00, -.53078000E+00, -.44719800E+00, -.12346300E+00, 0.43961600E+00, 0.45558900E+00, -.23893800E+01, 0.53558500E+00, 0.79109200E-03, -.34403000E+00, -.14261100E+00, 0.32831600E+00, 0.43835900E+00, -.63571200E+00, 0.44823600E+00, 0.23610400E+00, -.52447600E-01, -.45988800E+00, 0.27098600E+00, 0.16499600E-01, 0.17528600E+00, -.64251600E-01, -.14548400E+00, -.80681500E+00, 0.11053000E+00, 0.43258000E-01, -.37339800E-01, -.74490200E+00, 0.75074800E-01, -.66960800E+00, 0.22998800E-01, -.15286500E+01, -.12593300E+00, -.84511500E+00, -.24344300E+00, 0.38812800E-02, -.20980700E+00, 0.51894100E+00, -.20275500E-01, 0.24518100E+00, 0.29180900E+00, 0.63956000E-02, 0.30925300E+00, -.43528900E-01, 0.66538100E-01, -.70513600E-01, 0.12501800E+00, 0.13951600E+00, 0.10575000E+00, 0.41919100E+00, 0.85662200E+00, 0.70101000E-01, -.69283700E-01, 0.28443400E+00, -.11144500E+03, 0.52894200E+02, 0.27981600E+02, 0.45286800E+02, -.98064700E+02, -.57584000E+02, 0.87771900E+02, -.43605700E+02, 0.14273200E+02, -.43856100E+02, 0.36812900E+01, 0.36705800E+02, -.42719900E+02, 0.22096600E+02, -.72474500E+02, 0.30838400E+02, -.36136800E+02, -.14326700E+03, 0.73969300E+02, 0.12749200E+03, 0.71650700E+02, -.98195300E+02, -.78569700E+02, 0.11932100E+02, -.55755900E+02, -.78878000E+01, -.34328600E+02, -.89021000E+01, -.19874000E+02, 0.96933800E+01, -.38341100E+01, 0.99366800E+01, 0.11184600E+02, 0.12471800E+02, -.19985400E+02, -.11787200E+02, -.68012900E+01, 0.10201600E+02, -.10208700E+02, -.64732200E+02, 0.31994200E+02, -.45052100E+02, 0.32380400E+02, -.53005600E+02, 0.93427800E+02, -.24758600E+03, -.24472500E+02, 0.31736400E+02, 0.14898100E+02, -.42492800E+03, 0.16286200E+03, -.80454700E+02, -.41847000E+02, -.81428500E+02, -.15510500E+02, 0.18635900E+02, -.71594300E+02, -.31031000E+02, -.57340200E+02, 0.11007100E+02, -.15868600E+03, -.24005900E+02, 0.11665300E+02, 0.11598600E+03, 0.12035000E+02, 0.93755200E+02, 0.40000000E+02, -.26107900E+03, 0.59415900E+01, 0.53278500E+01, -.20406500E+02, -.51395200E+03, -.71779700E+02, 0.34095700E+02, 0.22263300E+02, 0.36125900E+02, 0.31003900E+02, 0.20243500E+01, -.98348000E+01, 0.55611900E+02, 0.67149400E+02, -.20275100E+02, 0.76130900E+02, 0.49678800E+00, -.31361900E+00, 0.43316000E+00, -.24807500E+00, 0.54428600E+00, 0.69742100E+00, -.43524200E+00, 0.27765900E+01, 0.18462600E+00, -.31382200E+00, 0.74256000E+00, -.21387300E+03, 0.10732400E+03, 0.12667600E+03, 0.10689900E+03, 0.21588700E+02, 0.58769600E+01, 0.20261100E+02, -.57490800E+02, -.26370000E+02, 0.21537900E+02, -.10046700E+03, -.36276500E+03, 0.18129100E+03, 0.22132200E+03, 0.18138100E+03, 0.88888700E+02, 0.50775500E+02, 0.27846400E+02, -.14244500E+02, 0.97388000E+02, 0.32001200E+02, 0.37310000E+02, 0.34220500E+03, -.17138200E+03, -.27581300E+03, -.17110500E+03, -.79945400E+02, -.27488700E+02, -.34301400E+02, 0.55869400E+02, -.10193400E+03, -.26993700E+02, -.68229000E+02, -.12430600E+01, 0.75193900E+01, 0.14041400E+02, -.31445900E+01, -.12504600E+02, -.79408300E+00, -.10574700E+00, 0.78442500E+01, 0.45284400E+00, 0.32957700E+01, -.18420500E+00, 0.71719300E+00, 0.12973700E+01, 0.39428300E+01, 0.29079500E+02, 0.24040400E+01, -.25829500E+02, 0.37248800E+01, 0.17195600E-01, 0.33152200E+01, 0.12236100E+02, 0.36488900E+01, 0.31490000E+00, -.51699200E+01, -.37671000E+01, -.11016700E+02 },
        { 0.33524900E+00, -.12129100E+01, 0.31001500E+01, 0.10619000E+01, -.74466500E+00, -.80002500E-01, -.21221800E+01, -.20739000E+01, -.43073700E+00, -.17881500E-01, -.14712200E+00, 0.15424000E+01, 0.13629000E-01, 0.93016600E+00, 0.82021500E+00, 0.15065300E-01, 0.28386800E+00, -.24810700E+00, 0.46931600E+00, -.22461200E+00, -.42985700E+00, 0.40822400E+01, 0.11091900E+00, -.95911200E+00, 0.74626500E-01, 0.81287600E-01, 0.17585900E+00, -.64647600E-01, 0.59182300E+00, -.60957600E-01, -.29091200E+00, -.13385400E+00, -.17813500E+00, -.13218700E+00, 0.36066600E+00, 0.28099200E-01, -.17284100E-01, 0.67354700E+00, 0.41374200E+00, 0.42462100E+00, 0.32176900E-01, 0.48660900E+00, 0.36370600E+00, 0.25714600E+00, 0.16443600E+00, 0.50425800E+00, 0.20419000E+01, 0.74306800E-02, -.30522800E-01, 0.48328500E+00, -.57981200E-01, -.66631100E+00, -.12991000E+00, 0.26752100E+01, -.33345300E+00, 0.13069000E+01, -.23298100E+00, 0.32417300E+00, -.28791300E+00, -.54302300E+00, -.26452300E+00, -.82635000E+00, -.18977800E+00, 0.58725000E+00, -.12696100E+00, 0.11466700E+00, 0.49291300E-01, 0.70896100E-01, -.94857200E-01, -.12006600E-02, 0.15559600E+01, -.67447600E+00, 0.10789500E+00, 0.19060300E+00, 0.20376900E+00, -.43663600E+00, 0.11842200E+00, 0.84940200E+00, 0.67624300E-01, -.15225600E+00, -.15776100E-01, -.24136700E-01, 0.35890800E-01, -.29355500E-01, -.91293100E-01, 0.25743600E+00, 0.27735700E+00, -.46547200E+00, 0.63494000E+00, 0.10722200E-01, 0.40429200E+00, -.83364300E-01, 0.29825100E+00, -.17164400E+01, 0.31633000E+00, -.55662200E+00, 0.53995300E+00, -.62710900E+00, -.14173000E-01, 0.37514700E+00, 0.39587900E+00, 0.18154400E+00, 0.10105800E-02, -.88499900E+00, -.51601400E+00, 0.96836000E+00, 0.56666400E+00, 0.83443100E+00, -.98899800E+00, -.41103600E+00, 0.81545100E+00, -.11024900E+00, 0.14927200E+00, 0.49672000E-01, 0.25824100E+00, 0.57166200E-01, -.43943200E-01, -.21592700E+00, -.59653200E+00, -.50339600E-01, 0.10663300E-01, 0.23150400E+01, 0.16301600E+00, 0.12554600E+01, -.70586500E-01, 0.11047900E+01, 0.87662200E+00, 0.14932100E+01, 0.25763300E+00, 0.68079600E+00, 0.92133800E+00, -.20066800E+01, 0.27809600E+00, -.27781900E+00, -.37749300E+00, 0.40178000E-01, -.89086000E+00, -.11840600E+00, 0.49731500E-01, 0.13391700E+00, -.36763400E+00, 0.43701500E+00, -.90878500E-01, -.21634700E+00, -.11797200E+01, -.30274600E+00, -.14867700E+00, -.37588000E+00, -.10877200E+01, -.13062200E+03, -.14105900E+03, -.45107300E+02, 0.11286500E+02, 0.33308200E+01, 0.80379100E+01, -.69160400E+01, -.24546800E+01, -.21958500E+00, -.95517900E+02, -.17860100E+02, -.22006200E+02, -.72896100E+02, -.11426300E+02, 0.10580600E+02, 0.17045800E+02, -.96069700E+02, 0.49692600E+02, -.46096300E+02, 0.47136900E+02, -.11914500E+03, -.81881600E+02, 0.27617900E+02, -.44389300E+02, 0.59805200E+02, -.85329400E+02, 0.65466100E+02, 0.19193300E+02, -.85730000E+01, 0.93102900E+01, -.92076800E+01, -.11515800E+02, -.11591400E+02, 0.30942300E+02, 0.30214400E+02, 0.33066600E+02, -.15512100E+02, 0.30333700E+02, -.10110000E+04, 0.50738700E+03, 0.65199400E+03, 0.50684500E+03, 0.26312000E+02, 0.82677500E+02, 0.34638900E+03, -.27757700E+03, 0.34174900E+03, 0.39949900E+02, 0.12620600E+04, -.29102100E+03, 0.14297000E+03, 0.70366500E+02, 0.14534800E+03, 0.20480700E+02, -.67217600E+02, 0.50829700E+02, -.70934400E+02, 0.69914800E+02, -.79437100E+02, 0.23445600E+03, -.11282900E+04, 0.56782800E+03, 0.35068600E+03, 0.56677800E+03, -.34602200E+02, -.10814100E+02, 0.39986000E+03, -.27724700E+03, 0.48706100E+03, -.32067500E+02, 0.14748700E+04, -.68207400E+02, 0.34810700E+02, -.91580500E+02, 0.31437100E+02, 0.65779700E+02, 0.74720300E+02, -.40082900E+02, -.22902600E+03, -.99295400E+02, 0.69545200E+02, 0.76041600E+02, -.61509800E+00, -.10802000E+00, -.23305700E+01, 0.59618400E+00, -.16932900E+01, -.12148000E+00, -.74855500E+00, -.32357300E+01, 0.96974700E+00, 0.12846600E+01, 0.43526200E-01, 0.32035300E+03, -.16256700E+03, -.21717900E+03, -.15914500E+03, -.11241400E+03, -.15768000E+03, 0.50287000E+01, 0.10451800E+03, 0.72650900E+02, -.14363500E+03, -.17131900E+03, 0.78066600E+02, -.34559600E+02, -.91044300E+02, -.39707600E+02, -.71738100E+02, -.73921100E+02, 0.57301500E+02, 0.11873900E+02, 0.61807100E+02, -.81089600E+02, 0.22888400E+03, -.61558400E+03, 0.30497800E+03, 0.39015200E+03, 0.30860600E+03, 0.16857300E+03, 0.10496600E+03, 0.38303100E+02, -.15951700E+03, 0.34672700E+02, 0.95770400E+02, -.17387500E+02, 0.30289000E+01, 0.51059000E+01, 0.24523100E+01, 0.16805700E+01, -.11952200E+02, -.80396200E+00, -.48885100E+01, 0.55402300E-01, -.49988600E+00, -.59942300E+01, -.39710300E+00, -.23814200E+00, 0.77149600E+01, 0.11318500E+01, 0.35769800E+02, 0.84527500E+00, -.23251800E+02, -.93295600E+01, -.10937500E+03, 0.13649700E+01, 0.86634800E+02, 0.24308300E+01, -.36033800E+00, -.57216000E+01, -.24810300E+01, -.12951900E+02 },
        { 0.24826600E+00, 0.10157400E+01, 0.16430200E+01, -.14706500E+00, -.14834800E+01, -.27790800E+00, -.19355000E+01, 0.19981800E+00, -.35966200E+00, -.84902300E+00, 0.22996700E+00, 0.25494900E+01, 0.18459200E+00, 0.69861000E+00, 0.30397700E+00, 0.14322100E+00, 0.99950900E+00, -.25175000E+00, -.11395200E+00, -.18100900E+00, -.11794700E+00, 0.31262500E+01, 0.17405900E+00, 0.17175400E+00, -.63009100E-01, 0.17527700E+00, 0.51274900E+00, 0.60669600E+00, 0.10520400E+00, -.22766000E+00, 0.18367800E+00, -.22482000E+00, 0.33912600E+00, 0.25943000E+00, -.11421800E+00, -.14029200E+00, 0.36477200E-01, -.18000700E+00, 0.28132700E-01, -.35554300E+00, -.86560000E-01, -.87097700E+00, -.13270600E+01, -.31195900E-01, 0.44917700E+00, 0.17142100E+00, 0.20898000E-01, 0.45602800E-01, -.24643000E+00, 0.93582700E-02, -.85856100E+00, 0.11790800E+01, 0.84650100E+00, -.17822200E+01, -.33268300E+00, -.50566800E+00, -.23540000E+00, 0.29413600E+00, -.25476400E+00, -.29051000E-01, -.19044600E-01, 0.36101800E+00, -.24473300E+00, -.13328600E+00, 0.21762700E+00, -.22561000E+00, -.42104800E-01, -.37523200E+00, -.23782200E+00, -.28781600E-02, 0.11874300E+01, 0.89702200E+00, 0.20078700E-01, 0.63837700E-01, -.48832900E+00, 0.25393100E+00, 0.10287800E+00, -.82068400E+00, 0.36689800E+00, 0.23585100E+00, 0.33894500E-02, -.69706400E-01, 0.58488500E+00, -.11863000E+00, -.54236200E-01, 0.36441600E+00, -.13486800E+01, -.15063500E+01, -.51715900E+00, 0.31229400E+00, 0.32085900E+00, 0.17996400E+00, 0.10987000E-01, -.76500900E+00, 0.46907200E+00, 0.93594600E+00, 0.24362400E+00, -.56355300E+00, -.35992300E+00, -.11564900E+00, -.59005300E+00, -.17004200E+00, -.69448200E-02, -.51904200E+00, -.25627900E+00, -.49336700E+00, -.19092500E+00, 0.10470200E+01, -.11836300E+01, -.73706500E-01, 0.77859400E+00, 0.31196600E+00, 0.23349800E+00, 0.28265600E-01, -.18471500E+00, -.85891700E+00, -.39095600E-01, 0.43334500E+01, 0.12970000E+01, 0.15839200E+00, 0.60341700E+00, 0.13686000E+01, -.24254200E+00, -.94498200E+00, -.82405100E-01, 0.58994700E+00, -.12384000E+01, 0.30063400E+00, 0.97777100E-01, -.59254200E-01, 0.27290500E+00, -.46851400E+00, 0.59529300E-01, 0.34462700E+00, -.18001100E+00, 0.32272000E-01, -.37930300E+00, -.29493100E+00, -.29857700E+00, 0.10321100E+01, -.23165300E+00, -.20890800E-01, -.24358100E+00, -.99129600E+00, -.12459100E+01, -.27532700E+00, 0.22448500E+00, 0.59226600E+00, -.47773100E+00, -.22940800E+00, -.11313200E+03, -.16216700E+03, 0.34694000E+02, -.77132200E+02, -.97715900E+02, 0.42374100E+02, 0.11443000E+03, 0.52290500E+02, -.58316900E+02, -.24680900E+02, 0.60503800E+02, -.13095700E+03, 0.10706900E+03, 0.28882600E+02, 0.57917100E+02, 0.46543800E+03, -.23253500E+03, -.26991700E+03, -.23350900E+03, 0.92781200E+02, 0.23515200E+03, -.30361200E+03, 0.45163200E+02, -.80409500E+02, 0.16059500E+03, -.12946200E+03, 0.39228300E+02, -.17381800E+02, -.24234200E+02, -.19266700E+02, -.19268700E+02, -.86317100E+01, 0.54484700E+02, 0.25880800E+02, -.17618100E+01, -.94003800E+01, 0.20254000E+02, 0.27124600E+03, -.13115900E+03, 0.23000900E+02, -.13440100E+03, -.11661800E+03, -.36863700E+03, 0.74743300E+03, 0.43806400E+03, 0.42211500E+03, -.41983200E+03, 0.55182500E+03, -.40685700E+03, 0.19812600E+03, 0.21636300E+03, 0.20330600E+03, 0.12807800E+03, -.61447800E+02, 0.59207900E+02, -.10625500E+03, 0.21579300E+02, -.77159400E+02, 0.32793400E+03, 0.50284100E+03, -.24322700E+03, -.40457500E+03, -.24902700E+03, -.90216900E+02, -.12381500E+03, 0.67834000E+03, 0.42123400E+03, 0.33223700E+03, -.25419300E+03, 0.63584400E+03, -.13185500E+03, 0.67904600E+02, -.11054500E+03, 0.63297500E+02, 0.46663000E+02, 0.37967000E+02, 0.13245700E+03, -.28442500E+03, -.48072300E+02, 0.12807200E+02, 0.12286100E+03, 0.18210600E+01, -.15507400E+01, -.50330900E+00, -.65188200E+00, 0.11319500E+01, 0.15890700E+01, 0.53891900E+01, -.41301900E+01, 0.13510800E+01, 0.24010100E+01, -.24157700E+01, 0.74292800E+03, -.37838700E+03, -.37380200E+03, -.37055400E+03, -.42068500E+02, -.77314400E+02, -.13506300E+03, 0.12530000E+03, -.60416000E+02, -.67796000E+02, -.20565600E+03, -.12464300E+03, 0.70111600E+02, 0.70586200E+02, 0.61717500E+02, 0.11395600E+03, -.53706200E+02, 0.11081400E+03, -.30067300E+03, -.20106600E+03, -.80953600E+01, 0.33811100E+03, -.20794400E+03, 0.99165400E+02, 0.13345100E+03, 0.10469700E+03, -.27532500E+02, 0.80361500E+02, -.75306600E+02, 0.18591200E+03, 0.30377000E+03, 0.20919100E+02, -.21185000E+03, 0.44619500E-01, 0.24955600E+02, -.14882300E+02, -.10693000E+02, -.81486900E+01, -.11815900E+02, 0.27802300E+02, 0.28776300E+02, -.28923300E+00, -.50394800E+01, -.52077400E+01, -.81928900E+01, 0.13370900E+02, 0.86258000E+01, 0.10541000E+02, -.89854900E+00, 0.58250000E+01, 0.29638100E+01, -.13067600E+03, -.11019600E+02, 0.38320200E+02, -.16650000E+02, -.55735000E-01, 0.10129000E+02, 0.44769000E+02, 0.33078200E+02 },
        { 0.58374000E+00, -.56384000E+00, -.70814200E+00, 0.25005100E+00, 0.56445300E+00, 0.14970600E+00, 0.32128800E+00, -.23733200E+01, -.25828400E+00, 0.26660000E+00, -.18330200E+00, 0.10641700E+01, -.48048600E+00, 0.23610300E+00, -.22821700E+01, -.40428400E+00, -.54562400E+00, -.34845900E-01, -.24965700E+01, 0.77084900E+00, -.10195100E+01, 0.29242800E+01, -.18509500E+00, -.73915800E+00, 0.11089900E+00, -.23519100E+00, 0.39707300E+00, -.57317400E+00, 0.35940200E+00, -.11330400E+00, -.10087400E+01, -.61819300E+00, 0.58945100E-01, 0.11374600E+01, 0.39609800E+00, 0.67600600E+00, 0.58793900E-02, 0.16403600E+01, 0.48514600E+00, -.97431000E-01, -.98500300E+00, -.12227000E+01, -.11374900E+01, 0.15213200E+00, 0.11283400E+01, 0.47007500E+00, 0.14628200E+01, 0.60801700E-01, 0.22785600E+00, 0.58682700E+00, 0.66957200E+00, -.33501400E+00, 0.55601500E+00, -.36951300E+01, -.12965100E+01, 0.10008400E+01, 0.97482300E+00, 0.19291200E+00, -.34285400E+00, -.36643600E+00, -.13768000E+00, -.47382900E+00, 0.36089600E-01, 0.17416600E+00, 0.29285800E+00, 0.30823200E+00, -.28705000E+00, -.83620800E+00, 0.71099400E+00, -.92758000E-03, -.71655000E+00, -.14212300E+01, 0.29251000E+00, 0.10981800E+00, -.49116100E+00, 0.14400900E+00, 0.13377600E-01, 0.17509700E+00, 0.16135300E+00, 0.36335400E+00, 0.55624600E-02, -.24595200E-01, 0.92083800E+00, -.26914400E+00, -.92781700E-01, -.50878500E-01, -.18829700E+00, -.14090600E+01, 0.56484300E-01, 0.29951200E-01, 0.23572800E+01, 0.26432100E+00, 0.87794100E-01, -.12371200E+01, 0.80282700E+00, 0.17857700E+01, 0.28514400E+00, -.68655100E-01, 0.34427000E+00, -.43213000E+00, -.10186200E+01, -.18386400E+01, 0.31577600E-01, 0.54784400E+00, 0.70570100E+00, -.11231200E+01, -.82143100E+00, 0.18307200E+01, -.95816200E+00, -.78632900E+00, 0.48827800E+00, 0.84214100E+00, -.50505000E+00, 0.38242300E-01, -.33511000E+00, 0.53316900E+00, 0.11041900E+00, 0.16581000E+01, -.10025100E+01, -.10535400E+00, 0.39604100E-01, 0.11439600E+01, 0.18796900E+00, 0.16167600E+01, -.23061600E+00, 0.35713900E+00, -.75030000E+00, 0.19934700E+00, 0.62248700E-01, 0.24671700E-01, 0.19022200E+00, 0.89013100E+00, -.20724200E-01, -.19604200E+00, -.66211200E+00, -.38191000E-02, -.58379000E+00, 0.71859800E-01, 0.61830200E-01, 0.38969800E+00, -.12439300E+00, 0.52278800E+00, -.13677700E+00, 0.96292700E+00, 0.30553500E+00, -.14679500E+00, 0.11485300E+00, 0.57814900E-01, 0.88173200E+00, -.41593300E+00, -.12442700E+01, -.20333100E+03, 0.34723000E+02, -.10873400E+03, -.25705600E+03, 0.11615000E+03, 0.45478200E+02, 0.13371500E+03, -.19682200E+03, -.99573400E+02, 0.13201800E+03, -.32386300E+03, 0.22401100E+03, 0.13637500E+02, 0.39186800E+03, 0.78144100E+03, -.39233600E+03, -.65442100E+03, -.39199000E+03, 0.25340400E+03, 0.35153700E+03, -.32991300E+03, 0.19228500E+03, -.23048000E+02, 0.18361900E+03, -.17758000E+03, 0.15288100E+03, -.72202600E+02, -.42074500E+02, -.75907400E+02, -.51094500E+02, -.50639500E+02, 0.13289000E+03, 0.99872000E+02, 0.27785300E+02, -.57084700E+02, 0.38463400E+00, -.56789000E+03, 0.29129300E+03, 0.10067500E+04, 0.28578500E+03, -.23513000E+03, -.61187900E+03, 0.16990800E+04, 0.25546300E+03, 0.82043300E+03, -.61097300E+03, 0.21677000E+04, -.14290900E+04, 0.70307300E+03, 0.60061700E+03, 0.71439900E+03, 0.18349500E+03, -.30979500E+03, 0.26750100E+03, -.22319600E+03, 0.25927700E+03, -.30041400E+03, 0.10393200E+04, -.89095400E+03, 0.45961300E+03, -.44023600E+03, 0.44907100E+03, -.46786700E+03, -.55484900E+03, 0.17989400E+04, 0.10891200E+03, 0.10907000E+04, -.61886500E+03, 0.27194700E+04, -.20523600E+03, 0.10858300E+03, -.36360000E+03, 0.98306200E+02, 0.14190800E+02, 0.15964700E+03, 0.89194100E+02, -.73330200E+03, -.17125000E+03, 0.15061100E+03, 0.25952800E+03, -.23422100E+01, -.61923700E-01, -.57128900E+01, 0.15672200E+01, -.11964500E+01, 0.11042300E+01, 0.82581200E+01, -.16072300E+02, 0.35249600E+01, 0.51676000E+01, 0.34196200E+01, 0.11447800E+04, -.58338200E+03, -.68594300E+03, -.57077700E+03, -.11974600E+03, -.24412600E+03, -.93085100E+02, 0.34868500E+03, 0.95980000E+02, -.24302000E+03, -.13794700E+02, 0.55936200E+03, -.26574100E+03, -.53127100E+03, -.28060300E+03, -.93419500E+02, -.29237400E+03, 0.26022700E+03, -.13830900E+03, -.25181600E+03, -.25573800E+03, -.30075500E+02, -.13634100E+04, 0.67233000E+03, 0.10370000E+04, 0.68282100E+03, 0.24206900E+03, 0.25080800E+03, -.17525900E+03, -.27309300E+03, 0.48006500E+03, 0.20363600E+03, 0.39762600E+03, 0.10431400E+02, 0.68245700E+01, -.54108600E+02, -.24997300E+02, -.50220400E+01, -.85117300E+01, 0.33744900E+02, 0.68846700E+00, -.20214000E+01, -.16703000E+02, -.22289800E+01, -.13790500E+01, 0.13541000E+02, 0.16909000E+02, -.10382600E+02, 0.43973800E+01, 0.45931600E+02, -.57338200E+01, -.28433000E+03, -.14352600E+02, 0.12912100E+03, -.39739300E+02, -.11156300E+01, 0.13326500E+02, 0.47009900E+02, 0.57286800E+02 },
        { -.75617500E-01, 0.26549700E+00, 0.10318100E+01, -.33037300E+00, -.32304800E+00, 0.43962900E-01, -.64345900E+00, -.11513200E+01, -.37812300E+00, 0.11563000E+00, 0.40795800E-01, -.49789200E+00, 0.14259800E+00, 0.32793300E-02, -.53654700E-01, -.42207200E+00, -.31109300E+00, 0.30641400E-01, 0.17826000E+00, -.87954600E-01, -.37512700E+00, 0.16498600E+00, -.23088300E+00, -.21044100E+00, 0.36530700E+00, 0.62136700E-01, -.34491600E+00, 0.34393400E+00, -.18938600E+00, -.10478200E+00, 0.89104300E-01, -.56147000E-01, -.70542100E+00, 0.25125200E+00, 0.29442600E+00, -.70052900E-01, -.38536300E-01, 0.97021800E+00, 0.46947400E+00, 0.62665800E+00, 0.37848500E-02, 0.99600300E-01, 0.19655200E+01, 0.86775300E+00, -.68597300E-01, 0.19387900E+00, 0.50374500E-01, -.62298200E-01, 0.75708200E-01, 0.89104000E+00, 0.99336600E+00, -.20004100E+00, -.62373400E+00, 0.27417200E+01, -.34630800E+00, 0.17541900E+01, 0.46495000E+00, 0.25441400E+00, 0.11839900E+00, 0.65764700E+00, 0.17234700E+00, -.28954900E+00, 0.57333600E-01, -.43605800E+00, -.54019500E-02, 0.33771500E+00, 0.30341900E+00, 0.63267300E+00, 0.68994000E-01, -.12276300E-02, -.28220500E+00, 0.77483400E+00, -.16781500E+00, -.17816600E+00, 0.16557000E-01, -.50796600E+00, 0.11596800E+00, 0.25365900E+00, -.13883700E+00, 0.53077400E-01, -.78641000E-02, 0.61843100E-01, 0.99801200E-01, 0.21680300E+00, -.99578700E-01, 0.43721700E-01, -.47057900E+00, -.31139000E-01, 0.27683100E+00, 0.24840100E+00, -.10464100E+01, -.15076800E+00, 0.59604900E+00, 0.10264900E+01, 0.59560800E-03, -.44494100E+00, -.25813600E+00, -.18764500E+00, 0.11351000E-01, 0.25183600E+00, -.80381600E+00, 0.54442200E+00, -.11840200E-02, -.73510400E-01, -.79601600E-01, 0.13241600E+00, 0.27048800E+00, 0.21751300E+00, 0.31779000E+00, 0.51813700E-01, -.50363400E+00, -.19719300E+00, -.23352000E-01, 0.34041100E-01, 0.91162400E-01, 0.60366100E-01, -.16919400E+00, -.10862400E+01, -.32191500E-01, 0.57011200E-01, -.53702600E-01, -.83607100E+00, -.44217400E-01, -.58849900E+00, 0.10223500E-02, -.63108300E+00, -.21178200E+00, -.40740500E+00, -.10029400E+00, -.83210500E-01, -.20141000E+00, 0.55820900E+00, -.47304700E-01, 0.12321600E+00, 0.13778100E+00, -.22271600E-02, 0.69469600E+00, 0.94181700E-01, 0.94856900E-01, 0.12775800E+00, -.27586100E-01, -.11629800E+01, -.14881800E-01, -.23545800E+00, 0.38345700E+00, 0.65272600E-01, 0.12887100E-01, 0.40755900E+00, 0.59591900E+00, -.22546600E+00, 0.26274300E-01, 0.19482100E-01, 0.16516400E+02, 0.18060300E+02, 0.32403400E+02, -.18004100E+02, 0.58221400E+02, -.16272400E+02, 0.23660600E+02, 0.16127700E+02, 0.12331400E+02, -.12929700E+02, -.22462800E+02, 0.19343000E+02, -.41925600E+02, -.26345100E+02, 0.16770300E+02, -.38005300E+01, 0.13190600E+02, 0.59050700E+00, 0.16514900E+02, -.21783800E+02, -.34481400E+02, -.12213200E+02, 0.17612200E+02, 0.71078100E+01, 0.95922800E+01, -.41952700E+01, -.34484200E+01, -.48047400E+01, -.52383900E+01, -.13481200E+01, 0.88965600E+01, 0.62206100E+00, -.69730600E+00, -.39713000E+01, -.92418000E+01, -.26289900E+02, 0.13983700E+02, 0.45526200E+01, 0.13121800E+02, -.77283800E+02, -.95541000E+02, 0.19327700E+03, 0.54551900E+02, 0.51464700E+02, -.14382600E+03, -.13215800E+03, 0.39932500E+02, -.21268900E+02, 0.28156100E+01, -.19941800E+02, 0.70444100E+01, 0.10925300E+02, -.30689100E+02, -.27494800E+02, -.57583900E+02, -.25927500E+01, 0.23085500E+02, -.40170100E+00, 0.22432700E+01, 0.27041300E+02, 0.15823400E+00, -.15080300E+03, -.14938700E+03, 0.21981700E+03, 0.60260600E+02, 0.41352400E+02, -.18485900E+03, -.16450300E+03, 0.16488900E+02, -.87664500E+01, -.72875200E-01, -.80281300E+01, -.95686500E+01, -.19962100E+02, 0.44559200E+02, 0.32274200E+02, 0.25539200E+02, -.49894700E+02, -.27206400E+02, 0.25542400E+00, -.56749000E+00, 0.41550200E+00, -.13366500E+00, 0.61458200E+00, 0.20163400E+00, 0.31323200E+01, 0.12056100E+01, 0.15097000E+00, -.79375700E-01, -.48401200E+00, -.22149600E+02, 0.91001700E+01, 0.18436300E+02, 0.11068600E+02, 0.11591300E+02, 0.20921600E+02, -.27369700E+02, -.57359800E+02, -.23719300E+02, 0.27564800E+02, 0.18528900E+02, -.10645200E+03, 0.57824800E+02, 0.57817500E+01, 0.53240500E+02, 0.63588000E+01, -.40711600E+01, 0.99476000E+01, -.25599700E+02, 0.74479700E+02, -.87018100E+01, 0.22299500E+02, -.86979800E+02, 0.41075400E+02, 0.47939800E+02, 0.43470600E+02, -.45548900E+00, 0.11175600E+02, 0.19546400E+02, -.35964500E+02, -.13858400E+02, -.11883100E+00, 0.43479600E+02, -.99948100E+00, -.34030100E+01, 0.25315000E+01, -.28116600E+01, 0.20629400E+00, -.22561500E+01, 0.58645100E+01, -.37820300E+01, 0.25222500E+00, 0.13292500E+01, -.16912300E+01, -.10283200E+01, 0.41296600E+01, 0.48485800E-01, 0.21394700E+01, -.79254900E+00, -.19147400E+01, 0.38407000E+00, -.17148400E+02, -.82865800E+01, 0.96083300E+01, 0.41657400E+00, 0.33682900E+00, 0.46174100E+01, -.95310600E+01, -.12336700E+02 },
        { 0.10127400E+00, -.48054300E+00, 0.92986600E+00, 0.14380600E+00, -.61877000E+00, -.87929000E-01, -.88052500E+00, 0.40636100E+00, 0.17418500E+00, -.26780700E+00, -.29282900E-02, 0.11747300E+01, -.14554500E+00, 0.53545400E+00, 0.48837500E-02, 0.11417700E-01, 0.45487900E+00, -.10690400E+00, -.10595200E-01, -.18709900E+00, 0.28933200E-01, 0.14912700E+01, -.29724600E-01, -.18652600E+00, 0.17634700E+00, 0.18740500E-01, 0.34302300E+00, 0.45036800E+00, 0.95802700E-01, -.27918300E+00, -.73522900E-01, -.92063500E-01, -.76361100E-01, 0.26086900E+00, -.12349300E+00, 0.49627900E-01, -.35447100E-02, 0.12775400E+00, -.21376000E+00, 0.29484000E+00, 0.83036000E-01, 0.27025800E+00, 0.48152900E+00, 0.81737100E-01, -.18626300E+00, 0.49434800E-01, 0.22682400E+00, 0.24052800E-01, -.18483100E-02, 0.14366900E+00, 0.15819800E-01, -.19800300E+00, 0.11712200E+00, 0.10717900E+01, 0.46629000E-01, 0.84162900E-02, -.47887500E-01, 0.26365800E+00, -.10868900E+00, 0.13933700E+00, -.13261600E+00, -.58818900E-01, 0.23859900E-01, 0.16797700E-01, 0.46905400E-01, 0.91372900E-01, 0.11307900E+00, -.10627600E+00, -.39358600E+00, -.29340200E-02, 0.48590600E+00, 0.20102200E+00, 0.89492800E-01, 0.42999900E-02, -.33278900E-02, -.97864600E-01, -.43315800E-01, 0.22305200E+00, 0.69368500E-01, -.52688600E-01, 0.15268700E-02, -.59581500E-01, 0.57628100E+00, -.11011200E+00, -.80594400E-01, 0.13185600E+00, -.44096800E+00, 0.19276000E+00, 0.29250300E+00, 0.71626700E-02, 0.33289900E+00, 0.33420000E-01, -.28349100E+00, -.56490900E+00, -.19814500E+00, 0.42886200E-01, 0.26505100E+00, -.30296900E+00, -.82933000E-01, -.13117600E+00, 0.10924500E+01, -.38436200E-01, -.36358300E-02, 0.85251500E-01, 0.37024900E-01, -.52250600E-01, -.25641100E-01, 0.15216900E-01, 0.56768800E-01, -.14387700E+00, -.11086600E+00, 0.12157200E+00, -.10156200E+00, 0.53900600E-02, 0.91842500E-02, 0.42205000E-01, 0.57968600E-01, -.12778500E+01, -.71695800E-01, -.85721900E-01, 0.45344300E-01, -.39360300E+00, -.88035000E-01, -.12833600E+00, 0.53541700E-01, -.54233100E-01, 0.19042600E+00, 0.10498200E+00, 0.32810200E-01, -.12830900E+00, -.16650300E+00, 0.37122400E-01, -.23723200E-01, -.10239700E+00, -.23261300E-01, -.13447400E-01, 0.23873900E+00, 0.54358300E-01, 0.53259100E-01, -.49522300E+00, -.18927300E-01, 0.42038400E-01, 0.13720400E+00, -.36910000E+00, -.38093200E+00, -.79991000E-02, -.36916600E-01, 0.81492800E-01, 0.10158200E-01, 0.88487000E-01, 0.21022800E+00, -.20820900E+00, 0.16009900E+00, -.50048700E+02, -.30444300E+02, 0.15633700E+02, -.20797000E+01, 0.14774100E+02, 0.82781400E+01, 0.42319700E+01, -.20274800E+02, 0.16913900E+02, 0.26179700E+02, -.11627600E+02, 0.30320300E+02, 0.83872500E+02, -.43514600E+02, -.81358800E+02, -.41840300E+02, 0.24469700E+02, 0.10195300E+02, -.74422500E+01, 0.44558100E+02, 0.15268500E+02, 0.45142600E+00, -.16676300E+02, 0.19230300E+02, -.96610700E+01, -.22342100E+01, -.96595000E+01, -.49890000E+01, -.69139100E+01, 0.42735100E+01, 0.13214200E+02, 0.64117300E+01, -.60317700E+01, -.11202100E+02, -.26525200E+03, 0.13262200E+03, 0.28005200E+03, 0.13246500E+03, 0.46329500E+02, 0.69199200E+02, 0.35242700E+02, -.68784000E+02, 0.78547800E+02, 0.70348400E+02, 0.16237700E+03, -.11488200E+01, 0.77597800E+00, 0.60122100E+01, 0.59159700E+00, 0.10932700E+02, 0.24106500E+02, 0.97284500E+01, 0.48727400E+01, 0.54938100E+01, 0.17580600E+02, -.44446400E+02, -.48100200E+03, 0.24040300E+03, 0.65809700E+02, 0.24018500E+03, 0.98471900E+02, 0.38735100E+02, 0.67650600E+02, -.96110400E+02, 0.21116300E+03, 0.34343900E+02, 0.28665000E+03, -.64360000E+02, 0.32390500E+02, -.37369500E+02, 0.32339800E+02, 0.10388600E+02, 0.82641900E+01, 0.21805400E+02, -.17822800E+02, 0.53881700E+01, 0.18119600E+02, 0.52562400E+02, -.10459800E+01, 0.61223900E+00, 0.61808500E-01, 0.48983400E+00, -.11258500E+00, -.10142800E+01, -.13821500E+01, 0.99371800E+00, 0.76718200E+00, -.10506900E+01, -.60657400E-01, 0.31198800E+02, -.14802900E+02, -.55784500E+02, -.15692500E+02, 0.67654800E+01, 0.29629300E+01, 0.24134600E+01, 0.35126600E+02, 0.18935200E+02, -.22920600E+01, 0.39437600E+02, 0.61303800E+02, -.31947900E+02, -.93421500E+02, -.30574300E+02, 0.14063600E+02, -.81927300E+01, 0.18229700E+02, 0.11455300E+02, -.17759800E+02, -.30758900E+01, -.46195500E+02, -.50796100E+02, 0.25955500E+02, 0.12079900E+03, 0.25306000E+02, -.22090600E+02, 0.17849200E+01, -.30053600E+02, -.13926700E+02, -.13988700E+02, 0.74380700E+01, 0.58586600E+02, 0.96718800E-01, -.16525000E+02, -.13266700E+02, -.11798600E+01, -.27525000E+01, 0.14052200E+01, -.58771600E+00, -.18334800E+02, -.58523700E-01, -.54789500E+00, 0.71834900E+00, 0.19361500E+01, -.10423100E+00, 0.19261300E+01, 0.29754600E+01, -.97790500E+00, 0.99619600E+01, -.97181000E+00, -.36310800E+02, 0.14766200E+01, 0.35295300E+02, -.11020100E+01, 0.70815800E-01, -.44763000E+01, 0.50250600E+01, 0.11850400E+02 },
        { -.25884200E+00, -.46556600E-01, -.29955700E+01, -.13287400E+00, 0.69916200E+00, -.51290800E-01, -.13711800E+01, 0.65136100E+00, -.43142200E-01, 0.93821600E-03, 0.95130300E-01, -.19413800E+01, 0.37665000E+00, -.47829000E+00, 0.27757500E+00, 0.59209000E+00, -.25252300E+00, -.13531800E+00, 0.66659500E+00, -.43707800E+00, -.12757600E+00, 0.26373600E+01, 0.38541600E+00, -.20477400E+00, -.65262000E+00, 0.24625800E-01, 0.42878900E+00, -.65132900E+00, 0.42895000E+00, 0.64862200E+00, 0.10506200E+00, 0.15941500E+00, 0.99919200E-01, -.30399600E+00, 0.20358500E-01, 0.28638500E+00, -.12618400E-01, 0.77422500E+00, 0.42372300E+00, 0.37802100E+00, -.16158800E+01, 0.12054300E+01, -.26333200E+00, 0.46500600E-02, 0.11019700E+00, 0.78010100E-01, 0.20573100E+00, -.81385000E-02, -.40554900E-02, 0.48767800E-01, 0.46271400E+00, -.47314700E+00, 0.20534300E+00, -.77054700E+00, -.33837500E-01, -.56483400E+00, -.24466700E-01, 0.25190600E-01, 0.33883400E-01, 0.27687100E+00, -.13566100E+00, 0.32476700E+00, -.25480200E+00, 0.39728600E+00, 0.55809900E-01, 0.15750900E+00, 0.61648600E-01, 0.42688400E-01, -.49179800E+00, 0.10564300E-02, 0.61224100E-01, 0.12230300E-01, 0.60962900E-01, -.14553300E-02, 0.18884300E+00, -.68546300E-01, -.20674400E+00, -.20245700E-01, 0.15918300E+00, 0.14116400E-01, 0.14993600E-01, -.93641500E-01, 0.21212400E+00, -.74737600E-01, -.35023600E-02, -.51290600E-01, -.15669000E+00, 0.10460600E+01, 0.99956200E+00, -.10865700E+00, 0.24807100E+00, 0.47742600E-01, -.34908300E+00, -.33394700E+00, -.16997700E+00, 0.87284200E+00, 0.12402600E+00, -.26731300E+00, 0.20068500E+00, -.46828400E-01, 0.35309100E+00, -.48638100E+00, -.80183500E-02, 0.32021500E+00, 0.22408800E+00, -.37981500E+00, -.25347200E+00, -.22152900E+00, 0.18079500E+00, -.22763100E+00, 0.58003200E+00, 0.17485400E+00, 0.25484400E-01, 0.75411800E-01, 0.10748700E+00, 0.28632000E+00, 0.10375900E+00, -.33319600E-01, -.19373200E+00, -.36729400E-01, 0.54193400E-01, 0.39532900E+00, -.22535200E+00, 0.39010300E+00, 0.71603700E-02, -.38204300E+00, -.13253700E+00, -.42362400E+00, -.10744500E+00, -.53526900E-01, -.18509100E+00, -.20800400E+00, 0.45856800E-01, -.44473800E-01, 0.95829900E-01, 0.42579500E-02, 0.32446100E-01, -.10860600E+00, -.51726100E-01, -.37572200E+00, 0.18647200E+00, 0.19461000E+00, -.80195500E-01, 0.38342500E+00, 0.45529700E+00, 0.23749700E+00, -.75072600E-01, -.14411500E+00, -.29985600E-01, -.74382900E-01, 0.24812200E+00, -.21926500E+00, -.11436300E+00, -.15483000E+00, 0.59201400E+02, -.30017600E+02, -.23536200E+02, -.29977900E+02, -.78745000E+02, -.54975000E+02, 0.15126900E+02, 0.48889600E+02, -.10022900E+02, -.53806700E+02, -.61886600E+02, -.34381100E+02, 0.15221300E+02, -.12275200E+01, 0.17289800E+02, -.43943300E+02, -.46224000E+02, 0.39938800E+02, 0.58099800E+02, 0.18561600E+02, -.50852200E+02, 0.14113000E+02, 0.14174100E+02, -.69183700E+01, -.38882300E+01, -.71268300E+01, -.66304800E+01, 0.20147000E+01, -.23696800E+01, 0.79635400E+01, 0.16017500E+01, 0.36574400E+01, -.15984700E+02, -.82212300E+03, 0.41118400E+03, 0.44620500E+03, 0.41092900E+03, 0.41914100E+01, 0.25250800E+03, -.83236900E+01, -.32816000E+03, 0.14932300E+03, 0.25156500E+03, 0.18231200E+03, -.19539300E+02, 0.95421700E+01, 0.16924900E+02, 0.97822600E+01, -.38977900E+02, -.64258600E+02, 0.48899300E+02, -.74613000E+01, 0.37861800E+02, -.59404000E+02, -.17869000E+02, -.86677800E+03, 0.43408600E+03, 0.36622300E+03, 0.43313100E+03, 0.51371600E+02, 0.18724100E+03, -.10497700E+02, -.33606200E+03, 0.21569700E+03, 0.21069300E+03, 0.20752800E+03, 0.76266900E+02, -.38979900E+02, -.10660400E+02, -.37913200E+02, -.19926000E+02, 0.16176500E+02, -.22189800E+02, -.35293100E+02, -.20677000E+02, 0.25231800E+02, -.54651200E+02, -.28232300E+00, 0.91590100E-01, -.62597100E+00, 0.11178400E+00, -.15573500E+01, -.29927500E+00, -.23265100E+01, -.54511800E+00, -.18253800E+01, 0.46609300E+00, 0.29935600E-01, -.16017400E+03, 0.78240800E+02, 0.50609800E+02, 0.79958600E+02, -.27383800E+02, -.23973400E+02, 0.94418200E+02, 0.95762000E+02, 0.65609500E+02, -.25483600E+02, 0.83614000E+01, -.49722700E+02, 0.24476100E+02, 0.50667700E+01, 0.24929700E+02, 0.88591000E+01, -.12004500E+02, 0.53262300E+02, 0.10686800E+03, 0.87921000E+02, -.26375900E+02, -.21688200E+02, -.10690100E+03, 0.52932600E+02, 0.55115500E+02, 0.53366700E+02, -.24938000E+02, 0.47736400E+02, -.44328000E+02, -.10937100E+03, -.12743600E+03, 0.61765400E+02, 0.77741100E+02, 0.30008900E+00, 0.13808600E+01, 0.63007100E+01, 0.50483800E+01, 0.12830700E+01, 0.12851100E+01, -.59408000E+01, -.40195800E+01, 0.15990100E+00, -.71609700E+00, -.26248500E-01, -.57884500E+01, -.48828300E+01, 0.40897300E+00, -.34449300E+01, 0.13907500E+01, -.12787100E+02, 0.23729200E+01, -.10139700E+02, 0.60248400E+01, 0.16017400E+02, -.18089300E+00, 0.37876300E-01, -.10492500E+02, -.64356400E+01, -.51086500E+01 },
        { -.23294000E+00, -.71624100E+00, -.18781800E+01, 0.11801500E+00, 0.16621900E+01, 0.30392300E+00, 0.11814800E+01, -.21329400E+01, 0.10408200E+00, 0.78498400E+00, -.21370200E+00, -.14456100E+01, -.19906500E+00, -.36905900E+00, -.10706400E+00, -.44367700E+00, -.94446500E+00, 0.33690700E+00, 0.88149600E+00, -.24929400E+00, 0.52729400E+00, -.31391700E+00, 0.26177500E+00, -.81384800E+00, -.76147200E+00, -.38950700E+00, -.13520300E+01, -.16113200E+00, 0.17348900E+00, 0.85809100E+00, 0.12023200E+00, 0.23399500E+00, -.51456500E+00, 0.70407300E+00, -.39871200E+00, -.69276600E+00, -.38560100E-01, -.13001000E+01, 0.31970900E+00, -.40818400E+00, -.56389300E+00, -.10518200E+01, -.14470500E+00, 0.33667600E+00, 0.23938200E+00, -.23994300E+00, -.13497800E+01, -.13762700E+00, -.74089200E+00, -.30665300E+00, -.12283600E+01, 0.16633700E+01, 0.14133100E+01, 0.14238000E+01, 0.16070700E+00, 0.56930300E+00, -.40324100E-01, -.41938500E+00, -.10262300E+00, -.20467500E-01, 0.28509800E+00, -.24941000E+00, 0.48349500E+00, -.68185800E+00, 0.42936300E-01, -.30025100E+00, 0.99531400E-01, 0.11613400E+01, -.61291900E+00, -.89871600E-02, 0.32388800E+00, -.33041500E+00, 0.19884400E+00, -.63219200E-01, -.38035300E+00, -.28059800E-02, 0.26675400E+00, 0.50706500E-01, -.31647800E+00, -.50072500E+00, -.27277700E-01, 0.79570600E-01, 0.80609500E+00, -.29725100E-01, -.37660300E-01, -.30860200E+00, -.34434800E+00, 0.33198800E+00, -.31844900E+00, 0.26330800E+00, -.14446500E+01, -.37242700E+00, 0.49999700E+00, 0.19760400E+01, -.71579900E+00, -.17933800E+01, 0.35198100E-01, -.33848500E+00, -.42257700E+00, -.32448500E-01, -.20877400E+01, 0.47441100E+00, 0.73185800E-01, -.60084400E+00, -.13813700E+00, -.10987600E+01, -.10486400E+00, -.86808600E+00, 0.10248100E+01, 0.35716600E+00, -.64010800E+00, -.46284000E+00, 0.68130200E-01, -.14527600E+00, -.24193500E+00, -.86903000E-01, 0.14520500E+00, 0.12538800E+01, 0.52517800E+00, 0.86344100E-01, -.23441200E+00, 0.74734200E-01, -.25219900E+00, 0.11166300E+00, 0.15878500E+00, -.27643400E+00, 0.13427600E+00, -.55086700E+00, -.54540300E-01, 0.19385800E+00, 0.34754300E-01, -.16071100E+01, 0.16119300E+00, 0.16168300E+00, -.19083300E-01, 0.19868200E-01, -.70820900E-01, -.44441500E+00, -.26861100E+00, -.68591100E+00, 0.19630000E+00, 0.24175500E+00, 0.21171200E+00, 0.76193700E+00, 0.69637100E+00, -.57174900E-01, -.31288300E-01, 0.46786900E+00, -.15932900E+00, -.10597300E+00, 0.67079200E+00, -.38707300E-01, -.19042000E+00, -.13345200E+01, 0.60142700E+00, 0.42726800E+01, 0.13343700E+03, -.28864700E+00, 0.15607500E+03, 0.84209000E+02, -.82662500E+02, 0.68896900E+02, -.44643000E+02, 0.35474900E+02, -.13300100E+03, -.21899100E+03, 0.10593300E+03, 0.39322700E+02, 0.10955700E+03, -.22637500E+02, -.11633800E+03, 0.12789000E+03, -.59437200E+02, 0.86243800E+02, -.60383900E+02, 0.10973400E+03, -.18038400E+02, 0.76102000E+01, 0.10768700E+02, 0.89933200E+01, 0.15562900E+02, 0.10407900E+02, -.42171200E+02, -.24213100E+02, -.14922100E+02, 0.10626700E+02, -.23229100E+02, -.16945000E+03, 0.82211100E+02, 0.43717700E+02, 0.84617100E+02, 0.27956900E+03, 0.22534000E+03, -.40015400E+03, -.10096500E+03, -.10149400E+03, 0.18775500E+03, -.84007300E+03, 0.45514400E+03, -.22404500E+03, -.13604700E+03, -.22762000E+03, -.33824000E+02, 0.12398200E+03, -.72353300E+02, 0.77365500E+02, -.78909500E+02, 0.10909100E+03, -.35908200E+03, -.14603800E+03, 0.67986100E+02, 0.18446800E+03, 0.72801400E+02, 0.30664800E+03, 0.11276800E+03, -.41154700E+03, -.66642700E+02, -.40653500E+02, 0.81517700E+02, -.94589300E+03, -.51540900E+02, 0.25293500E+02, 0.72798400E+02, 0.26680200E+02, 0.39308700E+02, -.70427800E+02, 0.47807700E+02, 0.24024600E+03, 0.75216400E+02, -.71600000E+02, -.38004900E+02, -.23977400E+00, 0.69298500E+00, 0.36390800E+01, 0.99548600E-01, 0.15454800E+01, -.87724900E+00, -.66267700E+01, 0.67892800E+01, -.38873700E+00, -.25082400E+01, -.25063100E+01, -.25679000E+03, 0.13730000E+03, 0.69744500E+02, 0.12825000E+03, 0.59752600E+02, 0.87694400E+02, -.17673400E+02, -.15913400E+03, -.32215500E+02, 0.88743800E+02, 0.16145100E+03, 0.99565800E+01, -.12224400E+02, -.57274000E+02, -.49324100E+01, 0.95245000E+01, 0.66511100E+02, -.68318100E+02, 0.67781900E+02, 0.32769100E+02, 0.44766800E+02, -.10816400E+03, 0.39750500E+03, -.19489700E+03, -.18166800E+03, -.19880300E+03, -.44943600E+02, -.88812600E+02, -.73743800E+01, 0.12393000E+02, -.15720000E+03, -.49331600E+02, -.55893200E+02, -.44834400E+01, -.27654200E+02, -.12854700E+02, 0.22686600E+01, 0.38729900E+01, 0.21631800E+01, -.97920300E+01, -.27117300E+02, 0.15196300E+01, 0.62771500E+01, 0.13895100E+01, -.52661700E+00, -.28121800E+00, -.48047000E+01, -.23469500E+01, -.67563000E+01, 0.20985300E+02, 0.33386100E+01, 0.27295100E+02, 0.47231200E+01, 0.24430900E+02, 0.12333200E+02, 0.12489500E+01, -.27143700E+01, -.99919700E+01, -.61648000E+01 },
        { -.19913700E+00, -.37826000E+00, -.10382000E+01, -.14320600E-01, 0.39275300E+00, -.12320300E+00, -.62770600E+00, 0.83045800E+00, 0.19587300E+00, 0.48097000E-01, -.38327200E-01, -.24326400E+01, -.17172400E+00, -.95051100E+00, 0.24192800E+00, 0.14649700E+00, 0.11136200E+00, 0.16718700E-01, 0.33115600E+00, 0.11832100E-01, -.18813400E+00, -.19630700E+01, -.17715300E+00, -.19629700E-01, 0.62009900E-01, 0.10609400E+00, -.83996400E-01, -.11253000E+01, -.33238900E+00, -.67484800E-02, -.74008300E+00, 0.54582700E-02, 0.18007200E+00, 0.21344300E-01, 0.22560200E-01, 0.21919600E-01, 0.73068500E-02, 0.18571000E+00, -.17165600E-01, 0.32547100E-02, -.14266400E+00, -.54324300E-01, -.17350300E-01, 0.78200900E-02, 0.81135700E+00, -.73412400E-01, -.34791300E+00, 0.34741800E-01, -.39345500E-01, -.27661000E+00, -.95828900E-01, -.74903800E-01, 0.33098400E+00, -.19189400E+01, 0.88219300E-01, -.60186800E+00, 0.12100400E+00, -.98571000E-01, -.96135000E-01, 0.20740700E+00, -.13864400E+00, 0.85573000E-01, 0.18321000E+00, -.27117900E+00, 0.48182100E-01, -.74004000E-01, -.48346000E-01, -.20207300E+00, 0.11207500E-01, -.27707700E-02, 0.66561400E+00, 0.31978500E+00, 0.21258200E-01, 0.67465100E-01, -.34894400E+00, 0.56877000E+00, 0.31577700E+00, -.50646100E+00, 0.29118900E+00, -.11493100E+00, -.19963600E-01, 0.10147600E+00, 0.38762400E-01, -.13286200E+00, -.26166100E+00, 0.22132100E+00, -.27200000E+00, 0.73470400E-02, 0.45348000E+00, -.70215900E-01, 0.82618200E+00, -.13119200E+00, -.61744300E+00, 0.48765000E+00, 0.20029200E+00, -.63364400E+00, 0.86901800E-01, -.20033800E+00, 0.67883400E+00, 0.46990400E-02, 0.57807800E+00, -.41486300E-01, 0.14210400E-01, -.29407200E+00, -.25750700E+00, -.41074200E+00, -.16382300E+00, 0.73609900E+00, -.11934100E+01, -.89282000E-01, -.58551300E+00, -.89084100E+00, -.16733400E+00, 0.79432700E-01, -.27907700E+00, 0.70537900E-01, 0.14714300E+00, 0.14246300E+01, -.48378000E+00, 0.13696300E+00, -.23671100E+00, 0.11634800E+01, -.17114400E+00, 0.26717400E+00, -.92411600E-01, 0.23383500E+00, -.77866900E-01, -.88465100E+00, 0.67320800E-02, -.67745200E-01, -.25803200E+00, 0.11374300E+00, -.63713200E-02, -.14844100E+00, 0.23545000E+00, 0.25253000E-02, 0.45679400E+00, 0.27844800E+00, -.34874600E-01, 0.76146500E-01, 0.13645000E-01, 0.18853000E+00, -.11830800E+00, 0.63272900E+00, 0.26501700E+00, -.90070300E-02, -.58614600E-01, -.88664600E-01, 0.20588300E+00, -.19686300E+00, -.39260100E+00, 0.23637300E+00, 0.55798600E-01, -.59697200E+00, 0.78019300E+00, -.23379100E+00, 0.11062000E+03, 0.67590000E+00, 0.40681600E+02, 0.14008100E+02, 0.28991900E+01, 0.75418600E+01, -.15347800E+02, 0.14541200E+02, -.63196400E+02, -.61357100E+02, 0.31389200E+02, -.11452100E+02, 0.30513100E+02, 0.54071400E+01, 0.59046800E+01, 0.77072300E+01, -.60657400E+02, -.68245000E+01, 0.19889200E+02, 0.21584600E+02, -.18725700E+01, 0.92109900E+00, 0.62344300E+01, 0.10058300E+01, 0.46936000E+01, -.56187500E+00, 0.26762100E+00, -.54142200E+01, -.58973200E+01, -.14022000E+01, -.55734600E+01, -.34566500E+02, 0.17513600E+02, -.78427300E+01, 0.17522800E+02, 0.11517000E+03, -.13438600E+02, 0.52292000E+02, 0.27858200E+02, -.61702000E+01, -.26406700E+02, -.16759500E+03, 0.52076000E+02, -.26086800E+02, -.24090500E+01, -.26061000E+02, 0.25429700E+02, 0.33524300E+02, -.25069100E+02, -.18507200E+01, -.24481900E+02, 0.28788400E+02, -.26653100E+02, 0.25763200E+02, -.13036900E+02, 0.58517300E+02, -.12413800E+02, 0.44840400E+02, -.68492700E+02, 0.67211500E+02, 0.42455900E+02, -.11246600E+02, -.83285900E+02, -.21923600E+03, -.30639000E+02, 0.16172500E+02, 0.18808800E+02, 0.14884200E+02, 0.36562500E+02, -.33074400E+02, 0.18660800E+02, 0.37630200E+02, 0.51255500E+02, -.40194800E+02, -.27890700E+02, 0.50021600E+00, -.20243100E+00, 0.18777300E+01, -.19849400E+00, 0.65013600E+00, -.27477100E+00, 0.19243300E+01, 0.25993100E+01, 0.17376100E+00, -.61472500E+00, -.12625800E+01, 0.14433200E+03, -.68761500E+02, -.84166700E+02, -.71970400E+02, 0.14490700E+02, 0.14248700E+02, -.75199100E+02, -.79753100E+02, -.62514500E+02, 0.18489200E+02, -.19016600E+02, 0.29173300E+02, -.14606900E+02, -.58525100E+02, -.14707000E+02, 0.32589300E+01, 0.24243200E+02, -.78973400E+01, -.13790300E+02, 0.22404800E+02, 0.10087000E+02, -.26743900E+02, 0.25529500E+02, -.12259100E+02, 0.53747800E+01, -.12619200E+02, 0.15147700E+02, -.40458300E+02, 0.45750800E+02, 0.13584200E+02, -.94918400E+01, -.27047700E+02, 0.14403900E+01, -.22397300E+01, -.13574900E+02, -.73459900E+00, -.29091000E+01, 0.17441000E+00, -.96615600E-01, 0.51460500E+01, -.11558700E+02, 0.73458300E+00, 0.78032100E+00, 0.21100800E+01, -.40673100E+00, 0.33140000E+01, 0.39460700E+00, 0.11463300E+01, -.77982400E+00, 0.16123600E+01, 0.11067400E+01, 0.91005200E+01, -.30876300E+01, 0.56895000E+01, 0.21440400E+01, 0.75173100E+00, 0.10052100E+02, -.71458000E+01, -.89814800E+01 },
        { -.80686700E+00, 0.17568100E+01, -.88866900E+01, 0.60460600E+00, 0.67423400E+01, 0.35710400E+00, 0.97457100E+01, 0.23822300E+01, -.45018400E+00, 0.63105400E+00, 0.51015800E+00, -.80771700E+01, 0.13726200E+01, -.13672000E+01, -.23685400E+00, -.63450700E+00, -.65903400E+01, 0.10291300E+01, -.68591900E+00, 0.18714500E+01, -.10754600E+01, -.47709200E+01, 0.49597100E+00, -.63815100E+00, -.10003000E+01, 0.53568500E+00, -.13874800E+01, 0.23984200E+00, -.37217000E+00, 0.90281100E+00, 0.68065400E+00, 0.10530500E+01, -.88284700E+00, -.10056700E+01, 0.42708800E+00, -.70066700E-01, -.10722400E+00, 0.44935100E+00, 0.13397900E+01, -.94509700E-01, 0.58280700E-01, -.17642600E+01, -.46909700E+01, -.19939700E+01, 0.23962900E+01, 0.13717900E+01, 0.33140400E+01, -.18609600E+00, 0.43345700E+00, -.78668000E+00, 0.62612000E+00, 0.14847200E+00, -.16184200E+01, -.69135000E-02, 0.72167100E-01, 0.15796500E+01, -.32338300E+00, -.10422300E+01, 0.71274000E+00, -.44928900E+00, 0.77826700E+00, -.19068600E+00, 0.24394300E+00, -.33668100E+00, -.17597300E+00, -.85640200E-01, -.71436400E+00, 0.46364700E-01, 0.15490800E+01, 0.54760100E-02, -.94097200E+00, 0.10981700E+01, -.37209100E+00, 0.58102300E-01, 0.46415400E+00, -.16811300E+00, 0.56888700E+00, -.12020700E+00, -.68474900E+00, 0.61736500E+00, -.31147400E-01, -.57230300E-01, -.14820200E+01, 0.29982400E+00, 0.20326200E+00, 0.45930100E+00, -.65741600E-01, -.53946100E+00, -.91539900E+00, 0.28809300E+00, -.13627400E+00, -.76783700E+00, -.69812900E+00, 0.78494000E+01, 0.17876400E+01, 0.27187600E+01, 0.28259000E+00, -.38775200E+00, 0.20702700E+01, 0.11905300E+01, -.53228200E+01, 0.70512500E+00, 0.72452400E+00, 0.92034400E+00, -.21562900E+00, 0.12440300E+01, 0.18068300E-01, 0.23601500E+01, -.52464700E+01, 0.10407100E+01, 0.11905700E+00, -.17624200E+01, 0.27250000E+00, -.17671900E+00, -.71596700E+00, 0.65018600E+00, 0.85487300E+00, 0.93954900E+00, -.11355600E+01, 0.64840000E+00, -.83930800E+00, 0.55641000E-02, 0.25887000E+00, 0.63818100E+00, -.41076000E-01, -.59041700E+00, -.15643800E+00, 0.63690000E+00, 0.12624500E+00, 0.28377600E+00, 0.19254200E+00, 0.29828400E+00, 0.23569700E+00, -.78687900E-01, 0.65176700E+00, -.42864000E+00, 0.11759400E+01, 0.48610500E+00, 0.15165200E+00, 0.16430500E+01, -.73880000E-01, -.19718500E+01, -.48460300E+00, -.83526500E+00, -.81776800E+00, 0.24088200E+00, -.23010600E+00, 0.76723100E+00, 0.13773900E+01, -.37548900E+00, -.99628300E+00, 0.79619900E+00, 0.13284200E+01, -.21840300E+01, -.86365500E+00, -.19677200E-01, -.12049100E+01, 0.10080800E+02, 0.25705600E+02, -.13710200E+02, -.48584500E+01, 0.71266400E+01, 0.39302600E+02, -.83514500E+01, 0.95985900E+02, 0.36910300E+03, -.18434600E+03, -.20121800E+03, -.18528000E+03, 0.13052600E+03, 0.11133800E+03, -.93494000E+02, 0.68302400E+02, -.52415000E+02, 0.12765800E+03, -.19000100E+03, -.25478400E+02, 0.12730300E+02, 0.11011200E+02, 0.13829400E+02, 0.12981500E+02, -.38773900E+01, 0.13503200E+02, -.13686200E+02, -.11914400E+02, -.30619200E+01, -.34511700E+01, 0.13832900E+04, -.69119800E+03, -.71004600E+03, -.68804800E+03, -.10604900E+03, -.45755100E+03, 0.14756000E+03, 0.51650300E+03, -.13792600E+03, -.47590600E+03, -.66382200E+03, 0.50864400E+02, -.25632000E+02, 0.32203900E+02, -.28317300E+02, 0.74484000E+02, 0.12851100E+03, -.11008600E+03, -.52847300E+01, -.13796400E+02, 0.12576000E+03, -.81918700E+02, 0.14994300E+04, -.74998600E+03, -.67601700E+03, -.74258900E+03, 0.72239200E+02, -.35134900E+03, 0.13891900E+03, 0.52327500E+03, -.19653200E+03, -.41992300E+03, -.80444400E+03, -.22590700E+03, 0.11492100E+03, 0.19000400E+01, 0.98260300E+02, 0.11623600E+03, 0.20798000E+02, -.30031200E+02, -.34023700E+02, 0.61938400E+02, 0.12572000E+02, 0.15649800E+03, 0.46766300E+00, -.10858700E+00, 0.26812200E+01, 0.52328000E+00, 0.17622800E+01, 0.69664300E+00, 0.18977300E+01, 0.15381700E+01, 0.17233800E+01, -.46028600E-01, 0.22659900E+01, -.11263100E+03, 0.61511900E+02, 0.31783800E+02, 0.55746800E+02, 0.12543000E+03, 0.10112200E+03, -.39110300E+02, -.61269900E+02, -.18041100E+02, 0.87941600E+02, 0.14962600E+02, 0.85284000E+02, -.42135400E+02, 0.36588500E+02, -.44393100E+02, -.81467900E+01, 0.52057400E+02, 0.82124600E+02, -.16143300E+03, -.28196900E+03, 0.39038600E+02, -.13554700E+03, 0.34261200E+03, -.17022700E+03, -.18091800E+03, -.16923500E+03, 0.16777100E+02, -.55461400E+02, -.79686900E+02, 0.36080100E+03, 0.26089800E+03, -.51719800E+02, -.10172600E+03, -.97334700E+00, -.15328600E+02, -.36975700E+02, -.13828200E+02, -.18565600E+02, 0.24072600E+01, 0.19046600E+01, -.62259600E+01, 0.55767200E+00, 0.91017500E+00, 0.13166300E+01, 0.71087500E+01, 0.24545300E+01, 0.13866400E+02, 0.19518700E+02, 0.43688000E+01, 0.20890800E+02, -.40540000E+00, -.10530400E+02, 0.66554100E+01, 0.40929700E+01, 0.49112100E+01, 0.63924000E+00, -.85896400E+01, 0.43789700E+02, 0.39567700E+02 },
        { -.67735200E+00, 0.24216300E+01, -.82410700E+00, -.78236100E+00, -.43019200E+00, -.65558600E+00, -.24219600E+01, 0.34025500E+00, -.12181100E+01, -.11947000E+01, 0.61212200E+00, -.10952200E+01, 0.15486500E+01, 0.98338800E+00, 0.26911700E+00, -.31463400E+00, -.37641200E+00, 0.90699600E-01, 0.10352600E+01, 0.98348600E+00, -.65790200E+00, 0.40023800E+01, 0.12518400E+01, -.13705400E+01, -.93188500E+00, -.52351800E+00, -.99792900E+00, 0.41819400E+00, -.10296000E+00, 0.76473600E+00, -.20909500E+00, 0.29631000E+00, -.10835000E+01, 0.28879900E+00, 0.80167300E-01, 0.17437800E+00, -.80908000E-01, 0.49196500E+00, 0.61014700E+00, 0.46026900E+00, 0.32951200E+00, -.92726300E+00, -.26523800E+01, -.27390700E+00, 0.98641700E+00, 0.75136300E+00, 0.87082500E+00, -.10277400E+00, 0.88255500E-01, 0.56381800E+00, 0.66461500E+00, -.57642500E+00, -.84218000E+00, 0.33946600E+01, 0.28888700E+00, 0.21786500E+01, -.19975900E+00, -.46496900E-01, 0.14213600E+00, -.37167800E+00, 0.53385400E+00, -.47339300E+00, -.64914600E-01, -.10318800E+00, -.12199400E+00, 0.60241800E+00, 0.10189000E+00, -.50696600E+00, 0.30096100E+00, 0.19863100E-03, -.61264700E+00, 0.20825000E+00, -.60121000E-01, 0.56692400E-01, 0.37430400E+00, -.10816200E+00, 0.46281000E-01, 0.18445000E+00, -.79510500E-01, 0.24098700E+00, -.24516700E-03, -.12663300E+00, 0.43417600E-01, 0.58350600E-01, -.82061500E-01, 0.29698400E+00, 0.95131600E+00, -.13944000E+00, 0.16007800E+01, -.29185500E+00, 0.44488400E+00, -.18812100E-01, -.55027500E-01, -.42017300E+00, 0.13509700E+01, 0.19748300E+01, 0.44232000E+00, -.74372500E+00, 0.11759800E+01, 0.70386800E+00, -.41620600E+01, -.40076100E+00, 0.38131500E-01, -.10519000E+00, 0.37366300E+00, -.88677400E+00, 0.80439400E-01, -.40580700E+00, 0.21420900E+01, 0.17778600E-01, 0.12717500E+01, 0.24495300E+00, 0.50323700E+00, 0.86818900E-01, 0.50141100E+00, 0.39878800E+00, -.36971200E+00, -.38911400E+01, -.13345200E+01, -.41186700E+00, 0.35146400E+00, 0.20138400E+00, 0.43482400E+00, 0.97626600E+00, -.77506900E-01, 0.22040700E-01, 0.16405500E+01, 0.16136100E+01, 0.13953200E+00, 0.45489100E+00, 0.17542900E+00, -.14202500E+01, 0.29722000E+00, -.11550000E+00, -.52626300E+00, 0.29008500E-01, -.11058800E+01, -.34216400E+00, 0.37472600E+00, 0.39738400E-01, -.17611000E+00, 0.21117400E+01, 0.71352600E-02, -.10555100E+01, -.87081500E+00, 0.11957000E+00, -.20902000E+00, -.60979700E+00, 0.43049900E+00, 0.40860100E+00, 0.73468800E-01, 0.24824800E+00, -.15216300E+01, -.10409500E+00, 0.18475500E+01, 0.10649300E+00, -.48530400E+00, 0.18633300E-01, 0.23146000E+03, 0.13602300E+03, -.21829100E+02, -.21901600E+02, -.10602400E+02, 0.12129400E+03, 0.14923400E+03, -.13612500E+03, 0.74549600E+02, 0.13781500E+02, 0.68092600E+02, 0.19757100E+02, 0.55153100E+02, -.77913000E+02, -.27942100E+03, -.57696800E+02, 0.77627200E+02, 0.42360500E+02, -.36737500E+02, 0.18528600E+02, 0.18703000E+02, 0.18361300E+02, 0.31024200E+02, 0.89920900E+01, 0.68889300E+00, -.24906500E+02, -.22025100E+02, -.30840700E+00, 0.76215300E+01, 0.17764100E+04, -.88724100E+03, -.10435700E+04, -.88820100E+03, 0.49025700E+02, -.50090400E+03, -.36941600E+02, 0.68888600E+03, -.54824300E+03, -.55422600E+03, -.79986900E+03, 0.16700200E+03, -.83546600E+02, -.33305700E+02, -.83502400E+02, 0.59595600E+02, 0.21043500E+03, -.13318500E+03, 0.12210100E+02, -.19887400E+03, 0.19159100E+03, -.24895500E+02, 0.17325900E+04, -.86555600E+03, -.59861100E+03, -.86628000E+03, -.88193500E+02, -.30431500E+03, -.39619100E+02, 0.68304000E+03, -.69339400E+03, -.40581800E+03, -.89013800E+03, -.23441300E+02, 0.13024200E+02, 0.12996900E+02, 0.11589100E+02, -.23181400E+02, -.11411200E+03, 0.14141300E+03, 0.23875500E+03, 0.10336600E+03, -.14563900E+03, 0.75925100E+02, 0.14277800E+01, -.99619300E+00, 0.22576000E+01, -.71788900E+00, 0.34262400E+01, 0.30122700E+00, 0.63238600E+01, 0.26442200E+01, 0.34335300E+01, -.17499600E+01, 0.21480100E+01, 0.32602300E+03, -.16149400E+03, -.15604200E+03, -.16318100E+03, 0.57413700E+02, 0.71575600E+02, -.23723500E+03, -.30695400E+03, -.22903200E+03, 0.70161700E+02, -.35467900E+02, -.17442400E+03, 0.93653300E+02, 0.18489000E+03, 0.87218100E+02, -.48088800E+02, 0.38822500E+02, -.21083800E+03, -.39939500E+03, -.81448700E+02, 0.10343600E+03, 0.14794400E+01, 0.55050800E+03, -.27591900E+03, -.29316600E+03, -.27526700E+03, 0.14316900E+02, -.17599300E+03, 0.27278400E+03, 0.42582300E+03, 0.13375300E+03, -.24250600E+03, -.24126700E+03, -.27098800E+01, 0.32469800E+01, 0.27472000E+01, -.19815000E+02, 0.35395900E+01, -.69032200E+01, 0.12034200E+02, 0.15570600E+02, 0.47300800E+00, 0.42067800E+01, -.14623800E+00, 0.13814700E+02, 0.15745200E+02, -.25140900E+01, 0.27094800E+01, 0.23034700E+01, 0.11956400E+02, 0.52435400E+01, 0.82003400E+02, -.17911200E+02, -.74972600E+02, 0.48779400E+01, 0.62783100E+00, 0.25825500E+02, 0.60387200E+01, -.16440900E+02 },
        { -.26948100E+00, -.63417100E+00, -.35205200E+01, 0.29232300E+00, 0.24955700E+01, 0.35294500E-01, 0.23148200E+01, -.74932000E+00, 0.21134700E+00, 0.80471700E+00, -.16471000E+00, -.36130400E+01, 0.88377600E-01, -.10096600E+01, 0.33589600E+00, -.17654800E+00, -.21741100E+01, 0.30003400E+00, 0.71393500E+00, -.18960500E+00, 0.37910200E-01, -.65182000E+00, 0.57876500E-01, -.66168500E+00, -.76522800E+00, -.15814700E+00, -.89933000E+00, -.99232800E+00, 0.29892900E+00, 0.95598700E+00, -.38537900E+00, 0.19157800E+00, -.49077500E+00, -.59479600E-01, -.11103400E+00, 0.19845200E+00, -.50374300E-01, 0.20738100E+00, 0.44320400E-01, 0.51732300E+00, -.15930300E+00, -.23136500E+01, -.28942500E+01, -.11440200E+01, 0.13858500E+01, 0.40540800E+00, 0.47449000E+00, -.65001800E-02, 0.11310600E+00, -.59186100E+00, -.37517000E+00, 0.43781600E+00, 0.39467800E+00, 0.15162300E+00, -.31699800E+00, 0.10033200E+01, 0.96711000E-01, -.33514000E-01, -.17336600E+00, -.22095800E+00, 0.74542400E+00, -.23506500E+00, -.13492400E+00, -.42094600E+00, -.10167800E+00, -.28616600E+00, -.33726300E+00, -.21887500E+00, 0.80270300E+00, 0.29623400E-02, 0.74401300E+00, 0.35371300E+00, -.52866200E-01, 0.18193800E+00, 0.65841900E+00, 0.38871500E+00, 0.52063200E-01, 0.44024300E+00, -.17898700E+00, 0.26619500E+00, -.31741500E-02, -.37637800E-01, -.15366200E+01, 0.28761500E+00, -.13672200E-01, 0.21074700E+00, 0.36004800E+00, -.39949800E+00, -.50053400E+00, -.13461700E-01, 0.18775700E+00, -.14037000E+00, -.26128500E+00, 0.19165900E+01, 0.94512100E+00, -.29770600E-02, 0.85675300E+00, -.31036400E+00, 0.19761800E+01, 0.81875100E+00, -.11859900E+01, 0.51985700E+00, -.24591300E-01, 0.41075600E+00, -.29810500E+00, 0.62161100E+00, 0.13236600E+00, 0.14573000E+01, -.15340600E+01, -.72256600E+00, 0.47643200E+00, -.70273700E+00, -.82328800E-01, 0.10527500E+00, -.10230300E+00, 0.15201800E+00, 0.14056100E+00, 0.10026100E+01, -.26258400E+00, 0.16623500E+00, 0.14653500E+00, 0.73487200E+00, -.57854500E-01, -.96892800E-01, -.13692500E+00, 0.53845000E+00, 0.63503600E+00, -.19830400E+00, -.57620000E-01, 0.45304900E+00, -.24589500E-01, -.15455900E+01, 0.17632400E+00, 0.10550500E+00, 0.67464600E-01, 0.35100200E-01, -.47084300E+00, -.49206100E+00, -.53727500E+00, 0.47911500E+00, -.87434800E-01, -.17057500E+01, -.70621700E-01, 0.38900900E-01, 0.82074600E+00, 0.29803300E-01, 0.46562300E-01, -.48521700E+00, 0.22285000E+00, 0.86564200E-02, -.64647600E-01, 0.16142700E+00, 0.34849700E+00, -.13286100E+01, 0.20567700E+00, 0.15208600E+00, -.98163500E+00, 0.12567800E+00, 0.17747000E+00, -.80852300E+02, 0.89033100E+02, 0.87880400E+02, 0.66587600E+02, -.85219000E+02, -.60695200E+02, -.39366400E+02, 0.19633200E+02, -.19618600E+02, 0.19435600E+02, -.39070700E+02, -.66023200E+02, 0.21355300E+02, 0.39090800E+01, 0.75522700E+02, -.59468500E+02, 0.38626000E+02, 0.82709900E+01, -.39310100E+01, 0.12086900E+02, -.41375200E+01, -.81541600E+01, -.10674300E+02, 0.19720400E+02, 0.12049300E+02, 0.16293300E+02, -.63909900E+01, 0.99099900E+01, -.99850200E+03, 0.50009600E+03, 0.61412600E+03, 0.49924300E+03, 0.24182300E+03, 0.15351600E+03, 0.31501100E+03, -.16258700E+03, 0.38012700E+03, 0.20688300E+03, 0.32643900E+03, 0.16423400E+02, -.85902400E+01, -.43693700E+02, -.79000800E+01, 0.11936000E+02, -.26223700E+02, 0.69692200E+02, 0.63006500E+02, 0.46406400E+02, -.32511800E+02, -.12054900E+02, -.10532300E+04, 0.52734800E+03, 0.38172900E+03, 0.52658400E+03, 0.18806800E+03, 0.63593400E+02, 0.36134400E+03, -.15311600E+03, 0.51630900E+03, 0.11847200E+03, 0.45193400E+03, -.86541800E+01, 0.57749400E+01, 0.16204500E+02, 0.54380500E+01, 0.23565000E+02, 0.20894400E+02, 0.46131700E+02, -.10566300E+02, -.50639700E+02, 0.35300600E+02, 0.41933200E+01, -.21522600E+01, 0.11166500E+01, 0.84363400E+00, 0.10803300E+01, -.18358300E+00, -.16607800E+01, 0.45527000E+01, 0.10279000E+01, 0.93967400E+00, -.91156000E+00, -.98266900E+00, 0.11998800E+03, -.56794500E+02, -.83835100E+02, -.59494300E+02, -.30889400E+02, -.54704700E+02, -.12293700E+02, 0.36332600E+02, 0.53096900E+02, -.48139300E+02, -.50353000E+01, 0.45666500E+03, -.22825600E+03, -.31854100E+03, -.22834300E+03, -.18424400E+03, -.98212900E+02, 0.23855400E+02, 0.16011200E+03, -.64624300E+02, -.10194200E+03, -.58231800E+02, -.61113000E+03, 0.30637100E+03, 0.40567100E+03, 0.30558800E+03, 0.19547000E+03, 0.10172200E+03, 0.33433400E+02, -.21822200E+03, 0.59080700E+02, 0.12758100E+03, 0.12257500E+03, 0.41833400E+00, -.94758300E+01, -.64773600E+01, 0.97220900E+00, -.40310700E+01, 0.45513500E+01, 0.84312600E+01, -.12409300E+02, -.88204300E-01, -.40383200E+01, 0.44517300E+01, -.48557800E+01, -.23280300E+01, 0.20516000E+01, 0.48416300E+01, 0.19867400E+01, 0.32639200E+00, -.40481600E+01, -.83013100E+02, -.85573400E+01, 0.76916200E+02, 0.37878600E+01, 0.39602500E+00, 0.21443600E+01, -.57897400E+00, 0.44470300E+01 },
        { 0.29938600E+00, -.11674300E+01, 0.30932200E+01, 0.43797800E+00, -.11126400E+01, -.35624000E+00, -.10524300E+01, 0.15361900E+01, 0.43965900E+00, -.36641900E+00, -.33916200E+00, 0.48501500E+00, -.20238600E+00, -.46317800E-01, 0.13140800E+00, 0.11534900E+00, 0.57426400E+00, -.10126900E+00, 0.31050100E+00, -.25355300E+00, 0.74929700E+00, 0.53529400E+00, 0.12809500E-01, 0.24480300E+00, 0.29324100E+00, -.50338100E-01, 0.37606600E+00, 0.40991800E+00, -.45421700E-01, -.37136800E+00, 0.63943600E-02, 0.80958700E-01, -.24587900E+00, -.20476200E+00, -.40311700E+00, 0.10295200E+00, -.31800500E-02, -.37973200E+00, -.73319800E+00, 0.42256400E+00, 0.57546600E+00, 0.20945700E+01, 0.16336800E+00, -.32057200E+00, -.15163800E+00, -.39362100E+00, -.79132000E+00, 0.54243100E-01, 0.22385700E-01, -.62385800E+00, 0.40363700E+00, -.12708000E+01, -.33205700E+00, -.17146600E+01, 0.10470400E+01, -.73244400E+00, 0.19600400E+00, -.11989000E-01, -.41145400E-01, 0.74892300E-01, -.27738400E+00, 0.16840500E+00, 0.22084500E+00, -.12506900E-01, 0.84514400E-01, -.10653300E+00, -.14467800E+00, -.14696800E+01, 0.56857200E+00, 0.22166300E-02, 0.54860300E+00, 0.94884200E+00, -.65358400E-01, 0.33651500E-01, -.11216200E+00, -.20814000E-01, 0.37751600E+00, 0.36259800E+00, -.63512200E-01, 0.33789200E-02, -.28766300E-01, 0.19974700E-01, 0.10237800E+00, -.38609500E+00, 0.12451400E+00, -.26911000E+00, 0.11604600E+00, 0.53648000E+00, 0.15218600E+00, -.10217900E+00, -.24475200E+00, -.31824900E+00, -.65407200E-01, -.48806400E+00, -.22991300E+00, -.36027500E+00, 0.21906900E+00, -.10163700E+00, 0.36998400E-01, 0.27412300E+00, 0.52704000E+00, 0.20536800E+00, 0.25470300E-01, 0.10772400E+00, -.57796700E-01, 0.17151300E-01, -.30090200E+00, 0.12886000E+00, 0.22663900E+00, 0.14614700E+01, -.10191500E+01, -.60103100E+00, 0.77025300E-01, -.11312300E+00, -.14211700E+00, -.10171200E+00, -.13768400E+00, 0.71311900E+00, 0.53881300E+00, 0.10473500E+00, 0.60631600E+00, -.14531800E+01, 0.27580000E-01, -.55460900E+00, 0.75870600E-02, 0.18779500E+00, 0.37075600E-01, -.79908300E+00, -.97870900E-01, -.23116700E+00, -.40400400E+00, 0.21199200E+00, -.10576400E+00, -.72668400E-01, 0.19203400E+00, -.25545300E-01, 0.31338800E+00, 0.40353600E+00, 0.23745200E-01, 0.65797900E+00, -.19704200E+00, -.15068900E+01, -.41040000E+00, -.54735800E+00, -.14625400E+00, -.11224700E+00, 0.19798000E+00, 0.21857600E+00, 0.60219800E+00, -.27472100E+00, -.47279300E+00, 0.44874300E+00, 0.35804200E+00, 0.84804800E+00, -.95507900E+00, -.31371500E+00, -.95342500E+00, -.51831200E-03, 0.42417500E+00, -.10389100E+00, -.72818900E+02, -.16330600E+01, -.47471900E+02, -.64598500E+01, -.47850800E+02, -.29384400E+03, 0.14501600E+03, 0.69594600E+02, 0.14692600E+03, -.11870700E+03, -.14463900E+03, 0.12936100E+03, -.55380700E+02, 0.62392700E+02, -.10192300E+03, 0.12201200E+03, 0.50156500E+01, -.24441600E+01, 0.12112600E+02, -.25079200E+01, 0.21381100E+01, -.16518800E+01, -.62690900E+01, 0.12038200E+02, 0.19684800E+02, -.31216100E+01, -.87139300E+01, -.13544900E+04, 0.67734200E+03, 0.62166600E+03, 0.67724500E+03, 0.29101000E+03, 0.40566300E+03, -.16912700E+03, -.40432000E+03, 0.28251000E+03, 0.39720700E+03, 0.50729900E+03, 0.82823700E+02, -.41207600E+02, -.88314000E+02, -.41433400E+02, -.18893600E+02, 0.71593400E+02, -.13136500E+02, 0.50029300E+02, 0.27315700E+02, 0.52267800E+02, 0.34664700E+01, -.13329700E+04, 0.66681600E+03, 0.68635500E+03, 0.66647900E+03, 0.25274200E+03, 0.25552300E+03, -.12682100E+03, -.36514000E+03, 0.39378700E+03, 0.28258800E+03, 0.50640000E+03, 0.10647400E+03, -.53892100E+02, 0.38496800E+02, -.53415800E+02, 0.10773500E+02, -.35048700E+02, -.89344700E+01, 0.10043700E+03, 0.52672600E+00, -.25757400E+02, -.90562700E+02, -.50099900E+00, 0.21938600E+00, -.21129200E+00, 0.25030400E+00, -.10884400E+01, -.17997700E+01, -.42073600E+01, 0.81339500E+00, -.10112100E+01, -.84974400E+00, -.63474000E+00, -.24461400E+03, 0.12426500E+03, 0.46818900E+02, 0.12226600E+03, -.46448300E+02, -.30458400E+02, 0.11572100E+03, 0.44533600E+02, 0.83812400E+02, -.23201800E+02, 0.15505900E+02, 0.32234800E+03, -.16144600E+03, -.22429600E+03, -.16117500E+03, -.16421600E+02, -.25640200E+02, 0.29198700E+01, 0.19967000E+03, 0.96877400E+02, -.64391700E+02, -.13136600E+03, -.41327800E+03, 0.20669200E+03, 0.27198300E+03, 0.20664100E+03, 0.47316100E+02, 0.53666600E+02, 0.58479800E+02, -.16959400E+03, -.10116300E+03, 0.80003700E+02, 0.16673500E+03, 0.74182700E+00, -.28949600E+02, 0.13900100E+02, 0.68259300E+01, 0.29805900E+01, 0.38455900E+01, -.19463600E+02, -.32565900E+02, 0.24303900E+00, -.34931300E+00, 0.29293500E+01, 0.43661600E+00, 0.35351800E+01, -.40931300E+01, -.24229700E+01, -.17710800E+01, -.20293500E+02, -.30520200E+01, -.64458900E+02, 0.28872400E+01, 0.88071900E+02, 0.14305700E+02, 0.85781300E-01, -.10050900E+02, -.16354800E+02, -.13779100E+02 },
        { -.92449700E-01, 0.32391000E+00, -.78688300E+00, -.17206300E+00, 0.28993300E+00, 0.75700700E-01, 0.88295400E+00, 0.58898600E+00, 0.18711100E+00, 0.17810200E-01, -.69404400E-03, -.50837700E+00, 0.59473400E-01, -.24308100E+00, -.58680700E-02, -.16777100E-01, -.36161600E+00, 0.78527000E-01, -.22283000E+00, 0.67517000E-01, -.84848300E-01, -.74695300E+00, -.75007600E-02, -.17502200E+00, -.11986000E+00, -.61592100E-01, -.24220400E+00, 0.11034600E+00, -.78878200E-01, 0.47222200E-01, 0.14592700E+00, 0.11161600E+00, 0.23019500E-01, -.10615000E+00, -.11654600E+00, -.56796700E-02, -.21767000E-02, -.98366400E-01, -.46815300E-01, 0.11600700E-01, -.54902900E-01, 0.12850400E+00, 0.22604700E+00, 0.42235000E-02, -.46936100E-01, -.24891900E-01, -.23121800E+00, -.84817000E-02, 0.48290800E-01, -.91732200E-01, 0.20429600E-01, -.11905600E+00, -.58652100E-01, -.24743800E+00, 0.44713600E-01, -.18603300E+00, -.15666100E-01, -.11476600E+00, 0.64441100E-01, 0.33687500E-01, -.34670400E-01, 0.53804900E-01, -.18753400E-02, -.43551500E-01, 0.72403800E-02, 0.38571400E-01, 0.15776800E-01, 0.10362600E+00, -.45289200E-01, 0.38345400E-03, -.16164600E+00, 0.52554700E-01, -.42141900E-02, -.91447500E-02, -.45866800E-02, 0.34221000E-01, -.63677100E-01, 0.28463800E-01, -.38820300E-01, 0.57975200E-01, 0.51282500E-02, -.10174600E-02, -.65122600E-01, 0.36329100E-01, -.15391100E-01, 0.25892800E-01, 0.27176500E-01, -.37915300E-01, 0.21715000E+00, 0.98686700E-03, -.13303300E+00, 0.37979400E-01, 0.81797400E-01, -.30948600E+00, 0.27561900E-02, -.11306500E+00, 0.39443800E-01, 0.23362000E-01, -.91046400E-01, -.86175300E-01, 0.46513800E+00, -.84005200E-01, -.41734800E-02, -.13453600E-01, -.40965700E-01, -.26212800E-01, -.39118000E-01, -.22652800E+00, 0.18509100E+00, -.52157300E-02, 0.18300600E-02, 0.40186700E-01, -.47661500E-01, 0.47005400E-03, 0.12870400E-01, -.17399900E-01, 0.40337600E-01, 0.36299900E-01, 0.17205500E-01, -.28641700E-02, 0.28941600E-01, -.12535800E+00, -.48960100E-01, 0.46357300E-01, 0.24695100E-01, 0.23756600E+00, 0.13098500E+00, -.27173100E+00, -.15492100E-01, -.52387300E-01, -.13030500E+00, 0.16773300E+00, -.38158800E-01, 0.46699900E-01, 0.12726400E+00, -.47718100E-02, 0.19949900E-01, 0.60147400E-02, -.55407400E-01, -.13071200E+00, 0.79270100E-01, -.27483800E+00, 0.32487900E-01, 0.50754500E-01, 0.20895500E+00, 0.36882500E-01, 0.42727500E-01, -.36904000E+00, -.33791200E-01, -.97283200E-01, -.89244600E-01, -.97105000E-02, -.17571100E+00, -.14662000E+00, 0.94261300E-01, -.21716200E-01, 0.83274600E-01, 0.53453700E-02, -.75972600E-01, 0.42293300E-01, -.30962700E-02, 0.20593400E+02, -.95632200E+00, -.36707000E+01, -.18337900E+02, -.65363700E+02, 0.32969800E+02, 0.36203700E+02, 0.32686300E+02, -.22939600E+02, -.23663800E+02, 0.22062900E+02, -.44711100E+01, 0.12300900E+02, -.17179200E+02, 0.24435500E+02, -.22781500E+01, 0.11265200E+01, -.69732900E+00, 0.11377100E+01, 0.40167800E+00, 0.40987100E+00, -.18830400E+01, 0.78968900E+00, 0.68114900E+01, 0.17619700E+00, 0.29210100E+01, -.31448300E+03, 0.15733000E+03, 0.13643700E+03, 0.15724300E+03, 0.28381800E+02, 0.51990800E+02, -.56211500E+01, -.58325300E+02, 0.10281300E+03, 0.55456300E+02, 0.72158600E+02, 0.15992600E+01, -.73699400E+00, 0.31259000E+00, -.79103000E+00, -.89978700E+01, 0.11328100E+01, 0.17023300E+02, 0.17000000E+02, 0.23454000E+01, 0.13579300E+01, -.12595400E+02, -.28701500E+03, 0.14351000E+03, 0.16057900E+03, 0.14351200E+03, 0.32015400E+02, 0.55384500E+02, -.12953500E+02, -.58905400E+02, 0.97205400E+02, 0.60328500E+02, 0.69150800E+02, 0.21248600E+02, -.10583600E+02, 0.29104200E+01, -.10693300E+02, -.11838100E+02, -.68902000E+01, 0.10813200E+02, 0.19056300E+02, 0.10848400E+02, -.73063400E+01, -.90412300E+01, -.42261500E-01, 0.33093900E-01, -.68085200E-01, 0.20446600E-01, -.14533900E+00, -.79433800E-01, -.13168800E+01, -.76232300E+00, -.26876500E+00, -.36165600E-01, -.21676300E+00, 0.10389200E+02, -.47081500E+01, -.20811000E+01, -.52057300E+01, -.11188400E+02, -.97829900E+01, -.89825000E+00, -.69506900E+00, -.29836800E+01, -.70207300E+01, -.53957000E+01, 0.44033400E+02, -.22003100E+02, -.17474900E+02, -.22015100E+02, -.14294700E+02, -.89167100E+01, -.12609400E+02, 0.11896400E+02, 0.13844400E+02, 0.47732000E+00, -.40343500E+01, -.13543800E+03, 0.67865600E+02, 0.48405200E+02, 0.67715900E+02, 0.64824400E+01, 0.17744100E+02, 0.15487100E+02, -.40405900E+02, -.16318300E+01, 0.11776100E+02, 0.45992800E+02, -.16649900E+00, 0.40599300E+01, 0.47749900E+01, 0.22217900E+01, 0.12843700E+01, -.31518900E+00, 0.24649700E+00, 0.25587300E+01, -.14850200E+00, 0.55444300E+00, 0.13221000E+00, -.15730600E+01, -.21334500E+01, -.11311100E+01, -.10541500E+01, -.14264900E+00, -.37677300E+01, -.10701400E+01, -.20377100E+02, -.14841700E+01, 0.16733200E+02, 0.13025400E+00, -.22273000E+00, 0.14923000E+01, -.62791700E+01, -.33844400E+01 },
        { 0.43205400E+00, 0.14197000E+01, 0.34311200E+01, -.40377800E+00, -.28661400E+01, -.68810100E+00, -.43385200E+01, 0.21340100E+01, -.48707100E+00, -.84044300E+00, 0.71761600E+00, 0.32125000E+01, -.10451800E+00, 0.31229700E+00, 0.32046900E+01, 0.14531500E+01, 0.32536400E+01, -.56989400E+00, 0.10437600E+01, 0.91992200E+00, -.21543600E+00, 0.41768400E+01, 0.40740900E+00, 0.24920800E+00, 0.12564500E+00, 0.53803000E+00, 0.44094500E+00, -.12993600E+00, -.38330400E+00, -.31557400E+00, -.10835600E+01, -.11875700E+00, 0.28978100E+00, 0.45154400E+00, -.61472500E+00, -.56996800E+00, 0.17652600E-01, -.52979100E+00, 0.47859600E+00, -.11866100E+00, 0.13063400E+00, -.43750300E+00, -.40067400E+01, -.13198500E+01, 0.18313500E+01, 0.51384000E+00, -.23031600E+00, 0.13171200E-01, 0.79447600E-01, -.11206500E+01, -.40296800E+00, -.60683800E+00, -.66017400E+00, 0.48832100E+00, 0.55926700E+00, -.50642500E+00, -.59715300E+00, 0.13712300E+01, -.91609000E-02, 0.93957400E+00, -.95466800E+00, 0.40639000E+00, -.69076800E+00, 0.69054800E+00, 0.10989300E+00, 0.19645400E+00, -.36685100E+00, -.13066700E+01, -.88110300E-01, -.85242200E-04, 0.14976200E+01, 0.79026000E+00, -.15057000E+00, 0.84281900E-01, 0.89692000E+00, 0.40150500E+00, 0.67851000E-01, -.63619600E+00, 0.65947200E-01, 0.20516400E-02, -.18912000E-02, -.20081600E+00, 0.10196300E+00, 0.14504800E+00, 0.14647700E+00, 0.55910900E+00, -.21433200E+00, -.80901000E+00, -.52839700E+00, 0.63783100E-01, 0.17409900E+01, 0.22818700E+00, -.86653500E+00, -.31174900E+01, 0.13774200E+00, 0.12184000E+01, 0.97295000E+00, 0.12942600E+00, 0.11420700E+01, -.33475400E+00, 0.66061100E+01, -.14410800E+01, -.73232400E-01, 0.14348900E+01, 0.59037100E+00, 0.54908000E+00, -.56829700E+00, 0.14989700E+01, -.43882900E+00, -.41594100E+00, -.56621900E+00, 0.79473800E+00, -.96164700E-01, 0.56441400E-01, -.34628300E+00, -.41556000E+00, -.36583000E-01, -.12862100E+01, -.20633400E+00, -.11646700E+00, 0.12806600E+01, 0.58789200E+00, -.17659500E+00, -.11393800E+00, -.16616000E+00, -.13234600E+01, -.34697400E+01, 0.82842500E+00, -.38934200E-01, 0.70125700E-03, -.20308600E+00, 0.79815800E-01, 0.71475100E-01, -.15787200E-01, 0.53055800E+00, 0.30967500E-01, 0.11161200E+01, 0.28426400E+00, -.14908500E-01, 0.11620200E+01, -.39743200E+00, -.74793200E+00, -.15715700E+00, -.61617400E+00, -.31036500E+00, -.21517700E+00, -.14000000E+00, -.83562500E+00, 0.34703200E-01, 0.47193900E+00, -.11619700E+00, -.14662900E+00, 0.33979000E+00, -.10525400E+00, 0.63202500E+00, -.53661400E+00, -.27033100E+00, 0.13818200E+00, 0.21580500E+00, 0.78159600E+00, 0.12159400E+01, 0.24828200E+01, 0.13590300E+03, 0.10447900E+02, 0.15912500E+03, 0.30065500E+03, -.14628500E+03, -.19945200E+03, -.15042300E+03, 0.19882700E+03, 0.27095400E+03, -.13619700E+03, 0.19994200E+02, -.88435400E+02, 0.17589300E+03, -.10643800E+03, 0.23062700E+02, -.11691500E+02, -.15694900E+02, -.11529400E+02, 0.11104600E+02, 0.13974600E+02, -.92120700E+01, -.86919400E+01, -.73489900E+02, 0.14057000E+02, -.43073500E+02, 0.27428700E+04, -.13724300E+04, -.12992300E+04, -.13714400E+04, -.47412600E+03, -.64061000E+03, 0.78426400E+02, 0.65334900E+03, -.94405000E+03, -.64950100E+03, -.12598200E+04, 0.74094400E+02, -.37541900E+02, 0.15060600E+02, -.36912300E+02, -.59250400E+01, -.14247000E+03, -.54720500E+02, -.83812400E+02, -.49214800E+02, -.13485400E+03, 0.26000200E+02, 0.26506800E+04, -.13266200E+04, -.13163900E+04, -.13253500E+04, -.52924800E+03, -.33588000E+03, -.39556200E+02, 0.59512900E+03, -.11242700E+04, -.42996900E+03, -.13438900E+04, -.10597000E+03, 0.53812000E+02, -.65215100E+02, 0.53709200E+02, -.16925400E+02, -.19927100E+01, -.25610000E+02, -.33964700E+02, 0.23318000E+02, -.22776000E+02, 0.32153700E+02, 0.16383900E+01, -.89932100E+00, 0.61720400E+00, -.81618600E+00, 0.14309000E+01, 0.17630300E+01, -.21303500E+01, 0.16518600E+01, 0.56943000E+00, 0.35410500E-01, 0.10912500E+01, 0.18411900E+03, -.95677700E+02, -.78509200E+02, -.91756000E+02, 0.61719900E+02, 0.61972600E+02, -.13008500E+03, -.11260600E+03, -.12220800E+03, 0.48271300E+02, 0.13335700E+03, -.91509900E+03, 0.45964100E+03, 0.51432500E+03, 0.45754500E+03, 0.21065800E+03, 0.17553100E+03, -.57270100E+02, -.42192500E+03, -.89264200E+02, 0.19115400E+03, 0.13915000E+03, 0.14453800E+04, -.72379000E+03, -.64196300E+03, -.72267900E+03, -.20356400E+03, -.23164400E+03, -.50672100E+02, 0.53846200E+03, -.53079400E+02, -.23796800E+03, -.37995800E+03, -.32240200E+01, 0.10467400E+02, -.22288700E+02, -.17847500E+02, 0.15518900E+02, -.12189900E+02, 0.22949800E+02, 0.21153000E+02, 0.45776900E+00, -.19610400E+01, -.58134800E+01, 0.21231200E+01, -.38529600E+01, -.38339500E+01, -.15155300E+02, 0.10843400E+01, 0.35981300E+02, 0.20936500E+02, 0.22844500E+03, -.82173200E+01, -.22826800E+03, -.18403500E+02, 0.26404600E+00, 0.82472200E+01, 0.42656700E+02, 0.18837300E+02 },
        { 0.11903800E+01, 0.76174200E+01, -.12026700E+01, 0.10822000E+01, -.19131000E+01, -.20321800E+01, -.33855300E+01, 0.11932400E+01, -.25231500E+00, 0.10740000E+00, 0.43173100E+00, 0.14041000E+01, -.39884700E+00, 0.29938100E+00, 0.27898000E+01, 0.13231100E+01, 0.21389400E+01, -.45958800E+00, -.70656500E+00, 0.10000500E+01, -.81723800E+00, -.12175200E+01, 0.25040100E+00, 0.60254100E+01, 0.81188700E+00, 0.55628800E+00, 0.24695500E+01, -.61659400E+00, -.53041700E+00, -.10247000E+01, 0.79284400E-01, -.92552500E+00, 0.11587800E+01, 0.99607700E-01, 0.34132200E+00, -.67082400E+00, 0.13096300E+00, 0.65616700E+00, 0.13839000E+01, -.74977800E+00, 0.35417400E+00, -.68016900E+00, -.22203300E+01, -.11394900E+01, 0.26933300E+01, 0.69261300E+00, 0.16609900E+01, 0.14935700E+00, 0.40544200E+00, -.39018600E+00, 0.19189300E+01, -.54375700E+00, -.53493100E+00, 0.31079200E+01, 0.29107000E+00, -.10876900E+01, 0.11638900E+01, -.32018200E+00, 0.15568800E+00, -.54319600E+00, 0.45011300E+00, 0.83508700E+00, -.28017600E+00, 0.85461500E+00, 0.27625000E-01, -.57475100E+00, -.60281900E+00, -.36233400E+01, 0.22739400E+01, 0.89286800E-02, -.22516000E-01, 0.48188500E+00, -.71108500E+00, -.66443600E-01, 0.14014900E+01, -.65615300E+00, -.15949100E+00, -.80560500E+00, 0.11440900E+01, 0.58844600E+00, 0.29206500E-01, -.50725500E+00, -.46785300E+00, -.41109700E+00, -.17133500E+00, -.24711500E+00, -.19311300E-01, 0.24589500E-01, -.83684800E-01, -.68376000E+00, 0.28492100E+01, -.28854000E+00, -.21067000E+01, 0.54315800E+01, 0.23279900E+01, 0.39934500E+01, 0.77923000E-02, -.39017100E+00, 0.26672100E+01, 0.13701500E+01, -.82251100E+01, -.29086900E+00, 0.80580200E-01, 0.73511300E+00, 0.66965800E+00, -.14431600E+01, -.61386800E+00, 0.89380000E+00, -.13866600E+01, 0.12376400E+01, 0.19392400E+01, -.79678400E+00, 0.78441900E+00, -.32077400E-01, -.12048300E+00, 0.50030000E+00, 0.12651800E+00, 0.97171900E+00, 0.37134400E+00, 0.16593300E+00, -.46874600E+00, 0.39694800E+00, 0.56401000E+00, 0.73016100E-02, -.23946400E+00, -.23865300E+01, -.18127600E+01, 0.10377600E+01, -.20153300E+00, 0.54098800E+00, 0.14744200E+01, -.55233900E+00, 0.26379200E+00, -.39159200E+00, -.78796000E+00, 0.26816900E-01, 0.36068600E+00, 0.27702100E+00, 0.87557600E+00, 0.49006000E-02, -.47050400E+00, 0.15355700E+01, -.81025100E-01, -.10090700E+01, -.25513500E+01, -.32565800E+00, -.32418900E+00, -.20317100E+00, -.27445600E+00, 0.46455600E-02, 0.53651300E+00, -.23820300E+00, -.34496100E+00, 0.19549900E+01, -.12051600E+01, 0.22781700E+01, -.23155900E+01, 0.33675600E+00, -.20382100E+01, -.73201400E+00, -.30928600E+01, -.75097800E+01, -.10727500E+01, 0.62407700E+02, 0.16057800E+03, -.12584000E+04, 0.65576800E+03, 0.24046900E+03, 0.62852100E+03, -.31209400E+03, -.36487400E+01, 0.10944100E+03, -.68476800E+03, -.11911500E+03, -.47673700E+02, 0.48726800E+03, 0.36321600E+02, -.15156100E+02, 0.39640400E+02, -.18218600E+02, 0.46267500E+02, -.30319400E+01, 0.62007800E+02, 0.53212900E+02, 0.27072800E+02, -.24402300E+02, 0.69010600E+01, -.18876200E+04, 0.95145500E+03, 0.64768500E+03, 0.94382900E+03, 0.60965400E+03, 0.38885000E+02, 0.55556400E+03, -.36764400E+03, -.22438000E+03, 0.83512000E+02, 0.21464600E+04, -.48567600E+03, 0.23758400E+03, -.17278700E+02, 0.24415700E+03, 0.22601700E+02, 0.13776700E+02, 0.10991700E+03, -.11408200E+02, -.12218000E+03, -.17816400E+02, 0.85247400E+03, -.22052000E+04, 0.11153200E+04, 0.13890200E+04, 0.11026200E+04, -.24394000E+03, 0.21250000E+03, 0.64758500E+03, -.47040500E+03, -.32320600E+03, 0.25507900E+03, 0.23546000E+04, 0.70062000E+03, -.34810800E+03, -.38860200E+02, -.34975300E+03, -.24871000E+03, -.31221000E+03, 0.22711600E+03, 0.25768800E+03, 0.11087700E+03, -.33292100E+03, -.39196700E+03, 0.30298700E+01, -.33809500E+01, -.37732300E+01, -.15261600E+01, -.35211200E+01, -.46524700E+01, 0.60123100E+01, -.81321700E+01, 0.57854200E+00, -.16874500E+01, 0.22596700E+01, 0.13706300E+04, -.70237400E+03, -.80380400E+03, -.68403700E+03, -.32572500E+03, -.31934400E+03, -.27581300E+03, -.16380000E+03, -.33135200E+03, -.28776000E+03, -.40573700E+03, -.19568700E+03, 0.12803200E+03, -.25139200E+02, 0.97857800E+02, -.15042600E+03, -.58514700E+02, -.35107200E+03, -.45523300E+03, 0.60053200E+03, 0.55418600E+02, 0.16226500E+03, -.98803500E+03, 0.48583200E+03, 0.74993500E+03, 0.49399400E+03, 0.23891700E+03, -.11691500E+03, 0.90016200E+03, 0.56824800E+02, -.22828700E+03, -.25509200E+03, 0.28238400E+03, -.12949700E+01, 0.25019200E+01, 0.12321200E+03, -.14249000E+02, 0.64325400E+02, -.18713100E+02, 0.18528200E+02, 0.37275900E+01, -.13696300E+01, -.10655300E+02, 0.63692300E+01, 0.73506100E+01, 0.20674500E+02, -.27716100E+02, -.51160900E+02, 0.12574900E+02, -.98480900E+02, 0.10157500E+02, 0.91223800E+02, -.61922700E+02, -.83737100E+02, -.22167200E+01, -.15597100E+01, 0.74978600E+02, -.10439600E+03, -.14685500E+03 },
        { -.75270700E+00, 0.14466600E-01, 0.10149900E+01, 0.74799800E-01, -.51418800E+00, -.15181800E+00, -.26069100E-01, -.78312000E-01, -.13712100E+00, 0.32926300E-01, 0.40746500E-01, -.19474800E+01, 0.45215800E-01, -.96018500E+00, 0.13509900E+00, -.89145500E-01, 0.14488600E+01, -.31774500E+00, -.11016300E+01, -.70900300E+00, -.17808300E-02, -.14304800E+01, -.24545700E+00, 0.72475200E+00, 0.14676400E+00, 0.22249800E+00, 0.71230400E+00, -.67602000E-01, -.20998400E+00, -.44760800E+00, 0.27487700E+00, -.80148200E-01, 0.47965400E+00, -.98970400E-01, 0.11405000E+00, -.40666400E+00, 0.70783800E-01, -.19327200E+00, -.21226300E+00, -.24403000E+00, 0.37875800E+00, 0.19341700E+00, -.19397100E+00, -.52128900E+00, 0.92237300E+00, 0.10717600E+00, -.15675700E+00, 0.11514500E+00, 0.37829500E-01, -.12469400E+00, 0.44828800E+00, 0.25242300E+00, 0.57123200E+00, -.35714400E-01, 0.63252100E+00, -.19998700E+01, 0.15785100E+01, -.10200900E+01, 0.12421200E+00, -.28565100E-01, 0.75830600E+00, 0.54801800E+00, 0.50277400E+00, -.35511800E+00, 0.25787400E+00, -.99517800E-01, 0.12944000E+00, -.14667800E+00, -.19531900E+00, 0.56260800E-03, -.20634000E+01, 0.51711000E+00, -.23091700E+00, -.30896900E-01, 0.23447800E+00, 0.14203600E+01, -.93586600E-01, -.20059900E+01, 0.83357400E+00, -.40181400E+00, 0.13406000E-01, 0.66614600E-02, -.11625500E+00, -.60369100E+00, -.90618500E+00, -.32551600E+00, 0.34934900E+00, -.57809000E+00, 0.15223400E+01, 0.25216800E-01, 0.14650700E+00, -.37269600E+00, 0.21273300E+00, -.73228800E+00, -.27580200E-01, -.16436700E+01, 0.12986200E+01, -.60760900E+00, 0.11855600E+01, -.13222300E+00, 0.24682700E+00, -.13225100E+00, 0.45050600E-01, -.83791700E+00, -.44840100E+00, -.11320600E+01, -.16740900E+00, -.46974300E-01, -.98797100E-01, -.78498000E+00, 0.63120600E-01, 0.10842800E+00, -.27512600E+00, -.16752400E+00, -.25723900E+00, -.65995100E+00, 0.57019800E-02, 0.30695000E+01, 0.63372600E+00, 0.14919500E+00, -.22862800E+00, 0.95850800E+00, 0.12782800E-01, -.11448600E+01, 0.19195200E+00, 0.22720500E+01, 0.50449900E+00, -.12670500E+00, 0.17391000E+00, 0.59595200E+00, 0.44679400E+00, -.19385800E+01, 0.13032500E+00, 0.17753800E+00, 0.21144900E+00, 0.17106000E-01, 0.14853800E+01, 0.20826900E+00, 0.52909100E+00, 0.82992100E+00, -.64272500E+00, -.61030900E+00, -.64240100E+00, -.24939900E+00, -.78213700E+00, -.20929100E+00, 0.24318100E+00, -.14020000E+01, -.88595300E-01, -.62606500E-01, 0.30085700E+00, 0.13600000E+00, -.19063000E+01, -.33320300E+01, 0.11339000E+01, -.12289400E+00, 0.32094000E+00, 0.13736300E-01, 0.31456800E+00, 0.87036800E+00, 0.10010700E+00, 0.28677800E+01, -.32570400E-01, -.23144300E+00, 0.14684600E+03, -.73471800E+02, 0.42579600E+02, -.28468500E+03, 0.36739900E+02, 0.55847000E+02, 0.16442900E+03, -.81651300E+02, -.85076900E+02, -.64317800E+02, 0.76138400E+02, 0.12878600E+03, 0.76955700E+02, -.37196600E+02, -.24030600E+01, -.38482100E+02, 0.68526900E+01, -.14216800E+02, 0.39673900E+02, 0.40149800E+02, -.19957500E+01, -.18212300E+02, -.34640700E+02, -.79067100E+03, 0.39810500E+03, 0.60872200E+03, 0.39533800E+03, 0.23362900E+03, 0.75867100E+02, 0.40562700E+03, -.44877900E+03, -.31753000E+03, 0.53221400E+02, 0.11903500E+04, -.25829600E+03, 0.12759200E+03, 0.39762700E+02, 0.12916900E+03, 0.43633700E+00, -.75289900E+02, 0.10837100E+03, -.41333900E+02, -.12200700E+02, -.10869100E+03, 0.36020100E+03, -.13026400E+04, 0.65690900E+03, 0.40250500E+03, 0.65132800E+03, -.22817300E+02, 0.20506100E+03, 0.38464500E+03, -.50410200E+03, -.10999800E+03, 0.15180600E+03, 0.14636500E+04, 0.78797100E+02, -.40035100E+02, -.14509900E+03, -.41069200E+02, -.94802900E+02, -.15181600E+03, 0.17284000E+03, 0.42447700E+02, 0.14451200E+03, -.15232500E+03, -.36893900E+02, -.49252700E+00, -.61458000E+00, -.17449900E+01, 0.24430800E+00, -.75510400E+00, -.18911100E+01, 0.12167700E+01, 0.35909200E+00, -.90697000E+00, -.11976400E+01, 0.23002900E+01, 0.58339100E+03, -.30174100E+03, -.44927900E+03, -.29173000E+03, -.70931600E+02, -.73737000E+02, -.89169300E+02, 0.59864700E+02, -.10189200E+03, -.87529500E+02, 0.56097900E+02, -.62659400E+03, 0.32312200E+03, 0.27896300E+03, 0.31330000E+03, 0.10240000E+02, -.96239600E+02, 0.89563600E+01, -.22204000E+03, 0.44780200E+03, -.61970500E+02, 0.14986500E+03, -.21626500E+03, 0.10430900E+03, 0.39592200E+03, 0.10812700E+03, 0.34077900E+02, 0.18710400E+01, 0.14415300E+03, -.16617700E+03, -.30960500E+03, -.31858000E+02, 0.23575700E+03, -.15801900E+01, 0.11080400E+01, 0.39525900E+01, -.15688100E+02, 0.30603900E+02, -.63092800E+01, 0.92301300E+01, -.47623200E+01, 0.58009600E+00, -.44843300E+01, -.48505400E+00, 0.50879700E+01, 0.12630900E+02, -.63885800E+01, -.26505900E+02, 0.60680000E+01, 0.86077600E+01, 0.10429900E+02, 0.60763200E+02, -.25581700E+02, -.37586200E+02, -.15432300E+02, 0.69657900E+00, 0.17921200E+02, -.26405200E+02, -.53676200E+02 },
        { 0.20466600E+00, 0.72698800E+00, -.55690800E-01, 0.18815200E+00, -.16413200E+01, 0.97276500E-01, -.17404800E+01, 0.11852300E+01, 0.91017000E-01, -.38740600E+00, -.93146600E-01, -.44835000E+00, 0.49319100E+00, -.18316100E+00, -.67686000E+00, 0.13299600E+01, 0.77382200E+00, -.76306300E-01, -.81996100E-01, -.10306100E+00, -.56694700E+00, 0.20021800E+01, 0.49214900E+00, -.77635500E+00, -.81762400E+00, -.18616700E+00, 0.43898100E+00, 0.65393900E+00, -.14290000E+00, -.38809300E+00, 0.12069300E+00, 0.30941400E-01, 0.33046900E+00, 0.19863800E+00, -.36319500E+00, -.60667300E+00, 0.57940800E-01, -.57807000E+00, -.14096800E+00, 0.16876500E+00, -.14772700E+00, 0.84476200E+00, 0.15168600E+01, 0.60603700E+00, -.28388800E+00, -.24783400E+00, -.69115300E+00, 0.74437700E-01, 0.18373200E+00, -.21281700E+00, 0.35979400E+00, -.52325000E+00, 0.30393200E+00, 0.41923300E+00, 0.59058600E+00, -.65167000E+00, 0.13483800E+00, -.15477800E+00, -.67802300E-01, 0.17816000E-01, -.42859300E+00, 0.13945200E+00, -.94716000E-01, 0.23805700E+00, 0.11585700E+00, -.95889900E-01, 0.11594100E+00, -.35902400E+00, -.43039900E+00, -.47837100E-02, 0.12676700E+01, -.56001900E+00, -.49806400E-01, 0.97355300E-02, 0.24283700E+00, 0.86956200E-01, -.11780800E+00, -.40131700E+00, 0.52615600E+00, -.54294800E-01, 0.11723500E-01, 0.61844300E-01, -.32256200E+00, -.30934600E+00, -.13509100E-01, -.29549200E+00, 0.14068900E+01, 0.14667200E+01, 0.21196600E+01, -.45715200E+00, 0.32628900E+00, 0.62919900E-01, -.25874900E+00, -.37461900E+01, 0.25821800E+00, 0.18432000E+01, 0.19472400E+00, -.40319200E+00, -.40685700E+00, -.13376200E+00, 0.46670900E+00, -.89324700E+00, 0.27076300E-01, -.58483400E+00, 0.54931100E-01, 0.91719800E+00, 0.16943000E+00, 0.30286900E-01, -.38954500E+00, -.23049500E+00, 0.61428300E+00, 0.26542200E+00, 0.30585400E+00, -.49074000E-01, 0.26310600E-01, -.33756000E+00, 0.31671600E-01, -.20453800E+00, 0.53798800E-01, 0.62772000E-01, 0.32201800E-01, 0.10625700E+01, 0.27483300E-01, -.43456500E+00, 0.99846500E-01, -.72198900E-01, -.24382900E+00, 0.33361700E+00, 0.33154100E-01, -.24670800E+00, -.39126000E-01, 0.82160600E+00, -.42138900E-01, 0.16391400E+00, 0.30354000E+00, 0.19530100E-02, 0.11847800E+01, 0.34244800E+00, 0.26862200E+00, 0.30222400E+00, -.13303300E+00, -.65950100E+00, -.12331400E+00, 0.56159100E-01, -.13689900E+00, -.17104800E-02, 0.35035100E-01, -.24064300E+00, 0.11472000E+00, 0.56054900E-01, -.51536000E-01, -.93958600E-02, 0.71039100E-01, 0.45867600E+00, 0.37933400E+00, -.24316200E+00, 0.88329500E+00, -.22561900E-01, 0.64366900E-01, -.34390800E+00, 0.14599000E+00, -.56444800E+00, 0.10980100E+00, -.11761700E+00, -.85291100E-01, -.21174500E+03, 0.10951000E+03, 0.82259100E+02, 0.10579100E+03, -.87308000E+02, -.52219800E+02, 0.13657600E+02, -.98579400E+02, 0.93477200E+01, -.60319600E+02, 0.84402800E+02, 0.59008900E+01, -.25830600E+01, 0.28608000E+01, -.29618700E+01, 0.41643800E+01, 0.18800200E+01, 0.34825100E+01, 0.65485100E+01, 0.56632500E+01, 0.22223400E+01, 0.17996400E+02, -.97634300E+01, 0.54875500E+01, 0.72433400E+02, 0.48873700E+01, 0.26958600E+02, 0.41626800E+02, -.34243200E+02, 0.19971400E+02, -.54463200E+02, 0.80277100E+02, 0.43847000E+03, -.82605100E+02, 0.40470200E+02, -.19554100E+02, 0.41495200E+02, -.82007700E+01, -.25170400E+02, 0.55697800E+02, 0.11118300E+02, 0.21188600E+01, -.38316400E+02, 0.11431700E+03, -.22476000E+03, 0.11364100E+03, 0.29986400E+02, 0.11239200E+03, -.15807700E+02, 0.44603800E+02, -.86319600E+01, -.22728400E+02, -.13013300E+02, 0.10351500E+03, 0.60936900E+03, 0.33950000E+02, -.16842700E+02, -.53846600E+01, -.17067100E+02, -.11465900E+02, -.18141600E+02, 0.45483700E+02, 0.62899300E+01, -.27612200E+02, -.11737100E+02, 0.41134400E+00, -.63992000E+00, 0.26468400E-01, -.12260600E+01, 0.31661900E+00, -.52501200E+00, -.11053600E+01, 0.57287600E+00, -.14387100E+01, 0.91918300E+00, -.69031800E+00, -.50913700E+00, 0.16959900E+03, -.86459200E+02, -.97875100E+02, -.84677900E+02, -.73187100E+02, -.69798300E+02, -.15326200E+02, 0.68619700E+01, -.15109200E+02, -.68037700E+02, -.61924300E+02, -.42229600E+02, 0.25504300E+02, -.43605700E+02, 0.21120200E+02, -.70474100E+02, -.65628800E+02, -.40264600E+02, -.43111600E+01, 0.10328400E+03, -.35209200E+02, 0.11672900E+03, -.34263400E+03, 0.16979100E+03, 0.22339100E+03, 0.17130700E+03, 0.15774800E+03, 0.66744800E+02, 0.88815300E+02, -.12083500E+03, -.19836200E+02, 0.38346900E+02, 0.57915700E+02, 0.40091100E+00, 0.18973800E+02, 0.20571600E+02, 0.40964200E+00, 0.52344200E+01, -.18534100E+01, 0.17839900E+01, 0.16067800E+02, -.69536500E+00, -.32035900E+01, -.50457000E+00, -.13295200E+01, 0.97358500E+00, -.33011100E+01, -.47587300E+01, -.63375700E+00, -.18032200E+02, 0.10797900E+01, 0.35007100E+01, -.10827700E+02, -.10050500E+02, 0.11171400E+01, -.52033600E+00, 0.66352600E+01, -.20096200E+02, -.24890000E+02 },
        { -.68894300E+00, -.46786700E+01, 0.18739900E+01, -.47621100E+00, 0.68021700E+00, 0.12438200E+01, 0.95480700E+00, -.18409500E+01, -.53366200E+00, 0.13030700E+00, 0.49126400E+00, 0.60494900E+00, -.35448000E+00, -.39021500E+00, -.42405300E-01, 0.47445200E-01, 0.25873200E+00, 0.56245900E-01, 0.65492700E+00, -.99707400E-01, 0.45570800E+00, -.11971300E+01, -.20950800E+00, -.39054800E+01, -.46150500E+00, 0.31018100E+00, -.12733200E+01, 0.65057000E+00, 0.23263500E-01, 0.76859800E+00, -.19234700E+00, 0.80103500E+00, -.39570300E+00, 0.93776600E-01, 0.30096000E+00, 0.37320300E+00, -.14273600E+00, 0.60545300E+00, -.20235700E+00, 0.18426800E+00, -.84792900E-01, -.24304100E+01, -.28627800E+01, -.60044600E+00, 0.16526500E+00, 0.93598400E-01, 0.50533400E+00, -.15098200E+00, 0.48172000E-01, -.49454900E-02, -.11076100E+01, 0.81693200E+00, 0.99025400E-01, 0.21634400E+00, -.45470300E+00, 0.90257000E+00, -.68169800E+00, 0.88475900E+00, 0.16988200E+00, -.79957700E-01, 0.27963200E+00, -.31707300E+00, -.17649400E+00, 0.11512400E+00, -.12185900E+00, 0.73016700E+00, 0.11300300E+00, 0.14297500E+01, -.56734200E+00, -.12925200E-02, -.11460900E+01, -.14474200E+01, 0.18978200E+00, -.12812000E+00, 0.84330500E-01, 0.16960400E+00, -.38710500E+00, -.69091000E-01, -.97924600E+00, 0.42929600E+00, 0.31380600E-01, 0.42850300E-02, -.21285900E+00, 0.29518700E+00, 0.57686700E-01, 0.43280400E+00, 0.48198000E-01, -.14223300E+01, 0.70208800E+00, 0.53875000E+00, 0.24173100E+00, 0.63569300E+00, 0.13956700E+01, -.54136200E+01, -.10176700E+01, -.15768200E+00, 0.14762200E+01, 0.21955200E+00, -.83097600E+00, -.75045900E+00, 0.49749800E+01, -.10619300E+01, -.90404300E-01, 0.93759300E+00, 0.25310100E+00, 0.14463400E+01, 0.72327500E-01, 0.35856900E+00, 0.52531500E+00, -.12482200E+01, 0.45905400E-01, 0.21579200E+01, -.43930100E+00, -.55436700E-01, -.26338700E-01, -.11479700E+00, -.13790400E+00, -.87396400E+00, -.94853800E+00, -.17722500E+00, 0.27110000E+00, 0.97388700E+00, 0.34558600E+00, 0.83805600E-01, 0.32569600E-01, 0.80793400E+00, 0.92358700E+00, 0.37444400E+00, 0.19715800E+00, 0.12130500E+00, -.69691500E+00, 0.18549200E+00, -.19803700E-01, 0.53485300E+00, 0.79122700E-01, 0.18311200E-01, -.85132100E+00, -.73569500E+00, -.74598800E+00, 0.26279700E+00, 0.29755500E+00, 0.11313800E+01, 0.43364900E+00, 0.76878200E+00, 0.16432200E+01, 0.84562000E-01, 0.20475100E+00, 0.12141500E+00, -.90727600E+00, 0.13594400E+00, -.25920300E-01, -.11455700E+00, -.29056300E+00, -.22058300E+01, 0.95395200E+00, 0.22751400E+00, -.52047500E+00, 0.40841000E-01, 0.49244700E+00, 0.34815000E+00, -.54431600E+00, -.19627000E+01, 0.24319800E+00, 0.64223600E-01, -.29792100E-01, -.80974700E+00, -.26027400E+02, 0.21414900E+03, 0.28592000E-01, -.86877900E+02, -.94312400E+02, -.21043100E+02, 0.33347300E+02, 0.76019000E+02, -.33455500E+02, -.45101000E+02, -.15819400E+01, 0.36568300E+01, -.16291900E+02, 0.77898500E+00, -.16293700E+02, -.15135200E+01, 0.92114800E+01, 0.64290900E+01, 0.26944200E+02, -.35347800E+00, 0.13822300E+02, -.72294400E+03, 0.36540800E+03, 0.39591600E+03, 0.36148400E+03, -.18666100E+03, 0.50012200E+02, 0.16706600E+03, 0.79853600E+02, 0.67479200E+03, 0.28237600E+02, 0.11410600E+03, -.18506900E+03, 0.84367100E+02, 0.10333000E+03, 0.92636100E+02, 0.69839600E+02, 0.59167000E+02, 0.63471800E+01, -.30447900E+01, 0.66884100E+02, 0.40219500E+02, -.25512500E+00, -.51695800E+03, 0.26372500E+03, 0.19652900E+03, 0.25851700E+03, 0.83583200E+02, -.29742000E+02, 0.16076000E+03, 0.15427100E+03, 0.70988500E+03, -.37229600E+02, 0.89473700E+02, -.33439100E+03, 0.16954200E+03, -.22822000E+02, 0.16700200E+03, 0.15599400E+03, 0.10125400E+03, 0.12569500E+02, -.89019000E+02, 0.67831200E+02, 0.80294800E+02, 0.23939700E+03, -.13548000E+01, 0.13967400E+01, 0.28988700E-01, 0.67168400E+00, 0.24566100E+01, 0.12091600E+01, -.14008800E+01, -.27710700E+01, 0.82590900E+00, 0.92216300E+00, -.29537600E-01, -.88860300E+02, 0.53998000E+02, 0.15127700E+03, 0.44399300E+02, 0.42056100E+01, 0.16709300E+02, 0.14938800E+02, 0.44594800E+02, 0.58277200E+02, 0.29908300E+02, -.78569200E+02, 0.45320800E+03, -.22286600E+03, -.16170500E+03, -.22659000E+03, -.28210500E+02, -.14613700E+03, 0.12213500E+03, 0.17272200E+03, -.12815600E+03, -.16458000E+03, -.17040600E+03, -.83283400E+03, 0.41378100E+03, 0.29280100E+03, 0.41638900E+03, 0.11814100E+03, 0.23092900E+03, -.11870500E+03, -.26267500E+03, 0.21475500E+03, 0.23227800E+03, 0.28882900E+03, 0.19748000E+01, 0.19040900E+02, -.19678700E+01, 0.32333100E+00, -.37233800E+02, 0.18304600E+00, 0.44510400E+01, 0.14641800E+02, -.56526400E+00, 0.52075400E+00, -.10549300E+01, -.58823400E+01, -.39460000E+01, 0.99741200E+01, 0.34274800E+02, 0.21554800E+00, -.14876400E+02, -.63332500E+01, -.17661200E+03, -.32506400E+00, 0.13804100E+03, 0.68810700E+01, -.45345800E+00, -.77199200E+01, 0.12427300E+02, 0.17892800E+02 },
        { -.57309900E+00, 0.87160800E+00, -.52416500E+01, -.58701200E+00, 0.28719900E+01, 0.77751900E+00, 0.35009000E+01, -.18367400E+01, -.69837800E+00, 0.54951400E+00, 0.87264500E+00, -.12985300E+01, 0.43142800E+00, 0.87678500E-01, -.19433600E+01, -.31348500E+00, -.15266400E+01, 0.45577800E+00, -.55856000E-01, 0.25084100E+00, -.83365500E+00, -.34843400E+01, 0.32940700E+00, -.38222400E+00, -.92268600E+00, -.14352700E+00, -.69941700E+00, 0.91875900E+00, -.27812800E+00, 0.55785200E+00, 0.10098100E+01, 0.95891000E-01, 0.10738200E+00, 0.11141800E+01, -.36771900E-01, -.68248300E+00, 0.86331700E-01, -.17105100E+00, 0.12671500E+01, -.10210600E+01, -.11659500E+01, -.22585800E+01, 0.47928900E+00, -.54856200E-01, -.99794000E+00, -.23342000E+00, -.28300200E+00, -.40645800E-01, -.45646200E+00, -.16274000E+00, -.28878100E+01, 0.32509500E+01, 0.97469000E+00, -.17731200E+00, -.67248900E+00, 0.16657400E+00, -.93186000E+00, 0.84761700E+00, -.15578000E+00, -.16765500E+00, 0.22628800E+00, -.88152200E-01, 0.37513300E+00, -.64895300E+00, -.66830200E-01, -.21434100E+00, 0.14586800E+00, 0.20809500E+01, -.88198800E+00, 0.12299200E-02, -.24410700E+00, -.17343000E+00, 0.88402600E-01, -.84243900E-01, -.72209700E-01, 0.31390200E+00, -.26705300E+00, -.39524200E+00, 0.61490100E-02, 0.37671900E-01, 0.21058500E-01, 0.16291300E+00, -.64567400E+00, 0.30393400E+00, 0.10261300E-01, -.88870800E-01, 0.87710000E+00, 0.27949500E+00, 0.85412300E+00, -.20165100E+00, -.11555300E+01, 0.18480700E+00, -.56217500E-01, -.14012500E+01, 0.43808000E+00, -.72648100E+00, 0.76511700E-01, -.39479100E+00, 0.60695300E-02, 0.14971100E+00, -.22496400E+01, 0.13779400E+00, 0.28142000E-02, -.66978900E+00, -.20555900E+00, 0.14634900E-01, 0.22750600E+00, -.14930800E+01, 0.63781600E+00, 0.49277900E+00, 0.52058000E+00, -.48822000E+00, 0.47283900E+00, -.75431300E-02, 0.15195200E+00, -.36706000E+00, 0.76156100E-02, 0.29441600E+01, 0.61819700E+00, 0.27121800E+00, -.50981200E-01, 0.21776700E-01, -.17113800E+00, 0.84393900E-01, 0.59726100E-01, -.19207300E+00, 0.16623400E+00, -.16159500E+01, -.24535200E+00, 0.14359900E+00, -.19701700E+00, -.81062900E+00, 0.11942900E+00, 0.49796100E+00, 0.78820200E+00, 0.47347200E-01, -.68518000E-01, -.41547000E+00, -.48963400E+00, -.10022700E+00, 0.34259700E+00, -.11302500E+01, 0.92298000E-01, 0.24753900E+00, 0.11102100E+01, 0.18460000E+00, -.34363200E-01, -.68839900E+00, 0.68799900E+00, -.27863800E+00, 0.77084300E+00, -.39030400E+00, 0.15062200E+00, 0.16060000E+01, 0.16220600E+01, -.34782600E-01, 0.58385100E+00, 0.37640900E+00, -.29097900E-01, 0.35447100E+00, -.83973300E+00, 0.10902600E+01, -.26245200E+00, 0.31458600E+00, -.59565900E+00, 0.99487300E+00, 0.32885800E+00, -.21531300E+03, -.27720200E+00, 0.76400900E+02, -.24946900E+01, 0.12541400E+03, 0.82447600E+02, 0.70391300E+02, -.29466000E+02, 0.93196200E+02, 0.19034600E+02, -.11254700E+02, -.31956800E+01, -.95058700E+01, 0.64324500E+01, 0.40249300E+01, -.22672400E+02, -.96140800E+01, -.43508100E+02, 0.29832800E+01, -.58097700E+02, 0.38067500E+03, -.19412000E+03, -.29194200E+03, -.19036000E+03, 0.65868100E+02, 0.26202500E+02, -.13692300E+03, -.30641900E+03, -.62913900E+03, 0.85247300E+01, -.55682700E+03, 0.26621100E+03, -.12899200E+03, -.10716300E+03, -.13289600E+03, -.11420200E+03, -.13966800E+03, -.10281400E+02, 0.34043700E+02, 0.47732800E+02, -.12413200E+03, -.39627100E+02, 0.58247700E+03, -.29651400E+03, -.15018300E+03, -.29131600E+03, -.98811100E+02, 0.75775600E+02, -.25596500E+03, -.24868800E+03, -.68492100E+03, 0.38843600E+02, -.79967900E+03, 0.18400900E+03, -.93769000E+02, 0.41104200E+01, -.90678600E+02, -.59952400E+02, -.33745200E+02, -.10277000E+03, 0.10066900E+03, -.83318300E+01, -.23671700E+02, -.26191100E+03, -.32884900E+00, 0.28535400E+00, 0.12617300E+01, 0.17512700E+00, -.68866600E+00, 0.11231900E+01, -.47032700E+01, 0.48330200E+01, -.35399300E+01, 0.93175200E+00, 0.77046900E+00, -.28105400E+03, 0.14128800E+03, 0.31528700E+02, 0.14115000E+03, 0.11874000E+02, 0.17360400E+02, 0.11139700E+03, 0.23446200E+02, 0.79413200E+02, 0.12753000E+02, 0.23437100E+03, -.41271800E+03, 0.19709300E+03, 0.31207100E+03, 0.20633300E+03, 0.76011300E+02, 0.10062800E+03, 0.91440800E+01, 0.57489000E+02, 0.15258000E+03, 0.41085200E+02, -.92235200E+02, 0.96411700E+03, -.47990900E+03, -.44703900E+03, -.48200300E+03, -.14731500E+03, -.14564700E+03, -.15256100E+03, -.15271500E+01, -.33312500E+03, -.81614400E+02, -.55211800E+02, -.75449600E+00, -.13972900E+02, -.20975500E+02, -.59808100E+00, 0.25956200E+02, 0.31595700E+01, -.17002700E+02, -.15310900E+02, 0.20880000E+01, 0.21491400E+01, 0.11662900E+01, 0.84141400E+01, -.42256200E+01, -.99110800E+01, -.29461000E+02, 0.25711200E+01, 0.30971700E+02, 0.11612900E+02, 0.17770700E+03, 0.97328200E+01, -.11315300E+03, -.21231400E+01, 0.16905900E+01, -.13482800E+02, 0.51295000E+01, -.10273600E-01 },
        { -.36140300E+00, 0.18554300E+01, -.57137200E+01, -.13264400E+00, 0.19215600E+01, 0.23961800E+00, 0.20509000E+01, 0.99465500E+00, -.11256300E+00, -.10025800E+00, -.24424500E+00, -.22474500E+01, 0.10050400E+01, 0.25331700E+00, -.35379100E+00, -.33291500E+00, -.21707700E+01, 0.32273200E+00, -.31202500E+00, 0.29970300E+00, -.62584600E+00, 0.52353000E+00, 0.52330700E+00, -.85132500E+00, -.11306400E+01, -.36401600E+00, -.53377300E+00, 0.15875000E+00, 0.26165200E-01, 0.38087100E+00, 0.42582400E+00, 0.18658300E+00, -.10039100E+01, 0.65173700E-01, 0.10664900E+00, 0.15193200E+00, -.47483600E-01, 0.22235200E+00, 0.40227300E+00, 0.13406300E+00, -.67344600E+00, -.19790700E+01, -.19592600E+01, -.42582100E+00, 0.29425500E+00, 0.17967000E+00, 0.87049500E+00, -.77914500E-01, 0.22971400E+00, -.20594700E-01, 0.33996600E+00, 0.56846000E+00, 0.36419800E-01, 0.92517800E-01, -.85967600E+00, 0.11412600E+01, 0.38846000E-01, -.29464400E-01, 0.11913900E+00, -.68595600E-01, 0.80543500E-01, -.32210500E+00, 0.14962000E+00, 0.36726100E-01, 0.59854400E-01, 0.42575000E-01, 0.60087900E-01, 0.69500300E+00, -.14296800E+00, -.70431500E-02, -.72556600E+00, -.21106600E+00, 0.11705300E-01, -.32176100E-01, 0.30278700E+00, -.55154000E-01, 0.18490100E+00, 0.10033800E+00, -.25768700E+00, -.16454500E+00, -.16183700E-01, 0.93487900E-01, -.55129700E+00, -.65814900E-02, 0.22858100E-01, -.28185800E+00, 0.46208800E+00, 0.86054300E+00, 0.11231000E+01, 0.32711800E-01, -.53870000E+00, -.28150800E+00, 0.36467100E+00, 0.19182700E+01, -.16177300E+00, -.98912400E+00, -.15522400E+00, 0.31284900E+00, 0.61131500E+00, 0.30988900E+00, -.14309100E+01, 0.28320000E+00, 0.44319200E-01, -.37441200E+00, -.23039500E+00, 0.36790500E+00, 0.37766900E+00, 0.31407500E+00, 0.16204300E+00, -.66149000E+00, -.64369600E+00, -.31982100E+00, -.94652800E-01, 0.13015500E-01, -.15148900E+00, -.16535900E+00, -.11073200E+00, -.36157100E+00, -.42474600E+00, 0.10599200E-01, -.38645700E+00, -.46590000E-01, 0.32277900E-01, -.66012100E-01, -.12740800E-01, -.26827100E+00, -.10058200E+00, 0.59344400E+00, 0.91461100E-01, 0.19848300E+00, 0.90696100E-01, -.37922600E+00, 0.84238400E-01, -.33872000E-01, -.14888500E+00, -.16157900E-02, 0.34117300E+00, 0.17835300E-02, 0.18886200E+00, 0.28474000E+00, -.18689600E+00, -.52179900E-01, 0.15797600E-01, -.11910700E+00, -.19777500E+00, 0.19628800E-01, -.43782700E-01, 0.62159800E+00, 0.21284400E+00, 0.38317200E-01, 0.28521500E+00, 0.19880500E-01, 0.65632500E+00, -.80333000E+00, -.85620100E+00, 0.31927200E+00, -.76240500E+00, -.45902200E-01, -.87016800E-01, 0.34927500E+00, 0.88488500E-01, -.57322600E+00, 0.97084900E-02, -.12153700E+00, 0.50779600E+00, -.13812400E+00, -.25357000E-01, -.17222800E+00, 0.35571100E+01, -.52592500E+01, -.23125800E+02, 0.24375000E+02, 0.67463200E+01, -.14944300E+02, -.12857600E+01, -.40627800E+02, -.21367600E+02, 0.10293300E+02, 0.51942200E+01, 0.10678900E+02, 0.38436400E+01, -.38724500E-01, -.36782200E+01, -.12418600E+02, -.82462900E+01, -.15573400E+01, 0.41441400E+01, 0.99765100E+03, -.49947000E+03, -.57416800E+03, -.49882200E+03, -.17954000E+03, -.24999900E+03, -.75524300E+02, 0.36698100E+03, -.18113400E+03, -.24235700E+03, -.41651300E+03, 0.12886200E+03, -.63892300E+02, -.35071900E+02, -.64512300E+02, -.87418800E+01, 0.58270500E+02, -.69959400E+02, 0.21082300E+02, -.32990900E+02, 0.61571100E+02, -.94197700E+02, 0.10614400E+04, -.53221400E+03, -.41943200E+03, -.53071000E+03, -.12743600E+03, -.24414600E+03, -.64845000E+02, 0.34754100E+03, -.27453700E+03, -.23663600E+03, -.50376000E+03, 0.72907900E+01, -.31789000E+01, 0.37742800E+02, -.38382200E+01, 0.22776000E+02, 0.66501400E+01, -.60828200E+02, 0.26047100E+02, -.26280800E+01, 0.66582400E+01, -.30665500E+02, -.13250200E+00, 0.23877700E+00, 0.12368100E+01, 0.62385100E-01, -.19472500E+00, -.58232000E+00, 0.24822400E+01, 0.31664000E+00, 0.14431800E+01, -.93120100E+00, 0.18888600E+00, -.16894300E+03, 0.86612800E+02, 0.83327900E+02, 0.84280000E+02, 0.22464100E+02, 0.22897100E+02, 0.18297500E+02, -.48292900E+02, 0.75633100E+01, 0.22950100E+02, 0.18240500E+00, 0.15602900E+03, -.79751000E+02, -.73789900E+02, -.78009400E+02, 0.10608200E+02, 0.74590100E+02, -.36688400E+02, -.28073600E+02, -.17019200E+03, 0.75762100E+02, -.12146400E+03, 0.23126600E+03, -.11465300E+03, -.17769700E+03, -.11564400E+03, -.25452200E+02, -.79884700E+02, 0.26783200E+02, 0.21272300E+03, 0.14088300E+03, -.81266800E+02, -.38932000E+02, -.25097000E+00, -.11057200E+02, 0.10281800E+01, 0.11392900E+01, -.49837400E+01, 0.47257400E+01, -.45653200E+01, -.64291100E+01, -.30602000E+00, 0.10914500E+01, 0.30159600E+01, 0.53067000E+01, -.27414900E+01, 0.36424200E+01, 0.43061100E+01, -.65318400E+00, -.70773400E+01, -.23723800E+01, 0.26512700E+02, 0.40267500E+01, -.29072000E+02, 0.63679000E+01, -.17006700E+00, -.35532200E+01, 0.10087000E+02, 0.20018900E+02 },
        { 0.35138200E+00, 0.87012800E+00, 0.33379600E+01, -.37292100E-01, -.20309900E+01, -.34505500E+00, -.17809000E+01, 0.13908800E+01, -.51398900E-01, -.71927300E+00, 0.26776200E+00, 0.34777200E+01, -.14087600E+00, 0.92123900E+00, 0.14029700E+01, 0.32810400E+00, 0.15392200E+01, -.31561200E+00, -.49241000E-01, 0.32617700E+00, 0.25099600E+00, 0.17695500E+01, 0.57863500E-01, 0.35503500E+00, 0.65967900E+00, 0.15140700E+00, 0.29830700E+00, 0.46469400E+00, 0.11323800E+00, -.25941100E+00, 0.41357200E+00, 0.83784700E-01, 0.83452200E+00, -.86447400E+00, -.53880000E-01, 0.62307900E-01, 0.29778200E-01, -.25484900E+00, 0.74413700E-01, -.34749800E+00, -.55707500E-01, 0.18930700E+01, 0.36805900E+01, 0.23545300E+00, -.12786100E+01, -.35885400E-02, 0.15808000E+00, -.41905900E-01, 0.10927500E+00, 0.33437300E+00, -.63198900E-01, -.35891100E+00, -.13673600E+01, -.94435800E+00, 0.16040900E+00, -.11693300E+00, -.50422200E+00, 0.95674500E-01, 0.34789700E+00, -.13645700E+01, -.14396600E-01, 0.62194100E-01, -.22717400E+00, 0.10280400E+01, -.37615200E+00, 0.50508500E+00, -.57918100E-01, -.38787500E+00, 0.33611800E+00, 0.19267000E-02, -.87037500E+00, -.95991100E-01, 0.15175000E+00, 0.24844800E+00, -.38527400E+00, -.97235200E+00, -.30985700E+00, 0.13952400E+01, -.28534500E+00, 0.17427000E+00, 0.16097500E-01, -.12835000E+00, 0.11407400E+01, -.61886600E-01, 0.10710700E+00, 0.28163500E+00, -.22430100E+00, -.93992700E+00, 0.53157700E+00, 0.24997200E+00, 0.42689600E+00, 0.42532300E+00, 0.86453800E+00, -.19190100E+01, 0.45524100E+00, 0.31120900E+01, -.23999400E+00, 0.11223900E+00, -.16614300E+01, -.38595200E+00, 0.95135000E+00, -.11285000E+01, -.25522200E-01, 0.45226200E+00, 0.11838100E+00, 0.13120000E+01, 0.16396900E-01, -.23311100E+00, -.55374700E+00, 0.50334300E+00, 0.11747500E+01, 0.12217700E+01, -.14562500E+00, -.54116400E-01, 0.14075400E+00, 0.18420800E+00, 0.27636100E+00, 0.52385000E+00, 0.37860500E+00, 0.16334100E+00, -.36768800E+00, -.23276900E+00, 0.14030600E+00, 0.11355100E+01, -.48886300E-02, 0.77095000E+00, 0.51831700E+00, 0.56440300E+00, 0.55878000E-01, 0.27507400E+00, 0.99838700E+00, 0.68648200E+00, -.84291600E-01, -.20269300E-01, -.58076400E+00, -.18884700E-01, -.24913800E+01, 0.57474500E-01, -.15334400E+00, -.89976200E+00, 0.24852000E+00, 0.81831100E+00, 0.16781300E+00, -.14260600E+00, -.49763200E+00, 0.10246100E-01, -.16595300E+00, 0.12690400E+01, 0.22560300E+00, -.79538000E-01, 0.46725600E+00, -.34946400E+00, 0.60926500E+00, 0.27590000E+01, -.51868800E+00, -.22431200E+00, 0.22290600E+00, -.37021800E-01, -.15473600E+00, -.10064300E+01, -.47008300E+00, -.13950500E+01, -.39493000E+00, -.52985700E-01, 0.83896600E-01, 0.10851900E+01, 0.10875900E+00, -.21096100E+00, -.55997400E-01, 0.70314300E+02, 0.18990000E+02, 0.86399500E+02, 0.25379700E+02, 0.18651900E+00, 0.16926700E+02, -.43121500E+01, -.10751300E+02, 0.40115400E+01, 0.57376500E+01, 0.53840300E+01, 0.76888600E+01, 0.16770700E+01, -.15922200E+02, -.93784900E+01, -.20424000E+02, -.19103200E+01, -.35701400E+02, -.84266400E+02, 0.39495900E+02, -.14158300E+03, 0.42118300E+02, 0.14664600E+03, 0.32925600E+01, -.82329600E+02, -.15329800E+03, -.18888900E+03, -.29815800E+02, -.69487200E+03, 0.35177000E+03, -.17347200E+03, -.12964100E+03, -.17573300E+03, -.62962900E+02, -.36305600E+02, -.12043700E+03, -.15215600E+02, -.60331200E+02, -.66940400E+01, -.16900900E+03, 0.21519800E+03, -.11218000E+03, 0.10412900E+03, -.10765000E+03, -.34912900E+02, -.62398400E+02, -.96048900E+02, -.80693500E+02, -.27849300E+03, -.10580000E+03, -.96992100E+03, 0.14969700E+03, -.74711400E+02, 0.56319100E+02, -.72683100E+02, -.49493600E+02, -.16277700E+02, -.88063500E+02, 0.74874000E+02, -.37309800E+02, -.16606700E+02, -.15651700E+03, 0.92394300E+00, -.10086300E+00, 0.12370000E+01, -.45429200E+00, -.56388700E+00, 0.86292800E+00, -.60948000E+00, 0.21064600E+01, -.17784700E+01, 0.25503400E+00, 0.10211400E+01, -.18909600E+03, 0.99326000E+02, 0.11361800E+03, 0.94975700E+02, 0.41894600E+02, 0.41951000E+02, 0.24184100E+02, -.67836300E+02, 0.58294200E+01, 0.42170000E+02, 0.70224300E+02, -.10087700E+03, 0.43652300E+02, 0.10623000E+03, 0.50421100E+02, 0.71998600E+02, 0.12625200E+03, -.34638200E+02, 0.62146000E+02, 0.60650600E+02, 0.85385300E+02, -.19086700E+03, 0.58784500E+03, -.29147000E+03, -.33946000E+03, -.29388500E+03, -.16249300E+03, -.15692100E+03, -.68477500E+01, 0.56329800E+02, -.14441100E+03, -.11939900E+03, -.70213500E+01, -.11812100E+01, -.31550500E+02, -.67904500E+01, 0.87146700E+00, 0.11627300E+02, 0.15266800E+01, -.69327600E+01, -.29187300E+02, 0.75505700E+00, 0.21522300E+01, 0.41397100E+01, 0.44842800E+01, -.58523900E+01, -.58930000E+01, -.12961800E+02, -.21435900E+00, 0.16979600E+02, 0.32772800E+01, 0.79157100E+02, 0.10816300E+02, -.42045200E+02, -.59709500E+00, 0.44374000E+00, -.84158700E+00, -.98886000E+01, 0.14139500E+01 },
        { 0.29648700E+00, -.83134600E+00, 0.21516700E+01, 0.61980900E+00, -.71492300E+00, -.24675200E+00, -.19875100E+01, -.12139500E+01, -.33533700E+00, 0.16548000E-01, -.94776200E-01, 0.92649700E+00, -.25663200E+00, 0.58591500E+00, 0.48266200E+00, -.76943100E-01, 0.13878400E+01, -.26176400E+00, 0.46058700E+00, -.19786800E+00, 0.39560600E+00, 0.29745300E+01, -.43793900E-02, 0.20339900E+00, 0.33682600E+00, 0.11335800E+00, 0.34854100E+00, -.57262400E+00, 0.40322200E+00, -.39363200E+00, -.31552000E+00, -.34732800E+00, 0.81926000E-01, 0.27781200E+00, 0.26771400E+00, -.25383400E+00, 0.41401300E-01, 0.13010200E-01, 0.95392400E-01, -.20963000E+00, 0.90243500E-01, -.72152700E+00, -.11517900E+00, -.12716600E+00, 0.25822200E+00, 0.13620000E+00, 0.90161400E+00, 0.67210300E-01, -.32198700E+00, 0.27372100E+00, -.58049100E+00, 0.13211300E+01, 0.54018000E+00, 0.51728100E+00, -.52970400E-01, 0.17570400E+00, -.14241200E+00, 0.47212500E+00, -.30335500E+00, -.59789200E+00, 0.46672500E+00, -.39525800E-01, 0.37196200E+00, -.16381500E+00, -.67372700E-01, -.19791200E+00, -.22003400E-02, -.50498600E+00, 0.72785800E-01, -.31862900E-02, 0.80833500E+00, 0.75315400E+00, 0.90808800E-01, 0.78031600E-01, -.14894100E+00, -.12519100E-02, 0.27954200E+00, -.20265200E+00, 0.27977300E+00, -.37459100E+00, -.23513100E-01, 0.84432200E-02, 0.63011400E+00, -.15818600E+00, -.13388900E+00, -.13257900E+00, -.85249300E+00, 0.44878500E+00, -.85204900E+00, -.58177200E-01, -.37332000E+00, -.38996600E+00, -.76715600E+00, 0.19387200E+01, -.11719600E+00, -.68344600E+00, -.16017100E+00, -.66680800E+00, 0.29786000E+00, 0.42740900E+00, -.33094900E+01, 0.97540500E+00, 0.55296900E-01, -.56151500E+00, -.24088800E+00, -.10413700E+01, -.12871900E+00, -.13682500E+00, 0.28150300E+00, 0.13298900E+01, 0.43503700E-01, -.63714600E+00, 0.14364100E+00, -.62184500E-01, 0.24506300E-01, 0.22168500E+00, -.35738200E-01, 0.15349000E+00, 0.10297600E+01, -.52074400E-02, 0.22211100E-01, -.14764800E+01, 0.43742900E-01, -.48646200E+00, -.24966900E-01, -.20900700E+00, -.52085700E+00, 0.24156900E+00, -.93443500E-01, 0.38961400E-01, 0.49764600E+00, -.86167600E+00, 0.65274900E-01, 0.97965800E-02, -.93435300E-02, 0.82495100E-02, 0.24336800E+00, -.11203000E+00, 0.67703200E-01, 0.80287800E+00, -.29981300E+00, -.37057600E+00, -.23796100E+00, -.13903500E+01, -.90511800E+00, -.17979000E+00, 0.57758100E-01, -.46762600E+00, -.17456800E+00, 0.25217800E+00, -.26025600E-01, 0.12722100E+00, -.47147900E+00, -.24801400E+00, -.57938000E+00, 0.22375500E+00, 0.53305900E+00, -.86378400E-01, 0.12707400E+00, 0.27532600E+00, 0.27957100E+00, -.90130300E+00, 0.17299100E+00, 0.30552100E-02, -.45317300E+00, 0.13764300E-01, -.11848800E+00, 0.50657800E+00, 0.10469200E+00, -.27864600E+00, 0.10209600E+03, -.11612300E+03, -.36257000E+02, -.10306700E+03, 0.62846600E+02, 0.20785700E+02, 0.38062400E+02, -.17178900E+02, -.87982600E+01, -.19031000E+02, -.34344100E+01, 0.31115000E+01, 0.19627200E+02, 0.16777500E+02, 0.12767500E+02, 0.24855000E+01, -.20622100E+02, -.16490600E+04, 0.82851100E+03, 0.93250200E+03, 0.82454400E+03, 0.17383200E+03, 0.27606600E+03, 0.29828100E+03, -.37350900E+03, 0.40218800E+03, 0.25587300E+03, 0.60191200E+03, -.36225800E+03, 0.17837400E+03, 0.11886300E+03, 0.18076700E+03, 0.45793700E+02, 0.25155400E+02, 0.11573900E+03, -.34516700E+02, -.21498700E+02, 0.30524800E+01, 0.21755400E+03, -.19258200E+04, 0.97010200E+03, 0.77442200E+03, 0.96296300E+03, 0.11627500E+03, 0.26568600E+03, 0.33120600E+03, -.44349200E+03, 0.51694800E+03, 0.26406100E+03, 0.77610200E+03, 0.86763700E+02, -.44659800E+02, -.95187600E+02, -.45760100E+02, -.10876700E+03, -.97745900E+02, 0.19774900E+03, -.63578900E+01, 0.10198300E+03, -.10232600E+03, 0.38186000E+02, -.23182000E+00, -.45612400E+00, -.24874900E+01, 0.10961600E+00, -.48080800E+00, -.11761800E+01, -.22455600E+00, -.43641600E+01, -.44514000E+00, -.27692800E+00, 0.31544900E+00, 0.25304200E+03, -.13648500E+03, -.11861500E+03, -.12717900E+03, -.19911400E+02, 0.26726400E+01, -.43914300E+02, 0.67039200E+02, -.77908700E+02, -.58588700E+01, -.84815800E+02, -.17430800E+03, 0.97275500E+02, 0.72141200E+01, 0.87170900E+02, -.15475700E+02, -.13078400E+03, 0.32568300E+02, -.74674600E+02, 0.26353100E+03, -.77495000E+02, 0.90449500E+02, -.60207900E+03, 0.29740300E+03, 0.35303100E+03, 0.30100300E+03, -.57702900E+01, 0.11245900E+03, 0.90304400E+02, -.20789000E+03, -.16184300E+03, 0.65733200E+02, 0.18123700E+03, 0.65076000E+00, 0.26573300E+02, 0.16742700E+02, 0.37705600E+00, 0.92236000E+01, -.80027100E+01, 0.10059200E+02, 0.18704700E+02, -.77331200E+00, -.58438100E+00, -.28313000E+01, -.10633200E+02, 0.58765600E+01, -.30121900E+01, -.47963600E+01, -.11551400E+01, -.11013300E+02, 0.56763700E+01, -.62876700E+02, -.17332600E+02, 0.34241500E+02, -.11195300E+02, -.73902600E+00, 0.89204200E+01, -.32868700E+02, -.42630500E+02 },
        { -.18394700E+00, -.65966100E+00, 0.60050100E+00, -.62882800E+00, 0.51738700E+00, -.13009700E+00, -.54481200E-01, -.11719100E+01, -.44078600E+00, -.82452900E-02, 0.18416800E+00, 0.62328300E+00, -.28532000E+00, 0.74095300E-01, 0.61999500E+00, -.47616300E+00, -.12872800E+00, 0.45746800E-01, 0.10659000E+01, 0.14174300E+00, 0.12596800E+00, 0.35323200E+00, -.32855700E+00, 0.39922300E+00, 0.71823500E+00, 0.60520400E+00, -.62853900E-01, -.17713500E+00, -.15254000E+00, 0.18507200E-01, -.21582400E+00, -.61245200E-03, 0.14816900E+00, -.26280400E+00, -.11503300E+00, 0.10728200E+00, -.67628200E-02, -.10164300E+00, -.69211500E-01, 0.14040000E+00, 0.23172600E+00, 0.10974400E+01, 0.64459100E+00, -.64786900E-01, -.13326700E+00, 0.13418700E+00, 0.15177900E+00, -.23984500E-01, -.13365600E+00, -.13482100E+00, 0.83912000E-01, -.19138600E-01, -.51349400E+00, 0.24954500E+01, 0.42151500E+00, 0.23448200E+00, 0.12704500E+00, -.33535100E+00, 0.11268800E+00, 0.89648800E+00, 0.71052100E-01, 0.12132600E+00, -.22815800E+00, 0.16929500E+00, 0.59334600E-01, -.19821700E+00, -.10890200E+00, -.19082800E+00, 0.20742100E+00, 0.10078700E-02, 0.49271900E+00, 0.68038500E+00, -.14650500E+00, -.53937100E-01, -.17252600E+00, 0.12451900E-02, 0.19641300E+00, -.44422200E+00, 0.78475400E-01, -.25011500E-01, -.11453800E-01, -.16678100E-01, 0.20498800E+00, 0.85328000E-01, 0.35426100E-01, 0.81676700E-01, -.32504600E+00, -.51890600E+00, -.50396600E+00, 0.77369500E-01, -.27820800E-01, -.79439500E-01, -.20179800E-01, 0.24126200E+00, 0.20126700E+00, 0.59885700E+00, 0.28282300E+00, -.33513000E+00, 0.35516700E+00, 0.17801300E+00, -.21948600E+00, -.18802000E-01, -.47498400E-02, 0.11168900E+00, -.14246500E-01, -.39908100E+00, -.24788400E+00, 0.23209500E+00, -.28254700E-01, 0.56441200E+00, 0.51443100E+00, 0.24908000E+00, 0.21772900E+00, -.18608600E-01, -.81379000E-02, -.95227300E-01, -.53312500E-01, -.10716400E+01, 0.12175600E+00, -.10747100E-01, 0.14107000E+00, -.22962300E+00, -.55158400E-01, -.11549100E+00, 0.12975900E-01, -.12604700E+00, -.64604700E+00, -.62131400E-01, -.60192400E-01, 0.60513300E-02, 0.53241900E-01, -.16033500E+00, 0.36817100E-01, 0.95890200E-01, 0.12629500E+00, 0.78813100E-02, 0.88522800E-01, -.70821900E-01, -.76496700E-01, -.26438100E+00, 0.10311800E+00, 0.35349600E+00, 0.95863400E-01, -.27398300E+00, -.15434500E+00, 0.84707600E-01, -.80642400E-01, 0.15393300E+00, 0.95705800E-01, -.14962700E-01, 0.46900000E+00, -.35893000E+00, 0.11677000E+00, 0.82043800E+00, -.15926000E+00, 0.14235500E-01, -.98183700E-01, 0.73131500E-01, -.21617100E+00, 0.14335900E+00, -.29909100E+00, -.29607700E+00, -.12220400E+00, -.22370500E-01, 0.23937000E+00, 0.57386800E+00, 0.12910600E+00, 0.79663000E-01, -.36262400E-02, 0.27693600E+00, 0.11136800E+00, 0.29118500E+02, -.41810600E+01, -.75338000E+01, 0.79556000E+01, -.17128300E+02, -.15088100E+02, 0.70456000E+01, 0.30319500E+01, 0.75389100E+01, 0.44870200E+01, 0.54161900E+01, -.99373000E+01, -.75009700E+01, -.47652100E+01, 0.58660700E+01, 0.46025600E+01, 0.28157200E+03, -.14158500E+03, -.25311700E+03, -.14078200E+03, -.17035400E+01, -.71569300E+01, -.14807800E+03, 0.11598700E+03, -.31336700E+02, -.83302200E+01, -.18550900E+03, 0.89357100E+02, -.43735600E+02, -.28845200E+02, -.44646000E+02, 0.12182500E+02, 0.25890200E+02, -.45870400E+02, 0.18915800E+02, -.84978000E+01, 0.33985200E+02, -.70996500E+02, 0.43505800E+03, -.21908600E+03, -.77879600E+02, -.21751800E+03, 0.16031800E+02, 0.21925600E+02, -.17618300E+03, 0.12847900E+03, -.11648600E+03, 0.15522400E+02, -.28733700E+03, 0.68687600E+02, -.33958800E+02, 0.33695200E+02, -.34121200E+02, -.18441700E+02, 0.37611800E+01, -.46591500E+02, 0.47291700E+02, -.13305100E+02, -.50726800E+00, -.37626300E+02, 0.77145900E+00, -.25117800E+00, 0.61187000E+00, -.38812300E+00, 0.75197100E-02, 0.32872200E+00, -.31643100E+00, -.60046500E-01, -.80037400E-01, 0.28420800E+00, -.30988100E+00, -.11040500E+03, 0.56711600E+02, 0.55453900E+02, 0.55160600E+02, 0.19526500E+02, 0.19789900E+02, 0.13200000E+02, -.32048400E+02, 0.32923100E+00, 0.21517000E+02, 0.70123100E+01, 0.13768100E+03, -.70929600E+02, -.49816800E+02, -.68836300E+02, 0.32554700E+02, 0.56199500E+02, -.63038400E+02, 0.30560100E+01, -.10567100E+03, 0.48604800E+02, -.22254800E+02, 0.17048900E+03, -.84162200E+02, -.12816000E+03, -.85253700E+02, -.59815400E+02, -.50738500E+02, 0.54705800E+02, 0.13093200E+03, 0.60603800E+02, -.47739300E+02, -.12488100E+03, -.10511600E+00, -.74395500E+01, 0.11000800E+01, 0.58533200E+00, 0.28345100E+01, -.21461000E+00, 0.23987900E+01, -.37230900E+01, 0.61661600E-01, 0.73544900E+00, -.30289400E+00, -.55848800E+00, -.13938800E+01, -.63552300E+00, -.80365100E+00, -.25229000E+00, -.43099100E+01, 0.25359300E+00, 0.90714400E+01, 0.20946100E+01, -.70254500E+01, 0.28281900E+01, -.59447200E-01, -.33788300E+00, 0.76213700E+01, 0.94085900E+01 },
        { -.69350500E+00, -.44461600E+01, 0.10732400E+01, -.27178500E+00, 0.22642100E+01, 0.12956100E+01, 0.27961300E+01, -.18949100E+01, -.51994200E+00, 0.57053200E+00, 0.48738500E+00, -.15756900E+01, -.18443900E+00, -.91656300E+00, -.19308900E+01, -.50873700E+00, -.94503600E+00, 0.35449900E+00, 0.73080600E+00, -.14888600E+00, 0.65433700E+00, -.18115400E+01, 0.15434900E+00, -.60455700E+01, -.14117500E+01, -.21167000E+00, -.21205700E+01, 0.73683500E-01, -.27160100E+00, 0.15932300E+01, -.34293900E+00, 0.14437500E+01, 0.67674100E+00, -.41212600E+00, -.30558300E-02, 0.73025300E-01, -.28090700E-01, -.75841500E+00, -.51165800E+00, -.46498900E+00, -.10014500E+01, -.30260100E+00, 0.11670700E+01, 0.46548100E+00, -.17747700E+01, -.22759900E+00, -.44304000E+00, -.72911500E-01, -.59478900E+00, 0.12136500E+00, -.20796400E+01, 0.23646600E+01, 0.12538900E+01, -.38761800E+00, -.56717600E+00, 0.59103100E+00, -.21957600E+01, 0.83391400E+00, -.35641300E+00, -.12951000E+01, 0.10590700E+01, -.44434500E+00, 0.40995400E+00, -.54244100E+00, -.20350700E+00, 0.21605600E+00, 0.88370500E-01, 0.21381400E+01, -.59131900E+00, 0.97874200E-02, -.40577000E+00, 0.73742200E-01, 0.34705700E+00, 0.96560800E-01, -.62393100E+00, 0.67744800E+00, -.34945400E+00, -.31836200E+00, -.62494500E+00, -.45563600E+00, 0.12642900E-01, 0.67976300E-01, -.46233400E+00, 0.34235000E+00, 0.11271600E+00, 0.30051300E-02, -.60441100E+00, 0.33520700E+00, 0.42165100E+00, -.56012400E-01, -.16276100E+01, 0.53920500E-02, -.95159700E-01, -.10585100E+01, -.86269800E+00, -.98291800E+00, -.15689400E+00, -.10551800E+00, 0.99615500E+00, 0.51446000E+00, -.34182300E+01, -.34003000E-01, -.26014700E-01, 0.62189100E+00, 0.32599300E+00, 0.10359500E+01, 0.42479400E+00, -.36982300E+00, 0.13492400E+01, -.31286500E+00, 0.40161100E+00, 0.18132700E+00, 0.45720100E+00, 0.20148800E-01, 0.16479800E-01, -.42495100E+00, -.13118800E+00, 0.34324000E+01, 0.91826500E+00, -.40335300E-01, 0.83609600E+00, 0.32247800E+00, -.32040900E-01, -.11677900E+01, -.39472300E-01, -.11127500E+01, -.78594800E+00, -.48728500E-01, -.14027500E+00, -.95038300E-01, -.10047300E+00, -.12049100E+00, -.13541900E-03, 0.63030700E+00, 0.24189200E-02, 0.28587400E-01, -.27992500E+00, -.30489200E+00, -.32549500E+00, 0.90888100E+00, -.14101800E+00, 0.52226200E+00, -.26608500E-01, 0.21059600E+01, 0.29322700E+01, 0.11062000E+00, -.19513400E+00, 0.14305300E+01, 0.88820600E+00, -.52340300E+00, 0.43913700E+00, -.20764600E+00, 0.12391800E+01, -.16288500E+00, 0.21499100E+01, -.53025000E+00, 0.15253000E+01, 0.21252000E+00, 0.53185400E+00, -.47658500E+00, -.59572500E+00, -.20380200E+01, -.33304000E+00, -.64825900E-01, 0.11374400E+00, 0.13518500E+01, -.39544800E+00, -.31886700E+00, -.16141700E+00, 0.17867900E+00, -.68914900E+00, 0.53683600E+00, 0.12245600E+03, 0.77370800E+02, 0.27607600E+01, 0.41950500E+02, 0.52570200E+02, -.24584300E+02, -.18999400E+02, -.26276400E+02, -.24053300E+02, -.13328600E+02, 0.32006700E+02, 0.32796200E+02, 0.28593300E+02, -.20174200E+02, -.57048100E+02, -.28562000E+04, 0.14310400E+04, 0.15438300E+04, 0.14280800E+04, 0.15306600E+03, 0.26473000E+03, 0.69563700E+03, -.67056300E+03, 0.10033000E+04, 0.96466100E+02, 0.21676400E+03, -.58194800E+02, 0.26710600E+02, 0.10237800E+02, 0.29422900E+02, -.21013800E+02, -.30479700E+02, 0.78297000E+01, -.20468700E+02, 0.27362700E+02, -.76213900E+02, 0.72676700E+02, -.26528400E+04, 0.13310400E+04, 0.11174500E+04, 0.13263600E+04, -.44269100E+02, 0.87644800E+01, 0.72698400E+03, -.53047400E+03, 0.11970700E+04, -.13441300E+03, 0.12451900E+03, -.83209300E+02, 0.37858500E+02, -.76110000E+02, 0.43560600E+02, -.21183400E+02, -.57211900E+02, 0.12343400E+03, 0.86525400E+01, 0.92060000E+02, -.87548300E+02, 0.91059900E+02, -.26295800E+01, 0.12012100E+01, -.20381800E+01, 0.13252500E+01, 0.10432900E+01, -.36907900E+00, -.10297000E+01, -.32402400E+01, -.80012000E+00, 0.18439400E+00, 0.17024100E+01, -.89548800E+02, 0.54269600E+02, 0.84459500E+02, 0.45546900E+02, 0.23765200E+02, 0.69931500E+02, 0.13301500E+02, 0.87895300E+02, 0.39542600E+02, 0.68533900E+02, 0.87538400E+02, 0.22363300E+02, -.66352000E+01, -.34632500E+02, -.11204200E+02, 0.63544300E+02, -.13615400E+03, 0.13650700E+03, 0.21643500E+03, 0.24841100E+03, -.18992000E+03, -.22034600E+03, -.81523000E+03, 0.40540700E+03, 0.44336000E+03, 0.40766300E+03, -.37732800E+02, 0.20341800E+03, -.13511700E+03, -.52753500E+03, -.19888900E+03, 0.23771600E+03, 0.50481200E+03, 0.18250200E+01, -.17597400E+01, -.10292400E+02, -.57354000E+00, -.48391000E+01, -.15184900E+01, -.18108200E+01, -.15221800E+02, -.65122000E+00, -.10945200E+01, 0.41089500E+01, -.51578700E+01, 0.92230200E+00, -.42890500E+01, 0.55462200E+01, 0.63829000E+00, 0.78250000E+01, -.17603900E+01, -.21785600E+03, -.11681000E+02, 0.18777200E+03, -.14058200E+01, -.51422900E+00, -.84284000E+01, -.13712700E+02, -.14742000E+02 },
        { -.97464000E-01, -.25409700E+00, 0.47996900E+00, -.12864700E+00, 0.30983100E+00, 0.14879800E+00, 0.53442200E+00, -.39170900E+00, -.22009300E+00, 0.29252200E+00, 0.12552300E+00, -.30281200E+00, -.39921400E-01, -.38787700E+00, -.24729600E+00, 0.75087500E-01, -.48147000E+00, 0.89388500E-02, 0.35524400E+00, 0.16251400E+00, -.34792600E+00, 0.62049600E+00, -.24978300E-01, -.22909200E+00, 0.11402700E+00, 0.15265100E-01, -.23745400E-01, -.60485000E+00, -.72595700E-01, 0.92023000E-01, -.28400100E+00, 0.10320400E-01, 0.49799500E+00, -.29726600E+00, 0.34005000E+00, 0.19683100E+00, 0.10162900E-02, 0.70243100E+00, -.30883200E-01, -.10172700E+00, 0.94952600E-01, 0.36251000E+00, -.23605200E+00, -.10736400E+00, 0.10070100E-01, 0.42168000E-01, 0.15852900E+00, 0.18564500E-01, 0.13544800E+00, -.19310900E+00, -.17266800E-01, -.20919700E+00, -.29671900E-01, -.20172100E-01, -.12158700E+00, -.21784300E+00, 0.48586100E-01, 0.85424700E-02, -.23916400E-03, -.19896600E+00, -.86314400E-01, 0.28312700E-01, -.78741000E-02, 0.95156100E-01, -.77626200E-01, 0.15464800E-01, -.16398900E+00, -.14704900E+00, 0.24203800E+00, -.12492200E-02, -.36006700E-01, -.78552200E+00, -.74166200E-02, 0.24539400E-01, 0.94725300E-01, -.19302400E+00, -.71394500E-01, 0.79436000E-01, -.16614400E+00, 0.16153400E+00, 0.69076900E-02, -.56968800E-01, 0.19331200E+00, 0.20874500E-01, 0.78165600E-01, -.15757800E+00, -.12345100E+00, 0.77450100E-01, -.62678600E-01, -.16505000E-01, 0.15818700E+00, 0.10846900E-01, 0.15657600E+00, -.64587700E+00, -.76386900E-01, 0.12331600E+00, -.14194900E+00, 0.18334800E+00, -.36568600E+00, -.18722600E+00, 0.30772100E+00, -.15052100E+00, 0.62502700E-02, -.17023700E+00, -.50681100E-01, -.38459000E-01, -.90345800E-01, -.29279100E+00, 0.12225300E-01, -.27052500E+00, 0.30641600E+00, -.11103900E+00, 0.86325400E-02, -.21043400E-02, -.99111000E-02, -.26790900E+00, 0.14506000E+00, 0.12242300E+01, 0.27009100E+00, -.37118400E-01, 0.10180100E+00, 0.45333000E+00, -.40771200E-01, 0.81785500E-01, 0.35611600E-01, -.39705900E+00, 0.12833400E+00, -.86368800E-01, 0.11151500E-01, 0.43940100E-01, 0.18893600E-01, 0.18713200E+00, -.44702500E-01, -.32423900E-01, -.75443200E-01, -.91215400E-02, -.73474700E-01, 0.18771300E-01, 0.53145100E-01, -.38090500E+00, 0.69323000E-01, 0.78258000E+00, 0.18925700E+00, 0.21342500E+00, -.16019400E+00, -.74559600E-01, -.48916300E-01, 0.30179800E+00, -.26513500E-01, -.54902900E-02, -.21413700E-01, 0.17331100E-01, -.23713500E-01, 0.36272600E+00, 0.84606400E-01, -.17579900E-02, 0.17930400E-01, 0.19380500E-01, -.30886100E-01, -.25838000E+00, 0.73129600E-01, -.37646600E+00, -.74969400E-01, 0.72899700E-01, -.12982000E+00, -.44525600E+00, -.44267900E-01, -.18955900E+00, -.43853900E-01, 0.36577400E-01, -.38796600E-01, -.35699800E+00, 0.43383400E-01, 0.16818600E+02, -.76925000E+01, 0.15153500E+02, -.82495900E+01, 0.37477500E+01, 0.13868000E+01, 0.41227300E+01, 0.19744200E+01, -.35363300E+01, -.28513500E+00, -.11762700E+01, 0.21281300E+01, -.26625800E+01, 0.19815500E+02, 0.50624300E+03, -.25405500E+03, -.22815800E+03, -.25312500E+03, -.38523400E+02, -.14046800E+03, -.13586500E+02, 0.11600400E+03, -.13696000E+03, -.12812900E+03, 0.45532400E+02, 0.19867000E+02, -.94231600E+01, -.14042700E+02, -.97838900E+01, -.79733500E+01, -.49739400E+02, 0.28908500E+02, 0.27314700E+02, 0.35746100E+02, -.51327500E+02, -.11902000E+02, 0.50072500E+03, -.25189200E+03, -.25499800E+03, -.25037800E+03, -.36335400E+02, -.85497200E+02, -.37599900E+02, 0.11505300E+03, -.16014600E+03, -.82893500E+02, 0.76294100E+02, -.32438300E+02, 0.16381800E+02, 0.15463600E+02, 0.16793200E+02, 0.82237200E+01, 0.15632000E+02, -.14245600E+02, -.68934900E+01, -.24407800E+02, 0.16408200E+02, 0.17330900E+02, -.12969000E+00, 0.12532000E+00, 0.18253200E+00, 0.66337600E-01, 0.21659700E+00, 0.17688700E+00, -.64295100E+00, 0.69017400E+00, 0.46209700E+00, -.53263100E-01, -.28223200E+00, 0.30240700E+02, -.14881400E+02, -.52071500E+01, -.14891800E+02, -.10698000E+02, -.15538700E+02, -.23149600E+01, 0.76481500E+01, 0.10326600E+02, -.16403200E+02, 0.10752900E+02, -.97636100E+02, 0.47091100E+02, 0.64146700E+02, 0.48813200E+02, -.82104700E+01, 0.16243900E+02, -.11323000E+02, -.27381100E+02, -.21674500E+02, 0.18334500E+02, 0.10386400E+03, 0.55849700E+02, -.27545800E+02, -.19214300E+02, -.27914000E+02, 0.57324200E+02, -.48465000E+01, -.26469600E+02, 0.88124400E+01, 0.41313900E+02, -.47594900E+01, -.62010200E+02, -.57535300E+00, 0.76535200E+01, -.79630200E+00, -.15428100E+01, 0.18184900E+01, 0.10025900E+01, 0.46504700E+01, 0.83853900E+01, 0.11694400E-01, -.71863800E+00, -.31339800E+00, 0.11608300E+01, -.12353000E+01, -.95297400E+00, -.21849900E+01, -.21149200E+00, 0.29575200E+01, -.27496700E+01, 0.14469300E+02, -.29661500E+01, -.14660200E+02, -.21200800E+01, 0.34372700E-01, 0.94310100E+00, 0.51044000E+01, 0.40402500E+01 },
        { 0.10069800E+01, -.14709300E+01, -.68658800E+00, 0.94223900E+00, 0.10400900E+01, 0.22709600E+00, 0.38765200E+00, -.20985600E+01, -.42483600E-01, 0.16008500E+01, 0.30586800E+00, 0.11800700E+01, -.16882500E+01, 0.25671300E+00, 0.13429500E+01, 0.44116000E+00, 0.95732900E+00, 0.52923600E-01, -.74942900E+00, 0.10766300E+01, -.28569000E+00, -.37549100E+01, -.45014600E+00, 0.72187200E+00, 0.31754900E+00, 0.30689100E+00, 0.18746700E+00, -.13332600E+01, -.12430000E+00, 0.14294200E+00, -.80309200E+00, -.27495600E+00, 0.25667200E+01, -.17228400E-01, 0.34225000E+00, 0.46145700E+00, 0.36695500E-01, 0.13081300E+01, 0.53400200E+00, -.93491300E+00, -.79201000E+00, -.39973500E+01, 0.22373400E+00, 0.68318400E+00, 0.13518100E+01, 0.43257300E+00, 0.19430400E+01, 0.71256700E-01, -.30209300E-01, 0.15078600E+00, -.15484100E+01, 0.25562000E+01, 0.11134300E+01, -.21667000E+01, -.96979300E+00, 0.81192000E+00, -.15211500E+01, 0.73085400E+00, -.48217900E+00, -.21394700E+01, 0.10493400E+01, -.49822600E+00, 0.90032900E+00, -.27616300E+00, -.49466500E+00, -.84171600E+00, -.31082700E+00, -.20676800E+00, 0.15189200E+01, 0.13497900E-02, 0.15702200E+01, -.14575100E+00, -.19842700E+00, -.15798000E-02, -.71018300E+00, -.11292500E+01, 0.23434200E+00, 0.60291800E+00, 0.45225600E-01, 0.11806800E+01, 0.20610200E-02, 0.17165700E+00, -.10212300E+01, 0.10334600E+00, 0.55710600E+00, 0.86076900E-01, 0.89080600E+00, 0.16228600E+01, -.52258000E+00, -.97348000E+00, 0.22643100E+01, 0.43219700E+00, -.26156000E+01, 0.42173000E+00, 0.20141500E+01, 0.71712600E+01, -.12080600E+01, 0.67712400E-01, 0.92035500E+00, 0.83393100E+00, -.61061800E+01, -.69153000E+00, 0.55166600E-02, 0.25153900E+01, 0.15441000E+01, 0.17867300E+01, -.20210400E+00, 0.88481000E+00, -.24604900E+01, 0.17672600E+01, 0.30449100E+01, -.44581600E+00, 0.11352700E+01, 0.39683700E-01, 0.19789200E+00, 0.13523000E+01, 0.48191000E+00, -.25712100E+01, -.13847300E+01, 0.34121500E+00, -.33692000E+00, 0.64951200E+00, 0.31883500E+00, 0.20921500E+01, -.15040000E+00, -.15852300E+01, 0.93640200E+00, 0.68368000E+00, -.66715100E-01, -.63665100E+00, 0.14291100E+00, 0.21017000E+01, 0.50427000E-01, -.19384000E+00, 0.38111200E+00, 0.25187500E-01, 0.26262100E+00, 0.68517700E+00, 0.21730600E+00, 0.96272800E+00, 0.42166900E+00, -.13091500E+01, -.18532000E+00, -.24823200E+00, 0.36760700E+00, 0.68222100E-01, -.27160100E+00, 0.83736700E+00, 0.35797400E-01, 0.50720700E+00, -.17443400E+00, -.20202500E+00, 0.16143000E+01, 0.22966200E+01, 0.96442100E+00, -.17737200E+00, 0.23547900E+01, -.40857400E-01, -.13250500E+00, -.14724500E+01, -.13569900E+01, -.13844900E+01, -.64025500E+00, 0.37189800E+00, -.36769000E+00, 0.17686600E+00, 0.11907600E+00, -.50613400E+00, -.46280600E-01, 0.76722300E+00, -.81623500E+00, -.76882400E+00, 0.65077600E+00, -.12901700E+01, -.64469300E+02, 0.11482000E+02, 0.36809600E+01, -.35178500E+01, -.16761500E+02, -.18398300E+01, 0.16590600E+02, 0.20185300E+02, -.44410300E+02, -.26477300E+02, -.54285200E+02, 0.30556200E+02, 0.52212300E+01, 0.28524200E+04, -.14304200E+04, -.11407900E+04, -.14262000E+04, -.39914100E+03, -.19024000E+03, -.70886100E+03, 0.39308900E+03, -.10454600E+04, -.10862000E+03, -.66308500E+03, -.14044900E+03, 0.73405300E+02, -.24354000E+02, 0.69837400E+02, -.29793700E+02, -.17419600E+03, 0.10078700E+03, -.41247400E+01, 0.78080400E+02, -.15568400E+03, 0.79816800E+02, 0.21873500E+04, -.10989400E+04, -.13570500E+04, -.10936400E+04, -.20480700E+03, -.68803900E+02, -.69846100E+03, 0.22415000E+03, -.10252200E+04, 0.50584600E+02, -.37525800E+03, 0.37482000E+02, -.18625400E+02, 0.27018300E+02, -.20451500E+02, -.37237900E+02, 0.44861200E+02, -.75696200E+02, -.74381400E+01, -.13613000E+03, 0.88169400E+02, -.26879700E+02, -.65801100E+00, 0.32194400E+00, -.21001100E+01, 0.32299300E+00, -.54445400E+00, 0.54329500E-01, -.29881800E+01, 0.33774500E+01, 0.51551000E+00, 0.49010900E+00, -.30573400E+00, -.38431100E+03, 0.17738500E+03, 0.16185600E+03, 0.19147900E+03, -.31350900E+02, -.41681600E+02, 0.14262000E+03, 0.42330300E+02, 0.88088800E+02, -.53862300E+02, 0.14647800E+03, -.78531700E+03, 0.38628700E+03, 0.25947000E+03, 0.39267200E+03, -.11864200E+01, 0.65370600E+02, 0.10760300E+02, -.81313900E+02, 0.35019300E+02, 0.66536700E+02, 0.25981300E+03, 0.12022600E+04, -.59988800E+03, -.46408100E+03, -.60115700E+03, 0.26725500E+02, -.96037700E+02, -.21200100E+03, 0.20167800E+03, -.17917100E+03, -.93523600E+02, -.32484900E+03, 0.96022000E+00, 0.35651900E+02, 0.43115500E+01, -.54370800E+01, 0.19891300E+02, -.20142100E+00, 0.13195600E+01, 0.37929600E+02, 0.11782100E+00, -.68435500E+01, -.61593100E+01, 0.26205600E+01, -.44257500E+01, -.33910100E+01, -.24428600E+02, 0.25779700E+01, 0.52059600E+01, 0.15628200E+02, 0.23072100E+03, -.19222500E-01, -.21720200E+03, -.65161700E+01, 0.23734700E+00, -.14327700E+02, 0.16753700E+02, 0.53858400E+01 },
        { 0.19374200E+00, -.42248700E+00, 0.10203100E+01, 0.11220200E+00, -.10430800E+01, -.34648100E+00, -.13868500E+01, 0.12910000E+01, 0.25218800E-01, -.10551200E+01, -.12271200E-01, 0.59616500E+00, -.27916800E-01, 0.33202400E+00, 0.67113900E-01, 0.36483300E+00, -.58480100E+00, -.14158000E+00, -.13751200E+00, -.45962500E-01, -.39991500E+00, 0.25521500E+01, 0.83373000E-01, -.85948000E+00, -.15567000E-01, -.21004200E-01, -.19873000E-01, 0.18692800E+00, 0.90174100E-01, 0.97690200E-01, 0.50147400E-01, 0.94183100E-01, 0.20825000E-01, -.11109400E+00, -.78915400E-01, 0.20478100E-01, -.42564700E-02, -.10968800E+00, -.20196300E+00, 0.14637000E+00, 0.36512100E-01, 0.10808300E+01, 0.12081700E+01, 0.28505300E+00, -.78381900E+00, -.26656700E-01, 0.31046400E-01, -.90728600E-02, -.29505500E-01, 0.22717000E+00, 0.11973200E+00, -.37608600E+00, 0.82140600E-01, 0.27131700E+01, 0.18174200E-01, -.35291700E-01, -.69708100E-01, 0.77459900E-01, -.16840800E-01, 0.12691700E+00, -.95979300E-01, -.37479400E-01, -.12962000E+00, 0.60201300E-01, 0.11162600E+00, 0.31969000E-01, 0.15032800E+00, 0.37886600E+00, -.23681000E+00, 0.25339500E-02, 0.15800700E+00, 0.44379700E+00, -.10890300E+00, -.48013600E-01, 0.96849300E-01, -.33873300E+00, -.23083000E+00, 0.50638400E+00, -.11043100E+00, -.16816000E-01, 0.12176000E-01, -.10003300E+00, 0.10260600E+00, -.26283900E-02, 0.35166700E-02, -.30963300E-01, 0.24295400E+00, -.44978400E-01, 0.46111000E+00, 0.56526800E-01, -.45196100E+00, 0.32157000E-01, 0.51830000E+00, -.10526600E+01, -.27678300E+00, 0.44011100E+00, 0.51333100E+00, -.19312400E+00, -.39639000E+00, -.34663900E-01, 0.11644100E+01, -.46012800E-01, -.18479000E-01, 0.27845500E+00, 0.76566700E-01, 0.22182600E+00, -.60729900E-01, -.72517000E+00, 0.99901900E+00, 0.28227900E+00, 0.10768400E+01, 0.96471100E+00, 0.13892400E+00, -.80291000E-01, 0.24961100E+00, 0.24077800E-01, 0.43233100E-01, -.17174100E+01, 0.25210700E+00, -.14479000E+00, 0.21110800E+00, 0.15996400E+00, 0.48057600E-01, 0.48528600E+00, 0.11334600E+00, 0.42943100E+00, 0.56020400E+00, 0.55169500E+00, 0.76693000E-01, -.31544400E-01, 0.38167700E+00, -.38257500E+00, 0.52624000E-01, 0.25067600E-02, -.72632000E-01, 0.40872900E-02, -.54726700E+00, 0.14360700E+00, 0.16126500E+00, 0.21676000E+00, -.17273300E+00, -.12651800E+01, -.24348900E+00, -.27647600E+00, -.33551000E+00, -.14250000E-01, 0.15797200E-01, -.52122600E-01, -.42118300E+00, 0.42131600E+00, 0.28686400E+00, -.28608000E+00, 0.21104000E+00, 0.33463700E+00, -.35396900E+00, -.37616100E-01, -.57075900E+00, 0.15035500E-01, -.69983400E-01, -.39039500E-02, 0.43809200E+00, 0.43184900E+00, 0.12751800E+00, 0.38022600E-01, -.12864300E-01, -.37816600E+00, -.75160700E-01, 0.85142700E-01, 0.45868900E-02, -.74964300E-01, 0.17404100E+00, -.20324200E+00, -.12397900E+00, 0.18398700E+00, -.77936300E-01, -.20492500E+02, -.43825000E+01, 0.22667600E+01, 0.13012600E+01, 0.21862500E+01, 0.17784700E+01, 0.11889500E+01, -.27218700E+01, -.14924800E+01, 0.25973500E+01, 0.27161600E+01, 0.10314900E+02, 0.35815000E+03, -.17913100E+03, -.10288900E+03, -.17907300E+03, -.87585500E+02, -.98773500E+02, -.67546900E+02, 0.12762000E+03, 0.39503800E+02, -.11116300E+03, -.62324500E+02, 0.27920000E+02, -.14492200E+02, -.35117300E+02, -.13865800E+02, -.17439500E+01, -.84783200E+01, -.28546600E+02, -.11088500E+02, -.10425600E+02, -.80164700E+01, -.94182600E+01, 0.26987700E+03, -.13523200E+03, -.20722500E+03, -.13493500E+03, -.89346200E+02, -.10413000E+03, -.45590300E+02, 0.10912400E+03, 0.67603300E+02, -.11627500E+03, 0.41230000E+01, -.68862800E+02, 0.35005900E+02, 0.25256600E+01, 0.34783700E+02, 0.25486400E+02, 0.13152300E+02, -.21865400E+02, -.27934600E+01, -.14738600E+02, 0.10987600E+02, 0.51256200E+02, -.42131900E+00, 0.27072900E+00, -.52224700E+00, 0.20939600E+00, 0.12355200E+00, -.17877900E+00, 0.11603200E+01, 0.22611900E+00, 0.12000100E+01, -.28701900E+00, -.11408300E+00, -.24991900E+01, 0.30374400E+01, 0.73505100E+00, 0.13183900E+01, 0.74410200E+01, 0.38265900E+01, -.22381400E+02, -.30250400E+02, -.10963900E+02, 0.39883700E+01, 0.13982400E+02, -.18576400E+03, 0.93111000E+02, 0.50006400E+02, 0.92883600E+02, -.94927500E+00, 0.32294500E+02, 0.90428000E+01, -.44135300E+02, -.10581700E+02, 0.40452200E+02, 0.92289600E+02, 0.48436800E+02, -.24330200E+02, 0.13867500E+02, -.24221600E+02, 0.57622300E+02, 0.18839400E+02, -.28791400E+02, 0.15348100E+02, 0.29033100E+02, 0.12361800E+02, -.29765900E+02, 0.31368600E+00, 0.47993300E+01, -.13622200E+01, -.52568600E+00, -.17952900E+01, -.64312100E+00, 0.16002700E+01, 0.46777400E+01, -.55359600E+00, -.21845400E+01, -.28889000E+00, 0.21467200E+01, -.28916900E+01, 0.13470000E+01, 0.21267500E+01, 0.70023400E-01, -.43445900E+00, -.98539200E+00, -.28707400E+02, -.18544200E+01, 0.15724700E+02, 0.22727200E+01, -.38822400E+00, 0.11088900E+01, 0.30113700E+01, 0.40446900E+01 },
        { 0.72877400E+00, -.36889700E+01, 0.11415800E+02, 0.57369700E+00, -.33737600E+01, -.41806300E+00, -.30728700E+01, -.16273900E+01, 0.34664000E+00, 0.29385600E+00, 0.50387600E+00, 0.38026300E+01, -.19815500E+01, -.75888300E+00, 0.24708600E+01, 0.78890900E+00, 0.29709800E+01, -.54911300E+00, 0.11239100E+00, 0.80370000E-01, 0.69575900E+00, -.30301300E+01, -.99915800E+00, 0.15081500E+01, 0.19480400E+01, 0.13999400E+01, 0.76115700E+00, 0.18971700E+00, -.28706700E+00, -.62927400E+00, -.16001500E+00, 0.14873000E+00, 0.18135300E+01, -.46027700E+00, -.44899100E+00, -.72238900E+00, 0.50653400E-01, -.79787100E+00, -.22671300E+00, -.45906300E+00, 0.92131000E+00, 0.30566800E+01, 0.24364100E+01, 0.20281800E+00, 0.46904900E+00, 0.15292000E+00, -.42901500E+00, 0.76906400E-02, -.37055000E+00, -.37312100E+00, -.52716700E+00, -.79199900E+00, -.17879000E+00, -.64623200E+00, 0.17796900E+01, -.22802700E+01, -.26862100E+00, -.26702100E+00, 0.12520100E+00, -.29718700E+00, -.23841100E-02, 0.87109300E+00, -.30316000E+00, -.24640400E+00, -.82941300E-01, -.34261000E+00, -.22345900E+00, -.14007000E+01, 0.13050800E+00, -.14175900E-01, 0.16586800E+01, 0.11407800E+01, 0.20705200E-01, 0.82991900E-01, -.75840400E+00, 0.38928600E+00, -.35078400E+00, -.32455000E+00, 0.36708700E+00, 0.56059100E+00, 0.40001000E-01, -.22539100E+00, 0.11267300E+01, -.88926600E-01, -.56200300E-01, 0.73243800E+00, -.12635100E+01, -.18610800E+01, -.22326800E+01, 0.20406800E+00, 0.37012300E+00, 0.66246600E+00, -.41786900E+00, -.43790700E+01, 0.24567400E+00, 0.19406100E+01, 0.44207900E+00, -.70893200E+00, -.17137800E+01, -.88859700E+00, 0.41439000E+01, -.77987400E+00, -.43603900E-01, 0.45573600E+00, 0.14685800E+00, -.18341100E+00, -.62874200E+00, -.47284600E+00, -.77075900E+00, 0.15396700E+01, 0.12264700E+01, 0.11832000E+01, -.38990900E-01, -.33466600E-01, 0.12657900E+00, 0.25172600E+00, 0.35837800E+00, -.67798700E+00, 0.50208700E+00, 0.82257400E-01, 0.39179700E+00, 0.33370000E-02, -.45657800E-01, 0.15977500E+00, 0.38836700E-01, 0.11473700E+01, 0.59050500E+00, -.12913000E+01, -.92548900E-01, -.19430600E+00, -.21973100E+00, 0.73448900E+00, -.16209400E+00, 0.59618800E-01, 0.41178200E+00, -.25888100E-01, -.10928700E+01, 0.78922600E-01, -.42863200E+00, -.65073400E+00, 0.42030000E+00, 0.63743100E+00, -.54883500E-01, 0.55394900E+00, 0.45778200E+00, -.11096000E+00, 0.19195900E+00, -.40887800E+00, 0.12733400E+00, -.24316700E+00, -.84520300E+00, 0.24603700E+00, -.14938200E+01, 0.14696100E+01, 0.12795200E+01, -.63640100E+00, 0.14118400E+01, -.21877300E-01, 0.28823500E+00, -.81943500E+00, 0.25675200E-01, 0.23779200E+00, 0.35576100E-01, 0.19454400E+00, -.91162700E+00, 0.25439300E+00, -.37883800E-01, -.73869300E-01, 0.41714000E+00, 0.46055400E+00, 0.81123300E-01, -.47482100E+00, 0.13378600E+00, 0.42349300E+01, -.21401200E-01, -.14766800E+01, 0.55873400E+02, -.25928500E+02, -.16283700E+02, -.27935900E+02, -.71352400E+01, 0.22223200E+02, -.78701600E+01, 0.20470800E+02, 0.87594900E+01, 0.26045800E+02, -.60224600E+02, -.31171400E+04, 0.15626500E+04, 0.16104400E+04, 0.15585900E+04, 0.36178800E+03, 0.92565200E+03, -.74748600E+02, -.91468300E+03, 0.87636500E+03, 0.87243700E+03, 0.58115500E+03, -.26898900E+03, 0.13131800E+03, 0.74850700E+02, 0.13388200E+03, 0.40652500E+02, 0.49755900E+02, -.44922300E+00, -.12957200E+03, -.40307700E+02, 0.58685200E+02, 0.19488100E+03, -.31657500E+04, 0.15901200E+04, 0.14130300E+04, 0.15829700E+04, 0.38841900E+03, 0.78587900E+03, -.37545600E+02, -.87181200E+03, 0.11102200E+04, 0.76083900E+03, 0.64190800E+03, 0.14603800E+02, -.78923700E+01, -.11083600E+03, -.10264300E+02, -.25280400E+02, -.20722200E+02, 0.97681800E+02, -.15860100E+02, 0.73139700E+02, -.26279200E+02, 0.52679900E+02, 0.65549300E+00, -.75733900E+00, -.29705000E+01, -.33837000E+00, 0.88165900E-01, 0.15046000E+01, -.42277200E+01, -.28591900E+01, -.40619600E+01, 0.28695100E+01, 0.14882400E+00, 0.68634000E+02, -.37047700E+02, -.95762400E+02, -.35444300E+02, 0.78630800E+01, 0.74798900E+01, 0.70826700E+01, 0.39828600E+02, -.13225400E+02, 0.15298600E+02, 0.57404800E+01, -.77904500E+02, 0.47939100E+02, -.34738000E+01, 0.38982000E+02, 0.11646000E+02, -.16647100E+03, 0.10650300E+03, 0.13553200E+03, 0.32932800E+03, -.17283400E+03, -.29571500E+01, -.60184200E+03, 0.29790600E+03, 0.38119400E+03, 0.30085600E+03, -.78195000E+02, 0.23851400E+03, -.28915900E+01, -.41780200E+03, -.32900500E+03, 0.22981100E+03, 0.20654400E+03, 0.32847200E+01, 0.95255000E+01, -.62640800E+01, 0.32029100E+01, 0.21257200E+00, -.15493700E+02, -.10334300E+02, -.15465700E+01, 0.38951500E+00, -.44848900E+00, -.88965300E+01, -.13559600E+02, 0.39778000E+01, -.47369300E-01, 0.20030400E+01, 0.30886300E+01, 0.60441300E+01, 0.15318200E+02, -.14159000E+03, 0.63243900E+01, 0.13479400E+03, -.34049000E+00, -.89007400E-03, -.10874600E+01, -.25685900E+02, -.42280400E+02 },
        { 0.35371000E+00, 0.26651400E+01, -.11498900E+01, 0.20745200E+00, -.53631200E+00, -.62660100E+00, -.40006200E+00, 0.72626800E+00, 0.20660600E+00, -.17207000E+00, -.10092000E+00, 0.16075600E+00, -.26352600E-01, 0.56778800E-01, 0.73665100E-01, 0.15517600E+00, 0.29214400E+00, -.62148800E-01, -.56319100E+00, 0.83404400E-01, -.81249500E-01, 0.46329300E+00, 0.93311400E-01, 0.18039400E+01, 0.20741500E+00, -.15614000E+00, 0.55044800E+00, -.10351100E+00, 0.29221900E-01, -.41570500E+00, 0.13510000E+00, -.43805800E+00, 0.25997200E+00, 0.10485900E+00, 0.59064200E-01, -.13298100E+00, 0.59663400E-01, 0.61221200E-01, 0.26403400E+00, -.26809800E+00, 0.19552600E+00, 0.17881200E+00, -.69538900E-01, 0.18494500E-01, 0.13974800E+00, -.14065600E-01, -.84770700E-01, 0.62195700E-01, 0.20147600E-01, 0.15137300E+00, 0.61891000E+00, -.21100100E+00, -.56198500E-01, 0.41128500E+00, 0.14393400E+00, -.33251600E+00, 0.40258100E+00, -.24485800E+00, -.29215200E-01, 0.15631700E-01, 0.82420400E-01, 0.21770800E+00, -.94527000E-01, 0.22538700E+00, 0.51504600E-01, -.24307700E+00, -.19623800E+00, -.65892500E+00, 0.56545600E+00, 0.19405100E-02, -.54206600E-01, 0.10328000E+00, -.15560700E+00, -.57887000E-03, 0.13633300E+00, -.36472900E-01, 0.35007800E-01, -.29946100E+00, 0.39130100E+00, -.89458400E-01, -.11369200E-02, -.30306900E-01, -.15920100E+00, -.16313100E+00, -.15956100E-01, -.34698100E+00, 0.27367100E+00, 0.33031800E+00, -.99409000E-01, -.27659800E+00, 0.56587300E+00, -.19020700E+00, -.44324000E+00, 0.20854800E+01, 0.46962200E+00, 0.69146000E+00, -.28007000E-01, -.42769600E-01, 0.59721800E+00, 0.48135500E+00, -.25598300E+01, 0.21681700E+00, 0.30277700E-01, 0.92185400E-01, 0.14092500E+00, -.76538600E+00, -.29783300E+00, -.18666000E+00, -.66767600E-02, 0.56738300E+00, 0.46999700E+00, -.49315900E+00, 0.22611700E+00, -.15892900E-01, 0.32268000E-01, 0.16977800E+00, 0.32164400E-01, 0.59333100E+00, 0.35946500E+00, 0.62419200E-01, -.13577700E+00, -.18877000E+00, 0.18740800E-01, 0.93805500E-01, -.25497700E-01, -.53632700E+00, -.39558300E+00, -.20269500E+00, -.12088900E+00, 0.23808300E-02, 0.29434900E+00, -.16253800E+00, 0.52048300E-01, -.93786400E-01, -.16368300E-01, 0.59025300E-02, 0.16185100E+00, 0.10018600E+00, 0.15213400E+00, 0.27979100E-01, 0.12378300E-01, -.36936200E+00, -.11506000E+00, -.40115500E+00, -.59783400E+00, -.71672400E-01, -.28523600E-01, -.28509600E+00, -.21982800E+00, 0.53874000E-01, 0.62353300E-01, -.31590300E-01, -.90545200E-01, 0.31881900E+00, -.28540700E+00, -.28377300E-01, -.33064800E-01, 0.28818200E-01, -.16014500E+00, 0.31914700E-01, 0.12173800E+00, 0.58914200E+00, 0.13145300E-01, 0.11993900E-01, -.12079700E+00, 0.13865700E+00, -.38266900E-01, 0.21022800E+00, 0.11976400E-01, -.42544900E-01, 0.28688600E+00, 0.30329400E-01, -.14733700E+00, 0.64862500E+00, -.78879900E-01, 0.35513400E+00, 0.87922600E-01, 0.64826800E+01, 0.28064900E+01, 0.25555900E-02, -.23294000E+01, -.40027700E+01, 0.56116400E+01, 0.38920500E+00, -.21557000E+01, -.48511000E+01, -.17621900E+01, 0.22270900E+03, -.11110400E+03, -.67114400E+02, -.11135800E+03, -.48834000E+02, -.49529700E+02, 0.59751700E+02, 0.30666200E+02, -.12755900E+03, -.44065500E+02, -.60318000E+02, -.20540400E+02, 0.99999300E+01, 0.11145500E+02, 0.10283300E+02, 0.75695800E+01, 0.24515300E+02, -.78606700E+01, -.14564200E+02, -.14603400E+02, 0.24286700E+02, 0.44932500E+01, 0.10687400E+03, -.52702900E+02, -.10370100E+03, -.53449900E+02, -.61172200E+02, -.93966000E+02, 0.10108400E+03, 0.79333500E+01, -.10227900E+03, -.79625500E+02, -.20281100E+02, -.11288700E+02, 0.47978200E+01, -.28116300E+01, 0.58730800E+01, 0.85011000E+01, 0.32530500E+01, -.63905100E+01, -.25814800E+02, -.10743300E+02, 0.82324100E+01, -.21569000E+01, -.34661300E-01, 0.27854800E-01, -.71787100E-01, 0.19130300E-01, -.30203900E+00, -.55832100E+00, 0.13969700E+01, 0.70136500E+00, 0.53892900E+00, -.52255600E+00, 0.14421900E+00, 0.19979200E+02, -.11629900E+02, -.62237200E+01, -.99104700E+01, -.40290300E+01, -.11319300E+01, -.22180200E+01, 0.68112700E+01, 0.23880100E+01, -.40417400E+01, -.40768700E+01, 0.63977100E+02, -.32318800E+02, -.58942800E+02, -.31992900E+02, -.17458100E+01, 0.11606700E+02, 0.98974500E+00, -.17247500E+02, -.28423700E+02, 0.92687300E+01, -.26125000E+02, 0.10466200E+03, -.52618700E+02, -.31987200E+02, -.52322000E+02, -.37775100E+02, -.52840900E+02, 0.52536400E+01, 0.76305200E+02, 0.26322000E+01, -.47632200E+02, -.41989100E+02, -.25810300E-01, -.11428200E+02, -.92617100E-01, 0.36001100E+00, -.17387600E+01, 0.25061400E+01, -.23328100E+01, -.98632400E+01, 0.47670400E-02, -.19672100E+00, 0.15713400E+01, 0.16464000E+01, 0.22814400E+01, 0.96891600E+00, 0.12264000E+01, -.41627900E-01, -.23953700E+00, -.12897800E+01, 0.31050600E+02, 0.20413000E+01, -.26233500E+02, 0.37812200E+00, 0.11011700E+00, 0.94482100E-01, 0.17611000E+01, 0.33807500E+01 },
        { 0.70620700E-01, 0.91104300E-01, 0.56868000E+00, 0.26008100E-01, -.18499100E+00, 0.42593600E-01, 0.62902300E+00, -.17252200E+00, -.14985200E-01, 0.81217000E-02, 0.12862200E-01, 0.17199400E+00, -.97607800E-02, 0.71060500E-02, -.20629200E-01, -.32426900E-01, -.19591600E-01, 0.18433300E-01, 0.74140100E-02, -.34872600E-01, 0.36963800E-01, -.66766200E-01, -.77591700E-02, 0.69130300E-01, 0.23673000E-01, -.98501800E-02, 0.11453800E-01, 0.51557900E-01, 0.18032400E-02, -.70654700E-01, -.10319800E-01, -.35102200E-01, -.45072900E-01, 0.85964900E-01, 0.40760600E-02, -.70291600E-01, 0.44892000E-02, -.53410700E-01, -.18122400E-01, -.33999200E-01, 0.61175200E-01, -.82818200E-01, -.31098300E+00, -.12376500E+00, -.24253200E-01, -.15910000E-01, -.67953300E-02, 0.53008600E-02, 0.74545900E-02, -.10206400E+00, -.34195300E-01, 0.18108400E-01, 0.42015400E-01, -.20656700E+00, 0.60206500E-01, -.14715900E+00, 0.28083600E-01, 0.63217300E-01, 0.32785800E-03, 0.75115600E-01, -.17200800E-01, 0.57649200E-01, 0.48919600E-02, -.21202700E-01, 0.26784200E-01, -.13357600E-02, -.15498600E-02, 0.21743100E-01, -.35030000E-01, -.18255700E-03, -.25344700E-01, 0.77260400E-01, -.16269900E-01, -.10301000E-01, 0.92281800E-01, 0.59052800E-01, -.15207500E-01, -.94266100E-01, 0.16836100E-01, -.35689900E-01, 0.10056400E-02, 0.28547200E-02, -.12733400E+00, 0.62540100E-01, 0.24116000E-01, -.35679500E-01, 0.68748100E-01, 0.17978000E+00, -.27818200E+00, -.41111700E-01, -.13788300E+00, -.20830800E-01, -.62943200E-01, 0.36974200E+00, -.31586800E-01, -.37238800E-01, -.36607000E-01, 0.27190500E-01, 0.50583900E-01, 0.45640200E-01, -.31659700E-01, 0.13411700E+00, -.31158200E-02, 0.20846600E-01, -.18246500E-01, -.21768600E-01, 0.19204300E-01, -.22797600E+00, -.68713800E-02, 0.10685400E+00, -.88197700E-01, -.13821900E+00, 0.97151000E-01, -.98516400E-02, -.23939500E-01, -.58807400E-01, 0.18318300E-02, 0.47076500E+00, 0.36766100E-02, 0.87112400E-02, 0.14975300E-01, 0.47306600E-01, -.30498700E-01, 0.21292700E-01, 0.19607200E-01, -.12141100E+00, -.10373300E+00, -.12188700E-02, 0.96195300E-03, 0.77354000E-01, 0.28351800E-01, -.20092700E+00, 0.30386700E-01, -.13727300E-01, 0.56901800E-02, 0.37405600E-02, 0.93844600E-01, -.39897400E-01, 0.44325400E-02, -.23214400E-01, 0.33401100E-02, -.10710400E+00, 0.19566900E-01, -.12146000E+00, 0.15899800E-01, 0.12055700E-01, -.14568500E-01, -.10881100E+00, -.93316700E-01, 0.71013500E-01, 0.52740600E-01, -.63591600E-01, 0.21135400E-01, 0.88739300E-01, 0.20374400E-01, -.18130800E-01, -.15502400E+00, 0.20545800E-01, -.12432300E-01, 0.12590300E+00, -.69045800E-01, 0.90397200E-01, -.55005000E-01, 0.99345900E-02, 0.82988800E-01, -.40781900E-02, 0.93763700E-02, -.44575200E-01, -.36283500E-02, 0.56277000E-01, -.14641700E+00, -.82096500E-02, 0.20810200E-01, -.33140500E+00, 0.42982900E-01, 0.66075600E-01, 0.32284400E-02, -.57828000E-03, -.19455600E+01, -.73637100E-03, -.10708000E+01, -.42203000E+00, 0.40475900E+01, 0.75681500E+00, 0.21605800E+01, -.58206800E+00, 0.24092700E+01, -.14583400E+02, 0.72371600E+01, -.10890400E+02, 0.72922400E+01, -.27719800E+01, 0.93674400E+00, -.87697500E+01, -.79174900E+00, 0.75263900E+01, -.97408900E+00, 0.34109000E+02, -.20857500E+02, 0.10418300E+02, 0.10087200E+02, 0.10435400E+02, -.10779600E+01, -.96971300E+01, 0.14791500E+02, 0.12709600E+02, 0.17032700E+02, -.11881100E+02, 0.99773500E+01, 0.23062000E+02, -.11572100E+02, 0.10526700E+02, -.11529500E+02, -.92444800E+00, 0.26812600E+02, -.25970200E+02, 0.29398900E+01, -.10942100E+02, 0.21828900E+02, 0.22244300E+02, -.55299900E+00, 0.22687400E+00, -.83727400E+00, 0.21986200E+00, -.30408200E+01, -.89910500E+00, 0.10166700E+01, 0.94048100E+01, 0.13937600E+02, -.39823700E+01, 0.10642000E+01, -.55950600E-01, 0.14178400E-01, 0.60552300E-01, 0.27657900E-01, 0.12837500E+00, 0.12398900E+00, -.27400600E+00, -.22557700E+00, -.15971000E+00, 0.11586900E+00, -.79977200E-01, -.71516300E+01, 0.32106500E+01, 0.81096400E+01, 0.35742300E+01, 0.20876000E+01, 0.31579800E+01, -.16438600E+00, -.34549700E+01, -.27077700E+01, 0.30064400E+01, 0.25665400E+01, -.18697400E+02, 0.94378400E+01, 0.24502100E+02, 0.93492900E+01, 0.63996000E+00, 0.39753300E+01, -.20657500E+01, -.27104500E+01, 0.49779500E+00, 0.53874300E+01, 0.17727700E+02, -.14534600E+02, 0.71740300E+01, -.83913400E+01, 0.72660800E+01, 0.10613800E+02, 0.51350500E+01, -.28600400E+01, -.71778800E+01, 0.80119800E+01, 0.29542200E+01, -.26945100E+01, -.58953400E-02, 0.42627900E+01, 0.57027200E+00, -.94760100E-01, -.10702500E+00, 0.60123000E-01, 0.11540600E+01, 0.40033400E+01, 0.76733500E-02, 0.18325700E+00, -.15247900E+00, -.16645500E+00, -.69975400E+00, -.16422200E+00, 0.11199500E+00, -.24253100E-01, -.54941300E+00, -.34038200E+00, -.40419500E+01, -.15822000E+01, 0.18935300E+01, -.58201800E+00, -.12898300E-01, 0.41484600E+00, 0.35985700E+00, 0.46010900E+00 },
        { 0.34936200E+00, -.58098200E+00, 0.28857400E+01, -.18878200E+00, -.23250000E+01, -.30790800E+00, -.31674600E+01, -.39151200E+00, 0.75948900E-01, -.26284900E+00, 0.43326200E-02, 0.24673300E+01, -.53437600E+00, 0.36969100E+00, 0.36914000E+00, 0.43218900E+00, 0.27637100E+01, -.39992800E+00, 0.17274500E+00, -.40530600E+00, 0.48981400E+00, 0.15943700E+01, -.17069000E+00, 0.42650500E+00, 0.52925800E+00, -.69366600E-01, 0.61320700E+00, -.93977300E-01, 0.41467700E-01, -.47302200E+00, -.36369500E+00, -.36894700E+00, 0.61379000E+00, 0.11217500E+00, -.37888900E-01, -.38761400E-01, 0.70495200E-01, -.21346500E+00, -.48166300E+00, -.14750400E+00, 0.17632200E+00, 0.67215000E+00, 0.87041100E+00, 0.29489500E+00, -.63277000E+00, -.44156200E+00, -.10960700E+01, 0.11165500E+00, -.81350500E-01, -.11025400E-01, -.34517100E+00, -.53064500E-01, 0.54056500E+00, -.97634300E+00, -.13820700E+00, -.60020200E+00, 0.20502200E+00, 0.55081300E+00, -.36591900E+00, 0.14826300E+00, -.27803400E+00, 0.11464900E+00, -.61618000E-01, 0.73888800E-01, 0.12607800E+00, -.45639700E-01, 0.97435000E-01, -.32752800E+00, 0.26850700E-02, -.63553500E-04, 0.32393700E+00, -.52551200E-01, -.27714300E-01, 0.63916800E-02, -.70774500E-01, 0.13967300E-01, -.12062200E+00, -.63791300E-01, 0.20977300E+00, -.12334300E+00, 0.73161500E-02, 0.19089500E-01, 0.84975800E-01, -.18110700E-01, 0.12644800E-01, -.23963000E+00, 0.16948500E+00, -.53970400E-01, -.77870400E+00, -.72387400E-01, 0.15943900E+00, 0.34852700E-01, 0.14003700E-01, -.71715700E+00, -.25707500E+00, -.85224600E-01, -.93050900E-01, 0.24039700E+00, -.17442100E+00, -.15735800E+00, 0.86805400E+00, -.14962700E+00, -.93207700E-02, 0.25247500E+00, 0.17344200E+00, -.33520900E+00, -.27912900E+00, -.23709200E+00, 0.38162100E+00, 0.67573800E-01, 0.28972700E+00, 0.39685300E+00, -.35775000E-01, -.25812100E-01, 0.14916100E-01, -.13007300E+00, -.11494400E-01, 0.11143700E+00, 0.47804800E+00, -.20923900E-01, 0.10093300E+00, -.39738500E-01, -.21253100E-01, -.29651900E+00, 0.15637500E-01, -.24753600E+00, -.43035300E+00, -.15512300E+00, -.44622900E-01, -.16900400E+00, 0.68457900E-01, 0.48982200E+00, -.77825400E-01, -.17945500E-01, -.28693700E-01, -.10621300E-01, 0.79196000E-01, 0.10488100E+00, 0.24835200E-01, 0.12395500E-02, 0.27404800E-01, -.19217700E+00, -.35750800E-01, -.64053200E-01, 0.40176000E-01, -.53706700E-01, -.44681500E-01, 0.13410500E+00, -.90864400E-01, 0.15999800E+00, 0.11491500E+00, -.12452400E+00, 0.17533400E+00, 0.32490400E+00, -.16711200E+00, -.10364800E+00, 0.26546800E+00, -.11645500E-01, -.52641300E-01, 0.16908300E+00, 0.29343800E-01, -.84417200E-01, 0.44554300E-01, -.49531700E-01, -.29273100E-01, 0.53758100E+00, 0.10689000E-01, 0.53327500E-01, 0.55073600E-02, 0.20750600E+00, 0.11327700E+00, 0.21401500E+00, 0.64890200E-01, -.27158800E+00, -.74820000E-02, -.59628700E-01, -.74237300E-01, 0.19654500E-01, 0.91495800E+00, 0.34875100E+01, 0.78114800E+00, 0.13949200E+01, -.60576900E+01, -.23094100E+01, -.54726500E+01, 0.21646700E+01, -.33968200E+01, 0.37978100E+03, -.18983400E+03, -.14289100E+03, -.18989700E+03, -.10608700E+03, -.62241400E+02, -.28614600E+02, 0.98224500E+02, -.71245300E+02, -.68221700E+02, -.18245100E+03, -.20322900E+02, 0.99037400E+01, 0.12557200E+02, 0.10005700E+02, 0.98496100E-01, 0.20635300E+01, -.10963300E+02, -.16680900E+02, -.11356700E+02, 0.44004900E+01, 0.72012900E+01, 0.29564000E+03, -.14746800E+03, -.19122100E+03, -.14783500E+03, -.76833700E+02, -.74955500E+02, -.52017100E+01, 0.74520400E+02, -.54578700E+02, -.78214300E+02, -.16146900E+03, -.26685600E+02, 0.13188100E+02, -.56235700E+01, 0.13437400E+02, 0.87367000E+01, 0.10512100E+02, -.15462600E+02, -.10270800E+02, -.21064300E+00, 0.10520600E+02, 0.94713900E+01, 0.35372600E+00, -.22421100E+00, -.24125100E+00, -.17300200E+00, -.11582900E+00, 0.10557800E+00, -.15425200E+00, 0.61159000E+00, 0.14296100E+00, 0.23294800E-01, 0.22280300E+00, -.35016000E+02, 0.14853200E+02, 0.80623400E+01, 0.17440200E+02, 0.42216800E+00, -.17877800E+00, 0.46971000E+01, -.71260100E+01, 0.51284900E+01, 0.49913100E-01, 0.25221200E+02, -.10202500E+03, 0.51292200E+02, 0.35313200E+02, 0.51006000E+02, 0.29762200E+02, 0.30525000E+02, 0.13701900E+02, -.50092500E+02, -.16291000E+02, 0.30280700E+02, 0.11965800E+02, 0.15506900E+03, -.77875400E+02, -.47892300E+02, -.77521500E+02, -.40966200E+02, -.20270700E+02, -.30672300E+02, 0.78765800E+02, 0.10066500E+01, -.21008400E+02, -.32440600E+02, -.12774100E+00, -.56213900E+01, -.60130800E+00, 0.80052800E-01, -.23900700E+00, -.53565400E+00, -.97160400E+00, -.44572600E+01, 0.29130500E-01, -.26041400E+00, -.72844200E+00, 0.29009500E+00, -.12751200E+00, 0.92346200E+00, -.42972300E+00, 0.22329200E+00, 0.12884000E+01, 0.10355000E+01, 0.11581000E+02, 0.13246400E+01, -.13717300E+02, 0.64510100E-01, 0.15012800E-01, -.30946200E+00, 0.53617600E+01, 0.47734200E+01 },
        { 0.65832500E+00, -.76671300E+00, 0.44609400E+01, 0.29277600E+00, -.37814000E+01, -.36594600E+00, -.49279700E+01, -.23008700E+00, 0.25053700E+00, -.51434000E+00, -.15897600E+00, 0.47807500E+01, -.10370000E+01, 0.10703600E+01, 0.16507500E+01, 0.36286100E+00, 0.32824900E+01, -.54559700E+00, 0.86705600E+00, -.65108100E+00, 0.93499700E+00, 0.33335800E+01, -.41871900E+00, 0.96134300E+00, 0.51122600E+00, 0.54951600E+00, 0.18406100E+01, -.11141900E+01, -.13902400E+00, -.10615000E+01, -.59454800E+00, -.73958500E+00, 0.13676600E+01, -.87914800E+00, -.25889700E-01, 0.51448800E+00, -.74031900E-01, 0.49912600E+00, -.92210000E+00, -.30567100E+00, -.14013100E+01, -.49329400E+01, -.25243300E+01, -.14063500E+01, 0.16775900E+00, 0.18673000E+00, 0.15146900E+01, -.43091400E-02, 0.36749800E+00, -.53411200E+00, -.20534200E+01, 0.29558000E+01, 0.59155000E+00, -.43018200E+01, -.13753200E+01, -.77021600E-01, -.71234300E+00, 0.15163700E+01, 0.44732600E-01, -.11597500E+01, 0.59156200E+00, 0.22586500E+00, 0.12934900E+00, 0.50104400E+00, -.24918400E+00, 0.61231200E+00, 0.97180900E-01, 0.47521100E+00, -.28517200E+00, -.42511900E-03, -.70669800E+00, -.20292100E+00, -.35010500E-01, -.15501600E+00, 0.70503200E+00, -.45186200E+00, -.45682100E+00, -.43141300E+00, -.10326400E+00, 0.12789800E+01, 0.57399200E-01, -.71383300E-01, -.98179000E+00, 0.13181700E+00, 0.48360700E-01, 0.38260600E+00, -.21533200E+00, -.19254800E+01, 0.13529100E+01, 0.20404700E+00, 0.21168200E+00, 0.67897900E+00, 0.39025200E+00, -.37209700E+01, 0.38390600E+00, 0.12063400E+01, 0.85834400E+00, -.18613700E+00, -.33132600E+00, 0.10699900E+00, 0.26380600E+00, -.74288400E+00, -.57723600E-01, 0.62287600E+00, 0.12409400E+00, 0.19695900E+01, 0.29322800E+00, 0.72525500E+00, -.77054600E+00, 0.87573500E+00, 0.54660000E+00, 0.14037000E+01, 0.45513500E-01, -.83415000E-02, 0.71152800E-01, 0.24969400E+00, -.22510600E+00, 0.10800300E+01, -.13808800E+00, 0.35053800E-01, 0.12586900E+00, -.51263600E+00, 0.98544800E-01, -.92993800E-01, -.32845800E-01, 0.92126700E+00, 0.67033600E+00, -.12936500E+00, 0.57693600E-01, 0.13300200E+00, -.27959100E+00, -.84568600E+00, 0.75765600E-01, 0.38592700E-01, 0.40757200E+00, 0.11236200E-01, 0.51966100E+00, -.64965100E-01, -.15361200E+00, 0.69318500E+00, -.40731400E-01, -.96895100E+00, -.23276200E+00, 0.61841800E-01, -.83464800E-01, 0.62288200E-01, 0.90289900E-01, 0.16921200E+01, 0.11145700E+01, -.10553000E+01, 0.48041600E+00, 0.11517500E+00, 0.20655200E+01, -.21866100E+01, -.19357500E+01, -.36821300E+00, -.22963900E+01, 0.47025100E+00, -.25655700E+00, 0.69624300E+00, 0.71014200E+00, -.12952200E+01, 0.86478900E-01, -.21581400E+00, 0.97735200E+00, 0.34457400E+00, 0.37631900E+00, 0.42674800E+00, -.17455100E+00, -.75867900E+00, -.11688900E+01, -.53092200E-01, -.47792000E+00, -.15849700E+01, -.19557300E+00, -.44706000E-01, -.14805400E+00, 0.90136600E-02, -.10582800E+02, -.70903700E-02, -.21179600E+02, -.31686100E+02, 0.95140100E+02, 0.40933900E+02, 0.90942800E+02, -.43075000E+02, 0.45257100E+02, -.25034500E+04, 0.12531800E+04, 0.12519900E+04, 0.12517200E+04, 0.26441200E+03, -.18922800E+02, 0.64560900E+03, -.44977800E+03, 0.89657200E+03, -.12926100E+03, 0.10742800E+04, -.38495200E+03, 0.19265200E+03, 0.20899600E+03, 0.19332400E+03, 0.40545400E+02, 0.69825900E+01, 0.14204100E+03, 0.83176300E+02, 0.11651500E+03, -.26667400E+02, 0.10109500E+03, -.23444200E+04, 0.11735200E+04, 0.11363400E+04, 0.11721500E+04, 0.13455900E+02, -.42109400E+02, 0.68003400E+03, -.42346700E+03, 0.92782300E+03, -.14574600E+03, 0.11595500E+04, -.19723800E+01, 0.15309900E+01, -.62391800E+02, 0.43016600E+01, -.10813500E+03, -.36469900E+02, 0.10442400E+03, -.16963400E+01, 0.77860800E+02, -.72478300E+02, 0.16579000E+03, -.19387200E+01, 0.11339500E+01, -.10967200E+01, 0.97060400E+00, 0.19641400E+00, -.93893700E+00, 0.55507700E-01, -.94952600E+01, 0.15352800E+01, -.13269700E+00, 0.50846200E+00, 0.47246300E+02, -.23468600E+02, 0.49311600E+02, -.22590600E+02, 0.30594800E+02, 0.18350100E+02, -.47733900E+02, -.28005300E+02, -.20492200E+02, 0.11976300E+02, -.24769600E+02, 0.22005300E+03, -.11063000E+03, -.12782900E+03, -.11004100E+03, -.75083100E+02, -.40131300E+01, -.85394700E+02, -.55603600E+02, 0.36608900E+02, 0.45196400E+02, 0.18996200E+03, -.11223400E+04, 0.56188600E+03, 0.47272100E+03, 0.56120700E+03, 0.17613000E+03, 0.69371400E+02, 0.15473200E+03, -.20879000E+03, 0.15421400E+03, 0.21590900E+02, 0.88800800E+02, 0.12143200E+01, 0.19773000E+02, 0.29713700E+01, -.14218500E+01, -.16073400E+01, 0.19955000E+01, 0.18163400E+02, 0.10699900E+02, -.20290900E+01, 0.53456100E+00, 0.50067100E+01, -.59771700E+01, -.36207300E+01, -.80174800E+00, 0.49741200E+01, -.35140100E+01, -.10610900E+01, -.24097600E+02, -.24801800E+03, -.20716400E+02, 0.18710100E+03, -.11029400E+02, -.18487800E+01, 0.10506700E+02, -.26943300E+02, -.12642600E+02 },
        { 0.91111900E-01, 0.48879300E+00, -.82734100E+00, 0.16168800E-01, -.57480700E+00, 0.21585500E-01, -.70259300E+00, -.28104700E-01, -.55907600E-01, -.11455200E+00, 0.20642600E+00, 0.15364700E+01, -.20254400E+00, 0.60915300E+00, 0.26778100E+00, 0.25568800E+00, 0.83457800E+00, -.35951000E-01, -.11705300E+00, 0.30809800E+00, -.31015800E+00, -.55346800E+00, 0.36994700E+00, -.21423500E+00, -.74023500E+00, -.70661000E-01, -.12601400E+00, 0.62307900E+00, -.34949000E+00, -.13142900E+00, 0.55297900E+00, -.39898000E-01, 0.23478300E+00, 0.34560000E+00, -.21088400E+00, -.44869500E+00, 0.48730000E-01, 0.25225000E+00, 0.48735100E+00, -.31187200E+00, -.40181700E+00, -.17845900E+01, -.10791000E+01, -.35579700E-02, 0.64762300E+00, 0.20954100E+00, 0.71957400E+00, 0.64336300E-01, 0.44837900E+00, 0.69748800E-01, 0.34861100E+00, 0.17030500E+00, 0.14726000E+00, -.70813200E+00, -.10028500E+01, 0.35429100E+00, 0.34205500E-01, 0.40476300E+00, -.10715300E+00, -.73312300E+00, -.13274300E+00, -.13069900E+00, -.14937500E-01, 0.13236700E+00, 0.85765700E-02, 0.12460400E+00, -.21175200E-01, -.15219200E+00, 0.36553300E+00, 0.17687000E-02, 0.17451000E+00, 0.10365000E-01, -.16760900E+00, 0.43867800E-01, 0.39077000E+00, -.42439900E+00, -.13374000E-01, -.46819800E-01, -.20433400E+00, 0.77019300E-02, 0.10143000E-03, -.37192900E-01, -.53822400E+00, 0.18656600E+00, -.93885200E-01, -.88529800E-01, 0.15685100E+00, -.35313900E+00, 0.31966300E+00, 0.10407700E+00, -.58235600E+00, -.21642700E+00, 0.25416600E+00, -.22692900E+00, -.11003200E+00, -.11136100E+01, 0.27163800E+00, -.55000200E-01, 0.98773300E+00, 0.24629700E+00, -.80212900E+00, 0.26311100E-01, 0.13343600E-01, 0.53644600E-01, -.10887600E+00, -.27074700E+00, -.60984100E-01, 0.64194800E-01, 0.52423600E+00, -.48870700E-01, 0.14995000E+00, -.10982500E+00, 0.11475800E+00, -.20571000E-01, -.12156300E+00, -.35584400E+00, -.17731000E-01, 0.23482200E+01, 0.43336200E+00, 0.95420200E-01, 0.27758800E+00, 0.60285900E+00, -.12927200E+00, -.26457800E+00, 0.35559700E-02, -.23606800E+00, -.67931100E+00, -.27836500E-01, -.21510200E-01, 0.18236500E+00, 0.13589900E+00, -.51090400E+00, 0.46394800E-01, 0.15594400E+00, -.21236300E+00, 0.10588000E-01, 0.24472000E+00, -.19247900E+00, -.56035200E-01, -.20869200E+00, -.50358600E-01, -.13118500E+00, 0.13866300E+00, -.11800800E+00, 0.71207500E-01, -.12356700E+00, -.51248400E-02, 0.15564800E+00, 0.10493800E+00, -.32945600E+00, 0.71111000E-01, 0.27790800E-01, 0.58085900E+00, -.41687900E+00, -.37707300E+00, 0.50940000E-01, -.48798300E+00, 0.10994200E+00, -.20348400E+00, 0.15101500E+00, -.19837700E+00, 0.69178800E+00, -.53748500E-01, -.26132400E-01, 0.83208000E-01, 0.53409500E-01, 0.33278300E-01, 0.97578100E-01, -.36101000E-01, 0.26082000E+00, 0.89970500E-01, -.66608100E+00, -.16293900E+00, 0.70637200E+00, -.19280700E+00, 0.21602500E-01, 0.54687600E-01, 0.84793300E-02, -.17920400E-01, -.31854700E-02, -.85014500E-02, 0.52427000E+01, -.23669000E+01, -.65335200E+01, -.11638100E+02, 0.56829200E+01, -.44605100E+01, 0.48886800E+03, -.24416000E+03, -.26223400E+03, -.24442800E+03, -.64777600E+02, -.88448400E+01, -.71802200E+02, 0.14367900E+03, -.99100200E+02, -.28058600E+02, -.14350900E+03, 0.21667000E+01, -.10871600E+01, 0.37898700E+01, -.94256400E+00, 0.13279200E+02, 0.35431800E+02, -.14166300E+02, -.61903600E+00, -.95861600E+01, 0.31074500E+02, -.11833000E+02, 0.48387100E+03, -.24160900E+03, -.21513500E+03, -.24192100E+03, -.40894000E+02, 0.10860100E+01, -.67129700E+02, 0.13851900E+03, -.12593400E+03, -.94503000E+01, -.17185500E+03, 0.39964500E+02, -.19430000E+02, 0.57337400E+01, -.20025600E+02, -.11979900E+02, -.12154700E+02, 0.11561100E+02, 0.30767300E+02, -.29436000E+01, -.90999500E+01, -.22480200E+02, 0.56117700E-01, -.22260500E-01, 0.18023700E+00, -.32141200E-01, 0.12818900E+00, -.23109500E+00, 0.59086600E+00, 0.44877700E-01, 0.45995500E+00, -.62817300E-01, -.26882600E+00, -.42840600E+02, 0.23143200E+02, 0.16004900E+02, 0.21471700E+02, 0.14267000E+02, 0.26231200E+02, -.16442000E+01, -.36909200E+01, -.75985600E+01, 0.20785000E+02, 0.18424600E+02, 0.55035000E+02, -.26843100E+02, -.25729900E+02, -.27510900E+02, 0.27195100E+02, 0.26290000E+02, -.22224500E+02, -.25172300E+02, -.91613500E+02, 0.18150600E+02, -.98821800E+01, 0.21205800E+03, -.10579900E+03, -.10938900E+03, -.10604200E+03, -.39180400E+02, -.26708100E+02, 0.27349400E+02, 0.15150500E+03, 0.31988200E+02, -.24934600E+02, -.11814800E+03, 0.18204900E+00, -.96401700E+00, -.40994600E+00, 0.68920000E+00, 0.13108800E+01, -.32923300E+00, -.13775400E+01, 0.20260200E+01, -.52952600E-01, -.10897000E+00, -.12520300E+01, -.57300100E+00, 0.24247600E+01, -.12277600E+01, 0.49511200E+00, 0.43938000E+00, -.31156900E-02, 0.29559700E+01, 0.17837900E+02, 0.76660600E+00, -.21832200E+02, 0.20612400E+01, 0.77046000E-03, -.75212000E+00, 0.14589800E+02, 0.76966600E+01 },
        { -.14846000E+00, -.44478600E+00, 0.66249200E+00, -.41290200E+00, 0.34103300E+00, -.65888300E-01, 0.13681200E+00, -.87751900E+00, -.32657300E+00, 0.34504700E-01, 0.16098100E+00, 0.64014200E-02, -.10033500E+00, -.18924800E+00, 0.35845400E+00, -.25950100E+00, -.23955300E+00, 0.49223500E-02, 0.77970300E+00, 0.13999700E+00, 0.23683600E+00, 0.25091400E+00, 0.18724200E+00, -.78551800E-01, -.51184600E-01, 0.19242000E+00, -.15462200E+00, -.50912900E+00, -.17758600E+00, 0.49279000E+00, 0.83622200E-01, 0.32739000E+00, 0.44815600E+00, -.57876900E+00, -.41065400E-01, -.19934200E+00, 0.14568100E-01, -.39601700E+00, -.62969500E-01, -.65451200E-01, -.26729600E+00, 0.68508500E+00, 0.14796600E+01, -.29251400E+00, -.86219000E+00, -.72357600E-01, -.23161800E+00, -.31839400E-01, -.49423200E-01, -.38417600E+00, -.79721700E+00, 0.63184200E+00, -.13245500E+00, 0.24545200E+00, 0.44056000E+00, -.26625900E+00, -.25305800E+00, -.15293500E+00, 0.15395700E+00, -.60587800E+00, 0.38375000E+00, 0.89311500E-01, 0.37428000E+00, -.11621900E+00, -.37860300E-01, -.57293800E-01, -.58080200E-01, 0.24535800E+00, 0.96429200E-01, 0.38769300E-03, -.17778000E+00, 0.54292800E+00, -.77848200E-01, -.18146400E-01, 0.35398900E+00, -.44244200E-02, -.11383500E-01, -.24769900E+00, -.16994100E+00, 0.24428300E+00, 0.59800200E-02, -.72026100E-01, -.18032700E+00, 0.99060500E-01, -.51195200E-01, -.11610700E+00, -.25387000E+00, -.66644400E+00, -.38126200E+00, 0.21341000E+00, -.12475800E+00, -.90384300E-01, 0.44360200E+00, 0.53222900E+00, -.20527700E+00, -.10789000E+00, 0.16412100E+00, 0.27789800E+00, 0.69782500E-01, 0.37949900E-01, -.58761900E-02, -.94115600E-01, 0.70337600E-03, 0.33444900E-01, -.13223900E+00, 0.55206200E+00, 0.24707600E-01, 0.40259300E+00, -.54832400E+00, -.32455500E-01, -.31143000E+00, 0.13669700E+00, -.10943100E+00, -.71074500E-01, -.26664700E+00, -.18696500E+00, 0.11222100E+00, 0.16158000E+01, 0.52143300E+00, 0.74801300E-01, 0.36455000E-01, -.11961100E+00, -.53977000E-01, -.59095000E+00, 0.31980200E-01, 0.23894300E+00, -.48369900E+00, 0.40594300E+00, 0.66797700E-01, 0.14455700E+00, 0.25661700E+00, -.52474600E+00, 0.46256100E-01, 0.17061000E+00, -.17555000E+00, 0.98753200E-02, -.11644500E+00, -.80382100E-02, -.16204400E-01, 0.38951200E+00, -.20663600E+00, -.26670900E+00, -.46073800E-01, -.27271700E+00, -.27806700E+00, -.20629800E+00, 0.46980600E-01, -.57280500E-02, -.35446700E+00, 0.25129600E-01, 0.42515600E+00, -.13248000E+00, 0.56172500E-03, -.88563700E-01, 0.11391800E-01, 0.20087300E-01, -.39446600E+00, 0.62652900E-01, 0.15486100E+00, 0.24041400E+00, 0.35205500E-01, 0.47294500E+00, -.79905200E-01, -.92990800E-02, 0.20672900E+00, 0.18506300E+00, 0.21864600E-01, -.78361200E-01, -.19470500E-01, 0.41055600E+00, -.84848000E-01, -.96058100E-01, 0.19768700E+00, -.19345900E+00, 0.58725200E-01, 0.67980400E-01, -.94651800E-01, 0.78347400E-02, 0.10512500E+01, -.88486200E-03, 0.86597600E-01, 0.48307900E+00, -.13304800E+02, 0.56319900E+00, -.16711100E+01, 0.20349800E+01, 0.62812400E+00, 0.27326000E+03, -.13674800E+03, -.98684700E+02, -.13662500E+03, -.10182800E+03, -.34454700E+02, -.73571100E+02, 0.73929300E+02, -.90281000E+02, 0.13807400E+02, -.51062400E+02, 0.43487800E+02, -.21946800E+02, -.17383100E+02, -.21990500E+02, 0.12046800E+01, 0.51260500E+01, -.24457100E+02, -.16779000E+02, -.24208900E+02, 0.13924500E+02, -.26200200E+02, 0.16521700E+03, -.82563500E+02, -.10898200E+03, -.82584100E+02, -.39869100E+02, -.38699400E+02, -.62290600E+02, 0.51911500E+02, -.68203400E+02, 0.53534000E+01, 0.16810300E+01, -.23796900E+02, 0.12249100E+02, 0.11052800E+02, 0.10792400E+02, 0.23772000E+02, 0.21386100E+02, -.46545800E+02, -.20901300E+02, -.20294100E+02, 0.29266800E+02, -.63495200E+01, 0.51129900E+00, -.30811500E+00, 0.14946600E+00, -.25749600E+00, -.68308900E-01, 0.59441700E-01, 0.25485400E+00, 0.16121600E+01, -.56955000E-01, -.18482200E+00, -.48751700E+00, 0.11503000E+02, -.83308500E+01, -.25029600E+02, -.61100700E+01, -.17153700E+02, -.27273800E+02, 0.12586900E+02, 0.73246200E+01, 0.14985000E+02, -.21151700E+02, 0.15391400E+02, 0.37328400E+02, -.18494400E+02, -.49205600E+02, -.18657200E+02, 0.32048700E+02, -.34462500E+01, -.52363600E+01, 0.30622000E+01, -.13324300E+02, 0.25723100E+01, -.32100400E+02, -.42110800E+00, -.43952700E-01, 0.32001300E+02, 0.19472400E+00, -.31615600E+02, -.59589800E+01, 0.40635800E+01, 0.19044000E+02, 0.14406000E+02, -.65845700E+01, 0.39380600E+02, -.48906200E+00, -.97520200E+01, 0.25583500E+00, 0.25758700E+00, 0.68309800E+00, 0.13186200E+00, -.87152400E+00, -.90776500E+01, 0.27845900E+00, 0.69386200E-01, -.30121700E+00, 0.13634000E+01, 0.17301400E+00, 0.13118000E+01, -.21778000E+01, 0.29439400E-01, 0.40077900E-01, -.69443500E-01, 0.22802900E+02, 0.41914700E+01, -.14267800E+02, 0.10385900E+01, 0.25827400E+00, 0.79089500E+00, -.38320300E-01, 0.40521200E+01 },
        { -.82842500E+00, -.70197600E+01, 0.19987300E+01, -.95877100E+00, 0.11603300E+01, 0.11493800E+01, 0.61297400E+00, -.12462000E+01, -.98784500E+00, 0.26646900E+00, 0.74646100E+00, -.44018500E+00, -.18837400E+01, -.12850500E+01, 0.62064400E+00, -.25264600E+00, 0.47762600E+01, -.33685000E+00, 0.25176000E+01, -.66705100E+00, 0.36382100E+01, -.58709500E+01, -.11008400E+01, -.78791200E+00, 0.86407200E+00, 0.13485500E+01, -.29608800E+00, -.12472800E+01, -.34165500E+00, 0.64623700E+00, -.77095800E+00, 0.48239300E+00, 0.14082800E+01, -.33959700E+00, 0.11725800E+01, 0.56353400E+00, -.55100000E-01, 0.10691800E+01, -.10115100E+00, -.11924600E+01, -.80446100E-01, -.58998700E+01, -.46208200E+01, -.16041900E+01, 0.10502300E+01, 0.23395500E+00, 0.21613100E+01, -.37186800E-01, 0.28525300E+00, 0.38304700E+00, 0.13838200E+00, 0.25643100E+01, -.16601700E+00, -.70082800E+00, -.10713900E+01, -.27694300E+00, 0.20389200E+01, 0.94534300E+00, 0.58750200E+00, 0.10333300E+01, 0.54483900E+00, 0.97302000E+00, -.69571200E+00, 0.13417900E+01, -.20897400E+00, 0.10600800E+00, -.43214300E+00, -.10735700E+01, 0.14823800E+01, -.18256000E-02, -.43474000E+01, -.30685700E+01, -.68097900E+00, -.61930800E+00, 0.22827800E+01, -.41295900E+00, -.11727900E+01, -.15365500E+01, -.16649900E+01, 0.11111800E+01, 0.10454500E+00, -.31510500E+00, -.20498800E+01, -.71766600E+00, -.41798000E+00, -.10911200E+01, 0.25781300E+01, 0.85906500E+00, 0.11361000E+01, 0.10921400E+01, 0.69477500E+00, 0.47529600E+00, 0.34835200E+01, -.33708800E+01, -.11845100E+01, 0.10257800E+01, 0.21800500E+01, 0.15086700E+01, -.74933900E+00, -.11422400E+01, -.11776300E+00, -.22350400E+01, 0.60708700E-02, 0.92103700E+00, 0.81497500E+00, 0.85289000E+00, -.64656700E+00, 0.37569600E+00, -.14295400E+00, 0.33044000E+00, -.71430900E+00, 0.32399200E+01, -.19330700E+00, -.53822100E+00, -.12594400E+01, -.17564200E+01, -.64221900E-01, 0.10007600E+02, 0.19628600E+01, 0.64571300E+00, 0.26598600E+00, -.45978500E+00, 0.15730200E+01, -.22114700E+01, -.24096200E+00, 0.38889700E+00, -.27025600E+01, -.17613800E+01, -.83962300E-01, -.55005100E+00, -.87013700E+00, 0.43533700E+01, -.52785500E+00, 0.81849700E+00, 0.75464400E+00, -.30470400E-01, 0.11857800E+01, 0.48887400E+00, -.39573200E+00, 0.22252800E+01, -.12728700E+00, -.16673500E+01, -.30970700E+00, 0.36175100E+01, 0.32622900E+01, -.55055500E-02, 0.57892600E+00, 0.15617300E+01, 0.11453200E+01, -.75807300E+00, -.22769300E+01, 0.13724300E+01, 0.13850100E+01, -.24820700E+01, 0.99516900E+00, 0.57611200E-01, 0.12352300E+01, -.12451600E+00, 0.42377900E+00, -.40606900E+00, 0.39758500E+00, -.26922500E+01, 0.82507000E+00, 0.26673400E+00, -.62736100E+00, -.18986600E+01, 0.68780000E+00, 0.40910600E-01, 0.64958100E-01, -.80642100E+00, -.39791400E+00, -.66135300E+00, 0.15212200E+00, -.12009500E+01, 0.60643600E+00, -.53608400E+00, -.61529400E+00, 0.51380800E-01, -.18716100E+01, -.16079500E-02, -.12690500E+00, 0.15255600E+00, -.25079300E+01, 0.41576400E+02, 0.72193400E+02, 0.36565500E+01, 0.43446100E+02, -.29032000E+04, 0.14551600E+04, 0.12940800E+04, 0.14516300E+04, 0.44323800E+03, 0.56104600E+03, -.56924200E+02, -.39964500E+03, 0.11737300E+04, 0.67724000E+03, 0.16071300E+04, -.40351000E+02, 0.16897400E+02, -.10317100E+02, 0.19413900E+02, 0.67514700E+01, 0.18297500E+02, 0.14345800E+02, 0.55338000E+01, 0.17912000E+01, 0.27187600E+02, 0.45351800E+02, -.25564600E+04, 0.12832100E+04, 0.14118100E+04, 0.12783300E+04, 0.57133200E+03, 0.70796200E+03, -.13721300E+03, -.29616300E+03, 0.12229500E+04, 0.76099500E+03, 0.16345600E+04, -.55500800E+02, 0.31617600E+02, -.91503200E+01, 0.24397000E+02, 0.96198900E+01, -.24614400E+00, 0.32068100E+02, -.68119000E+02, -.13029300E+02, 0.14443600E+01, 0.13241000E+03, 0.33366100E+01, -.17021600E+01, -.70251700E+00, -.16793900E+01, -.37258500E-01, 0.22040700E+01, -.44122200E+01, -.49989200E+01, -.47502200E+01, 0.24635900E+01, -.20251200E+01, 0.10422900E+03, -.40724300E+02, -.14594900E+03, -.53477200E+02, -.94159400E+01, -.44700300E+02, 0.85446200E+01, 0.21913200E+00, 0.53796100E+01, -.36163800E+02, -.77499000E+01, 0.41679400E+03, -.19944500E+03, -.14551000E+03, -.20836500E+03, -.60874100E+00, -.22636700E+03, -.10452600E+03, 0.12871100E+03, 0.22044800E+03, -.13378700E+03, 0.11059000E+03, -.20797200E+04, 0.10402400E+04, 0.10335600E+04, 0.10397900E+04, 0.14783600E+03, 0.40411700E+03, 0.27532400E+03, -.62925300E+03, 0.19049700E+03, 0.30508400E+03, 0.56797700E+03, -.16977700E+01, 0.18335000E+02, -.25693100E+01, 0.39655600E+01, 0.54970400E+01, -.17290500E+02, -.34990900E+01, 0.81367500E+01, -.95953800E-01, 0.17137300E+01, -.84180300E+01, -.13776100E+02, -.20866100E+01, 0.48218300E+01, -.44595700E+01, -.21273400E+01, 0.10725700E+02, -.73163000E+01, -.28678900E+03, 0.28118000E+01, 0.25463300E+03, -.56936300E+01, -.77253200E+00, 0.53754700E+01, -.50722900E+02, -.35450500E+02 },
        { 0.29612300E+00, -.62643500E+00, 0.19073100E+01, 0.40150800E+00, -.13295000E+01, -.34687400E+00, -.32671000E+01, -.14665900E+01, -.40625200E+00, -.20936500E+00, -.14094800E+00, 0.22937100E+01, -.37467700E+00, 0.10828200E+01, 0.18984500E+01, 0.77190100E-01, 0.23068600E+01, -.22637600E+00, 0.12393800E+01, -.77583200E-01, 0.72511900E+00, 0.20661300E+01, -.19099000E+00, 0.35383400E+00, 0.63264600E+00, 0.26076500E+00, -.98244400E-01, 0.45839400E-01, 0.33744000E+00, -.54501800E+00, -.19804200E+00, -.43553000E+00, -.73626500E+00, 0.47012900E+00, 0.31201100E+00, -.48294400E+00, -.51852400E-01, -.61806700E-01, 0.14396900E+00, 0.18682100E-01, 0.26902400E+00, -.11832700E+01, -.15497800E+01, -.14037900E+00, 0.32316000E+00, 0.97783300E-01, 0.10495300E+01, -.70791500E-01, -.47348900E-01, 0.20915400E+00, -.18264400E+00, 0.81329900E+00, 0.34333100E+00, 0.15492300E+00, -.43277500E+00, 0.82644300E+00, 0.19029500E+00, 0.14392600E+01, -.16274300E-01, 0.18453800E+00, -.35649600E+00, 0.71901300E-01, -.21161400E-01, 0.15047900E+00, 0.11863200E+00, 0.55536200E-01, 0.44272600E-01, -.74024600E+00, 0.11005500E+00, -.10954000E-01, 0.11309200E+01, 0.63602100E+00, -.81316700E-01, 0.55507900E-01, 0.14769500E+00, -.34353200E+00, 0.35179100E+00, -.38025800E-01, -.70366100E-01, -.12332900E+00, -.24602900E-01, -.16378000E-01, 0.50120200E+00, 0.69154700E-01, -.15231000E+00, -.17648100E-01, -.76400800E+00, -.40517000E+00, -.64804600E+00, 0.21684100E+00, 0.21652900E+00, -.33571100E+00, -.18140900E+00, 0.13966800E+01, -.37505100E+00, -.77837900E+00, 0.25355000E+00, -.19020600E+00, 0.27734800E+00, 0.99665800E-01, -.59608500E+00, 0.49039400E+00, 0.48887100E-01, -.64393000E-01, -.13439100E+00, -.86645100E+00, -.30255500E+00, 0.42665000E+00, 0.45475900E+00, 0.35686700E-01, -.30344400E+00, -.11091400E+00, -.44195800E+00, -.39027500E-01, -.57424400E-01, 0.44297100E+00, 0.62568800E-01, -.20039600E+01, 0.81267700E-01, -.48681500E-01, -.36471200E+00, -.12970000E+01, 0.62206900E-01, -.25324200E+00, 0.16152400E-01, 0.18878900E+00, -.27425300E-01, 0.35297200E+00, 0.32970200E-01, 0.16685600E+00, 0.24260000E+00, -.56532700E+00, 0.25087600E-01, -.16806700E+00, -.31118500E+00, -.15280400E-01, -.15302200E+00, -.12487200E+00, 0.10228900E-01, -.36398200E+00, -.13327300E+00, 0.58592800E+00, 0.19707000E+00, -.75922600E+00, -.53606600E+00, -.12359100E+00, 0.15461500E-02, -.35358500E+00, -.84604300E+00, 0.30634400E+00, 0.10603300E+01, -.65883300E+00, -.97728500E+00, -.36602900E+00, -.37552300E+00, 0.31798100E+00, 0.54309200E+00, -.25872700E+00, -.26682200E+00, -.89177100E-01, -.52255800E+00, 0.34390000E+00, -.11635500E+00, -.64013700E-01, 0.44479100E+00, -.12991000E-01, -.57763900E-01, -.43677600E+00, 0.57519500E-01, 0.76670900E+00, -.30383500E+00, -.94029300E-01, 0.43630500E+00, -.24705800E+01, 0.38676700E+00, -.51366900E+00, -.16212900E+00, 0.57323500E-01, 0.15511300E+01, 0.15650000E-03, -.23150400E+00, -.84131400E+00, -.51589200E+00, -.78093500E-01, 0.12332000E+02, 0.32959100E+01, 0.27306600E+02, 0.57243100E+03, -.28526700E+03, -.20109900E+03, -.28619800E+03, -.12399000E+03, -.19593600E+03, 0.11536600E+02, 0.32994300E+03, 0.61118700E+02, -.11897400E+03, 0.64587300E+02, -.17866000E+03, 0.87907800E+02, 0.93910500E+02, 0.89167400E+02, 0.24908600E+02, -.34241300E+02, 0.10135400E+03, 0.34496000E+02, 0.58558300E+02, -.26718300E+02, 0.21644500E+02, 0.40705900E+03, -.20179700E+03, -.27661700E+03, -.20347000E+03, -.18372400E+02, -.11764900E+03, -.53497300E+01, 0.24648100E+03, 0.68198800E+02, -.43963000E+02, 0.21322000E+03, -.10835900E+02, 0.77632900E+01, -.16425200E+02, 0.35547200E+01, -.32763700E+02, 0.71426800E+01, 0.41223400E+02, -.14214600E+02, 0.19490700E+02, 0.28551800E+01, 0.60669800E+02, -.62553600E+00, 0.12245400E-01, -.16484800E-01, 0.30300900E+00, 0.44736900E+00, 0.21926500E+00, -.25692700E+01, -.13795600E+01, 0.14187500E+01, 0.21130300E+00, -.68024600E+00, -.99738200E+01, 0.35915300E+01, 0.13166100E+01, 0.44281800E+01, 0.12119800E+02, 0.45274800E+01, -.20509400E+02, -.39203500E+02, -.86949600E+01, 0.22866100E+01, 0.60550400E+02, 0.25511800E+03, -.12255300E+03, -.20017300E+03, -.12753800E+03, -.79923200E+02, -.54161300E+02, -.32057600E+02, 0.41738200E+01, -.13821500E+03, -.16663900E+02, 0.15984300E+02, -.49020200E+03, 0.24388100E+03, 0.25089600E+03, 0.24505600E+03, 0.16942200E+03, 0.10640700E+03, 0.42172200E+02, -.32884700E+02, 0.21448300E+03, 0.82779600E+02, 0.56928500E+02, 0.78677500E+00, 0.24041300E+02, -.84346900E+00, -.85341500E+00, 0.12914700E+01, -.20633200E+01, 0.11543800E+02, 0.23298500E+02, -.26852600E+00, 0.12282300E+01, -.45750800E+01, -.41277500E+01, -.39544500E+01, 0.17907800E+01, 0.22379400E+01, -.13543300E+01, 0.85914500E+00, -.39777400E+01, -.47527600E+02, -.44564800E+01, 0.21896800E+02, -.53163800E+01, -.25105200E+00, 0.70184000E+01, 0.20546000E+01, 0.75069500E+01 },
        { 0.39941100E+00, -.17114600E+01, 0.34390400E+01, 0.70441400E+00, -.11973700E+01, -.27309900E+00, -.33935300E+01, -.28172500E+01, -.90539600E+00, 0.63962200E-01, -.27676900E-01, 0.17470000E+01, -.38015700E+00, 0.79154700E+00, 0.23920600E+00, 0.69164500E-01, 0.12734300E+01, -.16429400E+00, 0.80288700E+00, -.18375000E+00, 0.77319800E+00, 0.81871100E+00, -.49248500E-01, 0.87081700E+00, 0.42581700E+00, -.41567400E-01, 0.41795600E+00, -.61630400E+00, 0.29473300E+00, -.78501700E-01, -.78130400E+00, -.47157300E+00, -.33221600E+00, 0.51506800E+00, 0.29795700E+00, -.14142400E+00, 0.33224900E-02, 0.31515000E-01, 0.13036100E+00, 0.17420800E+00, 0.25137300E+00, 0.61726000E+00, 0.18288300E+01, 0.66167700E+00, -.10919100E+01, -.25020200E-01, 0.20696700E+00, -.20362600E-01, -.30474900E+00, 0.66174000E+00, -.28151900E+00, 0.44291100E+00, 0.28099700E-02, 0.27990100E+01, -.36220000E+00, 0.12634600E+01, -.11565700E+00, 0.72143200E+00, -.20719800E+00, 0.40281700E+00, -.91748600E-01, -.35668400E+00, 0.28607700E+00, -.18591600E+00, -.17440100E-01, -.44510500E-01, 0.14458200E+00, 0.76866300E-01, 0.26965000E+00, 0.34801400E-02, 0.51000400E+00, -.12660300E+01, -.46774200E-01, -.16816300E+00, 0.73988800E-01, -.49152800E+00, 0.19584300E+00, 0.25463000E+00, 0.74525500E-02, -.16225500E+00, -.18336300E-01, 0.66603600E-01, -.25126800E+00, -.23905800E-01, 0.15220700E+00, -.19772100E+00, -.91345200E+00, 0.15114800E+01, -.52868000E+00, -.96468500E-01, 0.15994900E+00, -.25027100E+00, -.73854600E+00, 0.36904000E+01, 0.10783800E+00, 0.45926400E+00, -.39063000E+00, -.49992500E+00, 0.52060000E+00, 0.26665800E+00, -.37584800E+01, 0.42714900E+00, 0.39575300E-01, 0.40704200E-01, 0.16503200E+00, -.13473800E+01, -.20463200E+00, 0.42451200E+00, -.46370900E+00, 0.18658200E+00, -.84737100E+00, -.11582000E+01, 0.11888100E+00, 0.27363200E-01, -.30292700E+00, 0.27136100E+00, -.44622500E-01, -.60155100E+00, -.96960900E+00, -.29805700E-01, -.43435400E+00, -.22783800E+00, 0.93242500E-02, 0.60929900E+00, -.81794400E-01, -.21043300E+01, 0.12902300E+00, -.42642600E+00, -.75134200E-01, 0.54266400E-01, -.40002200E+00, 0.80685500E-01, 0.76896800E-01, -.36306500E+00, -.51939000E+00, -.37098200E-02, -.41046300E+00, -.20018700E+00, -.95543500E-02, -.41290300E+00, 0.23549300E+00, 0.76882600E+00, 0.23869300E+00, -.56288300E-01, 0.88925000E-01, 0.19747900E+00, -.16449100E+00, 0.99404500E+00, -.70505600E-01, 0.22669100E+00, 0.31032400E-03, -.84063200E-01, 0.80025200E+00, 0.60466100E+00, -.12296400E+01, 0.63959700E-01, 0.48963300E+00, -.11271600E+00, -.34405800E+00, -.10899400E-01, -.67205500E-01, -.30854100E+01, 0.17915500E+00, 0.54075600E-01, -.37444400E+00, 0.42990000E+00, 0.15186100E+00, 0.60998100E+00, 0.12900600E+00, -.76898400E+00, -.28300300E+00, -.48004900E+00, -.30636300E+00, -.23882800E+01, 0.42423600E-01, -.64090100E+00, -.32225800E+00, 0.64353400E-01, -.22751800E+00, 0.45727600E-03, -.14582000E+00, -.67257400E+00, -.11092600E+01, 0.23927000E+00, 0.11424600E+01, -.57991700E+01, -.40770900E+02, -.13836600E+04, 0.69157900E+03, 0.71668600E+03, 0.69181800E+03, 0.11225100E+03, 0.14810300E+03, 0.11874000E+03, -.57917100E+03, 0.26655500E+03, -.37228300E+02, -.26513000E+03, 0.35869800E+02, -.15741700E+02, -.25439000E+01, -.17828600E+02, 0.18035600E+02, 0.84689300E+02, -.12137700E+03, -.78428100E+02, -.77606400E+02, 0.82050500E+02, -.49180700E+02, -.12938800E+04, 0.64633100E+03, 0.58669000E+03, 0.64689300E+03, -.34151000E+02, 0.11779200E+02, 0.18649100E+03, -.52328700E+03, 0.33519200E+03, -.16603500E+03, -.39014700E+03, -.88082500E+01, -.21920100E+00, -.76282700E+01, 0.69128400E+01, 0.77777800E+01, 0.10372400E+02, -.45705600E+02, -.56910500E+00, -.31276100E+02, 0.42929000E+01, 0.48776900E+00, 0.81572300E+00, -.11170800E+00, -.10470100E+01, -.40111100E+00, -.76312000E+00, -.17270800E+00, 0.92987200E+00, -.20846800E+01, -.61971000E+00, 0.40344900E-01, 0.14915700E+01, -.34644800E+02, 0.13658600E+02, 0.12856000E+02, 0.17671500E+02, 0.20835300E+02, 0.33661900E+02, -.75139400E+01, 0.15127800E+02, -.19624300E+02, 0.32536300E+02, -.25780000E+02, -.72328300E+03, 0.35585000E+03, 0.40856200E+03, 0.36162600E+03, 0.18827000E+03, 0.24426000E+03, 0.40730200E+02, -.21035200E+03, 0.15307700E+03, 0.19463100E+03, 0.69915700E+02, 0.10186400E+04, -.50855400E+03, -.46729700E+03, -.50928800E+03, -.31464000E+03, -.24324400E+03, -.96681700E+02, 0.25544000E+03, -.33626700E+03, -.20950200E+03, -.24402100E+03, -.45466400E+00, -.36867200E+02, -.23153100E+01, 0.27428100E+01, 0.37278700E+00, -.10282400E+01, -.62770600E+01, -.36823800E+02, -.62073800E+00, -.22645200E+01, 0.37778000E+01, 0.11280600E+01, -.18979300E+01, -.25486100E+01, -.17379200E+01, 0.19202600E+00, 0.38749900E+01, 0.83889500E+00, -.13517600E+02, 0.48938200E+01, 0.21130600E+02, 0.41867100E+01, -.70266000E+00, -.60936800E+01, 0.75678200E+01, 0.96452600E+00 },
        { 0.79282100E-01, -.34579200E+00, 0.38966300E+00, 0.10839400E+00, -.35860700E+00, -.71985000E-01, -.53304300E+00, 0.23441900E+00, 0.12735900E+00, -.21918500E+00, -.28061800E-01, 0.75547400E+00, -.10337200E+00, 0.35158000E+00, -.45879100E-01, 0.20145200E-01, 0.29794700E+00, -.72957700E-01, -.17047400E+00, -.46157200E-01, 0.72396800E-01, 0.11229400E+01, -.60925400E-03, -.18173500E+00, 0.55247400E-01, -.19752000E-01, 0.78031400E-01, 0.21037800E+00, 0.78290100E-01, -.10857900E+00, -.37799800E-01, -.70285200E-01, -.39404600E-01, 0.10191400E+00, -.74516900E-01, 0.20687600E-01, 0.14713300E-02, -.36242100E-01, -.10033500E+00, 0.73836200E-01, 0.13845500E+00, 0.18199500E+00, 0.26876600E+00, 0.15505300E+00, -.22837700E+00, -.27262700E-02, -.80808000E-01, 0.61546900E-02, -.10037300E+00, 0.22533600E+00, -.66669900E-01, -.45896600E-01, 0.55208900E-01, 0.58109100E+00, 0.11565000E+00, 0.43006500E-01, -.13444300E+00, 0.72666900E-01, -.70167400E-01, 0.33310400E-01, -.30471600E-01, -.62988200E-01, -.23808900E-01, 0.55185300E-01, 0.57240500E-02, 0.32981900E-01, 0.42613000E-01, -.46987100E-01, -.14957000E+00, -.12134500E-02, 0.34828100E+00, 0.24621900E+00, 0.34604700E-01, 0.36649700E-01, -.10558400E+00, -.54304300E-02, 0.49925600E-01, 0.54130100E-01, 0.77703000E-01, -.69800700E-01, -.45857700E-02, 0.12092300E-02, 0.25285000E+00, -.81257800E-01, -.36349600E-01, 0.45158400E-01, -.15305400E+00, -.12702500E+00, 0.73730000E-02, -.14528800E-02, 0.25362000E+00, -.56893200E-02, -.12145600E+00, 0.25668700E-02, -.32320600E-01, 0.15248700E-01, 0.53550000E-01, -.70396900E-01, 0.49507700E-01, -.39807500E-02, 0.13626000E+00, -.31770300E-02, 0.20888700E-02, 0.15628500E-01, 0.15141100E-01, -.21699300E-01, -.29463500E-01, 0.24549400E+00, -.28631900E+00, -.11721000E+00, 0.11545700E+00, -.10320300E-01, -.59085500E-01, 0.21209700E-01, 0.39593800E-02, 0.77263800E-01, 0.38729200E-01, -.33984200E+00, -.21928000E-01, 0.23921200E-02, -.31514700E-01, 0.17742100E+00, -.16920100E-01, 0.52720200E-01, -.24208900E-01, 0.65945900E-01, -.51795300E-01, 0.15592800E+00, 0.25453300E-01, -.10689600E+00, 0.66092400E-01, 0.96346300E-01, -.10475700E-01, -.53481300E-01, 0.15295600E-02, -.10250000E-02, -.47677900E-01, 0.97518400E-01, 0.92263700E-02, 0.37823200E-02, -.24194200E-01, 0.23982700E-01, -.45673900E-01, 0.92680100E-01, -.19723900E+00, -.71181300E-01, -.24865500E-01, 0.13455700E+00, -.82574700E-01, 0.42563800E-01, -.27882500E-01, -.44739300E-03, 0.17017200E+00, 0.25528000E+00, -.93502400E-01, -.65753300E-01, 0.23066400E+00, -.13261300E-01, -.31556200E-01, -.71370300E-01, 0.12577600E+00, -.37892900E+00, 0.69965700E-01, 0.15313100E-02, -.86953700E-01, 0.35932800E-01, 0.21188800E-02, 0.65207900E-01, 0.84444600E-02, -.40755100E-01, 0.16637300E+00, 0.13768200E+00, -.91292500E-02, 0.90272400E-01, -.19787500E-01, -.23820000E-01, -.32563100E-01, -.41806500E-02, -.76513900E+00, 0.25468100E-03, -.38323300E-01, -.15114500E+00, -.44648500E+00, 0.19141700E-01, 0.42899600E-01, -.15896000E+00, -.46628200E+01, -.79890100E+02, 0.39766700E+02, 0.80629400E+02, 0.39943700E+02, -.40077100E+02, -.35837600E+01, -.20829800E+01, -.74045400E+02, -.13899500E+02, -.22958900E+02, -.60208100E+02, -.50728900E+01, 0.29349900E+01, 0.74542200E+01, 0.25108000E+01, 0.55047800E+01, 0.19829200E+02, -.25640900E+02, -.21992400E+02, -.20315300E+02, 0.21343900E+02, -.78144600E+01, -.14068200E+03, 0.70052000E+02, 0.28606700E+02, 0.70337600E+02, -.49554800E+02, -.24092400E+02, 0.21521800E+02, -.80117400E+02, 0.13108400E+02, -.41839300E+02, -.38281000E+02, -.29015400E+02, 0.13886800E+02, -.10814000E+01, 0.14698300E+02, 0.14753600E+02, 0.10562800E+02, -.25294800E+02, -.10867100E+02, -.96484800E+01, 0.11519200E+02, 0.13686700E+02, 0.29578200E+00, -.74113100E-01, -.31152800E+00, -.14717300E+00, -.11251900E+00, -.50730300E-01, 0.26011100E+00, -.32814800E-01, 0.69197700E-01, -.74660700E-01, 0.34344300E-01, 0.18138200E+02, -.10774400E+02, -.13280600E+02, -.90756700E+01, -.39253100E+01, -.78114600E+01, 0.37085900E+00, 0.10407100E+02, 0.14114600E+01, -.57290600E+01, -.44899400E+01, -.16406300E+03, 0.80445300E+02, 0.75811100E+02, 0.82030000E+02, 0.47924100E+02, 0.54455400E+02, 0.65489200E+01, -.62056800E+02, 0.22693900E+02, 0.50506500E+02, 0.39562700E+02, 0.23852500E+03, -.11904900E+03, -.92548000E+02, -.11926000E+03, -.66396600E+02, -.56811200E+02, -.25544600E+02, 0.80241000E+02, -.62074400E+02, -.53388700E+02, -.71091300E+02, -.22675200E+00, -.87010300E+01, -.53415500E+00, 0.29420600E+00, -.40871400E+00, -.27676800E+00, -.15550800E+01, -.84000000E+01, -.12890700E+00, -.69728000E+00, 0.35576000E+00, 0.55228900E+00, -.39811300E+00, 0.21895800E+00, -.38794100E+00, 0.21457900E-01, 0.65745000E+00, -.18190400E-01, 0.10505400E+02, 0.21155300E+01, -.77275600E+01, 0.12864800E+01, -.12620300E+00, -.32693600E+00, 0.21135000E+01, 0.16389200E+01 },
        { 0.50117100E+00, -.84877300E+00, 0.50300500E+01, 0.68899600E+00, -.16252900E+01, 0.81864800E-02, -.18469800E+01, -.14931300E+01, -.81151700E-01, 0.43534200E+00, 0.24640100E+00, 0.16305700E+01, -.88364800E+00, -.46242700E+00, 0.12210400E+01, 0.23739500E+00, 0.15416800E+01, -.76649400E-01, -.33337100E+00, 0.56281500E+00, 0.73005200E+00, -.25245300E+01, -.20413900E+00, 0.12075900E+01, 0.25466600E+00, 0.40818000E+00, -.38488300E+00, -.12647200E+01, -.47168400E+00, 0.42561900E+00, -.15605000E+00, 0.70143900E-01, 0.13981300E+01, -.87534300E+00, 0.62866200E-01, -.74431500E+00, 0.93114700E-01, -.12338600E+01, 0.54422500E+00, -.15424300E+01, -.12617500E+00, 0.74355200E+00, -.16800000E-01, -.31188500E+00, -.92799000E+00, 0.31045700E+00, 0.57804200E+00, -.40519800E-01, -.28308100E+00, 0.27185700E+00, -.80051500E+00, 0.13694200E+01, -.15018400E+00, -.23172400E+01, -.38015800E-01, -.71192800E+00, -.21892200E+00, -.41549400E+00, 0.24358400E+00, -.66840800E+00, 0.53123000E+00, 0.52659000E+00, 0.18501100E+00, -.41204100E+00, -.62067300E-01, -.31079600E+00, 0.23136300E-01, 0.19473100E+00, 0.41801500E+00, 0.44585900E-02, -.50931100E+00, 0.81137900E+00, -.30432400E+00, -.10504000E+00, 0.98167600E-01, -.38790600E+00, -.33058100E+00, -.25018200E+00, -.47493400E-01, 0.51842800E+00, 0.33353900E-01, -.66092000E-01, -.93254800E+00, 0.27823400E+00, 0.23929800E+00, -.20032300E+00, 0.29597900E+00, -.88029800E+00, -.73071500E+00, 0.19990500E+00, -.20057600E+01, 0.15730800E+00, 0.82607900E+00, -.19687500E+01, 0.56126400E+00, 0.18969200E+01, -.59037700E-01, -.11830600E+00, -.23982900E+00, 0.15704800E-01, -.16793500E+01, -.81857500E+00, -.26707900E-02, 0.39485800E+00, 0.26947600E+00, 0.36912700E-01, -.54887700E+00, 0.58973100E-01, 0.32401500E+00, 0.14031700E+01, 0.10713600E+01, 0.67574900E+00, 0.20495800E+00, 0.38813500E+00, -.14876100E+00, -.58700500E-01, 0.18344800E+00, 0.37529200E+01, 0.93180800E+00, 0.58273600E-01, 0.28353800E+00, 0.87382000E+00, -.52666500E+00, 0.11638700E+01, 0.66489700E-02, 0.20639500E+01, -.64206200E+00, -.64334700E+00, -.49056700E-01, -.23832200E+00, 0.54032800E+00, -.76267000E+00, -.10975500E-01, 0.21110400E+00, 0.92361800E-01, 0.12397800E-01, -.77482300E+00, -.11328500E-01, -.30040800E+00, 0.84493800E+00, 0.10557400E+00, -.11189600E+01, -.45023100E+00, 0.25746900E+00, 0.95459600E+00, -.80059700E-01, 0.18406800E+00, -.26206600E+00, 0.90647500E+00, -.60836600E+00, -.64286300E+00, 0.66826700E+00, 0.98256500E-01, -.93239400E+00, -.76920000E-01, -.22525600E-01, 0.18112700E+00, 0.54693000E-01, 0.71955600E-01, 0.78292200E+00, -.35719300E+00, -.22118800E+01, -.34062300E+00, -.35630300E-01, -.20090100E+00, 0.14599900E+01, 0.19495500E-01, 0.41995500E+00, 0.82446800E-01, 0.62218900E+00, 0.97632400E+00, 0.38252400E+00, 0.19967800E+00, 0.12138900E+01, -.33538400E+00, 0.85843100E+00, 0.13897900E+00, -.15548600E+00, 0.43905200E+01, 0.33069800E-02, -.16175700E+00, -.11108900E+01, 0.82112200E+00, -.28720600E+00, -.19574800E+00, 0.44980300E+00, -.36312000E+01, 0.10448700E+04, -.52280500E+03, -.43312700E+03, -.52241500E+03, -.24245500E+03, -.91077000E+02, -.17772000E+03, 0.20388200E+03, -.29972600E+03, -.11095400E+03, -.16718900E+03, -.45734600E+02, 0.24137000E+02, 0.79232800E+02, 0.22441600E+02, 0.34724200E+02, 0.11808200E+03, -.74472900E+02, -.78947200E+02, -.86996900E+02, 0.13482300E+03, -.42997400E+02, 0.70264800E+03, -.35287200E+03, -.41483500E+03, -.35125600E+03, -.13749100E+03, -.40254100E+02, -.33856800E+02, 0.14436300E+03, -.26032800E+03, -.48759100E+02, -.43300500E+02, 0.24728600E+02, -.94805100E+01, -.22908800E+01, -.14455000E+02, -.15238800E+02, -.84067500E+01, -.12080700E+02, -.18531700E+02, -.20143300E+02, 0.12370000E+02, 0.80274600E+01, 0.17106200E+01, -.37733600E+00, 0.23377300E+00, -.86619700E+00, -.49523300E+00, -.31134600E+00, 0.12369100E+01, -.12404800E+00, 0.80096000E+00, -.22522100E-01, -.54048500E+00, -.44820400E+02, 0.20799400E+02, -.30015900E+02, 0.21545800E+02, 0.49426900E+00, -.12694200E+02, 0.23021900E+02, 0.17540400E+02, 0.14248100E+02, -.13595700E+02, 0.30459300E+02, -.26351000E+02, 0.82676400E+01, -.42359200E+02, 0.13199600E+02, 0.13302100E+03, 0.15352700E+03, -.69544100E+02, -.20553000E+03, -.18546400E+03, 0.15739600E+03, 0.90950500E+02, 0.62842500E+03, -.31047000E+03, -.21474500E+03, -.31426400E+03, -.23152700E+03, -.16565800E+03, 0.43829200E+02, 0.52349800E+03, 0.77502100E+02, -.19005300E+03, -.34465600E+03, -.86744700E+00, -.35393800E+02, -.26805000E+01, 0.14818700E+00, 0.36154500E+01, -.32641900E+01, -.67229700E+01, -.26440800E+02, -.31508400E+00, -.36337100E+00, -.38913000E+01, 0.92950300E+00, 0.71977700E+01, 0.29951900E+01, -.37548900E+01, 0.56857800E+00, 0.55287800E+01, -.47596900E+00, 0.41272100E+02, 0.13770200E+02, -.49686400E+02, 0.20892500E-01, -.30098900E+00, -.20666000E+01, 0.29075800E+02, 0.25862800E+02 },
        { 0.68864100E+00, 0.46281200E+01, -.10309900E+01, 0.32476800E+00, -.10105200E+01, -.10984400E+01, -.17829900E+01, -.66895000E+00, -.33804100E+00, -.57293900E+00, -.14580900E+00, 0.96267600E+00, 0.36209800E+00, 0.15158200E+00, -.16573800E+01, -.88373200E-01, -.22584300E+00, -.22668900E+00, -.20621200E+01, 0.46339500E+00, -.13970900E+01, 0.44585900E+01, 0.36284600E+00, 0.21374200E+01, -.28481700E+00, -.59139800E-01, 0.16754700E+01, -.38937000E+00, 0.25161800E+00, -.12702600E+00, 0.76753200E+00, -.57038000E+00, 0.12399600E+01, 0.11891100E+00, 0.14699500E+00, 0.29083700E+00, 0.11645800E+00, 0.20540500E+00, 0.48694600E+00, -.12058300E+01, -.12916100E+01, 0.61934700E-01, -.11450900E+01, -.60541300E-01, 0.15953100E+01, -.16806400E+00, 0.96723900E-01, 0.14337500E+00, 0.44308600E+00, -.79688800E+00, 0.10010500E+01, -.49848900E+00, 0.73671400E+00, -.32888800E+01, -.18267700E+01, -.35048600E-01, 0.68937100E+00, 0.48640300E+00, -.48026400E+00, 0.96364700E+00, -.14028500E+01, 0.15672700E+00, -.41787900E+00, 0.55864000E-01, 0.79144100E+00, -.32146300E+00, -.65037400E+00, -.82107200E+00, 0.79685600E+00, -.16519700E-02, 0.44633900E+00, -.15353300E+00, -.10623400E+00, 0.24700500E-01, -.36072500E+00, 0.50802500E+00, 0.31981200E+00, -.13243100E+01, 0.44445900E+00, -.60688800E-01, -.14252400E-01, -.11772500E+00, 0.53689300E+00, -.13637900E+00, 0.68879600E-01, 0.19474500E+00, -.68696800E+00, -.11337600E+01, -.70051700E+00, 0.32103100E-02, 0.15404100E+01, -.15021200E-02, -.55739400E+00, 0.28994500E+01, 0.13851100E+01, 0.20615800E+01, 0.55922900E+00, -.42595300E+00, 0.72322500E+00, 0.70695600E+00, -.32112500E+01, -.74893200E-01, 0.16590900E-01, -.11483100E+00, -.76946900E-01, -.11965800E+01, -.48926000E+00, 0.78833200E+00, -.38823100E+00, 0.22260800E+00, 0.66657300E+00, -.22703400E+00, 0.36825400E+00, 0.24850800E-01, -.11236600E+00, -.42722400E+00, -.54512500E-01, 0.32595900E+01, 0.12437600E+01, 0.29708400E-01, 0.46094800E+00, 0.64815500E+00, -.82518600E-01, -.74822900E+00, -.12375400E+00, -.74829800E+00, -.17197700E+01, 0.16343300E+00, -.13180600E+00, 0.24895600E+00, 0.66244600E+00, -.74485600E+00, 0.10809800E+00, 0.17322300E+00, -.56062400E+00, 0.22742200E-01, -.83746200E+00, -.27177700E+00, -.48663400E-02, 0.52121900E+00, -.33926600E+00, 0.81471100E+00, -.19366600E+00, -.96101300E+00, -.17899400E+01, -.24022100E+00, 0.74527500E-01, 0.95193800E-01, -.24553000E+00, -.15548000E+00, 0.66855100E+00, 0.14231800E+00, -.63368900E+00, 0.51607300E+00, -.51448000E+00, 0.25683000E+00, -.10846000E+01, 0.62198900E-01, 0.80975400E-01, 0.84378200E-01, 0.38025900E+00, 0.51844800E+00, 0.70031700E-01, -.27454600E-01, -.22127200E-01, 0.14073900E+00, -.10467000E+00, 0.71722200E-01, -.14988100E-01, 0.13242100E+00, 0.28947600E+00, -.22727800E+00, -.17500300E+00, 0.76161100E+00, -.51700700E-01, -.19556700E-01, 0.82026800E-01, 0.79244100E-01, -.23920500E+01, -.18110200E-02, 0.32176500E+00, 0.59735300E+00, 0.70066700E+00, -.80596900E-01, -.55711500E+00, -.37406700E+00, -.19889500E+00, -.76086000E-01, 0.74336100E+01, 0.33423900E+01, 0.42211000E-02, -.47941500E+02, -.52326600E+02, -.34825200E+00, -.23325600E+02, -.86489400E+02, -.43370900E+02, -.21602500E+02, -.56496200E+02, 0.27570100E+02, 0.48762700E+01, 0.28097000E+02, 0.16431300E+02, 0.15059600E+02, 0.10973400E+02, -.98893700E+00, 0.90626600E+01, 0.20467700E+02, 0.57487000E+01, -.27351500E+02, 0.15983100E+02, -.32869900E+01, 0.13693800E+02, 0.78098600E+01, -.13516900E+02, -.38512200E+01, -.26976400E+02, -.79876300E+02, -.16295500E+02, -.46720300E+01, -.57597700E+02, 0.26966800E+02, -.11210700E+02, 0.28214700E+02, 0.22176300E+02, 0.18325700E+02, -.44001400E+01, -.19143300E+02, 0.19109900E+02, 0.15610700E+02, 0.17605200E+02, -.15919900E-02, -.70699000E-01, 0.15157800E+00, -.87985400E-03, -.11070100E+00, -.11710600E+00, 0.15097100E+00, 0.11309300E+00, 0.47201300E+00, -.27672100E+00, -.38837700E+00, 0.23834800E+02, -.15938800E+02, -.15692700E+02, -.12164300E+02, 0.31529700E+01, 0.73950400E+01, -.15611600E+02, -.15333500E+02, -.14216600E+02, 0.61281000E+01, 0.10526700E+02, -.14158800E+03, 0.71700300E+02, 0.81850500E+02, 0.70799400E+02, 0.19514600E+02, 0.59441300E+02, -.17092300E+01, -.81251000E+02, -.70117700E+01, 0.62689300E+02, 0.58917400E+02, 0.22040800E+03, -.11133100E+03, -.91787400E+02, -.11021600E+03, -.42267400E+02, -.54741000E+02, -.15241400E+01, 0.97247700E+02, -.32069300E+02, -.52538200E+02, -.10288400E+03, -.25447700E+00, -.57909600E+01, -.14679400E+01, 0.25425800E+01, -.26274400E+01, -.12066400E+01, 0.83034200E-01, -.49588600E+01, -.11322400E+00, 0.84676900E+00, -.21264800E+01, 0.27023000E+00, -.21866800E+01, 0.21018900E+01, 0.37255300E+01, -.46634700E+00, 0.26235000E+01, -.65942800E+00, 0.26795000E+02, 0.11908200E+00, -.19599800E+02, -.15048200E+01, -.80363700E-01, 0.83149800E+00, 0.32756200E+01, 0.21897900E+01 },
        { 0.85225000E+00, -.58820800E+00, 0.56158400E+01, 0.39959500E+00, -.24246400E+01, -.13967700E+01, -.33607400E+01, 0.34866400E+01, 0.54340600E-01, -.16389300E+01, -.10649700E+01, 0.26499000E+01, 0.42099600E+00, 0.10764100E+01, -.14214700E+01, -.16535600E+00, 0.82720400E+00, -.41941200E+00, 0.25698400E+01, -.92426900E+00, 0.19182700E+01, -.59297400E+01, 0.19459400E+00, 0.48739000E+01, 0.94384700E+00, 0.76541300E+00, 0.32501100E+01, -.18427300E+00, -.27423900E-01, -.96361700E+00, 0.24341400E+01, -.90187300E-01, -.10817800E+00, -.13580500E+01, 0.52299100E+00, -.27566200E+00, 0.14337700E+00, -.22083100E+01, -.12741300E+01, -.14555600E+01, 0.93876600E+00, 0.24002600E+01, -.19151400E+00, -.77687200E+00, -.23095400E+01, -.95034700E+00, 0.21785900E+01, 0.21224300E+00, 0.21949200E+00, -.11032600E+01, -.13475800E+01, 0.12435600E+01, 0.23834700E+00, -.15995100E+01, -.60485300E-01, -.13653200E+01, -.20310000E+01, 0.85555300E+00, -.41880600E+00, -.42143000E+00, -.18444700E+00, 0.74876500E+00, -.79156100E+00, -.36295100E+00, 0.16124300E-02, -.22837900E+00, -.40400800E+00, -.41959100E+00, -.72486600E+00, 0.71512400E-02, 0.17678600E+01, 0.22303100E+01, 0.16678700E+00, 0.16576500E+00, 0.10090300E+01, -.19609200E+00, -.66536400E-01, -.77560200E+00, -.55047700E+00, 0.47829800E+00, 0.13170400E-01, -.44161700E+00, -.12047400E+01, 0.45534300E+00, 0.72957200E-01, 0.19225000E-01, -.16559300E+01, -.12887600E+00, -.18944500E+01, 0.60954400E+00, -.19796300E+01, -.53279200E+00, 0.48160000E+00, 0.16309200E+01, -.13037100E+01, -.24459800E+01, 0.26944600E+01, -.12259200E+01, 0.43673700E+00, 0.41099500E+00, 0.26520300E+01, 0.97084200E+00, -.30411300E-01, -.25129800E+00, -.77771700E+00, -.12165000E+01, -.12901800E+01, 0.14125400E+01, 0.17919500E+00, 0.25065000E+01, -.18308100E+01, 0.31216500E-01, -.94785300E+00, -.76562400E-01, -.64755100E+00, 0.11815100E+01, 0.43136700E+00, -.64511600E+01, 0.90844300E-01, -.19237200E+00, -.56485600E+00, 0.38294900E+00, -.34333300E-04, 0.59335800E+00, -.23479900E+00, 0.20748900E+01, 0.62376000E+00, -.23303200E+01, -.18817100E+00, 0.27517600E-01, -.72787400E+00, -.16588300E+00, -.57036900E-01, -.29886000E+00, 0.10564500E+01, 0.59954700E-02, 0.10329600E+01, 0.12122200E+01, -.32063300E+00, -.53106100E+00, 0.57781700E+00, -.31603000E+01, -.40286400E+00, 0.39866000E+00, 0.96659200E+00, -.35864200E-01, -.36388000E+00, -.18262600E+00, 0.45795900E+00, -.33619000E+00, 0.67111400E+00, -.58819300E+00, 0.16093400E+01, 0.67001300E+00, 0.34222200E+00, -.71162400E+00, 0.16817800E+01, 0.26515400E-01, -.11398100E+01, -.25612500E+00, -.59772000E+00, 0.56422200E+01, -.61055600E+00, -.62858400E-01, 0.87700100E+00, 0.59161900E+00, 0.31996200E-01, -.35964700E+00, -.90261200E-01, 0.16415600E+01, 0.14796300E+00, 0.19388700E+00, 0.10922800E+00, 0.45234300E-01, 0.21178400E+00, 0.20580800E+01, 0.12207200E-01, -.19729700E-01, 0.87752800E+00, 0.36764600E-02, 0.27088400E+00, -.40605800E+00, 0.15361800E+01, -.62681200E+00, -.73339100E+00, -.60114600E+00, 0.34057600E+01, 0.42365600E+00, 0.22358400E+00, -.33355900E+03, 0.51252100E-02, 0.28565100E+03, 0.67127400E+02, 0.13478000E+03, 0.40462000E+03, 0.41775700E+03, 0.10985800E+03, -.61670300E+02, 0.22804800E+03, -.11877400E+03, -.74225700E+02, -.11417400E+03, -.66268500E+02, -.10385500E+03, 0.33973800E+02, 0.87541700E+02, 0.27115700E+02, -.11966600E+03, -.12316100E+02, 0.66883700E+03, -.33236100E+03, 0.34391000E+02, -.33439600E+03, 0.25702500E+03, 0.87341000E+02, -.10216400E+02, 0.50249500E+03, 0.22894400E+03, 0.12441500E+03, -.42890200E+03, 0.22051500E+03, -.10567400E+03, 0.15357600E+02, -.11125300E+03, -.11911200E+03, -.70806000E+02, 0.13544800E+03, 0.89993500E+02, 0.22542900E+02, -.91961900E+02, -.59616300E+02, 0.17612200E+01, -.12212200E+01, 0.67724000E+00, -.88206600E+00, 0.45338800E+00, 0.25650400E+01, -.34363200E+01, 0.56712000E+00, -.37911200E+01, 0.24831900E+01, 0.12437500E+01, -.92370200E+02, 0.66196900E+02, 0.65771900E+02, 0.45891100E+02, 0.54996300E+02, 0.74535200E+02, -.30928200E+02, -.67416000E+02, -.37046100E+02, 0.57752500E+02, -.10995500E+01, 0.81753200E+03, -.39593900E+03, -.29425400E+03, -.40876000E+03, -.17829100E+03, -.29718500E+03, -.15594600E+01, 0.33435000E+03, -.47273300E+02, -.28736300E+03, -.37139700E+03, -.15735600E+04, 0.78480700E+03, 0.56430600E+03, 0.78676700E+03, 0.32596300E+03, 0.40473800E+03, 0.87078300E+02, -.47326700E+03, 0.33776600E+03, 0.36370600E+03, 0.75899900E+03, -.69514400E+00, 0.39774700E+02, 0.15521200E+01, -.45687600E+01, 0.44796300E+01, -.21873100E+01, 0.58783000E+01, 0.35068200E+02, 0.13671100E+01, 0.50603300E+01, -.37562900E+00, -.40129500E+01, 0.38719900E+01, -.49112900E+01, 0.23285400E+01, 0.13039000E+01, -.35497800E+01, 0.33119100E+01, -.14081800E+03, -.10139900E+02, 0.11434100E+03, -.54787900E+01, 0.76866600E+00, 0.33857200E+01, -.15618400E+02, -.12790100E+02 },
        { 0.68163100E+00, -.23862500E+00, 0.50181400E+01, -.30600100E+00, -.37494700E+01, -.62672600E+00, -.60579100E+01, -.23945500E+01, -.54820400E+00, -.71763100E+00, 0.73752700E-02, 0.45175100E+01, -.50232400E+00, 0.58678900E+00, -.28871700E+00, 0.40335800E+00, 0.35161400E+01, -.76654400E+00, -.96466600E+00, -.10920900E+00, -.55561100E+00, 0.53567500E+01, -.66695000E-01, 0.35868200E+00, 0.20387300E+00, 0.70775900E-01, 0.14821200E+01, -.54317300E+00, 0.29147800E+00, -.15210000E-01, 0.64162400E-01, -.47708700E+00, 0.16339900E+01, 0.13209200E-01, 0.18987600E+00, 0.35943300E+00, 0.10934500E+00, 0.57380600E-01, -.31491200E+00, -.10508400E+01, -.10602800E+01, 0.12505100E+01, 0.51582000E+00, 0.39982900E+00, 0.37164000E+00, -.48696200E+00, -.53143800E+00, 0.17474100E+00, 0.34436400E+00, -.68976900E+00, 0.12860700E-01, -.49289400E+00, 0.10914300E+01, -.49216100E+01, -.20001200E+01, -.42541300E+00, 0.63465200E+00, 0.13891000E+01, -.67922600E+00, 0.11522600E+01, -.18747600E+01, 0.78361800E-01, -.33666100E+00, 0.16421600E+00, 0.84583300E+00, 0.12262700E+00, -.24161000E+00, -.47024400E+00, 0.10594700E+00, 0.42462900E-02, 0.59677000E+00, -.53862500E+00, -.32970500E-01, -.33554600E-01, -.16644800E+00, 0.20898500E+00, 0.15203500E-01, -.10606000E+01, 0.14348800E+00, 0.87857600E-01, 0.60404300E-02, -.11485200E+00, 0.68604000E+00, 0.49658000E-01, 0.53457600E-01, 0.24968300E+00, -.74872300E+00, -.18089600E+01, -.13580600E+01, 0.35382600E+00, 0.12145000E+01, 0.29086500E+00, 0.23055200E+00, -.10526100E+01, 0.25360600E+00, 0.10832400E+01, 0.64930900E+00, 0.19619200E-01, -.19558400E+00, -.84345600E-01, 0.12130400E+01, -.57903400E+00, -.54834400E-01, 0.27400600E+00, 0.27093500E-01, -.24599700E+00, -.40819600E+00, 0.10112500E+01, -.34688700E+00, -.34179500E+00, 0.20113400E+00, 0.91758100E+00, 0.49997700E-01, -.19272300E-01, -.19121900E+00, -.73416300E+00, -.14377400E+00, 0.37271000E+01, 0.13694200E+01, -.15910300E-01, 0.83373100E+00, 0.90609000E+00, -.12869800E+00, -.12559300E+01, -.68699800E-01, -.18302700E+00, -.18965800E+01, 0.18869800E+00, -.19543600E-01, -.25363400E-01, 0.23191000E+00, 0.71022300E-01, -.50619600E-01, 0.29378000E+00, -.40048700E+00, 0.14374700E-01, -.40148500E+00, -.21099900E+00, -.19436200E+00, 0.83755500E+00, -.36086400E+00, 0.31692800E+00, -.17929800E+00, -.45030200E+00, -.82760200E+00, -.19325900E+00, 0.15765100E+00, 0.42852600E+00, -.28993900E+00, -.66184800E-01, 0.59680700E+00, 0.70101900E-01, -.78946800E-01, 0.17690800E+00, -.12080300E+00, 0.39078900E-02, -.46595000E+00, -.10794000E-01, 0.31112400E+00, 0.25169900E+00, 0.43536500E+00, 0.85580300E-01, 0.22016400E+00, -.10063500E+00, 0.12627100E-01, 0.29680200E+00, -.77470000E-02, 0.38088100E-01, -.23619300E-02, -.14828900E-01, 0.33544200E-01, -.12459100E+00, 0.38779900E-01, 0.38892300E-01, 0.38161500E-01, -.18424100E-01, 0.26217500E-01, 0.14947500E-01, -.12672200E+01, 0.12873100E-02, 0.29902800E+00, 0.84225400E+00, 0.11120600E+01, -.44471700E-02, -.62651300E+00, -.67049900E-01, -.10791100E+01, 0.79102100E-03, 0.18605700E-01, 0.30285800E-01, 0.34745300E+01, -.61987800E+02, -.93811500E+02, 0.22697900E+02, 0.40658800E+00, -.71100000E+02, -.76677200E+02, -.14258400E+03, -.98497600E+02, 0.49179500E+02, 0.36416200E+02, 0.49058000E+02, 0.70409500E+01, -.16460900E+02, 0.40674000E+02, 0.16061000E+02, 0.33032000E+02, -.11374800E+02, 0.13373800E+02, 0.45684000E+01, -.16326500E+01, -.11126100E+02, -.22808800E+01, -.31731000E+02, -.47364100E+02, 0.63082700E+00, -.73895000E+01, -.77964300E+02, -.45269300E+02, -.14114100E+03, -.49394400E+02, 0.23674900E+02, -.12737100E+02, 0.25419200E+02, 0.85634000E+01, 0.17838200E+02, -.17655100E+01, -.11001900E+02, 0.27660300E+02, 0.97938100E+01, 0.17422100E+02, -.50585200E-01, -.13611700E+00, 0.89004500E-01, 0.28225300E-01, -.74083100E-01, 0.52538100E-01, -.76027700E+00, -.55419900E+00, 0.27636900E+00, -.17153100E+00, -.16891200E+00, -.93917400E+01, 0.80597200E+00, 0.93495000E+01, 0.45394800E+01, 0.77846500E+01, 0.10556100E+02, -.20004300E+02, -.36803000E+02, -.20156300E+02, 0.10502700E+02, 0.23035500E+02, -.14679400E+03, 0.73774000E+02, 0.74111400E+02, 0.73395400E+02, 0.29737100E+01, 0.50214100E+02, -.18162300E+01, -.63933600E+02, 0.82982600E+01, 0.56329300E+02, 0.29933200E+02, 0.15830600E+03, -.80192800E+02, -.61951200E+02, -.79151100E+02, -.18360000E+02, -.43840400E+02, -.12516400E+02, 0.42595800E+02, -.31541200E+02, -.39955300E+02, -.52322700E+02, -.28569600E+00, -.35808300E+01, -.53613800E+00, 0.19704100E+01, -.18721200E+01, -.15229100E+01, 0.34877100E+01, -.34267200E+01, -.15238900E+00, 0.11433700E+01, -.17919500E+01, -.13060200E+01, -.45991100E+01, 0.12609300E+01, 0.26275700E+01, -.11491400E+01, 0.19284600E+01, -.10010900E+01, 0.26415600E+02, -.23202000E+01, -.20099500E+02, -.29824400E+01, -.17481600E+00, 0.12964000E+01, -.15872800E+01, 0.38054800E+00 },
        { 0.39414700E+00, 0.12989500E+01, 0.14069300E+01, -.17460500E+00, -.14985900E+01, -.47469900E+00, -.10887500E+01, 0.22285900E+01, 0.76991000E-01, -.80671000E+00, 0.31312000E+00, 0.61642200E+00, 0.11459400E+00, 0.13932900E+00, 0.14578000E+01, 0.22001800E+00, 0.20963800E+01, -.37209200E+00, 0.88334800E-01, -.34052500E+00, 0.53890300E+00, 0.20992700E+01, 0.15669300E+00, 0.23121700E+00, 0.43161300E+00, -.32274400E-01, -.19053200E+00, -.36155600E+00, 0.47506300E-01, 0.93220500E-01, -.61719500E+00, -.87775900E-01, 0.73032100E+00, -.19467200E+00, -.29332200E+00, -.15259500E-01, 0.35934100E-01, -.60023800E+00, 0.28463000E-01, -.24724000E+00, 0.27341300E+00, 0.14634300E+01, 0.81898000E+00, -.30644000E+00, -.23845900E+00, 0.16559300E+00, 0.48974800E+00, 0.15877400E-01, -.79462300E-02, 0.51887100E+00, 0.58980000E+00, -.37435400E+00, -.97131700E+00, -.58533100E+00, -.31566000E+00, -.39042300E+00, 0.11446600E+00, -.58071700E+00, 0.20238700E+00, -.63008900E-01, -.25936400E+00, 0.15477400E+00, 0.15731300E+00, 0.13506000E+00, -.12787900E+00, -.20509300E+00, -.42819300E+00, -.29817500E+00, 0.61834500E+00, 0.11958500E-02, -.14776600E+01, -.15236900E+01, 0.13487100E+00, 0.63187300E-01, -.27799600E+00, 0.74182300E+00, 0.18620000E+00, -.10290200E+01, 0.29483700E+00, -.94255100E-01, -.80771900E-02, 0.96001800E-01, 0.30452400E+00, -.10035100E+00, -.30055600E+00, -.12593800E+00, -.43626500E-01, -.88938400E+00, 0.91786500E+00, 0.39646800E-01, 0.12842100E+01, -.81024800E-01, -.32134800E-01, -.43853700E+00, 0.25219900E+00, 0.11221400E+00, 0.16153000E-01, 0.21001900E+00, 0.75325700E+00, -.17679400E+00, -.30752000E+00, -.30458100E+00, 0.11728400E-01, -.37072200E+00, -.30110200E+00, 0.11234300E+01, 0.68896100E+00, 0.13243000E+01, -.12408300E+01, -.22160300E+01, -.33246500E+00, 0.39347500E+00, -.49422300E+00, -.79007500E-01, -.17451800E+00, -.48972500E+00, -.25171000E+00, 0.42179600E+00, -.75830900E+00, 0.22548200E-01, -.37531000E+00, -.22520400E-01, 0.19046700E+00, -.11799900E+01, 0.17074400E+00, -.75998200E+00, -.11352500E+00, -.56431200E+00, 0.26684700E-01, 0.41185200E+00, -.31020000E+00, 0.88252600E+00, -.13318000E+00, 0.33901600E+00, -.38196800E+00, -.28104700E-01, 0.53775100E+00, -.39060800E+00, 0.22040300E-01, -.21418100E-01, 0.60986200E-01, 0.29023700E+01, 0.45973300E+00, -.15726300E-01, -.24076600E+00, 0.49308500E-01, 0.29317700E+00, 0.47742700E+00, -.21078700E+00, -.48070400E+00, 0.57829600E-01, 0.23382100E+00, -.11856800E+01, -.98964600E+00, 0.33458800E+00, 0.48041600E+00, 0.33284400E-02, 0.35700300E-02, 0.28887600E+00, 0.22922900E-01, -.79780800E+00, -.27876100E+01, -.12855000E+00, -.68745500E-01, 0.17561900E+00, -.24549800E+00, 0.10350500E+00, -.16489000E+00, -.19867600E-01, -.51097100E+00, -.49224200E+00, 0.21359600E+00, 0.28311700E-01, -.12592600E+01, 0.19708800E+00, -.15636000E+01, -.16129800E+00, 0.10076000E-01, -.15128100E+01, -.47875800E-02, -.21922600E+00, -.91798200E+00, -.19003000E+01, 0.38706000E+00, 0.30464400E+00, 0.10291700E+00, -.23737100E+01, -.23428000E+00, -.94310300E-01, -.37214600E+00, 0.21499000E-02, -.13127900E+03, 0.77956200E+01, -.70686100E+02, -.11335400E+03, -.21708600E+03, -.25628100E+02, 0.25025900E+03, -.70690100E+02, 0.36344500E+02, 0.33586800E+02, 0.35663500E+02, 0.31783200E+02, 0.78343600E+02, -.32744600E+02, -.77871200E+01, -.61500800E+01, 0.69036300E+02, 0.88405800E+01, -.10519100E+03, 0.52112800E+02, 0.60794200E+02, 0.52608300E+02, -.73885100E+02, 0.22244200E+02, -.37754200E+02, -.12030100E+03, -.21388600E+03, -.66691100E+01, 0.28645300E+03, -.52301200E+02, 0.25497600E+02, 0.74437300E+01, 0.26695600E+02, 0.40246800E+02, 0.28079900E+02, -.64167800E+02, 0.11969800E+02, 0.80226400E+00, 0.33498400E+02, 0.77658100E+01, 0.32922200E+00, 0.29625600E-01, 0.24090200E+00, -.16978100E+00, 0.67425700E-01, -.69483400E+00, 0.19227200E+01, 0.31458000E+00, 0.75438600E+00, -.72590100E+00, -.89228000E+00, 0.82640500E+02, -.43887200E+02, -.53654100E+02, -.41082300E+02, -.12893800E+02, -.24445900E+02, 0.68815300E+01, 0.46540800E+02, -.49218600E+01, -.18300200E+02, -.19345800E+02, -.23453100E+03, 0.11501700E+03, 0.10556000E+03, 0.11727300E+03, 0.13839500E+03, 0.12661000E+03, -.51958600E+02, -.13654300E+03, -.30471400E+02, 0.11507300E+03, 0.11258200E+03, 0.58384200E+03, -.29141900E+03, -.25980000E+03, -.29193400E+03, -.15436300E+03, -.13141200E+03, 0.37466000E+02, 0.27371200E+03, -.11263600E+03, -.12255200E+03, -.21573200E+03, -.65900300E+00, -.21175600E+02, 0.75904900E+00, 0.85150300E+00, -.13208600E+01, 0.19463400E+00, -.36962600E+01, -.18336400E+02, -.21672100E+00, -.14297400E+00, -.54301200E+00, 0.33483300E+01, 0.26815100E+01, 0.88802000E+00, 0.18680900E+01, 0.82018200E+00, 0.20862500E+00, -.69662500E+00, 0.57266700E+02, 0.19749000E+01, -.42615500E+02, 0.29995100E+01, -.95808300E-01, 0.83535500E+00, 0.15141300E+02, 0.52700800E+01 },
        { 0.79500100E+00, 0.44574900E+01, -.10232200E+01, 0.19410300E+00, -.88037700E+00, -.12134200E+01, -.58253200E+00, 0.15300400E+01, 0.11992900E+00, -.33589900E+00, -.11249300E+00, -.27321700E+01, -.10555000E+00, -.16985400E+01, 0.57212500E+00, 0.32141000E+00, 0.87845300E+00, -.35392900E+00, -.85880900E+00, -.20086900E+00, 0.34911000E+00, -.12934400E+01, 0.12281300E+00, 0.36226800E+01, 0.26692500E+00, 0.16923800E+00, 0.76168000E+00, -.20520900E+01, -.49199200E-01, 0.30494700E+00, -.71754500E-01, -.32837700E+00, 0.14752800E+01, -.16451300E+00, 0.24351900E+00, 0.27093900E+00, 0.77221900E-01, 0.52412000E+00, 0.70431800E+00, -.10004900E+01, -.53388300E+00, -.50348400E+00, -.10915500E+01, -.12378300E+01, 0.24575100E+01, 0.19132500E+00, 0.15354900E+01, 0.12058800E+00, 0.81037500E+00, -.66222900E-01, 0.38166700E+01, -.10609900E+01, -.63924300E+00, -.30228900E+01, -.15097800E+01, -.11332000E+01, 0.31037600E+01, -.17069300E+01, 0.51053900E+00, 0.44964900E+00, -.43188400E-01, 0.10586900E+01, -.39043000E+00, 0.95826100E+00, 0.11054200E+00, -.41457800E+00, -.63415400E+00, -.31671500E+01, 0.22320400E+01, 0.11642100E-01, -.31336900E+01, -.16056700E+01, -.29294700E+00, -.27911200E-01, 0.17334300E+01, 0.78491800E+00, -.29306400E+00, -.19606900E+01, 0.10764500E+01, 0.42661400E+00, 0.40902600E-01, -.10044300E+00, -.12553000E+01, -.81573000E+00, -.92232800E+00, -.12420300E+01, 0.30120200E+01, 0.90627400E+00, 0.40530700E+01, -.87564600E+00, 0.38371500E+01, -.43278700E+00, -.92325300E-01, 0.29626000E+01, 0.14732800E+01, 0.12059200E+01, -.49642300E+00, 0.88214400E+00, 0.16055400E+01, 0.30261100E+00, -.98529500E+01, -.11288500E+01, 0.16924500E+00, -.24866300E+00, 0.11024900E+01, -.25839700E+01, -.14040900E+00, -.58559800E+00, 0.30493400E+01, -.22489700E+01, 0.96072800E+00, 0.46304600E+00, 0.38375000E-01, -.31073800E+00, 0.11344900E+00, -.77529500E+00, -.75563700E+00, 0.51146900E+01, 0.80285500E-01, -.16937000E+00, -.37552100E+00, -.86468900E+00, 0.99955900E+00, -.95647400E+00, 0.21446100E+00, -.12250900E+01, -.18286900E+00, -.55555600E+00, -.15206700E+00, 0.43160300E+00, 0.19001300E+00, 0.13239200E+01, -.17040800E+00, 0.75314900E-01, -.12865100E+01, -.60627600E-01, 0.13603600E+01, -.23338600E+00, 0.10487900E+01, 0.40642900E-01, -.59898900E+00, 0.20008000E+01, 0.30098900E+00, 0.20722600E+01, 0.82047200E+00, 0.18438300E+00, 0.52389700E+00, -.63546800E+00, 0.34000500E+00, -.96866400E+00, -.10772800E+01, 0.85437600E+00, -.13021700E+01, -.15781200E+01, 0.55262800E+00, -.61314900E+00, 0.21214700E+01, -.52164000E-01, 0.25482100E+00, -.78829600E+00, -.85256100E-01, 0.38247000E+01, -.22601700E+00, -.42591100E+00, 0.24729300E+00, 0.42170800E+00, 0.22861500E+00, 0.78693200E+00, -.53841300E-01, -.20533000E-01, 0.55448800E+00, -.39671700E+00, -.53170300E+00, 0.13223600E+01, 0.72278400E-01, 0.65295500E+00, -.16051100E-01, 0.17593800E+00, -.78373900E+01, -.25151100E-02, 0.27137700E+00, -.42559900E+00, -.16545800E+01, 0.15677200E+00, -.33484800E+00, -.56909600E+00, -.13386500E+01, -.51630400E+00, 0.14711700E+00, -.28024500E+00, 0.24766400E-02, -.43412100E+00, 0.26506200E+03, -.30091700E+03, -.21989000E+03, -.20621300E+03, 0.23726400E+03, 0.55423100E+03, -.56955500E+02, 0.27916400E+02, 0.63212600E+02, 0.28359200E+02, 0.81885200E+02, 0.22008500E+03, -.77951000E+02, -.79200700E+02, -.79158800E+02, 0.23196000E+03, -.89316200E+02, -.22188600E+03, 0.11527700E+03, 0.96738700E+02, 0.11098200E+03, 0.17464900E+03, 0.28057200E+03, -.17159800E+03, -.22699400E+03, -.16084600E+03, 0.25126500E+03, 0.63507700E+03, 0.31560300E+02, -.21623000E+02, 0.51893800E+02, -.16378500E+02, 0.42905200E+02, 0.18785300E+02, -.59312400E+02, -.40862000E+02, -.76373000E+02, 0.57657600E+02, -.26754000E+02, 0.27769800E+01, -.22197000E+01, 0.68096800E+00, -.13950400E+01, -.71976700E+00, -.12167000E+01, 0.38010900E+01, 0.86588100E+00, -.29406800E+00, -.50581400E+00, -.18705600E+01, 0.85332900E+02, -.50882600E+02, -.12494400E+03, -.43046300E+02, -.67788400E+01, -.16095900E+02, 0.28216300E+02, 0.86953200E+02, -.57122200E+01, -.16952700E+02, -.11424900E+02, -.42858100E+02, 0.39566400E+02, -.57669800E+02, 0.21443100E+02, 0.20741600E+03, 0.21802100E+03, -.12129100E+03, -.18256100E+03, -.19900700E+03, 0.19032300E+03, 0.52503600E+02, 0.10203100E+04, -.52292800E+03, -.41093000E+03, -.51018400E+03, -.37647900E+03, -.26865600E+03, 0.15393200E+03, 0.61947000E+03, -.51677900E+02, -.25981800E+03, -.42507400E+03, -.13975400E+01, -.60085300E+02, -.22007100E+01, 0.45929000E+01, 0.10932900E+01, -.12893500E+01, -.16802800E+02, -.48680300E+02, 0.80369200E-01, -.56649200E+00, -.34203700E+01, 0.24402000E+01, 0.12074200E+02, 0.49280900E+01, 0.14090400E+01, 0.13372500E+01, 0.47475100E+01, -.61405000E+00, 0.64132300E+02, 0.24409700E+02, -.44399300E+02, 0.51651600E+01, 0.57518600E-01, -.14958500E+01, 0.39990200E+02, 0.30607100E+02 },
        { 0.23842000E+00, -.82419200E+00, 0.25886700E+00, 0.40315200E+00, -.67349000E+00, -.26360600E+00, -.93818400E+00, 0.10548300E+01, 0.31102100E+00, -.79228000E+00, 0.38659400E-01, 0.17674800E+01, -.47228300E+00, 0.93034300E+00, 0.17375500E+00, -.31799800E+00, 0.10515800E+01, -.79466800E-01, -.13936000E+01, 0.78840800E-01, 0.50694900E+00, -.46163400E+00, -.17177400E+00, 0.42156900E-01, 0.18106100E+00, -.94074800E-01, -.45407200E+00, 0.41733100E+00, -.17552400E-01, -.44124700E+00, 0.85236600E-01, -.15928900E+00, -.10803900E+00, 0.10035500E+00, -.12091000E+00, -.24205800E+00, 0.16593500E-01, -.31315000E+00, -.26477000E-01, -.33883700E+00, 0.78027700E+00, 0.25383800E+00, -.19142100E+01, -.19854300E-01, -.27042500E+00, 0.75698000E-03, -.34156800E+00, -.71808600E-03, -.22624900E+00, 0.42256500E+00, 0.32577300E-01, 0.11124100E+00, 0.16107000E+00, -.42096000E+01, 0.78860700E-01, -.66527700E+00, 0.43658400E+00, -.20203800E-01, 0.31033400E-01, -.55111100E-01, -.75771400E-01, 0.33767700E+00, 0.83310400E-01, -.13432500E+00, 0.89361200E-01, -.16724300E+00, -.10727100E+00, -.47087900E+00, 0.44786800E+00, -.10252700E-02, 0.21837300E+00, 0.35987000E-01, -.18188100E+00, -.80342300E-01, -.21922300E+00, -.11100100E+00, 0.53887900E-01, -.33203700E+00, -.28669500E-01, 0.16931300E+00, 0.14112500E-02, -.21526200E-01, -.42237900E-01, 0.13903200E+00, 0.71490700E-01, -.14780600E+00, 0.56972600E-02, -.38711800E+00, -.91693800E+00, 0.23398500E-01, 0.28408200E+00, -.16392900E-01, -.15551000E+00, -.10161500E+00, 0.97110500E-01, 0.33603200E+00, -.83448900E-02, -.12740600E+00, 0.18874300E+00, 0.34305500E+00, -.26925500E+01, 0.63346900E+00, 0.79655500E-02, -.46157000E-01, 0.30045600E-01, 0.20675100E-02, 0.30271600E+00, 0.51264300E-01, 0.59857600E+00, -.45000000E+00, 0.34907500E-01, -.69247800E-01, -.11686100E+00, 0.51580500E-02, 0.36151900E+00, 0.17444800E+00, -.35659500E+00, -.54825500E+00, -.43922000E-01, 0.53212200E-02, -.15912500E+00, -.12028600E+01, 0.37465000E+00, -.22281500E+00, -.44670500E-01, -.53436200E+00, 0.61334800E+00, -.37137400E+00, -.47535400E-01, 0.40370900E+00, 0.30031900E-01, 0.37638500E+00, 0.91730500E-02, -.24688700E-01, -.23867700E+00, -.14990600E-02, -.11195600E+01, -.22118500E+00, -.25892600E+00, -.90911400E-01, 0.27677400E+00, 0.35206900E+00, 0.38338900E+00, -.43336900E+00, 0.39770600E+00, 0.15010200E-01, -.85511300E-03, 0.11145300E+00, -.60044100E+00, 0.20930600E+00, 0.31934100E+00, -.29079300E+00, 0.77094400E-01, -.81585500E-01, -.14204700E+00, 0.16314200E-01, 0.45719600E+00, -.64040000E-01, -.32709900E+00, -.32821200E+00, -.75765300E+00, 0.97808900E+00, -.54551600E-01, 0.12487900E+00, -.11116800E+00, -.36657700E+00, 0.10319400E+00, 0.50573800E-01, 0.26185300E-01, -.37993800E+00, -.45327900E+00, 0.21197200E-01, -.33922700E-01, -.55717400E+00, 0.16110400E+00, -.47006400E+00, 0.15702000E+00, -.29831400E-01, -.31338600E+01, 0.61016300E-03, 0.10762000E+00, -.40890400E+00, -.37727600E+00, 0.10939600E-01, -.32748300E+00, -.51832700E+00, 0.29256900E+01, -.10968500E+00, -.19026100E-01, 0.20779600E+00, 0.10591700E-02, -.65765700E+00, -.33514100E-01, -.98589400E+02, -.48908000E+02, -.12919800E+03, -.25294200E+02, 0.11168400E+03, -.37685600E+02, 0.20335900E+02, 0.41412300E+01, 0.19042800E+02, 0.34931700E+02, 0.43063900E+02, 0.10571400E+02, 0.34510600E+02, 0.42419700E+02, 0.33030100E+02, -.46962700E+02, -.50462000E+02, 0.24676400E+02, 0.26681200E+02, 0.25250600E+02, 0.45092200E+02, 0.56343100E+02, -.11364900E+03, -.49615000E+02, -.12521800E+03, 0.21313100E+02, 0.13818400E+03, -.33371500E+01, 0.80507000E-01, 0.27506200E+02, 0.19698400E+01, 0.12695600E+02, 0.94150500E+01, -.16750100E+02, 0.64910400E+02, 0.16037800E+02, 0.10435300E+02, -.14322500E+02, -.10207100E+01, 0.48855200E+00, 0.92888600E+00, 0.50402100E+00, 0.29164100E+00, -.12277500E+01, 0.18306100E+01, 0.32360100E+00, 0.14580100E+01, -.13017400E+01, -.11874300E+01, -.89701900E+02, 0.42174500E+02, 0.32980600E+02, 0.44888700E+02, 0.11851800E+02, 0.26083300E+02, 0.23594000E+02, 0.10797700E+02, 0.14628600E+01, 0.23201900E+02, 0.38977200E+02, -.23095800E+03, 0.11471800E+03, 0.90336300E+02, 0.11548800E+03, 0.86768500E+02, 0.14566300E+03, -.51992100E+02, -.73546400E+02, -.52937300E+02, 0.12940500E+03, 0.92935400E+02, 0.55345200E+03, -.27713100E+03, -.22824700E+03, -.27674400E+03, -.63620200E+02, -.11798100E+03, 0.42314400E+02, 0.19918700E+03, -.71482100E+02, -.98893700E+02, -.24202700E+03, -.14989500E+00, -.15779800E+02, -.26869900E+00, 0.15782800E+01, 0.74553700E+00, 0.16412100E+01, 0.14610000E+01, -.12778000E+02, -.32993500E+00, -.41547400E+00, -.72471600E+00, 0.32692800E+01, -.33676200E+01, 0.83253600E-01, 0.13217200E+01, 0.51995300E-01, 0.38144300E+00, -.89749500E+00, 0.29025300E+02, -.11591700E+01, -.18294800E+02, 0.21366900E+01, -.81467200E-01, -.27957900E+01, 0.14815400E+02, 0.11682600E+02 },
        { 0.13697600E+00, -.67113000E+00, 0.46814200E+00, 0.11721800E+00, -.27483700E+00, -.11425200E+00, -.41885900E+00, 0.55386400E+00, 0.12149000E+00, -.27998400E+00, -.55545200E-01, 0.94704000E-01, -.18731300E+00, -.64117600E-01, 0.21021400E+00, 0.46456600E+00, -.11696700E+01, -.56955700E-01, -.46170700E-01, 0.34933400E-01, -.17171500E+00, 0.18817900E-01, -.31398100E-01, -.13243000E+00, 0.93741800E-01, 0.94614300E-01, 0.17905500E+00, 0.14908300E+00, -.20071000E-01, -.85071500E-01, 0.41072600E-01, 0.61829900E-01, 0.13763100E-01, 0.82408400E-01, 0.24742400E-01, 0.12299900E+00, -.14985600E-01, 0.33334400E+00, -.60208700E-01, 0.18525500E+00, -.72430900E-01, -.31597300E-01, 0.14453700E+00, 0.15998300E-01, 0.10049900E+00, 0.65757200E-01, 0.33895200E+00, 0.63384400E-02, 0.61385000E-01, 0.27120100E-01, 0.26029200E+00, -.65220400E-01, 0.11422000E+00, 0.79311900E-01, -.17495700E+00, -.73108300E-01, 0.21761300E+00, 0.13979500E+00, 0.37496100E-02, 0.16798200E+00, -.17936500E-01, 0.62523500E-01, -.11996900E+00, 0.20005700E-01, 0.35256100E-01, 0.97208200E-01, 0.64437000E-01, 0.23045800E+00, -.20705300E+00, 0.15779400E-03, 0.24932200E+00, 0.73137800E+00, -.11572300E-01, -.29426300E-01, -.80022800E-01, -.22628100E+00, -.92090200E-01, 0.33254600E+00, -.11525300E+00, -.74478900E-03, 0.42252700E-02, -.75543500E-01, 0.39197900E+00, 0.32922100E-01, 0.18731400E-01, 0.54916600E-02, 0.11452600E-01, -.99396200E-01, -.31106100E+00, 0.60558700E-01, -.94396800E-01, 0.33937100E-01, 0.12494000E+00, -.18136800E+00, -.12134300E+00, -.19570700E-01, 0.13711800E+00, 0.49063300E-01, -.92678200E-01, -.11754500E+00, 0.84292600E+00, -.12619600E+00, -.73666700E-02, 0.17430700E+00, 0.33273600E-01, -.34178200E+00, -.24153800E+00, -.26770800E+00, 0.47304100E+00, 0.18405300E+00, 0.16420900E+00, 0.29876100E+00, -.93827500E-01, 0.18381600E-02, 0.29296300E-01, 0.12412900E+00, 0.89694800E-01, -.55538200E+00, 0.36886600E-01, -.10037100E+00, 0.16420200E+00, -.14864500E+00, -.10721600E+00, 0.45868600E+00, 0.16088700E-01, 0.98944500E-01, 0.14046900E+00, -.42696300E-01, -.30765900E-02, -.11035700E+00, -.50491300E-01, -.12677800E+00, -.15077900E-02, -.91367500E-01, 0.36028200E-02, -.56499000E-02, -.35384700E+00, 0.22681100E-01, -.50839300E-01, -.21378800E+00, -.14688400E-01, -.41409100E+00, -.11930500E-01, 0.11627900E-01, 0.33606700E-01, 0.32501400E-01, -.17669700E-01, -.46319100E-01, 0.51258600E-01, 0.14323500E+00, -.23984300E-01, -.60163900E-01, 0.77219300E-01, 0.24696900E+00, -.12707400E+00, -.17182300E-01, -.71008000E-01, -.40467000E-01, 0.15082000E-01, 0.16335900E-01, 0.19287100E+00, 0.67288400E+00, 0.95409300E-01, -.19469900E-01, -.46015900E-01, -.55402900E-01, -.23614000E-01, 0.65758000E-01, 0.20788500E-01, 0.73744300E-02, 0.12482600E+00, 0.73538000E-02, -.10959800E+00, -.46291100E-01, -.18472600E-01, 0.86221100E-01, 0.37742300E-01, 0.24635400E-01, -.93869200E-01, 0.53260200E-03, 0.31108700E-01, -.45076600E-01, 0.12217700E+00, -.29098400E-01, -.13608500E+00, 0.36435400E-02, -.47822300E+00, 0.14452800E+00, 0.31734600E-01, -.64725700E-01, -.56533700E-03, -.80251900E-01, -.12388600E+00, 0.12967200E+00, 0.35522300E+02, 0.85446100E+02, -.16530600E+02, -.77534300E+01, 0.11092200E+02, -.66661100E+01, -.36748900E+01, -.55484200E+01, -.86568800E+00, 0.31715000E+01, -.67248400E+01, 0.14673800E+01, -.28253000E+01, -.11582900E-01, -.20010200E+01, 0.43180800E+02, -.20345800E+02, -.19800100E+02, -.21593000E+02, 0.25106200E+01, 0.10962000E+01, -.50342500E+01, 0.42648000E+02, 0.83233800E+02, -.19207800E+02, -.30674700E+02, -.15558700E+02, 0.69531100E+01, 0.45620400E+01, 0.78719600E+01, 0.90083500E+01, 0.48402900E+01, -.54287100E+01, -.11983000E+02, -.13504300E+02, 0.43507800E+01, 0.15479900E+02, 0.46996700E+00, -.45046300E+00, -.20590200E+00, -.23405900E+00, -.41353800E-02, 0.21189100E+00, -.80423800E-01, 0.16610000E+00, -.32067100E+00, 0.23022600E+00, 0.88153100E-01, 0.16847800E+02, -.68966100E+01, -.13357400E+02, -.84075200E+01, 0.51024500E+01, 0.41897500E+01, -.67839200E+01, 0.25407200E+01, -.46717100E+01, 0.24715600E+01, -.47855800E+01, -.50722900E+02, 0.29888800E+02, 0.28821000E+02, 0.25360200E+02, 0.59712400E+01, -.76195900E+00, 0.11133800E+02, -.11390000E+02, 0.56903600E+01, 0.30240700E+00, 0.69375600E+00, -.98729300E+01, 0.23581100E+01, 0.55008200E+01, 0.49390800E+01, 0.73410200E+01, 0.14449700E+02, -.90153700E+01, 0.56782500E+01, 0.13098200E+02, 0.63535000E+01, 0.37048100E+02, -.30444500E+00, -.72836800E+00, -.94912700E+00, -.16808300E+00, -.88458400E+00, -.59530500E+00, -.82151300E+00, -.82738300E+00, 0.47209600E-01, -.29378100E+00, -.26859500E+00, -.12462000E+00, 0.92349800E+00, 0.13368900E+00, 0.13486300E+01, 0.23668800E+00, 0.54315600E+00, 0.76511000E-01, -.25403700E+02, 0.10200900E+00, 0.18232000E+02, 0.51183200E+00, -.13403800E-01, 0.53801500E+00, 0.18279800E+01, 0.18037900E+01 },
        { 0.20242500E+00, -.45007700E+00, 0.19051400E+00, 0.12121500E+00, 0.31609200E-01, 0.55915000E-01, 0.17295300E+00, -.22659000E+00, 0.15147000E+00, 0.18962100E+00, -.63688700E-01, 0.64098400E+00, -.37272700E+00, 0.54839400E-01, -.48181200E-01, -.24415100E-01, 0.13177600E+00, -.26146000E-01, -.22076000E+00, -.10828900E+00, 0.51661200E-01, -.16866100E+00, -.14911700E+00, 0.18590900E+00, 0.11244900E+00, 0.17942500E-01, 0.16488000E+00, -.67958500E-01, 0.13164600E-01, -.10500800E+00, -.34421500E-01, -.10289200E+00, 0.20323300E+00, 0.22689700E-01, -.14050700E-01, -.26659000E-01, 0.16706300E-01, -.47679200E-02, -.50581600E-01, -.84699800E-01, -.58119100E-02, 0.51962900E-01, 0.34460600E+00, 0.89681800E-01, -.88450100E-01, -.89796200E-01, -.21471300E+00, 0.20446200E-01, -.11137100E-01, -.71223800E-02, -.60520900E-01, -.27262500E-01, 0.69516200E-01, 0.26288800E+00, -.70939900E-02, 0.20028400E-01, -.75277200E-01, 0.68628200E-01, -.87039500E-01, -.22896700E-01, -.89642400E-02, -.63052600E-01, 0.46482700E-01, -.97489800E-02, 0.22759600E-02, -.37626600E-01, 0.68826400E-02, -.63486700E-01, 0.56669500E-01, -.46378000E-03, 0.28968000E+00, -.46858500E-02, -.55161800E-02, 0.14156500E-01, -.49754300E-01, -.77356600E-01, 0.23854000E-01, 0.43547200E-01, 0.79397500E-01, 0.80083100E-02, -.13746300E-02, 0.14158400E-01, 0.59677600E-01, -.90474400E-02, 0.39407800E-01, -.34511700E-01, 0.35003700E-01, 0.47889300E-01, -.16073200E+00, -.78478900E-01, 0.39089200E+00, 0.27608100E-01, -.19165600E+00, 0.21317200E-01, 0.54391000E-01, 0.57926200E+00, 0.13397200E-01, -.33141900E-02, 0.67754900E-01, -.57135300E-02, -.50160700E-01, -.10675400E+00, -.81396000E-03, 0.25757200E+00, 0.15919300E+00, -.14442600E+00, -.16280000E+00, 0.52998700E-01, -.24006200E+00, 0.20155100E+00, 0.38882300E+00, 0.14070100E+00, 0.21865000E-01, -.25616800E-03, 0.40333200E-01, 0.24595700E+00, 0.42852300E-01, -.86657600E+00, -.20146300E+00, -.19540000E-01, -.11972000E+00, -.16974900E-01, 0.57568700E-01, 0.34917200E+00, -.14703700E-01, -.18522300E+00, 0.47755300E-01, 0.83032100E-01, -.85555800E-02, -.51117000E-01, 0.27148300E-01, 0.91740300E-01, 0.13136600E-01, -.15023000E+00, -.12937900E-01, -.28690700E-02, -.32863000E-01, 0.75593800E-01, 0.28196300E-01, -.28285200E+00, 0.98467100E-01, 0.61541900E-01, 0.45056200E-01, 0.47598900E-01, -.26770400E-01, -.37036300E-01, -.69158400E-01, 0.99613400E-01, -.98038500E-01, 0.79517400E-01, -.61607200E-01, -.77566600E-01, 0.13051500E+00, 0.34957400E+00, -.17214100E+00, -.83388700E-01, -.87211600E-01, 0.21119000E-01, -.16186200E+00, -.16245800E+00, -.12961200E+00, -.45225300E+00, -.10137200E+00, 0.53423700E-01, -.13953900E+00, 0.15516900E+00, 0.28533200E-01, 0.14945000E+00, 0.15865100E-02, 0.11226400E+00, 0.85961400E-01, -.26706900E+00, -.22524800E-01, 0.54897400E+00, -.18024600E+00, 0.67144900E+00, 0.12614500E+00, -.60085500E-01, 0.98567700E+00, 0.11117700E-02, -.93605100E-01, -.19001900E+00, -.60716500E-01, -.11301000E+00, -.93697100E-01, -.65110200E-01, 0.44758200E+00, 0.28363100E-02, 0.29463200E-01, -.12828400E-02, 0.12566600E-02, -.19556400E+00, 0.13326200E+00, -.27253700E+00, 0.74883400E+00, -.10952500E+03, 0.22578400E+02, 0.15388800E+02, -.84250900E+02, 0.44088900E+02, 0.57961200E+02, 0.42147200E+02, 0.30242500E+02, 0.23262400E+02, 0.22441200E+02, 0.10009800E+02, 0.18930600E+02, 0.24302600E+02, -.12225200E+02, -.97336900E+02, 0.47060800E+02, 0.45427900E+02, 0.48688800E+02, 0.38116300E+02, -.82714200E+00, 0.12750500E+02, -.19122900E+02, -.10585200E+03, 0.30869200E+02, 0.56150200E+02, 0.42993400E+02, -.19739800E+02, 0.77275100E+01, -.21768300E+02, -.20593500E+02, -.60064100E+00, 0.67213700E+01, 0.22276900E+02, 0.72542300E+01, 0.24319100E+01, -.16195700E+02, -.60934700E+00, 0.62443500E+00, -.82236800E+00, 0.29949400E+00, 0.37401100E-01, -.64001200E+00, 0.28466100E+00, -.88701300E+00, 0.74258800E+00, -.63733700E+00, -.53535400E+00, -.48501300E+02, 0.22941200E+02, 0.23635800E+02, 0.24110000E+02, 0.43370900E+01, 0.67426200E+01, 0.93699300E+01, -.71442900E+01, -.38167200E-01, 0.64445200E+01, 0.23510400E+02, 0.15004500E+03, -.81386300E+02, -.88352800E+02, -.75014000E+02, 0.21657400E+02, 0.15790300E+02, -.53462000E+02, -.84075700E+00, -.57648500E+02, 0.15583000E+02, -.21263800E+02, 0.29656300E+02, -.10364000E+02, -.19538700E+02, -.14845800E+02, -.33441100E+02, -.43828500E+02, 0.70064200E+02, 0.71753700E+02, 0.10049600E+02, -.36775900E+02, -.84380600E+02, -.39484800E-01, -.48652200E+01, 0.12139900E+01, 0.83765100E+00, 0.30655400E+01, 0.88726100E+00, 0.49212800E+01, -.33518700E+01, -.43751000E+00, 0.85555400E+00, 0.39199900E+00, -.15524800E+01, -.42266400E+00, -.12548800E+01, -.19944900E+01, -.95017700E+00, -.40767900E+00, -.23862000E+00, 0.32645900E+02, -.60387700E+00, -.25671700E+02, -.19014000E+01, -.30006200E+00, 0.56094100E+00, 0.16669600E+01, 0.53562800E+00 },
        { 0.18232600E+00, -.53880300E+00, 0.20495200E+01, 0.24680000E+00, -.64170000E+00, -.21542500E+00, -.68234900E+00, 0.44624000E+00, 0.19318600E+00, -.12391800E+00, -.28341000E+00, 0.40247400E+00, -.15947600E+00, 0.26767600E-01, -.25650700E+00, -.95457100E-01, 0.35942400E+00, -.11027900E+00, 0.13775800E-01, -.14459800E+00, 0.36600100E+00, 0.65807200E+00, -.14901700E-01, 0.28095300E+00, 0.13082600E+00, 0.10625600E-01, 0.23322800E+00, -.26816900E+00, 0.34986700E-01, -.74363800E-01, -.28319400E-01, -.32245100E-01, 0.13762900E+00, -.11317700E+00, -.17082900E+00, 0.10273100E+00, 0.11745900E-01, -.16060800E+00, -.27476200E+00, 0.73975600E-01, 0.12050300E+00, 0.93002400E+00, 0.77827600E+00, 0.17701100E+00, -.41829800E+00, -.13074200E+00, -.30800600E+00, 0.25013000E-01, -.31614200E-01, 0.81776500E-01, 0.20768800E+00, -.44274900E+00, -.10164400E+00, 0.24381800E+00, 0.26835600E+00, -.63066600E-01, 0.44007700E-01, -.78335200E-01, -.56803800E-01, 0.28340700E-01, -.76499100E-01, -.21163800E-01, 0.13213900E-01, 0.88185400E-02, 0.29587400E-01, -.50093100E-01, -.22169900E-01, -.31267000E+00, 0.10687100E+00, 0.97274900E-03, 0.15650000E+00, 0.25951000E+00, -.50840600E-02, 0.48475200E-01, -.10735000E+00, 0.52145100E-01, 0.11209300E+00, 0.71963000E-01, 0.58580800E-01, -.13172400E+00, -.10576100E-01, 0.14220400E-01, 0.60869300E-01, -.15295900E+00, 0.67617000E-03, -.75404800E-01, 0.16304400E+00, -.11935100E+00, -.23256000E+00, 0.92935500E-02, -.34115100E-01, -.91342100E-01, 0.86836700E-01, 0.34580900E+00, -.13918400E+00, -.32650400E+00, -.57085100E-01, 0.12693200E+00, 0.32547200E-01, 0.69359900E-01, 0.32995100E-01, 0.13900600E+00, 0.48366200E-02, 0.14514600E-01, 0.12699800E-01, 0.13580300E-01, 0.93103700E-02, 0.15647300E+00, 0.54490100E-01, 0.88740200E-01, 0.62878200E-02, 0.74209600E-01, -.28278800E-02, -.17530200E-01, 0.18827200E-01, -.25728200E-02, -.70155300E-01, -.42699900E+00, 0.11577200E+00, -.38605400E-01, -.32849400E-01, -.73648400E-01, 0.43452500E-01, -.50221200E-01, -.40023500E-02, -.10752200E-01, -.90155900E-01, 0.27123300E+00, 0.26322600E-01, -.13546700E-01, 0.11009700E+00, -.13742800E+00, 0.10557900E-01, -.99250500E-01, -.65774000E-01, -.29199400E-02, 0.45470400E-01, 0.66915600E-01, 0.53436600E-01, 0.45450700E-01, -.61754900E-01, 0.23014600E-01, -.11453700E+00, 0.45571500E-01, -.32260100E+00, -.81378300E-01, 0.24086600E-02, 0.38566200E+00, -.87210300E-01, 0.70029500E-01, -.28474400E-01, 0.77591500E-01, 0.18311400E+00, 0.20614300E+00, -.52713600E+00, 0.10120500E+00, -.10391100E+00, -.38683900E-01, -.58304900E-01, -.18594700E+00, 0.18623500E+00, -.14265200E+01, -.31283300E-01, 0.35934200E-01, -.17949500E+00, -.10695200E+00, -.39919100E-01, 0.16030000E+00, 0.25008400E-01, -.25638400E+00, 0.23561000E+00, 0.35577300E-01, 0.13828100E-01, 0.46155300E+00, -.71820900E-01, 0.11988600E+00, -.84939800E-01, -.26117000E-02, 0.88193800E-01, 0.50835200E-03, -.10859100E+00, -.42865500E+00, -.65547700E+00, 0.87761400E-01, -.13365500E-01, -.69966300E-02, 0.92079800E+00, 0.12898400E+00, 0.40836300E-01, 0.82885400E-01, 0.11096500E-02, 0.11813400E+00, 0.48701800E-01, 0.26397200E-01, 0.38989600E+00, 0.33245800E+00, 0.25922800E+02, 0.11095200E+02, 0.15252700E+02, -.79088700E+01, -.12478400E+02, -.76432100E+01, -.99356100E+01, -.22376400E+02, 0.25061700E+01, -.93175400E+01, -.10116900E+02, -.15932300E+02, 0.14094400E+02, -.11356800E+02, 0.58038200E+01, 0.42672200E+01, 0.56796700E+01, -.75533600E+00, 0.54816700E+00, -.20947700E+02, -.13151600E+02, -.32396500E+01, 0.24913500E+02, 0.31268900E+02, 0.97969200E+01, -.43497200E+01, -.71108900E+01, -.51085800E+01, -.61693200E+01, -.36301600E+01, 0.73084600E+01, 0.27638000E+00, 0.89405300E+01, -.38615100E+01, -.15132300E+01, -.55993900E+00, 0.21333400E+00, 0.54068200E+00, 0.28023300E+00, 0.84922600E-01, -.85984500E-01, 0.33581000E+00, -.38987800E+00, 0.18016700E+00, -.43182000E-01, -.18668900E+01, 0.20091900E+02, -.11600600E+02, -.26110600E+01, -.10053300E+02, -.10897500E+02, -.17862700E+02, -.55084800E+01, -.10443400E+02, 0.48216100E+01, -.14941300E+02, 0.43064000E+01, 0.91075400E+02, -.45096900E+02, -.58491800E+02, -.45537600E+02, -.68666200E+02, -.54219600E+02, 0.15892700E+02, 0.49272500E+02, 0.11130000E+02, -.48963200E+02, -.17819300E+02, -.16171500E+03, 0.80672900E+02, 0.69911900E+02, 0.80857300E+02, 0.55471700E+02, 0.25415800E+02, 0.10722000E+02, -.92936600E+02, 0.23026000E+02, 0.26714900E+02, 0.29086900E+02, 0.65746300E+00, 0.76665200E+01, 0.15377100E+01, 0.30328800E+00, -.10946800E+01, 0.13463700E+01, 0.18812500E+01, 0.68666800E+01, 0.31002700E-01, -.49394100E+00, 0.49237600E+00, -.45129800E+00, -.79613400E+00, 0.15675300E+01, 0.63905400E+00, -.63590400E+00, -.12891900E+01, 0.53997000E+00, 0.47710700E+01, -.90892900E+00, -.23807400E+01, -.21210700E+00, 0.12508200E+00, 0.22275400E+01, -.58148400E+01, -.38600700E+01 },
        { 0.28245600E+00, -.16672100E+01, 0.33265600E+01, 0.94362000E+00, -.98300100E+00, -.11245000E+00, -.33226900E+01, -.19451800E+01, -.43728500E+00, 0.17567500E+00, -.19293300E+00, 0.77018200E+00, -.88158500E-01, 0.33105700E+00, 0.29294000E+00, 0.31101500E+00, 0.13020800E+00, -.14917000E+00, 0.83759600E+00, -.21484000E+00, 0.35765100E+00, 0.16484900E+01, 0.14933200E+00, 0.17272900E+00, -.95855000E-01, 0.12258300E+00, 0.34735600E+00, -.45397800E+00, 0.24413600E+00, 0.18036700E+00, -.26510200E+00, -.10116000E+00, 0.25347700E+00, -.47970300E-01, -.87372800E-01, -.28507600E-01, 0.19089400E-01, -.39387800E+00, 0.16542100E+00, -.11178000E+00, -.61917700E+00, 0.95013700E+00, 0.17993500E+01, 0.90497300E+00, -.39360900E+00, 0.29056000E-02, 0.81845200E-01, -.36839500E-02, -.17787800E+00, 0.13088000E+00, -.29289600E-01, 0.63985900E-01, 0.18923000E+00, 0.77784800E+00, -.28776800E+00, 0.62626700E+00, -.90084600E-01, 0.51234500E-02, -.16143500E+00, -.43591400E+00, 0.33612700E-01, -.14284900E+00, -.46597200E+00, 0.90259200E+00, 0.55005700E-01, -.57323100E-01, 0.18911100E+00, -.54032900E+00, 0.33015000E-01, 0.11433000E-01, 0.67610600E-01, 0.15055500E+01, -.91971300E-01, 0.13994400E+00, 0.22457100E+00, -.30540700E+00, 0.79250300E-01, 0.51039500E+00, 0.12140300E+00, 0.13811100E+00, -.71875100E-02, 0.21840200E-02, -.31858900E+00, -.16751600E+00, 0.66021400E-01, 0.54750200E-01, 0.53681200E+00, -.49221400E+00, -.88015200E+00, 0.64398800E-01, -.33960500E+00, 0.25407000E-01, 0.36554900E+00, 0.40969200E+00, -.31861800E-01, 0.95697100E+00, -.11711900E+01, 0.72542500E+00, -.37552700E+00, -.35214900E+00, 0.69690600E+00, -.53934800E+00, -.17316000E-01, 0.74369400E+00, 0.64708600E+00, 0.30935600E+00, -.41532400E-01, 0.50821800E+00, -.80247400E+00, 0.43648700E+00, 0.39344500E+00, 0.33520000E+00, 0.22507500E+00, 0.56756900E-02, -.47286900E-01, -.15861800E-01, -.73247700E-01, -.48113900E+00, 0.37188800E-01, 0.64567400E-01, -.27031900E+00, 0.93834100E+00, 0.78864700E-01, 0.15629700E+00, -.90454200E-01, 0.76548000E+00, 0.94958200E-01, 0.29670500E+00, 0.17874400E-01, -.17094200E+00, 0.23434200E+00, 0.26984000E+00, -.28415100E-01, 0.21556600E-01, -.85044000E-01, 0.28224500E-02, 0.12309000E+00, 0.14966500E+00, 0.10580700E+00, 0.36234700E+00, -.41777800E-01, 0.26356200E+00, -.31056300E+00, 0.34588800E+00, -.10340400E+00, -.24478500E-01, -.12807400E-01, 0.65902500E+00, 0.46689500E+00, -.13936200E+00, -.36333700E+00, 0.30074700E+00, 0.34802300E+00, 0.80674400E-02, -.85150100E+00, -.16237500E+00, 0.11893700E+00, 0.11812000E-01, 0.15976500E-01, 0.12737900E+00, 0.24101100E+00, -.22489600E+01, -.32864300E-01, -.98678000E-01, 0.52100600E-02, 0.52252700E+00, 0.21348200E-01, 0.34518100E+00, 0.22764800E-01, -.23532100E+00, 0.23698500E+00, 0.17906400E+00, -.12064000E+00, 0.10283600E+00, -.80609400E-01, 0.17349200E+00, -.14315100E-01, 0.99666600E-02, 0.59783200E+00, 0.32351100E-03, 0.13841800E+00, 0.47308400E+00, 0.89321100E+00, -.53581300E-02, 0.33892200E+00, 0.77488600E+00, -.18494600E+01, -.14961200E+00, -.69293200E-01, 0.16125900E+00, -.95016400E-03, 0.34683700E+00, 0.24931400E+00, 0.62479200E-02, -.14298100E+01, -.67901300E+00, 0.38259000E-01, -.15928600E+03, -.23035800E+02, 0.11500200E+02, 0.27335900E+02, 0.11384100E+02, -.21432900E+02, -.40311400E+02, 0.14213600E+02, 0.28894100E+02, 0.14867300E+02, -.40377700E+02, 0.38814800E+02, 0.10603200E+02, -.68327300E+01, -.64994600E+01, -.53131600E+01, -.23380500E+02, 0.12804100E+02, 0.45437400E+01, 0.12240300E+02, -.18326800E+01, 0.11489200E+02, -.16236300E+03, -.28331900E+02, 0.15931400E+02, -.12184100E+02, 0.14172100E+02, 0.47195100E+01, 0.50427200E+01, 0.57609000E+01, -.36648400E+02, -.72947700E+01, 0.11865300E+01, 0.21640200E+02, 0.53819500E-01, 0.24484400E+00, -.10975900E+01, -.23329500E-01, -.13582000E+00, 0.29589100E+00, -.87900300E+00, -.18630500E+01, -.42629000E+00, 0.18075100E+00, 0.24496700E+00, -.68217500E+01, 0.63317700E+01, 0.95891500E+01, 0.33715800E+01, -.42185800E+01, -.11933900E+02, -.75510000E+01, -.26911800E+02, 0.11007200E+01, -.93742500E+01, -.93490300E+01, 0.14022100E+01, -.51987800E+01, 0.13395700E+02, -.70658000E+00, -.48048600E+02, -.56330700E+02, 0.14243800E+02, 0.99443800E+01, 0.69673200E+02, -.42486800E+02, 0.27811400E+02, -.15875100E+03, 0.82907700E+02, 0.85973800E+02, 0.79386400E+02, 0.32373700E+02, 0.19242800E+02, -.93720500E+01, -.87083500E+02, -.63802400E+01, 0.51785200E+01, 0.14102500E+02, -.61187700E+00, 0.40736700E+01, 0.17853500E+00, 0.93464900E-01, -.17123900E+01, -.11233000E+01, 0.38245700E+01, 0.29039400E+01, -.55167500E+00, -.29545400E+00, -.51816900E-02, -.35236500E+01, -.68667100E+00, -.57258500E+00, -.11655900E+00, -.15434700E+01, 0.92990600E+00, -.82005000E-01, 0.25768900E+01, -.57435700E+01, -.45970900E+01, -.27049100E+01, -.58491100E+00, -.45300400E+00, -.13309300E+02, -.11914400E+02 },
        { 0.34618900E+00, -.96759900E+00, 0.12596100E+01, 0.30499900E+00, -.44270000E+00, -.12398700E-01, -.10484500E+00, 0.54710900E+00, 0.47681000E+00, 0.13898000E+00, -.57094800E-01, -.94360100E-01, -.47737600E+00, 0.95307900E-02, 0.12051600E+00, 0.14634500E-01, 0.69700600E+00, -.53783100E-01, -.44600600E-01, -.13049800E+00, 0.13425200E+00, -.37735100E+00, -.26872800E+00, -.27259900E+00, 0.35082700E+00, 0.59308800E-01, 0.40151300E-01, -.26493400E-01, -.18019600E+00, -.14463900E+00, -.26366100E+00, -.27710700E-01, 0.47388000E+00, -.11647700E-01, -.20054600E+00, -.97685200E-01, 0.27946600E-01, -.22672700E+00, -.19494000E+00, -.30837000E-01, -.27542700E+00, 0.38591900E+00, 0.14761500E+01, 0.26199900E+00, -.95555200E+00, -.58047100E-01, -.32677600E+00, 0.69671400E-02, -.12420300E+00, 0.32054400E+00, -.40558900E+00, 0.51663900E+00, -.38543700E-01, 0.14367500E+01, 0.10657700E+00, 0.99891100E-01, -.41718400E+00, 0.14014200E+00, -.48243200E-01, -.57062400E-01, 0.13610400E+00, -.92053500E-02, 0.21214900E+00, -.33888200E+00, -.12386900E-01, -.85023400E-01, 0.16061600E+00, 0.17548500E+00, -.17619300E+00, -.31577400E-02, -.22259400E+00, 0.61943000E+00, -.38737200E-01, -.52459500E-01, -.12508400E+00, -.24407600E-01, -.17200900E+00, -.10881400E+00, 0.11070700E+00, 0.74794900E-01, 0.15218900E-01, 0.28418600E-01, -.57565100E-01, -.92419600E-01, 0.10257300E-01, -.10133800E+00, 0.17927500E+00, 0.52976500E+00, 0.64548400E+00, -.98770000E-01, -.56631100E+00, 0.10668400E+00, -.67904700E-01, -.13289300E+01, 0.85691300E-01, 0.96855400E+00, 0.83093900E-01, -.24159200E+00, -.20738800E+00, 0.78006800E-02, -.44975800E+00, -.51610200E-01, 0.16873200E-02, 0.15517700E+00, 0.17905200E+00, -.76618000E-01, -.11907300E+00, -.82311800E+00, 0.79131300E+00, 0.10819400E+01, 0.35671000E+00, 0.42856100E+00, 0.17518600E+00, -.43528800E-01, 0.19268800E+00, 0.33725400E+00, -.29761100E-01, -.13630300E+01, 0.22254400E+00, -.36306300E-01, 0.53205500E-01, -.13203600E+01, 0.72883700E-01, -.14156100E+00, 0.54822600E-01, 0.55639100E-01, -.37960900E+00, 0.55824500E+00, 0.32677400E-01, -.13168900E+00, 0.23493600E+00, 0.30066000E+00, -.19990400E-02, -.19616800E-01, 0.37825700E+00, 0.22207900E-02, 0.10938800E+01, 0.23931500E+00, 0.36251600E+00, 0.11557200E+00, -.89600400E-01, -.79332400E+00, -.15376800E+00, -.26435800E+00, -.97241900E-01, -.48679200E-01, -.24599000E-01, -.13527900E+00, 0.38171300E+00, 0.78705100E-01, -.51054300E-01, 0.55437500E-02, -.19077800E+00, 0.30323100E+00, 0.28983400E+00, -.30346900E-01, 0.46079400E+00, -.76433100E-01, 0.11980200E+00, -.45726500E+00, 0.26649000E-01, 0.55549700E+00, -.45876500E-01, 0.21704600E-01, -.50172300E-01, 0.10193700E+00, -.76535500E-01, -.14286900E+00, 0.14445600E-03, 0.14187100E+00, 0.10795200E+00, 0.21082600E+00, 0.19654300E+00, 0.16360200E+00, 0.34235800E-01, 0.82989600E-01, 0.42296400E-01, -.25493900E-01, 0.14448500E+01, 0.17717200E-02, -.27280200E+00, -.38349000E+00, -.69923400E+00, -.17070700E-01, -.48564900E-01, -.15417700E+00, 0.21257200E+00, 0.74693700E-01, -.26032000E-01, -.12762800E+00, -.11008900E-03, -.43644500E+00, 0.15114800E+00, -.22604600E+00, 0.10038200E+01, 0.78423600E+00, -.76063600E+00, 0.48905500E-01, 0.11572000E+03, -.58224300E+02, -.74938400E+02, -.57655000E+02, -.35103700E+02, -.45662100E+02, -.22322700E+02, 0.23144300E+01, -.14329600E+02, -.48934100E+02, -.76457800E+01, 0.34500600E+02, -.17998400E+02, -.71902000E+01, -.17260100E+02, -.62165400E+02, -.26346600E+02, -.28886300E+02, 0.43512200E+01, -.17032300E+01, -.24603300E+02, 0.62951500E+00, 0.93091300E+01, -.36168700E+01, -.52458700E+01, -.42689900E+01, -.13334500E+02, -.18468300E+02, -.33252400E+01, 0.39844800E+02, 0.16046800E+02, -.25568100E+02, 0.15419300E+01, -.11453300E+01, 0.58999700E+00, 0.13648300E+01, 0.57322400E+00, 0.39698300E+00, 0.19739700E-01, 0.83776900E+00, 0.73441200E+00, 0.68805700E+00, -.82964700E-01, -.93962100E+00, -.26064800E+00, -.66804400E+00, 0.15312700E+02, 0.41745400E+00, -.15126100E+02, -.22423400E+02, 0.62424900E+01, 0.52543700E+01, 0.20866100E+02, -.17468200E+02, 0.36474000E+01, -.21994500E+02, 0.98173400E+01, -.59623900E+01, 0.10994600E+02, -.53527400E+02, -.44181600E+02, 0.41108700E+02, 0.80709200E+02, 0.40243400E+02, -.48929600E+02, -.34639400E+01, -.10105400E+03, 0.51050700E+02, 0.35337300E+02, 0.50533300E+02, 0.94061000E+02, 0.55213200E+02, -.40754000E+02, -.14368400E+03, -.19258700E+02, 0.67162600E+02, 0.67543700E+02, 0.12391600E+01, 0.13230200E+02, 0.19151300E+01, -.22761400E+01, -.31989100E+00, 0.26190600E+01, 0.92811600E+00, 0.10825600E+02, 0.18417700E+00, -.13923000E+01, 0.21023700E+01, 0.27561500E+01, -.16602200E+01, 0.33211800E-01, -.10354700E+01, 0.79271100E+00, -.31865300E+01, 0.53277900E+00, -.68054500E+01, -.39402600E+01, 0.10243100E+02, 0.27914400E+01, 0.32994500E+00, 0.97391600E+00, -.43254200E+01, -.36208800E+01 },
        { -.81310500E+00, -.70004600E+01, 0.26451000E+01, -.75510600E+00, 0.11593200E+01, 0.13200400E+01, -.35644100E+00, -.23770000E+01, -.10383800E+01, -.86349900E-01, 0.73481400E+00, 0.11604900E+01, -.13050500E+01, -.44653200E+00, 0.59566300E+00, -.63058000E+00, 0.13773200E+01, -.54498700E-01, 0.17951700E+01, -.53814600E+00, 0.21839800E+01, -.37394700E+01, -.83665900E+00, -.25503100E+01, 0.40918200E-01, 0.11255800E+01, -.82393400E+00, -.17233000E+00, -.32736600E+00, 0.10939300E+01, -.70920800E+00, 0.76494700E+00, -.39376100E+00, 0.21875200E-01, 0.50148600E+00, 0.37028800E+00, -.14097600E+00, 0.64277700E+00, 0.86962400E-01, -.22298100E+00, -.73468200E-01, -.33003300E+01, -.58692800E+01, -.14651500E+01, 0.93204900E+00, 0.47684900E+00, 0.14230800E+01, -.16178700E+00, -.12583900E-01, 0.15332000E+00, -.18388500E+00, 0.11178900E+01, -.70401900E+00, 0.12212800E+01, -.21055900E+00, 0.70434600E+00, 0.92384200E+00, 0.63752300E+00, 0.56548900E+00, 0.14475200E+01, -.85157000E-01, 0.41321900E+00, -.62676600E+00, 0.91102700E+00, -.26663100E-02, 0.71526800E+00, 0.86108000E-01, -.73824400E+00, -.99947400E-01, -.29495600E-02, -.21764200E+01, -.15269200E+01, -.20395000E+00, -.42340700E+00, 0.16097500E+01, -.27884000E+00, -.50207700E+00, -.77700200E+00, -.12421000E+01, 0.65914400E+00, 0.47063400E-01, -.27531400E+00, -.37336100E+00, -.40560300E+00, -.17571700E+00, -.24829400E+00, 0.20086900E+01, -.26458500E-01, 0.24585000E+01, 0.64678700E+00, 0.10784600E+01, 0.38790900E+00, 0.24730000E+01, -.55292100E+01, -.40968500E+00, 0.12416800E+01, 0.22405200E+01, 0.19305300E+00, -.64826800E+00, -.54281200E+00, -.48554400E+00, -.20431700E+01, 0.26575000E-01, 0.12293300E+00, 0.77194200E+00, -.89246100E+00, -.64733500E+00, -.23322700E+00, 0.31960700E+01, 0.66113400E+00, -.39573000E-01, 0.31048300E+01, 0.10556800E+00, -.31402100E+00, -.76117600E-01, -.58376600E+00, -.84075100E+00, -.11605900E+01, 0.13387700E+00, -.34642100E+00, 0.55625600E+00, -.12209900E+01, 0.16979800E+01, -.95868500E+00, -.21900500E+00, 0.74209100E+00, -.36618100E+00, 0.19387500E+00, 0.40564900E-01, 0.98051000E-01, -.74140300E+00, 0.10485300E+01, -.13525000E+00, 0.50466700E-01, -.97153400E-01, -.30599100E-01, 0.27504400E-01, -.27177500E-01, 0.58289700E-01, 0.50277900E+00, -.40328400E+00, 0.21851700E+01, 0.33942600E+00, 0.10639600E+01, 0.12537500E+01, 0.38265000E-01, 0.14037200E+00, -.91212800E-01, 0.63202100E+00, -.30843600E+00, -.77584900E+00, 0.49265000E+00, -.78693600E+00, -.14296900E+01, 0.16673900E+01, 0.47736200E-01, 0.59630700E+00, -.18080100E-01, 0.50533100E+00, -.19476800E+00, -.49247800E-01, -.58249800E+00, 0.20936100E+00, 0.14610600E+00, -.22504200E+00, -.91257000E+00, 0.32282300E+00, 0.26967800E-01, 0.11417600E-01, -.45319500E-01, 0.16551400E+00, -.52061600E+00, 0.11850900E+00, 0.14357700E+01, 0.14471400E+00, 0.10119100E+01, 0.17552000E+00, -.11653200E+00, -.16346200E+01, 0.79143300E-03, 0.23416400E+00, 0.31967400E+00, 0.16562500E+00, 0.12521800E+00, -.81041600E+00, -.18941300E+00, -.11060600E+01, 0.12790800E-01, -.40397200E-01, 0.23715400E+00, 0.21487300E-02, 0.48531800E+00, -.14244500E+00, 0.36453000E-01, 0.69467700E+00, 0.47142600E+00, 0.20321400E+01, 0.32345400E+00, -.77951000E+00, 0.93318700E+01, -.65792000E+01, -.29282100E+00, 0.22837000E+02, 0.53371800E+02, -.19268700E+02, -.17863600E+02, -.91733400E+01, 0.56858600E+02, -.10264400E+03, 0.16558600E+02, -.84831100E+01, -.15694400E+02, -.82618900E+01, 0.13636100E+02, 0.11644800E+02, 0.25968400E+02, 0.67276000E+01, 0.78803100E+01, 0.10281600E+01, -.21652300E+02, 0.53610900E+02, -.27504100E+02, 0.26860600E+02, -.27597400E+02, -.17020100E+02, -.12474800E+02, -.26237800E+01, 0.16355800E+02, -.18229800E+02, -.90116100E+01, -.42837400E+02, 0.93445300E+00, -.95763900E+00, 0.13828100E+01, -.46831400E+00, -.24876100E+00, -.89396000E-01, -.18257700E-01, 0.15580500E+01, -.14094800E+00, 0.51113700E-01, 0.25810200E+01, -.11868400E+03, 0.62450600E+02, 0.24974900E+02, 0.58942500E+02, 0.13509900E+02, 0.33214400E+02, 0.29111900E+02, 0.15020200E+02, 0.14560300E+02, 0.27090300E+02, 0.26240900E+02, 0.29913100E+01, 0.20520600E+01, -.19342200E+02, -.14908800E+01, 0.10328800E+03, 0.13185600E+03, -.33701700E+02, -.38783700E+02, -.95130800E+02, 0.10864400E+03, -.84903800E+02, 0.38482500E+03, -.19446300E+03, -.14957200E+03, -.19242400E+03, -.13908900E+03, -.85892700E+02, -.23543000E+02, 0.17760500E+03, -.16442600E+02, -.64657200E+02, -.59637200E+02, -.11817800E+00, -.22982000E+02, -.30487100E+01, 0.97156400E+00, 0.58337400E+01, -.20355200E+01, -.56320000E+01, -.19394300E+02, 0.55793300E+00, 0.55594800E+00, -.13503200E+01, 0.12023200E+01, -.41360600E+00, -.83213300E+00, -.55957100E+01, 0.97452000E+00, 0.26682400E+01, -.16202800E+01, 0.23150400E+01, 0.93308500E+01, -.88487800E-01, 0.26931900E+01, 0.38253200E+00, -.71884600E+01, 0.16346000E+02, 0.21866400E+02 },
        { -.25435800E+00, -.66702800E+00, -.15270000E+01, 0.23863600E+00, 0.12255300E+01, 0.31713000E+00, 0.13155100E+01, -.16626500E+01, 0.81070500E-01, 0.55210300E+00, -.15635900E+00, -.11817900E+01, 0.20222200E-01, -.36826700E+00, -.66206700E+00, -.19724800E+00, -.12127100E+01, 0.20371200E+00, -.91280000E-02, -.28572900E+00, -.53596800E-01, 0.13240300E+01, 0.12921100E+00, -.59087500E+00, -.48306700E+00, -.27795800E+00, -.58294600E+00, 0.63698600E-01, 0.38931600E+00, 0.24576300E+00, -.12609400E+00, -.98469200E-01, -.81446400E+00, 0.86611000E+00, -.13004900E+00, 0.65924600E-01, -.45100600E-01, 0.33837200E+00, 0.22628500E+00, 0.38890400E+00, 0.10263300E+00, -.11304600E+01, -.17271800E+01, -.27468900E+00, 0.10804600E+01, 0.27582600E+00, 0.36040800E+00, -.13506000E-01, -.12363300E+00, 0.14580400E+00, 0.36850100E+00, 0.30610500E+00, 0.48526300E+00, 0.71077400E+00, -.49711600E+00, 0.89178900E+00, 0.83115100E+00, -.38450500E+00, -.11338500E+00, 0.24836000E+00, 0.29214000E+00, -.24705600E+00, 0.13279700E+00, -.18033900E+00, 0.66037400E-01, 0.21647700E+00, 0.15113000E+00, 0.31077000E+00, -.28487300E+00, -.48902300E-03, -.80620000E+00, -.12957900E+01, 0.17915600E+00, -.10639400E+00, 0.63510500E-01, -.38558400E-01, -.18470700E-01, 0.22940300E-01, 0.91647100E-01, 0.16055200E-01, 0.21643300E-02, -.37487600E-01, 0.82066800E+00, -.94370300E-01, -.16112400E+00, -.13054600E-01, -.21885700E+00, -.24231400E-03, 0.72363700E+00, 0.17404600E+00, 0.55654000E+00, 0.38119800E-01, 0.22272200E+00, -.28284000E+00, -.28874100E+00, -.58699900E+00, 0.63733500E+00, -.42944100E+00, -.18590400E+00, -.35060000E+00, 0.55783100E+00, -.73138200E-01, 0.67392300E-02, -.34889700E+00, -.15757600E+00, -.85191900E+00, 0.11282800E-01, -.14430800E+00, 0.14648500E+00, -.10307000E+01, -.45390500E+00, 0.30047600E+00, -.37004100E+00, -.50007200E-01, -.11107200E+00, 0.57483200E-01, -.82414200E-02, -.84395500E+00, -.98871800E+00, 0.46014100E-02, -.52951800E+00, 0.71147800E+00, -.90628900E-02, 0.53366900E+00, 0.11567900E+00, 0.29084400E+00, 0.12387900E+01, -.30071000E+00, 0.51611700E-01, 0.36611000E+00, -.36722200E+00, -.74182600E+00, 0.91796800E-01, -.11216200E+00, -.37226800E+00, -.22276000E-02, -.29431900E-01, -.27656700E+00, -.93848700E-01, -.26028800E+00, 0.15677700E+00, 0.40093000E+00, 0.19446400E+00, 0.37370000E+00, 0.78802500E+00, 0.16570900E+00, 0.84886700E-01, -.23360000E-01, 0.11990200E+00, -.12427800E+00, -.56764000E+00, 0.50970700E+00, -.28589900E+00, -.14576900E+01, -.59452000E+00, 0.30546900E+00, -.17093700E+00, 0.42113300E-02, 0.17921800E-01, 0.45907200E+00, -.58891200E-01, -.67573600E+00, 0.13816000E+00, -.92996100E-01, -.41963400E+00, 0.29935000E+00, -.47582700E-01, 0.10727800E+00, 0.41900600E-01, -.42911900E+00, 0.15349400E+00, -.19644200E+00, -.96271900E-01, 0.70041800E-01, -.10058600E+00, -.12410800E+01, -.11233500E+00, 0.51421500E-01, 0.92152500E-01, -.32883600E-02, -.26428100E+00, 0.38912400E+00, -.11258100E+01, 0.20691800E+00, 0.13850800E+00, 0.78176000E-02, 0.27806100E+01, 0.10532900E+00, 0.15967700E-01, 0.19470900E+00, 0.71693400E-03, -.25826700E+00, 0.10646600E+00, 0.41310400E+00, -.71457100E-01, -.16590300E+00, -.24585600E+00, 0.15624200E+00, -.36725600E+00, -.48444100E-01, -.43232900E+02, 0.35448700E+00, -.22062400E+02, -.83750800E+02, 0.14868300E+02, 0.51188900E+01, 0.24251200E+02, -.77398100E+02, 0.47857500E+02, -.43792300E+01, 0.19663100E+01, -.29170200E+01, 0.21812300E+01, -.49526600E+02, -.89677500E+02, -.17448500E+02, -.87005200E+01, 0.86482700E+01, -.74967800E+02, 0.71918600E+01, -.15908500E+02, 0.84581800E+01, -.44392500E+02, 0.85693900E+01, -.16754500E+02, -.85646700E-01, -.22035400E+02, 0.15731300E+02, 0.61059100E+02, -.79703000E+01, -.99292100E+01, -.20904500E+01, 0.89274900E+00, 0.43644300E+00, 0.10432600E+01, 0.23057000E+00, 0.25055100E-02, 0.10281000E+01, 0.73839000E+00, 0.96535200E+00, -.24504600E+00, 0.23181800E+00, 0.19596300E+01, -.59379200E+01, 0.30279400E+02, -.60161000E+00, -.12854700E+02, -.13931400E+02, -.14145000E+02, -.33887500E+02, -.97182000E+00, -.75993900E+01, 0.27483200E+02, 0.93660100E+01, -.60384200E+01, -.30760600E+02, -.46833500E+01, -.12433500E+03, -.11670200E+03, 0.51936200E+02, 0.92637600E+02, 0.70739800E+02, -.10341400E+03, 0.18638300E+01, -.34328600E+03, 0.17171800E+03, 0.12706400E+03, 0.17164600E+03, 0.15438200E+03, 0.11320400E+03, -.25837500E+02, -.26098500E+03, -.56536600E+01, 0.12259900E+03, 0.13973100E+03, 0.21185100E+01, 0.22787100E+02, 0.33070100E+01, -.58963800E+00, -.19004200E+00, 0.37275800E+01, 0.74881600E+01, 0.18325000E+02, 0.15241000E+00, -.14787800E+00, 0.33663700E+01, 0.22570200E+01, -.24603800E+01, -.16205400E+00, -.19123500E+01, 0.77223400E+00, -.26736700E+01, 0.75826100E+00, -.91538200E+01, -.76320800E+01, 0.14399600E+02, -.24767600E+01, 0.36364700E+00, 0.37831900E+01, -.13508800E+02, -.14992300E+02 },
        { -.79748900E+00, 0.20424300E+01, -.85879600E+01, 0.51067500E+00, 0.63928700E+01, 0.44007400E+00, 0.79067500E+01, 0.94946500E+00, -.61799700E+00, 0.19292100E+00, 0.46703600E+00, -.58626700E+01, 0.15329300E+01, -.55854800E+00, -.68231800E+00, -.11243400E+01, -.83692800E+01, 0.11622300E+01, -.90463500E+00, 0.14889300E+01, -.16258100E+01, -.28448500E+01, 0.55575800E+00, -.10694200E+01, -.14072200E+01, 0.13279600E+00, -.16105100E+01, 0.72810200E+00, -.22494500E+00, 0.12947100E+01, 0.48400300E+00, 0.86202500E+00, -.24141900E+01, -.32781900E+00, 0.18120300E+00, -.61981300E-01, -.19924600E+00, 0.56265100E+00, 0.15885700E+01, 0.56655700E+00, 0.34263400E+00, 0.10262600E+00, -.58845000E+01, -.16177500E+01, 0.20934800E+01, 0.15590600E+01, 0.28281700E+01, -.30012500E+00, 0.12721000E+00, -.26436200E+00, 0.11169800E+01, -.10546000E+01, -.21789600E+01, 0.29688900E+01, 0.76023800E+00, 0.22770700E+01, -.48859700E+00, -.13550900E+01, 0.90256300E+00, 0.39655800E+00, 0.37106500E+00, -.40516100E+00, -.16865600E-02, -.53429000E-01, -.50104800E-01, 0.59818000E+00, -.19800600E+00, -.65145300E-01, 0.21908000E+00, 0.17055900E-01, -.25930200E+00, 0.11426100E+01, -.54443700E-01, 0.24528200E-01, 0.64831200E+00, -.30442700E+00, 0.68642400E+00, 0.87518300E-01, -.32850200E+00, 0.28347300E+00, -.47237200E-01, -.16188500E+00, -.39787200E-01, 0.23438100E+00, 0.23075500E+00, 0.66736700E+00, 0.15246400E+00, -.61570500E+00, 0.15467400E+01, -.10516400E-01, 0.10097200E+01, -.23661700E+00, -.54480700E+00, 0.18013400E+01, 0.16684600E+01, 0.26553700E+01, 0.10152000E+01, -.10032000E+01, 0.17978300E+01, 0.12127100E+01, -.44179100E+01, -.19123100E+00, 0.16153100E-01, 0.40357900E-01, 0.35849400E-01, -.16238700E+00, 0.13005600E+00, 0.97987600E+00, -.93570700E-01, 0.74372600E+00, 0.94021200E-01, -.62451700E+00, 0.58120900E+00, -.77530000E-02, 0.24350300E+00, 0.73230500E+00, -.37018500E+00, -.43873500E+01, -.13532000E+01, -.29220500E+00, 0.10313200E+00, -.61735300E+00, 0.49042000E+00, 0.64829100E+00, -.78302300E-01, -.34474400E+00, 0.59591000E+00, 0.10077100E+01, 0.77842400E-02, 0.55008000E+00, -.28800100E+00, -.21561900E+01, 0.40996400E+00, -.26814900E+00, 0.92376000E-01, 0.48471100E-01, 0.68802300E+00, -.23100200E+00, 0.27182900E+00, 0.46824600E+00, -.34957800E+00, 0.10218800E+01, 0.20668300E+00, -.17069700E+01, -.11288900E+01, 0.22252800E+00, -.22312500E-01, -.95774200E+00, -.25990800E-01, 0.10815700E+00, 0.34293000E+00, -.92715500E-01, -.91993400E+00, -.14251200E+00, 0.57890200E+00, 0.76518100E-01, -.92785800E+00, 0.11078300E+00, 0.36771300E+00, 0.94899200E-01, 0.84876300E-01, 0.30262800E+00, -.15669800E+00, 0.81675600E-01, 0.29256500E-01, -.96731600E+00, -.17166500E-01, 0.32498000E+00, 0.24996700E-01, -.69059400E+00, 0.39665200E+00, 0.63157000E-01, -.31650000E+00, 0.20641100E+01, -.15136200E+00, 0.22161900E+01, 0.62314700E+00, -.14949100E+00, -.43252100E+01, -.62657200E-02, 0.66046600E+00, 0.68369800E+00, 0.19732500E+01, -.42134200E+00, -.14583400E+01, -.12904700E+00, -.18470900E+01, -.36457100E+00, 0.24619900E-01, 0.33322400E+00, 0.11199700E-01, 0.62960600E+00, -.15733900E+00, 0.43926900E+00, -.47024800E+00, 0.45195800E+00, 0.36620000E+01, 0.10051700E+01, -.15737700E+01, -.10907300E-01, 0.11750400E-01, 0.32823600E+01, 0.15241400E+02, 0.76839500E+02, -.75370600E+01, -.21968800E+02, -.75201700E+01, 0.74376600E+02, -.13046800E+03, 0.42936600E+02, -.19570200E+02, -.13433800E+02, -.21364600E+02, -.16020300E+02, 0.41870300E+02, 0.22032700E+02, 0.13730500E+02, 0.50029800E+01, 0.26792600E+02, -.43020500E+02, 0.65682300E+02, -.35343000E+02, 0.44693200E+02, -.35565100E+02, -.12447200E+02, -.30509100E+02, -.15223600E+02, 0.15793000E+02, -.30840600E+02, -.23093900E+02, -.47871400E+02, 0.18787600E+01, -.13224900E+01, 0.21064100E+01, -.95470300E+00, -.28291400E+00, 0.37893200E+00, -.11828400E+01, 0.29591300E+01, -.82768000E+00, 0.54892600E+00, 0.49863000E+01, -.37939500E+01, 0.47797600E+01, -.39231500E+02, 0.11404100E+01, 0.23002300E+02, 0.49536800E+02, 0.14827800E+02, 0.53539500E+02, -.13900400E+02, 0.35722200E+02, -.21491200E+02, -.92067600E+02, 0.54018300E+02, 0.44615700E+02, 0.46069700E+02, 0.16583200E+03, 0.18925100E+03, -.32617900E+02, -.55560400E+02, -.93994400E+02, 0.15705300E+03, -.10762700E+03, 0.57477600E+03, -.29267200E+03, -.24441000E+03, -.28746400E+03, -.17772100E+03, -.10543700E+03, -.70636600E+02, 0.24597100E+03, -.47020700E+02, -.84359800E+02, -.13132400E+02, -.40933700E+00, -.27503600E+02, -.49216300E+01, -.10423900E+01, 0.71128900E+01, -.28212800E+01, -.13560900E+02, -.23338400E+02, 0.11809600E+01, 0.81772900E+00, -.13676000E+01, 0.30222700E+01, 0.12802000E+01, -.26820100E+01, -.66342300E+01, 0.26987700E+01, 0.15720600E+01, -.22157300E+01, -.50957700E+00, 0.15721500E+02, 0.20383400E+01, 0.59225800E+01, 0.77783300E+00, -.68894700E+01, 0.22931600E+02, 0.30897600E+02 },
        { 0.46659600E-01, 0.19584900E+00, -.21085400E+00, 0.10787700E+00, -.17754600E+00, 0.13631700E-01, -.13752600E+00, 0.23817900E+00, 0.80156800E-01, -.30281900E-01, -.23889800E-01, 0.34628800E-01, 0.36916100E-01, 0.59400900E-01, -.12746400E+00, 0.84078800E-01, 0.13163700E+00, -.10651600E-01, -.24942900E+00, -.12076000E-01, -.71582800E-01, -.19998600E-01, 0.27162200E-01, -.38725400E-01, -.88779200E-01, -.10128200E+00, 0.45737600E-01, 0.11194800E+00, 0.56100600E-02, -.95103000E-01, 0.10917000E-01, -.49571400E-01, -.20326800E-01, 0.52698200E-01, 0.21355800E-01, -.39502200E-01, 0.47798600E-02, 0.75468400E-02, 0.18800600E-01, -.21976400E-01, 0.34139000E-01, -.80640500E-01, -.31923500E-01, 0.41627300E-01, 0.35837500E-01, 0.91213100E-03, 0.43059100E-01, 0.66040900E-02, 0.10086100E-01, 0.64849400E-01, 0.82668600E-01, -.46186000E-01, 0.32369600E-01, -.16118500E+00, -.76124600E-01, 0.90698800E-02, 0.28260600E-01, 0.26218400E-01, -.25429600E-01, -.35961300E-01, -.46214700E-01, -.24248400E-01, -.11478500E-01, 0.17515900E-01, 0.17883000E-02, 0.34528400E-01, 0.14131000E-01, -.25834500E-01, -.22992900E-01, -.13343000E-02, 0.66216800E-01, -.69327000E-01, 0.12326600E-01, 0.94614000E-02, -.95975600E-02, -.21114500E-01, -.97843300E-02, 0.23712800E-01, 0.36428600E-01, -.41779700E-01, 0.16078400E-03, -.41104000E-02, 0.11884600E+00, 0.79080100E-02, -.10839900E-01, -.23392800E-02, -.23903300E-01, -.18950800E-01, -.13603300E+00, -.15463500E-01, 0.90312700E-01, 0.48998400E-02, -.70143000E-01, -.10967700E+00, -.38416400E-02, -.16082400E-01, 0.14094100E-01, -.21759800E-01, 0.11302800E-01, -.23121700E-01, 0.14797600E+00, 0.82906300E-02, 0.95029900E-03, 0.40919800E-01, 0.28159200E-01, -.16329600E+00, -.59924600E-01, -.29224300E-01, 0.85583400E-01, -.12133700E-01, 0.18428900E-01, 0.12787900E-03, -.26376800E-02, 0.28099600E-02, 0.19837500E-01, -.97374900E-02, -.95236600E-02, 0.12518000E+00, 0.51402100E-01, -.19919900E-01, 0.99672100E-01, -.18716100E-01, -.26642000E-01, -.39544000E-01, 0.70818700E-02, 0.15132900E-01, -.17105000E-01, 0.98728000E-02, 0.47519400E-02, -.75080100E-02, -.19366700E-02, -.12788800E-01, -.64522100E-02, -.82331300E-02, -.17423100E-02, -.20936500E-02, 0.12492000E-01, -.31479400E-02, -.30917900E-02, -.10494200E-01, -.17108900E-01, -.74831300E-01, -.18606100E-01, -.14079500E-01, -.34204100E-01, 0.15768300E-02, 0.53748100E-02, 0.60668300E-01, 0.36331200E-01, -.79281600E-02, 0.22950600E-01, -.15983900E-02, 0.54945400E-01, 0.11641600E-01, -.41076300E-01, 0.80428600E-02, 0.25023100E-02, -.63377700E-02, -.80310200E-02, 0.27041300E-01, 0.20785500E-01, -.21273000E+00, 0.10133700E-01, 0.17552800E-02, -.33375700E-02, 0.14998600E-02, 0.33585400E-02, 0.35426100E-01, 0.71264500E-02, -.10095000E-01, -.13949300E-01, -.18680200E+00, -.52861800E-01, -.96639500E-01, -.18777400E-01, -.25454300E-01, -.11532300E-01, 0.39767300E-02, 0.23859600E+00, 0.71663900E-04, 0.20051800E-02, 0.39615700E-01, 0.20545600E-01, 0.34446200E-01, 0.42562800E-01, 0.62993900E-01, -.99581900E-01, 0.62935200E-02, -.34327600E-02, -.20924200E-01, -.31568000E-03, 0.14695600E-01, -.34786000E-01, -.87241900E-01, 0.13627000E+00, 0.71933300E-01, -.22410200E+00, -.25025400E-01, 0.53787600E-01, 0.66226600E-02, 0.80466100E-01, -.10338300E-01, 0.55348000E+01, 0.10983400E+02, -.14973100E+01, 0.59386900E+00, -.22230900E+01, 0.96236600E+01, -.79213000E+01, -.73564100E+01, 0.37621100E+01, 0.19668100E+01, 0.36785900E+01, 0.87191000E+01, 0.21064900E+01, 0.25744900E+01, -.30845900E+00, -.27464700E+00, 0.26879300E+01, 0.39171500E+01, 0.70641800E+01, -.38822600E+01, 0.71194900E+01, -.35790200E+01, -.20480300E+01, -.29442100E+01, 0.50693200E+01, 0.73437700E+01, -.35196200E+01, -.22559300E+01, 0.13348800E+01, -.28600700E-01, -.29117000E-02, 0.11429700E+00, 0.14511800E-01, -.12628100E+00, -.22561900E+00, 0.21835200E+00, -.22501900E+00, 0.14918700E+00, -.14052500E+00, -.42326700E+00, -.16441600E+02, 0.80518400E+01, 0.63845800E+01, 0.81833800E+01, 0.19141800E+01, 0.19062400E+01, 0.36768800E+01, 0.12882300E+01, 0.25435600E+01, 0.14945000E+01, 0.33945400E+01, 0.34735300E+02, -.16678100E+02, -.29743200E+02, -.17367700E+02, 0.29908000E+00, 0.66451000E+01, -.11897100E+02, 0.33187700E+01, -.18683000E+02, 0.38850300E+01, -.13698600E+01, 0.29787100E+02, -.15368300E+02, -.70231000E+01, -.14893500E+02, -.12272900E+02, -.14170300E+02, 0.13505100E+02, 0.24317500E+02, 0.45097600E+01, -.13062300E+02, -.31268200E+02, 0.77519000E-02, -.32644600E+01, -.23138200E+00, 0.29197100E+00, -.21971900E-01, 0.19712800E+00, 0.12171200E+00, -.25812500E+01, -.76916800E-01, -.32555500E+00, -.17543300E+00, -.33723800E+00, 0.37422800E+00, 0.43650300E+00, 0.64735600E+00, -.20784500E+00, 0.24887000E+00, -.13100300E+00, 0.14384300E+01, 0.11606600E+00, -.15223900E+01, 0.54924700E+00, -.49444100E-01, -.55019600E+00, 0.16982000E+01, 0.17651800E+01 },
        { -.18869600E-01, -.26455900E+00, -.30048000E+00, 0.99501100E-02, 0.28741900E+00, 0.10623000E+00, 0.41815800E+00, -.16647900E+00, 0.79090600E-01, 0.16382900E+00, -.52982800E-01, -.27976800E+00, -.75377200E-01, -.14601200E+00, -.18358100E+00, -.48729100E-01, -.27059900E+00, 0.46281200E-01, -.55983300E-01, -.67543200E-01, -.72868500E-02, -.35654000E+00, -.51817300E-01, -.83170500E-01, -.61436900E-01, -.21566600E-01, -.57109600E-01, -.61613500E-01, 0.24045800E-02, 0.51074700E-01, 0.19950200E-01, 0.16626500E-01, 0.35699400E-01, -.31260400E-02, -.12225600E-01, 0.19269500E-01, 0.21446200E-03, 0.13895200E-01, -.32552200E-01, -.19016400E-02, -.67082400E-01, -.13171100E+00, 0.94863000E-01, 0.31843400E-01, 0.12795200E-01, -.38556200E-01, -.11624400E+00, 0.21383200E-02, 0.19568700E-01, -.29639000E-01, -.26150400E-02, 0.18385100E-01, 0.54290800E-01, 0.11557400E+00, -.16498500E-01, 0.46516200E-01, 0.17035600E-01, -.66689200E-01, -.11776400E-01, -.12163800E-01, 0.55746800E-01, -.30369100E-01, 0.23008200E-01, -.61387600E-01, -.60959500E-02, -.16541700E-01, 0.10877900E-01, 0.67612800E-01, -.33819500E-03, -.25433000E-03, -.33919900E-01, -.80655500E-01, 0.11299500E-01, -.33232100E-03, -.32814400E-01, 0.16803800E-01, 0.10903200E-02, 0.45318600E-02, -.50981800E-02, 0.28076000E-02, -.17850000E-04, 0.15226300E-01, -.24696300E-01, -.93321200E-02, -.20391700E-03, -.27104300E-01, 0.44318500E-01, 0.67279400E-01, 0.12605000E+00, -.11104200E-01, -.15699700E-01, -.10441700E-02, 0.33571900E-01, -.64563800E-01, -.64567000E-02, -.53996400E-02, 0.44463300E-01, -.24983300E-01, -.13480600E-01, -.16437100E-01, -.63431900E-01, -.46255100E-02, 0.23836100E-02, -.21515000E-01, 0.59843800E-03, -.91350300E-01, -.28631500E-01, -.81647200E-01, 0.56288400E-01, 0.24520500E-01, 0.60281400E-01, 0.32768200E-01, -.13719200E-01, -.58658000E-02, 0.11421400E-01, 0.40827400E-01, 0.84646700E-02, -.12619300E+00, -.42739700E-01, 0.36785200E-03, -.36721600E-01, -.21078400E-01, 0.23153800E-01, 0.62151600E-01, 0.42771300E-02, 0.24746700E-01, 0.12143900E+00, -.82868400E-01, -.62886500E-02, -.40622100E-02, -.51884500E-01, 0.31594200E-01, -.49582700E-02, -.27245800E-01, 0.23536600E-01, -.21642000E-02, 0.88774600E-02, 0.68025400E-02, -.11643500E-01, -.91604800E-01, 0.39115600E-01, -.21290000E-01, 0.22440500E-01, 0.88967600E-01, 0.11795500E+00, 0.11245900E-01, 0.83999000E-04, -.24169600E-01, -.50505600E-02, -.17216500E-01, -.57443000E-01, 0.97911300E-02, -.60312800E-02, -.17141900E-01, 0.22869400E-01, -.91609300E-02, 0.19614000E-01, 0.19222400E-02, -.23695500E-01, -.40676400E-01, -.17769100E-01, 0.64384100E-01, -.19707500E-01, 0.10920500E-01, -.38972100E-01, -.38732300E-01, -.32170800E-04, -.10794100E-01, -.37755600E-02, 0.55233400E-02, -.12689900E-01, -.72711200E-01, -.36953100E-02, 0.10888700E+00, -.30046600E-02, 0.21537100E-01, 0.26560800E-01, -.32206400E-02, 0.26055200E-01, -.57004700E-04, 0.20806400E-02, 0.36062100E-01, 0.22930200E-01, -.66435900E-02, -.10166300E-01, -.12760100E-01, 0.39753200E-01, -.35412200E-01, -.27565300E-02, 0.11593900E-01, 0.78615200E-04, -.47580400E-02, 0.23105700E-01, -.19613100E-01, -.91539900E-01, -.50423900E-01, -.10796400E+00, 0.11856900E-01, -.58274400E-02, 0.15165300E-01, -.49872300E-01, 0.72295600E-02, -.17168400E+00, -.48329300E+01, -.52340400E+00, -.10548000E+01, -.93851000E+00, -.40773200E+01, 0.15065800E+01, -.31377800E+01, 0.14279000E+01, 0.19207800E+01, 0.15690000E+01, -.25271200E+01, -.51865700E+01, -.21010800E+01, -.16681600E+01, -.41389300E+00, -.39129000E+01, 0.33522000E+01, 0.35635800E+01, -.15807300E+01, -.19772300E+01, -.17494600E+01, -.38893100E+01, -.14461000E+01, 0.30250200E+00, 0.50978300E+01, 0.51392900E+01, -.22075700E+01, 0.21026400E+00, -.19570800E+00, 0.11592900E+00, 0.39032400E-01, 0.97517400E-01, 0.15527200E-01, -.64072700E-01, 0.16670600E+00, -.10206300E+00, 0.13554200E+00, -.66514600E-01, -.36839300E+00, 0.31317900E+00, -.56628200E+00, 0.25867600E+01, -.14381700E+00, -.86066000E+00, -.21172800E+01, -.22465400E+01, -.40938600E+01, 0.13156400E-01, -.14278500E+01, 0.30439800E+01, 0.12359800E+02, -.68034600E+01, -.94149000E+01, -.61796100E+01, -.13417100E+02, -.87203200E+01, 0.64231100E+00, 0.62606600E+01, 0.22422800E+00, -.79342600E+01, 0.50741200E+01, -.22984800E+02, 0.11858800E+02, 0.85816100E+01, 0.11491900E+02, 0.11421800E+02, 0.32399000E+01, 0.47166700E+01, -.13295400E+02, 0.29487100E+01, 0.38532100E+01, -.57200400E+01, 0.16100300E+00, 0.11972500E+01, 0.31238500E+00, 0.39878300E-01, 0.10675500E+00, 0.44350800E+00, 0.12630700E+01, 0.11147000E+01, -.27391700E-02, -.14694700E+00, 0.27749200E+00, -.85862300E-01, -.10927200E+00, 0.82150200E-01, -.74082400E-01, -.10275900E+00, -.22891600E+00, 0.11201300E+00, -.23886500E-01, -.73113600E+00, 0.32248400E+00, -.15148600E+00, 0.51485300E-02, 0.61454800E+00, -.68972700E+00, -.10050100E+01 },
        { -.58633000E+00, 0.95620700E+00, -.37395100E+01, -.11761200E+01, 0.11161500E+01, 0.41734800E+00, 0.24064000E+01, 0.18497700E+01, 0.40016000E+00, -.44729700E+00, -.24813000E+00, -.17615100E+01, 0.84144100E+00, -.37792300E+00, -.13085600E+01, -.36396600E+00, -.15730900E+01, 0.34034300E+00, 0.20561900E+00, -.13063400E+00, 0.22269800E+00, 0.24373500E+01, 0.37569200E+00, -.18093800E+01, -.64677000E+00, -.81938300E+00, -.14237200E+01, 0.23147100E+00, 0.54531200E+00, 0.10661300E+00, 0.46779400E+00, 0.10404100E+00, 0.29142800E+00, -.15916900E+00, -.33856800E+00, 0.28623000E+00, 0.28453400E-01, -.45348000E+00, -.24017800E+00, -.30463600E+00, -.92606500E+00, -.96296400E+00, 0.26486400E+01, 0.94005400E+00, -.19379100E+01, -.39441200E+00, -.11915900E+01, -.35005700E-01, 0.15420600E+00, 0.20112900E+00, -.11637000E+01, 0.13684300E+01, 0.39969300E-01, -.19530400E+01, -.79499500E+00, 0.87762100E+00, -.83794000E+00, 0.16844600E+00, 0.84005900E-02, -.93241500E+00, 0.43552300E+00, -.40728600E+00, -.12844300E+00, 0.35930700E-01, -.25645400E+00, 0.16510500E+00, 0.10322200E+00, 0.14096800E+01, -.12202000E+00, 0.49875500E-02, -.16065600E+01, -.31763500E-01, 0.78814900E-01, 0.21771700E+00, 0.39941200E+00, 0.15836300E+00, -.57898800E+00, 0.38509400E+00, -.23879600E-01, 0.22667600E+00, 0.41247000E-01, 0.18354400E+00, -.18949300E+01, 0.33964200E+00, -.20201600E+00, -.21413700E+00, 0.22425300E+01, -.23406400E+00, 0.15945900E+01, -.12453500E+00, -.11450900E+01, 0.23728800E+00, 0.16037200E+01, -.24956100E+01, -.63268800E-01, 0.77227300E+00, -.42631100E+00, 0.10569000E+01, -.96992800E+00, -.90140900E+00, 0.41140300E+01, -.12504400E+01, -.36676200E-01, 0.59766600E+00, 0.40074200E+00, 0.10411000E+01, -.41277700E+00, -.37851400E+00, -.15140500E+00, -.45993800E+00, 0.11698700E+01, 0.96780300E+00, -.37464500E+00, 0.25105400E-01, -.50821600E-01, 0.33934300E+00, 0.51332500E+00, -.13485400E+01, -.10205100E+01, 0.10191400E+00, 0.86237000E-01, 0.75359000E+00, -.37270000E+00, 0.21498700E+01, 0.65611700E-01, 0.25797000E+01, 0.18379000E+01, -.19750400E+01, -.11372700E+00, -.69434000E+00, -.89573900E+00, 0.16835300E+01, -.39625400E+00, 0.12314500E+00, 0.13396100E+00, -.59020800E-01, -.15927900E+01, 0.25235600E+00, -.66749300E+00, -.11016100E+01, 0.90096700E+00, -.73777000E+00, 0.18160900E+00, 0.16431500E+01, 0.24549300E+01, 0.23700200E+00, 0.15694400E+00, -.67078600E+00, 0.12551100E+01, -.11532700E+01, -.13350300E+01, 0.50656300E+00, 0.24893700E-01, 0.15727600E+00, 0.22043600E+01, -.66161600E+00, 0.68737400E+00, 0.24002600E+00, 0.55270900E-01, -.12028900E+00, -.18180600E+00, 0.58717600E+01, 0.49247200E-01, 0.14588700E+00, -.10760500E+00, -.15031000E+01, 0.71632200E-01, -.77573400E-01, -.16655800E+00, 0.43392300E-01, -.22535400E+00, -.13736100E+01, -.41676000E+00, 0.25160900E+01, 0.34666200E-01, 0.34772000E+00, 0.36081700E+00, 0.23445900E-01, -.74181600E+01, -.13453700E-02, 0.79138300E+00, -.63791100E-01, 0.91277800E+00, -.24793800E+00, -.13819700E+01, -.93642900E+00, -.57165400E+00, 0.37053400E+00, 0.83533400E-01, 0.12587700E+00, -.15278100E-02, -.11813200E+01, 0.21091400E-01, 0.16557600E+01, 0.20455200E+01, -.97825500E+00, -.76520300E+00, -.90045200E+00, -.38825300E+00, 0.13837000E+00, 0.13866000E+01, -.11330900E+00, 0.44234500E+01, -.85496000E+01, -.10210900E+03, -.20097400E+02, -.37156900E+02, 0.10686900E+01, 0.12312900E+03, 0.59727000E+01, -.83882700E+01, 0.27598500E+01, -.29888600E+01, -.10674000E+03, -.25779600E+02, 0.64464500E+02, 0.42275400E+02, -.22427600E+01, -.41280200E+01, 0.16530000E+02, -.39545600E+02, 0.27695100E+02, -.35156500E+02, 0.20051100E+02, 0.15332600E+02, 0.21827600E+02, -.37556000E+02, -.59894200E+02, -.39993900E+02, 0.10479600E+02, 0.30799000E+02, 0.39286900E+00, 0.12775400E+01, -.31186000E+01, -.19405900E+00, 0.25042100E+00, 0.90499500E+00, 0.11014900E+01, -.17861200E+01, 0.43103500E+00, 0.98363300E+00, -.23928700E+01, 0.17043400E+03, -.77686200E+02, -.65800100E+02, -.85221300E+02, -.34290500E+02, -.59547000E+02, -.32097800E+02, 0.61698600E+01, 0.19025100E+02, -.49896000E+02, -.52664900E+02, 0.19849100E+03, -.12285500E+03, -.26094900E+02, -.99247700E+02, 0.54597400E+02, -.22879700E+02, -.25055100E+01, 0.25230600E+02, 0.53489000E+02, -.51201300E+02, -.24756400E+02, -.25402200E+03, 0.14409000E+03, 0.12473600E+03, 0.12701500E+03, -.13523900E+02, -.72268400E+01, -.14704400E+02, -.63507900E+02, 0.10555400E+02, 0.11005100E+01, -.16130300E+02, 0.43193900E-01, 0.42622700E+01, 0.29179600E+01, -.35840000E+00, -.21483300E+01, -.30709600E+01, 0.37235800E+01, 0.43993900E+01, -.10173300E+01, -.12291000E+01, 0.77534200E+00, -.20768600E+01, 0.28216400E+01, -.27631000E+01, 0.36322100E+00, -.12584600E+01, -.10986500E+01, 0.47474600E+00, 0.56285700E+01, -.87079300E+01, -.12892200E+02, 0.48870100E+00, -.10767000E+01, 0.77252700E+01, -.84421200E+01, -.13324000E+02 },
        { 0.26803600E+00, -.87938700E+00, 0.30442100E+01, 0.41852600E+00, -.10430500E+01, -.32819600E+00, -.10230000E+01, 0.79764000E+00, 0.33054100E+00, -.22829900E+00, -.44757700E+00, 0.23526600E+00, -.13921600E+00, -.10060900E+00, -.34247800E+00, -.61020000E-01, 0.46525800E+00, -.14525900E+00, -.14952500E+00, -.15096500E+00, 0.49386200E+00, 0.55418100E+00, -.58132400E-02, 0.37921100E+00, 0.13017000E+00, -.77299600E-02, 0.38689000E+00, -.14786500E+00, 0.35777400E-01, -.26640900E+00, -.10556700E-01, -.57927700E-01, 0.62018700E-01, -.12395800E+00, -.26098900E+00, 0.14615600E+00, 0.12223800E-01, -.98296500E-01, -.44094700E+00, 0.23129900E+00, 0.30207200E+00, 0.12449500E+01, 0.56684300E+00, 0.76433700E-01, -.28675400E+00, -.15730100E+00, -.32230700E+00, 0.53089200E-01, 0.36820500E-01, -.13822100E+00, 0.23077200E+00, -.72525100E+00, -.56409200E-01, -.88967000E+00, 0.37372600E+00, -.20036500E+00, 0.24577900E+00, -.12119500E+00, -.11276400E+00, 0.29616600E-01, -.16949800E+00, -.44120900E-01, 0.13974300E+00, 0.68238700E-01, 0.80917500E-01, -.14492500E-02, -.82789400E-02, -.61615600E+00, 0.14666700E+00, 0.15035200E-02, 0.33769700E+00, 0.40708100E+00, 0.92418000E-02, 0.73872300E-01, 0.51157300E-01, -.16079200E+00, 0.19520400E+00, 0.29439900E+00, 0.68008800E-01, -.11977900E+00, -.17337200E-01, -.33913400E-02, 0.22534000E+00, -.16541500E+00, 0.27999700E-01, -.17574600E+00, 0.23014700E+00, -.27870300E+00, -.73705600E+00, 0.17093900E-01, 0.30725500E-01, -.17465600E+00, 0.11319300E+00, 0.41091800E+00, -.35897200E+00, -.53342500E+00, -.15117100E+00, 0.25972300E+00, -.42436300E-01, 0.85649000E-01, 0.23307900E+00, 0.21406600E+00, 0.98136800E-02, 0.20132000E+00, 0.10274100E+00, -.11399400E+00, -.10525800E+00, 0.14879000E-01, 0.20314300E+00, 0.48735600E+00, -.25056900E+00, -.23174500E-01, 0.94031100E-01, -.70284700E-01, -.31595300E-01, -.46783700E-01, -.10311000E+00, -.32317400E+00, 0.26367500E+00, -.29891000E-02, 0.42971900E-02, -.28464100E+00, 0.19299300E-01, -.16880800E+00, 0.35959200E-01, -.16021700E+00, 0.27767800E-02, 0.31409500E+00, 0.13707100E-01, -.31276600E-01, 0.12771900E+00, -.36820100E+00, 0.45028000E-01, -.88937800E-01, -.11061800E+00, -.32648200E-03, 0.14021400E+00, 0.33367800E-01, 0.79388600E-01, 0.22280700E-01, -.59458000E-01, -.32889900E+00, -.72874200E-01, -.31716100E+00, -.34545200E+00, -.93612800E-01, -.93022200E-02, 0.42935500E+00, -.24556500E+00, 0.16145600E+00, 0.25936200E+00, -.11294300E+00, 0.35723800E+00, -.36271000E-01, -.69251800E+00, 0.10187400E+00, -.55631600E+00, -.17611500E-01, -.57272400E-01, 0.23397300E+00, 0.28282400E+00, -.85682600E+00, 0.22927000E-01, -.40136400E-01, 0.13283500E+00, -.14643600E+00, -.25480900E-01, -.10570600E+00, 0.67071400E-02, -.88383600E-02, 0.41358300E-01, 0.24159000E+00, -.62448600E-02, 0.12246700E+00, -.37683300E-01, 0.89554700E-01, -.47935100E-01, 0.24939900E-02, 0.32870700E+00, 0.26924500E-03, 0.40120600E-01, 0.21839500E+00, 0.32991800E+00, -.19586700E-01, 0.44478500E-01, 0.70417700E-01, -.76402800E+00, -.73128400E-01, -.18491100E-01, -.12749500E+00, 0.15120800E-03, 0.26407100E+00, -.43038900E-01, -.18281500E+00, -.30612300E+00, -.24596600E+00, -.48250600E-01, 0.64640900E+00, -.31752500E-01, -.21755700E-01, -.21837000E+00, -.11151700E-01, 0.16201800E+01, 0.36740400E+00, 0.92125200E-01, -.30076300E+02, -.90151100E+01, 0.60353800E+01, -.21690300E+02, 0.29539500E+01, 0.17387600E+00, 0.28608100E+01, -.14584200E+01, 0.17509900E+02, -.16723900E+02, -.18636100E+02, -.15905800E+02, 0.55365000E+01, -.20601300E+02, -.12053300E+02, 0.76409500E+01, -.50941100E+01, -.11183200E+02, -.42868800E+01, -.78802700E+01, -.87703700E+00, -.68309400E+01, 0.19641400E+02, 0.30362400E+02, 0.83836100E-01, -.12996900E+02, 0.11799800E+00, -.43917600E+00, 0.68613200E+00, -.63516700E-01, 0.23472900E+00, 0.32056000E+00, -.23180800E+00, 0.13359600E+01, -.34378800E+00, 0.13698800E+00, 0.10073000E+01, -.19914800E+02, 0.74521400E+01, 0.39317100E+01, 0.98215300E+01, 0.80907500E+01, 0.17740200E+02, -.71382600E+00, -.50200500E+01, -.12266600E+02, 0.14422700E+02, 0.29636900E+02, -.12242500E+03, 0.66509600E+02, 0.72419300E+02, 0.61220300E+02, 0.13657400E+02, 0.24432000E+02, 0.16578800E+02, -.25456400E+02, -.90297500E+00, 0.28559100E+02, -.27119500E+02, 0.46407400E+02, -.26929500E+02, -.47347200E+02, -.23219600E+02, 0.98085800E+01, 0.19158000E+02, -.14086300E+02, 0.60653200E+01, -.47484300E+01, 0.22015200E+02, 0.84759700E+02, 0.31485500E+00, 0.27816400E+01, 0.25056300E+00, -.29249500E+00, 0.14599800E+01, 0.61906100E+00, -.25141300E+01, 0.20730500E+01, 0.59270500E+00, 0.11657300E+01, 0.52391800E+00, 0.24786200E+01, -.19099300E+01, 0.23421800E+00, -.16250000E+01, 0.12030300E+01, -.17591900E+00, 0.64062400E+00, -.46546400E+01, 0.49653100E+01, 0.86230500E+01, -.49309000E+00, 0.53669700E+00, 0.84700400E+00, 0.37576900E+01, 0.42638000E+01 },
        { 0.33451300E+00, 0.16396500E+01, 0.25181700E+01, -.23541800E+00, -.23316200E+01, -.51204600E+00, -.26859400E+01, 0.78837900E+00, -.36011100E+00, -.11496300E+01, 0.31968500E+00, 0.28164400E+01, 0.26284500E+00, 0.10306200E+01, 0.54239300E+00, 0.26835800E+00, 0.19234900E+01, -.36732400E+00, -.63677600E+00, 0.41149800E+00, -.39925500E-01, 0.38444200E+01, 0.23502900E+00, -.11539300E+00, 0.51354100E+00, -.45604800E-01, 0.21988500E+00, 0.54519800E+00, 0.83754400E-01, -.70411400E+00, -.10603100E+01, -.52553900E+00, -.59092700E+00, 0.10673900E+01, 0.26818000E-01, 0.28324900E-02, -.52125900E-02, 0.95669500E+00, 0.28371700E+00, 0.60384500E+00, 0.28941600E+00, -.12888600E+01, -.17337200E+01, -.19665700E+00, 0.38239900E+00, 0.80754300E+00, 0.10694200E+01, 0.32058000E-01, -.37511700E+00, 0.11378300E+01, -.53932500E+00, 0.13042200E+01, 0.43735600E+00, -.27272200E+01, 0.30765000E+00, -.48930000E+00, 0.52458600E+00, -.37813000E+00, -.32985100E-02, -.13075900E+01, 0.12302700E+01, 0.40480000E+00, -.13479600E+00, 0.46926300E-01, -.13781300E+00, 0.87138100E-01, -.15158300E-03, -.12016400E+01, 0.19004600E+00, 0.62391200E-03, -.18566600E+00, 0.69223300E+00, 0.23047900E+00, 0.18468100E+00, -.55658700E+00, 0.43487200E+00, -.10110200E+00, -.36992900E+00, 0.67724200E+00, 0.47493800E+00, 0.20297500E-01, -.79528200E-01, 0.69232600E+00, -.24596100E+00, -.36255900E+00, 0.21379600E+00, -.13444000E+01, -.23670600E+01, -.20685000E+00, 0.28055100E+00, 0.52777800E+00, 0.17021700E+00, 0.34278500E+00, -.12570000E+01, 0.66943100E+00, -.30590000E-01, -.10223100E-01, -.50391700E+00, -.56697000E-01, -.37694500E+00, -.96329300E+00, -.89691200E+00, 0.17686100E-01, -.69987600E+00, -.18608300E+00, -.81313700E+00, -.23971800E+00, 0.19236000E+01, -.14428500E+01, -.10368200E+01, 0.11796700E+01, 0.84568600E+00, -.32422600E+00, 0.66121100E-01, -.23735900E+00, -.42622200E+00, -.17055400E-01, 0.39414800E+01, 0.27501300E+00, 0.54289100E-01, 0.30843700E+00, 0.16369500E+01, -.17097700E+00, -.28429400E+00, -.99982300E-01, 0.12093800E+01, -.76269600E+00, 0.24444200E+00, 0.16476400E+00, 0.13366400E+00, 0.57116700E+00, 0.52631900E-01, -.34834100E-01, 0.30928700E+00, -.92774500E+00, 0.62035000E-02, -.10840500E+01, -.40097700E+00, -.11611100E+00, 0.82462600E+00, -.30726100E+00, 0.10044300E+01, -.21921900E+00, -.25477100E+00, -.88327600E+00, -.28889800E+00, 0.37097000E+00, 0.47221400E+00, 0.60893200E+00, -.87357000E+00, -.84750700E-01, 0.77949600E+00, -.46248300E+00, -.11705000E+00, -.33132400E+00, 0.67639000E-01, 0.87464500E-01, 0.16537000E-01, -.11188700E+00, 0.19108100E+00, -.34001100E+00, -.22402700E+00, -.23399400E+00, -.27901600E-01, 0.21837000E+00, -.13782700E+00, -.28337700E-01, 0.20688300E+00, 0.80060500E-02, -.18966500E+00, 0.40269300E+00, 0.56405700E+00, -.29132900E+00, -.33768600E-01, -.12937100E+00, -.23967500E+00, -.21669200E-01, 0.15024100E-01, -.21660900E+01, -.26715200E-03, -.46095600E-01, -.53756600E+00, -.75156800E+00, 0.20562900E-01, 0.13669300E-01, 0.48078200E-01, -.12519700E+01, 0.34539100E+00, -.39916400E-01, -.93326800E-01, -.23717700E-02, 0.14570800E+00, -.12045800E+00, 0.50705900E+00, 0.48116700E+00, -.60643200E+00, 0.70700300E+00, 0.27877800E+00, 0.23807800E+00, 0.10359400E-01, -.52029400E-01, 0.44127100E-01, 0.82561900E+00, 0.13777900E+01, -.48301300E-01, -.27425100E+00, 0.22340800E+02, -.59789200E+01, -.62091200E+01, -.27007600E+02, 0.13531300E+02, 0.51405400E+01, 0.13482100E+02, -.16186000E+02, -.37852400E+02, -.64639400E+01, 0.31349800E+02, 0.47206000E+02, -.29086800E+02, -.46015200E+01, -.33176000E+02, 0.16008900E+02, 0.81094400E+01, 0.17622000E+02, 0.26675400E+02, 0.23275000E+02, -.35032600E+02, -.10836800E+02, -.11051000E+02, 0.21622100E+02, 0.57246700E+01, 0.20716600E+00, -.19629000E-01, -.15914900E+01, -.10099700E+00, 0.28092300E+00, 0.57568900E+00, -.11865700E+01, 0.12787400E+01, -.42407900E+00, 0.37050600E+00, 0.26817500E+01, -.30496600E+02, 0.16594500E+02, 0.19762400E+02, 0.15512600E+02, 0.41675700E+01, 0.14450500E+02, 0.18598800E+02, 0.16518000E+02, 0.33241200E+01, 0.12762400E+02, 0.56121100E+01, -.10369400E+02, 0.54493900E+01, 0.64920100E+02, 0.51777300E+01, 0.95658300E+02, 0.75975400E+01, -.20022400E+02, 0.14221800E+02, 0.26300000E+02, -.26392600E+01, -.84003200E+02, -.66230200E+02, 0.33175400E+02, 0.30338600E+01, 0.33130400E+02, -.11652200E+02, 0.45512100E+02, -.17655000E+02, -.35200500E+02, -.29909300E+02, 0.51672700E+02, 0.15267100E+03, -.32559400E+00, 0.44777100E+01, 0.45349000E-01, -.20006600E+01, 0.12694400E+01, -.13029900E+01, -.42562300E+01, 0.21806600E+01, 0.65793300E-01, 0.16572000E+01, -.29277700E-01, 0.12772600E+01, 0.37068000E+00, -.30352500E+01, -.22389500E+01, 0.14334600E+01, -.12905800E+01, -.99339500E-01, -.48107000E+01, 0.31769300E+01, 0.13913500E+02, 0.65885200E+00, -.14540400E-01, -.14132700E+01, 0.19871800E+01, -.18343700E+01 },
        { -.15251300E+00, 0.67992800E+00, 0.30565200E-02, -.29583100E+00, 0.37900900E+00, 0.94072000E-01, 0.53226200E+00, -.59406400E+00, -.34284500E+00, 0.39986800E+00, 0.15005900E+00, -.48313000E+00, -.10638200E+00, -.41772700E+00, 0.19554200E+00, 0.14054200E-01, -.45805400E+00, 0.26401200E-01, 0.52142000E+00, 0.37598700E+00, -.58133400E+00, -.66992200E+00, -.16404700E+00, 0.65044400E+00, 0.35593300E+00, 0.27682000E+00, 0.89682400E-01, -.69372900E+00, -.19939400E+00, -.73509300E-02, -.16743400E+00, -.94987700E-01, 0.19117500E+00, 0.48606700E-01, 0.47076200E+00, -.22106000E-01, -.50711600E-02, 0.88882800E+00, 0.42619700E+00, -.11436200E+00, 0.10788300E+00, -.76468200E+00, -.89705500E-01, -.27249900E+00, 0.63249500E+00, 0.22218700E+00, 0.84987600E+00, -.80402500E-02, 0.28653100E+00, 0.37797000E-01, 0.97795000E+00, -.26787400E+00, -.25359600E+00, 0.15822900E+01, -.22596200E+00, 0.26428500E+00, 0.90038900E+00, 0.13318500E+00, 0.18926500E+00, 0.14231700E+00, -.50835800E-01, 0.19734400E+00, 0.30126700E-02, -.13240100E+00, -.95241100E-01, -.27881500E-01, -.34768500E+00, -.38069800E+00, 0.72425600E+00, -.84911500E-02, -.13217600E-01, -.18112000E+01, -.14448900E+00, -.13785700E+00, 0.47556100E+00, -.38984200E+00, -.22214400E+00, -.31385900E-01, -.24324800E+00, 0.62418200E-01, 0.17229200E-01, -.13498200E+00, 0.14394500E+00, 0.14618800E+00, 0.61021500E-01, -.37347400E+00, 0.77216900E-01, 0.31701700E+00, -.34849200E+00, 0.70973500E-01, -.93270800E-01, -.64562000E-01, 0.62182300E+00, -.92542300E+00, -.49421100E+00, 0.32045800E-01, 0.27711100E+00, 0.51826200E-01, -.50454800E+00, -.14663100E+00, 0.93281500E+00, 0.36630400E+00, 0.14669800E-02, -.91197200E-01, -.59612100E-01, 0.20941800E-01, -.22458500E+00, -.34801100E+00, 0.43033800E-01, -.14729000E+00, 0.84561600E+00, 0.17616100E+00, 0.91466400E-01, -.20544000E-01, 0.25465600E-01, -.17545700E+00, 0.22782300E+00, 0.51656500E+00, 0.28000800E+00, -.75928400E-01, 0.20925900E+00, 0.90085000E+00, -.24298000E-01, 0.19064500E+00, 0.54260600E-01, -.22426600E+00, 0.26486800E+00, 0.12140900E+00, 0.10647500E-01, 0.10066300E+00, 0.11700100E+00, -.43405500E+00, 0.93034300E-03, -.82967300E-01, -.16776500E+00, -.78538800E-02, -.38584300E+00, -.14160100E+00, -.32571000E-01, -.52535100E+00, 0.54670600E-01, 0.16597700E+01, 0.28825500E+00, 0.72054200E-01, -.33810200E+00, -.49842700E-01, -.82016800E-01, 0.83803700E-01, -.34513500E+00, 0.51584900E-01, 0.30124000E+00, -.18928900E+00, -.45459300E+00, 0.41612800E+00, 0.13973600E+00, 0.11254400E+00, -.36195900E+00, 0.56012600E-01, -.10171900E+00, -.28066100E+00, -.28492600E+00, -.49286100E+00, -.23877700E+00, 0.94315500E-01, 0.87648400E-01, -.44293300E+00, 0.60896200E-02, -.25835300E+00, -.67140200E-01, 0.20208300E+00, -.15401400E+00, -.19398600E+00, 0.56200300E-01, 0.80630800E+00, -.69903100E-02, -.21913500E-01, 0.14460400E-01, -.15709200E-01, -.25632300E+00, -.31991500E-03, -.60118700E-01, -.47511100E-01, -.29087600E+00, 0.41525200E-02, 0.14508400E+00, 0.35608500E-01, 0.17097400E-01, -.47407300E-01, -.11293700E-01, 0.19198000E-01, -.24590700E-03, -.60715200E-01, 0.26569700E-01, 0.19062700E+00, -.33224700E+00, -.12950300E+00, 0.60576400E+00, 0.13723800E+00, 0.13353300E+00, 0.46948400E-01, -.22234800E+00, 0.39072400E-01, 0.12742900E+01, 0.15223700E+01, 0.17903100E-01, 0.66871800E-01, 0.24863300E+00, 0.62380700E+01, 0.64126200E+01, 0.15694400E+02, -.77776600E+01, -.20656500E+01, -.78544700E+01, -.10502900E+02, -.14201300E+02, 0.15101100E+02, 0.47984900E+01, -.48074700E+01, -.12794000E+02, -.11121500E+02, -.15945500E+02, 0.83992200E+01, -.78840600E+01, 0.81529500E+01, 0.88202500E+01, 0.71688300E+01, -.15697600E+02, -.14489600E+02, 0.16494400E+01, 0.87329800E+01, -.80253500E+01, 0.30515200E+00, -.10297600E+00, -.38218500E+00, -.15213500E+00, 0.62450500E-01, 0.29892100E+00, -.11331600E+00, 0.47453600E+00, -.19640500E+00, 0.20414000E+00, 0.12419500E+01, 0.58317700E+02, -.29201200E+02, -.26279300E+02, -.28998600E+02, -.39055600E+01, -.55596900E+01, -.10328400E+02, 0.51654300E+01, -.93263100E+01, -.33691400E+01, -.20265600E+02, -.31044200E+02, 0.14356600E+02, 0.20191800E+02, 0.15520100E+02, 0.15581700E+02, -.61776900E+01, 0.88262800E+01, -.13556700E+02, 0.10710700E+02, 0.44620000E+00, 0.49574000E+01, -.16147900E+02, 0.87048200E+01, 0.55346000E+00, 0.80786300E+01, -.23639000E+01, 0.10968900E+02, -.11694100E+02, -.12110100E+01, -.72336700E+00, 0.63092100E+01, 0.36119700E+02, -.17166900E+00, -.20235000E+00, 0.11411800E+00, -.20650200E+00, 0.18381800E+00, -.48251500E+00, -.10512700E+01, -.62725300E+00, 0.47641300E-01, 0.74692600E+00, 0.39848100E+00, 0.75941900E+00, 0.48048800E+00, -.10331800E+01, -.10598200E+01, 0.47487600E+00, -.25924500E+00, -.12050700E+00, -.13086200E+01, 0.15612100E+01, 0.52765100E+00, -.70215800E+00, 0.15702000E-01, 0.11281500E+01, -.16858300E+01, -.11187900E+01 },
        { 0.16586500E+01, -.38512400E+01, 0.17051800E+02, 0.24865300E+01, -.74446500E+01, -.17355400E+00, -.40896100E+01, 0.22541200E+01, 0.26143900E+01, 0.66365400E+00, -.74560600E+00, 0.38687400E+01, -.27293900E+01, -.17357300E+01, 0.23791000E+01, 0.17926400E+01, 0.62718000E+01, -.10981000E+01, -.23535900E+01, 0.97687200E-02, 0.90581300E+00, -.46324100E+01, -.89933500E+00, 0.17550100E+01, 0.13142200E+01, 0.10655600E+01, 0.19174400E+01, -.10895200E+01, -.48540600E+00, -.19598600E+01, 0.70160800E+00, 0.63268300E-01, 0.53977500E+01, -.13759000E+01, -.10429700E+01, -.44792700E+00, 0.27486400E+00, -.68371900E+00, -.12075300E+01, -.14107500E+01, -.13493300E+01, -.16423700E+01, 0.85936200E+01, 0.77721000E+00, -.48997600E+00, -.48883400E+00, 0.10410400E+00, 0.38785000E+00, 0.26015000E+00, -.52439100E+00, -.16978400E+01, 0.27258500E+01, 0.18389100E+01, -.68837200E+01, 0.10407900E+00, -.45666500E+01, -.13203100E+00, 0.35547100E-01, -.38347300E+00, -.32195800E+01, 0.94852900E+00, 0.13407200E+01, 0.67191800E+00, -.20071400E+00, -.36996400E+00, -.14090800E+01, -.43249700E+00, -.15707500E+01, 0.11088700E+01, -.38948400E-02, 0.14200500E+01, 0.16430400E+01, -.28420300E+00, 0.13995800E+00, -.64326700E+00, -.28548000E+00, -.79508100E+00, -.12230100E+00, 0.38966800E+00, 0.15334200E+01, 0.85893200E-01, -.79144100E-01, -.73357300E+00, -.37811600E+00, -.33144400E+00, 0.20272000E+00, -.23513600E+01, -.15117300E+01, -.24559500E+01, 0.57261800E+00, -.18229700E+01, 0.63090500E+00, -.47571200E-01, -.24935400E+01, -.10955500E+01, -.33653100E-01, -.49331200E+00, 0.95790000E-01, -.25417600E+01, -.12287900E+01, 0.46857700E+01, 0.49331700E+00, -.94018000E-01, 0.63581700E+00, -.75831400E+00, 0.33510200E+01, 0.96323200E-01, 0.34829900E+00, -.59086800E+01, 0.20359200E+01, 0.18761700E+01, 0.76168200E+00, -.62493100E+00, -.15531600E+00, -.61152900E+00, 0.42002700E+00, 0.15063800E+01, 0.88858000E+01, 0.15357100E+01, 0.12199600E+01, -.84834900E+00, 0.75799200E+00, -.74701100E+00, 0.16169100E+00, 0.22080900E+00, 0.27675300E+01, 0.74171800E+00, -.13440800E+01, 0.19654900E+00, -.29995900E+00, 0.84931100E+00, 0.12026400E+01, -.20327700E+00, 0.40359500E+00, 0.10999000E+01, 0.20061400E-01, -.70172300E+00, 0.62556600E+00, -.55122800E+00, 0.14967300E+00, 0.61922100E+00, -.43591700E+01, -.95989300E+00, 0.10379800E+01, 0.31973300E+00, -.58622400E+00, 0.40794200E+00, 0.50048600E+00, -.26097100E-01, -.82730400E+00, -.10685400E+01, 0.47934100E+00, 0.39904700E+00, -.38865700E+00, 0.12657900E+01, -.42701600E+00, 0.14690800E+01, 0.14111800E+00, -.16860500E+00, -.10402100E+01, -.43189000E+00, 0.12381600E+01, 0.50960000E-01, 0.29570300E+00, -.58073600E+00, -.12507700E+00, 0.58042100E-01, -.54823500E+00, -.12507300E+00, 0.62496600E+00, -.95656000E+00, -.19526400E+01, 0.50759800E+00, 0.35669900E+00, 0.18749800E+00, -.26752000E+01, -.15362400E+00, 0.81314600E-02, 0.13117800E+01, -.71589500E-02, -.51254100E+00, 0.82463600E+00, -.17171800E+01, 0.66262700E+00, 0.14899200E+01, -.20118300E+00, 0.34167900E+01, -.37773100E+00, -.37989100E+00, -.46601400E+00, -.23949600E-02, -.20071200E+01, 0.92913400E+00, 0.50717700E+00, -.37668200E+01, -.11540300E+01, -.46339700E+01, -.32309000E+00, 0.18836500E+01, 0.17250300E+00, 0.82392000E-01, 0.66614600E+00, -.19718800E+01, 0.28042600E+02, -.95071400E-01, -.15250500E+01, 0.50665100E+00, -.33649300E+00, 0.25343200E+03, 0.29430000E+02, -.13564000E+02, -.88441900E+01, -.14780900E+02, 0.77393500E+02, 0.64008300E+02, -.21975000E+02, -.33149900E+02, -.32723400E+02, 0.60770800E+02, -.28798400E+02, -.23740200E+03, 0.11783700E+03, -.57942000E+02, 0.12017300E+03, 0.12832600E+03, 0.12015300E+03, -.47637200E+01, -.18627600E+03, -.65366400E+02, 0.13092000E+03, 0.11835200E+03, 0.35807800E+01, -.16368900E+01, -.47690100E+01, -.17769500E+01, 0.11186300E-01, 0.23804300E+01, -.26564300E+01, -.26881100E-01, -.34128500E+01, 0.22487700E+01, 0.11336100E+00, 0.28425300E+03, -.13279800E+03, -.11370800E+03, -.14139000E+03, -.25373400E+02, -.65370800E+02, -.16506000E+02, 0.69092400E+02, -.14182100E+02, -.56389400E+02, -.12794000E+03, -.28543300E+03, 0.14699000E+03, 0.24067900E+03, 0.14269100E+03, 0.33873400E+02, -.11877900E+03, 0.92897900E+02, -.10565500E+03, 0.17773900E+03, -.75007900E+02, 0.91320300E+02, -.34018000E+03, 0.16832200E+03, 0.97728000E+02, 0.17014300E+03, 0.61797400E+02, 0.11998700E+03, -.68269600E+02, -.19464600E+02, 0.38509100E+01, 0.43867200E+02, 0.27782100E+03, -.32129500E+01, 0.23681300E+02, 0.89387500E+00, -.34304900E+01, -.18912200E+02, -.60350500E+01, -.77767000E+01, 0.17733400E+02, -.86599600E+00, 0.35766600E+01, -.42064500E+01, 0.13974900E+01, 0.55563600E+01, 0.41227600E+01, 0.19011700E+02, 0.92957500E+00, -.62772000E+00, 0.30973800E+01, -.49161900E+01, -.35485900E+01, -.12312200E+02, -.81388700E+01, -.54484100E+00, 0.50604900E+01, -.18923300E+02, -.25845400E+02 },
        { 0.80603600E-01, 0.31277200E+00, -.20219100E+00, 0.20005100E+00, -.31296500E+00, 0.12427800E-01, -.22653700E+00, 0.39820100E+00, 0.14289900E+00, -.50624400E-01, -.31953400E-01, 0.13879400E+00, 0.17708200E-01, 0.11440300E+00, -.14662800E+00, 0.20553100E+00, 0.22307200E+00, -.24936000E-01, -.38123100E+00, 0.48061000E-01, -.54063900E-01, 0.87735400E-01, 0.83666100E-01, -.11782800E+00, -.19835400E+00, -.16016500E+00, 0.26964100E-01, 0.13524200E+00, -.13312900E-02, -.85148100E-01, 0.21514600E-01, -.58403100E-01, -.59529500E-01, 0.82302800E-01, -.21780100E-01, -.75612400E-01, 0.82413300E-02, -.63865600E-01, 0.39954100E-01, -.50432800E-01, 0.65678900E-02, -.17449500E+00, -.22121500E-01, 0.80324200E-01, -.13507400E+00, 0.10609200E-01, 0.54936700E-01, 0.37987300E-02, -.17578400E-01, 0.14875000E+00, -.33299600E-01, 0.46008300E-01, 0.85544000E-01, -.34642900E+00, -.68333400E-01, -.29467200E-01, -.46756700E-01, 0.13748200E+00, -.31706900E-01, -.68178500E-01, -.92076000E-01, 0.41877200E-02, -.29620100E-01, 0.10319600E+00, 0.13756600E-01, 0.72161300E-01, 0.66065900E-02, -.44956300E-01, -.16969900E-01, -.13883900E-02, 0.12762700E+00, 0.11526400E-01, -.15605700E-01, 0.10673900E-01, 0.38152700E-01, -.75018900E-01, 0.10113200E-01, 0.23602700E-01, -.17620000E-01, 0.39552500E-02, -.58695000E-03, 0.20496000E-01, -.12258800E+00, -.37372300E-02, 0.17678100E-02, -.44297700E-01, 0.11747000E+00, 0.66005900E-01, 0.17745600E+00, -.59639300E-01, 0.17015700E-02, -.23916900E-01, -.41743100E-01, 0.46553500E-02, 0.51107700E-01, 0.71573500E-01, 0.29983800E-02, -.31727100E-01, 0.52221200E-01, 0.57649000E-01, -.47639500E+00, -.41599100E-01, 0.11721000E-01, 0.88487900E-01, 0.91261100E-01, -.19041300E+00, -.11497600E+00, -.18589900E-01, 0.14028300E+00, 0.72819700E-01, 0.16107000E+00, -.13566800E+00, 0.18269600E-01, 0.11374200E-01, 0.31718800E-01, 0.10723400E+00, 0.13269100E-01, 0.30126900E+00, 0.27127700E-01, 0.21073900E-01, -.12513400E-02, 0.26738200E+00, 0.12440700E-01, 0.11367600E+00, -.27390700E-01, 0.10021300E+00, 0.54766500E-01, 0.18059400E-01, 0.19254000E-02, -.76399500E-01, 0.44723600E-01, 0.71345000E-01, -.20992600E-02, -.31925600E-03, 0.33384200E-01, 0.26124500E-02, -.55386800E-01, 0.31673400E-01, -.16023500E-01, 0.14670900E+00, 0.17865800E-01, -.14986000E+00, -.82711000E-01, 0.43922800E-01, -.49224000E-01, -.37791000E-01, 0.16277800E-01, -.88845900E-01, -.58235800E-01, -.54488900E-01, -.11203000E+00, 0.89461500E-01, -.36913100E-01, -.12245400E+00, 0.14045900E+00, -.50070100E-01, 0.12446800E+00, 0.10199500E-01, 0.47630400E-01, -.68867500E-01, 0.72913100E-01, -.30875900E-01, 0.24599000E-01, 0.14679000E-01, -.77398400E-01, 0.88849700E-02, 0.17747600E-01, 0.66412900E-01, -.27530600E-02, 0.96068200E-02, 0.12758700E+00, -.62345600E-01, -.14651900E-01, 0.23828000E+00, -.11825800E-01, 0.97961700E-01, 0.16289800E-01, -.15488000E-01, -.10089000E+01, 0.17816500E-03, -.15697000E-01, -.22265100E+00, -.46782200E+00, -.19136500E-01, -.22643300E-01, -.14424200E+00, 0.37723400E+00, 0.84509400E-01, 0.73787000E-02, -.38098800E-01, 0.29996600E-04, 0.10933300E+00, 0.95698700E-02, -.15506800E+00, 0.63938100E+00, 0.37054500E+00, 0.45102100E+00, 0.59978000E-02, 0.71826200E-01, 0.19567700E-01, 0.26922300E+00, -.34819700E-01, 0.17671800E+01, -.16622800E+01, -.28207300E-01, -.12706500E+00, 0.25562500E+00, 0.27547100E+00, -.89945100E-02, 0.26886000E+02, -.13707700E+02, -.84416900E+01, -.13432100E+02, -.52510600E+01, 0.29610300E+02, -.69977500E+01, -.68740700E+01, -.12728100E+02, 0.21636700E+02, -.11251900E+02, -.39792600E+00, 0.41296800E+00, -.18114200E+01, -.20672300E+00, 0.24365800E+00, -.21731700E+01, 0.51820100E+01, -.92601600E+00, 0.36032800E+01, -.33968500E+01, -.59852800E+01, 0.41829000E+00, -.14770100E+00, 0.41806300E+00, -.21025800E+00, 0.10466000E+00, 0.20547900E+00, -.26520200E+00, 0.35391100E+00, -.35697000E+00, 0.15885400E+00, 0.11366200E+00, 0.13794800E+02, -.56302200E+01, -.11141500E+02, -.70506800E+01, 0.25505500E+01, 0.57688100E+01, -.47455300E+01, 0.20507900E+01, -.36349600E+01, 0.34577300E+01, -.77493600E+01, -.81535800E+02, 0.39086700E+02, 0.55668400E+02, 0.40771300E+02, 0.14341900E+02, 0.36725700E+02, 0.13370400E+02, -.31615700E+02, 0.54416900E+01, 0.35445100E+02, 0.26001900E+02, 0.85140300E+02, -.41581600E+02, -.34237900E+02, -.42577600E+02, -.15692600E+02, -.19658600E+02, -.23161300E+02, 0.32535700E+02, -.51287100E+01, -.19581300E+02, -.27053000E+02, -.30514800E+00, -.17372000E+01, -.77711800E+00, 0.20677800E+00, 0.14152500E+00, -.61776100E+00, -.66131900E+00, -.10993400E+01, 0.27320500E+00, 0.44436400E-01, -.55342000E+00, 0.44251000E+00, -.12040000E+01, 0.43903700E-01, -.51201100E-01, 0.70974800E-01, 0.44921600E+00, 0.22105800E-01, 0.55990600E+00, 0.22876800E+00, -.32703400E+01, 0.54430200E-01, 0.14420800E+00, -.50134500E+00, 0.12804900E+01, 0.31215400E+01 },
        { 0.89668400E+00, 0.66416200E+01, -.13461600E+01, 0.63634000E+00, -.12871600E+01, -.15609500E+01, -.15334500E+01, 0.11291300E+00, -.23418900E+00, -.75082100E+00, -.15271600E+00, 0.23699500E+00, 0.28972500E+00, 0.21444600E+00, -.15480900E+01, -.15932900E+00, 0.10331000E+00, -.26689500E+00, -.34930600E+01, 0.14930700E+01, -.13267800E+01, 0.36820700E+01, 0.36935900E+00, 0.31498900E+01, 0.52761200E+00, -.33238900E+00, 0.14833000E+01, -.79761000E+00, 0.22972500E+00, -.75323200E+00, -.43557900E+00, -.10990200E+01, 0.33692500E+00, 0.10202300E+01, 0.77894100E+00, 0.53221500E+00, 0.74762500E-01, 0.24007600E+01, 0.14077600E+01, -.43434000E+00, -.95131300E+00, -.14299600E+01, -.23917200E+01, -.46838900E+00, 0.21052900E+01, 0.74329600E+00, 0.18273400E+01, 0.11279500E+00, 0.50691000E+00, 0.74299600E+00, 0.22233300E+01, -.63925600E+00, -.24728500E+00, -.28146400E+01, -.93050300E+00, 0.35203600E+00, 0.20369400E+01, -.63083000E+00, 0.38187900E-01, -.81185000E+00, 0.49019900E+00, 0.19676700E+00, -.28060200E+00, 0.49618300E+00, 0.30663800E+00, -.45972100E-01, -.80130100E+00, -.21160600E+01, 0.21453600E+01, 0.47685100E-02, -.20366200E+01, -.52532600E+00, -.49753500E-01, 0.89921600E-01, -.29500900E+00, 0.63629100E+00, 0.17946200E+00, -.99896500E+00, 0.86106200E+00, 0.22583700E+00, 0.13510800E-03, -.80330900E-01, 0.92260400E-01, -.49108000E+00, -.29465200E+00, -.33436300E+00, -.16615900E+00, -.17666600E+01, 0.24795200E+00, -.28081500E+00, 0.25904100E+01, -.17732300E+00, -.32713000E+00, 0.48302200E+01, 0.21475600E+01, 0.19394500E+01, 0.26835300E+00, -.23656500E+00, 0.15887900E+01, 0.94991200E+00, -.76518300E+01, -.86499300E+00, 0.94965700E-01, -.49126900E-02, 0.41729500E+00, -.23097700E+01, -.99029300E+00, 0.16023100E+01, -.72397800E+00, 0.41782700E+00, 0.90990500E+00, -.40193400E+00, -.51334200E-01, 0.21675600E-01, -.26586700E+00, 0.59650600E+00, 0.25470800E-01, 0.33219000E+01, 0.22514600E+00, 0.26852600E-01, -.22581700E+00, -.13637100E+00, 0.32461100E+00, 0.52301900E+00, -.29515500E+00, -.12204100E+01, -.18045200E+01, -.38337300E+00, -.27614000E+00, 0.36713500E+00, 0.10770900E+01, 0.16627100E+00, 0.42608600E-01, -.84194300E-01, -.11872500E+01, -.59383800E-03, -.12747800E+01, -.17076900E+00, 0.26270200E+00, 0.25234000E-01, -.21525500E+00, 0.15431000E+01, -.77068300E-01, -.40167900E+00, -.15704600E+01, -.29721600E+00, 0.85008500E-01, -.38351200E+00, 0.58311700E+00, -.77341200E+00, -.48336300E+00, 0.69408100E+00, -.63182300E+00, 0.17525900E+01, -.92555400E+00, 0.10212800E+00, -.98690400E+00, 0.12800800E+00, -.32199900E+00, 0.12178900E-01, -.32516400E+00, 0.16058500E+01, -.23817300E+00, 0.18111900E-01, 0.16823700E+00, -.35508100E-01, -.18811800E-02, 0.35338700E+00, -.25769500E-01, 0.91199700E-01, 0.69277300E+00, 0.51539000E+00, -.58106500E+00, 0.50614700E+00, -.13607200E+00, 0.38304300E+00, 0.21975900E+00, 0.50282200E-01, -.63256300E+01, -.21738100E-02, 0.44206500E+00, -.80965400E+00, 0.10300800E-01, -.30080500E+00, -.71160600E+00, -.69032300E+00, -.20543100E+01, 0.52680800E+00, 0.14318800E+00, -.20352300E+00, -.19031900E-02, -.38246800E-01, -.12942300E+00, 0.55115200E+00, 0.39945100E-02, -.52047500E+00, 0.21675000E+00, -.20309800E+00, 0.25172800E-01, -.16440100E+00, 0.76649500E+00, -.62570500E-01, 0.35757300E+01, -.63683200E+01, 0.59693000E-01, -.45354000E+00, 0.93648100E+00, -.69533200E+00, 0.15489600E-01, 0.93663000E+00, 0.93455300E+01, -.23600900E+01, 0.69888600E-02, 0.19100900E+02, 0.47108400E+02, -.52386100E+02, -.22478800E+02, -.10843400E+02, 0.29266500E+02, 0.87562300E+01, -.48060500E+02, 0.23200600E+02, 0.39270600E+01, 0.23900000E+02, 0.28635900E+02, 0.71824900E+01, -.14620400E+02, -.13102100E+02, 0.20802900E+01, 0.58090700E+00, 0.28638800E+02, 0.36740800E+00, -.38636200E+00, -.38340200E+00, -.18516400E+00, 0.30739400E+00, 0.34174300E+00, -.29472900E+00, 0.37472000E+00, -.42829700E+00, 0.15900400E+00, -.66349100E+00, 0.11693800E+03, -.55789300E+02, -.62524800E+02, -.58454100E+02, 0.39056200E+01, 0.37797700E+01, -.28829000E+02, 0.97688800E+01, -.27317800E+02, 0.74706300E+00, -.30689500E+02, -.17766500E+03, 0.90856600E+02, 0.14880300E+03, 0.88835100E+02, 0.28960400E+02, 0.23559200E+02, 0.27719900E+02, -.56700700E+02, 0.33618100E+02, 0.24889500E+02, 0.43504200E+02, 0.11517900E+03, -.58664500E+02, -.74160600E+02, -.57595100E+02, -.17661900E+02, -.29466500E+02, -.83548300E+01, 0.45603900E+02, -.34158100E+01, -.35706800E+02, -.12099600E+02, -.53818300E+00, 0.16072600E+01, -.75690600E+00, 0.39207100E+00, -.21387200E+01, -.10186100E+00, -.10996000E+01, 0.28840800E+01, 0.22779300E+00, -.39044500E+00, -.85655100E+00, -.31444500E+00, -.31686500E+00, 0.75643700E-01, 0.29957000E+01, 0.80596800E-01, -.99804500E-02, 0.34229400E+00, 0.69274900E+00, 0.55541000E+00, -.13166700E+01, 0.15912700E+01, 0.66493200E-01, 0.32026400E+01, 0.39760300E+01, 0.29450800E+01 },
        { 0.11397100E+00, 0.61881500E+00, -.14421900E+00, 0.21687000E+00, -.63622200E+00, 0.24272100E-01, -.38858100E+00, 0.13207800E+01, -.30926100E-02, -.46738200E+00, 0.14711600E+00, 0.10895100E+01, 0.11903900E+00, 0.59359000E+00, 0.90099000E+00, 0.82902000E-01, 0.58294900E+00, -.12162000E+00, -.76935600E+00, 0.41740400E+00, -.29213200E+00, 0.36107400E+00, 0.58317700E-01, -.17788500E+00, 0.27291900E-02, -.92338100E-01, 0.13272600E+00, 0.20283800E+00, 0.14932600E-01, -.96537900E-01, 0.36513500E-02, -.20775000E-01, -.71916800E-01, -.78604900E-01, 0.83029500E-01, 0.17631300E+00, 0.35616800E-02, 0.33328100E+00, 0.14375900E+00, 0.51029400E-01, -.26481100E+00, -.10608900E+01, -.11202500E+01, -.14799600E+00, -.26414000E-01, 0.25113600E+00, 0.11550400E+01, 0.30416800E-01, 0.10442000E+00, 0.37254900E+00, 0.35389700E+00, 0.15724000E+00, -.39809100E+00, 0.52966000E+00, -.34332900E+00, 0.28391000E+00, -.16788700E+00, 0.24277900E+00, 0.15825500E-01, 0.30696600E+00, -.23551400E+00, -.73452000E-01, -.16279700E+00, 0.35766800E+00, -.11825700E-01, 0.82790700E-01, -.16679700E+00, 0.95575700E-01, 0.12864600E+00, 0.32769200E-02, -.12088600E+00, -.56460500E-01, -.28946000E-01, 0.50634000E-02, 0.88421800E-01, -.16116700E+00, 0.79887100E-01, 0.14872300E+00, -.13341200E+00, -.11298800E+00, -.95283700E-02, -.12666400E-01, 0.17415600E+00, 0.11550800E+00, 0.52531800E-01, -.56058500E-02, -.10712400E+00, -.78053200E-01, -.54171000E+00, -.14517500E-01, 0.49562400E+00, -.59134900E-01, -.21013400E+00, 0.71282100E+00, -.17275000E-01, 0.15909300E+00, -.52864300E-01, 0.19390100E+00, 0.39431100E+00, 0.83704000E-01, 0.23120500E-01, 0.23373700E-01, -.85046400E-02, 0.34565200E+00, 0.10599800E+00, 0.32413800E-01, -.18272300E-01, 0.26107100E+00, -.18116000E+00, -.32310700E+00, 0.27279100E-01, -.89747700E-01, -.41917000E-02, 0.41422400E-02, 0.10578600E-01, 0.54303800E-01, 0.44432500E-02, -.23966400E+00, -.10380800E+00, -.99366600E-01, 0.59588100E-01, -.12493600E-01, -.11833900E-02, 0.10148400E+00, 0.11359700E-01, -.30204200E+00, -.24563700E+00, 0.48999800E+00, 0.48135000E-01, -.88993200E-02, 0.17883300E+00, 0.17860300E-01, 0.10390700E-01, -.40306900E-01, -.18177100E+00, -.31413300E-03, 0.20240500E+00, 0.84391100E-02, 0.14900500E+00, -.18131100E+00, -.89165800E-01, 0.96261400E-01, 0.15786800E+00, -.45554400E+00, -.49680600E+00, -.20442100E-01, -.84223800E-01, 0.30216700E-01, -.19457400E+00, 0.17064700E+00, 0.24244800E+00, -.25176800E+00, 0.39280200E+00, 0.37038700E+00, -.23737600E+00, 0.96791600E-02, -.13480300E+00, 0.19925200E-01, -.13099000E+00, 0.13630600E+00, -.23387800E+00, -.41322400E+00, -.55093600E-01, -.49581000E-01, 0.23034200E+00, 0.10815700E+00, 0.67977000E-01, 0.38563600E-01, -.79445400E-02, 0.67588800E-01, 0.77406700E-01, 0.22719200E+00, -.12105100E+00, -.40851000E+00, -.87522700E-01, 0.68177900E-01, -.28744800E-01, -.35080000E-01, -.21786500E+00, -.10366500E-05, 0.57962700E-01, -.76162200E-02, 0.39718200E+00, -.94454600E-01, 0.12743100E-01, -.12180000E-01, -.34812000E+00, -.44991800E-01, -.16101100E-01, -.15620100E+00, -.44819500E-03, -.22832000E+00, 0.76825500E-02, 0.17872200E+00, 0.75428100E+00, 0.32815700E-01, -.10785800E+00, 0.18360100E-01, -.81266400E-01, 0.50038000E-01, 0.11750800E+00, 0.17809900E-01, -.13822500E+01, -.38552100E+01, 0.12564800E+00, 0.44940100E-01, -.22056700E+00, -.75436800E+00, 0.37445300E-01, -.67215100E+00, -.10786700E+00, 0.75950100E+01, -.63227300E-02, -.30531500E+02, -.20735000E+02, 0.30162000E+00, -.31966500E+01, -.53353800E+01, -.14237800E+02, 0.21526600E+00, 0.70285000E+01, -.24212000E+01, 0.30923900E+00, -.31525800E+01, -.66510000E+01, -.11633400E+02, 0.15970700E+01, 0.35058900E+02, 0.21656400E+02, -.14314700E+02, 0.15411800E+01, -.21451100E+00, 0.38013800E+00, 0.19938000E+00, 0.10672400E+00, 0.27136000E-01, -.19874400E+00, 0.16522400E+00, -.37816800E+00, 0.17741300E+00, -.14713700E+00, -.48150400E+00, 0.17103500E+02, -.54773400E+01, 0.70063300E+01, -.83717100E+01, 0.20972900E+01, 0.53288500E+01, -.11670700E+02, -.64528800E+01, -.18798800E+02, 0.55229800E+01, -.20918800E+00, 0.30871100E+02, -.19332100E+02, -.30067500E+02, -.15436600E+02, -.16292700E+02, -.53302000E+01, -.14328200E+02, 0.82319400E+01, -.13344200E+02, -.43947100E+01, 0.78529400E+01, -.37843400E+02, 0.21565400E+02, 0.13094600E+02, 0.18924600E+02, 0.20501800E+02, 0.47610000E+01, 0.14233500E+02, -.48325300E+01, 0.53454500E+01, 0.61351800E+01, 0.22212500E+01, 0.27303800E+00, 0.38443500E+00, 0.23427700E+01, -.21949600E+00, 0.13015500E+00, 0.13470700E+01, 0.91745600E+00, 0.41280700E+00, 0.71995400E-01, -.42366700E+00, 0.11697600E+01, 0.16652200E+00, -.37478700E+00, -.36138300E+00, 0.22263700E+00, -.38661800E-01, -.18614900E+01, 0.25792800E+00, -.60311900E+00, -.64479900E+00, 0.79708700E+00, 0.12917700E+01, -.93636000E-02, 0.15788300E+01, -.17689800E-01, -.80140100E+00 },
        { 0.88361700E+00, -.98010000E+00, 0.81217700E+01, -.46735300E+00, -.57542400E+01, -.85219200E+00, -.86138800E+01, -.27283900E+01, -.61282800E+00, -.10167900E+01, 0.82239900E-01, 0.59938900E+01, -.67074000E+00, 0.12469300E+01, 0.11666000E+01, 0.78595800E+00, 0.54612200E+01, -.10931600E+01, -.18196100E+01, 0.83741200E+00, -.63211300E+00, 0.61397200E+01, -.11135400E+00, -.81328000E+00, 0.10074400E+01, -.41762400E+00, 0.64943300E+00, -.82752400E+00, 0.35877500E+00, -.34651500E+00, -.16502100E+01, -.79915200E+00, 0.42960400E+00, 0.65557000E+00, 0.62414200E+00, 0.58226800E+00, 0.25412500E-01, 0.18338000E+01, -.40648300E-02, 0.28832900E+00, -.40104000E+00, 0.26388100E+01, 0.20781900E+01, 0.80252900E+00, -.69709200E+00, 0.46171400E+00, 0.12710600E+01, 0.10957300E+00, 0.28490700E+00, 0.10724200E+01, 0.42253400E+00, -.12779000E+01, 0.11607900E+00, -.62730800E+01, -.10599600E+01, -.19069500E+00, 0.16258600E+01, 0.87091100E+00, -.21211100E+00, -.42123000E+00, -.72852100E+00, -.17089700E+00, 0.91254600E-01, 0.66273200E+00, 0.46632700E+00, 0.10053800E+01, 0.13622600E+00, -.14246600E+01, 0.54367500E+00, 0.22103800E-01, -.14152100E+01, -.57647100E+00, 0.13127400E+00, 0.92686500E-01, 0.22861500E+00, -.15691100E+00, -.30048400E+00, 0.14328100E+00, 0.43043600E+00, 0.55889500E+00, 0.28651000E-01, -.53231300E-01, 0.18679000E+00, 0.18899100E-01, -.33189900E+00, -.38858800E-01, -.20186500E+00, -.28329900E+01, -.86436000E+00, 0.17237800E+00, 0.17335500E+01, 0.27220800E+00, 0.63557700E+00, -.19628900E+01, 0.19437300E+00, -.17598800E+00, -.33413000E+00, 0.65578500E+00, 0.92285000E-01, -.52018300E+00, 0.98695400E+00, -.17540800E+01, -.41224400E-01, 0.74815500E+00, 0.62993800E+00, -.27015900E+00, -.59884100E+00, 0.22240800E+01, -.11793000E+01, -.11304900E+01, -.21240700E+00, 0.77827000E+00, -.60237300E+00, 0.50904800E-01, -.38114300E+00, 0.16221200E+00, -.54917500E-01, 0.39122600E+01, -.20095700E+00, -.43979000E-01, 0.29614400E+00, 0.12228200E+01, -.73559700E-01, 0.14708900E+00, -.18242600E+00, 0.36797800E+00, -.15503700E+01, 0.10808400E+00, 0.47531100E-01, -.18934600E+00, 0.34465700E+00, 0.13768500E+01, -.19695200E+00, 0.93275800E-01, -.89644400E+00, -.28119300E-02, -.38170300E-01, -.49003100E-03, 0.11470700E-01, 0.78167300E+00, -.27750300E+00, 0.66664300E-01, -.14500700E+00, 0.63644800E+00, 0.24284000E+00, -.14482600E+00, 0.23581400E+00, -.13097900E+00, 0.64224900E+00, -.74769300E+00, -.76369900E+00, 0.66035400E+00, 0.65246500E+00, 0.92662900E+00, -.39943900E+00, -.24537600E+00, 0.19025700E+00, 0.15028900E-01, -.19694400E+00, 0.26874200E+00, -.44191200E+00, 0.71066100E+00, -.11846900E+00, -.50609100E-01, 0.29098300E+00, 0.21169700E+00, 0.10036900E+00, 0.52385500E+00, 0.15772400E-01, -.47685200E+00, 0.35682200E+00, 0.75574900E+00, -.27897600E+00, -.40929500E+00, -.59711000E-01, 0.91985400E+00, 0.16144500E+00, -.92442100E-01, -.55920700E+01, 0.36052400E-02, 0.47913800E+00, -.40600400E+00, 0.78270300E+00, -.26265200E+00, -.93327200E+00, -.10271400E+00, -.30306800E+01, 0.58338100E+00, -.67277600E-01, -.88656500E-04, -.23227900E-02, 0.63129000E-01, -.26637900E+00, 0.10788700E+01, 0.53043900E+00, -.36968100E+00, 0.23874000E+01, 0.11634600E+01, -.82616100E+00, -.77056000E-01, 0.66117400E+00, -.50950900E-01, 0.37952000E+01, -.97292800E+01, -.80126600E-02, 0.46992600E+00, 0.10894100E+01, -.92778900E+00, -.61157200E-01, 0.20192700E+01, -.29923900E-01, 0.28561700E+00, 0.34551400E+01, -.39260700E+02, -.29587700E+02, -.35873000E+01, -.14501800E+02, -.16028200E+02, -.25736400E+02, 0.82427100E+01, -.23218600E+01, 0.18064500E+01, 0.75684600E+01, 0.42386800E+01, -.81160800E+00, -.37771000E+01, -.32501100E+02, -.27927000E+01, -.18813100E+02, -.91441100E+01, 0.13624100E+02, 0.14047800E+00, -.98104400E-01, -.47429700E+00, -.63769000E-01, 0.35138600E-01, 0.26037600E+00, 0.10257500E+00, 0.77372200E+00, 0.25796400E+00, 0.35558300E+00, 0.24056100E+00, 0.13468900E+03, -.68947900E+02, -.59456600E+02, -.66873000E+02, -.81240400E+01, -.25731000E+02, -.22509800E+02, 0.27334100E+02, -.10993400E+02, -.19820100E+02, -.40787200E+02, 0.33207100E+02, -.16345400E+02, -.35833800E+02, -.16613200E+02, 0.30865000E+02, -.96834700E+01, 0.12048100E+02, 0.34789000E+02, -.14621400E+02, -.23601800E+02, -.46671000E+02, 0.70109500E+02, -.35466000E+02, -.50961600E+02, -.35034400E+02, -.24480100E+02, -.11884200E+02, -.23015200E+02, 0.12491000E+02, -.20064300E+01, -.10734400E+01, 0.28631100E+02, 0.59963600E+00, -.15334900E+01, 0.72549800E+00, -.19740000E+01, 0.34439600E+00, 0.41531900E+00, 0.25775400E-01, -.39034400E+00, 0.14783900E+00, -.75479100E+00, 0.91090400E+00, 0.22522000E+00, 0.28420000E+01, -.17573900E+01, 0.50634600E+00, 0.99969300E+00, -.24202600E+01, -.59304400E+00, 0.15847400E+01, 0.89452400E+00, -.27321500E+01, 0.26149000E+01, 0.46886300E-01, 0.49191000E+01, 0.52036800E+01, 0.45737800E+01 },
        { 0.45456400E-01, -.15928400E+00, 0.43684000E-01, 0.51128300E-01, -.15478800E+00, -.52511900E-01, -.24770400E+00, 0.17055600E+00, 0.67121200E-01, -.15634400E+00, -.16670100E-01, 0.25726100E+00, -.20318800E-01, 0.16103400E+00, -.56347700E-01, -.44907000E-01, 0.25400200E+00, -.25356300E-01, -.79260800E-01, -.40597400E-01, 0.10827400E+00, 0.28970800E+00, -.95576000E-04, 0.15559200E-02, 0.34263800E-01, -.24524100E-01, 0.20762500E-01, 0.11512500E+00, 0.42977000E-01, -.79544200E-01, 0.11333100E-01, -.56644200E-01, -.44584200E-01, 0.64047000E-01, -.13861900E-02, -.81050700E-02, 0.33241100E-02, -.29975100E-01, -.31448500E-01, -.41542700E-01, 0.11195200E+00, -.92476000E-01, -.34089100E+00, -.43098200E-01, -.12056800E-01, -.10031000E-01, -.51379200E-02, 0.70327900E-02, -.50230600E-01, 0.72599100E-01, -.58674800E-01, 0.86880000E-01, 0.59352800E-01, -.29707500E+00, 0.26555400E-01, -.53182700E-01, -.11575000E-01, -.52286200E-02, -.30390600E-01, -.23157600E-01, 0.28543100E-01, 0.29405200E-02, 0.10251500E-01, -.23327200E-02, 0.40875600E-02, 0.23698800E-02, 0.22446700E-01, -.14038300E-01, -.75463200E-01, -.65627500E-03, 0.89579200E-01, 0.16557300E+00, 0.20109700E-01, 0.14005700E-01, -.23699700E-01, 0.50647400E-02, 0.44589400E-02, -.88910900E-02, 0.52786800E-01, -.40483100E-01, -.66702100E-03, -.75342400E-02, 0.12745600E+00, 0.44815500E-03, -.25688800E-01, 0.12207700E-01, -.23781100E-01, -.15408600E+00, -.20952800E+00, 0.22525800E-01, 0.26081700E-01, -.17366200E-02, -.99858000E-02, -.95185000E-02, -.72452500E-01, -.13480700E+00, 0.10184900E-01, -.20927500E-02, 0.60610000E-03, 0.59968500E-02, 0.79696100E-01, 0.88673000E-01, -.20586000E-02, 0.16754400E-02, -.26317100E-02, -.12630000E-01, 0.19991400E-01, 0.46298700E-01, 0.10321100E-01, -.12138300E-01, -.27519700E-01, 0.61140300E-01, -.23200200E-01, 0.99589500E-03, 0.22596500E-01, 0.14985700E-01, -.29997700E-01, -.46765600E-01, 0.18366500E-01, -.18607400E-01, 0.50624200E-01, -.14243000E+00, -.17126900E-01, -.23853100E-01, 0.59442200E-02, 0.76996600E-01, -.16351900E-01, 0.92838200E-01, 0.19391100E-01, 0.10149000E-01, 0.30286300E-01, -.99299200E-01, 0.84720400E-02, -.19348300E-01, -.26322500E-01, 0.17172000E-05, -.69147700E-01, -.16451900E-01, -.10419600E-01, -.49029400E-01, -.10700500E-01, -.53061300E-01, -.14550500E-01, -.54186800E-01, -.85218300E-01, -.17064500E-01, -.13087300E-02, 0.78190100E-01, -.87011500E-02, 0.16400200E-01, 0.57958800E-01, -.20301200E-01, 0.23260900E-02, 0.36532000E-01, -.69910500E-01, -.27563700E-01, 0.23980200E-01, -.10473000E-01, 0.82059600E-03, 0.60104300E-01, 0.41563600E-01, -.13980400E-02, 0.46031400E-01, -.32882100E-01, 0.42737500E-01, 0.12612800E+00, 0.81408300E-02, -.89828900E-02, 0.50827200E-02, 0.74495900E-02, -.11190800E-01, 0.11306500E+00, -.28854200E-01, -.18568200E+00, -.50302000E-01, -.19598400E+00, -.34729900E-01, 0.47407600E-02, 0.18312500E+00, 0.24705900E-03, -.61727400E-01, -.71824600E-01, -.24337000E+00, 0.34730300E-01, 0.57816100E-01, 0.23534000E-01, 0.16748600E+00, 0.91190600E-01, -.56479500E-02, -.54661300E-01, -.55754700E-03, -.60308500E-01, -.60137400E-01, 0.57847200E-02, 0.11516300E+00, 0.59441300E-01, -.90613700E-01, -.41822900E-01, 0.42121500E-03, -.41037100E-01, 0.17479400E+00, -.95123800E-02, 0.38103500E+00, -.79873300E+00, -.14554200E-01, -.55903400E-01, 0.41051600E-01, -.37031200E-01, 0.61987600E-02, 0.13946400E+00, 0.33308800E-01, 0.17487300E+00, -.28866300E-03, 0.81226700E+01, -.31900600E+00, 0.52443800E+00, 0.33533100E+01, 0.16492700E+01, -.27676200E+00, -.63745500E+00, 0.64369200E+01, -.34713100E+01, 0.35002800E+01, -.32561000E+01, -.18669400E+01, 0.23853100E+01, -.16975900E+01, -.31678700E+01, -.11798100E+02, 0.38014300E+01, 0.20719200E+00, 0.13716200E+00, -.20112900E+00, -.74423500E-01, -.68220700E-01, 0.44342600E-01, 0.34693100E-01, 0.43585300E-01, 0.15741800E+00, -.84638000E-01, -.13780300E+00, -.13314200E+00, -.17325500E+02, 0.80049900E+01, 0.49760600E+01, 0.86402500E+01, 0.35846400E+00, -.13939500E+01, 0.66754600E+01, 0.30134700E+01, 0.63251000E+01, -.96783200E+00, 0.48608500E+01, 0.50175500E+01, -.41871800E+00, -.73354900E+01, -.25092900E+01, 0.49278700E+01, -.33646300E+00, -.56602900E+01, 0.36584500E+01, -.26936300E+01, -.93480300E+00, -.85054800E+01, -.12761600E+01, -.67063100E+00, 0.21613800E+01, 0.63904700E+00, 0.16096200E+01, 0.23148300E+01, 0.59753700E+01, 0.36676500E+01, -.11108400E+01, 0.16778500E+01, 0.85261700E+01, -.53705100E-01, 0.18382700E+00, -.14992600E+00, -.16432100E+00, 0.41863800E+00, -.43106600E-01, -.36485800E+00, 0.19008100E-01, 0.77731700E-01, -.13995300E+00, -.11319200E+00, 0.38820700E-01, 0.18522700E+00, -.13175800E+00, -.38485700E+00, 0.20358600E-01, 0.62341700E-01, 0.18736000E-01, -.43576700E+00, 0.40872600E+00, 0.84497500E+00, 0.35496200E-01, 0.81202300E-01, -.29116100E+00, 0.39830000E+00, 0.58736100E-01 },
        { 0.16196100E+00, -.97581600E+00, 0.24226000E+00, 0.24351700E+00, -.29743600E+00, -.74857700E-01, -.37219900E+00, 0.50837500E+00, 0.18439500E+00, -.53931200E+00, -.27381000E-01, 0.15825100E+01, -.27921900E+00, 0.71804600E+00, -.27622600E+00, -.65564900E-01, -.31074800E+00, -.79826800E-01, -.21196600E+01, 0.10247500E+01, -.27228000E+00, 0.96775400E+00, 0.72671800E-02, -.91505800E+00, -.13181700E+00, -.11233800E+00, -.23974000E+00, 0.62501000E+00, -.97331500E-02, -.26960400E+00, 0.24303400E+00, 0.50847600E-02, -.15479100E+00, -.24056300E+00, 0.19607100E-01, 0.12849500E-01, 0.49240100E-02, 0.79579400E-01, 0.18532500E+00, -.15360500E+00, -.11504200E+00, -.26039200E+00, 0.68126600E+00, 0.44425500E+00, -.10389600E+01, 0.38952400E+00, 0.11708300E+01, -.32403600E-01, -.28570000E+00, 0.10444900E+01, -.12143800E+00, 0.90116200E+00, 0.27817900E+00, 0.44010500E-01, -.87012000E+00, 0.90914800E+00, -.19609900E+00, 0.48217400E+00, -.15017900E+00, -.23613600E+00, 0.77051800E-01, -.24816000E+00, 0.25699200E+00, -.16359900E+00, 0.13261500E+00, -.13383300E-01, -.24871800E+00, -.83705300E-01, 0.65600300E+00, 0.49547800E-03, 0.25683800E+00, 0.20592100E+00, 0.38918700E-01, -.32014300E-01, -.28327500E+00, -.37932900E+00, 0.15898000E-01, 0.50860500E+00, -.15436300E+00, 0.33006000E-01, -.37305600E-02, -.16598100E-01, 0.43786700E+00, 0.14397200E+00, 0.68072700E-01, -.16786000E-01, 0.26568100E-01, -.44324300E+00, -.30589900E+00, 0.68006200E-01, -.31667200E+00, -.21477600E-02, 0.28002700E+00, -.75285300E+00, -.14427600E+00, 0.23460600E-01, -.16777300E+00, 0.23896600E+00, -.11355700E+00, -.12825900E+00, 0.12431200E+01, -.25425500E+00, -.92786600E-02, 0.16823800E+00, -.10881300E-01, 0.40557800E+00, -.17026700E+00, 0.50306300E+00, -.14444200E+00, 0.39228400E-01, 0.53618300E+00, 0.47442100E+00, -.88448800E-01, 0.22251100E-01, 0.58727700E-01, 0.27949800E+00, 0.18195800E-01, -.16446700E+01, -.48294500E+00, -.14386800E+00, 0.25594400E+00, 0.92584000E-01, -.13331900E+00, 0.73353400E+00, 0.13032500E-01, 0.56902300E-01, -.11298100E+00, 0.36012200E-02, 0.11030800E-01, -.91166200E-01, -.96563400E-02, 0.61296200E-01, 0.79116000E-03, 0.10365200E+00, 0.15560300E+00, 0.50219900E-02, 0.65870600E+00, 0.10297900E+00, 0.15969900E+00, 0.28182000E+00, -.98354700E-01, -.84679300E+00, -.14515800E+00, -.53493500E+00, -.29076300E+00, -.27632600E-02, 0.23065200E-01, -.70403300E-01, 0.21774600E+00, -.30908700E-01, 0.18760000E+00, -.19780200E-01, 0.11091100E+00, -.10328300E+00, 0.12514700E+00, 0.10688200E-01, -.11661300E+00, -.12630800E-01, 0.13440600E+00, 0.63012600E-01, 0.63333700E-01, 0.35195400E+00, -.68777600E-01, -.54952900E-01, 0.16599500E+00, 0.17725500E+00, -.21385100E-01, -.22335700E-01, -.13718600E-02, 0.13567200E+00, 0.37486700E-01, 0.13633100E+00, 0.62500600E-01, -.34422700E+00, 0.17985200E-01, 0.16181700E+00, -.79824300E-01, 0.10410500E-01, 0.11240600E+01, 0.58933700E-03, -.24063800E-01, 0.71426600E-01, 0.22789900E+00, -.40224900E-01, -.70274900E-01, 0.72422300E-02, 0.16692000E-01, 0.13111300E+00, 0.47349700E-01, -.38560000E-01, -.47122600E-03, -.14701700E-01, -.13444000E+00, -.26163400E+00, 0.39585500E+00, 0.39364500E+00, -.52911700E-01, -.31645600E+00, -.12162000E+00, -.92191500E-01, 0.33641400E+00, -.30097400E-01, 0.45042700E+00, -.37453700E+01, -.45864100E-01, -.20361100E+00, -.49976300E-02, 0.39272200E-01, -.89439600E-02, -.38060400E+00, 0.83898000E-02, 0.43957700E+00, 0.33250500E-02, 0.18808700E+01, 0.47356100E+02, -.10890500E+02, -.12234800E+02, -.70059500E+01, 0.43829000E+02, 0.69488300E+01, -.48848400E+01, 0.28299300E+01, -.70226200E+01, 0.20526700E+01, 0.21999800E+01, -.27770700E+01, 0.13645400E+02, -.51215400E+01, 0.13459700E+02, -.49220700E+01, 0.27213500E+01, -.13307500E+00, 0.13644700E+00, 0.66209600E+00, 0.65221900E-01, 0.44005000E-02, 0.58074600E-01, -.26581200E+00, -.29861900E+00, 0.10296400E+00, 0.46256200E+00, -.36366300E+00, 0.64935000E+02, -.30708100E+02, -.35092700E+02, -.32604500E+02, -.19509500E+01, -.23851400E+01, -.18074700E+02, 0.23710200E+01, -.83153300E+01, -.52395800E+01, -.19317800E+02, -.46599700E+02, 0.22312200E+02, 0.41532100E+02, 0.23304000E+02, -.59904300E+01, 0.29664600E+02, 0.23716300E+02, -.16169900E+02, 0.66599300E+01, 0.24809400E+02, 0.22876400E+02, 0.89950000E+02, -.44027600E+02, -.38560300E+02, -.44984000E+02, -.15150100E+02, -.27774600E+02, -.19372400E+02, 0.28405600E+02, 0.10995000E+01, -.27234200E+02, -.57249400E+02, 0.10570200E+00, -.12933300E+01, -.99068400E+00, 0.41434900E+00, -.16505600E+01, -.32314500E+00, 0.58329600E+00, -.32419100E+00, 0.23907800E-01, -.31089000E-01, -.72851500E+00, 0.58819900E-01, -.24353100E+00, 0.96664600E+00, 0.22515100E+01, -.31970200E-01, 0.38798000E+00, 0.25910500E-01, 0.11825800E+01, -.61029200E+00, -.54278100E+01, -.96764600E-01, -.71734300E-01, 0.93791300E+00, 0.19995300E+01, 0.41226300E+01 },
        { -.47528300E+00, 0.67167000E+00, -.38835200E+01, -.45057700E+00, 0.17695300E+01, 0.25669800E+00, 0.16758600E+01, -.24453100E+00, -.34430100E+00, 0.49820200E-01, -.16872000E-01, -.19539300E+01, 0.71659900E+00, -.38395100E-01, -.82396300E+00, -.31192400E+00, -.14208200E+01, 0.28382700E+00, 0.42372000E+00, -.20782100E-01, -.19322800E+00, 0.30223700E+00, 0.21479100E+00, -.70866100E+00, -.43685700E+00, -.30074200E+00, -.64705800E+00, 0.13485200E+00, 0.14128600E+00, 0.41983000E+00, 0.44583200E-01, 0.78544900E-01, -.92690800E+00, 0.23570800E+00, 0.21460100E+00, 0.11797500E+00, -.49881100E-01, 0.12765300E+00, 0.18200300E+00, 0.20272300E+00, 0.34279600E-01, -.30982000E+00, -.92741700E+00, 0.76733500E-01, -.32528900E-01, 0.28702700E-01, 0.15620400E+00, -.65256100E-01, -.26862600E-01, 0.20375100E+00, 0.31180000E+00, -.11805100E+00, -.54626500E-01, 0.54190100E+00, -.17492100E+00, 0.62496800E+00, 0.19228200E+00, -.20767200E+00, 0.10797900E+00, 0.43201000E+00, -.61698100E-01, -.21447400E+00, -.13522000E-01, -.54349600E-01, 0.29232200E-01, 0.11157200E+00, 0.81833200E-01, 0.71091900E+00, -.27323500E+00, 0.16285300E-02, -.76859600E+00, -.58111000E+00, 0.68033000E-01, -.63048500E-01, 0.67740200E-01, 0.10195800E+00, 0.47478300E-01, 0.12450100E+00, -.49450700E-01, -.26034100E+00, 0.41060400E+00, 0.80925900E-01, -.16139900E+00, 0.64899500E-01, -.11102300E-01, -.15696600E+00, 0.51064200E+00, 0.52439900E+00, 0.83701500E+00, 0.36718000E-01, -.68071800E+00, -.15763100E+00, 0.58741000E+00, 0.13609200E+00, -.35434200E+00, -.15494200E+01, -.13151000E+00, 0.18525200E+00, -.21422000E+00, -.46485600E-01, -.14795300E+00, 0.34018400E+00, 0.17244900E-01, -.61840500E+00, -.18418700E+00, -.55068200E-01, 0.36337300E+00, -.46827700E+00, 0.11483300E+01, -.68266500E+00, -.11856200E+01, -.47551000E+00, -.12732100E+00, -.17345100E-02, 0.49032100E-01, -.25648900E+00, -.22717100E+00, 0.47653900E+00, -.18096700E+00, -.72040500E-01, 0.18821000E-01, -.19286500E+00, 0.70747200E-01, -.16791100E-01, 0.14094300E-01, 0.39637300E+00, 0.48566600E+00, -.16888100E+00, 0.15404000E-01, 0.12721100E-01, -.36887500E+00, -.46979000E-01, -.38295900E-01, 0.29316700E-01, -.14138300E+00, -.93810800E-02, -.52687100E-01, -.70748000E-01, -.28538100E-01, 0.59376600E-01, -.20193500E-01, 0.59124100E-01, 0.35660400E-01, 0.76626300E+00, 0.79390500E+00, 0.10506500E+00, 0.10620400E+00, -.68965900E-02, 0.21674000E+00, -.17311400E+00, -.40529200E+00, 0.31682300E+00, -.22972700E-02, -.74347900E+00, -.89348900E+00, 0.72462400E-01, -.79677900E+00, -.15709100E-01, -.67349600E-01, 0.49966500E-01, 0.35183900E+00, -.98943300E-01, -.67037700E-01, -.84530100E-02, -.26835000E-01, -.49764900E+00, -.77275500E-01, 0.11653200E+00, 0.94270500E-02, -.21537600E+00, 0.20985100E+00, -.17154300E+00, -.21507300E+00, 0.12156300E+01, -.35497200E+00, 0.88965700E+00, 0.71940300E-01, -.18180900E-01, 0.21887400E+01, 0.62038100E-03, -.25013100E+00, 0.20281700E+00, -.56554600E+00, 0.48231700E-01, -.45178200E+00, 0.17621000E+00, 0.58594800E+00, 0.31108000E+00, 0.82404200E-01, 0.20260300E-01, 0.17834100E-02, -.60572500E-01, -.16881700E+00, -.31649300E+00, 0.20004500E+01, 0.21501900E+01, 0.20673800E+01, -.53605500E+00, 0.55824200E+00, -.20426800E+00, -.62365100E+00, 0.12621600E-01, -.28387400E+01, 0.18862500E+01, -.28998100E+00, -.74531000E+00, 0.53018200E+00, 0.11093200E+01, -.97106600E-01, -.74775100E+00, 0.18175400E+00, -.69257300E+00, 0.50389800E-02, 0.23452100E+01, -.43215700E-01, 0.38199000E+02, -.21182200E+02, -.21970900E+02, 0.48420300E+01, -.11984800E+02, 0.87150400E+01, -.55876000E+01, -.35984600E+02, -.52261500E+01, -.20876200E+02, -.15799500E+02, 0.31969900E+02, -.32094900E+01, 0.41501900E+02, -.16313000E+02, -.23263000E+02, -.30967000E+01, 0.14677600E+01, 0.27422600E+01, 0.15470200E+01, -.60067000E+00, 0.30993900E-01, 0.32704700E-01, -.46961200E+00, -.30484900E+00, 0.52084200E+00, 0.24945100E+01, -.97352000E+02, 0.52847200E+02, 0.50381700E+02, 0.48368500E+02, 0.94449500E+01, 0.24856600E+02, 0.73930000E+01, -.24517900E+02, -.90612800E+01, 0.20690400E+02, 0.27099500E+02, 0.55510200E+02, -.25906800E+02, -.66552900E+02, -.27749400E+02, -.52298700E+02, 0.14707900E+02, 0.30131700E+00, 0.27829500E+01, -.29791100E+02, 0.13012200E+02, -.51555400E+02, -.36265600E+02, 0.16699100E+02, 0.28156000E+02, 0.18119700E+02, 0.54811200E+01, -.72639600E+01, -.21072400E+02, 0.10123900E+02, 0.26625100E+02, -.32592200E+01, 0.47101200E+02, 0.29275800E+01, -.38285200E+01, -.37851000E+00, -.11126600E+01, -.35222600E+01, 0.70336000E+00, 0.15941400E+01, -.33128900E+01, 0.54417600E+00, -.38597900E+00, 0.43641700E+00, 0.22646400E+01, -.14172400E+01, 0.36728200E+01, 0.43256700E+01, 0.19256600E+01, 0.17391100E+01, -.67063100E+00, -.38344300E+01, -.23375600E+01, -.46712800E+01, -.33210200E+00, 0.71061300E+00, -.51958000E+01, -.95822300E+00, 0.35800700E+01 },
        { -.39800300E+00, 0.13208900E+01, -.33353600E+01, -.77504400E+00, 0.75316400E+00, 0.20418100E+00, 0.18549300E+01, 0.25850300E+01, 0.94724800E+00, 0.35225100E-01, -.35338500E-01, -.16174400E+01, 0.12346600E+00, -.88119200E+00, 0.74289900E+00, 0.27440800E+00, -.55709600E+00, 0.31609000E+00, 0.21702500E+01, -.60658000E+00, 0.10284800E+01, -.31999600E+01, 0.74209800E-01, 0.11399300E+01, -.13333700E+00, -.62651500E-01, -.74291700E+00, -.50030500E+00, -.39436400E-01, 0.43093000E+00, 0.25417000E+00, 0.46990600E-01, 0.34451900E+00, 0.20763900E+00, -.11535300E+00, -.26727600E+00, 0.11909300E-01, -.79945500E+00, -.16732600E+00, -.60960300E+00, 0.22181400E+00, -.16877600E+01, -.37085100E+00, -.26769100E+00, 0.25066000E+00, -.48164300E+00, -.15717300E+01, -.16200600E-01, -.18662300E+00, -.39071800E+00, -.58064000E+00, 0.13463200E+01, 0.24709100E+00, -.69510600E+00, 0.10735400E+01, -.13815100E+01, -.61295700E+00, -.10564800E+01, 0.31351700E+00, -.57261600E+00, 0.11674000E+01, 0.80726700E+00, -.12197700E+00, -.22812000E+00, -.38678000E+00, -.60739500E+00, 0.17282700E+00, -.95985900E-01, -.44623700E+00, 0.44300500E-02, 0.73276100E+00, 0.24232900E+01, -.87570400E-01, 0.12876900E+00, 0.47257700E+00, 0.28030800E-01, -.11128400E-01, -.29660500E+00, 0.27679100E+00, -.28739200E-01, 0.19780600E-02, 0.15119200E-01, -.62859500E+00, -.14711000E+00, 0.10114600E+00, -.10640700E-01, 0.19388300E+00, 0.16198500E+00, -.92361900E+00, -.53944300E-01, -.12683400E+01, -.23157600E-01, -.32544000E+00, 0.10213900E+01, -.52952100E+00, -.62031900E+00, -.91152400E+00, 0.33450100E+00, -.54947900E+00, -.15829500E+00, -.79008400E+00, 0.89773800E+00, -.26935800E-02, 0.46276000E+00, 0.56554400E+00, -.24602800E+00, 0.27298800E+00, -.82318400E+00, 0.85319400E+00, 0.26415300E+00, 0.89250900E+00, 0.30581900E+00, 0.45612800E+00, -.76905000E-01, 0.31887100E+00, -.52562600E+00, -.21904000E+00, 0.10884600E+01, 0.12757300E+01, -.13430400E+00, 0.50675200E+00, -.49657900E+00, 0.31994900E-01, -.12942200E+01, 0.15596700E+00, -.10380300E+00, -.16653400E+00, 0.83549000E+00, 0.91246200E-01, 0.23477700E+00, 0.45205500E+00, -.11556900E+01, 0.11257300E+00, 0.26746400E+00, -.79183800E-01, 0.20559700E-01, -.16385800E+00, -.42953600E+00, 0.18336100E+00, 0.18824400E+00, -.28317800E+00, 0.79451500E+00, -.95812600E-01, -.97804100E+00, -.15074000E+01, -.10497800E+00, 0.98577500E-01, -.19488900E+00, -.12159800E+01, 0.46482300E+00, 0.12161600E+01, -.50867200E+00, -.14729700E+01, -.98625700E+00, 0.27043800E+00, 0.19286900E+00, -.39752000E+00, -.52011800E-01, 0.28944800E+00, -.24897300E+00, 0.35542700E+00, 0.13941900E+01, 0.17227300E+00, 0.42361500E-02, 0.23574600E+00, -.89435400E+00, -.48794400E-01, -.32117100E+00, -.42428700E-01, -.26310100E+00, -.55253100E+00, -.54645200E+00, 0.12897200E+00, -.38292400E+00, 0.31140600E+00, -.11494400E+01, -.72548500E-01, 0.87484700E-01, -.10776200E+01, -.18205400E-02, 0.89041700E-01, 0.11767400E+01, 0.57407400E-01, 0.17699900E+00, 0.75568100E-01, -.28845800E+00, 0.12447200E+01, -.90930400E+00, -.48445000E-01, -.16195600E+00, 0.93245500E-03, -.20206900E+00, 0.74201500E-01, 0.34257500E+00, -.14571500E+01, -.67061700E+00, -.88597600E+00, 0.41304600E+00, 0.40080000E+00, -.64685100E-01, -.67054000E+00, -.10406700E-01, 0.25964000E+01, 0.38635700E+01, 0.29719500E+00, 0.16216200E+01, -.64158200E+00, 0.15650800E+01, -.75043000E-01, -.15486200E+01, -.28112100E-01, -.16583100E+01, -.19229900E-02, -.60180400E+01, 0.14670200E+00, 0.33908100E+00, 0.97076100E+02, 0.53749700E+02, 0.13237000E+01, -.23548600E+01, -.38565500E+00, 0.12167400E+01, 0.31954600E+02, 0.97383800E+00, 0.28114500E+01, 0.20266300E+02, -.42851700E+01, -.21491400E+02, -.83235800E+02, 0.25964300E+02, 0.60625500E+02, 0.25622800E+01, -.15045200E+01, -.22535800E+01, -.12768800E+01, 0.48652600E+00, 0.54065700E+00, -.88237700E+00, 0.48983000E+00, -.56788400E+00, -.75223200E+00, -.20732600E+01, 0.60286100E+01, 0.16840000E+01, 0.11520900E+01, -.29627600E+01, 0.89980500E+01, -.33964400E+01, -.37790400E+00, 0.11305100E+02, 0.12748500E+01, -.22040600E+01, -.91126300E+00, 0.36646800E+02, -.12923500E+02, -.20986400E+02, -.18331700E+02, 0.33211800E+02, -.64422000E+01, -.68006700E+02, -.10401200E+02, -.40524500E+01, 0.18046200E+01, 0.13963000E+02, -.79576700E+02, 0.37396400E+02, 0.43731300E+02, 0.39805400E+02, 0.36488300E+02, 0.41281500E+02, 0.58882000E+02, 0.48969800E+02, -.26860400E+02, 0.22371700E+02, 0.34603600E+02, -.19769900E+01, 0.46985100E+01, 0.56483400E+00, -.11316300E+01, 0.21362200E+01, -.23323000E+01, -.15143600E+01, 0.22050800E+01, 0.86831700E-01, -.14381900E+00, -.17526900E+01, -.24957200E+01, 0.20942500E+01, -.26330300E+01, -.90215400E+00, -.92103900E+00, -.13934400E+01, 0.84780600E+00, -.41509100E+01, 0.25404200E+01, 0.14310100E+02, -.65422500E+00, -.15036000E+00, 0.32506900E+01, -.38743700E+00, -.83290300E+01 },
        { -.29851100E+00, -.86162500E+00, -.28467800E+01, 0.27948500E+00, 0.23024600E+01, 0.16201500E+00, 0.10579400E+01, -.19956600E+01, -.15658400E+00, 0.58963800E+00, -.15162900E+00, -.24375900E+01, 0.28577200E+00, -.47175700E+00, -.46597400E+00, -.46226900E+00, -.34629000E+01, 0.40385300E+00, 0.27132500E+00, -.32851900E+00, -.17618800E+00, 0.48779100E+00, 0.14126700E+00, -.10452400E+01, -.10589900E+01, -.31442000E+00, -.94948600E+00, -.39197700E+00, 0.24918600E+00, 0.10227200E+01, -.31349700E+00, 0.17180300E+00, -.12890900E+01, 0.28173900E+00, -.47862000E+00, 0.70010800E-01, -.68058400E-01, -.27808400E+00, 0.61172300E-01, 0.75264600E+00, -.26510000E+00, -.86517300E+00, -.31140100E+01, -.36763400E+00, 0.72436100E+00, 0.29861500E+00, -.63986200E+00, -.59105500E-01, -.39167800E+00, -.37271000E+00, -.70862000E+00, 0.55278300E+00, 0.55242500E+00, 0.11525800E+01, -.52725300E-02, 0.10286400E+01, -.53964200E+00, -.36350800E+00, -.23974100E+00, -.14677200E-01, 0.73251600E+00, -.28492900E+00, -.24849100E+00, -.30677700E+00, 0.77527800E-01, -.37982100E-01, 0.17485300E+00, 0.11204200E+00, -.22922100E+00, 0.95589000E-02, -.68968100E-01, 0.77975600E+00, 0.21351700E+00, 0.81059800E-01, -.19644800E+00, 0.50624600E+00, 0.12070300E+00, 0.28357100E+00, 0.18973100E+00, 0.23692000E+00, -.66596000E-02, -.41848000E-01, 0.34687300E-01, 0.12960800E+00, 0.16576800E-01, 0.33535600E+00, -.63084900E-01, -.77702300E+00, 0.54202000E+00, -.42088600E-01, 0.52083400E+00, 0.52386700E-01, -.20625300E+00, -.40426800E+00, 0.69352400E+00, 0.79670500E+00, -.58739800E+00, 0.56129500E-01, 0.68665400E+00, 0.77134000E-01, -.12743600E+01, -.68624400E+00, -.22630000E-02, 0.11332200E+00, 0.30039500E+00, -.23545800E+00, 0.99387800E-01, 0.74073500E+00, 0.10923200E+00, -.76737600E+00, -.72845500E-01, -.11563700E+00, 0.67291400E-01, 0.11251800E+00, 0.60369000E-01, -.14776000E+00, -.36409800E+00, -.26351100E+00, -.47435100E+00, -.18441300E+00, 0.13671900E+00, 0.17352300E+00, 0.92318200E-01, 0.18626900E+00, -.15204600E+00, 0.17708600E+00, -.63050800E+00, 0.67857400E-01, -.17618300E-01, -.38694200E-01, -.39159200E+00, 0.51907300E+00, -.19890900E-01, 0.21435700E-01, 0.54081300E-01, 0.31462200E-02, 0.13871200E+01, 0.15443800E+00, 0.21054800E+00, 0.63519500E+00, -.12346900E+00, -.23051100E+00, -.22016000E-01, -.17902600E+00, 0.41920000E+00, 0.94394300E-01, -.20227700E-01, -.68549700E+00, 0.37783900E+00, -.24680400E+00, -.35702200E+00, 0.19762300E+00, 0.24366000E+00, -.79151900E+00, 0.56350100E+00, -.30758600E+00, 0.61090900E+00, 0.82312000E-01, 0.51854600E-01, 0.37168300E+00, 0.92502500E-01, 0.78581100E+00, 0.18518600E+00, 0.42999900E-01, -.28277000E+00, -.19811500E+00, -.50833200E-01, 0.50250100E+00, 0.25062300E-01, -.78568000E+00, 0.17705000E+00, -.38213900E+00, -.97901200E-01, 0.11933700E+01, -.10266500E+00, 0.63978000E+00, 0.18470300E+00, -.29649500E-01, -.19738400E+01, 0.11277900E-02, 0.22442800E+00, 0.60531100E+00, 0.59446700E+00, -.25760300E-01, -.61603700E+00, 0.41713000E-01, 0.68111200E+00, -.57931600E-01, -.67148100E-01, 0.22927600E+00, 0.10545600E-02, -.50888100E+00, 0.23474600E+00, 0.56283200E+00, 0.18695200E+00, 0.42433100E+00, 0.35939500E+00, 0.81884100E+00, -.60240600E+00, -.11008900E+00, 0.11860100E+01, -.10892600E+00, 0.33217900E+01, -.80522700E+01, 0.18481200E+00, 0.62814000E+00, 0.89477900E+00, 0.77298500E+00, -.16359200E+00, 0.19981300E+01, -.86296600E-01, -.14407200E+00, 0.75484800E-03, 0.64126300E+00, 0.34750200E+00, -.11910100E+00, -.33735000E+00, -.17949200E+02, 0.81706300E+01, 0.13613700E+02, 0.51058300E+02, -.23841600E+02, 0.12288700E+02, -.25732400E+02, -.33833700E+02, -.18340800E+02, 0.47408700E+02, 0.14002400E+02, -.41812200E+02, -.13735300E+02, 0.45643700E+02, 0.55054000E-01, -.10462600E+00, 0.88687800E+00, -.24598300E-01, -.29905000E+00, -.44710100E+00, 0.26803300E+00, -.23021500E+01, 0.24309900E+00, -.22582900E+00, -.39955000E+01, 0.14972000E+02, -.56243200E+01, 0.49489900E+01, -.74853200E+01, -.36745800E+01, -.28935500E+02, -.87877000E+01, 0.54693300E+01, 0.91394800E+01, -.24160300E+02, -.28865300E+01, 0.22627200E+03, -.10998100E+03, -.21517500E+03, -.11314000E+03, -.12589600E+03, -.78326000E+02, -.10164800E+02, 0.85726400E+02, -.40506500E+02, -.72524700E+02, -.17312800E+02, -.74502500E+02, 0.36149700E+02, 0.46534100E+02, 0.37258300E+02, 0.65914800E+02, 0.88150200E+01, 0.21120900E+02, -.89420200E+01, 0.13484100E+02, -.24767900E+01, -.54814600E+02, 0.77949600E+00, 0.20004700E+01, 0.13424000E+01, -.53139400E+00, -.22915200E+01, 0.13259500E+01, 0.29918800E+01, 0.13798100E+01, -.22865900E+00, -.27446200E+01, -.51049300E+00, -.33623200E+01, 0.22900500E+01, 0.26952600E+01, 0.50918900E+01, -.14820000E+01, -.20248400E+01, 0.35406600E+00, -.54816700E+00, -.11105400E+01, -.39538700E+01, 0.14140600E+01, -.15145700E+00, 0.30712600E+01, -.47923000E+01, -.37033400E+01 },
        { -.76294400E+00, 0.17324700E+01, -.58656700E+01, -.81205100E+00, 0.30662100E+01, 0.54765400E+00, 0.23381400E+01, -.24803500E+01, -.89946500E+00, 0.57055000E+00, -.14834400E+00, -.29035600E+01, 0.11143300E+01, -.25415100E+00, -.20089800E+01, -.93428200E+00, -.24960700E+01, 0.46377600E+00, -.11108500E-01, 0.75637000E-01, -.46907500E+00, -.56694200E+00, 0.24767400E+00, -.48447600E+00, -.81741400E+00, -.44953200E+00, -.94150000E+00, -.21800400E+00, 0.19480800E+00, 0.78103500E+00, 0.23568700E+00, -.34414200E-02, -.14999400E+01, 0.31882100E+00, 0.67933000E+00, 0.27033100E+00, -.76695600E-01, 0.52643000E+00, 0.52235300E+00, 0.16025800E+00, 0.21357200E+00, -.17693600E+01, -.15240200E+01, 0.27638700E+00, 0.49216000E+00, -.23134100E-01, 0.14469200E+00, 0.28837000E+00, -.69521200E-01, 0.23523900E+00, 0.23964500E+00, 0.63799800E+00, 0.18175000E+00, 0.13402500E+00, -.40692200E+00, 0.12260000E+01, 0.34195800E+00, -.11084400E+01, 0.25279600E+00, -.22674700E+00, 0.69337900E+00, -.50638000E+00, 0.12400700E+00, 0.13979900E-01, -.15946300E+00, -.14463900E-01, -.36571000E-01, 0.15962000E+01, 0.48161000E-01, 0.43594300E-02, -.11465700E+01, -.17198700E+01, 0.10424400E+00, 0.25604600E-01, 0.26553400E+00, 0.10849800E+00, 0.22616700E+00, 0.84164300E-01, -.15579200E+00, -.57150200E+00, -.27984900E-01, 0.20700300E+00, -.98857700E+00, 0.45248700E+00, 0.74945600E-01, -.27626000E+00, 0.10070700E+01, 0.89315500E-02, -.10429800E+01, -.91587900E-01, -.96540000E+00, -.35355500E+00, 0.78558900E+00, 0.52094000E+01, 0.21969400E+00, -.11244700E+01, -.15803400E+01, 0.73807500E+00, 0.20976400E+00, 0.32617500E+00, -.43417400E+01, 0.89066700E+00, 0.37793500E-01, -.78004400E+00, -.99569500E-01, -.88236000E+00, 0.30776900E+00, -.44926800E+00, -.67181200E-01, -.66575700E+00, 0.90843200E+00, -.11043500E+01, 0.67494500E+00, 0.12391400E+00, 0.21622200E-02, -.86470700E+00, -.24227500E-01, 0.51633100E+01, 0.75208900E+00, -.79677600E-01, 0.25974400E+00, 0.17661100E+01, -.28105900E+00, 0.64955300E+00, -.98275900E-01, 0.93327800E+00, 0.48820100E+00, 0.11156000E+01, 0.14583600E+00, 0.25805800E+00, 0.87818900E+00, -.22563700E+01, 0.24372500E+00, 0.47256600E+00, -.54924800E+00, 0.55845700E-01, -.16433700E+01, -.10599100E+01, -.41619600E+00, -.78546100E-01, 0.94503300E-01, 0.69156000E+00, 0.13218000E+00, -.16362800E+00, -.40659600E+00, -.57673600E-01, -.95847400E-01, -.15527000E+00, -.74134600E+00, 0.39696600E+00, 0.10412000E+01, -.49094400E+00, 0.47387800E-01, -.80397400E+00, -.72320400E+00, 0.43842000E+00, -.19080000E+01, 0.15255900E+00, -.33186300E+00, 0.14864400E+01, -.40872500E+00, -.24873400E+01, 0.87713200E-01, 0.27773200E-01, 0.57699300E+00, -.55313300E-01, 0.25747300E+00, 0.65821600E-01, 0.26456100E-01, 0.20293800E+00, -.39195100E+00, 0.38299500E-01, -.40123600E-01, -.32078300E+01, 0.11154600E+00, -.92965300E+00, -.74121100E+00, 0.33136600E-01, 0.34390700E+01, -.12988700E-02, -.42697000E+00, -.15390700E+01, -.18691300E+01, 0.21719600E+00, 0.18923700E+01, 0.74291900E+00, 0.14193100E+01, 0.20519100E+00, 0.30036200E-01, 0.12896100E+00, -.19291300E-02, -.76796900E-01, 0.81650700E-01, -.52787200E+00, -.24804500E+01, -.24554900E+00, -.26054400E+01, -.14464600E+01, 0.77406300E+00, -.86990600E-01, 0.56565100E+00, -.90051000E-02, -.15712300E-01, -.77892200E+01, 0.17377700E+00, -.82202900E+00, -.11882800E+01, -.11255100E+01, 0.18885600E+00, -.33536500E+01, -.27521000E-01, 0.10419000E+01, 0.32992500E-02, 0.67833100E+01, 0.33465600E+01, -.84276600E+00, 0.11081600E+00, -.11106200E-01, -.27959900E+02, -.11530000E+02, -.12851100E+03, 0.63904900E+02, -.36908400E+02, 0.63988700E+02, 0.54843400E+02, 0.28846500E+01, -.20684400E+02, 0.14367400E+02, 0.11807200E+03, -.46687000E+01, -.26620500E+02, -.31354000E+01, 0.20837400E+01, 0.43520100E+00, 0.15654400E+01, 0.26311100E+00, -.77150500E-01, 0.79202800E+00, 0.31297700E+00, -.76201100E+00, -.34904100E+00, 0.33291600E+01, 0.45860400E+01, 0.59749900E+01, 0.17727300E+02, -.21184500E+01, 0.14875100E+02, 0.54751600E+02, -.34718600E+02, -.63687900E+02, -.62241500E+02, 0.50662700E+02, 0.20629700E+02, -.15014700E+03, 0.64109900E+02, 0.14579600E+03, 0.75073600E+02, 0.67166100E+01, -.26641300E+02, -.28003700E+01, -.11483600E+03, 0.50768500E+02, 0.24606600E+02, 0.41077800E+02, -.19886900E+03, 0.10449300E+03, 0.68819200E+02, 0.99435700E+02, 0.37134400E+02, 0.22111600E+02, 0.35421500E+02, -.42050200E+02, 0.24480400E+02, 0.11818700E+01, 0.10252100E+03, 0.83463000E+00, 0.58239300E+01, 0.69543000E+00, 0.17663100E+01, -.33520800E+01, 0.93556700E+00, 0.13470800E+00, 0.43123400E+01, 0.21758600E+00, 0.19519100E+01, 0.21120900E+01, 0.18636600E+01, -.51403700E+01, 0.12492400E+01, 0.81858500E+00, 0.66146000E+00, 0.14902900E+01, 0.64695800E+00, -.37803400E+01, -.23315500E+01, 0.62795900E+01, -.11927700E+01, 0.37164800E+00, -.75367700E+00, -.11986100E+02, -.94746900E+01 },
        { -.90091200E+00, 0.15638200E+01, -.30240000E+01, -.62359000E+00, 0.97569000E+00, 0.13718400E+00, 0.53099100E+00, 0.86784200E+00, -.49150000E+00, -.77819200E+00, 0.24881300E+00, 0.53881400E+00, 0.91527600E+00, 0.60385400E+00, -.31313200E+00, -.20841000E+00, -.17829000E+01, 0.80180200E-01, -.18497500E+00, -.12359200E+00, -.37715400E+00, 0.32923900E+01, 0.38056300E+00, -.51784100E+00, -.33368500E+00, 0.37995900E-02, -.33630700E-01, 0.12740500E+01, 0.32042900E+00, -.27962500E+00, 0.51671400E+00, 0.44270500E-01, -.13970700E+01, 0.51531300E+00, 0.27840800E+00, 0.11630600E-01, -.61002500E-01, 0.47574600E+00, 0.49349000E-01, 0.30234000E+00, 0.10127300E+01, -.53427100E+00, -.53226000E+01, -.97716000E+00, 0.13841500E+01, 0.22356500E+00, 0.97810900E+00, 0.52740700E-02, -.22669700E-01, -.33230100E+00, 0.90727000E+00, -.83474400E+00, 0.48147000E+00, -.16831100E+01, 0.36894600E+00, -.13666600E+01, 0.84692900E+00, -.64364000E+00, 0.11711500E+00, 0.40283200E+00, -.10068500E+00, 0.50276600E+00, -.54908600E+00, 0.62351000E+00, 0.31655600E+00, -.61015300E-01, -.16070600E+00, -.74265900E+00, -.28287400E+00, 0.21530800E-02, -.85771700E+00, 0.86899700E-01, 0.10274800E-01, -.45717700E-01, 0.61075200E+00, 0.37602800E+00, -.98655600E-01, -.28424400E+00, -.26728100E+00, 0.51820400E-01, 0.76155000E-02, -.27328300E+00, 0.53648900E+00, 0.25967000E-01, -.10819900E+00, -.15305000E+00, -.39569900E+00, -.77482900E+00, -.16955100E+01, 0.32104600E+00, 0.23988700E+00, -.17058900E+00, 0.59755900E+00, 0.72601800E-01, -.15863900E+01, -.38581200E+01, 0.49879600E+00, 0.93552400E+00, 0.83780200E-02, -.23205100E+00, 0.49581100E+01, 0.13181800E+01, -.62146600E-01, -.96809100E+00, -.10720100E+01, 0.12376700E+01, 0.90485600E+00, 0.43175600E+00, -.11200200E+01, -.18639800E+01, -.17179400E+01, -.17468000E-02, -.76522800E+00, 0.18302000E-01, 0.11752800E+00, -.14800700E+00, -.18330300E+00, -.49606100E+01, -.86992300E+00, -.14763100E+00, -.58847600E+00, -.75857700E-01, 0.32316600E+00, -.13999200E+01, 0.10229000E+00, -.57195700E+00, 0.94524400E+00, -.52548800E+00, 0.55696100E-01, -.28154500E-01, -.10655300E+01, 0.13674100E+01, -.19849200E+00, -.19627700E+00, -.17786900E+00, -.52309400E-01, 0.41760100E+00, 0.11530900E+00, -.11479700E+00, -.45729800E+00, 0.26165700E+00, 0.13093800E+01, 0.52897700E+00, 0.32347300E+00, 0.20098400E+00, 0.78905900E-02, 0.20498200E+00, 0.13129000E+00, -.10399300E+01, 0.95525600E-03, -.38167500E+00, -.22619200E-01, 0.27541800E+00, 0.89256400E+00, -.87524900E+00, -.31814900E+00, -.42882800E+00, 0.23974200E-01, -.64523600E-01, 0.89919800E-01, 0.70297100E+00, 0.10611900E+01, 0.46734700E+00, -.74008800E-01, -.29771600E+00, -.12507400E+01, -.62208100E-01, -.20227200E+00, -.43352000E-01, -.78124000E+00, -.22355900E+00, 0.25282600E+00, -.45881400E+00, 0.10175700E+01, 0.10561700E-01, -.73612300E+00, 0.36059900E+00, 0.44612200E-01, -.42921200E+01, -.43497100E-02, 0.22874600E+00, -.57572100E+00, -.56970400E+00, 0.91183100E-01, -.19057900E+00, -.26947400E+00, -.23467300E+01, 0.15290200E+00, -.77539300E-01, -.50965200E+00, -.20682400E-02, 0.36574000E+00, -.15337100E+00, 0.55730900E+00, 0.15446700E+01, 0.36953200E+00, 0.81837200E+00, -.10231300E+01, 0.29439200E+00, -.23396700E+00, -.55506500E+00, 0.32708500E-01, -.90344800E+01, -.17955800E+01, 0.25332500E+00, -.12684700E+01, -.32414800E-01, -.25293800E+00, -.67001200E-01, 0.21971500E+00, 0.33061100E+00, 0.73974600E+00, -.11703600E-01, 0.84586600E+01, -.36436200E+00, -.89248700E+00, -.46795800E+00, -.46255000E+00, -.81103200E-01, -.36717600E+02, -.66534800E+02, 0.28783900E+02, -.49041900E+02, 0.33425100E+02, 0.56358600E+01, -.12335100E+02, 0.55865700E+02, 0.84245600E+01, 0.10646100E+03, -.12349000E+02, 0.98474000E+01, -.28242300E+01, 0.13246500E+01, 0.34743600E+01, 0.14183500E+01, -.20552700E+01, -.19177700E+00, -.65507500E+00, -.22838600E+01, -.77042900E+00, 0.11469800E+01, 0.22030400E+01, -.12829100E+03, 0.76169800E+02, 0.10303500E+03, 0.64046500E+02, 0.24115200E+02, 0.52238700E+02, -.16402000E+02, -.68428600E+02, -.44279100E+02, 0.42310800E+02, 0.25511400E+02, 0.24884400E+02, -.63059200E+01, -.60379000E+02, -.12452300E+02, -.22697300E+03, -.77367900E+02, 0.30219600E+02, 0.69248600E+01, 0.63503700E+02, -.49460800E+02, 0.41911800E+02, -.26703700E+03, 0.12881500E+03, 0.14567500E+03, 0.13353800E+03, 0.77995800E+02, 0.32256800E+02, -.29428200E+02, -.12172100E+03, 0.19066600E+02, 0.80457500E+01, 0.11665500E+03, 0.21243200E+01, -.11523200E+01, -.12395300E+01, 0.45007500E+00, -.11134200E+02, 0.13245500E+01, 0.57468600E+01, -.28508100E+01, 0.10004800E+00, 0.85900100E-01, 0.31483600E+00, -.52337700E-01, -.26921500E+01, 0.82542200E+01, 0.14312700E+02, 0.68522900E+00, 0.38952500E+01, -.12943300E+00, -.94280400E+01, -.56487000E+01, 0.75002100E+01, -.24289200E+01, 0.20725000E+00, -.87630700E+01, -.20933000E+02, -.12332800E+02 },
        { 0.84827400E-01, -.42552400E+00, 0.42893000E+00, 0.11534500E+00, -.39352000E+00, -.11886700E+00, -.60157100E+00, 0.42140700E+00, 0.14542900E+00, -.11073400E+00, -.23634000E-01, 0.43953000E+00, -.16253300E+00, 0.18919800E+00, 0.12799600E+00, 0.18102200E+00, 0.53453400E+00, -.11872600E+00, -.12435800E+00, -.13172700E-01, 0.86368300E-01, 0.77777300E+00, -.92134000E-02, -.57701000E-01, 0.74394200E-01, 0.36778700E-01, 0.18657300E+00, 0.68114800E-01, 0.35898200E-01, -.12181900E+00, -.66987900E-01, -.46464000E-01, 0.18322500E+00, -.22925100E-01, -.88972500E-01, -.11419500E-01, 0.13992700E-01, -.11115900E+00, -.14494200E+00, -.80136300E-02, 0.11422100E+00, 0.32443000E+00, 0.13836800E+00, 0.52376300E-01, -.16214600E+00, 0.16815900E-02, -.39740700E-01, 0.24385500E-01, -.30022900E-01, 0.46950400E-01, -.13941000E+00, -.12253100E+00, 0.91939700E-01, 0.11440200E+00, 0.85545400E-01, -.20408000E+00, -.78637700E-01, 0.77413800E-01, -.83039400E-01, -.83126000E-01, -.69322100E-01, 0.65101700E-02, -.79809000E-01, 0.13928200E+00, 0.12010200E-01, 0.30102200E-01, 0.36151800E-02, -.18526200E+00, -.84718100E-01, -.84054200E-03, 0.25721000E+00, 0.88563000E-01, 0.19940700E-01, 0.58342800E-01, -.60139000E-01, 0.17146900E-01, 0.27917200E-02, -.22089100E-01, 0.66447100E-01, 0.13565900E-01, 0.44328500E-03, -.16718900E-01, 0.16133700E+00, -.70675600E-01, -.19028200E-01, 0.40437600E-01, -.52497400E-01, -.28527100E+00, -.76799900E-01, 0.12347500E-01, 0.31808800E+00, 0.47087500E-01, -.69049800E-01, -.47563500E+00, -.93436700E-02, 0.91055700E-01, 0.77691200E-01, 0.24643500E-01, 0.11174500E-01, -.95137600E-01, 0.46976800E+00, -.20824200E+00, -.12451800E-02, 0.42604500E-01, 0.33251700E-01, 0.26665500E-01, -.51866900E-01, 0.14580900E+00, -.25372900E+00, -.22636200E+00, 0.21685500E+00, 0.13378800E+00, -.66035800E-01, 0.94032300E-02, -.19731400E-01, -.63531300E-01, 0.71121500E-01, 0.13756900E+00, 0.14615800E+00, 0.15585800E-01, -.16354600E-01, 0.36593000E+00, -.10267400E-01, -.15152700E-01, -.16751200E-01, 0.11518600E+00, -.12879400E+00, 0.82512200E-01, 0.28105000E-01, -.11892200E+00, 0.51045700E-01, 0.20985100E+00, -.27560700E-01, -.44640000E-01, 0.17705400E-01, -.33394300E-02, 0.41550000E-01, 0.13530600E+00, 0.16765900E-01, 0.47121500E-01, -.31667000E-01, 0.52467500E-01, -.40536000E-01, 0.14320300E+00, -.17039600E+00, -.74415300E-01, -.10254600E-01, 0.15614500E+00, -.92992700E-01, 0.61289000E-01, -.76682700E-01, 0.24953800E-01, 0.16757900E+00, 0.28655000E+00, -.63860900E-01, -.86991100E-01, 0.25918900E+00, -.15919300E-01, -.32701200E-02, -.93074100E-01, 0.15430800E+00, -.34260100E+00, 0.91296900E-01, -.53360300E-02, -.91790900E-01, 0.32631900E-01, -.44604900E-03, 0.30023500E-01, 0.48672600E-02, -.53135100E-01, 0.11138900E+00, 0.14174800E+00, 0.12957000E-01, 0.12964600E+00, -.27209100E-02, -.54959400E-01, -.28546500E-01, 0.46980300E-03, -.73107300E+00, 0.21277700E-03, -.40880000E-01, -.92293300E-01, -.47180600E+00, 0.45076200E-01, 0.42180700E-02, -.27726500E-01, -.28626500E-02, 0.10509800E+00, -.17239600E-01, -.75213400E-01, -.28605300E-03, 0.74783400E-01, -.77512000E-01, -.20758900E-02, 0.18672400E+00, 0.93205300E-01, 0.60586600E+00, 0.75714200E-01, 0.27394600E-01, -.35697600E-01, -.64074200E-01, -.59879300E-02, 0.86852600E+00, -.10410300E+00, -.11504500E-02, -.32253500E-01, 0.26446200E+00, 0.30280400E+00, -.33107300E-01, 0.83614500E+00, 0.77168300E-01, -.24799300E-01, -.12348300E-02, 0.11303600E+01, -.51032600E+00, 0.12251700E+00, -.59328100E-01, -.19838800E+00, -.11141800E+00, -.74543600E-01, -.23510800E+02, 0.11624100E+02, -.70244800E+01, 0.11811300E+02, 0.69422400E+01, 0.11684700E+01, 0.75772300E+01, 0.61486600E+00, 0.19242500E+02, 0.38372900E+00, 0.15492500E+02, -.12914700E+00, 0.75116100E-01, 0.31547400E+00, 0.65258600E-01, -.27699500E+00, -.50981900E-01, -.61973600E-01, -.55692200E+00, 0.12098300E-01, 0.30622900E+00, -.24026400E+00, 0.58299000E+02, -.27139300E+02, -.19090300E+02, -.29100000E+02, -.16658900E+01, -.37584200E+01, -.21314000E+02, -.67517000E+01, -.16879600E+02, -.38242600E+01, -.11507800E+02, 0.14287000E+01, -.18774500E+00, -.17544500E+02, -.71575100E+00, -.49030400E+02, -.24129000E+02, 0.15921300E+02, 0.13910900E+01, 0.13151700E+02, -.14419300E+02, 0.21704400E+02, -.38416600E+02, 0.18733700E+02, 0.18264700E+02, 0.19211300E+02, 0.23136400E+02, 0.92669300E+01, -.76642500E+01, -.16755400E+02, 0.58756400E+00, 0.11173900E+01, 0.48758700E+01, 0.60175100E-01, -.32221700E+00, 0.19584100E+00, 0.36081300E+00, -.27664700E+01, 0.22409200E+00, 0.15226400E+01, -.84790900E+00, -.15931100E+00, 0.15510400E+00, 0.29409600E-01, -.54340300E+00, 0.83954700E-01, 0.15340700E+01, 0.35381400E+01, -.21145800E+00, -.19321200E+00, 0.17569100E+00, -.13204800E+01, -.99785700E+00, 0.95883900E+00, -.50206600E+00, -.17133600E+00, 0.16824400E+01, -.43375400E+01, -.28335600E+01 },
        { -.42693000E+00, -.31677300E+01, -.20788600E+01, -.11980800E+01, 0.18862500E+01, 0.72234900E+00, 0.66530100E+00, -.30817500E+01, -.97422700E+00, 0.24330700E+00, 0.16065200E+00, 0.83890400E+00, -.57675800E+00, 0.40449700E+00, -.16595500E+00, -.77775000E+00, 0.11549200E+01, 0.25605600E-01, 0.22218300E+01, -.70722200E+00, 0.14114100E+01, 0.33148100E+00, -.53594800E+00, -.25533000E+01, 0.18874300E+00, 0.44550600E+00, -.93070000E+00, -.27924100E+00, 0.94091900E-01, 0.72231400E+00, -.48029600E+00, 0.24774800E+00, -.32387700E+00, -.45293700E-01, 0.10760700E+01, -.65428000E-01, -.62973400E-01, 0.88003700E+00, -.14493600E+00, -.25314100E+00, 0.12651600E-01, -.19564500E+01, -.22107600E+01, -.59665800E+00, -.59216300E+00, -.15674100E+00, 0.72150900E+00, -.69609600E-01, 0.31379700E+00, 0.28791700E+00, -.26315300E+00, 0.98693400E+00, 0.33586700E+00, -.15645100E+01, -.15638800E+01, 0.11134000E+01, 0.60740400E-01, 0.13033600E+01, 0.43753600E-02, -.70379300E+00, 0.34161500E+00, -.31638200E+00, 0.83201500E-01, 0.49612300E+00, -.46903800E-01, 0.72392200E+00, 0.43638200E+00, 0.41179200E+00, 0.11158900E+00, -.58345100E-03, -.10995600E+01, -.81148000E+00, -.23246900E+00, -.10739700E+00, 0.14598700E+01, -.45126400E+00, -.39973700E+00, -.82195700E+00, -.80853300E+00, 0.43269000E+00, 0.37111700E-01, -.49562300E-01, -.13488300E+01, 0.28519400E+00, -.29383100E+00, -.54405100E+00, 0.87400500E+00, -.35084100E+00, 0.96519200E+00, 0.25057400E+00, 0.65136800E+00, -.67430200E-01, 0.12203500E+01, -.14845200E+01, -.11412900E+01, -.13880200E+01, 0.40826100E+00, 0.11170900E+01, 0.88067400E+00, -.95261500E-01, -.17091200E+01, -.76501000E+00, 0.19847100E-01, 0.57406400E+00, 0.54362200E+00, 0.33891900E+00, 0.61059700E-01, 0.67584000E+00, 0.16144200E+01, -.14470900E+01, -.68232100E+00, 0.12107500E+01, -.32676700E+00, -.10876500E+00, -.32414200E+00, -.73393200E+00, -.41933300E+00, 0.39825900E+01, 0.60696000E+00, -.94894600E-01, 0.38483400E+00, -.31209200E+00, 0.65744500E+00, -.14379500E+01, -.14531000E+00, 0.23075200E+00, -.12743000E+01, 0.10598500E+01, 0.16963800E+00, -.12050400E+00, 0.75544900E-01, 0.14480500E+01, -.23838800E+00, 0.26871700E+00, -.72340800E+00, -.29184800E-01, 0.22907300E+00, 0.18662000E+00, 0.17058000E+00, 0.11210400E+01, -.64437900E+00, 0.34377000E+00, 0.30429600E-01, 0.20768500E+01, 0.18008000E+01, -.21509600E+00, 0.10258400E+00, 0.90492500E+00, -.19699300E+00, -.23066700E+00, -.55304900E+00, 0.26910400E+00, 0.12051000E+01, -.12765500E+01, 0.44355800E+00, -.31498600E+00, 0.13209000E+01, -.14653600E+00, 0.29444300E+00, -.33843600E+00, -.18241100E+00, -.12756700E+01, -.33737700E-02, -.13213500E+00, 0.22391200E+00, -.79905500E-01, -.40517800E-01, -.49924000E+00, -.43275300E-01, 0.41213900E+00, -.62849000E-01, 0.30838200E+00, 0.64927100E+00, -.90993300E+00, 0.26463300E+00, -.26378900E+00, -.33248500E+00, 0.25404100E-01, 0.64933300E+00, 0.14491500E-02, -.15288000E+00, -.63170900E+00, -.66110800E+00, 0.90583100E-01, 0.29094500E+00, -.26476600E+00, -.19628600E+00, 0.17331800E+00, 0.43470600E-01, -.11209300E+00, -.17182000E-02, -.38972000E-01, 0.10106800E+00, 0.11719900E+00, 0.94631600E+00, -.43698100E+00, -.23184400E-01, -.44298000E+00, 0.53771000E+00, 0.18176400E+00, -.53524800E+00, 0.44926900E-01, -.24999200E+01, 0.30662800E+01, 0.19639800E+00, -.35360800E+00, 0.16349000E+00, 0.34970700E-01, -.81037600E-03, -.27562100E+00, 0.22910000E-01, -.58556500E+00, -.45267400E-02, 0.17624400E+00, -.75029800E+00, -.29526900E+00, -.18739900E+00, 0.46601500E+00, 0.80480200E-01, 0.44859000E+00, 0.74873700E+00, 0.10600300E+02, 0.16378800E+01, 0.49979100E-01, 0.33580300E+01, -.46587500E+01, -.19722400E+02, 0.90900200E+01, -.79363700E+00, -.25560800E+01, -.30268600E+02, 0.48027000E+00, -.18992100E+00, -.16441800E+01, -.24415000E+00, 0.95367300E+00, -.88525900E-01, 0.43973600E+00, 0.11420100E+01, 0.18456400E+00, -.94695600E+00, 0.76252000E+00, -.56211700E+02, 0.21897000E+02, 0.48060400E+01, 0.28034500E+02, 0.10001200E+02, 0.21973100E+02, 0.13820400E+02, -.55096800E+01, 0.29024500E+01, 0.19293700E+02, 0.27482800E+02, -.11598500E+03, 0.53960700E+02, 0.12311100E+03, 0.57998600E+02, 0.12398600E+03, 0.71531700E+02, -.31772200E+02, -.56331800E+02, -.19223400E+02, 0.61529500E+02, -.14237300E+02, 0.33882700E+02, -.12575000E+02, -.24882100E+02, -.16953500E+02, -.35758600E+02, -.79897300E+01, 0.49720300E+02, 0.42348900E+02, 0.11648000E+02, 0.79452200E+01, 0.64110000E+01, -.11126000E+01, 0.28485900E+01, -.61074300E+00, 0.14143700E+01, 0.63493800E+01, -.48170300E+00, -.33871300E+01, 0.39471500E+01, -.11280700E-01, 0.52719700E+00, 0.11732100E+01, 0.20877900E+01, -.24676200E+01, -.42008000E+01, -.90819400E+01, -.25374700E+00, 0.16048300E+01, 0.52621300E+00, 0.45944700E+01, 0.13529000E+01, -.41023200E+01, -.96729000E+00, -.35686500E-01, -.61796800E+00, 0.98219300E+01, 0.43350400E+01 },
        { 0.47850500E-01, -.18641200E+00, -.68614000E-02, 0.51159700E-01, -.15299100E+00, -.86302500E-01, -.26122300E+00, 0.30349300E+00, 0.75367700E-01, -.82830400E-01, -.11638100E-01, 0.11505800E-01, -.37737900E-01, 0.63770700E-01, 0.63413900E-01, 0.55109600E-01, 0.40241900E+00, -.43157900E-01, -.50814900E-01, 0.87094300E-02, 0.15967900E+00, -.33458100E-01, 0.95859900E-02, 0.96478800E-01, 0.25335400E-01, -.14773100E-02, 0.42937400E-01, 0.60708400E-01, 0.23411400E-02, -.74758200E-01, 0.19173700E-01, -.25163400E-01, 0.16260200E-01, -.95614300E-02, -.24968600E-01, -.45862000E-01, 0.82672300E-02, -.11689800E+00, -.67363300E-01, -.65393700E-01, 0.13840700E+00, 0.40202300E-01, -.35795300E+00, -.10361200E+00, -.27982200E-02, -.28980700E-01, -.75678700E-01, 0.12829700E-01, -.19885300E-01, -.31193300E-01, -.51132300E-01, -.21152900E-01, 0.53977500E-01, -.38537500E+00, 0.71617000E-01, -.22751900E+00, 0.30573000E-01, -.17436100E-01, -.19116300E-01, -.40551700E-01, -.38615900E-02, 0.60254500E-01, -.33976200E-01, 0.55587800E-01, 0.13235600E-01, 0.10305100E-01, -.79064800E-03, -.10305500E+00, -.25235400E-01, -.31097800E-03, 0.31892800E-01, 0.10912200E+00, 0.28681700E-02, 0.15136200E-01, 0.13036700E-01, 0.16136100E-01, -.21556700E-01, -.32566100E-01, 0.31334300E-01, -.87408900E-03, 0.18246100E-02, -.20359700E-01, 0.85479900E-01, 0.12587300E-01, -.76656500E-02, -.29272200E-02, -.39567900E-02, -.23312900E+00, -.28466500E+00, 0.31079400E-01, 0.31987200E-01, 0.16261000E-01, 0.56792600E-01, -.18841700E+00, -.81444500E-01, -.10063300E+00, 0.18219800E-01, 0.72991500E-01, -.56083300E-01, -.37289400E-01, 0.36133400E+00, -.78127700E-03, -.50176400E-02, 0.16554900E-01, -.12019700E-01, 0.16997900E-01, -.15824000E-01, -.14754600E-01, -.31721200E-01, 0.64559000E-02, 0.64802300E-01, 0.13006900E+00, -.13273900E-01, -.66715000E-02, 0.15974300E-01, -.33555000E-01, -.12150500E-01, 0.77100300E-01, 0.11764100E+00, -.14964700E-01, 0.60641900E-01, -.38515500E-01, -.19987100E-02, -.10556300E+00, 0.90419500E-02, 0.10857100E+00, 0.18016400E-01, 0.44525900E-01, 0.11316600E-01, 0.23187300E-01, 0.32928700E-01, -.13815600E+00, 0.78384700E-03, -.14655900E-01, -.38287100E-01, -.21575300E-02, -.59425900E-01, -.35752800E-01, -.17351000E-01, -.15354600E+00, 0.13213900E-02, 0.16991200E+00, 0.44560600E-01, -.56865400E-01, -.10139800E+00, -.17219400E-01, -.13242000E-01, 0.87697700E-01, -.21221600E-01, 0.21899000E-01, 0.12194000E+00, -.72403600E-01, 0.45424500E-02, 0.15702700E+00, -.82002100E-04, -.66276100E-02, -.77922300E-01, 0.52067000E-02, -.94221200E-02, 0.98067500E-01, -.22436600E-01, -.17350800E+00, 0.13525000E-01, -.54384100E-02, 0.50695100E-01, -.13714300E-01, 0.17249900E-01, -.44403700E-01, -.18660300E-02, 0.41427300E-01, -.29956300E-01, 0.96305000E-01, -.35748200E-02, -.11399400E+00, 0.15728700E-01, -.13807100E+00, -.41163100E-01, 0.81047700E-02, 0.60700200E-01, 0.10508900E-03, -.93454600E-02, -.20836200E-01, -.36535700E-01, 0.16482400E-01, 0.20043400E-01, -.42491200E-01, 0.54114900E+00, -.16435500E-01, 0.11293500E-01, 0.56138600E-01, -.15404200E-03, -.50321700E-01, -.23851300E-01, 0.13722000E+00, -.24452700E+00, -.17273600E+00, -.11373500E+00, -.13269400E-01, -.59752600E-01, -.24754100E-02, -.37443400E-01, 0.10991000E-01, -.30521400E+00, -.81816100E+00, 0.34977300E-01, 0.69113800E-01, -.94070000E-01, -.23231500E+00, 0.15823600E-01, -.44863600E+00, -.49506700E-02, 0.64673000E-01, -.38692600E-03, -.97015100E+00, -.65168900E-02, -.39697400E-01, 0.20231800E-01, 0.10106700E+00, 0.21265200E-01, -.21964600E-01, 0.44304800E-01, -.40488500E-01, -.50738700E+01, -.45148700E-01, -.17041600E+01, 0.10837000E+01, -.39404600E+01, -.17343000E+01, 0.48320200E+01, 0.71356300E+00, -.69631400E+01, -.24374500E+00, -.11682900E-01, 0.67870300E-03, 0.12150600E+00, 0.83354300E-01, -.19342800E+00, 0.21475200E+00, 0.23133200E+00, 0.10465700E+00, -.17120200E+00, 0.34198600E+00, -.10130900E+02, 0.37043600E+01, 0.13493300E+01, 0.50486300E+01, 0.62484400E+00, 0.34192700E+01, 0.24483500E+01, -.18485800E+01, 0.19429300E+01, 0.29414600E+01, 0.45448400E+01, -.23893100E+02, 0.13146900E+02, 0.22073600E+02, 0.11946800E+02, 0.13547900E+02, 0.65486200E+01, -.17044800E+01, -.69215700E+01, 0.28420900E+00, 0.62896900E+01, 0.36400300E+01, 0.66108800E+01, -.41961900E+01, -.59478700E+01, -.33059400E+01, -.22604300E+01, 0.17675600E+01, 0.40731900E+01, -.27097000E+01, 0.62555100E+00, 0.40225200E+01, -.18708800E+01, 0.17793100E+00, 0.12882900E+01, -.45093500E+00, 0.24700200E-01, 0.57868800E+00, 0.18572300E+00, -.32140800E+00, 0.13143000E+01, 0.92712000E-01, 0.45849400E+00, 0.43098200E+00, 0.28830300E+00, -.39430200E-01, -.29436700E+00, -.10405900E+01, 0.27197500E+00, 0.48272600E+00, -.52090900E-01, 0.21981100E+00, 0.11274400E+00, -.11535200E+00, -.42295700E+00, 0.10583300E+00, -.53630200E+00, 0.14172400E+01, 0.67796800E+00 },
        { 0.11648000E+01, -.95668000E+00, 0.94197600E+01, -.84876700E+00, -.79662200E+01, -.13775400E+01, -.13640600E+02, -.27890000E+01, -.94099000E+00, -.39254400E+00, 0.65705400E+00, 0.94496700E+01, -.19105600E+01, 0.17731000E+01, 0.54803900E+01, 0.23610300E+01, 0.10862100E+02, -.16855900E+01, 0.21309600E+01, -.54028200E+00, 0.95273600E+00, 0.27033500E+01, -.50322900E+00, 0.27302000E+01, 0.19115400E+01, 0.19240500E+00, 0.20060700E+01, -.12383000E+01, -.16596400E+00, -.70303700E+00, -.17176700E+01, -.11957600E+01, 0.15318500E+01, 0.18638800E+00, 0.75699300E+00, -.36990900E+00, 0.11538600E+00, 0.61711300E+00, -.36053900E+00, -.23820300E+00, 0.12557700E+01, 0.29677700E+01, 0.24757900E+01, 0.48485200E+00, -.78678800E+00, -.51073300E+00, -.13242400E+01, 0.21324500E+00, 0.19559900E+00, 0.33825600E-01, -.38745900E+00, -.15422700E+01, -.28388600E+00, 0.14214800E+01, 0.47291900E+00, -.15671900E+01, 0.56352000E+00, 0.18446500E+01, -.30744000E+00, 0.13954100E+00, -.89338400E+00, 0.25144600E+00, -.13530700E+00, 0.11453800E+01, 0.85221500E-01, 0.51756400E+00, 0.33938800E-01, -.18570700E+01, 0.99159800E+00, 0.29942300E-01, 0.98927600E+00, -.10499500E+01, -.48142600E+00, -.14930200E+00, 0.88834400E+00, -.11186200E+01, -.27584800E+00, -.31331300E+00, 0.48099100E+00, 0.17225000E+00, 0.21054800E-01, -.21147100E+00, -.74161400E-01, 0.32995200E+00, 0.12670300E+00, -.81958600E-01, -.24559800E+00, -.18629200E+01, -.19943200E+01, -.17143800E+00, 0.22893700E+01, 0.16850300E+00, -.71135100E+00, -.15509800E+01, 0.13674200E+00, 0.14790100E+01, 0.28663700E+00, 0.43554800E+00, 0.11366300E+01, 0.38228500E+00, 0.62803100E+00, -.52113200E+00, -.10171200E+00, 0.16926400E+01, 0.87027500E+00, 0.22599300E+00, -.48404600E+00, 0.10402200E+01, -.46886300E+00, 0.13028800E+00, 0.12108300E+01, 0.83736900E+00, 0.42602200E+00, -.34204100E-01, 0.77571000E-01, -.14658200E+00, -.17538000E+00, 0.22831100E+01, 0.15393100E+01, -.15949900E+00, 0.86911700E+00, 0.11166200E+01, 0.62936500E-01, -.98585000E+00, -.10967400E+00, -.21079100E+01, -.26834000E+01, 0.13939500E+01, -.10889600E+00, -.13078900E+00, 0.96553500E+00, -.50069600E-01, 0.40381900E-01, -.25861800E-01, -.58003800E+00, 0.41553100E-01, 0.51674200E+00, -.12790700E+00, 0.16254600E+00, 0.51430400E+00, -.41079000E+00, 0.45201300E+00, 0.76036800E-01, -.12636500E+01, -.16411300E+01, -.27433700E+00, -.21078300E+00, -.10926200E+00, -.18263600E+01, 0.77506800E+00, 0.15127900E+01, -.10873100E+01, 0.75038900E+00, 0.20460100E+01, -.13245500E+01, -.24890700E+00, 0.24371100E+00, 0.28564300E+00, -.63358400E+00, -.12828000E-01, -.60179300E+00, -.15699000E+00, -.23184500E+00, -.74265000E-01, 0.25619200E+00, 0.16750000E+01, 0.21445200E+00, 0.50816300E+00, 0.11040400E+00, 0.17602200E+00, 0.35495600E+00, 0.61968100E+00, -.12143500E+00, 0.90349600E+00, -.40046100E-01, 0.15421300E+01, 0.72034600E+00, -.18868000E+00, -.29949000E+01, -.97840200E-01, 0.75620000E+00, 0.17239500E+01, 0.38505800E+01, -.66275700E+00, -.14191200E+01, 0.30143500E+00, -.47476300E+01, -.16958200E+00, -.45336600E-01, 0.21557900E-02, -.35980900E+00, 0.91256800E+00, -.51751500E+00, 0.94775400E+00, -.37008200E+00, -.48155200E+00, 0.43782200E+01, 0.30421200E+01, -.18757200E+01, -.59487400E-01, -.15252500E+01, 0.26307900E+00, -.23245400E+01, 0.11626600E+01, -.33485000E+00, 0.25315800E+01, 0.50652000E-01, -.30027200E+00, -.17244600E+00, 0.77285000E+00, -.15868000E-01, 0.11547600E+00, -.73660400E+00, -.13094900E+02, -.22878800E+01, 0.10591400E+01, 0.43379000E+00, 0.77143100E-01, -.24171500E+00, -.47490200E+00, 0.21059800E+00, -.38957200E+00, -.76087000E+01, 0.11796200E+02, -.15528700E+02, 0.29278900E+02, -.95994600E+02, -.68415700E+02, -.71443700E+02, 0.21174700E+02, -.26215500E+02, 0.10638300E+01, -.26353900E+01, -.16107700E+01, -.76555300E+00, 0.46190700E+00, -.47317300E+00, 0.15146900E+01, 0.49048300E+01, 0.52398100E+00, -.11491100E+01, 0.24746100E+01, -.47314200E+02, 0.15792500E+01, -.26507500E+02, 0.24255500E+02, 0.10110600E+02, -.14882300E+01, 0.32239700E+02, 0.31997800E+02, 0.46129200E+02, 0.34246000E+01, 0.16368000E+02, -.11655500E+03, 0.84675100E+02, 0.11244500E+03, 0.58836200E+02, 0.25759000E+03, 0.10986900E+03, -.52773400E+02, -.12509100E+02, -.62947700E+02, 0.67211500E+02, -.11318700E+03, 0.26007000E+03, -.14805300E+03, -.14937900E+03, -.13065700E+03, -.15110500E+03, -.38122200E+02, 0.46802700E+02, 0.97014200E+02, 0.85611000E+01, 0.31177800E+01, 0.44526800E+02, 0.36879100E+00, 0.31409000E+01, -.71942600E+01, -.34785300E+01, 0.67521600E+01, -.10448500E+01, -.57154000E+01, 0.59709300E+01, 0.13591200E+01, 0.27351200E+01, 0.19901700E+01, 0.21447300E+01, 0.50941300E+01, -.46491300E+01, -.73417900E+01, 0.30389600E+01, 0.46374400E+01, -.18961900E+01, 0.49346900E+01, 0.52629400E+01, -.37411900E+01, -.17986800E+01, 0.11505700E+01, -.12330100E+01, 0.29130000E+02, 0.21761400E+02 },
        { 0.92063400E-01, 0.25202600E+00, 0.64057300E+00, -.55768900E-01, -.45603400E+00, -.91589600E-01, -.32155100E+00, 0.51930900E+00, -.58757200E-02, -.18161900E+00, 0.86291700E-01, 0.69061100E+00, -.73147800E-01, 0.13693300E+00, 0.42249700E+00, 0.10781900E+00, 0.51015100E+00, -.83227200E-01, -.83670600E-01, 0.13366300E+00, 0.18894500E-01, 0.61106100E-01, -.54901800E-02, 0.11007500E+00, 0.13622000E+00, 0.66972300E-01, 0.74913000E-01, 0.85176300E-01, -.69257700E-01, -.10587300E+00, 0.93199800E-03, 0.11862400E-01, 0.14210900E+00, -.96321000E-01, -.31268900E-01, -.44206300E-01, 0.60116200E-02, -.63469100E-01, 0.14835700E-01, -.61905300E-01, 0.51358800E-01, 0.31838500E+00, 0.23627600E+00, -.71177500E-02, -.94707800E-01, 0.16101200E-01, 0.13584400E-01, -.14199300E-02, 0.36286700E-02, -.11859400E-01, -.26483700E-01, -.12111700E+00, -.14595700E+00, -.60416800E-01, 0.43050500E-01, -.14438800E+00, -.11260500E+00, 0.16515500E+00, 0.24471600E-01, 0.42502400E-02, -.14656700E+00, 0.49932100E-01, -.26799000E-01, 0.11402200E+00, 0.72510500E-02, 0.39920500E-01, -.29108400E-01, -.12244000E+00, 0.65188100E-01, 0.43829300E-03, 0.10978200E+00, 0.11434300E+00, -.44000100E-01, -.47803100E-02, 0.38182400E-01, -.73347700E-01, -.31936400E-01, 0.29341600E-01, -.22816700E-01, 0.47455800E-01, 0.27430000E-02, -.22336900E-01, 0.20368500E-02, 0.25149600E-01, 0.29593700E-01, 0.53093400E-01, -.35514600E-01, -.11672000E+00, -.14971400E+00, -.60741800E-02, 0.15513600E+00, 0.54847900E-01, -.72615600E-01, -.20505400E+00, 0.57568600E-01, 0.40858400E+00, -.18020600E-01, 0.67875900E-01, -.10147900E-01, -.69012200E-02, 0.36013200E+00, -.15644900E+00, -.90048900E-02, 0.23206800E+00, 0.85407600E-01, 0.20419200E+00, -.56615600E-01, 0.66597700E-01, -.12471800E+00, 0.14235600E+00, 0.13758500E+00, 0.10341300E+00, 0.45995400E-01, 0.19501500E-02, -.35855200E-02, 0.32013700E-01, 0.35384300E-01, -.11690400E+00, 0.34334600E-01, -.30545800E-02, 0.59150400E-01, 0.45833600E-02, -.13553300E-01, 0.33519800E-01, -.59218100E-02, -.65935900E-01, -.16754400E+00, 0.12876200E+00, 0.23529600E-02, -.51303300E-01, 0.79294100E-01, 0.91765500E-01, 0.16660800E-03, 0.24714600E-01, 0.61022200E-01, 0.29443300E-02, 0.42613800E-01, 0.48895900E-01, 0.37559700E-01, 0.10410800E+00, -.24990100E-01, -.76245100E-01, -.39604700E-01, -.15329900E+00, -.16039700E+00, -.28689000E-01, -.14175000E-01, -.58090600E-01, -.20519100E-01, 0.50851500E-01, 0.50948000E-01, -.52360400E-01, -.50088300E-01, 0.14382700E+00, 0.21235600E+00, -.42723400E-01, 0.86012100E-01, 0.20855400E-02, 0.79020000E-01, -.31003400E-02, 0.13716000E-01, 0.69427500E-01, -.45966900E-02, 0.36417900E-02, 0.19418900E-01, 0.37322200E-01, 0.28560700E-02, -.29383600E-01, -.27361500E-02, 0.12897900E+00, 0.31700000E-01, -.27894100E-01, 0.65035300E-01, 0.14801900E+00, 0.31647300E-01, 0.16701800E+00, 0.24669800E-01, -.11516000E-01, 0.56384100E-01, 0.21683100E-03, 0.36823600E-01, 0.18035500E+00, 0.24378700E+00, -.40853600E-01, -.14531400E+00, -.80420600E-01, -.23630900E+00, -.19566200E-01, 0.10245300E-01, -.49372500E-01, 0.45352500E-03, 0.71790500E-01, -.70420200E-01, -.15694900E-01, 0.46608100E+00, 0.21189300E+00, 0.41554300E+00, 0.45780300E-03, -.15636200E+00, 0.31076000E-02, 0.11972400E-01, -.28599000E-01, 0.10143200E+00, -.21079000E+01, 0.94123000E-02, 0.15098400E+00, -.17098000E+00, 0.22655300E-01, -.13368400E-01, -.37902100E+00, -.45496500E-01, 0.11478700E+00, 0.17826600E-02, -.70042400E+00, 0.24895600E+00, 0.80837400E-01, 0.29643000E-01, -.12779600E+00, 0.41011500E-01, -.25114900E-01, -.50930100E+00, -.16339400E-01, -.20420500E+00, -.40121100E-02, -.53237800E+01, 0.94198600E+00, 0.46060100E+01, -.60042100E+01, -.87302600E+01, 0.52496000E+00, 0.14830700E+02, 0.64301500E+00, -.41607700E+00, -.15003100E-01, -.32142800E+00, -.17286500E+00, 0.70625300E-01, -.31107700E+00, -.14540700E+00, -.61382300E+00, 0.56410800E-01, -.43970000E+00, 0.95253900E+01, -.53433500E+01, -.37266100E+01, -.48232900E+01, -.28881900E+00, -.66219500E+01, -.81166400E+00, 0.44458700E+01, 0.23194200E+01, -.55344100E+01, -.56945400E+01, 0.70476700E+01, -.16343200E+01, -.20031200E+02, -.35227800E+01, -.11134900E+02, -.71494100E+00, -.42646600E+01, -.26118800E+01, -.26433200E+01, 0.13868400E+01, 0.12694000E+02, 0.47248200E+01, -.35872400E+01, -.36378300E+00, -.23628100E+01, 0.12517000E+01, 0.21209400E+00, -.36873400E+01, 0.14278600E+02, -.32725600E+01, -.34201500E+01, -.54931500E+01, -.24511200E+00, -.19087400E+00, -.65645000E+00, -.31593200E+00, -.38227400E+00, -.36823500E+00, 0.85965400E-01, -.42855100E+00, 0.22521700E+00, 0.15521300E+00, -.40155400E+00, -.76802400E+00, 0.56611800E+00, 0.61557000E+00, 0.96705800E+00, -.94584400E-01, 0.30235800E+00, 0.14185100E+00, -.26069600E+00, 0.35043500E+00, -.97807000E-01, -.48719800E+00, 0.69039300E-01, 0.52946700E-01, -.87218800E+00, -.79224200E+00 },
        { -.93430300E+00, 0.15024400E+01, -.56051500E+01, 0.53829200E+00, 0.46259900E+01, 0.80954600E+00, 0.65695700E+01, 0.13679400E+01, 0.74469000E-01, 0.27258600E+00, 0.10483200E+00, -.51058800E+01, 0.11824200E+01, -.52076700E+00, -.23676400E+00, -.10284900E+01, -.68889200E+01, 0.84329100E+00, -.20469600E+01, 0.14170900E+01, -.17451400E+01, -.18267800E+01, 0.40233200E+00, -.21365600E+01, -.11904300E+01, -.19543300E+00, -.21210900E+01, 0.66928200E+00, -.19947500E-01, 0.80738700E+00, 0.55549400E+00, 0.65487900E+00, -.15656300E+01, -.27511700E+00, 0.68423000E+00, 0.38042600E-01, -.20402800E+00, 0.16184400E+01, 0.13469700E+01, 0.37530000E+00, 0.79520000E+00, -.19629800E+01, -.37479000E+01, -.98138200E+00, 0.14012200E+01, 0.17726000E+01, 0.45322600E+01, -.27849400E+00, 0.10346100E+00, 0.11139900E+01, 0.86748300E+00, 0.70471400E+00, -.13911400E+01, -.86448300E+00, 0.11080000E+01, 0.24919400E+00, 0.29419900E+00, -.27965400E+01, 0.13473400E+01, -.20018000E+01, 0.19384100E+01, 0.83058900E-01, 0.75971000E+00, 0.87423500E-01, -.32064700E+00, 0.45023800E-01, -.26394300E+00, -.46863300E-01, 0.47862100E+00, 0.17516100E-01, -.20242600E+01, 0.13421800E+01, -.40797200E-01, 0.32035700E-01, 0.11073300E+01, -.35879500E+00, 0.21935800E+00, -.46025200E+00, -.28166700E+00, 0.94982200E+00, 0.11232700E-02, -.70213400E-01, -.95136400E+00, 0.35837500E+00, -.91322100E-01, -.50628700E-01, 0.12069200E+00, -.18646100E+01, -.35489600E+00, 0.77847800E-01, -.60492000E+00, -.26534200E+00, 0.56481000E+00, 0.22122400E+01, -.22785900E+00, -.16816900E+01, -.37832100E+00, 0.71362100E+00, 0.51638700E+00, 0.98574200E+00, -.36476800E+01, 0.15570800E+01, -.72752200E+00, -.10534800E+01, -.10005200E+01, 0.24149400E+01, 0.14794300E+01, -.16931300E-01, -.21467400E+01, 0.14245700E+01, -.10085800E+01, -.17702400E+01, 0.56455900E+00, -.10206200E+00, 0.25203000E+00, 0.78864100E+00, -.29426400E+00, 0.12905900E+01, -.55704200E+00, 0.24935600E+00, -.75467200E+00, -.61825500E+00, 0.33914700E+00, -.61134800E+00, 0.15567400E+00, -.14145000E+00, 0.14106600E+01, 0.53273100E+00, 0.56823100E-01, 0.58628700E+00, -.12344400E+00, -.24505700E+01, 0.45416800E+00, 0.24316800E+00, 0.55469200E+00, 0.23755800E-01, 0.21199100E+01, -.27789800E+00, 0.20739600E+00, 0.50805400E+00, 0.42327200E-01, -.19100700E+01, 0.43800600E-01, -.10249500E+01, -.39518900E+00, 0.28835800E-01, 0.57343000E+00, -.23098200E+01, -.24556700E+01, -.22915500E+00, 0.47345300E+00, -.46041900E+00, -.10925000E+01, 0.11435900E+01, 0.21113200E+01, -.17125500E+00, -.32989500E+00, -.39907600E+00, 0.42736800E+00, -.73944700E+00, 0.11915500E-01, 0.22727900E+01, -.10978700E+00, 0.41244100E+00, -.56594100E+00, -.28935600E+01, 0.60578800E-01, 0.28148100E+00, 0.20424800E+00, -.19326700E+01, -.46379700E+00, -.11956900E+01, -.33962500E+00, 0.37048700E+01, 0.60010000E-01, 0.20338200E+01, 0.12294100E+01, -.31314200E+00, -.11558400E+02, 0.17576700E+00, 0.10946200E+01, 0.13879500E+01, 0.18296100E+01, -.43105100E+00, -.18231100E+01, -.90975100E+00, -.52627300E+00, -.14859600E+01, -.23700900E+00, 0.19333100E+00, 0.90076500E-01, 0.97925700E-01, 0.67663200E+00, 0.12909900E+01, -.38237000E+01, 0.10138900E+00, 0.42316400E+01, 0.14827600E+01, -.17975500E+01, -.14535300E-01, -.23147900E+00, -.82132500E+00, 0.14914300E+01, -.13748800E+02, 0.24006500E+00, 0.21301000E+01, -.16140100E+00, 0.94792800E-01, -.30581400E+00, 0.39250200E+01, -.24861900E+00, 0.37126600E+01, 0.27941100E-01, -.35434600E+01, 0.12740300E+01, -.31032000E-01, 0.61104700E+00, -.48971700E+00, -.26498500E-01, 0.53586200E+00, -.20020900E+01, -.93919800E-01, -.67954100E+01, -.54582800E+00, -.45787800E+00, 0.48081600E+02, -.16408600E+03, -.24327100E+03, -.19267200E+03, 0.64818700E+02, -.73602600E+01, 0.15519900E+01, -.37204600E+01, -.32146100E+01, -.51874500E+00, -.97018300E-01, -.41384000E-03, 0.13382400E+01, 0.74742300E+01, -.35213800E+00, -.45383300E+00, 0.77509700E+01, 0.32057700E+03, -.18578400E+03, -.23997000E+03, -.16186100E+03, -.29766600E+02, -.88296100E+02, 0.26838600E+02, 0.15886100E+03, 0.79829600E+02, -.76619800E+02, -.16355500E+03, -.14316600E+03, 0.11119800E+03, 0.15596200E+03, 0.72031500E+02, 0.26589500E+03, -.38702200E+02, 0.27470100E+02, 0.47221800E+02, 0.64008600E+02, -.54848600E+02, -.11281100E+03, 0.32464100E+03, -.18858900E+03, -.23692900E+03, -.16279800E+03, -.12715500E+03, 0.23019300E+02, -.92073600E+02, -.64577900E+01, -.77303400E+02, 0.25993400E+02, 0.15693300E+03, 0.88392700E+00, 0.13803600E+02, -.16730400E+02, -.94151400E+01, 0.90389600E+01, -.27622000E+01, -.93099900E+01, 0.12603900E+02, 0.16304800E+01, 0.36172300E+01, 0.42048800E+01, 0.26569600E+01, 0.18814700E+02, -.89949500E+01, -.13656500E+02, 0.67568300E+01, 0.48693800E+01, -.33325500E+01, 0.16400200E+00, 0.11719500E+02, -.15341800E+01, -.30397700E+01, 0.18074500E+01, -.14399900E+01, 0.19373100E+02, 0.13995200E+02 },
        { 0.49765300E+00, -.12542500E+01, 0.35265900E+01, 0.76155900E+00, -.13241200E+01, -.49155800E+00, -.41919400E+01, -.39121800E+01, -.11515700E+01, 0.10016600E+00, -.11646200E+00, 0.26283200E+01, -.45764800E+00, 0.13184200E+01, 0.13755500E+01, -.11651700E+00, 0.21320500E+01, -.61823100E+00, 0.18672100E+01, -.93350000E+00, 0.17374200E+01, 0.46232200E+01, 0.14110100E+00, 0.18295500E+01, 0.85894200E+00, 0.60128000E+00, 0.10396000E+01, -.60113200E+00, 0.76484300E+00, 0.37346500E-01, -.16106400E+00, -.32675600E+00, -.13420300E+01, 0.99002600E-01, 0.11442100E+01, -.90100800E+00, -.29167400E-03, -.45117500E+00, 0.10046700E+01, -.55620500E+00, 0.13347000E+01, 0.51022000E+01, -.66299300E+00, -.83453800E+00, -.12112900E+00, 0.35628700E+00, 0.25858100E+01, -.77168600E-01, -.16120000E+01, 0.46962700E+00, 0.73992500E+00, 0.49595700E+00, 0.78341200E-01, 0.93290900E+00, -.21544700E+00, 0.18833700E+00, 0.67241500E+00, -.72085800E-01, -.25894700E+00, 0.27454500E+00, 0.11889300E+00, 0.10465700E+00, 0.20430900E+00, 0.80313600E-01, 0.81718500E-01, -.13436000E+00, 0.56010300E-01, -.32239300E+00, 0.12526100E+00, 0.64811300E-02, -.32871000E+00, 0.38195100E+00, -.14710300E+00, -.10726400E+00, 0.35512600E+00, -.35396100E+00, 0.21750400E+00, -.15391200E+00, -.37261100E+00, -.19390100E+00, -.20142500E-01, -.71138100E-01, 0.31503600E+00, -.16240700E+00, -.27071900E+00, -.45951400E+00, 0.19713300E-01, 0.18119500E+01, 0.89031200E+00, 0.36529800E+00, -.20159800E-01, -.54155600E+00, 0.38469400E+00, 0.13036300E+01, -.68573300E+00, 0.17955800E+00, 0.63059500E+00, -.36134900E+00, 0.58962000E+00, -.12217000E-01, -.40800400E+00, 0.71826700E-01, 0.27114900E-01, -.38169500E+00, -.38709500E+00, -.62931900E-03, -.20346400E-01, 0.49513000E+00, -.14295000E+01, -.22826900E-01, -.12640100E+00, -.30546600E+00, -.21947000E+00, -.12720500E+00, -.32988300E+00, 0.16267700E+00, 0.31219600E+00, 0.26126600E+01, -.29119900E-01, 0.24193000E+00, -.82442600E-01, 0.43780600E+00, -.39926300E-02, 0.57641600E+00, 0.41260400E-01, 0.14186800E+01, -.24162900E+00, 0.37258100E+00, 0.19018700E+00, -.84685100E-01, 0.90258800E-02, 0.60683800E-01, 0.44694000E-01, -.86379800E-01, 0.34861300E+00, 0.17611900E-01, 0.10516300E+01, 0.54187800E+00, 0.14799500E+00, 0.13572700E+01, -.27170000E+00, -.25145600E+01, -.61197700E+00, -.19130300E+00, -.44477300E-01, -.45153100E-01, 0.15369400E+00, -.12584500E+01, -.15582000E+00, 0.44370300E+00, -.13024000E+01, 0.70850400E+00, -.51544300E+00, -.76329600E+00, 0.83217400E+00, -.24290100E+00, 0.10744400E+01, -.93800900E-02, 0.47935200E+00, 0.18547500E-01, 0.65590600E+00, 0.23211300E+01, 0.26786600E+00, -.95316000E-01, -.59986500E+00, -.29943900E-01, -.33782000E+00, 0.29268200E+00, 0.20916900E-01, -.31466000E+00, 0.14174600E+01, 0.13133200E+01, 0.14437600E+00, 0.80301100E+00, -.12929100E+00, -.55608400E+00, -.93692800E-01, 0.27331500E-01, 0.11535200E+01, -.17384800E-02, -.33700700E+00, -.11319800E+00, -.15199700E+00, -.14534500E-01, -.82623400E+00, -.75410100E+00, 0.30871400E+01, 0.43752500E+00, 0.75006400E-01, -.13678100E+00, -.12086600E-02, -.85295200E+00, -.24119200E+00, 0.12329400E+01, 0.26345700E+01, 0.14014600E+00, 0.10154800E+01, -.56413300E+00, -.32650700E+00, -.24362800E+00, 0.10093900E+01, 0.11615200E+00, -.19320400E+01, -.82729600E+01, 0.24715100E+00, -.44207800E+00, 0.39096600E+00, -.21121800E+00, -.29737700E-01, -.31655500E+00, -.73234700E-01, 0.15104800E+01, -.50152400E-02, 0.31904900E+01, 0.11589100E+01, 0.85166700E+00, 0.39561600E-01, 0.67310400E+00, 0.35308700E+00, -.25365500E+00, 0.17391300E+01, 0.63765700E-01, -.53878500E+01, 0.19780300E+00, -.27642900E+01, 0.43504700E+00, 0.57602000E+02, 0.78281700E+02, 0.53234600E+02, -.62067100E+01, -.39733900E+01, 0.29693000E+01, -.92428600E+00, -.13138800E+01, -.15496000E+01, -.33575400E+00, -.64057300E+00, -.17782100E+00, -.14828000E+01, -.89378000E+00, -.68248200E+00, -.23317700E+01, 0.98561900E+01, -.29566100E+01, 0.91048900E+01, -.39711300E+01, 0.49029000E+01, 0.26700300E+02, -.77853900E+00, 0.35844100E+02, -.63787000E+00, 0.19989600E+02, -.11736200E+02, -.19567400E+03, 0.91696700E+02, 0.12181200E+03, 0.97524700E+02, 0.93701600E+00, 0.92744000E+02, -.19466400E+02, -.86458400E+02, 0.98635700E+01, 0.85404800E+02, 0.16315700E+03, 0.13526700E+01, 0.40227900E+01, 0.26394100E+02, -.32406800E+00, -.82204800E+01, -.90180500E+01, 0.20674800E+02, 0.24271800E+02, -.75082800E+01, 0.22256000E+01, -.11749600E+03, -.34472200E+01, 0.80715400E+00, -.86857300E+00, 0.47847900E+01, -.25079400E-01, -.86593800E+00, 0.71507400E+00, 0.12959400E+01, -.41440600E+00, 0.15817800E+01, -.14090900E+01, -.17310000E+01, -.68798300E+01, 0.68479400E+00, -.86849500E+00, -.31216200E+01, 0.20979900E+01, 0.15897600E+01, 0.73303300E+01, -.23586000E+01, -.55876800E+01, -.26479200E+01, -.90412300E+00, -.33627800E+01, -.22077600E+01, -.73889100E+01 },
        { -.59070600E+00, 0.12833200E+01, -.53014400E+01, -.82268900E+00, 0.16665000E+01, 0.61770700E+00, 0.18724900E+01, -.16877100E+01, -.76338200E+00, 0.13895300E+00, 0.79097200E+00, 0.20761700E+00, 0.51721500E+00, 0.47217200E+00, -.17171700E+00, 0.17633900E+00, -.76519600E+00, 0.27785400E+00, -.45348800E-01, 0.32178500E+00, -.11213400E+01, -.16753900E+01, 0.12023200E+00, -.45202100E+00, -.48773900E+00, 0.32511400E-01, -.48088800E+00, 0.14791000E+01, -.14720900E-01, 0.71735800E-02, 0.62264600E+00, -.23782600E+00, -.69106700E+00, 0.12084200E+01, 0.27389100E+00, -.75012200E-01, -.51394700E-01, 0.10490600E+01, 0.11581700E+01, -.32834800E+00, -.42093300E+00, -.43471000E+01, -.32866300E+01, -.53116700E+00, 0.97680700E+00, 0.56156700E+00, 0.18849800E+01, -.10043900E+00, 0.24010000E+00, 0.24880700E+00, -.11199800E+01, 0.19816300E+01, 0.44537900E+00, -.20676900E-01, -.17245300E+01, 0.12649900E+01, -.31088300E+00, 0.95224900E+00, 0.87393700E-01, -.75899500E-01, 0.19381800E+00, -.30354200E+00, -.12391300E+00, 0.70115600E-01, -.11448100E+00, 0.40740000E+00, 0.20682500E+00, 0.16432100E+01, -.73523700E+00, -.24788000E-02, -.11425700E+01, -.16988700E+01, 0.85687900E-01, -.13524600E+00, 0.74069700E+00, -.27591600E+00, -.62235800E+00, -.97190500E-01, -.96410500E-01, 0.59772400E+00, 0.54808000E-01, -.59423300E-01, -.59695800E+00, 0.47218100E+00, -.12402400E+00, 0.38036600E+00, 0.58261800E+00, -.55443700E+00, 0.15796700E+01, 0.12591300E+00, 0.78904900E+00, 0.62447400E+00, 0.34247700E+00, -.35907600E+01, 0.17448800E+00, 0.65954300E+00, 0.89244900E+00, -.50918800E-01, -.19237500E-01, -.51641100E+00, 0.32516700E+01, -.96740600E+00, -.69479500E-01, 0.38042100E+00, 0.10187700E+00, 0.10149900E+01, 0.31016400E+00, 0.28820200E+00, -.25405800E+00, -.18687900E+01, 0.15910700E+00, 0.11336900E+01, -.34192600E+00, 0.93051500E-01, 0.11025500E-01, 0.38662500E-01, -.16686600E-01, -.95275800E+00, -.19182100E+01, -.50967500E-02, -.39932500E+00, 0.14223400E+01, -.95449900E-01, 0.10025800E+01, 0.68873300E-01, 0.75116100E+00, 0.11649500E+01, 0.40293300E-03, 0.16930800E+00, 0.30046300E+00, -.67200300E+00, -.28487100E+00, 0.11394700E+00, -.19103800E-01, -.13012300E-01, 0.15623800E-01, -.46402900E-01, -.32101200E+00, -.19504700E+00, -.67540900E-01, 0.70131200E-01, 0.17966500E+00, 0.75664100E-01, 0.10621300E+01, 0.12629700E+01, 0.50988300E+00, 0.62319900E-01, -.29046700E+00, 0.33516500E+00, -.31257200E+00, -.92605000E-01, 0.24471600E+00, -.47101800E+00, -.20577500E+01, 0.11305700E+01, 0.27512100E+00, 0.10450600E+01, -.42467500E-01, 0.12070700E+00, 0.47446300E-01, -.35281100E+00, 0.10327000E+01, 0.20768900E+00, -.92185500E-01, -.27947900E+00, 0.32186600E+00, -.38552700E-01, 0.36804400E-01, 0.33386600E-01, -.64837000E+00, -.29338400E+00, -.19212100E+00, 0.17712500E+00, -.92822800E-01, -.25920600E-01, -.79702500E+00, -.94412700E-01, 0.29679300E-01, 0.12144300E+01, -.17204400E-02, -.46819000E+00, -.10773400E+01, -.19675500E+01, 0.37636500E-01, -.13150300E+00, -.12251000E+00, 0.29661400E+01, 0.44537800E+00, 0.20562400E+00, 0.36572900E+00, 0.42903700E-02, 0.92431400E-01, -.30922900E+00, 0.33495600E+00, 0.18577700E+01, 0.13044000E+01, 0.21796300E+01, -.62283200E+00, -.10384800E+00, -.99326400E-01, 0.42728700E+00, -.19920900E-01, 0.32094700E+01, -.32641400E+01, -.43035600E-01, -.67965900E-01, -.18863100E+00, 0.24765800E+01, -.17564800E+00, -.17731300E+01, 0.10612300E+00, -.12780400E+01, 0.78529800E-02, 0.40425000E+01, 0.12265800E+01, 0.29168700E+00, -.14242400E+00, -.54464400E+00, 0.27475500E+00, 0.15804800E+00, -.28096100E+01, 0.27570900E+00, 0.15737000E+01, 0.62488000E-01, 0.63286500E+00, -.17416200E+00, 0.57435100E+00, -.77897500E+02, -.62915500E+02, 0.13841300E+02, 0.53360400E+02, 0.75986500E+00, -.50472700E+00, 0.12247600E+01, -.28198900E+00, -.73297900E+00, 0.47417800E+00, -.74753600E+00, -.53894000E+00, 0.46638000E+00, 0.13618900E+01, -.50125200E+00, 0.26417000E+03, -.12398600E+03, -.11338100E+03, -.13265400E+03, -.17265300E+02, -.53051200E+02, -.75580200E+02, -.14090100E+02, -.50875400E+02, -.45492500E+02, -.61773600E+02, 0.20615400E+03, -.99154400E+02, -.21212800E+03, -.10285800E+03, -.17398100E+03, -.17215800E+03, 0.76554800E+02, 0.11095900E+03, 0.43446300E+02, -.13651900E+03, -.35563000E+02, -.28640700E+02, 0.12301400E+02, 0.90823000E+00, 0.14079400E+02, 0.52692000E+02, 0.49659900E+02, -.96116700E+02, -.71421500E+02, -.43338500E+02, 0.82127000E+01, 0.53077100E+02, 0.68185900E+00, -.10660900E+01, 0.30970500E+01, -.20712700E+01, -.47519400E+01, -.68268000E+00, 0.34236400E+01, -.40913400E+01, -.83316900E-01, -.15718400E+01, -.28644200E+00, -.30247500E+01, 0.84929700E+01, 0.21092000E+01, 0.77915100E+01, 0.26999800E-01, -.41000100E+01, -.63907900E+00, -.78498900E+01, 0.81728100E+00, 0.60618900E+01, 0.84278700E+00, -.16749600E+00, 0.11095500E+02, -.14461400E+02, -.55875200E+01 },
        { 0.94639200E+00, 0.95133300E+00, 0.37298900E+01, 0.99080100E+00, -.33667900E+01, 0.31838300E-01, -.19183800E+01, 0.50023200E+00, 0.14223600E+01, 0.33945000E+00, -.61321500E+00, 0.26394900E+01, -.94350200E+00, -.25035500E+00, 0.32298900E+01, 0.12420200E+01, 0.21363900E+01, -.30401100E+00, -.10527200E+01, 0.58937000E+00, -.84666400E+00, -.39213200E+01, -.32850000E+00, 0.12810000E+01, 0.58247300E-01, 0.99885800E+00, 0.63912600E+00, 0.83122500E+00, -.42545200E+00, -.90742100E+00, 0.13983700E+01, 0.33809900E-01, 0.14961200E+01, 0.51993500E+00, 0.53874800E-01, -.77780300E+00, 0.67047300E-01, 0.66890600E+00, 0.65734000E+00, -.13724800E+01, -.14640100E+01, -.72610100E+01, -.52801200E+01, -.86790200E+00, 0.32771100E+01, -.30828800E+00, 0.21207800E-01, 0.11706900E+00, 0.92565000E+00, -.10280100E+01, 0.90914900E+00, 0.13980000E+01, 0.21356300E+01, -.13649300E+01, -.24105000E+01, -.23578600E+01, 0.77411800E+00, -.82572200E+00, -.12729900E+00, -.20643300E+01, 0.54041100E+00, 0.43086600E+00, -.12450000E+00, -.20039000E+00, 0.11543400E+00, -.16221500E+01, 0.91786900E-01, -.12394500E+01, 0.99760800E+00, -.12058200E+00, 0.65065900E+00, 0.21405100E+01, -.65725900E+00, -.82680100E-01, -.26158500E+00, -.67077200E+00, 0.22239300E+00, -.31529100E+00, -.27837000E+00, 0.57030000E+00, 0.23555600E-01, -.13068900E+00, -.31519100E+00, 0.24298200E+00, -.24287600E+00, 0.79570100E+00, -.15209000E+01, -.23914400E+01, -.78068600E+00, 0.10263900E+01, -.10576100E+01, 0.33208900E+00, 0.10584500E+01, -.13345900E+01, -.14334600E+00, -.18268200E+01, -.73929600E-01, 0.49521900E+00, -.21465400E+00, -.41897100E+00, 0.36656800E+01, 0.94720500E-01, -.10242000E+00, -.47383900E+00, -.90953200E+00, 0.25118400E+01, 0.10739200E+01, 0.15389000E+01, -.11433100E+01, -.24751400E+01, -.28687700E+00, 0.11993900E+01, -.11127200E+01, 0.13429400E+00, -.32815300E+00, -.10845400E+01, 0.10696200E+00, 0.35324900E+01, 0.11536700E+01, 0.20627800E+00, -.87538800E-01, 0.51382100E+00, -.67389000E-01, -.16445800E+01, -.18409800E+00, 0.28763300E+01, -.11009800E+01, 0.31379000E+00, 0.25845000E+00, 0.12013800E+00, 0.36084900E+00, 0.13786300E+01, -.29670700E+00, 0.44812600E+00, -.42713200E+00, -.14058700E-01, -.13471500E+01, 0.86491200E-01, -.24792400E+00, 0.73123500E+00, -.50199900E+00, 0.14743700E-01, 0.13271500E+00, 0.79822900E+00, 0.48145300E+00, -.66771600E+00, 0.39772300E+00, -.89136800E+00, -.33011500E+00, -.28731300E+00, -.11764600E+01, 0.72725400E+00, -.74359200E+00, -.26780800E+01, 0.10729100E+01, -.17233900E+00, 0.67442100E+00, -.20748100E-01, 0.55290600E+00, 0.47418100E+00, 0.51206700E+00, 0.37079100E+01, 0.70547600E+00, -.19989800E-02, -.16571900E+00, -.10043100E+01, -.36283900E+00, -.12352000E+01, -.92671400E-01, 0.70960300E+00, -.50604600E+00, -.10462500E+01, 0.75480900E+00, 0.40057200E+00, 0.32964200E+00, -.30704500E+01, -.44683700E-01, 0.88489700E-01, 0.39760500E+01, -.47554000E-02, -.86503800E+00, -.67155200E+00, -.23478200E+01, 0.34764300E+00, 0.12284000E+01, -.65855900E+00, 0.31008800E+01, 0.33703600E+00, -.15498000E+00, -.35803600E+00, -.41055300E-02, -.10838500E+01, 0.29867000E+00, 0.10096900E+01, 0.11641800E+01, 0.25955700E-01, -.57778100E+00, -.93874500E+00, 0.15218800E+01, -.80184100E-02, 0.34269000E+00, 0.19746400E+00, 0.34067800E+01, 0.10207100E+02, 0.59627100E+00, -.40010400E+00, 0.12535500E+01, 0.23923500E+01, 0.14068500E+00, 0.20761800E+01, 0.19529800E+00, -.22285500E+01, -.22624300E-01, 0.44214100E+00, -.38146800E+00, -.36064700E+00, -.36733500E+00, 0.20476400E+00, -.12492700E+00, 0.63226000E+00, 0.31784200E+01, 0.97753400E-01, -.22265900E+01, 0.15138200E+00, -.36298800E+01, 0.21813700E+00, 0.10783300E+01, 0.70246900E+00, -.49155100E+02, 0.45131600E+01, 0.10433700E+02, -.86151800E+00, 0.29722200E+00, -.84809300E+00, 0.41426400E+00, 0.17129800E+01, 0.25902700E+00, -.66557500E+00, 0.46956700E-01, -.26064400E+01, -.20727800E+01, 0.12569100E+00, -.54191900E+03, 0.26395300E+03, 0.24168300E+03, 0.27137400E+03, 0.22160000E+02, 0.28732800E+02, 0.14789700E+03, -.29924200E+02, 0.86846700E+02, 0.32989900E+02, 0.13068000E+03, 0.13883500E+03, -.72665900E+02, -.13847800E+02, -.69426600E+02, 0.16058900E+03, 0.42184300E+02, -.15751700E+03, -.67343900E+02, -.11381100E+03, 0.62121700E+02, -.16921800E+03, -.17977000E+03, 0.90320900E+02, 0.47061300E+02, 0.89901600E+02, 0.14606500E+02, 0.19560700E+02, 0.15301200E+03, 0.11355100E+03, 0.63634500E+02, 0.11898600E+02, 0.15652800E+03, 0.41091600E+00, 0.11169200E+02, 0.66476200E+00, -.31002500E+01, 0.66692000E+01, 0.12973500E+00, -.91110100E+01, 0.95268900E+01, 0.14183200E+01, -.10434200E+01, 0.11973100E+01, 0.24325800E+01, -.34626500E+01, -.19803700E+01, -.11480300E+02, 0.59480700E+00, 0.13439600E+01, 0.16176700E+01, -.55177100E+01, 0.43129000E+01, 0.11446400E+01, 0.15589300E+01, 0.13635900E+01, -.14501600E+02, 0.10946100E+02, 0.55909500E+01 },
        { 0.50945200E+00, 0.39514100E+01, 0.17180200E+01, 0.15780600E+00, -.29134300E+01, -.10101500E+01, -.37308800E+01, 0.24682300E-02, -.26284900E+00, -.35787200E+00, 0.93013400E+00, 0.24097800E+01, -.61047200E+00, 0.30045600E+00, 0.26307700E+01, 0.95531500E+00, 0.32834300E+01, -.35808500E+00, -.97680200E-01, 0.85304100E+00, -.28894800E+00, -.14146900E+01, 0.13893300E+00, 0.17447500E+01, 0.35719300E+00, 0.45628900E+00, 0.82101400E+00, -.18525300E+00, -.62017400E+00, -.50817300E+00, -.19476300E+00, -.30301000E+00, 0.26440200E+01, 0.12344800E+00, -.13396800E+00, -.89441400E-01, 0.12238900E+00, 0.51285700E+00, 0.72841400E+00, -.11196500E+01, -.10663100E+01, -.39685600E+01, -.67492400E-01, 0.64989300E+00, 0.12459800E+01, 0.61179500E+00, 0.10441000E+01, 0.12954800E+00, 0.16723700E+00, 0.65923700E+00, -.55580300E-01, 0.21181000E+01, 0.74772700E+00, 0.37028100E+00, -.52279700E+00, -.66626900E+00, -.24265200E+00, -.11187700E+00, -.73522300E-01, -.16124400E+01, 0.12061600E+01, 0.40663900E+00, -.49560500E-02, -.10533500E+00, -.31569600E+00, -.77676200E+00, -.46922300E+00, -.85303500E+00, 0.14513300E+01, 0.40113800E-02, -.36071300E+00, 0.49503700E+00, -.29571800E+00, 0.44731600E-02, -.28639600E+00, -.97650400E-01, -.28987200E+00, -.50331000E+00, -.39370800E+00, 0.24665000E+00, 0.25007400E-01, -.70345700E-01, -.15091800E+01, -.90906400E-01, -.28368800E+00, 0.93638700E-01, 0.61266500E+00, 0.68612900E+00, 0.18510200E+01, -.19896200E+00, -.93930000E+00, -.13059800E+00, -.19985200E+00, 0.16453900E+01, 0.11344500E+01, 0.13515800E+01, -.20827600E-01, -.48965900E+00, 0.10384100E+01, 0.93887300E+00, -.70252000E+01, 0.33809300E+00, 0.50759400E-01, -.90325200E-01, 0.14646700E+00, 0.38782700E+00, 0.28865000E+00, 0.75689400E-01, 0.26666000E+00, 0.91270000E+00, 0.17898300E+01, -.63907200E+00, 0.51385600E+00, 0.58743100E-01, 0.15985400E+00, 0.47053800E+00, 0.20707800E+00, 0.11289000E+01, -.89235000E-01, 0.75343800E-01, -.17810600E+00, 0.86275900E+00, 0.40496400E+00, 0.62162600E+00, -.17771000E+00, 0.77149600E+00, 0.60672200E+00, 0.83873800E+00, 0.71958000E-01, -.75548000E-01, 0.92831200E+00, 0.89277400E+00, -.66189700E-01, 0.20996600E-01, -.72699500E+00, -.17843900E-02, -.19783000E+01, 0.24002500E+00, 0.16728700E+00, 0.10487600E+00, 0.52156600E-01, 0.19294500E+01, -.30007100E+00, 0.10614100E+01, -.10827500E+01, -.35719100E+00, 0.43935700E-01, -.20706600E+00, 0.41808700E+00, -.89322800E+00, -.12162600E+01, 0.10019600E+01, -.10256500E+01, 0.63577000E+00, -.15091000E+00, -.23252300E+00, 0.61772800E+00, 0.15664400E+00, -.23824200E+00, -.16370000E+01, 0.16966200E+00, 0.13306100E+01, -.17790700E+00, 0.20748300E+00, -.64239600E+00, -.52666600E+00, -.60883300E-01, 0.43809000E+00, -.12230100E+00, 0.16994600E+00, 0.96651800E+00, -.72548100E+00, -.40877900E+00, 0.41134000E+01, -.19751000E+00, 0.57029700E+00, 0.29175900E+00, -.32034300E+00, -.97826200E+01, -.35443200E-02, 0.67272400E+00, 0.49471300E+00, -.33837500E+00, -.86017200E-01, -.86153200E+00, -.13189800E+01, 0.25918300E+01, -.18419300E+00, -.29653200E+00, -.15818500E+00, 0.16403900E-02, -.13227600E+01, 0.78517800E+00, 0.46582500E+00, -.35757800E+00, 0.66745700E+00, -.35705700E+00, -.20664900E+00, 0.69258300E+00, 0.89883000E-01, 0.14169800E+01, -.16212700E+00, 0.44262600E+01, -.11608500E+02, 0.42036900E+00, 0.69972700E+00, -.20938100E+00, 0.18406200E+00, 0.15958500E+00, -.11447000E+00, -.62677000E+00, -.77903000E+00, 0.51987700E-02, 0.57140100E+01, 0.20096600E+01, -.10044000E+01, -.26163000E+00, 0.10884600E+00, 0.22849900E+00, 0.30055500E+00, 0.27059200E+01, 0.41484200E+00, -.53963900E+00, 0.77625800E-02, -.35374700E+00, -.15133700E+00, -.52674000E+00, 0.32819300E+00, 0.44889300E+00, -.19012800E+02, -.57258600E+01, 0.16129600E+01, 0.50232100E-01, -.15561400E+01, -.82768200E+00, -.41109300E+00, 0.20887400E+00, -.13479600E+01, 0.20147900E+01, -.55172700E+00, 0.55010200E-01, 0.17783000E+01, 0.12756100E+03, -.61420400E+02, -.67516700E+02, -.63681000E+02, 0.16423300E+02, 0.44504000E+02, -.17508200E+02, 0.66880700E+02, -.13085200E+02, 0.31281200E+02, -.67330400E+02, -.22362100E+03, 0.88243500E+02, 0.25638000E+03, 0.11165000E+03, 0.10922500E+03, 0.13468500E+03, 0.36501000E+01, -.93895600E+02, 0.44260600E+01, 0.76849400E+02, 0.14685900E+03, 0.21844500E+03, -.90730800E+02, -.11446400E+03, -.10905100E+03, -.95305800E+02, -.49751300E+02, -.90936300E+02, 0.86757900E+02, -.23942300E+02, -.13212100E+02, -.14144200E+03, -.13237600E+01, -.11326500E+01, -.65252400E+01, 0.87009100E+00, 0.13237200E+01, -.21651700E+01, -.29394500E+01, 0.28576000E+01, 0.83148800E+00, 0.18938300E+01, -.25357900E+01, -.30031500E+00, 0.13944800E+00, -.29475100E+01, -.89475400E+00, 0.12924000E+01, 0.42286200E+01, -.12273600E+01, 0.64589300E+01, 0.93566200E+00, -.39939400E+01, 0.12031400E+01, 0.16140200E+00, -.33850600E+01, 0.17065800E+02, 0.29254400E+01 },
        { -.18209300E+01, 0.17631600E+01, -.16138900E+02, -.20955100E+01, 0.68865900E+01, 0.10933700E+01, 0.70843300E+01, 0.18558800E+01, 0.35443300E-01, 0.11324000E+01, -.33398300E+00, -.52143900E+01, 0.10527600E+01, -.37913200E-01, -.15876400E-01, -.85948300E+00, -.27345600E+01, 0.11050300E+01, 0.69529200E+01, -.34504800E+01, 0.26158700E+01, -.54334000E+01, 0.91884600E-01, 0.16579000E+01, -.10552500E+01, -.71392300E+00, -.16979100E+01, 0.67229400E+00, 0.21647200E+00, 0.11129900E+01, 0.17490800E+01, 0.17314000E+00, -.20796900E+01, -.27100500E+00, 0.15293200E+00, -.79198100E+00, -.47993700E-01, -.27456200E+01, -.70611900E+00, -.58282400E-01, 0.24888300E+01, -.13632500E+01, -.11992300E+00, 0.60594800E+00, -.23794000E+01, -.21881300E+01, -.53014700E+01, -.14588800E+00, -.68736800E+00, -.45188700E+00, -.65558800E+00, 0.54473000E+00, -.60933900E+00, 0.14916500E+02, 0.19994200E+01, 0.11852900E+01, -.23712500E+01, -.48580000E+00, 0.15820300E+00, 0.23961000E+01, 0.22955200E+00, -.54836200E+00, -.16851900E+00, -.43501800E+00, -.81165500E+00, -.96052000E+00, 0.34764700E+00, 0.42244200E+01, -.14607400E+01, -.14684500E-02, 0.17925000E+01, -.18281600E+01, -.37484200E+00, -.39171900E+00, 0.32687900E+00, -.49206200E+00, 0.53630000E+00, -.19567600E+00, -.64441900E+00, -.21639500E+01, -.78161400E-01, 0.40080900E+00, -.86662400E+00, 0.42887700E+00, 0.62574800E+00, -.10071400E+01, 0.21296000E+01, 0.60937300E+01, 0.16253600E+01, -.95119300E+00, -.24500200E+01, -.10101200E+01, -.81263200E+00, 0.54903500E+01, -.14667400E+01, -.31094600E+01, -.24144600E+00, 0.29754000E-01, 0.50743900E+00, 0.13896000E+01, -.32463800E+01, 0.43096400E+01, 0.32497600E-01, -.13421500E+01, -.54051700E+00, -.86084700E+00, 0.11669700E+01, -.50525100E+01, 0.49745000E+01, 0.34428900E+00, -.14898900E+01, -.30565700E+01, 0.13894100E+01, -.56227200E-01, 0.97030800E+00, -.96949400E+00, -.59443500E+00, -.32174400E+01, 0.15555000E+01, -.24561500E+00, 0.27590400E+00, -.17928400E+01, -.15421400E-01, -.10411200E+01, 0.29212300E+00, -.23681800E+01, 0.14732000E+01, -.29055100E+00, -.32123200E+00, -.27455500E+00, -.79317500E+00, -.20722800E+01, 0.19033900E+00, -.11717200E+00, 0.10398000E+01, 0.22192800E-01, 0.10644800E+01, -.12491400E+00, 0.24471100E-01, -.12267100E+01, 0.28585400E+00, -.12770900E+01, 0.44145700E+00, -.56174800E+00, 0.26007500E+00, 0.36853100E+00, -.52903800E+00, -.90481100E+00, -.32662500E+01, 0.19816600E+01, 0.20869700E+01, -.19347400E+01, 0.19814400E+00, -.14541300E+01, -.42717500E-01, 0.40768300E+00, -.13210500E+00, -.12782500E+00, -.95875600E-01, -.13201500E+00, 0.10825600E+01, -.46580500E+00, 0.35398700E+00, 0.78930700E-02, -.61022500E+00, -.26727000E+00, -.15726700E+00, -.30283200E+00, 0.17105900E-02, -.17311600E-01, -.82839900E-01, -.77457200E+00, 0.26014300E+00, 0.13335000E+01, -.56329500E-01, 0.98406300E-02, 0.24116300E-01, 0.46743000E-01, 0.73656000E+01, 0.48129900E-02, -.26479300E+00, 0.11895100E+01, 0.11404000E+01, -.18579900E+00, 0.70945100E+00, 0.72270400E-02, 0.43686400E+01, -.14495800E+01, 0.21558100E+00, 0.16823000E+00, 0.21997300E-02, -.12619300E-01, 0.66162900E+00, -.15030600E+01, 0.39557900E+00, 0.10200700E+01, -.18834800E+01, -.88793400E+00, 0.79560500E+00, 0.25467900E+00, -.22260300E+01, 0.98411600E-01, -.13129600E+02, 0.10561600E+02, 0.22614000E+00, 0.71047400E+00, -.30240700E+01, 0.88182500E+00, -.65881500E-01, -.45617200E+01, -.29931300E-01, 0.78326200E+00, 0.41539300E+00, 0.70824000E+01, 0.69463400E+00, 0.90506800E+00, 0.52099900E+00, -.18673500E+01, -.41468700E+00, 0.87307000E-01, 0.58465700E+00, 0.37225900E+00, 0.27396400E+01, -.53435700E-01, 0.33867000E+01, -.10321900E+01, -.11003900E+01, 0.12066900E+01, -.27894700E+00, -.26071200E+00, -.76608300E+02, 0.20806600E+01, -.87766200E+00, -.56806200E+01, -.97825000E+00, -.16336300E+00, -.26071800E+01, 0.22764000E+01, 0.11471600E+01, -.49621100E+00, -.37246000E+01, 0.26153000E+01, -.29141000E+03, 0.12098300E+03, 0.93061300E+02, 0.14630900E+03, 0.16844800E+02, 0.53727200E+02, 0.14525900E+03, 0.12920800E+03, 0.15740900E+03, 0.43971900E+02, -.25674000E+02, -.20525600E+03, 0.93074800E+02, 0.37131700E+03, 0.10244700E+03, 0.29255600E+03, 0.11345800E+03, -.12506300E+03, -.13411200E+03, 0.26647300E+01, 0.95628500E+02, 0.13726200E+03, -.89316200E+02, 0.50183300E+02, 0.39626300E+01, 0.44896600E+02, -.11121300E+03, -.64073100E+01, 0.10902900E+03, -.48477800E+02, 0.24217200E+02, 0.34441600E+02, -.14699500E+03, -.42273600E+01, 0.25925800E+02, -.20273100E+02, 0.28997400E+01, 0.12287800E+02, -.11408500E+01, -.93123200E+01, 0.26683700E+02, -.77367200E+00, 0.44046800E+01, 0.29324700E+01, -.58760800E+00, -.42188800E+01, -.71739900E+01, -.22112800E+02, -.19296500E+01, 0.14314200E+02, -.80645700E-01, 0.19361800E+02, 0.26072300E+01, -.17297800E+02, -.72816600E+01, -.26957700E+00, -.26724700E+02, 0.12043400E+02, -.61257700E+01 },
        { -.53863200E+00, 0.72513900E+00, -.45836500E+01, -.52217900E+00, 0.21150500E+01, 0.32837100E+00, 0.20809300E+01, -.34163000E+00, -.36809400E+00, 0.11658100E+00, -.36175300E-01, -.22228700E+01, 0.77543800E+00, -.61245800E-01, -.10053200E+01, -.37873900E+00, -.16936500E+01, 0.33471300E+00, 0.42354900E+00, -.61056600E-01, -.23232200E+00, 0.25972100E+00, 0.21917800E+00, -.81136100E+00, -.50694000E+00, -.35892400E+00, -.73304400E+00, 0.16312200E+00, 0.16767500E+00, 0.47052400E+00, 0.77439800E-01, 0.82451100E-01, -.10399800E+01, 0.26713300E+00, 0.24441200E+00, 0.13411100E+00, -.54584100E-01, 0.14348200E+00, 0.18988000E+00, 0.22755700E+00, 0.34303000E-01, -.29466600E+00, -.88529800E+00, 0.13497000E+00, -.77031500E-01, 0.25061100E-03, 0.10255000E+00, -.71781900E-01, -.22624100E-01, 0.22687900E+00, 0.37747500E+00, -.19270000E+00, -.48444700E-01, 0.76165200E+00, -.21116300E+00, 0.72349800E+00, 0.22792900E+00, -.23231300E+00, 0.10959600E+00, 0.52688900E+00, -.98311000E-01, -.26641000E+00, -.86436600E-02, -.73213800E-01, 0.41312000E-01, 0.12845900E+00, 0.96720500E-01, 0.84285900E+00, -.31227800E+00, 0.17164200E-02, -.85195900E+00, -.73855100E+00, 0.77373000E-01, -.74591700E-01, 0.66692900E-01, 0.10674800E+00, 0.55973100E-01, 0.15579300E+00, -.25370900E+00, -.34603300E+00, -.12198200E-01, 0.92427500E-01, -.11270400E+00, 0.52044300E-01, -.14157300E-01, -.22488800E+00, 0.53439000E+00, 0.76149400E+00, 0.73742500E+00, -.48597700E-01, -.60432600E+00, -.19935400E+00, 0.44336900E+00, 0.59057500E+00, -.35315000E+00, -.15856700E+01, -.25523000E+00, 0.20938900E+00, -.10126600E+00, -.20949400E-01, -.30606100E+00, 0.38862700E+00, 0.20350700E-01, -.60470500E+00, -.14637600E+00, -.29886600E+00, 0.28959100E+00, -.52188600E+00, 0.11183100E+01, -.73351900E+00, -.11570400E+01, -.68124900E+00, -.73268900E-01, 0.19497300E-01, 0.33562400E-01, -.27896200E+00, -.19704200E+00, 0.36746500E+00, -.17114300E+00, -.65214900E-01, -.10583300E-01, -.63105200E-02, 0.61774300E-02, -.38658600E-01, 0.75844900E-02, 0.60822100E-02, 0.30529300E+00, -.26472900E+00, -.21899000E-01, -.18090800E-02, -.30544000E+00, 0.54004900E-01, -.41654400E-01, 0.58130100E-01, -.12232700E+00, -.65949100E-02, 0.83842700E-01, -.10104000E+00, -.24546200E-01, 0.28461200E-02, 0.32349000E-02, 0.67236400E-01, 0.11239600E+00, 0.57236300E+00, 0.70995900E+00, 0.12717400E+00, 0.41953000E-01, -.19296200E+00, 0.28472100E-01, -.71105100E-01, -.22893600E+00, 0.16047200E+00, 0.12802500E+00, -.62794600E+00, -.47613500E+00, 0.12765300E+00, -.40374300E+00, -.15350600E-01, -.74876200E-01, 0.13594200E+00, 0.16361100E+00, 0.32980600E+00, 0.28132600E-01, -.37086200E-01, 0.50120000E-01, -.28833600E+00, -.45254100E-01, 0.10907800E-01, 0.91870500E-03, -.20244100E+00, 0.67473500E-01, 0.19425700E+00, -.12245000E+00, 0.52450700E-02, -.91687800E-01, 0.53871300E-01, -.38155400E-01, 0.16065000E-01, 0.71433600E+00, 0.38254600E-03, -.10014500E+00, -.25351000E+00, -.31104400E+00, -.17194500E-01, 0.31593600E-01, 0.63727800E-01, 0.12000500E+00, 0.83208300E-01, 0.43637700E-01, 0.43769700E-01, -.39985000E-03, 0.47075300E-01, -.18199000E-01, -.58793000E-01, 0.61933100E+00, 0.24716500E+00, 0.28213600E+00, -.27503000E+00, 0.36595300E+00, -.48350800E-02, -.37655900E+00, 0.43657200E-01, -.21588000E+01, 0.11877000E+01, -.31745700E-01, -.33946200E+00, 0.18878400E-01, 0.20890400E+00, -.28213700E-01, -.66145800E+00, 0.22516400E-01, -.14952500E+00, -.12442500E-02, 0.14016100E+01, -.14807900E+00, 0.14249700E+00, -.75166200E-01, 0.64470300E-01, -.22319400E-02, 0.12850600E+00, 0.17210000E+00, 0.68708800E-01, 0.36932100E+00, 0.16760500E-01, -.60424200E+00, -.62172600E-01, -.10242200E+00, 0.63404100E-01, 0.44624600E-01, 0.20697400E-02, 0.23976300E-01, 0.42640100E+01, -.57354800E+00, -.70204100E+00, -.66181500E+00, -.37049800E-01, -.23513600E-01, -.17035300E+00, 0.10122100E+00, -.29295000E+00, -.91403100E-01, -.23385000E+00, 0.31686000E+02, -.16124900E+02, -.18309100E+02, -.15796200E+02, -.84373800E+00, -.88336000E+00, -.56257000E+01, 0.82154900E+01, -.44198800E-01, -.17327000E+01, -.10828300E+02, -.49957600E+02, 0.23786600E+02, 0.36589900E+02, 0.24956800E+02, 0.13087900E+02, 0.12331500E+02, 0.65021300E+01, -.16996100E+02, 0.11568600E+02, 0.12796900E+02, 0.29737400E+02, 0.13277700E+02, -.58452600E+01, -.63397800E+01, -.66127000E+01, -.81007000E+01, -.53708300E+00, -.47999000E+01, 0.16083600E+01, -.54382900E+01, 0.25668100E+00, -.21221200E+02, -.11920600E+01, 0.12772900E+01, -.91002600E+00, 0.97320900E+00, 0.87946500E+00, -.51271400E+00, -.35419100E+00, 0.12382100E+01, -.10013800E-01, 0.63589500E+00, -.21091400E+00, -.45945300E+00, -.54398100E+00, -.85031100E+00, -.94168600E+00, -.70746500E+00, 0.64623500E+00, 0.26253500E+00, 0.17066800E+01, 0.29743400E+00, -.14969200E+01, -.95805600E+00, -.22279000E+00, 0.19210800E+00, -.66386700E+00, -.13112300E+01 },
        { 0.26490700E+00, 0.18932000E+01, -.53209000E+00, 0.13778200E+00, -.41326200E+00, -.47202200E+00, -.43720800E+00, 0.48069900E+00, 0.11575700E+00, -.11789500E+00, -.76041900E-01, 0.35647400E+00, 0.14269100E+00, 0.27339800E+00, 0.36637900E-01, 0.84725000E-01, -.15251100E-01, -.36580900E-01, -.30848600E+00, 0.94294000E-01, -.29145000E+00, 0.93706700E+00, 0.14844900E+00, 0.78775200E+00, 0.60219800E-01, -.16687700E+00, 0.33455200E+00, 0.10054500E-01, 0.31071200E-01, -.23319200E+00, 0.50129700E-01, -.21677400E+00, 0.39442900E-01, 0.34461800E-01, -.13561700E+00, -.57107600E-01, 0.29760900E-01, -.13943800E+00, 0.25270300E-01, 0.61660200E-01, 0.76049900E-01, 0.77257400E+00, 0.83694400E+00, 0.21634700E+00, -.19083500E+00, 0.13972500E-01, -.26684500E-01, 0.34294600E-01, -.20122800E-01, 0.82735300E-01, 0.19593500E+00, -.25755400E+00, -.10678000E-01, 0.94813700E-01, 0.65410500E-01, -.12577900E+00, -.25416500E-01, -.44266200E-01, -.80365400E-01, -.45654500E-01, -.94966700E-01, 0.68303400E-02, 0.28334000E-01, 0.56887200E-01, 0.32817800E-01, -.68435600E-01, -.56911200E-02, -.37014600E+00, 0.96500900E-01, 0.15262700E-02, 0.31730600E+00, 0.36701400E+00, -.25346000E-01, 0.70052500E-01, 0.33286200E-01, -.65271000E-01, 0.38392300E-01, 0.12470000E+00, 0.31231300E+00, -.46158400E-01, -.33067600E-02, -.19259400E-01, 0.14825100E-01, -.35656400E-01, -.22739400E-01, -.15932700E-01, -.16036400E-01, 0.23407900E+00, -.15354100E+00, -.23253000E+00, 0.33216900E+00, -.90374800E-01, -.61627500E+00, 0.13964600E+01, 0.37498500E+00, 0.44723400E+00, -.40623500E+00, -.30577300E-01, 0.42915900E+00, 0.19131200E+00, -.11113600E+01, 0.51795500E-01, 0.14564900E-01, 0.11015500E+00, 0.11415300E+00, -.34878800E+00, -.84501600E-01, 0.11612800E+00, -.35537000E+00, 0.14182100E-01, 0.27937400E+00, -.54399500E+00, 0.11966200E+00, 0.57359600E-01, 0.16067600E-01, 0.17551900E+00, 0.79911000E-01, -.32630200E+00, -.17835000E+00, 0.18074500E-01, -.16094900E+00, 0.26765800E+00, -.13224300E+00, 0.27445900E+00, -.20795900E-01, -.29473200E+00, -.97032600E-01, 0.15380900E+00, -.18702900E-01, -.69350100E-02, 0.23719200E+00, -.10478900E+00, 0.43110700E-01, -.54930400E-01, -.53780400E-01, 0.67897500E-02, 0.15642700E+00, 0.38597900E-01, 0.11999400E+00, -.10196800E+00, 0.26365900E-01, 0.18464600E-01, -.35263600E-01, -.23202400E+00, -.43173100E+00, -.24385800E-01, -.85428000E-01, -.10081400E+00, -.83052000E-02, 0.31764800E-01, 0.12686300E+00, -.81812700E-01, 0.51545800E-01, 0.33166300E+00, -.10477300E+00, 0.93462000E-01, 0.84551900E-01, 0.25051700E-01, -.20269900E+00, -.35865500E-01, -.22865800E+00, -.17512100E+00, -.10374100E+00, 0.35289700E-01, 0.38863300E-01, 0.22433300E+00, -.26550500E-01, 0.12022600E+00, 0.37413100E-02, 0.15823100E-01, 0.91128500E-01, 0.63997600E-01, -.18563900E-01, -.49436900E-01, -.59532200E-02, 0.11942300E+00, -.26513700E-01, 0.50131300E-02, -.58680000E+00, 0.56080300E-03, 0.35653900E-01, -.63425300E-01, 0.18647200E-02, -.49900900E-01, 0.45413100E-01, -.48700400E-01, 0.31345600E+00, -.29058100E-01, 0.17982000E-01, -.78766900E-02, -.71263500E-04, -.10364500E+00, 0.98754100E-01, -.62748200E-01, 0.15759700E+00, 0.99264700E-01, -.18991400E+00, 0.26290500E-01, -.23341000E-01, -.43515900E-02, 0.24828100E+00, -.28332200E-01, 0.31266000E+00, -.26439500E+01, 0.31875700E-01, 0.68212600E-01, -.13494900E+00, -.30134900E+00, 0.12970300E-01, 0.69111900E-01, -.71919000E-01, 0.11311100E+00, -.32911000E-03, -.24062000E+00, 0.15910100E-01, -.14293400E+00, -.26602000E-01, 0.12566500E-01, -.13887600E-01, -.39741900E-01, 0.10602600E+00, 0.13816700E-01, 0.34018600E+00, -.46804600E-02, 0.57583200E-01, -.40595200E-01, -.77597900E-01, -.11704700E-01, 0.51384200E-02, 0.38232300E-01, 0.98574300E-02, -.66773600E-01, 0.64962500E+01, 0.20975600E+00, 0.10424100E+00, -.71425800E-01, 0.46987800E-01, -.26137000E-01, 0.81780200E-01, -.11288000E+00, 0.56962500E-01, 0.10548100E+00, 0.13280800E+02, -.62777500E+01, -.58136700E+01, -.66714400E+01, -.12553600E+01, -.27041500E+01, -.14295300E+01, 0.39410900E+01, 0.60214600E+00, -.25353300E+01, -.52447500E+01, -.13341200E+01, 0.76823800E+00, -.65527400E+01, 0.67238500E+00, -.46234700E+01, -.59581300E+00, 0.34940100E+01, 0.27495400E+01, 0.47935400E+01, 0.15434700E+00, 0.32090200E+01, 0.22516200E+01, -.10236600E+01, 0.46314300E+00, -.11304800E+01, 0.23368100E+01, 0.46569500E+00, -.76529500E+01, -.25717200E+01, -.41406800E+01, -.87661000E+00, 0.21179300E+01, 0.23551400E+00, -.61534400E+00, -.28480300E+00, -.29874600E+00, -.35174400E+00, 0.60376000E-01, 0.13763600E+00, -.77589400E+00, 0.11190700E+00, -.16918300E+00, -.30979500E-02, 0.18638000E+00, 0.24350100E-01, 0.26324400E+00, 0.51485800E+00, 0.23158300E+00, -.13971700E+00, -.31859200E-01, -.53852700E+00, -.13268800E-01, 0.43170600E+00, 0.26147200E+00, 0.89862200E-01, 0.95083400E-01, -.12432900E+01, -.36947900E+00 },
        { 0.22532400E+00, -.50723900E+00, 0.88192600E-01, 0.13030300E+00, 0.98323600E-01, 0.69161900E-01, 0.23505000E+00, -.27376600E+00, 0.15881200E+00, 0.21632600E+00, -.74030000E-01, 0.67199700E+00, -.40527800E+00, 0.73641600E-01, -.84109800E-01, -.42115600E-01, 0.12165700E+00, -.20710400E-01, -.22188900E+00, -.12114100E+00, 0.55178700E-01, -.14945300E+00, -.16167000E+00, 0.18411300E+00, 0.11451000E+00, 0.11173500E-01, 0.16431200E+00, -.85040800E-01, 0.22747500E-01, -.99782600E-01, -.41067700E-01, -.12009900E+00, 0.22257000E+00, 0.33862800E-01, -.63840700E-02, -.23180400E-01, 0.18237700E-01, -.56296300E-02, -.47860200E-01, -.11067500E+00, -.10575000E-01, -.20777200E-01, 0.34271500E+00, 0.10982300E+00, -.10151700E+00, -.96395800E-01, -.21920000E+00, 0.21606700E-01, -.16552200E-01, 0.11488900E-01, -.77160200E-01, 0.40321600E-02, 0.90820700E-01, 0.38416800E+00, -.23516000E-01, 0.73929300E-01, -.99287400E-01, 0.93421700E-01, -.10306400E+00, -.31254300E-01, 0.14639300E-02, -.88626800E-01, 0.57549800E-01, -.96558200E-02, 0.10754800E-02, -.45190700E-01, 0.94943800E-02, -.61063900E-01, 0.72527600E-01, -.44991600E-03, 0.30255000E+00, -.11505100E-01, -.94577500E-02, 0.14718800E-01, -.52536800E-01, -.93366200E-01, 0.21087700E-01, 0.59565500E-01, 0.89979800E-01, -.84617700E-02, -.15285800E-02, 0.17069600E-01, 0.49126700E-01, -.12820700E-01, 0.39425600E-01, -.47876300E-01, 0.57550500E-01, 0.10140000E+00, -.13496600E+00, -.98557600E-01, 0.38251000E+00, 0.18731000E-01, -.22777500E+00, 0.79974900E-01, 0.67110800E-01, 0.59722300E+00, -.96855800E-02, -.11329200E-01, 0.12849000E+00, 0.23937300E-01, -.22191900E+00, -.93687100E-01, 0.65665700E-03, 0.28192200E+00, 0.18578900E+00, -.14030600E+00, -.15575500E+00, 0.41645800E-01, -.22585900E+00, 0.22082700E+00, 0.41974900E+00, 0.11364900E+00, 0.57990500E-01, 0.32947100E-03, 0.38950300E-01, 0.24346700E+00, 0.45754300E-01, -.83458000E+00, -.18771800E+00, -.17175300E-01, -.83453900E-01, -.19856700E-01, 0.47573800E-01, 0.33097100E+00, -.14462900E-01, -.25795100E+00, 0.47361000E-02, 0.11691600E+00, -.88760000E-02, -.47177500E-01, 0.60773500E-01, 0.70557900E-01, 0.22822200E-01, -.12553700E+00, 0.47616600E-01, 0.84221800E-03, 0.99077200E-01, 0.77512100E-01, 0.54149600E-01, -.15937700E+00, 0.58048700E-01, -.63618500E-01, 0.14228600E-01, -.38657400E-01, -.73187200E-01, -.22377800E-01, -.75121600E-01, 0.30679000E-01, -.11592600E+00, 0.12874900E+00, -.96532100E-02, -.97592700E-01, 0.12344100E+00, 0.33761900E+00, 0.98387400E-01, -.60837300E-01, 0.27132500E+00, -.11533000E-02, -.80375100E-01, -.13764100E+00, -.10507800E+00, -.29522800E+00, -.25975300E-01, 0.30737700E-01, -.96698000E-01, 0.15238100E+00, 0.20077100E-01, 0.18367500E-01, 0.46996700E-03, 0.73487700E-01, -.53055600E-02, -.93665200E-01, 0.43351100E-01, -.11493200E-01, 0.20868400E-01, 0.54686900E-01, 0.17959500E-01, -.11722300E-01, 0.41120700E-01, 0.44508500E-03, -.13048800E-01, 0.69630500E-02, -.38646700E-01, -.28281200E-01, 0.64122100E-01, -.45156200E-01, 0.39241400E+00, -.10742100E+00, 0.23007700E-03, 0.88604100E-02, 0.22220100E-03, -.34767400E-01, 0.83929300E-01, -.13518600E+00, -.18323600E+00, -.39907000E-01, -.40188300E+00, 0.55701300E-01, -.89290500E-01, 0.40166700E-01, 0.62997900E-01, -.59075000E-02, -.17719700E+00, 0.28474400E+00, 0.94263800E-02, 0.63994200E-01, -.14987700E+00, -.28143900E+00, 0.11519000E-01, 0.23151200E-01, -.31202500E-01, 0.18710100E+00, 0.14133000E-03, -.12931300E+00, 0.10060100E+00, -.10608300E+00, 0.65980200E-02, 0.40177400E-02, 0.22059200E-01, -.34568000E-01, -.27357200E-01, -.37185400E-02, 0.32648200E+00, -.46448900E-02, 0.19773700E+00, -.33170100E-01, -.76510900E-01, -.19058700E-01, -.48867200E-02, 0.84010000E-02, 0.29158500E-02, -.33525500E-01, 0.77253000E-02, 0.14135900E+01, 0.52931200E-01, -.77475300E-01, 0.92049000E-02, 0.27182900E-01, 0.26970800E-01, 0.14433000E-01, 0.36861900E-01, 0.11730500E+00, 0.12621100E+02, -.66927900E+01, -.65677000E+01, -.63188300E+01, -.11079100E+01, -.19635400E+01, -.23782900E-01, 0.65272500E+01, 0.13435300E+01, -.17811700E+01, -.53787500E+01, -.82219100E+01, 0.45341600E+01, 0.27061200E+01, 0.41095500E+01, 0.25202800E+01, 0.28719000E+01, 0.63194900E+00, -.37995400E+00, 0.19845200E+01, 0.21782900E+01, 0.59611500E+01, 0.97515700E+01, -.50699200E+01, -.35925700E+01, -.48733600E+01, -.35170100E+01, -.65123500E+00, -.42901900E+01, 0.43025100E+00, -.33315600E+01, -.32706600E+00, -.25719500E+01, 0.95183200E-01, -.40638400E+00, -.30966800E+00, -.17877100E+00, -.10663600E+00, -.36640900E-01, 0.11735300E+00, -.40633400E+00, -.55467900E-01, -.99829200E-01, 0.31051800E-01, 0.10235300E+00, 0.81518900E-01, 0.13549700E+00, 0.21655200E-01, 0.12965300E+00, 0.47717700E-01, -.54829100E-01, 0.24908400E+00, -.89566500E-01, -.16209400E+00, 0.99250000E-01, 0.13748200E-01, -.13647100E-01, -.56527300E-01, 0.23570700E-01 },
        { 0.26260700E+00, -.38718800E+00, 0.23049000E+01, -.10703000E+00, -.16179800E+01, -.23827500E+00, -.22706000E+01, -.26475700E+00, 0.39374400E-01, -.16851300E+00, -.15898800E-02, 0.19360600E+01, -.42297200E+00, 0.33012600E+00, 0.28358500E+00, 0.22621600E+00, 0.19754800E+01, -.29528200E+00, 0.23489100E+00, -.31109000E+00, 0.38587000E+00, 0.10258000E+01, -.13378300E+00, 0.45674700E+00, 0.42306500E+00, 0.13542700E-01, 0.52511200E+00, -.14008200E+00, 0.21405200E-01, -.31274000E+00, -.24186700E+00, -.24892800E+00, 0.47865800E+00, 0.93295700E-01, -.47841300E-01, 0.13381800E-01, 0.46668200E-01, -.10656900E+00, -.33059600E+00, -.73112800E-01, 0.68903500E-01, 0.33444000E+00, 0.82924700E+00, 0.21057400E+00, -.38985100E+00, -.29972700E+00, -.71475500E+00, 0.77135400E-01, -.47589700E-01, 0.67163200E-02, -.24862800E+00, 0.24318700E-01, 0.29367700E+00, -.26840500E+00, -.67415800E-01, -.35635300E+00, 0.98266300E-02, 0.39776000E+00, -.24241600E+00, 0.75161900E-02, -.13355400E+00, 0.62857700E-01, -.56187700E-01, 0.66374300E-01, 0.27649200E-01, -.41577300E-01, 0.32316200E-01, -.26329900E+00, 0.27218300E-01, -.28401000E-03, 0.34781600E+00, -.21900100E-01, -.68806300E-02, 0.21424500E-01, -.93064000E-01, 0.16319500E-01, -.67316500E-01, -.65093300E-01, 0.15717800E+00, -.62919700E-01, 0.44842600E-02, -.44413100E-02, 0.14196700E+00, -.27270100E-01, -.54314000E-02, -.50045700E-01, -.52208400E-01, -.81333300E-01, -.46533000E+00, -.42668700E-01, 0.30087500E+00, 0.55373400E-01, -.13291900E+00, -.23276700E+00, -.41090500E-01, 0.25251300E+00, -.46340900E-01, 0.85670500E-01, -.96731300E-02, -.81979200E-01, 0.44416500E+00, -.16229600E+00, -.87794900E-02, 0.22465300E+00, 0.14065100E+00, -.19029300E+00, -.18288600E+00, 0.30806000E-01, 0.18708500E-01, 0.17233100E-01, 0.34792400E+00, 0.29393400E+00, 0.75308600E-04, 0.40757000E-02, -.47984500E-02, -.35909100E-01, 0.27959600E-01, -.11201800E+00, 0.21195300E+00, -.26518000E-01, 0.73035700E-01, 0.78382300E-01, -.30086700E-01, -.10991600E+00, -.89349200E-02, -.24297900E+00, -.36455400E+00, 0.72627800E-01, -.14621100E-01, -.82871800E-01, 0.13554700E+00, 0.25933400E+00, -.35075800E-01, -.16594600E-01, -.71004000E-01, -.39381500E-02, -.90216000E-01, 0.35103200E-01, 0.17366700E-01, -.10531800E+00, 0.21248000E-02, 0.15813900E+00, -.12399500E-02, -.75803700E-01, -.17426800E+00, -.51748100E-01, -.70977800E-01, 0.15853500E+00, -.45351700E-01, 0.11725800E+00, 0.15772700E+00, -.12519500E+00, 0.79385500E-01, 0.38840200E+00, 0.41910300E-01, -.35504200E-01, 0.27185000E+00, -.75251500E-02, -.28480200E-01, 0.20590200E-01, -.76616200E-01, -.21687400E+00, 0.95478100E-02, -.21662300E-01, 0.80675100E-02, 0.37336900E+00, 0.20149300E-01, 0.11555600E-01, -.26246300E-02, 0.17836900E+00, 0.25911600E-01, 0.84117300E-01, 0.72367100E-01, -.35800100E+00, 0.44754800E-01, -.12826400E+00, -.68162100E-01, 0.12723200E-01, 0.43107900E+00, 0.18681100E-02, -.19142900E-01, -.32996100E-01, 0.70142500E-01, 0.23914900E-02, 0.82403700E-01, 0.52190500E-02, -.85965000E-01, 0.55303500E-01, 0.74622900E-02, -.42370500E-01, -.20137700E-02, 0.18135800E-01, -.39095100E-01, -.75227700E-01, 0.18561600E+00, -.86417500E-01, -.35932900E+00, 0.23049500E-01, -.71086100E-01, 0.77659700E-02, 0.14999800E+00, -.11120700E-01, 0.32282500E+00, -.70115400E+00, 0.74490800E-02, 0.77196600E-01, -.10176700E+00, -.21777500E+00, 0.10193900E-01, -.49183200E-01, -.11589200E-01, -.62390100E-01, -.52501000E-02, -.46498700E+00, -.22287500E-01, -.10315200E+00, -.11948000E-01, -.30022700E-01, 0.26227200E-02, -.63742700E-01, -.11577800E-01, -.14347700E-01, 0.23238300E+00, 0.38356800E-01, 0.41936500E+00, -.65788900E-01, -.16473400E-01, 0.16702500E-03, 0.28530100E-03, 0.18551500E-01, 0.25903900E-02, -.12552600E+00, 0.20604600E-01, 0.10987500E+00, 0.36814900E+01, -.14666200E-01, -.25683200E-02, 0.10669000E+00, 0.60836000E-02, 0.13179500E+00, 0.35582500E-01, 0.11258600E+00, 0.69698100E+01, -.34635500E+01, -.30308700E+01, -.34787600E+01, -.43032300E+00, -.10089600E+01, -.13516100E+01, 0.11681300E+01, -.76897400E+00, -.87207400E+00, -.14508200E+01, 0.39475600E+00, 0.90084700E+00, -.32117700E+01, -.20119700E+00, -.21091000E+00, -.11222100E+01, 0.11513200E+01, 0.36741300E+01, 0.80857300E+00, -.12791500E+01, -.45081000E+01, 0.27580100E+01, -.21072100E+01, -.81417000E+00, -.13668700E+01, -.48614600E+00, -.50703100E-01, -.40734100E+00, -.15840100E+01, -.58496100E+00, -.10239600E+00, 0.43606400E+01, 0.31510500E+00, -.38231100E+00, 0.56919800E-01, -.25963300E+00, -.34426400E+00, 0.11972500E+00, 0.20397600E+00, -.39780400E+00, -.30675700E-01, -.18297200E+00, 0.12446700E+00, 0.15403300E+00, 0.90777400E-01, 0.17078200E+00, 0.49755500E+00, 0.21495900E+00, -.18306800E+00, -.94828900E-01, -.22419200E+00, -.14370800E+00, 0.22917600E+00, 0.22041500E+00, 0.36152400E-01, 0.27413200E+00, -.48955500E-01, 0.30831000E+00 },
        { 0.52443200E-01, 0.21878900E+00, -.24476400E+00, 0.12169500E+00, -.20165100E+00, 0.15023200E-01, -.15792200E+00, 0.27545700E+00, 0.88694400E-01, -.38930400E-01, -.27154400E-01, 0.60521600E-01, 0.40316300E-01, 0.76939900E-01, -.14991800E+00, 0.98863100E-01, 0.15636800E+00, -.11445400E-01, -.27344700E+00, -.72244200E-02, -.84016000E-01, 0.28243700E-01, 0.42486300E-01, -.56640000E-01, -.11229900E+00, -.12082700E+00, 0.41130300E-01, 0.13576000E+00, 0.58461300E-02, -.10673300E+00, 0.13040500E-01, -.56748000E-01, -.31294000E-01, 0.73112700E-01, 0.18057200E-01, -.47441400E-01, 0.50360600E-02, 0.16684400E-01, 0.22377200E-01, -.17012200E-01, 0.47404600E-01, -.86440200E-01, -.39205700E-01, 0.57081400E-01, 0.51212600E-01, 0.30909700E-03, 0.33691600E-01, 0.78264300E-02, 0.19644500E-01, 0.80003300E-01, 0.12075000E+00, -.95005200E-01, 0.31697400E-01, -.17110500E+00, -.84334800E-01, 0.20695900E-01, 0.42085400E-01, 0.36823300E-01, -.29679300E-01, -.32768600E-01, -.67545300E-01, -.29227200E-01, -.18013800E-01, 0.23454800E-01, 0.49587700E-02, 0.45803900E-01, 0.16993200E-01, -.44304000E-01, -.21667200E-01, -.15251000E-02, 0.97102300E-01, -.98990800E-01, 0.11980900E-01, 0.99572100E-02, -.87173300E-02, -.30495600E-01, -.80087400E-02, 0.24393200E-01, 0.43659700E-01, -.44155200E-01, 0.45789700E-04, -.37267800E-02, 0.13445400E+00, 0.68795100E-02, -.11996500E-01, -.71160600E-02, -.17414600E-01, -.26419900E-01, -.12340800E+00, -.22505700E-01, 0.10936100E+00, 0.32864100E-02, -.74253300E-01, -.15981300E+00, -.10207900E-01, -.47526700E-01, 0.28877900E-01, -.30632700E-01, 0.13037600E-01, -.22508300E-01, 0.16594700E+00, 0.64066600E-02, 0.16610200E-02, 0.39704900E-01, 0.32946100E-01, -.20229800E+00, -.73045900E-01, -.42120600E-01, 0.13279100E+00, -.16739100E-01, 0.29053200E-01, 0.48523100E-02, -.40008100E-02, 0.30404900E-02, 0.25147600E-01, -.51724400E-02, -.13779500E-01, 0.77537900E-01, 0.36565600E-01, -.23182900E-01, 0.10385700E+00, 0.82514300E-02, -.26353100E-01, -.26153400E-01, 0.77329300E-02, 0.55209300E-02, 0.13190400E-01, -.17250400E-02, 0.29590500E-02, -.17827400E-02, -.92010400E-02, -.38384800E-01, -.49311700E-02, -.17017700E-01, -.13080600E-01, -.24573900E-02, -.78043300E-02, -.11941100E-01, -.83238500E-02, -.63354200E-01, -.92866500E-02, -.19278600E-01, -.13172000E-03, 0.24922400E-02, -.22889000E-01, 0.12260400E-02, -.88683800E-03, 0.75422300E-01, 0.32786700E-01, -.82081500E-02, 0.25397100E-01, -.99392800E-02, 0.64058800E-01, 0.37190300E-01, -.41390600E-01, -.35073700E-02, 0.13507200E-01, -.45741100E-02, -.12869000E-01, 0.28956600E-01, 0.93156400E-02, -.22015800E+00, 0.13059200E-01, -.36522500E-02, 0.13691500E-02, 0.26023900E-01, 0.84220900E-02, 0.18831100E-01, 0.46562100E-02, 0.44492300E-02, -.24299000E-01, -.13145700E+00, -.41001000E-01, -.11336800E+00, -.81025400E-02, -.91596600E-01, -.15774800E-01, 0.71903600E-02, 0.77516300E-01, -.14982800E-04, 0.61858300E-02, 0.47546500E-01, -.60544600E-02, 0.32210000E-01, 0.61200300E-01, 0.40693100E-01, 0.11275000E-01, -.12379300E-01, -.23010600E-02, -.10418200E-01, -.32278600E-03, 0.16952700E-01, -.23777200E-01, -.51584000E-01, -.40127800E-01, -.57758600E-01, -.26477900E+00, -.13177800E-01, -.18975500E-02, 0.83443400E-02, 0.56689700E-01, -.60733500E-02, 0.61450400E+00, 0.16683100E+00, -.10360800E-02, 0.30622200E-02, -.29429000E-01, -.67827200E-01, 0.57599600E-02, -.50904700E-01, -.21510400E-02, 0.35033700E-01, 0.18073100E-04, -.13117700E+00, 0.19136900E-01, -.21944900E-01, 0.84054900E-02, 0.18272300E-01, 0.65761200E-02, -.88789000E-02, -.61291100E-01, -.77845500E-02, 0.15901300E+00, -.15907600E-02, -.26391100E-01, 0.43665000E-02, 0.11896800E-01, -.74202700E-02, -.44701700E-02, -.26822000E-02, -.51258000E-02, -.18535800E-01, 0.52331400E-02, -.30458800E-02, 0.73624600E-02, 0.24589300E+00, 0.32949500E-01, -.16260500E-01, -.44433500E-01, -.28196300E-01, 0.28979200E-01, -.32625300E-01, -.31166900E+00, 0.10221200E+00, 0.40526600E+00, 0.14498800E+00, -.78806400E-01, -.31332000E+00, -.15723700E+00, -.69209000E+00, -.82338600E-01, -.21400000E+00, 0.21831000E+00, 0.58829200E+00, -.38332400E+00, -.75551900E+00, -.29166100E+00, -.19846000E+01, -.96787300E+00, 0.12076100E+00, 0.12090900E+00, 0.73218600E+00, -.53266300E+00, 0.11817000E+01, -.31845600E+01, 0.16670800E+01, 0.15763800E+01, 0.15895500E+01, 0.12431100E+01, 0.51374000E+00, -.89342600E-01, -.83946600E+00, -.11551900E+00, 0.70046200E-01, 0.75529300E+00, 0.30826500E-01, 0.59292700E-01, 0.15312800E+00, -.12364700E-01, -.62985700E-02, -.21360800E-01, 0.26666900E-02, 0.20785700E-01, -.16907500E-01, 0.24708300E-01, -.27929000E-01, -.10594600E-01, -.71212500E-01, -.47125700E-01, 0.68567500E-01, 0.65169400E-02, -.18424300E+00, 0.56029900E-01, -.55173000E-01, 0.11262300E-01, 0.10085600E-01, -.25008900E-01, -.19311900E-02, 0.15614600E+00, -.28595600E+00, -.22964200E+00 },
        { 0.53763300E-01, -.22000100E+00, -.38148400E-01, 0.55824200E-01, -.16136700E+00, -.94413300E-01, -.27773500E+00, 0.34903400E+00, 0.83649900E-01, -.95938000E-01, -.11925400E-01, 0.82191400E-01, -.55787400E-01, 0.89714800E-01, 0.79202700E-01, 0.64797000E-01, 0.42269700E+00, -.50340100E-01, -.84321700E-01, 0.90499300E-03, 0.16768200E+00, 0.21098300E-01, 0.95988500E-02, 0.99037100E-01, 0.24432800E-01, -.64425400E-02, 0.56777600E-01, 0.88950300E-01, 0.13462100E-01, -.95143500E-01, 0.20782200E-01, -.33095200E-01, 0.82696700E-02, 0.70000000E-03, -.35913700E-01, -.52186900E-01, 0.88552600E-02, -.12471300E+00, -.81551200E-01, -.50986700E-01, 0.17138400E+00, 0.10295600E+00, -.33599600E+00, -.10389700E+00, -.17228500E-03, -.33442700E-01, -.89586000E-01, 0.15311600E-01, -.17253500E-01, -.39047700E-01, -.35782100E-01, -.79171700E-01, 0.57508300E-01, -.36050100E+00, 0.85960900E-01, -.24786000E+00, 0.49447700E-01, -.84454700E-02, -.26451200E-01, -.30326100E-01, -.22522800E-01, 0.58909500E-01, -.31707800E-01, 0.64054300E-01, 0.19943700E-01, 0.13087700E-01, -.91273200E-02, -.14909500E+00, -.68967800E-02, -.26412100E-03, 0.78010900E-01, 0.71270400E-01, 0.15405600E-02, 0.15952800E-01, 0.33835400E-01, -.99495800E-03, -.21837800E-01, -.71148900E-02, 0.28693300E-01, 0.18779300E-03, 0.16846400E-02, -.29220500E-01, 0.11123700E+00, 0.12936700E-01, -.64381600E-02, -.72410600E-02, -.37395900E-01, -.23735600E+00, -.31481000E+00, 0.30371700E-01, 0.67556600E-01, 0.78056200E-02, 0.48615800E-01, -.20518200E+00, -.10775900E+00, -.12626100E+00, 0.58769400E-01, 0.55415100E-01, -.36293500E-01, -.39690300E-01, 0.47651500E+00, 0.19257500E-01, -.60055800E-02, 0.26558500E-01, -.16434600E-01, -.14760700E-02, -.26747900E-01, 0.40629800E-02, -.33020000E-01, -.18125600E-01, 0.59935700E-01, 0.13298100E+00, -.31860900E-01, -.58545300E-02, 0.19404900E-01, -.17081300E-01, -.51626000E-02, -.97012000E-01, 0.90666200E-01, -.23342400E-01, 0.58834200E-01, -.31080400E-01, -.66309700E-02, -.73551300E-01, 0.11163500E-01, 0.90945400E-01, 0.65384000E-01, 0.12606400E-01, 0.85961800E-02, 0.18119600E-01, -.29019300E-02, -.14882900E+00, 0.19339500E-02, -.35433800E-01, -.32489900E-01, -.28942100E-02, -.92378200E-01, -.31694500E-01, -.35865500E-01, -.15559200E+00, 0.10339300E-01, 0.12079400E+00, 0.38749000E-01, -.67414800E-01, -.89745200E-01, -.18097200E-01, -.76327600E-02, 0.69648200E-01, -.49843200E-01, 0.23203600E-01, 0.97208500E-01, -.66168600E-01, 0.74969000E-02, 0.13445400E+00, -.51137500E-01, -.25087500E-01, -.53872900E-01, 0.42811000E-02, -.21772100E-01, 0.82622500E-01, 0.52949300E-02, -.10658700E+00, 0.26504400E-01, -.11570400E-01, 0.30327400E-01, 0.44201900E-01, 0.21700100E-01, -.47100900E-02, 0.11412200E-02, 0.47785700E-02, -.35499800E-01, 0.45807700E-01, -.29132600E-01, -.54247200E-01, -.20384400E-01, -.13051900E+00, -.17420800E-01, 0.45457100E-02, -.63487700E-01, 0.16718300E-03, -.50202500E-02, 0.51814600E-03, -.64863200E-01, 0.24928400E-01, 0.35681400E-01, 0.10644500E-01, 0.30870700E+00, 0.12257400E-01, 0.95750700E-03, 0.16189900E-01, -.29227100E-03, -.49911400E-01, -.28578900E-01, 0.79044700E-01, -.15807700E+00, -.68239800E-01, -.48417600E-01, -.99225200E-02, -.62609900E-01, -.15696800E-01, 0.44542600E-01, -.12439600E-02, 0.46928300E-01, -.51395500E+00, 0.14289800E-01, 0.10557600E-01, -.18882600E-01, -.86987400E-01, 0.57163400E-02, -.88653000E-01, 0.18679500E-01, 0.13802200E+00, -.39594000E-03, 0.18802100E+00, 0.41953400E-02, 0.52375500E-02, 0.11444700E-01, 0.73939200E-02, 0.10910300E-01, -.14658800E-01, 0.30817600E-01, -.21163400E-01, 0.17488900E+00, -.14954900E-02, 0.42519500E-01, 0.37599900E-02, -.89807200E-02, -.19568000E-01, -.19123200E-01, -.19666800E-01, -.77350200E-03, 0.27275200E-02, -.15948300E-02, -.60049200E-02, -.10864000E-02, 0.75713300E-01, 0.23571300E+00, -.77681500E-02, 0.12290300E-01, 0.16687400E-01, 0.39276300E-01, 0.28829000E-01, -.34748200E+01, 0.13978500E+01, 0.16306300E+01, 0.17508400E+01, 0.20315400E+00, 0.37958800E+00, 0.13413700E+01, 0.63578500E+00, 0.10779000E+01, 0.37324300E+00, 0.38799600E+00, 0.12506400E+01, -.88420600E+00, 0.65490500E+00, -.62868800E+00, 0.94789100E+00, -.29723100E+00, -.78159100E-01, 0.20576200E+00, -.13932700E+01, -.74211800E+00, 0.90714600E+00, 0.33910100E+01, -.14965700E+01, -.23644900E+01, -.16914000E+01, -.11958200E+01, -.45681100E-01, -.64966800E+00, 0.55077300E+00, 0.50556600E-01, 0.30938100E+00, -.25769100E+01, -.48653500E-02, 0.48245400E-01, -.64095600E-01, -.46418800E-01, 0.77356900E-01, -.43389700E-01, -.68839400E-01, 0.96612200E-01, 0.42013600E-03, 0.53629500E-02, -.18630500E-01, 0.33196700E-01, 0.11890700E+00, -.17721700E-01, -.18252500E+00, 0.23963100E-01, 0.45887000E-01, 0.33252000E-02, 0.13626700E+00, 0.50417300E-01, -.89834900E-01, -.13167900E-02, -.91425500E-02, -.12812200E+00, 0.38912500E+00, 0.16635800E+00 },
        { 0.56104600E-01, 0.27519100E-01, 0.61749700E+00, 0.28202500E-01, -.18102600E+00, 0.27050300E-01, 0.34130800E+00, -.16112700E+00, -.11586300E-01, 0.14007300E-01, -.13262100E-02, 0.30872700E+00, -.51943900E-01, 0.59703000E-01, -.38731200E-01, -.41718200E-01, 0.33014000E-01, 0.12690000E-01, 0.37659700E-01, -.18953700E-01, 0.65036100E-01, -.17565000E-01, -.23958100E-01, 0.75279300E-01, 0.58339800E-01, 0.29260100E-02, 0.18290300E-01, 0.37294100E-01, -.16755900E-01, -.43864600E-01, -.39492100E-01, -.37359100E-01, 0.89752000E-02, 0.65512100E-01, -.26121100E-02, -.33811900E-01, 0.41729100E-02, -.45850600E-01, -.24165600E-01, -.22882400E-01, 0.53004900E-01, -.45180500E-01, 0.18134600E-01, -.29003400E-01, -.13897400E+00, 0.83546000E-02, 0.57160200E-01, 0.23281900E-02, -.55523200E-02, 0.11164800E-01, -.29410900E-01, 0.85611800E-01, -.20370200E-03, 0.10731200E+00, -.99186700E-02, -.71455200E-03, -.14473300E-01, 0.52586200E-01, -.22388100E-02, -.12965900E-02, 0.20930200E-01, 0.97993100E-02, -.56981100E-02, 0.33177800E-01, -.70849200E-02, 0.43241200E-02, -.87711300E-02, -.14362800E-02, 0.65696100E-03, -.26816200E-04, -.62466100E-01, -.15193600E-01, 0.62463300E-03, -.20422100E-02, 0.46195300E-01, 0.32575700E-01, -.14874200E-01, -.73510900E-01, 0.20528800E-01, 0.46909800E-02, 0.15940500E-02, 0.10189100E-01, -.60198500E-01, 0.95408900E-02, 0.10407500E-01, -.35882600E-01, 0.13238200E-02, 0.86659400E-01, -.63744200E-01, -.41969600E-01, 0.44444600E-01, 0.51917500E-02, -.87336700E-01, 0.14612400E+00, 0.37463100E-01, 0.99247900E-01, -.40644900E-01, 0.14146000E-01, 0.80692600E-01, 0.27244500E-01, -.26093000E+00, -.36319200E-02, 0.39004200E-03, 0.44385700E-01, 0.26484700E-01, 0.54331600E-02, 0.42697400E-03, -.51609800E-01, -.42920400E-01, -.39398600E-02, 0.41758300E-01, -.48621600E-01, 0.44767400E-01, -.10569200E-02, -.18343100E-01, -.33481900E-01, 0.64817900E-02, 0.25069100E+00, 0.14121700E-02, 0.13447200E-01, 0.63154000E-02, -.18049700E-01, -.66155400E-02, -.16968300E-01, 0.23640700E-02, -.98394400E-01, -.77636300E-01, -.98926000E-02, -.95314500E-02, -.70066800E-02, 0.72054400E-02, 0.56209300E-01, -.45595300E-03, 0.29996100E-01, 0.18956300E-01, 0.13486000E-02, 0.74125900E-01, 0.80849800E-02, 0.16884100E-01, 0.81732000E-01, -.16634500E-01, -.10821900E+00, 0.11467100E-02, -.95722300E-01, -.34815500E-02, 0.60355000E-03, 0.15382600E-02, -.10011300E+00, -.10273700E-01, 0.34115100E-01, -.12496400E-01, -.96179400E-02, -.55537100E-02, -.16079000E-01, 0.26983200E-01, 0.52947200E-02, 0.16343200E-01, 0.37055400E-02, 0.11509800E-01, 0.61756700E-01, -.38183800E-01, 0.12068600E+00, -.19336400E-01, -.74966800E-02, 0.23056600E-01, 0.47700300E-01, -.78026400E-02, 0.15013000E-02, 0.19001100E-02, 0.25353700E-01, 0.21198900E-01, 0.68762700E-01, 0.34897700E-01, -.13327500E+00, 0.21691600E-01, 0.89790600E-01, -.37243100E-02, -.33039100E-02, 0.22116500E+00, 0.56564500E-04, 0.11831900E-01, -.35820300E-01, 0.14962900E+00, -.32854300E-01, -.42313800E-01, -.22407300E-01, -.18287000E+00, 0.84920600E-02, 0.83472700E-02, -.22737700E-03, 0.90168800E-04, 0.55110300E-01, -.16330400E-01, -.10476600E-01, 0.16728300E+00, -.67608400E-02, 0.29672600E-01, -.14083300E-01, -.93867200E-01, 0.12013400E-01, 0.38554100E-01, -.16983500E-02, -.19553800E+00, -.63824300E+00, 0.23048900E-02, -.56796900E-02, -.53673400E-01, -.10979700E+00, -.28767400E-02, -.25057000E-02, -.19523500E-01, -.19922800E-01, -.31575300E-03, -.55328300E+00, -.18396000E-01, -.22931000E-01, -.25464200E-02, 0.17950000E-01, 0.85220100E-03, -.19032000E-01, -.31644100E-01, -.51390300E-02, -.10170200E-01, 0.49089100E-02, 0.10924700E+00, -.16160300E-01, -.22724900E-01, -.17111100E-01, 0.15214200E-01, -.21080900E-03, -.18490000E-02, -.74833800E-02, -.31933500E-02, 0.10488700E-01, 0.45509200E-02, -.17679000E+00, -.11455500E+00, 0.32015700E+01, 0.11271100E+00, 0.52992200E-01, -.26085100E-01, 0.30686200E-01, 0.64844100E+01, -.33813600E+01, -.34179900E+01, -.32500100E+01, -.13973000E+00, -.82831500E-01, -.53932200E+00, 0.33683700E+01, 0.46501900E+00, -.32599500E+00, -.28670500E+01, -.72487300E+01, 0.41902300E+01, 0.34496000E+01, 0.36247100E+01, 0.73320100E+00, 0.14339400E+01, 0.13734300E+01, -.64377400E-01, 0.22062900E+01, 0.10047200E+01, 0.13361500E+01, 0.61282900E+01, -.33854700E+01, -.28881000E+01, -.30636900E+01, -.11456100E+01, -.36634400E+00, -.21054400E+01, -.74654700E+00, -.20750200E+01, 0.41375100E-01, 0.18728200E+00, 0.33015800E-01, 0.94340600E-01, -.28042200E+00, -.84505100E-01, -.64367900E-01, 0.47978700E-01, -.14989200E-02, 0.63171000E-01, 0.60838100E-02, -.52620100E-01, 0.89421000E-01, 0.15569900E+00, 0.86736000E-01, 0.67737300E-01, 0.60419300E-01, 0.92969300E-01, 0.89901400E-01, -.81443500E-02, 0.10554500E+00, 0.15957800E-01, -.47099800E-01, 0.40408900E-01, 0.21741500E-01, -.10164600E+00, 0.45691400E-02, 0.38208800E-01 },
        { -.10569200E+00, 0.36077700E+00, -.90533500E+00, -.19529600E+00, 0.33628800E+00, 0.87370500E-01, 0.98203800E+00, 0.63682300E+00, 0.20122900E+00, 0.22461200E-01, -.30132600E-02, -.59328700E+00, 0.71915100E-01, -.27248000E+00, -.24298300E-01, -.17105900E-01, -.39451300E+00, 0.90078300E-01, -.21443000E+00, 0.86996300E-01, -.87890500E-01, -.83560600E+00, -.53439500E-02, -.19281400E+00, -.12529800E+00, -.70274100E-01, -.27295000E+00, 0.86227300E-01, -.79088000E-01, 0.64515400E-01, 0.14561600E+00, 0.11806400E+00, 0.60069600E-01, -.11677800E+00, -.10961800E+00, 0.19121200E-01, -.23837900E-02, -.72832300E-01, -.43180600E-01, -.61334300E-02, -.90020000E-01, 0.39420600E-01, 0.25981800E+00, 0.22800900E-01, -.45286000E-01, -.23033200E-01, -.20151200E+00, -.86556000E-02, 0.62195800E-01, -.83239600E-01, 0.21256900E-01, -.87991500E-01, -.48205700E-01, -.32898100E+00, 0.14804100E-01, -.17403200E+00, -.21304300E-01, -.11786700E+00, 0.68129100E-01, -.12170600E-01, -.13611700E-01, 0.49274700E-01, -.21178300E-02, -.32697700E-01, -.84398100E-03, 0.27166200E-01, 0.60915200E-02, 0.11709100E+00, -.10174100E-01, 0.59398200E-03, -.21089400E+00, 0.48361700E-01, -.86772400E-02, -.57325800E-02, -.12008900E-01, 0.36360400E-01, -.73752900E-01, 0.37006900E-01, -.44622900E-01, 0.73725100E-01, 0.60131400E-02, 0.62439100E-02, -.12542900E+00, 0.36774100E-01, -.10956500E-01, 0.20969400E-01, 0.94300800E-01, -.57707800E-01, 0.19636400E+00, -.61278500E-02, -.13204900E+00, 0.53120900E-01, 0.99179700E-01, -.30366700E+00, 0.17905500E-01, -.21013200E-01, -.22262800E-01, 0.83134500E-01, -.11921500E+00, -.91334600E-01, 0.41520000E+00, -.11589000E+00, -.51116600E-02, 0.41411900E-01, -.11375800E-01, 0.69762300E-01, -.32656200E-01, -.20550800E+00, 0.97316100E-01, 0.41941100E-02, 0.42077500E-01, 0.41000200E-01, -.33532600E-01, 0.36789100E-03, 0.42469700E-02, -.69862400E-02, 0.53448500E-01, 0.25205600E+00, 0.47020500E-02, 0.14792000E-01, 0.12544300E-01, -.54335400E-01, -.46523200E-01, 0.58168300E-01, 0.23041600E-01, 0.28923000E+00, 0.18164000E+00, -.22957000E+00, -.86450500E-02, -.61706500E-01, -.91998600E-01, 0.19201200E+00, -.41146800E-01, 0.61065800E-01, 0.10220500E+00, -.44347000E-02, -.23677300E-02, 0.17438500E-01, -.35583300E-01, -.14793100E+00, 0.77610200E-01, -.17778500E+00, 0.25668000E-01, 0.14513200E+00, 0.22829400E+00, 0.34399900E-01, 0.32272500E-01, -.23887800E+00, 0.66087000E-01, -.13057700E+00, -.70430400E-01, -.27095300E-02, -.13352200E+00, -.59601500E-01, 0.23159400E+00, -.13389600E-01, 0.14492100E-01, 0.19839800E-01, -.13738500E-01, 0.81771700E-03, -.69842400E-01, 0.80562000E+00, -.44656600E-01, 0.14890900E-01, 0.38917800E-02, -.11819400E+00, -.77015400E-02, -.28497800E-01, -.13435400E-01, 0.56771400E-01, 0.62276000E-02, -.72299000E-01, -.83248400E-03, 0.30942700E+00, 0.16978500E-02, 0.15754100E+00, 0.71990900E-01, -.10359500E-01, -.28866800E+00, -.13285600E-03, 0.75927000E-01, 0.89057200E-01, 0.30547800E+00, -.58136000E-01, -.20834300E+00, -.12893700E+00, -.15614100E+00, -.36093200E-02, 0.10172400E-01, 0.13865800E-01, 0.25448100E-03, -.10776700E-01, -.25693000E-01, 0.99904000E-01, 0.15925500E+00, -.77261300E-01, 0.84880100E-01, -.70655300E-01, -.13969700E+00, 0.21540500E-01, -.35548400E-01, 0.45304100E-04, -.23809300E+00, 0.32177800E+00, 0.30055900E-01, 0.39636900E-02, -.32139900E-01, -.91037700E-02, -.41937100E-02, -.57585900E-01, -.15207500E-01, -.93001100E-01, 0.24361000E-03, -.67257300E+00, -.48724600E-01, 0.23402400E-01, 0.56718700E-02, -.78761100E-02, -.16269900E-01, 0.16587600E-01, -.16535700E+00, 0.26911000E-02, -.13369400E+00, 0.28787600E-04, 0.19816200E+00, 0.47634500E-02, -.15345300E-02, -.11486800E-01, 0.13554100E-01, 0.34154800E-02, -.10725400E-01, 0.12897400E-01, -.26189900E-02, -.43550200E-01, -.42417900E-02, 0.84386600E-02, -.12200700E+00, 0.37083400E-01, 0.12015100E+01, 0.12870200E+00, -.41849700E-01, 0.32461200E-02, 0.27522000E+01, -.12261400E+01, -.15783400E+01, -.13614600E+01, 0.34258700E+00, 0.91359300E+00, -.52095800E+00, 0.12643800E+01, -.46017200E+00, 0.64496100E+00, -.51758800E+00, -.26488700E-01, 0.14839200E+00, 0.61203800E+00, 0.11422200E-01, 0.32073900E+01, 0.12855500E+00, -.34008900E-01, -.64054700E-01, -.10088200E+01, -.29563300E-01, -.44718300E+01, -.28419800E-01, 0.10085800E-01, -.10195300E+01, 0.16423300E-01, -.49778500E+00, 0.17210800E+00, 0.15847100E+01, 0.42412000E+00, 0.48858500E+00, 0.94906400E+00, 0.29034900E+01, -.24480400E-01, 0.44781200E+00, -.31650600E-01, -.40335100E-01, 0.62613700E-01, 0.27257800E-01, -.11996500E+00, 0.42047300E+00, -.22288800E-01, 0.37822300E-01, 0.11542500E+00, 0.15113300E+00, 0.13598000E+00, -.87632700E-01, -.11205800E+00, 0.45294800E-01, -.50623200E-03, -.42060800E-02, 0.18404800E+00, 0.10417700E+00, -.16658200E+00, -.44130800E-01, 0.10131200E-01, 0.86184800E-01, 0.36170100E+00, 0.18920900E+00 },
        { 0.68921200E+00, -.16934300E+01, 0.84997500E+01, 0.11337500E+01, -.25279700E+01, -.93673600E+00, -.25429300E+01, 0.81121600E+00, 0.28504200E+00, -.68539800E+00, -.10774000E+01, 0.16505500E+00, 0.11505100E+00, 0.50202600E-01, -.27448400E+01, -.76824100E+00, 0.94240000E+00, -.69046900E+00, -.23042900E+01, 0.39238100E+00, -.60842800E-01, 0.68997100E+00, -.41568800E-01, 0.13403300E+01, 0.99072700E+00, 0.31343900E+00, 0.26758300E+01, -.97840000E+00, 0.59202800E+00, -.12134600E+01, 0.14473300E+00, -.43691600E+00, 0.94589200E-01, 0.46362200E-01, 0.59758900E+00, 0.70303400E+00, 0.58814300E-01, 0.16357300E+01, -.56502600E+00, 0.44320900E+00, -.31291000E+00, 0.24783000E+01, 0.11676500E+01, -.77265600E+00, -.38412100E+00, 0.59465200E+00, 0.48268500E+01, 0.23933800E+00, 0.55201700E+00, 0.19307200E+00, 0.73443500E-01, 0.51447800E+00, 0.74112100E+00, -.10159100E+02, -.20168400E+01, -.11728800E+00, 0.18075200E+01, -.73448200E+00, -.46380300E+00, -.20492800E+01, 0.49221300E+00, -.31004800E+00, 0.10603200E+01, -.50976400E+00, -.13282200E-01, 0.60659500E+00, 0.22411400E+00, -.15906300E+01, -.62661300E+00, -.28341300E-02, -.43680900E+00, 0.17901200E+01, 0.68267700E+00, 0.40453600E+00, 0.42333700E+00, -.13203700E+01, 0.27073800E+00, 0.12042000E+01, 0.78639300E-01, 0.98943100E+00, -.57882400E-02, -.38917300E+00, 0.24815300E+01, 0.22135300E+00, -.64392400E+00, 0.68420300E+00, 0.16144900E+00, -.33385000E+01, -.26424000E+01, 0.95164200E+00, 0.67669100E+00, 0.41427500E-01, 0.26966500E+00, -.51807100E+00, -.10715700E+00, -.52419700E+00, -.13757000E+01, 0.70422200E+00, -.12824700E+00, -.75802100E+00, -.86512000E-01, -.15392700E+01, 0.44459200E-01, 0.72777600E+00, 0.86326500E+00, -.53712100E+00, -.44164100E+00, 0.85117500E+00, -.83784900E+00, -.33583900E+00, -.33961600E+00, -.55881700E-01, -.47351300E+00, 0.44730700E-01, -.34566400E+00, 0.70698700E+00, 0.20060700E+00, 0.77178000E+00, -.15359600E+01, 0.55353700E-01, -.59113400E+00, 0.64949700E+00, 0.10688200E-01, 0.18371400E+01, -.12389100E+00, 0.97104700E+00, 0.37811100E+00, 0.40488100E+00, 0.16688800E+00, -.18211800E+00, 0.45783900E+00, 0.11187400E+01, -.52911500E-01, -.10876100E+00, -.50057200E+00, -.70594500E-02, 0.21510900E+00, 0.26892200E+00, 0.42399300E+00, 0.90200600E-01, -.11208800E+00, -.21618500E+00, -.16355900E+00, 0.13573000E+01, 0.97389000E+00, 0.18049700E-01, 0.94616200E-03, 0.38444700E-01, 0.13217200E+01, -.47742300E+00, -.12429200E+01, 0.70636700E+00, 0.74915400E+00, -.57102400E+00, -.13888600E+00, 0.86574200E-01, 0.84374700E+00, -.77884000E-01, -.40862200E+00, 0.19705700E+00, -.41051600E+00, 0.66687100E+00, -.10926100E-01, -.92091600E-01, 0.60888200E+00, 0.69407300E-01, 0.12222000E-01, 0.14244900E+00, 0.49903800E-01, -.28767600E+00, 0.98556100E-01, 0.12390200E+01, -.15420800E+00, -.15347400E+01, -.93727700E-01, 0.73674800E+00, 0.38894000E-01, -.79901800E-01, 0.29510700E+00, 0.25851700E-02, -.12648200E+00, -.23032900E+01, -.54198100E+00, -.25165100E+00, 0.31398000E+00, 0.36831300E+00, -.37756300E+01, 0.69519100E+00, -.85125000E-01, -.16936800E+00, -.21207500E-02, -.26033400E+00, -.32688100E-01, 0.64008600E-01, -.73650800E+00, -.51895100E+00, -.10129400E+01, 0.42416400E+00, 0.99650300E+00, -.50927500E-01, -.46267800E+00, 0.11907500E+00, 0.40459100E+01, 0.16674800E+01, 0.10073300E+00, 0.17606600E-01, 0.91539500E+00, -.73646700E+00, 0.76298800E-01, -.47227900E+00, 0.11733800E+00, 0.76880300E+00, 0.22639600E-02, 0.55591400E+01, 0.87316000E+00, -.56142600E+00, -.64157500E+00, 0.64772600E+00, 0.58395800E+00, -.67422800E+00, 0.16739100E+01, -.28965900E+00, 0.38865000E+01, 0.83750400E-01, -.27670700E+01, 0.12002300E+00, 0.64866600E+00, 0.69056700E+00, -.24702600E-01, 0.78339500E-01, 0.14505900E+00, -.22522500E+00, 0.69067400E-01, 0.14756300E+01, 0.54716500E-01, -.27863600E+00, 0.81617000E+01, -.74432900E+00, 0.41911900E-01, -.28747400E+01, 0.88673600E+00, 0.85640200E+00, -.28405000E+03, 0.15364700E+03, 0.14304000E+03, 0.14172500E+03, 0.20460400E+02, 0.32677600E+02, 0.50311600E+02, -.53498600E+02, -.51711300E+00, 0.28084700E+02, 0.80744100E+02, -.25445300E+02, 0.18325800E+02, -.40888600E+02, 0.12740700E+02, -.42066000E+02, 0.60558700E+02, -.73388200E+01, -.24896200E+02, 0.70237700E+01, 0.53711700E+02, -.13129500E+03, -.61969000E+02, 0.27966900E+02, 0.63107100E+02, 0.30949900E+02, 0.13287600E+02, -.15384500E+02, -.14602500E+02, 0.54442500E+02, 0.15096400E+02, -.17824900E+02, 0.20871800E+03, 0.83705300E+00, -.10501000E+02, 0.38354500E+01, -.12589700E+01, -.27196200E+01, -.12022200E+01, -.37044300E+00, -.99640600E+01, 0.10276500E+01, -.15035700E+01, -.31057600E+01, 0.28271700E+01, -.57841700E+01, 0.31131700E+01, 0.59057400E+01, 0.12760100E+01, -.25572300E+00, 0.68543800E+00, -.87912100E+01, -.69336900E+00, 0.65711800E+01, 0.13394200E+01, 0.86252000E+00, -.71326700E+01, -.67635800E+01, 0.85689800E+00 },
        { 0.51080100E-01, -.18589000E+00, 0.25322100E-01, 0.56264600E-01, -.16601600E+00, -.57138100E-01, -.26718900E+00, 0.19782500E+00, 0.74680900E-01, -.17812300E+00, -.17799800E-01, 0.34706500E+00, -.31502500E-01, 0.19967300E+00, -.57946500E-01, -.49776000E-01, 0.25492700E+00, -.28586300E-01, -.11711200E+00, -.50093400E-01, 0.11234500E+00, 0.36650200E+00, 0.56630500E-03, -.10156200E-01, 0.30805100E-01, -.33500100E-01, 0.26065600E-01, 0.15505800E+00, 0.55202200E-01, -.99924500E-01, 0.15713000E-01, -.64923100E-01, -.64428900E-01, 0.80939900E-01, -.12796700E-01, -.10090800E-01, 0.30417900E-02, -.29892100E-01, -.41827000E-01, -.22032300E-01, 0.14007200E+00, -.39020300E-01, -.31999400E+00, -.31280500E-01, -.19122100E-01, -.12943500E-01, -.19540000E-01, 0.81247500E-02, -.55895900E-01, 0.78024500E-01, -.54501500E-01, 0.54118500E-01, 0.64718900E-01, -.30065200E+00, 0.29535000E-01, -.55124100E-01, -.85189800E-02, 0.15824900E-02, -.39017200E-01, -.59026400E-02, 0.10864000E-01, -.44032900E-02, 0.14691700E-01, -.35012800E-02, 0.80320500E-02, 0.85380400E-02, 0.22015300E-01, -.26339100E-01, -.79797200E-01, -.71280000E-03, 0.14954600E+00, 0.14067900E+00, 0.24753000E-01, 0.14202900E-01, -.18179000E-01, -.14486900E-01, 0.90856000E-02, 0.17716700E-01, 0.53271300E-01, -.43300600E-01, -.11871000E-02, -.12916100E-01, 0.16375900E+00, 0.45008100E-02, -.23148000E-01, 0.15465200E-01, -.46523500E-01, -.15591700E+00, -.23060900E+00, 0.20501000E-01, 0.67530300E-01, -.57729000E-02, -.26593800E-01, -.17604300E-01, -.80470800E-01, -.12009000E+00, 0.35561900E-01, -.18038200E-01, 0.10772700E-01, 0.13268900E-01, 0.13662000E+00, 0.10551100E+00, -.28568700E-02, 0.78542100E-02, -.88373500E-02, -.21312700E-01, 0.94122800E-02, 0.80343200E-01, -.29890200E-01, -.19479500E-01, -.60896900E-02, 0.54282100E-01, -.25093400E-01, 0.33642800E-02, 0.33472500E-01, 0.35584000E-01, -.31360700E-01, -.21266900E+00, -.42485500E-02, -.26936900E-01, 0.52633300E-01, -.13865500E+00, -.16848600E-01, -.30017800E-01, 0.74120900E-02, 0.49178000E-01, 0.40413200E-01, 0.69040000E-01, 0.14966200E-01, 0.10901400E-01, 0.85139200E-02, -.13023200E+00, 0.82616800E-02, -.34015000E-01, -.38449300E-01, -.12693000E-02, -.73845000E-01, -.26526300E-01, -.20004800E-01, -.11086900E+00, -.92840700E-03, 0.24182200E-01, 0.11465700E-01, -.69568900E-01, -.99004900E-01, -.14362000E-01, -.85048400E-02, 0.99676600E-01, -.17266700E-01, 0.13361000E-01, 0.87916500E-01, -.42219900E-01, 0.40788500E-01, 0.95998700E-01, -.35284800E-01, -.10277500E-01, -.20931100E-03, -.47654300E-02, -.55785700E-02, 0.57838700E-01, 0.16584900E-01, -.14545700E+00, 0.33728300E-01, -.10314800E-01, 0.10237300E-01, 0.36459200E-01, 0.14566500E-01, 0.17233600E-01, 0.60390600E-02, -.30556400E-01, -.93722700E-02, 0.47336200E-01, -.28222800E-01, -.12075000E+00, -.19976900E-01, -.15113800E+00, -.33314600E-01, 0.56756900E-02, -.99966900E-01, 0.16159500E-03, -.20352000E-01, -.39615000E-01, -.16040800E+00, 0.33010400E-01, 0.42665600E-01, -.10810300E-01, 0.40799200E+00, 0.25090100E-01, -.13886600E-03, 0.45825000E-03, -.26568800E-03, -.72993900E-01, -.22860200E-01, 0.54773900E-01, -.87690700E-01, -.31953500E-01, -.14704800E+00, -.26549900E-01, -.86668600E-02, -.19916500E-01, 0.91717400E-01, -.50587900E-02, 0.25735300E+00, -.51374400E+00, 0.99862700E-02, 0.15538200E-01, -.15976600E-01, -.65308700E-01, 0.88408100E-02, -.74028100E-01, 0.13300300E-01, 0.77422300E-01, -.58056200E-04, 0.25606100E+00, 0.45563800E-01, -.25697300E-01, 0.58114700E-02, 0.26090700E-01, 0.13320800E-01, 0.38025200E-02, 0.59653900E-02, -.48963000E-02, 0.18461100E+00, -.21699600E-02, -.37426500E-02, 0.35233500E-02, 0.32125900E-02, -.62341800E-03, -.54946300E-02, -.65446300E-03, -.35026400E-02, -.91964500E-02, 0.23365700E-02, -.13461800E-01, 0.35151100E-02, 0.13586000E+00, 0.15023000E+00, -.60960300E-02, -.22696900E-01, -.13061400E-02, 0.24287900E+00, 0.31075200E-01, 0.18997200E+00, -.88098300E-01, -.29461700E+00, -.94093800E-01, 0.44020900E-01, 0.11192100E+00, 0.54483400E-01, -.11984800E+00, -.42859700E-01, 0.54642300E-01, 0.13369900E+00, 0.38651900E+00, -.26349900E+00, 0.55911800E+00, -.19320400E+00, 0.23196600E+01, 0.23682000E+00, -.75407500E+00, -.29928100E-01, -.41992700E+00, 0.16414500E+00, -.59049000E+00, -.40238600E+00, 0.24522500E+00, -.15750900E-01, 0.20097500E+00, -.76958300E+00, 0.37168300E-01, 0.91075800E+00, -.24698800E+00, 0.39831400E+00, 0.22074900E+00, -.23006700E-01, 0.10378000E-01, 0.55682500E-01, 0.43622000E-01, -.12596700E-01, 0.35368400E-01, -.51585400E-01, -.17927600E-01, 0.58789300E-01, -.10993300E-01, 0.13516500E-01, -.12562300E-01, 0.17279900E-01, 0.12059500E-01, -.31649300E-01, -.69532100E-01, 0.13169300E-01, -.27977700E-01, 0.16717500E-01, 0.12924000E+00, 0.46436900E-02, -.11969200E+00, -.16061100E-01, -.15625500E-01, 0.83117600E-01, 0.90182000E-01, 0.38498800E-01 },
        { 0.20797300E+00, -.58765600E+00, 0.24112400E+01, 0.28494000E+00, -.78584000E+00, -.25927200E+00, -.84903300E+00, 0.54114100E+00, 0.21403700E+00, -.16288100E+00, -.30680000E+00, 0.45862900E+00, -.16795300E+00, 0.27627100E-01, -.23318100E+00, -.88190000E-01, 0.44947900E+00, -.13668200E+00, 0.23914800E-01, -.14728300E+00, 0.41563400E+00, 0.73523800E+00, -.75100900E-02, 0.34619400E+00, 0.16264100E+00, 0.26167000E-01, 0.28775200E+00, -.29824100E+00, 0.44195700E-01, -.10583600E+00, -.21560700E-01, -.32998000E-01, 0.13625700E+00, -.13401300E+00, -.17938300E+00, 0.95243200E-01, 0.13350500E-01, -.18814800E+00, -.30586800E+00, 0.81678500E-01, 0.15377100E+00, 0.10149800E+01, 0.73463900E+00, 0.12568500E+00, -.43746400E+00, -.14279000E+00, -.29480900E+00, 0.29462600E-01, -.41844700E-01, 0.50078900E-01, 0.17002000E+00, -.41333500E+00, -.11033500E+00, 0.44758200E-01, 0.32196400E+00, -.12403100E+00, 0.33550300E-01, -.82403200E-01, -.58983300E-01, -.23168900E-02, -.51857800E-01, 0.82468500E-02, 0.22509700E-01, -.17390600E-02, 0.24944500E-01, -.49763900E-01, -.24838000E-01, -.37759600E+00, 0.10517100E+00, 0.10808200E-02, 0.20639500E+00, 0.36467300E+00, -.17296500E-02, 0.53954000E-01, -.95037600E-01, 0.53300000E-01, 0.12204800E+00, 0.62525800E-01, 0.71388900E-01, -.11392000E+00, -.10863400E-01, 0.76309400E-02, 0.64860100E-01, -.15242000E+00, -.22098800E-02, -.68237500E-01, 0.14700700E+00, -.10766900E+00, -.22819400E+00, 0.10980500E-01, -.56096500E-01, -.10147600E+00, 0.67011600E-01, 0.35245800E+00, -.12047100E+00, -.27584500E+00, -.46927300E-01, 0.97033300E-01, 0.67313900E-01, 0.10844900E+00, -.46225300E-01, 0.13885600E+00, 0.48185200E-02, 0.28794300E-01, 0.87776200E-02, 0.63547200E-01, 0.88578400E-02, 0.21070700E+00, -.83541900E-02, 0.16752300E+00, -.52699000E-01, 0.32852500E-01, 0.23742900E-01, -.21665700E-01, -.68498700E-02, -.63685900E-02, -.71146100E-01, -.38281200E+00, 0.11458200E+00, -.15256000E-01, -.20208800E-01, -.55980100E-01, 0.37033300E-01, -.10606400E+00, -.64727000E-02, -.10996800E+00, -.16711200E+00, 0.20799500E+00, 0.13115800E-01, -.20854900E-01, 0.10107700E+00, -.62976800E-01, 0.71100700E-02, -.74635600E-01, -.55159400E-01, -.18592100E-02, 0.43862500E-01, 0.60384200E-01, 0.35779500E-01, 0.99907400E-01, -.51352900E-01, -.53848100E-01, -.78521700E-01, -.98345400E-01, -.29649700E+00, -.84717800E-01, 0.51340700E-02, 0.30510400E+00, -.95302200E-01, 0.61278000E-01, 0.40916600E-02, 0.33675100E-01, 0.18643000E+00, 0.18475100E+00, -.39589200E+00, -.30734000E-02, -.15994000E+00, -.18570200E-01, -.64817400E-02, -.40469900E-01, 0.16566900E+00, -.83789300E+00, 0.55532100E-02, -.10469900E-01, 0.67001300E-02, -.21476300E-01, -.56293400E-02, -.33330800E-02, 0.43794900E-02, -.48883100E-01, 0.74212900E-01, 0.15870100E+00, 0.19585800E-01, -.92830300E-01, 0.11044100E-01, -.11033100E+00, -.92884800E-01, 0.62080200E-02, -.43982000E+00, -.91597300E-04, -.95580300E-02, 0.15146700E-01, -.20416700E+00, 0.58609000E-01, 0.96793800E-01, 0.41085000E-02, 0.13001200E+00, -.25811100E-01, -.19810300E-01, -.49492900E-01, -.83897200E-04, 0.71037700E-01, 0.23300200E-01, -.16411700E-03, -.32697000E+00, -.17941000E+00, 0.83251400E-01, 0.17489900E+00, -.49435500E-01, -.18128200E-01, 0.21599300E-01, -.53478000E-02, 0.20978000E+00, 0.81174000E-01, 0.51826500E-02, 0.15612500E+00, 0.94239900E-02, -.14452000E+00, 0.16140500E-01, 0.21861700E+00, -.25793600E-02, 0.18876200E+00, -.16318700E-03, 0.41635600E+00, -.23931500E-01, -.13410800E-01, 0.17274700E-01, -.35286600E-01, -.12898700E-01, -.29377500E-01, 0.41951000E+00, 0.37128500E-02, -.16017200E+00, -.59453800E-02, -.18782900E+00, 0.30368600E-01, 0.74244100E-02, -.28840700E-01, 0.69556300E-02, 0.32252200E-01, -.39899500E-02, -.35807100E-01, 0.11943800E-01, -.20183800E-01, 0.12928100E-01, -.14848900E+00, 0.14830200E+00, -.65093100E-02, -.75908700E-01, -.80561600E-03, 0.24097300E+00, 0.23319700E+01, 0.14075000E+02, -.69966700E+01, -.66653800E+01, -.70581600E+01, -.22863800E+01, -.46537200E+01, -.25161800E+01, 0.97510200E-01, -.84553000E+00, -.40608100E+01, -.43920800E+01, -.53259700E+01, 0.28853400E+01, -.61761400E+00, 0.26662900E+01, -.17851600E+01, -.37423200E+00, 0.18327600E+01, 0.10070200E+01, 0.46238200E+01, -.11190200E-01, 0.11267300E+02, 0.20146300E+01, -.12196400E+01, 0.10723000E+01, -.10116400E+01, 0.22402100E+00, -.80065100E+00, -.20169800E+01, -.24055100E+01, -.24409600E+01, -.19079900E+01, -.75028600E+01, 0.82778900E-01, -.55442100E+00, 0.88709800E-01, -.16791500E+00, -.12801000E+00, -.13469800E-01, 0.20002500E+00, -.60114800E+00, -.49421400E-01, 0.44053400E-01, 0.11236600E-01, -.38833100E-01, 0.49276900E-01, -.11498200E+00, 0.36824100E+00, 0.77378500E-01, -.23756500E+00, -.11428700E+00, 0.91106900E-01, -.42338000E-01, -.12524300E+00, -.18275600E-01, -.26033100E-01, 0.35416900E+00, -.83739300E+00, -.46726500E+00 },
        { -.17702500E+00, 0.27056900E+00, -.30878400E+00, -.11853300E+00, 0.83683700E+00, 0.25063000E+00, 0.14658900E+01, -.57992900E+00, -.30890500E+00, 0.51743100E+00, 0.88647600E-01, -.20117000E+01, 0.31250900E+00, -.86758500E+00, -.66813600E+00, -.64431200E-01, -.15274000E+01, 0.21359400E+00, -.36019900E+00, 0.27381900E+00, -.57840200E+00, -.18358500E+01, 0.15503300E+00, -.20077700E+00, -.34450200E+00, -.23063000E+00, -.46724300E+00, -.39182000E+00, -.24773700E+00, 0.58575400E+00, 0.13001300E+00, 0.31405900E+00, 0.25341800E+00, -.31184600E+00, 0.11773000E+00, -.83002400E-02, 0.12188700E-01, 0.92908800E-01, 0.37352100E+00, 0.59202900E-01, -.41061300E+00, 0.10185700E+01, 0.11704800E+01, 0.65445200E+00, -.33565800E+00, -.80608900E-01, -.71760000E+00, -.24106700E-01, 0.66659600E-01, 0.95448300E-01, 0.55888200E+00, -.72454500E+00, -.37626800E+00, 0.35684200E+01, 0.45145300E+00, 0.39377200E+00, -.80921200E-01, -.59160600E+00, 0.12442000E+00, -.31825500E-02, 0.41937700E+00, -.18332500E+00, -.22754100E-01, -.40798200E+00, -.22421000E-01, -.21348400E+00, -.78059800E-02, 0.59142100E+00, 0.30356400E+00, 0.10838200E-01, -.15590400E+01, -.65861700E+00, 0.41537700E-01, -.34121700E-01, -.24942000E+00, 0.45662700E+00, -.30546400E+00, 0.38073800E+00, -.13424200E-01, -.17147200E+00, 0.14100400E-01, 0.42310600E-01, -.47166200E+00, -.12231300E+00, 0.18616600E+00, -.24711900E+00, 0.66296900E+00, 0.10640100E+01, 0.28545300E+00, -.16360500E+00, -.90488000E+00, 0.11034900E+00, 0.26853500E+00, -.55411000E+00, 0.25432700E+00, -.51227700E-02, -.39757600E+00, 0.36291400E+00, 0.37338500E-01, 0.45953800E-02, 0.23239900E+00, -.41847300E+00, -.26956100E-01, -.75514900E-01, -.85386900E-01, 0.52648700E+00, 0.10552900E+00, -.72602100E+00, -.12933200E+00, 0.25455400E+00, 0.70750200E+00, 0.24643000E+00, 0.28529100E+00, -.10130100E-01, -.16856400E-01, -.25676600E+00, 0.12045800E+00, -.11639800E+01, 0.15121400E-01, 0.55046300E-01, -.12168400E+00, 0.78970900E+00, 0.12546400E+00, -.34530700E+00, 0.10348100E-01, -.11304000E+01, 0.32567600E-02, -.83111200E+00, -.19017300E+00, -.93791000E-01, -.13569100E+00, 0.89083200E+00, -.73557900E-01, 0.21791800E+00, 0.17699800E+00, -.15328500E-02, -.46160700E+00, 0.34964200E-01, 0.19246200E-01, 0.13385100E+00, 0.14999900E+00, 0.14298800E+01, 0.92514100E-01, 0.53018400E+00, 0.59998500E+00, 0.25901300E-01, -.42817800E-01, 0.90555600E-02, 0.68454700E+00, 0.14017400E+00, -.32847700E+00, 0.12055300E+00, -.60763500E+00, -.11232600E+00, -.16086000E+00, -.19139100E+00, 0.32732500E+00, -.19659100E-01, 0.90489000E-02, -.15807100E-02, 0.24758600E+00, 0.57133700E+00, 0.17429800E+00, -.68039700E-01, -.47085800E-01, 0.71987800E-01, -.17822200E-01, 0.94587400E-01, 0.11058200E-01, -.16495000E+00, 0.65045600E-01, -.46089500E-01, -.88143000E-01, 0.26525700E+00, -.80012400E-01, 0.21129000E+00, 0.96306700E-01, -.25806100E-02, -.61140900E+00, -.16864500E-03, 0.88964700E-01, -.14073000E+00, 0.13673300E+00, -.66537200E-01, -.12991200E+00, 0.48035400E-02, 0.18504600E-03, 0.71695000E-01, 0.31593600E-01, 0.10592400E+00, 0.59080800E-03, 0.85013200E-01, -.40991500E-01, -.75162900E-01, 0.35372400E+00, 0.24080300E+00, 0.12617000E+00, 0.77813800E-02, 0.29103300E-01, 0.71529200E-02, 0.16930200E+00, -.27314800E-01, 0.17295300E+01, -.22334400E+01, -.16250300E-01, -.19386600E-01, -.15506400E+00, 0.40596300E-01, -.95533000E-02, 0.84702300E-01, 0.21737400E-02, -.27495600E+00, 0.66925200E-03, -.14907000E+01, -.45209100E-01, 0.14369000E+00, 0.74999900E-01, -.31572100E+00, -.68835100E-01, -.16045900E+00, -.35091500E+00, -.22875000E-01, -.55813300E+00, 0.14933900E-01, -.20585100E-01, 0.69232800E-01, 0.36415200E+00, 0.11436300E-01, 0.38668100E-01, 0.13256200E+00, -.75017700E-01, -.34206900E+00, 0.49539800E-01, 0.56934100E+00, 0.13162400E+00, 0.10109300E+00, -.64326800E+00, 0.55336000E-01, -.60427300E+00, -.55997100E-01, 0.19150400E+00, -.22185200E+00, -.93249600E+02, 0.47333500E+02, 0.51035100E+02, 0.46477900E+02, -.17208900E+00, -.35546200E+01, 0.13470600E+02, -.31163600E+02, 0.95019400E+01, -.15834900E+01, 0.36143800E+02, 0.92842200E+02, -.43269800E+02, -.83323200E+02, -.46351700E+02, -.73790700E+02, -.61860300E+02, 0.86410400E+01, 0.33312800E+02, 0.10648000E+02, -.41345700E+02, -.51562100E+02, -.10964800E+03, 0.52061700E+02, 0.54149200E+02, 0.54747300E+02, 0.49494500E+02, 0.17414500E+02, 0.12133500E+02, -.47092000E+02, 0.10337200E+02, 0.29442500E+01, 0.53524000E+02, 0.84995100E+00, 0.14617600E+01, 0.13364600E+01, -.44303500E+00, -.15284300E+01, 0.10380200E+01, 0.10444300E+01, 0.92556500E-01, 0.22975000E-01, -.60972400E+00, 0.14326000E+00, -.56405400E+00, -.28518400E+00, 0.15259300E+01, 0.19088700E+01, -.14356500E+00, -.78627100E+00, 0.14048000E+00, -.48285800E+01, -.65581400E+00, 0.37199700E+01, 0.65288100E+00, 0.14048700E+00, -.69686400E+00, -.84032300E+01, -.32682800E+01 },
        { -.11677200E+01, -.83581700E+01, 0.26312300E+01, -.50987100E+00, 0.58666300E+00, 0.22956100E+01, 0.55487300E+00, -.16145000E+00, -.31698500E+00, 0.14907700E+00, 0.62541900E+00, -.20826700E+01, -.72632900E+00, -.19807800E+01, -.12891000E+01, 0.90808700E+00, 0.15651400E+01, -.21645600E+00, -.23969900E-01, -.64753700E+00, 0.45316900E+00, -.34314400E+01, -.53187900E+00, -.59017400E+01, -.19943400E+01, 0.10513400E+01, -.24730700E+00, -.38589100E+00, -.40472900E+00, 0.47781600E+00, -.33512500E+00, 0.97909700E+00, 0.19958700E+01, -.44469300E+00, -.90576200E+00, 0.11719100E+01, -.28968900E-01, 0.48036500E+00, -.79504600E+00, 0.31149600E-01, -.28241200E+01, -.10736300E+02, -.36654300E+01, 0.57354200E-01, -.66036200E+00, 0.64950200E+00, 0.31955700E+01, 0.83905900E-01, 0.99147900E+00, 0.91791100E+00, -.20970400E+01, 0.41737100E+01, 0.61048300E-01, 0.20370600E+01, -.36424800E+00, -.13512900E+01, -.19987500E+00, 0.18673500E+01, 0.67701800E+00, 0.15921100E+01, -.66419100E+00, 0.11090700E+01, -.12602700E+01, 0.24136100E+01, -.18907100E+00, 0.52047500E-02, -.95404800E+00, 0.30938400E+00, -.98914900E-01, -.40111500E-02, -.19912900E+01, -.22825200E+01, -.19578500E+00, -.35122000E+00, 0.13122900E+01, -.21480800E+00, -.98283700E+00, -.59555100E+00, -.99187800E+00, 0.10693900E+01, 0.87923700E-01, -.90993900E-01, -.14587600E+01, 0.83495900E-01, -.11197200E+00, -.31676900E+00, 0.14417100E+01, -.98567000E+00, 0.76713700E+00, 0.56637000E+00, -.50967300E-01, 0.74070700E+00, 0.26570900E+01, -.61464600E+01, -.91873100E+00, -.11993300E+00, 0.16150800E+01, 0.96499500E+00, -.13097300E+01, -.12219700E+01, 0.53992400E+01, -.21294000E+01, -.68483900E-01, 0.48548800E+00, 0.22804900E+00, 0.11627100E+01, -.49952900E+00, 0.12387100E+00, 0.52665200E+00, -.67648700E+00, 0.10461700E+01, 0.32544600E+01, -.39470600E+00, -.14370200E+00, -.48874200E+00, -.47646100E+00, 0.11960500E+00, 0.43065000E+00, -.62286200E+00, -.37666000E-01, -.25299400E+00, 0.22328900E+01, 0.38784900E+00, 0.50665200E+00, -.18325100E-01, 0.16079700E+01, 0.22134400E+00, 0.46488700E+00, 0.24555600E+00, 0.27995200E-01, -.11016900E+00, 0.30865400E+00, -.59380100E-01, 0.35774200E+00, -.42245000E+00, 0.46043600E-02, -.12507600E+01, -.46449900E+00, -.40890100E+00, -.80141200E+00, 0.33646500E+00, 0.18739800E+01, 0.38399500E+00, 0.13651000E+01, 0.12850000E+01, 0.60536300E-01, -.82637400E-02, -.14964800E+00, 0.19118900E+00, -.34708700E+00, 0.20432600E-01, -.40000400E-01, -.11150200E+00, -.21797300E+01, 0.10325800E+01, -.22211300E+00, 0.76734600E+00, -.10128200E+00, 0.63386100E-01, 0.73739200E+00, 0.25122700E+00, 0.23074700E+01, 0.55455100E+00, -.17814800E+00, 0.17248900E+00, -.34080000E+00, 0.19461200E+00, -.35478000E+00, 0.27273600E-01, 0.51180300E+00, -.37092200E+00, -.12590200E+01, 0.28669500E-01, 0.55713300E-02, 0.18059300E+00, -.79967400E+00, -.17747800E+00, 0.56489500E-01, 0.65663700E+00, -.20717000E-02, -.26004200E+00, 0.41156600E+00, -.12232400E+01, 0.22206300E+00, 0.67197900E+00, 0.29605900E-01, 0.66881200E+00, 0.27598100E+00, -.15186500E+00, -.25209100E-02, -.29852000E-03, -.32981500E+00, 0.23436500E+00, 0.98590500E-01, 0.85879300E+00, 0.47832000E+00, -.20734000E+00, 0.57023000E+00, 0.93579400E+00, -.81430600E-01, 0.24999800E+00, -.66727400E-01, 0.53814100E+01, 0.33251600E+01, 0.19807000E+00, 0.10292800E+01, 0.61047900E+00, 0.12044800E+01, -.10926000E-01, 0.19004000E+01, -.75110800E-01, -.29887800E+01, -.78338500E-02, -.45040100E+01, -.16107400E+01, -.25426300E+00, -.19969200E+00, 0.13491800E-01, -.41382600E+00, 0.41441700E+00, 0.13026600E+01, 0.46763400E+00, -.48096500E+00, -.48744000E-01, -.37471500E+00, 0.94363000E-01, 0.30244000E+00, -.25458700E-01, 0.51936900E+00, 0.36318500E+00, -.25163900E+00, -.17669400E+00, 0.11749800E-01, 0.38228400E+00, 0.69647300E-01, 0.99744800E+00, -.26934900E+01, 0.22545000E+00, -.73740300E+00, -.28425400E+00, -.59854800E+00, -.18798600E+00, 0.24554400E+01, 0.32442400E+02, -.10145600E+02, 0.28827300E+00, 0.50333500E+01, 0.16961100E+02, -.13722800E+02, 0.20520100E+02, -.49531900E+01, 0.17257600E+02, -.18890200E+02, -.54328500E+02, 0.22412500E+02, 0.84488000E+02, 0.27085600E+02, 0.14814000E+03, 0.94228000E+02, -.39284300E+02, -.39526500E+02, -.56754000E+02, 0.63436400E+02, 0.10644700E+02, 0.16119400E+03, -.77627200E+02, -.84776300E+02, -.80508800E+02, -.10306900E+03, -.28382400E+02, -.14616800E+01, 0.86058400E+02, 0.13486600E+01, -.16092000E+01, -.57701200E+02, -.15557700E+01, -.22693700E+01, 0.86435900E-01, 0.25422200E+00, 0.28572300E+01, -.21810700E+01, -.19317700E+01, 0.26957800E+00, 0.97490500E-01, 0.84037200E+00, -.72972500E+00, 0.73259400E+00, -.11938700E-01, -.23750700E+01, -.33374400E+01, -.18315700E+00, 0.10100200E+01, -.36168600E+00, 0.79155600E+01, 0.10999700E+01, -.64245500E+01, -.84207700E+00, -.18039500E+00, -.47738700E+01, 0.16642100E+02, 0.96650600E+01 },
        { 0.26842900E+00, -.99853200E+00, 0.14890700E+00, 0.41546600E+00, -.70008200E+00, -.42062600E+00, -.10066900E+01, 0.16431200E+01, 0.34560300E+00, -.51424100E+00, 0.37205300E-01, 0.81735800E+00, -.65213600E+00, 0.44902100E+00, 0.58699300E+00, 0.49315000E-01, 0.19128300E+01, -.17306900E+00, -.12573000E+01, 0.23275700E+00, 0.91691400E+00, -.25794100E+01, -.19596700E+00, 0.89235200E+00, 0.24184600E+00, 0.85257800E-01, -.18074400E+00, -.50782400E-01, -.20517400E+00, -.55597100E+00, 0.41687800E-01, -.24347300E+00, 0.58384100E+00, -.18414400E-01, -.13229300E+00, -.52660600E+00, 0.80901400E-01, -.85351200E+00, -.53316300E-01, -.98264300E+00, 0.78690300E+00, 0.12942100E+00, -.19765700E+01, -.10533400E+00, -.53056900E+00, 0.46280300E-02, -.22129600E+00, 0.49811400E-01, -.28276900E+00, 0.26120700E+00, -.50564300E+00, 0.88413300E+00, 0.61310300E+00, -.48002600E+01, -.14548000E+00, -.14447800E+01, 0.25839000E+00, 0.10165300E-01, -.60662500E-01, -.43272500E+00, 0.20300700E+00, 0.62471200E+00, 0.71077600E-01, -.14908600E+00, 0.12484500E+00, -.50159500E+00, -.36998600E+00, -.60889600E+00, 0.10970900E+01, 0.41569100E-02, 0.50567600E-01, 0.59130100E+00, -.43065000E+00, -.69316000E-01, 0.15225500E+00, -.16607800E+00, -.12252600E+00, -.56774500E+00, -.13928800E+00, 0.47579200E+00, 0.19123000E-01, -.10581300E+00, -.92553100E+00, 0.37010200E+00, 0.21433400E+00, -.40215600E+00, 0.73083000E+00, -.10405000E+01, -.26966600E+01, 0.33516100E-01, -.30353300E+00, -.90348200E-02, 0.51488100E-01, -.28533900E+00, -.14581600E+00, 0.46248600E-01, -.99185400E-01, 0.88209100E+00, 0.10025500E+01, 0.13587700E+00, 0.72800700E-01, 0.39204600E+00, -.38253100E-01, 0.69553200E+00, 0.11405900E+00, 0.49949600E+00, -.35950100E-01, 0.30529000E+00, -.57929000E+00, 0.27138900E-01, 0.45939900E+00, 0.35806200E+00, 0.43264400E-03, -.20226000E-01, 0.11535200E+00, 0.18286800E+00, -.13212700E+00, -.24864700E+01, -.22422800E-02, 0.10748900E+00, -.14740100E+00, -.33898100E+00, 0.27534100E+00, -.84505000E+00, -.37531200E-01, -.55736800E+00, 0.34597700E+00, -.11930000E+01, -.17700200E+00, 0.70376700E-01, -.26468400E+00, 0.78753200E+00, -.10566600E+00, 0.14185200E+00, -.57362000E-01, -.15529100E-01, -.46803500E+00, -.20821800E+00, -.35311900E+00, 0.15584600E+00, 0.32835600E+00, 0.54011400E+00, 0.40020900E+00, -.28787500E+00, 0.79864300E+00, 0.71581700E-01, 0.94975900E-01, 0.27710900E+00, -.27412900E+00, -.30631600E-01, 0.18127000E+00, -.21653400E+00, 0.11594000E+00, 0.95099300E-01, -.49192100E+00, -.10121200E+00, 0.55177600E+00, -.41193800E-01, -.25522300E+00, -.13204700E+00, -.80271400E+00, 0.78859300E+00, -.60024400E-01, -.66920300E-01, 0.10728900E+00, 0.55585400E+00, 0.15281900E+00, 0.35550000E-01, 0.11522300E-01, -.12413100E+00, -.39037500E+00, 0.58616100E+00, -.56520900E-01, -.63231900E+00, 0.61231900E-01, -.50797900E+00, 0.19121200E+00, -.17009400E-01, -.27074000E+01, 0.12256300E-02, 0.10130900E+00, -.80915600E+00, -.35897500E+00, -.79159400E-01, -.40187700E+00, -.28086600E+00, 0.16426600E+01, 0.26438700E+00, 0.68533900E-01, 0.19114400E+00, 0.98230800E-04, -.44343600E+00, -.26849100E+00, 0.96785100E+00, 0.93289800E+00, 0.16864700E+00, 0.98518400E+00, -.19325600E+00, -.52225900E+00, -.40537300E-01, 0.25992400E+00, 0.44077300E-02, -.69436200E+00, -.56572000E+01, -.26498500E-01, -.51120800E+00, 0.14368400E+00, -.35053800E+00, -.15963700E-01, 0.17065400E+00, 0.93448100E-01, 0.10634300E+01, 0.20834100E-03, 0.29535600E+01, -.15154900E+00, 0.35391500E+00, -.58638200E-01, -.22996800E+00, 0.37522300E-01, -.33478900E+00, -.72329700E-01, -.95828500E-01, 0.87479300E+00, 0.21972800E-01, 0.53141200E+00, -.20044200E+00, -.24126100E+00, 0.13472800E+00, -.26761700E+00, -.74459600E-01, 0.97903400E-01, 0.73953100E-01, -.70167800E-01, 0.13505700E+00, -.24792000E-01, -.60451900E+00, -.18180300E+00, 0.14326300E-01, 0.23299800E+00, 0.12264600E+00, -.24308900E+00, -.75193400E-01, 0.84044700E+00, -.26360000E+00, -.13741400E+02, 0.37169200E+00, 0.21043000E+00, 0.20930200E+01, 0.20448600E+02, 0.51582100E+02, 0.26744000E+02, 0.24036100E+01, -.32029400E+02, -.10670900E+03, 0.52200300E+02, 0.10375000E+03, 0.53248700E+02, 0.10516500E+03, 0.73992200E+02, -.11731200E+02, -.39841700E+02, -.34754800E+02, 0.44636200E+02, 0.60194000E+02, 0.15978600E+03, -.78782700E+02, -.81924900E+02, -.79768100E+02, -.72867600E+02, -.19616100E+02, -.55408900E+01, 0.65897400E+02, -.32240600E+01, 0.50786000E+01, -.82467100E+02, -.12878800E+01, 0.32724100E+00, -.38125800E+01, -.41673700E+00, 0.26975200E+01, -.13112600E+01, -.22868300E+01, 0.25033800E+01, 0.12788400E+00, 0.11373600E+01, -.11626000E-01, 0.97452200E+00, 0.15501600E+01, -.13694800E+01, -.46194200E+01, 0.41995300E+00, 0.23912300E+01, -.75351500E-01, 0.74534100E+01, 0.12675100E+01, -.57092600E+01, -.12514800E+01, -.12234600E+00, -.52875000E+01, 0.15487600E+02, 0.64499300E+01 },
        { 0.47319300E+00, -.56104500E+00, 0.37793200E+01, -.78849800E-01, -.20610600E+01, -.46671400E+00, -.27373400E+01, -.12956400E+01, -.57451600E-01, -.94792200E-01, -.15306400E-02, 0.37610000E+01, -.97694600E+00, 0.88693900E+00, -.13528800E+01, -.51632900E+00, 0.39316600E+01, -.32249700E+00, 0.12912800E+01, -.10360600E+01, 0.23026600E+01, 0.15872100E+01, -.47368800E+00, 0.21486000E+01, 0.20332600E+01, -.53972600E+00, 0.58482300E+00, -.25986600E+00, 0.26664600E+00, -.56418300E+00, -.92110500E+00, -.76422900E+00, 0.21958300E+00, 0.84042800E+00, 0.27247700E-01, -.12314900E+00, 0.28109300E-01, -.86980300E+00, -.94185000E+00, -.19217800E+00, 0.16510200E+01, 0.59774200E+01, 0.52759800E+01, 0.14631600E+01, -.14734700E+01, -.11521900E+01, -.35692900E+01, 0.56883000E-01, -.10545300E+01, 0.20479100E+00, -.39323200E+00, -.15017100E+01, 0.10380600E+01, -.18933000E+01, 0.26930200E+00, -.14088000E+01, 0.50584300E+00, 0.59278800E+00, -.59011000E+00, 0.63688300E+00, -.72632600E+00, 0.70604300E-01, -.54240900E-01, -.57311800E-01, 0.92771800E-01, 0.30738400E+00, 0.53458700E+00, -.31253200E+00, -.62137800E+00, 0.23514400E-01, 0.21622400E+00, -.12142300E+01, 0.13975800E+00, -.67547200E-01, -.65831500E+00, 0.99427300E-01, -.42489900E+00, 0.48027200E+00, 0.46984900E+00, -.52682000E+00, 0.14752300E-01, 0.75719400E-01, 0.46848600E+00, -.43714900E+00, 0.27718300E-01, -.35835600E-01, 0.76589600E+00, 0.14406800E+01, 0.84071400E+00, -.45134200E+00, -.14109200E+00, 0.30312000E+00, -.22566400E+00, -.18019600E+01, -.16580100E+00, 0.12270300E+00, -.61314600E+00, -.14612300E+00, -.15097900E+01, -.36376100E+00, 0.42902000E+00, -.79139100E-01, -.51931200E-01, -.52835900E-01, 0.61149000E+00, -.14234400E+01, -.41273900E+00, -.18173400E+01, 0.19555200E+01, 0.89013900E+00, 0.23554600E+00, -.25188000E+00, 0.48689900E+00, 0.61753800E-01, 0.54496900E+00, 0.33269800E-01, -.28680900E+00, 0.26015000E+00, 0.70077300E+00, -.85980300E-01, 0.37463900E+00, -.17417800E+00, 0.12819500E+00, 0.17680000E-01, -.81770600E-01, -.86804500E+00, 0.10419100E+00, -.14573200E+01, -.34732000E+00, -.49288400E+00, -.38062700E+00, 0.10139600E+01, -.14959700E+00, 0.16361000E-01, 0.53029000E+00, 0.13666300E-01, -.62145800E-01, -.15287500E+00, -.21419100E+00, -.51072300E+00, 0.46299300E+00, 0.17824900E+00, -.58433400E-01, 0.66464100E+00, 0.93007300E+00, 0.23064000E+00, -.11731700E+00, -.52636900E+00, -.35896000E-02, -.31702800E+00, 0.19963800E+00, -.22616200E+00, -.27741500E+00, 0.46776700E+00, 0.17061200E+01, -.10209800E+00, 0.80568100E+00, 0.13442600E+00, -.17571300E+00, -.59573200E+00, -.28996500E+00, 0.84795800E+00, -.10846300E+00, 0.23858400E+00, -.51027500E+00, -.99398600E-01, 0.10361500E+00, 0.44828300E+00, -.84468900E-01, -.26826600E+00, -.18897400E-01, -.10715900E+01, -.79946000E-01, 0.23257500E+01, -.53500000E-01, 0.17554300E+01, 0.45887300E+00, -.90247200E-01, -.25817000E+01, 0.69740200E-02, 0.45065200E+00, 0.11966200E+01, 0.12053400E+01, -.16013600E+00, -.81979900E+00, -.10735200E-01, -.71995100E+00, -.50638000E+00, -.36865100E-01, 0.34659300E+00, -.19205300E-02, 0.26158000E+00, 0.30157700E+00, -.35346100E+00, -.16934800E+01, 0.52294400E+00, 0.10011900E+01, 0.11402100E+01, -.67012600E+00, 0.45791400E-01, -.11636800E+00, -.57412500E-01, 0.29904200E+01, 0.10813600E+01, -.15199400E+00, 0.10399000E+01, -.21766800E+00, 0.46506100E+00, -.48939900E-01, 0.13852500E+01, -.59419600E-01, -.49103500E+00, -.15822900E-01, -.26700300E+01, 0.53228100E-01, 0.48996500E-02, 0.10240000E+00, -.46836000E+00, -.20252300E+00, -.88281700E-01, -.16667600E+01, -.43185800E-01, 0.38265200E+00, 0.29381200E-01, 0.20450100E+01, -.55882800E-01, -.13845300E+00, 0.10592600E+00, -.13194800E+00, 0.73026400E-01, -.10679800E+00, -.30287100E+00, 0.10073300E+00, 0.83283700E-01, 0.12405400E+00, -.20063600E+00, -.70755300E+00, 0.59990000E-01, -.34709200E+00, -.11194100E+00, -.27816400E+00, 0.27850600E+00, 0.13385300E+01, -.51106000E-01, 0.45807200E+00, 0.44659800E+01, -.30466700E+01, 0.57528800E+01, 0.16808600E+01, 0.21446100E+02, -.79836800E+00, 0.51244300E+01, -.13252200E+02, -.16386500E+01, -.63539100E+01, 0.38571000E+02, 0.66405000E+00, 0.58749700E+02, 0.31601100E+02, -.21132000E+02, -.18768600E+02, -.16051400E+02, 0.22702500E+02, -.43988000E+01, 0.23906600E+02, -.71181400E+01, -.17114100E+02, -.11753400E+02, -.30116200E+02, -.74377200E+01, -.11555500E+02, 0.26742700E+02, -.76006000E+00, -.10607700E+01, -.41602000E+01, -.51541500E-01, -.40509100E+00, 0.87101500E+00, -.41910600E+00, -.79479400E-01, -.55348100E+00, -.97060600E+00, 0.92915400E-01, -.22187300E+00, -.11726800E+00, -.38215700E+00, 0.63342300E+00, -.10703000E+01, -.10266900E+01, 0.14910800E+00, 0.26851200E+00, 0.97319900E-02, -.30071100E+00, 0.12130500E+01, 0.17586200E+00, -.13575000E+01, 0.26038900E+00, -.19987100E-01, -.23758000E+01, 0.39744200E+01, 0.19514200E+01 },
        { 0.16876500E+01, -.32424100E+01, 0.17629300E+02, 0.28627900E+01, -.72834300E+01, 0.10554800E+00, -.58805400E+01, 0.56795300E-01, 0.25005500E+01, -.44108300E-01, -.80112100E+00, 0.70357200E+01, -.23556300E+01, -.57659600E+00, 0.21777000E+01, 0.78962500E+00, 0.88815700E+00, -.63829500E+00, -.35056000E+01, -.14517800E+00, -.68106400E+00, -.27750100E+01, -.73616800E+00, 0.77905100E+00, 0.20049600E+00, 0.98421100E+00, 0.14696200E+01, 0.45657500E+00, -.48525200E+00, -.12388700E+01, 0.10122500E+01, 0.21638600E+00, 0.24099600E+01, -.29209000E+00, -.19665200E+01, -.77210600E+00, 0.14977900E+00, -.96525000E+00, -.31735900E+00, -.22111100E+00, -.13058200E+01, 0.99003000E+00, 0.44876900E+01, 0.74458100E+00, 0.55839600E-01, 0.26462600E+00, 0.16598600E+00, 0.20041800E+00, -.31443700E+00, -.85359700E-01, -.56698200E+00, 0.85734700E+00, 0.81693100E+00, -.15982600E+01, 0.14515000E+01, -.31793900E+01, -.65389300E+00, -.10211500E+01, -.13595400E+00, -.19030900E+01, 0.26788600E+00, 0.10844900E+01, 0.28491700E+00, -.95758900E-02, -.46792000E-01, -.53074500E+00, 0.32450800E+00, -.21893400E+01, -.13213100E+01, -.51593400E-02, 0.34211700E+01, 0.32282100E+01, 0.30904500E+00, 0.17751800E+00, -.49740800E+00, -.34040300E+00, -.19191200E+00, 0.34900100E+00, 0.91984400E+00, 0.92246300E+00, 0.32133600E-01, -.35291200E+00, 0.23398900E+01, -.59967300E+00, -.28821900E+00, 0.85227200E+00, -.24657900E+01, -.15770500E+01, 0.20169300E+01, 0.29197100E+00, -.37977600E+00, 0.17422900E+00, -.34846200E+00, -.67328900E+01, -.64601100E+00, 0.10075600E+01, 0.11671400E+01, -.22163700E+01, -.21991000E+01, -.24830900E+00, 0.28705900E+01, 0.22718600E+00, 0.25846800E+00, -.74523700E+00, -.57491400E+00, -.38537300E+00, -.36667600E+00, -.52497900E+00, 0.76741000E+00, 0.31357400E+01, 0.32489100E+01, 0.27327700E+01, -.31003500E+00, -.62819300E-01, 0.12541600E+01, 0.25958600E+01, -.11057100E+00, -.11742300E+02, -.21680700E+01, -.55562100E+00, -.38993200E+00, -.20575900E+01, 0.35771100E+00, 0.21603800E+01, 0.27242900E+00, 0.37041200E+01, 0.42770200E+01, 0.26212600E+01, 0.55743400E+00, 0.98693800E+00, 0.58656300E+00, -.37683300E+01, 0.46573400E+00, -.10349200E+01, -.36590000E-02, -.18590900E+00, -.16208100E+01, -.13433500E+00, 0.47157000E+00, -.25654400E+01, -.76395100E-02, 0.27504300E+01, 0.20985800E+00, -.32541500E+01, -.34183200E+01, -.43686600E+00, -.31026600E+00, -.20888900E+01, -.27491500E+00, 0.16675700E+00, 0.70916300E+00, -.55793400E+00, -.36844600E+01, -.14815900E+01, 0.29474100E+01, 0.60308200E-01, -.22758400E+00, 0.66142400E+00, 0.16114400E+00, -.22931600E+00, -.11101100E+01, 0.48153600E+01, -.38956000E+00, 0.17409800E+00, 0.68308500E-01, 0.50903000E+00, 0.72154400E-01, -.11345300E+00, -.12520800E+00, 0.12180300E+01, 0.11466000E+00, -.22483800E+01, 0.70571400E-01, 0.43456500E+01, -.67583000E+00, 0.68381300E+00, 0.91558900E+00, -.26567000E+00, 0.22089300E+01, 0.15969600E-02, 0.49846000E+00, 0.29911300E+01, 0.46392100E+01, -.38523700E+00, -.89742000E+00, -.38372200E+00, 0.39642100E+00, -.41013500E+00, -.23168500E+00, -.64332200E-01, -.28784000E-02, -.16263500E+01, 0.18475400E+00, 0.10762800E+01, -.25899500E+01, -.93114500E+00, -.13587800E+01, 0.12499500E+00, -.62507700E+00, 0.11569600E+00, 0.72870200E-01, 0.22134300E-01, 0.54612900E+01, 0.18944600E+02, 0.30120100E+00, 0.95155100E+00, 0.95957000E+00, 0.23597100E+01, 0.78428000E-01, 0.52352200E+00, 0.75247300E-02, -.27118500E+01, -.64874500E-02, -.10942100E+02, 0.80943800E+00, 0.65483100E+00, 0.18849700E-01, 0.65407900E+00, 0.93523800E-01, 0.69191600E+00, -.64988800E+01, 0.55068600E-01, -.13204000E+02, 0.10360000E+00, 0.36331300E+01, 0.13749700E+01, 0.28452700E+01, -.10138600E+01, 0.11074900E-01, -.75569800E+00, -.72325400E+00, -.12743000E+01, 0.49844700E+00, 0.23938700E+00, 0.48874100E+00, 0.64386200E+01, -.74261700E+01, 0.37815800E+00, 0.80622000E-01, -.16434000E+01, 0.35447700E+01, 0.39642300E+00, 0.72802900E+01, 0.86306300E+00, 0.63846000E+00, 0.64063600E-01, 0.74062000E+02, 0.15525000E+03, -.53162800E+02, -.70319300E+02, -.16208100E+03, 0.12322800E+03, 0.32164600E+02, -.19705900E+03, 0.52931500E+02, 0.25104800E+03, 0.98289300E+02, 0.22509800E+03, 0.25930800E+03, -.49928700E+02, -.16695700E+03, -.11654900E+03, 0.16637000E+03, -.40518200E+02, 0.31591000E+03, -.12012000E+03, -.15781900E+03, -.15772300E+03, -.14966100E+03, -.74667400E+02, -.58573500E+02, 0.31443900E+03, 0.11394500E+02, -.21117000E+02, 0.45732400E+02, -.56560300E+00, -.19437700E+02, 0.70999600E+01, 0.18980100E+01, 0.42038900E+01, -.38368400E+01, -.61965200E+01, -.11411900E+02, 0.39923300E+00, 0.63896800E+00, -.30236900E+01, 0.58026100E+01, -.77678600E+00, -.43837800E+01, -.18392700E+01, 0.28756100E+01, 0.86589100E+00, -.72291400E+00, 0.52646800E+01, 0.23845300E+01, -.43407900E+01, 0.69331300E+00, 0.47606700E+00, 0.58479300E+01, 0.42253500E+02, 0.20386900E+02 },
        { -.18615800E+00, -.54956700E+00, 0.97366300E+00, -.47757400E+00, 0.26194500E+00, -.14419500E-01, 0.24308500E-01, -.32203700E+00, -.29737400E+00, 0.16527200E-02, 0.93514200E-01, -.52321900E+00, 0.80494300E-01, -.40563800E+00, -.13752400E+01, 0.42928200E-01, 0.28884200E+00, -.27512200E-01, 0.37412300E+00, 0.16825400E-01, 0.10080600E+00, -.28029000E+00, -.78126800E-03, -.16639200E+00, 0.12757500E-01, 0.20111400E+00, -.12158000E+00, 0.13812100E+00, -.10347400E+00, 0.14205400E-01, 0.13477100E+00, 0.10494800E+00, 0.94770600E-01, 0.28376400E-02, -.23475400E+00, -.13912900E+00, -.29851300E-01, -.42743600E+00, -.39631100E-03, -.14041500E+00, -.72532800E-01, 0.12542200E+00, 0.75684000E+00, 0.16704000E+00, -.41256100E+00, -.96153400E-01, -.48407800E+00, -.10310500E+00, -.96042400E-01, -.19850600E+00, -.10437700E+01, 0.44927100E+00, 0.52588900E-01, 0.98120600E-01, 0.40684000E+00, -.43329800E+00, -.65091200E-01, 0.32906700E+00, 0.25271700E+00, -.37418000E-01, -.22745900E+00, 0.12314400E+00, 0.26369700E-01, 0.10662900E+00, 0.22522900E-01, 0.50358500E-01, 0.43728000E-01, 0.43709400E+00, -.39149600E+00, -.93541300E-02, -.38842200E+00, -.45053900E+00, 0.23691400E-01, -.90790000E-01, -.20212200E-01, 0.19668800E+00, -.22794300E+00, -.13457500E+00, 0.59178700E-01, 0.13352200E+00, 0.21208400E-01, 0.47267700E-01, -.23707400E+00, 0.76297600E-01, -.27467800E-01, 0.11446600E+00, 0.39469700E+00, -.53679200E+00, 0.57858600E-02, 0.98066300E-01, -.46446300E+00, 0.29782800E+00, 0.57578700E+00, -.16100500E+01, 0.72919900E-01, -.26004200E+00, 0.29716500E-01, 0.19496900E+00, -.93479500E+00, -.45832700E+00, 0.20815800E+01, -.43751500E+00, -.62905900E-02, -.26744800E+00, -.10386900E+00, 0.15253900E+00, -.76873300E-01, -.39693900E+00, 0.43523500E+00, 0.23976200E+00, -.32911300E+00, 0.63041600E+00, -.87995000E-01, -.17907500E-01, -.11330500E+00, -.30500800E+00, -.19388600E-01, 0.61869800E-01, 0.18035700E+00, -.16695500E-02, 0.49549800E-01, -.14468000E+00, -.95420100E-01, -.19788900E+00, 0.27359600E-01, 0.40978600E+00, 0.99931100E-02, -.15755000E+00, 0.29072400E-01, -.78436000E-02, -.14537600E+00, -.16518600E+00, -.22576300E-01, 0.70561800E-01, 0.12138800E+00, -.69388800E-02, -.19803300E+00, -.10176100E+00, -.10932300E+00, -.15843800E+00, 0.73310700E-01, 0.18994100E+00, -.32752900E-01, 0.11725500E+00, 0.10834200E+00, 0.30969400E-01, 0.53819700E-01, 0.24012900E+00, 0.31267800E+00, -.62257200E-01, 0.18385700E+00, 0.17752700E-01, -.22445500E+00, -.23178400E+00, -.15950100E+00, 0.13503300E+00, -.24647900E+00, -.97450100E-01, 0.83336600E-01, 0.33459700E+00, 0.24483800E+00, -.38749900E-01, 0.12511200E+00, -.25126600E-02, 0.11751100E+00, -.21497700E+00, -.16642600E-01, -.16539700E+00, 0.55350600E-01, 0.51770300E-01, -.25313200E+00, -.15426900E+00, 0.69152100E-01, -.99102700E+00, 0.14811200E+00, -.61479800E+00, -.28755700E+00, 0.71915300E-01, 0.17594200E+01, 0.19313400E-03, -.25503900E+00, -.19561600E+00, -.97814500E+00, 0.24106100E+00, 0.42764300E+00, 0.15912700E+00, 0.71566500E+00, 0.22316800E+00, 0.67509500E-02, 0.38953500E-01, -.26905600E-03, 0.21584500E+00, -.18442100E+00, -.23814100E+00, 0.34528100E+00, 0.19123700E+00, -.31597400E+00, -.26611600E+00, 0.38497300E+00, -.56572300E-01, 0.68181700E-01, -.56155700E-01, 0.18284200E+01, 0.93466000E+00, -.85486700E-01, -.10280500E+00, 0.16895100E+00, 0.43467300E+00, -.80942600E-02, 0.91510700E-01, 0.51139300E-01, -.91020000E+00, 0.30394700E-02, -.95250700E+00, -.24147300E+00, -.65080200E-01, -.23512100E-01, 0.19560700E+00, 0.49492900E-02, 0.97521300E-01, -.48328900E-01, -.45687000E-02, 0.54948900E+00, -.55364300E-01, -.31765700E+00, 0.53514100E-02, -.45485900E-01, -.59726200E-01, 0.49074000E-01, 0.25925600E-01, 0.26103000E-02, 0.13923900E+00, -.47338800E-01, -.40536500E-01, -.57236400E-01, 0.10149100E+01, 0.14267000E+00, 0.75258700E-02, 0.21934000E+00, 0.21998800E-01, -.29394300E+00, -.13017800E+00, -.13453600E+00, 0.76292200E-01, 0.69610400E-01, -.62717600E-01, 0.86592000E-01, -.14249700E+02, -.21258200E+01, -.84034700E+01, 0.53307000E+01, -.10234500E+02, 0.40834000E+01, 0.31930300E+02, -.99211700E+01, -.43628400E+02, -.15891000E+02, -.29426500E+02, -.34081400E+02, 0.22575600E+01, 0.18961700E+02, 0.11918000E+02, -.18069700E+02, -.74577300E+01, -.50943600E+02, 0.20125400E+02, 0.25618300E+02, 0.25387900E+02, 0.23866100E+02, 0.10365100E+02, 0.18517800E+02, -.32585700E+02, 0.15035000E+01, 0.56424900E+00, 0.38807400E+01, 0.90971400E-01, 0.16780500E+01, 0.26641400E+00, 0.41044000E-01, -.11737900E+00, 0.47000100E+00, 0.72114600E+00, 0.69668200E+00, 0.11805200E+00, -.13786800E+00, 0.34045900E+00, -.73523900E+00, 0.64142300E-02, 0.48992700E+00, 0.44563800E-01, -.45335200E+00, -.75748200E+00, 0.25762100E+00, -.14666000E+01, -.12134400E+00, 0.11184900E+01, -.42665100E-01, 0.71789100E-02, 0.25844100E+01, -.58627000E+01, -.23943300E+01 },
        { 0.23734800E+01, -.29439400E+01, 0.19348500E+02, 0.20945200E+01, -.68321400E+01, -.18749200E+01, -.64289700E+01, -.24050100E+01, 0.12306200E+01, 0.24691800E+00, -.45544100E+00, 0.10998500E+02, -.46050000E+01, 0.94723100E+00, 0.65222300E+01, -.12715900E+01, 0.72661600E+01, -.91540500E+00, 0.15704600E+01, 0.27992000E-01, 0.54304500E+01, -.74085200E+01, -.18418300E+01, 0.63855200E+01, 0.50716600E+01, 0.16608500E+01, 0.34435700E+00, -.79727100E+00, -.57073000E+00, -.40516300E+00, -.16182300E+00, 0.20308000E+00, 0.10964900E+01, -.80242000E+00, -.23458500E-01, -.19323200E+01, 0.66165100E-01, -.26763900E+01, -.29426400E+00, -.14035700E+01, 0.33548500E+01, 0.16114500E+02, 0.11873200E+02, 0.23471100E+00, -.52509000E+00, -.91476100E+00, -.33878700E+01, -.85620400E-01, -.22864700E+01, -.12795100E+01, 0.34827200E+00, -.39176700E+01, -.72126600E+00, -.84833200E+01, 0.31841800E+01, -.37003200E+01, 0.24040100E+01, -.17584500E+01, 0.20956500E+00, -.47394000E+00, -.11825300E+01, 0.92035800E+00, 0.15984700E+01, -.16744500E+01, 0.26242100E+00, -.15642800E+00, 0.10648300E+01, -.31727800E+01, -.48626700E+00, 0.19477700E+00, 0.18939200E+01, 0.24472500E+01, -.14198300E+00, -.29576900E+00, -.13171200E+01, -.64597700E+00, 0.38389300E+00, 0.15657900E+01, -.10608000E+01, 0.17802700E+00, -.76767300E-01, -.52905000E-01, 0.17303500E+01, -.19389200E+01, -.34755200E-01, 0.59157700E+00, 0.34116300E+00, 0.18134900E+01, 0.97460600E+00, 0.12759800E+01, -.37044300E+01, 0.36097700E-01, 0.20748500E+01, -.42743900E+01, -.13935900E+01, 0.38754800E-01, 0.32505900E+00, -.14580400E+01, -.62764200E+01, -.12747300E+01, 0.20670000E+01, 0.11435900E+01, -.24506600E+00, -.19757400E+01, -.59654300E+00, 0.68113900E-01, -.20448200E+00, -.26125900E+01, -.16307000E+01, 0.80416500E+01, -.19129800E+01, -.13406900E+01, 0.94954200E+00, -.55939000E+00, 0.10906700E+00, -.24636100E-01, 0.48552300E-01, 0.51353600E+01, 0.32913000E+01, 0.11667300E+01, -.16765600E+00, -.28765400E+01, 0.12770100E+01, -.39813100E+00, -.53137000E-01, 0.41283400E+01, 0.20111300E+01, -.40211500E+01, -.23902300E+00, -.32831400E+00, -.52289200E+00, 0.30738600E+00, -.99597000E-01, 0.53334500E-01, 0.34972800E+01, -.19311200E-01, 0.58653900E+00, 0.10701200E+01, -.85385100E+00, 0.21832900E+01, 0.31069400E+00, -.56099700E+01, -.13340100E+01, 0.11390100E+00, 0.23937100E+00, -.73505500E+00, 0.99881400E+00, -.15243400E+01, 0.94720200E-01, -.87531400E+00, -.27633200E+01, 0.16726500E+01, -.21269200E+01, 0.97126000E+00, 0.25042500E+01, -.11018300E+01, 0.28223300E+01, 0.18679500E+00, 0.83810100E+00, -.28185900E+01, 0.13157700E+01, 0.47581700E+01, 0.16645600E+00, 0.73649000E+00, -.20774600E+01, -.14481600E+01, -.18421400E-01, 0.80133300E+00, -.12466400E+00, -.96719200E+00, 0.48843500E-01, -.21783300E+01, 0.32656400E+00, 0.74657700E+01, 0.62138500E-01, 0.21709000E+01, 0.15045100E+01, -.19549400E+00, -.58775800E+01, 0.44214800E-02, 0.48152200E+00, 0.13594700E+01, 0.26236200E+00, 0.16513400E+00, -.14515600E+01, -.40700000E+00, 0.22858700E+01, -.14033500E+01, -.16922400E+00, 0.78337300E+00, 0.40398900E-02, 0.20286800E+00, 0.78505200E+00, -.30922300E+00, -.74464300E+01, 0.78928100E+00, 0.29802700E+01, 0.94750000E+00, -.19101800E+01, -.26088700E+00, 0.19877500E+00, -.67256100E-01, 0.93595500E+01, 0.37044500E+01, -.43335600E+00, 0.11286000E+00, 0.45240700E+00, 0.26788500E+01, -.46780000E-01, 0.49776200E+01, 0.10591800E+00, 0.22211300E+01, -.51477700E-02, 0.57380100E+01, 0.39841000E+01, 0.65046900E+00, 0.40915500E+00, -.99154000E+00, 0.33630600E+00, -.12172300E+01, -.22343200E+01, -.38628100E+00, -.12712600E+01, 0.17500700E+00, 0.40385500E+00, 0.61598200E+00, 0.18335000E+01, 0.11550700E+01, -.83892900E+00, -.40437900E+00, -.21657800E-01, -.17411900E+01, 0.50233100E+00, 0.17764100E+01, 0.62618400E+00, -.20184500E+01, 0.54322600E+01, -.59841200E+00, -.79901400E+00, 0.70300900E+00, -.57093200E+00, 0.66652700E+00, 0.22504600E+01, -.11189800E+00, -.36683300E+00, 0.37925200E+00, -.42476500E+00, -.31146300E+01, 0.88397200E+02, 0.92813000E+02, 0.28352600E+02, -.17454200E+01, -.84409600E+02, 0.35790600E+02, -.43304300E+02, 0.90202800E+02, -.18114900E+02, 0.14373300E+03, 0.67022200E+02, -.68437800E+02, -.60130400E+02, -.66902500E+02, 0.35487000E+02, 0.10608700E+03, 0.68465200E+02, -.18622900E+02, -.57090300E+02, -.33993200E+02, -.29644800E+02, -.27020200E+02, 0.19304100E+02, 0.10855300E+03, 0.11990600E+02, -.12276500E+02, -.15414100E+03, 0.59589700E+00, 0.14222400E+01, -.23520700E+01, -.26707100E+01, 0.20015900E+01, 0.46472900E+00, -.51878700E+01, 0.33749900E+01, 0.38321500E+00, 0.95058000E+00, 0.69973600E+00, 0.24415100E+01, 0.27099200E+01, -.16022700E+01, -.56979300E+01, 0.21271700E+01, -.79433700E-01, -.29763700E+00, 0.33020700E+01, 0.28749500E+01, -.30832100E+01, 0.25782900E+00, 0.54470900E+00, -.60147800E+01, 0.17633600E+02, 0.25890600E+01 },
        { -.10025000E+01, 0.20757300E+01, -.48187400E+00, -.50227800E+00, -.10909100E+01, 0.60958900E-01, -.18473000E+01, 0.26067900E+01, -.45236200E+00, -.99743400E+00, 0.53429500E+00, -.49165800E+01, 0.24730800E+01, -.91903400E+00, -.12212400E+01, 0.13604000E+01, -.46931400E+00, -.66206800E-01, -.70178700E+00, 0.40043600E+00, -.22983300E+01, 0.18417800E+01, 0.45908600E-01, -.16169300E+01, -.44527000E+00, 0.38651100E+00, -.13143800E+00, 0.14745700E+01, 0.21998100E+00, -.40796900E+00, 0.22075700E+00, -.12324900E+00, -.65366300E+00, 0.15314600E+01, -.53248200E+00, 0.91238200E+00, -.13669300E+00, 0.22597500E+01, 0.37690300E+00, 0.11082500E+01, -.41335300E+00, -.64175400E+01, -.71754300E+01, 0.64811400E+00, 0.25418100E+01, 0.63564400E+00, 0.62672200E+00, -.18724800E-01, 0.82593600E+00, 0.11066800E+01, 0.12619200E+01, -.72257900E+00, 0.97695400E-01, 0.42951500E+01, -.31661500E+00, 0.11305300E+01, -.10656100E+01, 0.91354100E+00, 0.64795000E-01, 0.21647200E+01, -.77963400E-01, 0.29769000E+00, -.21132200E+01, 0.54620100E+00, -.98467700E-01, 0.24092300E+00, -.26837700E-02, 0.98250600E+00, -.74337200E+00, -.71565700E-02, -.54844200E-01, -.22466100E+00, 0.11995300E+00, 0.52555900E-01, -.27735000E+00, 0.40364800E+00, -.73088800E+00, -.41914800E+00, 0.84245600E+00, 0.38791200E+00, 0.64443200E-01, -.40372400E-01, -.44610800E+00, 0.45378900E+00, 0.22336100E-01, 0.43108500E+00, -.46847800E+00, -.40477500E+00, 0.66074200E+00, -.61185000E+00, 0.53644600E+00, 0.64452700E+00, -.12247900E+01, -.10080400E+01, 0.12778400E+01, 0.17518000E+01, -.37403800E+00, -.19705300E+00, 0.71529500E+00, 0.13145600E+00, -.38583200E-01, -.93839000E+00, -.46466200E-01, 0.54721700E+00, 0.37687100E+00, 0.23808400E+00, 0.40395800E-01, -.24609500E+00, 0.67178000E+00, -.14450600E+01, 0.10886200E+01, 0.42250500E+00, 0.39917200E-01, 0.29859300E+00, 0.24455700E+00, 0.25437700E+00, 0.94253100E-01, -.16478800E+01, -.90806700E+00, -.24531300E+00, 0.72636700E-01, 0.82040700E+00, -.58969800E+00, 0.32774500E+00, -.61109200E-02, -.11262000E+01, -.38292200E+00, -.42010300E+00, -.19053600E+00, -.21291800E+00, -.40656200E+00, 0.54681200E+00, -.20362600E-01, 0.18651400E+00, -.73999000E-01, -.27605300E-02, 0.28051600E+00, -.30173000E+00, 0.53379300E-01, -.10475600E+01, 0.36987500E+00, 0.14187200E+01, 0.25222400E+00, 0.11151800E+01, 0.12857000E+01, 0.52703500E+00, -.22282300E+00, 0.32810500E+00, 0.78450600E+00, -.45648900E+00, 0.93852100E+00, -.61677700E+00, 0.25340900E+00, -.44484000E+00, 0.14998900E+01, -.47742200E-01, 0.46934700E-01, -.55958300E-01, -.13965000E+00, 0.28207600E+00, -.40057800E+00, -.70893100E+00, -.81849200E-01, -.88643400E-01, 0.48274700E+00, 0.73615100E-01, 0.50579800E-01, -.45247400E+00, -.15186400E-01, 0.47440700E+00, -.54789200E+00, 0.25029500E+00, 0.19292200E+00, -.28601300E+00, 0.16162900E+00, -.71458000E-01, -.85744400E-01, 0.55839800E-01, -.25908700E+00, 0.12913900E-02, 0.17503100E+00, -.35367300E+00, 0.10645100E+00, -.13082200E+00, 0.23710200E+00, -.62514100E-01, -.91350500E+00, 0.76490700E-01, 0.66951200E-01, -.75393300E-03, 0.12296500E-02, 0.18647400E+00, 0.56891600E-01, -.50564400E+00, 0.78859000E+00, 0.33170700E+00, -.48658900E+00, 0.14051700E+00, 0.36168500E+00, 0.44835400E-01, 0.94697200E-01, -.14216800E+00, 0.46182800E+00, -.56099200E+01, 0.14515700E+00, 0.73309000E+00, -.45931200E+00, -.26025200E+00, -.35030300E-01, -.69968400E+00, -.48709500E-01, -.80532600E+00, 0.66508900E-02, -.12955600E+01, -.29212900E+00, -.52536700E+00, 0.41454100E-01, -.18850600E+00, -.13263500E+00, 0.38061300E+00, -.31556600E+00, 0.10960000E+00, 0.32296100E+01, -.13369700E+00, 0.18729200E+01, -.38512700E+00, -.96447400E+00, -.80657500E-01, 0.22084600E+00, 0.20602900E+00, -.66242000E-01, 0.42266700E+00, -.12250300E+00, -.83960100E+00, -.14765000E+00, -.97873100E+00, -.18281100E+01, 0.27551800E+00, -.10629200E+00, -.27949700E+00, -.14380000E-01, 0.96686500E-01, -.16896300E-01, -.12081400E+00, -.13768100E+01, 0.88475900E-01, 0.84937800E-01, 0.11071400E+00, 0.20947300E+00, 0.78244300E+02, 0.47054400E+02, 0.23981400E+01, -.39477500E+02, -.21540800E+03, 0.12042300E+03, 0.16397100E+03, 0.10762900E+03, 0.14713800E+03, 0.11032600E+03, -.16534700E+01, -.41411300E+02, -.28778600E+02, 0.69173600E+02, 0.50683600E+02, 0.24206400E+03, -.12889600E+03, -.11466500E+03, -.12093900E+03, -.13269400E+03, -.21280300E+02, -.13217200E+02, 0.51400100E+02, -.96706500E+01, 0.19743900E+02, -.73983100E+02, -.28951100E+01, 0.14672300E+01, -.59515400E+01, 0.18474400E-01, 0.36178200E+01, -.32747200E+01, -.18382900E+01, 0.46221100E+01, -.18071200E+00, 0.13656100E+01, -.73717800E+00, 0.44674100E+00, 0.42024300E+00, -.20573100E+01, -.55558700E+01, -.53578600E+00, 0.42984500E+01, 0.29547300E-01, 0.13776200E+02, 0.70477900E+00, -.10434300E+02, -.25478500E+01, -.63542700E+00, -.80722200E+01, 0.19341700E+02, 0.99429200E+01 },
        { -.96260700E+00, 0.10625700E+01, -.75270200E+01, -.64278300E+00, 0.29081100E+01, 0.77513600E+00, 0.28126500E+01, 0.16593500E+01, -.20080100E+00, -.55655100E-01, -.33205400E-01, -.57180300E+01, 0.18789800E+01, -.11145800E+01, -.38071800E+01, 0.52074700E+00, -.37879900E+01, 0.40819800E+00, -.10837300E+01, -.17962200E+00, -.27538900E+01, 0.32263900E+01, 0.79218500E+00, -.36097700E+01, -.30487700E+01, -.57100900E+00, 0.43185000E+00, -.55298000E+00, 0.41995000E-01, 0.28346600E+00, -.37548000E-02, 0.43007400E-01, 0.48023300E+00, -.43558900E+00, 0.18179300E+00, 0.14651400E+01, 0.89759400E-01, 0.20688100E+01, -.19219600E+00, 0.73599700E+00, -.27280500E+01, -.10928700E+02, -.71231800E+01, -.11870400E+01, 0.39731400E+00, 0.42036600E+00, 0.24537100E+01, 0.33863400E+00, 0.17058200E+01, 0.33123400E+00, -.20417800E-02, 0.28634400E+01, -.47621500E+00, 0.42185400E+01, -.13529800E+01, 0.23675400E+01, -.47300600E+00, 0.23960200E+00, -.21557000E+00, 0.13021200E+00, 0.96595200E+00, -.50866100E+00, -.20938100E+00, 0.28269900E+00, -.16152300E+00, -.33040100E+00, -.71484300E+00, 0.74083700E+00, 0.11188800E+01, 0.11428500E-01, -.93630600E+00, 0.14973300E+00, -.14928600E+00, 0.93222500E-01, 0.10347100E+01, -.13917500E+00, 0.48485400E+00, -.70831700E+00, -.52344000E+00, 0.98343900E-01, -.31990800E-01, -.25673800E-01, -.42633400E+00, 0.86487900E+00, -.58108100E-01, -.48705600E+00, -.58768700E+00, -.15460000E+01, -.18575300E+01, 0.22794900E+00, 0.16059900E+01, -.64720900E+00, -.13961100E+00, 0.34776800E+01, 0.15345500E+00, -.51415200E+00, 0.70412500E+00, 0.63474200E+00, 0.34931200E+01, 0.74395100E+00, -.18879100E+01, 0.20175100E+00, -.79505100E-02, 0.52366600E+00, -.42635700E+00, 0.82634400E+00, 0.35265100E+00, 0.24711100E+01, -.13730000E+01, -.28128500E+01, -.16481300E+00, 0.70914400E-01, -.64330300E+00, -.63275700E-01, -.65461500E+00, -.33358100E+00, 0.21892800E+00, 0.94069000E+00, -.53955300E+00, -.21213700E+00, 0.13657300E+00, 0.47124900E+00, -.33009900E+00, -.34510300E+00, 0.14074600E+00, -.32298700E-02, -.12023800E+01, 0.28645300E+01, 0.46199000E+00, 0.42553800E+00, 0.76795300E+00, -.10414500E+01, 0.12662200E+00, 0.26418700E-01, -.15057900E+01, 0.65920100E-02, 0.45140400E+00, 0.53060300E-01, 0.52362700E+00, 0.59674600E+00, -.85299700E+00, -.21835600E+00, 0.33134100E+00, -.14811400E+01, -.15221500E+01, -.22768900E+00, -.16360300E+00, 0.10552600E+00, -.38421100E+00, 0.10524900E+01, 0.27655700E+00, -.14742400E+00, 0.96052700E+00, -.41057900E+00, -.29096700E+01, 0.34541900E+00, -.13395500E+01, -.65727600E-01, 0.36934500E-01, 0.16704400E+01, 0.52015000E-01, -.72998400E+00, 0.10314200E+00, -.49814800E+00, 0.10070700E+01, 0.10765200E+01, -.12817600E+00, -.30352000E+00, 0.46945400E-01, 0.47805600E+00, 0.72405800E+00, 0.26751100E+01, -.29870700E-01, -.43905700E+01, -.16932300E+00, -.22501400E+01, -.82044200E+00, 0.75582600E-01, 0.60977400E+01, -.14420400E-02, -.71624900E+00, -.16963700E+01, -.37835800E+00, -.94344400E-01, 0.10009100E+01, 0.56778600E-01, 0.59470000E+00, 0.97815600E+00, 0.78725900E-01, -.69059200E+00, -.70245500E-02, -.98904300E+00, -.52678800E+00, 0.10734800E+01, 0.47637500E+01, -.70494100E+00, -.16313100E+01, -.14312500E+01, 0.11355900E+01, -.22886600E-01, 0.95303800E-01, 0.28795400E+00, -.95523100E+01, -.54747000E+01, 0.36906400E+00, -.12711100E+01, -.12636300E+00, -.19867300E+01, 0.13980400E+00, -.40952200E+01, -.10942500E+00, 0.13533200E+01, -.95333100E-02, 0.74290000E+00, -.76075900E+00, 0.21746900E+00, -.14494100E+00, 0.85248500E+00, 0.20797900E+00, 0.14004700E+00, 0.27283700E+01, 0.12004600E+00, -.24971000E+01, 0.12824900E+00, -.33652300E+01, 0.38453800E-02, 0.21841400E+00, -.22438700E+00, 0.32623600E+00, -.53968700E-01, 0.21697500E+00, 0.51846900E+00, -.18240700E+00, 0.45720500E-02, -.18821400E+00, 0.20798400E+00, 0.39910200E+00, -.26572700E-01, 0.66857100E+00, 0.10522200E+00, 0.71661400E+00, -.64175200E+00, -.24707100E+01, 0.20232200E+00, -.13287100E+01, 0.22401800E+00, 0.18629700E+00, 0.25047100E+01, 0.55537600E-01, -.24458600E+00, 0.31408900E+02, -.18767000E+01, 0.55365100E+01, -.90672800E+02, 0.59508800E+02, 0.18087100E+02, 0.45367700E+02, -.37927100E+02, 0.21244000E+01, 0.52422400E+02, 0.12407600E+02, 0.78922300E+01, -.13090100E+02, 0.30775500E+02, 0.10450100E+03, -.59931200E+02, -.41590600E+02, -.52273100E+02, -.24284000E+02, -.29120200E+01, -.17386600E+02, -.90287600E+01, -.37068600E+01, 0.12153200E+02, -.24678700E+02, -.90139400E+00, 0.39706800E+00, -.68999500E+01, 0.37759000E+00, 0.66634500E+00, -.30702900E+00, 0.73241700E+00, 0.13790200E+01, 0.26044900E+00, 0.94532500E+00, 0.40940300E+00, -.32069100E+00, 0.33160200E+01, 0.13265700E+01, -.66010700E+00, 0.12952700E-01, 0.32981800E+01, 0.92496300E-01, 0.46258300E+01, 0.53789600E-01, -.27048400E+01, -.13010500E+01, -.16432900E+00, -.38803600E+01, 0.57647600E+01, 0.31870800E+01 },
        { -.21261100E+00, 0.65228500E+00, 0.47352600E+00, -.19128300E+00, 0.24351100E+00, 0.30188700E+00, 0.54521000E+00, -.19175600E+00, -.22444600E+00, 0.60546600E+00, 0.12532300E+00, -.11277200E+01, 0.22910200E+00, -.75475900E+00, -.28380900E+00, 0.51463200E+00, -.11194500E+01, -.25193000E-01, -.80973600E+00, 0.78591900E+00, -.15791900E+01, -.17076200E+01, -.26827100E-01, -.21003300E+00, -.18655800E+00, 0.19829400E+00, -.17808100E-01, -.46762500E+00, -.31865900E+00, 0.27963100E+00, 0.29730200E-01, 0.36828300E+00, 0.47267300E+00, -.47678000E+00, 0.91529600E-01, 0.73528800E-01, -.36067800E-01, 0.28107900E+00, -.45931900E-01, 0.14986000E+00, -.51391900E+00, -.69409200E+00, 0.21375700E+01, 0.15583300E+00, 0.31450500E+00, -.21502300E+00, -.11326700E+01, -.66908700E-01, 0.34275500E+00, -.53993500E+00, -.30991100E+00, -.61012900E+00, -.27769600E-01, 0.12962900E+01, 0.52197400E-01, 0.71819700E-01, 0.20741100E-01, 0.31127200E+00, 0.15079300E+00, -.44043800E+00, -.14963500E+00, -.14959100E+00, -.87713100E-01, -.81645300E-01, 0.63370600E-02, 0.18262000E+00, 0.50788900E-01, 0.29327600E-01, 0.12875900E+00, -.56376700E-02, -.33229500E+00, -.10385800E+01, 0.93555000E-01, 0.21828300E-01, -.72459900E-01, 0.59742800E-01, -.25041900E+00, 0.49109900E+00, 0.43474500E-01, 0.33826800E+00, 0.22115200E-01, 0.15420100E-03, 0.94487800E-01, 0.47559800E-01, 0.18632600E+00, 0.87804100E-01, -.14394900E+01, -.80335800E+00, -.35030100E+00, -.12185900E+00, 0.32714800E+00, 0.28834900E+00, -.10485100E+00, -.89698700E-01, 0.69049200E+00, 0.21902900E+00, -.16091200E+00, 0.13000600E+00, -.46916200E+00, -.19525500E+00, 0.92534500E+00, -.34260200E+00, -.82554000E-02, 0.56683000E-01, 0.42744800E-01, -.10100400E+00, -.16977000E+00, -.15786600E+00, 0.43161600E-01, 0.70034000E-02, 0.26618200E+00, 0.22449500E+00, -.52252400E-01, 0.22085900E-01, -.94879200E-02, 0.34379000E-01, 0.11241800E+00, -.69535700E+00, 0.63474500E-01, -.31374600E-01, -.67916100E-01, 0.36025600E+00, -.17423200E-02, 0.49995600E-02, -.22264100E-01, -.13019100E-01, 0.85385300E-01, 0.10708200E-01, -.16517300E-01, -.10885100E-01, 0.93916600E-01, 0.48231600E-01, -.18883100E-01, -.89819300E-02, -.25060400E-01, -.29045900E-02, -.35704900E+00, 0.14920300E-02, 0.17914200E-01, -.20877800E+00, -.10500700E-02, 0.74874500E+00, 0.75744400E-01, 0.13965700E+00, -.56143700E-01, -.14859400E-01, -.71448600E-01, 0.65806400E-01, -.42655300E-01, 0.45982400E-01, 0.15286100E+00, -.15362400E+00, 0.12592300E+00, 0.22960900E+00, 0.19968700E-01, 0.35613500E-01, 0.65797000E-01, 0.97018400E-02, -.14687200E+00, -.66020800E-01, -.10668000E+00, -.39804300E+00, -.34142800E-01, 0.62637600E-01, -.16165600E-01, -.92870300E-01, 0.11894800E-01, -.23627500E-01, -.36519300E-02, 0.86954700E-01, 0.45075800E-02, -.14085700E+00, 0.45214900E-01, 0.20503500E+00, 0.44341600E-02, 0.16989900E+00, 0.10226200E-01, -.23689400E-01, 0.48401100E+00, 0.47905300E-03, 0.19577000E-01, 0.22250000E+00, 0.30657000E+00, -.10240800E-01, 0.96713400E-01, 0.12287100E-01, 0.76208200E-01, -.20943300E+00, -.47883700E-01, 0.44392700E-01, 0.10040900E-03, -.68760800E-01, 0.12632200E+00, -.15244400E-01, -.84674300E+00, -.32843700E+00, -.50424800E+00, 0.28523700E+00, 0.12720800E+00, 0.73798700E-01, -.44472400E+00, 0.33263500E-01, -.64436300E+00, 0.40950600E+01, 0.15083100E-01, 0.35395000E+00, -.11048500E+00, -.48301200E-01, 0.23672700E-01, -.47043500E+00, -.55215500E-01, -.22920000E+00, -.71333500E-03, -.17533500E+01, -.11842100E+00, -.31379300E-01, 0.23256100E-01, 0.14379600E+00, 0.22514500E-01, 0.75361600E-01, -.34339200E+00, -.71458500E-02, -.56748300E+00, -.60142900E-03, 0.23278500E+00, 0.42889900E-01, -.58243900E-01, -.11414600E+00, 0.27060400E-01, -.63368700E-01, 0.15341100E-01, 0.83635000E-01, 0.12725600E-02, -.54497800E-01, -.34253100E-01, 0.25403600E+00, 0.17910900E-02, -.38081100E-01, 0.97584200E-01, -.52798800E-01, 0.21022500E+00, -.77538500E-01, -.14373700E+00, 0.56161000E-01, -.23602500E+00, 0.14924100E-01, 0.61753700E-01, 0.22736200E+00, -.65362000E-02, 0.67290200E-01, -.78016300E-01, 0.40815400E+01, 0.61107200E+00, 0.13599600E+01, -.99260200E+00, -.52439400E+01, -.70100100E+00, -.13782000E+02, -.50613600E+01, 0.79872900E+01, -.23195100E+01, -.42186200E+01, -.50991600E+01, 0.10951000E+02, 0.10945800E+02, -.52630600E+01, -.38104000E+01, -.54476800E+01, -.77717700E+00, 0.11443300E+01, -.66319300E+01, 0.71274300E+01, -.10728700E+01, 0.16359400E+01, -.10133000E+02, -.15070500E+00, -.34850200E+00, -.32393200E+00, 0.17262500E+00, 0.65187000E-01, 0.34917400E-01, 0.22831800E+00, -.15269900E+00, 0.28748300E-01, 0.75653200E-01, -.15381500E+00, -.13683400E+00, 0.60551000E+00, 0.24353100E+00, -.58566600E-01, -.34634200E-01, 0.28449000E+00, 0.75958800E-01, 0.82513000E-01, -.18926800E+00, 0.39028600E-01, -.11303400E+00, -.10774600E-01, -.31797000E+00, 0.10383400E+01, 0.94223700E-01 },
        { -.95066300E+00, 0.23382000E+01, -.10133500E+02, -.11390200E+01, 0.24283600E+01, 0.12404700E+01, 0.22729200E+01, -.42790400E+00, -.74775000E+00, 0.30805300E+00, 0.15340300E+01, -.27848700E+01, 0.12904300E+01, -.43828700E+00, -.39957100E+00, 0.17425200E+01, -.23554500E+01, 0.51480000E+00, -.71600700E+00, 0.61241700E+00, -.33532500E+01, -.44029900E+01, 0.20519300E+00, -.17103700E+01, -.61213500E+00, -.38655100E+00, 0.87599100E+00, 0.12724500E+01, -.20213300E+00, -.37838700E+00, -.49737700E-01, 0.15601900E+00, 0.32984200E+00, -.93657400E+00, 0.16675900E+01, 0.32337400E+00, 0.60514800E-02, 0.11966600E+01, -.60023100E-01, 0.17472200E+00, -.10553300E+01, -.82857000E+01, -.56449800E+01, -.91798400E+00, 0.67398800E+00, 0.15254700E+00, 0.22340800E+01, 0.11405600E+00, 0.10810600E+01, -.13082300E+00, -.12375100E+01, 0.31550500E+01, 0.69998000E+00, -.56153200E-01, -.57275500E+00, -.81003400E+00, -.17044000E+01, 0.48966800E+00, 0.18609800E+00, -.17229700E+01, 0.18052800E+01, 0.59997100E+00, -.92727200E+00, 0.61412100E+00, -.55758700E+00, -.19275800E+00, -.77958400E+00, 0.36320300E+00, 0.56515900E+00, -.43689400E-02, 0.64896800E+00, -.25452400E+00, 0.14896500E+00, 0.10707200E+00, 0.29944400E+00, 0.13089500E+00, -.83204800E+00, -.98249100E+00, 0.69741100E+00, 0.10492500E+01, 0.85231800E-01, -.35793900E+00, -.27027100E+00, 0.14109900E+01, -.31265700E-01, 0.83241400E+00, -.28613600E+01, -.34426200E+01, -.27880000E+01, -.22560600E+00, 0.16773000E+01, 0.64236300E+00, -.16157900E+01, -.12295200E+01, 0.91236800E+00, 0.22159300E+01, 0.93537100E+00, -.60036500E+00, 0.18882400E+01, 0.23651400E+00, 0.29117700E+01, -.10888000E+01, -.12459800E+00, 0.20795200E+01, 0.39446000E+00, 0.13024300E+01, -.22233000E+00, 0.24301100E+01, -.85361600E+00, -.24496800E+01, 0.18704300E+01, 0.20396100E+01, -.67256100E+00, 0.22366000E+00, -.15202200E+00, 0.10721600E+01, 0.61608300E+00, -.44997100E+01, -.19203900E+01, -.67830400E+00, 0.59697900E+00, 0.22554600E+01, -.10826800E+01, 0.11134600E+01, 0.19676000E+00, -.52202700E+00, -.41041100E+00, 0.13549600E+01, 0.14033100E+00, -.81650700E-01, -.97391800E-02, -.81449100E-03, 0.91210000E-02, 0.14007200E+00, -.15735500E+01, -.16652800E-01, -.86638100E+00, -.42017600E+00, 0.92284900E-02, -.13448600E+01, 0.25963300E+00, 0.24926300E+01, 0.34222900E+00, 0.93680800E+00, 0.66828600E+00, 0.25453700E+00, -.14889600E+00, 0.68939500E+00, 0.49568100E+00, -.63098300E+00, 0.44235300E+00, -.17513000E+00, 0.18830600E+00, 0.59318200E-01, 0.13310000E+01, 0.95133600E-01, 0.35408800E+00, -.86596700E-02, -.67156700E-01, -.19484300E+00, -.63558100E+00, -.16700200E+01, -.21639400E+00, 0.30447900E-01, 0.82295500E-01, 0.51111800E-01, 0.48863500E-01, -.23616500E+00, -.29270500E-01, 0.28307700E+00, -.49884600E+00, -.10591200E+01, 0.14767200E+00, 0.12156800E+01, -.38134700E-01, 0.74219200E+00, -.14561300E-01, -.26890100E-02, -.55072100E+00, 0.11622000E-02, 0.29682700E+00, 0.80549800E+00, 0.60938600E+00, 0.66082400E-01, -.22629800E+00, -.65067200E-01, -.55942300E+00, -.28462100E+00, -.50180700E-02, 0.18102500E+00, 0.30590900E-02, 0.98145500E-01, 0.29865900E+00, -.53681900E+00, -.23988400E+01, -.27298200E+00, -.16127900E+01, 0.16582700E+00, -.43182400E+00, 0.61358700E-01, 0.20414800E-01, -.17208400E+00, 0.21075200E+01, 0.16341200E+01, 0.84178500E-01, 0.10319300E+01, -.75244900E+00, -.12877900E+00, 0.10779100E-01, -.77370200E+00, -.74063400E-02, -.16520200E+01, 0.84417300E-02, -.25636900E+01, -.21817800E+00, -.84587300E+00, -.13961000E+00, -.13491600E+00, -.25519000E+00, 0.25949200E+00, -.20730600E+01, 0.43724100E-01, 0.65370900E+01, -.15909000E+00, 0.27168300E+01, -.37701700E+00, -.73154400E+00, 0.53030700E-01, 0.30870500E-01, 0.10506100E+00, -.13723100E+00, -.15447000E-01, 0.41088500E-01, -.29532800E+00, 0.13973300E-01, -.11210900E+01, 0.79726800E+00, -.14299700E-01, -.12158100E+00, -.94765500E-01, 0.35278900E+00, 0.37230900E+00, 0.11963000E-01, -.25074800E-02, 0.87984500E-01, -.18286800E-01, -.82005500E-01, -.59863100E+00, -.14960300E-01, 0.29852700E+00, -.37461500E+00, 0.13491400E+00, 0.53243700E+02, 0.18860000E+02, -.99177300E+01, -.30108700E+02, -.93445100E+01, -.60926200E+02, -.33995400E+02, 0.17991700E+02, 0.13001400E+02, 0.17549000E+02, -.25241200E+02, -.17183000E+02, -.50219800E+02, 0.26072900E+02, 0.20947800E+02, 0.25014400E+02, 0.44164700E+02, 0.14718200E+02, -.22892700E+02, -.23731300E+02, -.11894900E+02, 0.70981700E+01, 0.51531800E+02, 0.63367000E+00, 0.20391300E+01, 0.14368100E+01, 0.88828800E-01, -.98118000E+00, 0.68358600E+00, 0.99122100E+00, 0.10391700E+01, -.27753700E-01, -.65443400E+00, -.10009600E+00, 0.11689900E+00, 0.45616300E-01, 0.68595500E+00, 0.94657900E+00, 0.18953700E+00, -.60151000E+00, 0.20437000E+00, -.32043000E+01, -.62582900E+00, 0.25588800E+01, 0.99597100E+00, 0.58415500E-01, 0.50842500E+01, -.51680200E+01, -.36977600E+01 },
        { 0.10520800E+00, 0.29686000E+00, 0.80456100E+00, -.58071900E-01, -.56370300E+00, -.11963500E+00, -.44738700E+00, 0.60875400E+00, -.12721500E-01, -.22590900E+00, 0.10289200E+00, 0.76988100E+00, -.70948600E-01, 0.14975800E+00, 0.50892600E+00, 0.13921200E+00, 0.60864300E+00, -.98908500E-01, -.60383500E-01, 0.17258400E+00, 0.28313500E-01, 0.68297500E-01, 0.22427200E-02, 0.13780000E+00, 0.16396500E+00, 0.83966600E-01, 0.83794300E-01, 0.70734000E-01, -.83254300E-01, -.11395600E+00, -.24788700E-01, 0.14041300E-01, 0.15276700E+00, -.10386600E+00, -.30655300E-01, -.46436700E-01, 0.56268600E-02, -.59242400E-01, 0.25988700E-01, -.67434900E-01, 0.55366900E-01, 0.31993400E+00, 0.16604400E+00, -.37113900E-01, -.76314800E-01, 0.31704600E-01, 0.52239600E-01, -.22151800E-02, 0.23562700E-02, -.17384500E-01, -.39705100E-01, -.10859400E+00, -.16573800E+00, -.22599800E+00, 0.52761200E-01, -.18155900E+00, -.12365500E+00, 0.17680600E+00, 0.34296400E-01, -.22204900E-01, -.14556300E+00, 0.72332900E-01, -.36293900E-01, 0.13779500E+00, 0.18276000E-02, 0.40923200E-01, -.35992100E-01, -.16382300E+00, 0.77958400E-01, 0.61331300E-03, 0.11835000E+00, 0.17915000E+00, -.48600300E-01, -.75728500E-03, 0.51941100E-01, -.79480600E-01, -.34627600E-01, 0.31216700E-01, -.23988500E-01, 0.70363800E-01, 0.33016100E-02, -.25715400E-01, -.80509400E-02, 0.30494600E-01, 0.33700400E-01, 0.58249100E-01, -.19402000E-01, -.18573100E+00, -.23449400E+00, -.34989900E-03, 0.16868800E+00, 0.65634400E-01, -.71334600E-01, -.26140000E+00, 0.55536700E-01, 0.43948800E+00, -.65439900E-01, 0.11533200E+00, -.24411000E-01, -.26430600E-01, 0.43418000E+00, -.20647900E+00, -.10047000E-01, 0.29070300E+00, 0.12169600E+00, 0.25287200E+00, -.66403200E-01, 0.11565800E+00, -.14979100E+00, 0.13838700E+00, 0.14469200E+00, 0.13286600E+00, 0.52615000E-01, 0.55687300E-03, -.17914000E-01, 0.46693800E-02, 0.33448600E-01, 0.51479200E-01, 0.63235500E-01, -.30750900E-02, 0.88690700E-01, 0.10690700E-01, -.22070000E-01, 0.26162300E-01, -.76716600E-02, -.55631800E-01, -.27339500E+00, 0.15943400E+00, 0.63778500E-02, -.62040700E-01, 0.10141900E+00, 0.13590900E+00, -.41929600E-02, 0.44414600E-01, 0.52909100E-01, 0.32994800E-02, 0.56788800E-01, 0.52664400E-01, 0.43273100E-01, 0.14801000E+00, -.43107900E-01, -.94359600E-01, -.49200000E-01, -.15210000E+00, -.17895300E+00, -.32175700E-01, -.90067700E-02, -.45136800E-01, -.57771800E-02, 0.44374300E-01, 0.51007100E-01, -.48985900E-01, -.16511300E-01, 0.12898800E+00, 0.17989500E+00, -.32256900E-01, 0.10339800E+00, 0.18444000E-02, 0.57278500E-01, -.10136800E-01, -.49043300E-02, 0.64221700E-01, 0.18037100E-01, 0.30310800E-02, 0.27947900E-01, 0.68839000E-01, 0.98256700E-02, -.40434000E-02, 0.27020100E-03, 0.82422100E-01, 0.26021500E-01, 0.28463100E-01, 0.63837800E-01, -.47044900E-01, 0.37334000E-01, 0.98130800E-01, -.10239000E-01, -.87366900E-02, -.11364800E+00, 0.14861200E-03, 0.32228700E-01, 0.35412200E-01, 0.13404700E+00, -.22858100E-01, -.59617900E-01, -.54339700E-01, -.11929900E+00, 0.20008100E-02, 0.55363400E-02, -.19738400E-01, 0.25243500E-03, 0.44963900E-01, -.27753100E-01, -.80783900E-02, 0.12736300E+00, 0.47436400E-01, 0.18357600E+00, 0.11747700E-01, -.12869600E+00, 0.86178600E-02, 0.88801100E-01, -.20129700E-01, 0.42298300E+00, -.15249000E+01, 0.62497400E-02, 0.71500600E-01, -.81467700E-01, -.81836700E-01, 0.28687800E-02, 0.61392200E-01, -.25446100E-01, 0.25315500E-01, 0.58812500E-03, -.61774600E+00, 0.49884400E-01, -.81465500E-02, 0.25363500E-01, -.32972400E-01, 0.11050600E-03, -.23213400E-01, -.11031200E+00, -.32819100E-02, -.67748200E-01, -.30939000E-02, 0.22366200E+00, 0.23019400E-02, -.15917300E-01, -.19950000E-01, 0.57610900E-02, 0.62164500E-02, -.12017400E-01, -.18586400E-01, 0.29105900E-02, -.54393100E-02, 0.76113200E-02, -.14025500E+00, -.10789400E+00, 0.24533900E-01, 0.74812400E-01, -.17842200E+00, 0.55854000E+00, 0.84909900E-01, 0.50195800E+00, 0.46199800E-01, 0.10722000E+00, -.55455300E-02, 0.40202100E-01, 0.15121000E-01, 0.36164900E-01, 0.29596800E-01, -.86241100E-01, -.16525400E+00, 0.41233800E-01, -.34449800E+02, 0.20644900E+02, 0.45646000E+01, 0.17219900E+02, -.88193300E+01, 0.14951000E+02, 0.67070800E+01, -.52957700E+01, 0.94940400E+01, 0.12111500E+02, -.20547100E+01, 0.12582800E+02, -.81992400E+01, 0.22302500E+01, -.62863000E+01, -.44057300E+01, -.42595100E+01, -.86471800E+01, 0.61720600E+01, -.38717700E+01, -.31641600E+01, 0.22059200E+02, -.76032600E-01, -.18782300E+01, -.39503600E+00, 0.31483600E-01, -.39083000E+00, -.27748500E+00, 0.28107600E+00, -.17757600E+01, 0.16474400E+00, -.13239800E+00, -.38496500E+00, 0.31789400E+00, -.68021900E+00, 0.47358600E+00, 0.10424300E+01, 0.12633000E+00, 0.26960800E+00, 0.74239200E-01, -.33527100E+00, -.20132000E+00, 0.34048300E+00, -.23675700E-01, 0.81820400E-01, -.59615000E+00, -.12842800E+01, -.76457200E-01 },
        { 0.86815600E+00, -.20451600E+01, 0.99913700E+01, 0.16737700E+01, -.27950500E+01, -.13399600E+01, -.32553400E+01, 0.29701800E+01, 0.59547900E+00, -.40248300E+00, -.11276400E+01, 0.12147100E+00, -.40014200E+00, -.36218500E+00, 0.44821600E+00, 0.31026000E+00, 0.12723600E+01, -.10307900E+01, -.42364100E+00, -.17375000E+00, 0.13970000E+01, 0.56783400E+01, 0.49180500E+00, 0.20797100E+01, 0.10437500E+00, 0.64239700E+00, 0.13149200E+01, -.23367400E+01, 0.58182200E+00, -.23342100E+00, 0.84924900E+00, 0.57238900E+00, -.20867600E+01, -.52072800E+00, -.71416000E+00, -.48095100E+00, -.74104900E-01, -.86298800E+00, -.93090600E+00, 0.15863900E+01, 0.14860700E+01, 0.57345100E+01, -.21309000E+01, -.23113900E+01, 0.58028300E+00, -.97220300E+00, -.18906200E+01, 0.24174700E-01, 0.28600900E-01, -.17352700E+01, 0.30076900E+01, -.41691600E+01, -.15346100E+01, 0.32786400E+01, 0.33275800E+01, -.22851000E+01, 0.21138200E+01, -.80834700E+00, 0.56143800E+00, 0.20557700E+01, -.68888900E+00, 0.12376700E+01, -.36114000E+00, 0.36355400E+00, 0.57229200E+00, 0.63010300E+00, 0.27602600E+00, -.30102500E+01, -.30510600E+00, 0.70141500E-02, 0.44464300E+00, 0.23883000E+01, -.24744000E+00, -.34320300E+00, 0.23116800E+00, 0.24820200E+00, 0.73778500E+00, -.16339200E+00, 0.34986400E-01, -.18432500E+00, -.54154700E-01, -.28260200E+00, 0.20506400E+01, -.45004600E+00, -.46138300E-02, 0.19991100E+00, -.18628500E+01, -.92334100E+00, -.14484200E+01, 0.76237800E+00, -.58894000E+00, -.51553500E+00, 0.10535700E+01, 0.26427100E+01, -.13166100E+01, -.22239600E+01, 0.83090500E+00, -.18909900E+00, -.13385400E+01, 0.87044800E-01, 0.47942600E+01, 0.10885700E+01, -.27152100E-01, -.73462400E+00, -.72412000E+00, 0.72898300E+00, 0.46598000E+00, 0.14804600E+01, -.73260300E+00, 0.33103000E-01, -.13834800E+01, 0.10280800E+01, -.69890600E+00, -.19327100E+00, -.15513000E-02, 0.37570400E+00, -.41374100E+00, -.77142800E+01, 0.20595800E+00, -.54520800E+00, -.77267400E+00, 0.59107300E+00, 0.75563600E+00, -.12984600E+01, -.11024800E-02, 0.31844400E-03, -.69587300E+00, 0.20794600E+01, 0.25471400E+00, 0.41316700E+00, 0.61580300E+00, -.11247000E+01, 0.10447600E+00, -.80163000E+00, -.21845100E+00, -.16147900E-01, 0.75416200E+00, 0.19359500E+00, 0.42370500E+00, 0.65678500E+00, -.70417600E+00, 0.24081700E+01, -.17434500E+00, 0.20751000E+00, -.22117400E+01, -.62839700E+00, 0.22964900E+00, 0.14033700E+01, -.13093400E+01, 0.61124100E+00, -.70571800E+00, 0.48026600E+00, 0.27239600E-01, 0.74175600E+00, -.34893800E+01, -.45071600E+00, -.10179700E+01, -.79930600E-01, -.10890800E+00, -.90935200E+00, 0.12777600E+01, -.76106100E+01, 0.20725400E+00, -.10362000E+00, 0.16118000E-01, 0.53468700E+00, 0.14566500E+00, 0.14992800E+00, 0.16027100E-01, -.69596200E+00, -.99787000E-01, 0.10424800E+01, 0.25063900E-01, -.12993600E+01, -.15837500E+00, -.19595600E+01, -.59693500E+00, 0.19278400E-01, -.33186700E+01, -.53178700E-02, -.26840400E+00, 0.70131000E+00, -.24859000E+01, 0.86660200E+00, 0.19356300E+01, 0.53471600E+00, 0.48491200E+01, -.13342000E+01, -.35713400E+00, -.22898900E+00, 0.23950200E-02, -.35997300E+00, 0.89987000E+00, -.45287200E+00, -.71821300E+01, -.17656700E+01, -.14032800E+01, 0.16241200E+01, 0.20415200E+00, -.54804400E-01, -.63883300E+00, 0.19567200E+00, -.18403400E+00, 0.17930100E+02, -.50978700E+00, -.51539700E-01, 0.39350400E+00, -.12241500E+01, 0.29571200E+00, 0.18246700E+01, -.13826000E-01, 0.29709400E+01, 0.10136500E-01, 0.67104400E+01, 0.27601600E+00, 0.11841900E+01, 0.40717300E+00, -.19996500E+00, 0.35628800E-01, -.80529600E+00, 0.39321600E+01, -.27609600E-01, -.50819900E+01, -.30983200E-01, -.53094200E+01, 0.68811300E+00, 0.65189000E+00, -.34517800E+00, -.47873500E+00, 0.35491000E-01, 0.50660800E-01, -.15692300E+00, 0.12193400E+00, 0.45898200E+00, 0.19053500E-01, 0.16722500E+01, 0.10857300E+01, -.38651200E+00, -.92016900E+00, 0.71180000E+00, -.16235100E+01, -.73323600E+00, 0.40297500E-01, -.35123700E+00, -.72563200E-01, 0.11195900E+00, -.34553100E+00, -.44319700E-01, -.87479800E-01, -.43666400E+00, -.33061500E-01, 0.13608700E+01, -.65876500E+00, 0.39915000E+01, -.38196700E+02, 0.12401300E+03, -.49508200E-01, 0.14630900E+03, -.41511900E+01, -.37461000E+02, -.37905100E+02, -.70329200E+02, -.23629000E+02, 0.25193500E+03, 0.13382300E+03, -.41348600E+02, -.11424200E+03, -.66877000E+02, -.27756200E+02, 0.24699000E+02, -.72628800E+01, 0.41994400E+02, -.17873400E+02, 0.36113500E+02, -.30444600E+03, -.15042000E+01, 0.11458100E+02, 0.18922800E+01, -.19309500E+00, 0.70808100E+01, -.15584600E+01, -.41209300E+01, 0.13395700E+02, -.95188800E+00, 0.33101000E+01, 0.81240800E+00, -.17047900E+01, 0.75979500E+01, -.58824800E+01, -.11400100E+02, -.16963300E+00, -.17712600E+00, 0.15469400E+00, 0.12528400E+02, 0.29798300E+01, -.11487200E+02, -.18206200E+01, -.70608900E+00, 0.26831500E+01, 0.23519600E+02, 0.61149600E+00 },
        { -.14579200E+01, 0.19883200E+01, -.15197700E+02, -.12129000E+01, 0.66869300E+01, 0.64414200E+00, 0.63996600E+01, -.52083200E+00, -.77870500E+00, 0.14061500E+01, -.11746700E+00, -.98465000E+01, 0.10944100E+01, -.14226900E+01, -.22461300E+01, -.10924600E+01, -.79172500E+00, 0.68829200E+00, -.47014700E-01, -.46092400E+00, 0.68406300E+00, -.65358800E+01, 0.40204000E-01, 0.12144100E+00, -.10654900E+01, -.92016700E+00, -.17665300E+01, -.74499800E+00, -.37499400E+00, 0.88676400E+00, -.11591700E+01, -.25743300E+00, -.27548600E+01, 0.21346200E+01, 0.87762000E+00, -.42085300E-01, -.12093000E+00, 0.11452400E+01, 0.42329200E+00, 0.98569200E+00, 0.10630000E+01, -.23288200E+00, -.49318500E+01, 0.82134000E+00, 0.12553600E+01, -.22499400E+00, -.12425000E+01, -.64047200E-01, -.99053300E+00, 0.85881700E+00, 0.13372100E+01, 0.16038900E+00, 0.21318700E+01, -.13413100E-01, -.29798800E+00, -.61217600E+00, 0.21882300E+01, -.87239500E+00, -.17719000E+00, 0.36050200E+01, -.25734800E+00, 0.14595000E+00, 0.12633200E+01, -.18698000E+01, 0.80385300E+00, -.59686900E+00, 0.36629800E+00, 0.15980200E+01, 0.38987100E+00, 0.10193700E-01, -.15955400E+01, -.17955200E+01, -.47340500E+00, -.11504300E+01, -.56330900E+00, 0.87737900E+00, 0.62546900E+00, -.16481800E+01, 0.47638100E-02, -.51120700E+00, -.43964600E-01, 0.38856000E+00, -.80094800E+00, 0.10248300E+00, -.41411500E-01, -.14348200E+01, 0.11681000E+01, 0.29690800E+01, -.20034700E+01, -.65061500E+00, -.38378900E+00, -.92343600E+00, -.88449700E+00, 0.57297200E+01, -.10782800E+01, -.46502200E+01, -.22203000E+01, 0.15578800E+01, 0.21179800E+01, 0.90255000E-01, -.44389200E+01, 0.12281600E+01, 0.97525300E-01, -.84367800E+00, 0.29687800E+00, -.33825200E+01, -.19109700E+00, 0.18791600E+00, 0.22822200E+01, -.14734500E+01, -.23891400E+01, -.20843900E+01, 0.38194600E-01, 0.15526000E+00, 0.74028600E-01, 0.46443100E+00, -.80677900E+00, -.37448200E+01, -.21263100E+01, -.84380500E+00, 0.72144600E-01, -.51620800E-01, -.10826700E+00, 0.19599600E+00, 0.42933100E+00, -.43897100E+01, 0.60164600E+00, -.18537000E+01, -.23804100E+00, -.38001400E-01, -.11007700E+01, -.83076400E+00, 0.19437800E+00, 0.13653500E+00, -.43613000E+00, 0.14123100E-01, 0.49684600E+01, -.46814600E+00, 0.11287200E+01, 0.10219700E+01, -.74857500E+00, -.76312200E+00, 0.45891500E+00, -.47610600E+00, 0.97850800E+00, 0.68211100E+00, -.14737700E+00, -.28280700E+00, 0.17683700E+00, 0.77838900E+00, 0.87023900E+00, -.72020500E+00, 0.20045400E+01, -.30575900E+01, -.31507000E+01, 0.10133700E+01, -.14835900E+01, -.11098100E-01, -.97258800E+00, 0.26806400E+01, -.14090600E+01, -.28633000E+01, -.24552700E+00, -.20411600E+00, 0.16156400E+01, -.20753300E-01, 0.21337700E+00, 0.87823100E+00, 0.20498800E+00, -.16996800E+01, -.77165300E+00, 0.22850600E+01, -.15950200E+00, -.60912000E+01, -.45843800E-01, 0.20387400E-01, -.10375300E+01, 0.17101700E+00, 0.77780800E+01, 0.45810600E-02, -.99150700E+00, -.12830800E+01, -.21407400E+01, 0.32895800E+00, 0.23002100E+01, 0.25494500E+01, -.17700900E+01, 0.82636300E+00, 0.14858700E+00, -.17336500E+00, -.55004800E-02, 0.43570100E+00, -.39672400E+00, -.73306200E+00, 0.40620400E+01, 0.16805100E+01, 0.12959200E+01, -.14082200E+00, 0.35366000E+00, -.18555400E+00, -.13079700E+00, 0.10956600E+00, -.13899900E+02, -.19256900E+02, -.61838700E+00, -.17977500E+01, -.32646900E+00, -.46646000E+01, 0.95304700E-01, -.10492200E+01, -.24930300E-01, 0.21503800E+01, -.15059800E-01, -.37998500E+01, -.51212200E+01, 0.10384200E+01, -.30661600E+00, 0.11559500E+01, -.10034100E+01, -.39235900E+00, 0.47507500E+01, 0.89952300E-01, 0.18221400E+01, -.34722900E-01, -.59567400E+01, -.19285400E-01, -.76430200E+00, -.10458800E+01, -.18589700E+00, -.14270800E+00, 0.32840500E+00, 0.87629900E+00, -.26295100E+00, 0.13252500E+01, -.35676400E+00, 0.75625200E+00, 0.39165100E+01, -.43113800E+00, 0.11014700E+01, 0.99902200E+00, -.56904400E+00, -.14280100E+01, -.50785800E+01, -.12116600E+00, -.22702000E+01, -.58572300E-03, -.43184800E+00, 0.47048200E+00, -.31910300E+00, -.41126600E+00, 0.95543500E+00, 0.62030900E+00, -.77375500E+00, -.72444500E+01, 0.13313900E+00, -.13638700E+03, -.32917100E-01, -.25773200E+02, 0.38549900E+02, 0.76957100E+02, 0.13586400E+02, 0.47312200E+02, 0.37655500E+02, 0.11081400E+02, 0.16663700E+02, -.74147700E+01, 0.20038200E+02, -.82889900E+01, 0.59333400E+01, -.26059600E+02, -.99268100E+02, 0.34341800E+02, -.32742500E+02, -.32921200E+02, 0.52559400E+02, -.30900500E+00, -.10208600E+02, -.14493900E+01, -.18081700E+01, -.53878900E+00, -.43893300E+00, -.14761600E+01, -.11079100E+02, 0.33297400E+01, 0.11203700E+00, -.13551400E+01, 0.18653600E+01, -.10628200E+01, 0.27293200E+01, 0.14417700E+01, 0.12616700E+01, -.80843200E+00, 0.63137500E+00, -.52906600E+01, 0.25305300E+01, 0.35138200E+01, 0.14404200E+01, 0.13588100E+01, -.10272900E+01, -.17377700E+02, -.28320800E+01 },
        { -.86447600E+00, -.36078200E+00, -.48539500E+01, 0.17475200E+00, 0.36031600E+01, 0.71413800E+00, 0.51264100E+01, -.12726400E+01, 0.98193300E-01, 0.11809900E+01, -.29349300E+00, -.64232300E+01, 0.20158500E+00, -.12126000E+01, -.23608500E+01, -.13991400E+01, -.17731900E+01, 0.49154000E+00, -.19690400E+01, -.91675000E-01, -.20327600E+00, -.42130200E+01, -.48240500E+00, -.10039300E+01, -.11418500E+00, -.31616600E+00, -.99277000E+00, -.65486400E+00, -.13495500E+00, 0.12224800E+00, -.47722400E+00, -.65255500E-01, 0.76400000E-01, 0.69988600E+00, 0.37871600E+00, 0.47993400E+00, -.19396400E-01, 0.12252400E+01, 0.20115800E+00, 0.12732800E+00, -.56788200E+00, -.38142300E+01, 0.62957900E-01, 0.71358100E+00, 0.45260500E+00, 0.42170000E+00, 0.84435400E+00, 0.18953100E-03, -.52718300E+00, 0.13933900E+01, -.68238900E+00, 0.36275000E+01, 0.13482100E+01, -.45787400E+01, -.45428800E+00, 0.29153600E-01, 0.59390900E+00, -.19569500E+01, 0.57052400E-01, -.12907200E+01, 0.24365800E+01, -.16956500E+00, 0.13275800E+01, -.13062200E+01, -.40546800E+00, -.52669700E+00, 0.32850600E+00, 0.24739000E+01, -.62245900E+00, -.76367600E-02, -.22991600E+01, 0.83763100E+00, 0.32423400E+00, -.11252100E-01, -.14049800E+01, 0.16209100E+01, 0.57642300E+00, -.17494900E+01, 0.68269700E+00, -.21658800E+00, -.29634100E-01, 0.65507100E+00, -.54651500E+00, -.41439300E+00, -.59677800E+00, -.54911100E+00, 0.12282100E+01, 0.19107300E+01, 0.14439400E+01, -.62662300E+00, 0.60875100E+00, -.28456100E+00, -.86586500E+00, 0.29834700E+01, 0.62718400E+00, -.49575000E-01, -.17135400E+01, 0.49613400E+00, 0.74344100E+00, -.25912700E+00, -.44238600E+01, -.52612000E+00, 0.11160500E+00, -.53987000E+00, 0.43684900E+00, -.11987500E+01, 0.11927400E+00, 0.85342000E-01, -.45993200E+00, -.10730100E+01, -.11214300E+01, -.15187800E+01, -.65795200E-01, 0.34909700E-01, -.35353800E+00, 0.19518000E+00, -.46432500E-01, 0.45142000E+00, -.18432900E+01, 0.24217400E+00, -.10695400E+01, 0.31164000E+00, 0.71317700E-01, 0.75791000E+00, -.26290300E-01, 0.11137600E+00, 0.56624500E+00, -.83652400E+00, -.82493200E-02, -.93337400E-01, -.48821700E+00, 0.14208000E+01, -.10081600E+00, -.33481900E-02, 0.36012200E-01, -.19193300E-01, 0.25725800E+01, 0.49062500E+00, 0.68512700E+00, 0.51600000E-01, 0.11783700E+00, -.41790000E+00, -.74933600E-02, 0.16643100E+01, 0.19015000E+01, 0.28849400E+00, -.49780600E-01, 0.30783000E-01, 0.17041900E+01, -.68968900E+00, -.11096900E+01, 0.58405700E+00, 0.89807300E+00, -.12321900E+01, 0.68081500E+00, -.11585000E+00, 0.17124900E+01, 0.30934900E-01, -.39526400E+00, -.11237600E+00, -.11237300E+01, 0.75536400E-01, -.43931200E+00, -.28188300E-01, 0.51530400E+00, 0.81386500E+00, 0.14924600E+00, 0.34368300E+00, 0.71315600E-02, 0.19948700E+00, -.21319200E+00, 0.64634900E-01, 0.23775500E+00, -.17914100E+01, 0.10546600E+00, 0.20004800E+00, -.63078000E+00, 0.64912000E-01, 0.17632700E+01, 0.72653600E-03, -.50992200E+00, -.85695700E+00, -.20618600E+01, 0.36980400E+00, 0.84681300E+00, 0.43263400E+00, 0.17405300E+01, 0.30270100E+00, -.27427000E-02, 0.83639700E-01, -.41488300E-03, -.68887100E+00, 0.49178300E+00, -.31574900E+00, 0.15951100E+01, 0.73684900E+00, -.10186700E+01, -.23118600E+00, 0.62390700E+00, 0.11782400E+00, 0.80346900E+00, 0.29205700E-01, -.48549100E+00, -.11891100E+01, -.13059600E+00, -.97952500E+00, 0.18863500E+00, -.72282100E+00, 0.14271800E+00, 0.49521100E+00, -.25794200E+00, 0.28075800E+00, 0.11451300E-02, -.86918300E+00, -.13609200E+01, 0.32390400E+00, -.22501800E+00, 0.39796500E+00, -.24275500E+00, -.40550800E+00, 0.43132400E+00, 0.12197800E+00, 0.19731800E+01, -.55996700E-01, -.18663300E+01, 0.33163900E-01, 0.35717500E+00, -.50364900E-01, -.20930100E+00, -.40505500E-01, -.55268900E-01, -.15305300E+00, 0.87085600E-01, 0.61766500E+00, 0.50770000E-01, -.15644100E-02, 0.16848600E+01, -.15597700E+00, 0.13588700E+00, 0.46293800E+00, -.79421800E+00, -.23085400E+00, -.10232300E+01, -.14848400E+00, -.49386300E+00, -.12844800E-01, -.19257500E+00, 0.10395900E+00, -.10228600E-01, -.87234000E-01, 0.17695700E+00, 0.31813900E+00, -.26486100E+00, -.58129300E+00, 0.46003300E+00, 0.36587400E+00, 0.35944100E+01, -.90160000E+01, -.14769400E+02, -.77223400E+01, 0.13428100E+01, 0.10942400E+02, -.64835800E+01, -.10869000E+03, -.41382100E+02, 0.19293100E+02, 0.25915300E+02, 0.20568600E+02, 0.72856200E+01, -.99030200E+00, 0.23150200E+02, -.93549100E+01, 0.12786400E+02, -.47605000E+01, 0.98425200E+02, 0.11279400E+01, 0.47406800E+00, -.75847100E-01, -.40769800E+00, -.26003100E+01, 0.90936300E+00, 0.91064300E+00, -.19763100E+00, -.24802500E+00, -.12029300E+01, 0.51217000E+00, 0.62581800E+00, -.11072700E+01, 0.87061600E+00, 0.40794800E+01, 0.45498200E+00, -.23953000E+00, -.31287500E+00, -.25838900E+01, -.79057400E+00, 0.24384600E+01, 0.10344100E+01, 0.13817300E+00, -.17059400E+00, -.22927900E+01, 0.51974100E+00 },
        { -.10359900E+01, 0.14321200E+01, -.15119100E+02, -.82611200E+00, 0.84790600E+01, 0.76841700E+00, 0.99255200E+01, 0.12818400E+01, 0.25461200E+00, 0.48960800E+00, -.22639400E+01, -.77377600E+01, 0.21357100E+01, -.41559800E+00, -.72333600E+01, -.26741500E+01, -.78044100E+01, 0.10594900E+01, 0.29683900E+00, -.20606500E+01, 0.97030500E+00, 0.33787900E+01, 0.19895900E+00, -.94158100E+00, -.13327500E+01, -.15819100E+01, -.13143000E+01, -.44531600E-01, 0.14867000E+01, 0.10560400E+01, 0.90170700E+00, -.10391200E+00, -.61910200E+01, 0.60088700E+00, 0.55671100E+00, 0.51114200E+00, 0.15708700E+00, -.56992600E+00, -.70903200E+00, 0.24854100E+01, 0.22777100E+01, 0.68746500E+01, -.92661400E+00, -.10997200E+01, -.31307000E+01, -.13840500E+01, -.12688300E+01, -.28853600E+00, -.26314500E+00, -.12447900E+00, 0.26266700E+01, -.48615800E+01, -.25037000E+01, 0.32871800E+01, 0.10531100E+01, 0.21658500E+01, 0.13331800E+01, -.21994200E+00, 0.55759200E+00, 0.47374200E+01, -.27788600E+01, -.69387600E+00, -.61725800E+00, 0.18682800E+01, 0.58987300E+00, 0.15343900E+01, 0.14976600E+00, 0.13804700E+01, -.18430800E+01, 0.24596200E-02, -.12112400E+01, -.27150500E+01, 0.31540400E+00, -.75128900E-01, 0.13899100E+01, 0.47455000E+00, 0.97002000E+00, 0.29853300E+00, -.68038200E+00, -.15902100E+01, -.10139700E+00, 0.25807600E+00, 0.20357300E+01, -.47600100E+00, 0.39457300E+00, -.14065700E+01, 0.10143600E+01, 0.26921900E+01, -.65939300E+00, -.51239000E+00, 0.36291700E+01, -.79364200E+00, -.23557000E+00, 0.54346900E+01, -.16781400E+01, -.30075800E+01, -.18765800E+00, 0.13593500E+01, 0.51326000E+00, -.48842000E+00, 0.95203200E+00, -.12187800E+00, 0.97100800E-01, -.15268200E+00, 0.67472500E+00, -.57476500E+01, -.15617400E+01, -.19083400E+01, 0.39802100E+01, -.18522800E+01, -.34443300E+01, -.23651100E+01, -.57253300E-01, 0.39703000E-01, -.47973500E-01, -.11491300E+01, -.73613000E+00, 0.14079700E+01, 0.13517800E+01, -.32431500E+00, 0.26148700E-01, -.16359400E+01, 0.39297300E-01, -.90542800E+00, -.14739400E+00, -.28483200E+01, -.24674800E+01, -.30714900E+00, -.38124000E+00, 0.44620500E+00, 0.15694800E-01, -.23865300E+01, 0.26271200E+00, -.14385700E+00, 0.21183400E+00, 0.31521800E-01, 0.21730500E+01, -.60113600E+00, 0.22794300E+00, -.84104400E-01, -.70212400E+00, -.22718100E+01, 0.47909000E+00, -.10300500E+01, 0.57765100E-01, 0.22315600E+00, -.29455200E+00, -.20291600E+01, -.18449500E+01, 0.12424300E+01, 0.13926900E+01, -.11642700E+01, 0.97170100E+00, -.24281300E+01, -.17072700E+01, 0.96812100E+00, -.93815000E+00, -.20158700E+00, -.68124400E+00, 0.21351700E+01, 0.93527000E+00, 0.31106800E+01, 0.66747500E+00, -.29390600E+00, 0.43731300E+00, -.52613000E+00, -.20530100E+00, 0.19654900E+00, 0.17666000E+00, -.74160000E+00, 0.88154700E+00, 0.13527900E+01, -.53312900E+00, -.27567500E+00, -.21620400E+00, 0.92474800E+00, 0.32703900E+00, -.76679300E-01, 0.47951500E+01, 0.76614900E-02, -.33633200E-01, -.28649300E+00, 0.15187000E+01, -.76510600E+00, -.36232700E+00, 0.25194300E-01, -.11480100E+01, -.41628700E+00, 0.26496100E+00, 0.20479500E+00, 0.64399700E-04, 0.14561000E+01, -.47081400E+00, -.11513600E+01, 0.29814500E+01, 0.54742000E+00, 0.17377400E+01, -.10797100E+01, 0.78072300E-01, 0.33426500E+00, -.34364100E+01, 0.13549800E+00, -.17049400E+02, 0.48924800E+01, -.21012600E+00, -.76671900E+00, -.12055100E+01, -.14788200E+00, -.36045700E+00, -.45703900E+01, -.20278100E-01, -.24692800E+01, -.80335600E-02, -.74484300E+01, -.16107600E+01, -.96093900E+00, -.53166900E+00, 0.73617100E+00, 0.28254300E-01, 0.12396200E+01, -.37406900E+01, 0.75262700E-01, 0.29701400E+00, -.57086100E-01, 0.36872800E+01, -.57743300E+00, -.18456900E+01, -.12265400E+01, 0.16363100E+00, -.10360200E+01, 0.22455600E-01, 0.16585600E+01, -.36851300E+00, -.20654200E+01, -.59246900E+00, -.33543600E+01, -.58855400E+01, 0.42571900E+00, 0.29258600E+01, -.38408200E+00, -.37620300E+01, 0.61795200E+00, -.38783400E+01, 0.30438300E+00, -.63814900E+00, -.10595000E+00, 0.41010200E+00, 0.11429500E+00, 0.15900000E-01, 0.44267700E+00, 0.59715000E+00, -.10946700E+01, 0.49928200E+00, -.29338000E+01, -.31118100E+00, 0.87288600E+00, 0.30137600E-01, -.26415700E+03, -.17994000E+03, -.32502200E+02, 0.16931600E+02, 0.59607500E+02, -.86125800E+02, 0.12563900E+03, -.24466200E+03, 0.12066500E+03, 0.99582500E+02, 0.12222400E+03, 0.18763900E+03, 0.12107100E+03, 0.45002200E+02, -.18990900E+03, -.28661000E+02, 0.59699700E+02, -.30209500E+02, 0.69493400E+00, 0.16350300E+02, -.56077900E+00, 0.28361400E+01, -.29280100E+01, 0.30958500E+01, 0.37510600E+01, 0.10484900E+02, -.20761600E+01, -.96943000E+00, 0.16845500E+01, -.35517900E+01, -.25008600E+01, 0.19397800E+01, 0.16586800E+01, -.20930800E+01, 0.16883800E+00, 0.11613200E+01, -.14165500E+02, -.37160400E+01, 0.11630900E+02, -.15078900E+01, -.68848600E+00, -.82848800E+00, -.20844000E+02, -.18363200E+02 },
        { 0.21134700E+00, -.60255900E+00, 0.13421200E+01, 0.13084100E+00, -.12905300E+01, -.56577400E+00, -.17965500E+01, 0.23188400E+01, 0.14104800E+00, -.73550100E+00, 0.20448100E-01, -.60447400E+00, -.31454800E+00, -.26850100E+00, 0.91281300E+00, 0.86742100E+00, 0.67634700E+00, -.32831900E+00, 0.30230800E+00, 0.31959400E-01, -.19565100E+00, 0.11884500E+01, 0.36296000E-01, -.16436600E+00, 0.11778000E+00, 0.23149800E+00, 0.41931200E+00, -.49121100E+00, -.95617600E-01, 0.40958900E-01, -.20002300E+00, 0.18238400E+00, 0.79545000E+00, -.35955600E+00, -.14204700E+00, -.30989900E-01, 0.22291300E-01, 0.53981100E-01, -.29082400E+00, 0.14661200E+00, -.19719600E+00, 0.12384900E+01, 0.15707700E+01, -.40280200E-02, -.28109000E+00, 0.37849400E-01, 0.16687000E+00, 0.48793500E-01, 0.22952400E+00, -.30913600E+00, 0.28664300E+00, -.57542200E+00, 0.12384600E+00, 0.63083900E+00, -.18246900E+00, -.62429700E+00, 0.46517100E+00, 0.13591500E+00, -.17428400E-01, 0.29700000E+00, -.33719300E+00, 0.29121800E+00, -.31124700E+00, 0.81530700E-01, 0.13393300E+00, -.16356600E-01, 0.18527400E+00, 0.21832600E+00, -.39006800E+00, 0.67080200E-03, 0.56442400E+00, 0.68723200E+00, -.18498800E+00, -.12990500E-01, 0.44066700E+00, 0.15436300E+00, -.10186600E+00, -.41967100E+00, 0.11326800E+00, 0.62391200E-01, 0.10541600E-01, 0.43406900E-01, -.10859100E+01, -.52997300E-01, 0.17892100E-03, 0.33275600E-01, 0.35322200E+00, 0.14684600E+00, 0.10852300E+01, -.24991600E-01, -.34740700E+00, 0.51174600E-01, 0.28032400E+00, -.14954700E+01, -.78106700E-01, 0.46960400E+00, 0.57672500E+00, -.38109400E+00, -.27655900E+00, 0.15284700E+00, 0.34766000E+00, 0.10718600E+00, -.14307800E-01, 0.12541700E-01, -.19298400E-01, 0.72257900E+00, 0.24706600E+00, -.67213500E+00, 0.61261000E+00, -.34084500E-01, 0.96218700E+00, 0.49579300E+00, 0.31830500E+00, -.69541300E-01, 0.25464000E+00, -.32070600E+00, -.82432700E-02, -.22054600E+00, 0.59146100E+00, 0.19167700E-01, 0.15209400E+00, 0.57363500E+00, 0.93698600E-01, -.21732100E+00, 0.10229600E+00, 0.55106300E+00, 0.35797700E+00, 0.34123300E+00, 0.57192400E-01, -.19662000E-03, 0.30000100E+00, -.37152100E+00, 0.34986700E-01, 0.90306200E-01, 0.12051700E+00, 0.88342000E-02, 0.84740300E-01, 0.23054300E+00, 0.16515500E+00, 0.62083300E+00, -.20037600E+00, -.11710700E+01, -.31399200E+00, -.30935500E+00, -.36644900E+00, -.82377000E-01, 0.68543800E-01, -.15380200E+00, -.47945700E+00, 0.27976200E+00, 0.27694400E+00, -.19521200E+00, 0.18965500E+00, 0.35217100E-01, -.83373300E-01, -.15703900E+00, -.57585500E+00, 0.71837300E-01, 0.44525700E-01, -.62778100E-01, 0.31232600E+00, 0.59846500E-01, -.22471300E-01, 0.44767100E-01, 0.12916300E+00, -.17703000E+00, -.27521900E-02, -.92088400E-02, -.32793400E-01, 0.51470300E-01, -.94339200E-01, -.20696300E+00, 0.72233000E-01, 0.27353900E-01, 0.39544100E-01, 0.82939500E+00, -.56588200E-01, -.17392900E-01, 0.82443400E-01, -.38122800E-03, 0.28368900E-01, 0.46422600E-01, 0.12922600E+00, 0.54279600E-01, 0.17797300E+00, 0.32115600E-01, 0.20796000E+00, -.12907200E+00, -.38635500E-01, 0.32696200E-01, -.12873800E-03, -.15205900E+00, 0.17601800E+00, -.97647200E-01, -.99594300E+00, 0.72187400E-01, -.80217200E-01, -.46066100E-01, -.98541400E-01, -.14319400E-01, 0.26001500E+00, 0.69753800E-02, 0.86951200E+00, -.15627000E+01, 0.25447900E-01, -.91053700E-01, 0.21684700E-01, 0.85360700E-01, 0.36789800E-01, 0.84565700E-01, -.42865400E-01, 0.51089500E+00, -.30461400E-03, 0.10359000E+01, 0.59973900E+00, -.46821700E-01, 0.24611700E-01, -.13095200E+00, 0.36916100E-01, -.58135900E-01, -.24456700E-01, -.83369000E-02, -.38542200E+00, 0.16682600E-01, -.14997500E+00, 0.80507200E-01, 0.24363000E+00, 0.42703900E-02, 0.37369900E-02, -.81236500E-01, -.56370200E-01, -.17123400E+00, 0.64661000E-01, 0.22222400E+00, 0.63893900E-01, -.54076000E+00, -.70074000E-01, -.28774800E-01, -.28307100E+00, -.14774100E-02, 0.30337600E+00, -.89111400E-01, 0.12354800E-01, -.89012200E-02, -.41751100E+00, 0.39356100E-01, -.16228600E-01, 0.12869700E+00, 0.85937600E-01, 0.12256800E+00, 0.90890500E-01, -.28694700E-01, -.14236100E+00, -.77574800E+00, 0.10258400E+00, 0.10979200E+00, -.29253000E-02, 0.12503400E+00, 0.30770500E+02, 0.65403300E+01, -.21227300E+01, -.34280200E+01, 0.11504400E+02, -.28984200E+02, 0.34996600E+02, -.16948000E+02, -.61561100E+01, -.17471300E+02, -.24135700E+02, -.21047100E+02, -.14469100E+02, 0.31530900E+02, 0.37753600E+01, -.13771400E+02, 0.25161700E+02, 0.36283500E+00, -.53750400E+01, -.46719100E+00, -.82348200E-01, -.11271000E+01, -.28691000E+00, 0.34044100E+00, -.41989900E+01, 0.11998300E+00, -.48695400E+00, -.73078400E+00, 0.69384000E+00, -.38403900E+00, 0.58336700E+00, 0.27117900E+01, 0.50432300E+00, 0.36386400E+00, -.41533000E+00, 0.48345100E+00, -.29289300E+00, -.16983400E+00, 0.67704100E+00, 0.14496000E+00, -.63913700E+00, 0.25122400E+01, 0.22521600E+01 },
        { 0.86662000E+00, -.72919900E+00, 0.12999000E+02, 0.27825300E+01, -.58237900E+01, -.46179000E+00, -.32599900E+01, 0.51677300E+01, 0.21581600E+01, -.28905600E+00, -.41694400E-01, 0.77321400E+00, -.92638700E+00, -.18281700E+01, 0.17059900E+01, 0.17355700E+01, 0.13026600E+01, -.53212400E+00, -.39035200E+01, 0.97669000E+00, -.63744900E+00, -.55188400E+01, 0.78896400E-01, 0.48540900E+00, -.67540600E+00, 0.41849800E+00, 0.13095300E+01, -.52299600E-01, -.78952700E+00, -.91627400E+00, 0.41399000E+00, 0.76285100E+00, 0.24517600E+01, -.82631300E+00, -.14249600E+01, 0.63912200E+00, 0.43405800E-01, -.21615900E+00, -.41127300E+00, -.30356900E+00, -.13612000E+01, -.34581500E+01, -.18572500E+01, -.15866500E+01, 0.29550000E+01, 0.70796500E+00, 0.90563200E+00, 0.16428800E+00, -.17989400E-01, -.13516200E+01, -.77304400E+00, 0.20631300E+01, 0.63028000E+00, -.22965300E+01, 0.18493200E+00, -.13357600E+01, -.90455100E+00, -.10805900E+01, -.21390300E+00, -.13503600E+01, 0.16328300E+01, 0.81942100E+00, -.69327700E-01, -.74725700E+00, -.37749200E+00, -.70556000E+00, -.58676200E+00, -.20095300E+01, 0.86916300E+00, 0.66557000E-02, 0.70674800E+00, 0.21240000E+01, 0.99640600E-01, 0.21592500E+00, -.70423700E+00, 0.44243500E+00, -.23098100E+00, 0.79625500E-01, 0.14759700E+00, 0.12596200E+01, 0.37076200E-01, -.36134200E+00, 0.55675800E+00, -.45109800E+00, 0.10287000E+00, 0.12775800E+01, -.16822400E+01, -.63316500E+00, 0.61027400E+00, 0.13140100E+00, 0.77386300E+00, 0.76118300E+00, -.16053100E+01, -.27352500E+01, 0.20310700E+01, 0.60811000E+01, 0.12983000E+01, -.19043900E+01, 0.18097800E+00, 0.15912700E+00, -.14065400E+01, -.10451600E+01, -.61268600E-01, 0.94443400E+00, 0.37231300E-02, 0.85904800E+00, -.35271900E+00, 0.46648200E+00, -.24047000E+01, 0.24427100E+01, 0.36492200E+01, 0.15379800E+01, 0.39094800E+00, -.23107900E-01, 0.32000300E+00, 0.12447700E+01, 0.56196700E+00, -.30446000E+01, -.71823900E+00, 0.12850100E+00, -.38564100E-01, -.10459600E+01, 0.23878000E+00, 0.95751400E+00, 0.56108800E-01, 0.82376900E+00, 0.15108100E+01, 0.38449500E+00, 0.81652600E-01, 0.37626700E+00, 0.16901900E+00, -.91407400E+00, 0.26553000E+00, -.66037500E-01, 0.90365500E+00, 0.42896600E-01, -.23433800E+00, -.12106200E+00, 0.41627800E-01, -.22512400E+00, 0.31689400E+00, 0.19448800E+00, -.19280300E+00, -.20274000E+01, -.13042800E+01, 0.16990200E+00, -.92766100E-01, -.24237000E+00, 0.15929500E+01, -.47544400E+00, 0.80432800E-01, 0.11750400E+00, -.17087100E+01, -.20138600E+00, 0.24109700E+01, 0.83372000E-01, -.43858900E+00, 0.33278000E+00, 0.48443700E+00, -.29231200E+00, -.79537600E+00, 0.14594400E+00, -.37862300E+00, 0.27657100E+00, -.10933100E+00, -.57735200E+00, 0.67459400E-01, -.15363300E+00, -.12873700E+00, 0.30374100E+00, -.23663200E+00, -.10829700E+01, -.35332600E-01, 0.16317000E+01, -.12858600E+00, 0.25420900E+00, 0.25238600E+00, -.10186100E+00, -.38585300E+00, -.67180500E-02, -.18665200E-01, 0.12604900E+01, 0.98767800E-01, 0.24214700E+00, -.19370700E+00, 0.22325200E-01, 0.86596300E+00, -.32520700E+00, -.22716600E+00, -.14631300E-01, 0.16526700E-02, -.80390000E+00, 0.21653600E+00, 0.39678900E+00, -.26700600E+01, -.10527000E+00, -.94372300E+00, 0.26437900E+00, -.11313800E+00, -.54264500E-01, 0.94952800E+00, 0.60961200E-01, 0.57680400E+01, 0.36705700E+01, -.75179000E-01, -.36650200E-01, 0.68788400E+00, 0.33160900E+00, 0.21398300E+00, 0.13400100E+01, -.18922100E-01, 0.20667000E+00, 0.53095200E-02, -.18076900E+01, 0.49636900E+00, 0.25446300E+00, 0.20468600E+00, 0.63534400E-01, -.10669600E+00, -.28719300E+00, -.69160500E+00, 0.16905600E-01, -.14132200E+01, 0.14807000E+00, -.22721100E+01, 0.32883300E+00, 0.11935600E+01, 0.59690700E+00, -.48305800E+00, 0.13929100E+00, -.29900400E+00, -.86773700E+00, 0.17206900E+00, 0.22577500E+00, 0.33329600E+00, 0.39934900E+01, -.92877900E+00, -.56339200E-01, -.54751700E+00, 0.75173800E+00, -.83383900E+01, -.34721600E-01, 0.32237500E+01, -.50721800E+00, 0.27922100E+01, 0.13807300E-01, 0.86469000E-01, -.39259200E+00, -.83569900E-01, -.35045200E+00, 0.46701600E+00, 0.86982700E+00, -.23261800E+00, -.57914600E+01, -.18452300E+00, -.45315300E+00, -.15817600E-01, -.56739500E+00, -.36090400E+00, -.11247100E+03, -.48156400E+02, 0.41879800E+02, 0.53351300E+02, 0.64568600E+02, -.22697100E+03, 0.11174900E+03, 0.10019800E+03, 0.11347800E+03, 0.96255700E+02, 0.30956800E+02, 0.63831400E+02, -.47424700E+02, -.16642100E+02, -.10009300E+02, 0.48023700E+02, 0.45675500E+00, 0.78416900E+01, -.25103600E+00, 0.10765100E+01, 0.18122300E+01, 0.61632500E+00, -.14811300E+01, 0.32361700E+01, 0.75482500E+00, -.55318200E+00, 0.48654400E+00, -.55512800E+00, -.60417100E+01, -.76592600E+00, -.30964000E+01, -.74044600E+00, -.46726400E+00, 0.12852600E+01, -.69788100E+01, 0.89417700E+00, 0.28857400E+01, -.54075900E-01, 0.79294300E+00, 0.41445700E+00, -.21808300E+02, -.14154000E+02 },
        { 0.27552300E+00, -.25911700E+00, 0.16829100E+01, 0.22084200E+00, -.70875700E+00, -.26742400E+00, -.23367200E+01, -.15364300E+01, -.10626200E+01, -.74430100E+00, 0.15231100E+00, 0.30002900E+01, 0.34311100E+00, 0.16105200E+01, -.38865100E-01, -.25749100E-01, 0.19809900E+00, -.18316700E+00, 0.73103200E+00, 0.23420600E-01, -.34054300E+00, 0.49500700E+01, 0.28088600E+00, -.55193500E+00, 0.16090700E+00, 0.51437800E-01, 0.47156900E+00, 0.70089400E+00, 0.34611100E+00, -.36335200E-02, -.54568000E+00, -.20752300E+00, -.17126800E+01, 0.66520100E+00, 0.34948500E+00, 0.75528000E-01, -.90782700E-01, 0.59894500E+00, 0.18924200E+00, 0.10789700E+01, 0.68591600E+00, 0.53303600E+00, -.26162100E+01, -.21701500E+00, 0.13743000E+00, 0.32762700E+00, 0.14300100E+01, -.45743900E-01, -.74576600E-01, 0.41182100E+00, 0.61956200E+00, -.13877300E+01, -.38175800E-01, 0.78876300E+01, -.18665700E+00, 0.20658600E+01, 0.78946900E-01, 0.11522300E+01, -.33033100E+00, 0.11942600E+01, -.75241500E+00, -.79231400E+00, 0.65368300E-01, -.18654100E+00, 0.39263600E+00, -.13317500E+00, -.43350400E-01, -.50656500E+00, 0.32087600E+00, 0.21090300E-02, 0.35400000E+00, -.22777300E+01, -.23765000E+00, -.53133000E+00, 0.47865800E+00, -.20090400E+00, 0.93110400E-02, -.41509600E+00, -.25558800E+00, 0.12808400E+00, 0.26242000E-02, -.15217500E+00, 0.26220500E-01, 0.11579800E+00, 0.22980400E+00, -.70973200E-01, -.12643800E+01, 0.49469500E+00, -.74613800E+00, 0.11907300E+00, 0.80303200E-01, -.99175400E-01, -.39863600E+00, 0.89948200E+00, -.51958100E+00, -.81942300E+00, -.13795900E-01, -.46637000E+00, 0.86447300E-01, 0.43313200E+00, -.28411300E+01, 0.81203000E+00, 0.75228100E-02, -.15792800E+00, 0.90866300E-01, 0.98969600E-02, 0.30116500E+00, 0.35792300E+00, 0.62477100E+00, -.33546400E-01, -.14509300E+01, -.81627400E+00, 0.27893500E+00, 0.14254300E-01, -.89105900E-01, -.39173200E+00, -.36904400E+00, 0.27311300E+01, 0.24962200E+00, -.31242000E+00, 0.69702300E+00, -.15202000E+01, -.95989900E-01, -.51902700E+00, 0.18122400E-02, -.18817600E+01, -.10217700E+01, 0.41018600E-01, -.28539200E-01, -.37941700E+00, -.81126100E+00, 0.13071100E+00, 0.53545600E-01, -.16608800E-01, 0.34002400E+00, 0.13843000E-01, 0.11839200E+01, 0.17214200E-01, 0.14818500E+00, 0.49636200E+00, -.43118500E-01, -.29467200E+00, -.75111700E-01, -.63633200E+00, -.52839200E+00, 0.12943700E-03, 0.24237400E-01, -.12475500E+00, -.38474000E+00, 0.32511200E+00, 0.84594600E-01, -.96288400E-01, 0.20679300E+00, -.54582000E-01, 0.56228500E-01, -.25018600E-01, -.21320200E+00, -.28058200E-02, 0.10871200E+00, 0.40268700E+00, -.30487900E-02, -.98901600E+00, 0.18651500E+00, 0.19431400E-01, -.75603600E-01, -.13550800E+00, 0.36623000E-01, 0.24881100E+00, 0.58780900E-01, -.68761500E+00, -.40029400E+00, 0.18519800E+00, 0.34127900E-01, -.19958800E+01, 0.13203700E+00, -.34147900E+00, -.28827900E+00, 0.42611900E-01, -.21886300E+00, -.10838800E-02, 0.29922000E-01, 0.29140500E+00, -.11204300E+00, 0.22164000E+00, 0.32537800E-01, 0.17795900E+00, -.16817400E+01, 0.10235700E+00, -.73797600E-01, -.34822100E+00, -.27991000E-03, -.79913800E-01, -.22654000E+00, -.11253600E+00, -.35071000E+00, -.10939000E+00, -.10310200E+01, 0.23995900E+00, -.40913100E+00, -.21140100E+00, 0.82771700E+00, -.88714100E-01, 0.28731000E+01, -.57649000E+01, -.95467800E-01, 0.25550600E+00, 0.23714200E+00, -.68291700E+00, 0.59773500E-01, 0.74519700E+00, 0.38561900E-02, 0.12125300E+01, 0.89489100E-02, 0.11214700E+01, 0.62325400E+00, 0.20626500E-01, -.78737200E-02, 0.34925400E+00, 0.74122700E-01, -.34377900E+00, 0.72665800E+00, -.14260000E+00, -.39048700E+00, -.47540000E-01, 0.95039900E+00, 0.33707500E-01, -.28289800E+00, -.30409600E+00, -.14792500E+00, 0.14049700E+00, -.37383700E-01, -.80393000E-01, -.34712200E-01, -.14041900E+00, 0.32935700E-01, 0.85512400E+00, -.18831900E+00, 0.65563600E-01, -.22178400E+00, -.15775900E+00, 0.39381000E+00, 0.12947300E+00, 0.42423700E+00, -.49015800E-01, 0.41754800E+00, -.34402900E-01, 0.28783500E-01, 0.58534900E-01, -.25372900E-01, -.71881000E-01, -.13590600E+00, -.11180300E+00, 0.13609700E-02, 0.19101100E+01, -.56246900E-01, -.15979900E+00, 0.23051800E-02, -.14134600E+00, -.86095100E+00, -.48289900E-01, 0.27292800E+02, 0.19547500E+02, -.72282200E+00, 0.94557800E+01, -.71584900E+01, 0.31180500E+01, 0.66455700E+01, 0.35741500E+01, -.44203900E+01, 0.31714500E+01, 0.11192700E+01, -.13022900E+02, -.83216700E+01, -.10375100E+01, -.12129000E+01, 0.31133100E+00, -.65033700E+00, 0.58203700E+00, -.15859200E+00, -.78783900E+00, -.28353100E-01, 0.70570100E+00, -.79713100E+00, -.19661400E+00, -.25733200E+00, -.40633300E+00, -.14818100E+00, -.96342200E+00, 0.47245100E-01, 0.12914400E+01, 0.10937700E+00, -.69236900E+00, -.22342400E+00, -.15343000E+01, -.79486300E+00, 0.77419900E+00, -.32677500E-01, -.50179500E-01, 0.39204800E+00, -.30534300E+01, -.73102400E+00 },
        { 0.62526900E+00, 0.15738700E+01, 0.17699000E+01, -.19995000E+00, -.20989900E+01, -.61294300E+00, -.18659700E+01, 0.32448300E+01, 0.86782200E-01, -.98658400E+00, 0.45986900E+00, 0.29652300E+01, 0.19961900E-01, 0.25525700E+00, 0.30031100E+01, 0.10534900E+01, 0.21757900E+01, -.46150100E+00, 0.10551700E+01, -.34686300E+00, 0.55910700E+00, 0.13177200E+01, 0.46340200E+00, 0.14422100E+01, -.16961500E+00, 0.38230800E+00, 0.70468400E+00, 0.49587300E+00, -.82385600E-01, -.39782200E+00, 0.76321800E+00, 0.13017800E+00, 0.85694700E+00, -.82407300E+00, -.62187900E+00, -.86123500E+00, 0.87073900E-01, -.16941600E+01, -.15677500E+00, -.74488800E+00, 0.62063600E+00, 0.97213100E+00, -.22590400E+01, -.10780900E+01, 0.60523800E+00, -.19115100E+00, -.10172100E+01, 0.74251300E-01, 0.13138400E-01, -.14927800E+01, -.66561400E+00, -.75465700E+00, -.16245000E+00, 0.15347800E+01, 0.58164100E+00, -.16687100E+01, -.10408000E+01, 0.97632400E+00, -.17415400E+00, 0.30752100E+00, -.93604200E+00, 0.57118700E+00, -.52396400E+00, 0.64746900E+00, 0.12409700E+00, -.14826800E+00, -.33815300E+00, -.13102300E+01, 0.60793700E+00, 0.98904500E-03, 0.17922100E+01, 0.32260300E+00, -.43990700E+00, -.40527900E-01, 0.18086800E+00, -.88298100E+00, -.25967700E+00, 0.37783300E+00, -.15286000E+00, 0.56931400E+00, 0.25293300E-01, -.49217100E+00, 0.13249200E+01, 0.22124700E+00, 0.13087300E+00, 0.25322200E+00, -.95483200E+00, -.26226100E+01, -.26355300E+01, 0.49973900E+00, 0.75084900E+00, 0.23119800E+00, -.63340700E-01, -.30138600E+01, -.40050500E+00, 0.69966400E+00, 0.91191100E+00, 0.24016500E+00, 0.19452500E+00, -.53705100E+00, 0.47157000E+01, -.77433300E+00, -.59491300E-01, 0.88171900E+00, -.20033600E+00, 0.84826800E+00, -.67254200E+00, 0.99026000E+00, -.17697200E+01, 0.20344700E+00, 0.22204200E+00, 0.93579300E+00, -.30360300E+00, -.10124800E+00, -.51377400E+00, -.59130200E+00, 0.40826400E+00, 0.14962400E+01, 0.12044400E+01, 0.11974300E+00, 0.73851800E+00, 0.19208300E+00, -.47164700E+00, -.50185800E+00, 0.63999900E-01, -.27276300E+00, -.13839800E+01, -.14213600E+01, -.10401800E+00, -.24227800E+00, -.64518500E+00, 0.63897000E-01, -.71936400E-01, 0.20105300E+00, 0.78998100E+00, -.11995500E-02, 0.83956000E+00, 0.10911800E+00, -.50589700E+00, 0.26359300E+00, -.58432200E-02, -.94040700E+00, -.20540600E-02, -.10986200E+01, -.76927000E+00, -.42790100E-01, 0.11833900E+00, 0.88623200E+00, -.48683100E+00, 0.29864100E+00, 0.11341900E+01, -.52847400E+00, 0.20741700E+00, 0.32849400E+00, 0.97663900E+00, 0.21375300E+00, 0.40182900E+00, -.10297500E+00, 0.45841900E+00, 0.17100100E+00, 0.33789300E+00, -.15268200E+01, 0.61531400E+00, 0.11091800E-01, -.36277400E+00, -.18046500E+00, -.16170200E-01, -.37957200E+00, 0.49928100E-01, -.29818000E+00, -.55457400E+00, -.11913600E+00, 0.21763800E+00, -.10250800E+01, 0.19550300E+00, -.11946900E+01, -.48409400E-01, 0.18749900E-01, 0.33286500E+01, -.56303100E-03, -.23307000E+00, -.79707400E+00, -.70380400E+00, 0.26339600E+00, 0.25040300E+00, 0.42755600E+00, -.13435600E+01, 0.32426100E+00, -.33962000E-01, -.24298900E+00, 0.53228700E-03, -.47440700E-01, -.22604400E+00, -.60243500E+00, -.83443100E+00, 0.10725500E+01, -.16002800E+01, -.97815400E+00, 0.25429600E+00, -.35736400E+00, 0.51342500E+00, -.56160600E-01, -.78628900E+00, -.59210600E+01, -.18160600E-01, -.54890400E+00, -.53182700E+00, -.87623600E+00, 0.74747200E-01, 0.17163500E+01, 0.40548400E+00, 0.18706300E+00, -.48910600E-02, 0.49935700E+01, -.31226000E+00, -.13846200E+01, -.36680100E+00, -.73667500E-01, -.86320000E-01, 0.34964100E+00, 0.20826000E+01, -.85926800E-01, 0.65744900E+01, -.36221700E-01, -.24369900E+00, -.27795600E+00, -.46076900E+00, 0.44237400E+00, 0.31471300E+00, 0.35265100E+00, 0.35903000E-02, -.15522600E+00, -.43579600E-01, 0.35567400E+00, 0.58108500E-01, -.13214000E+01, 0.33363500E+01, -.79276900E-01, -.36771000E+00, 0.89630400E-01, 0.17263000E+01, 0.86880500E-01, -.55667600E+00, 0.28586100E-01, 0.13333400E+00, -.17374100E-01, -.10161900E+00, 0.29623000E-01, 0.69768100E-02, 0.16934400E+00, -.15882200E+00, -.67340800E+00, 0.34351600E+00, -.35099900E+01, -.65548400E+00, 0.75965400E-01, -.17815000E-01, -.12186600E+00, 0.10135100E+01, 0.23104900E+00, 0.15171500E+00, -.85995700E+02, -.19360600E+02, 0.40809100E+02, 0.39167100E+02, -.17380700E+02, -.27655000E+02, -.19571600E+02, 0.10987900E+02, 0.10020800E+02, 0.79715700E+01, 0.10245900E+02, 0.55604300E+02, 0.35112700E+02, -.62851400E+02, -.52717600E+00, 0.11765200E+01, -.45328800E+00, 0.40427300E-01, 0.12253700E+01, -.92983000E+00, -.11070500E+00, 0.36238300E+01, -.99973900E+00, 0.10221600E+01, -.17910300E+00, 0.48742700E+00, 0.22709200E+01, -.92713500E+00, -.21822800E+01, -.24600500E+00, 0.41430500E+00, 0.24221600E+00, 0.58498900E+01, -.28745300E+00, -.56734800E+01, -.15423800E+01, -.64051600E+00, -.91470800E+00, 0.16248100E+02, 0.69176500E+01 },
        { -.13951700E+01, 0.36017500E+00, -.99740900E+01, -.11753700E+01, 0.47740400E+01, 0.89320500E+00, 0.61354100E+01, 0.26674700E+01, 0.39426000E+00, 0.90276000E+00, -.11357900E+00, -.50374800E+01, 0.83410100E+00, 0.27651500E+00, 0.13314000E+01, -.44739600E+00, -.20386700E+01, 0.89949200E+00, 0.39379500E+01, -.98317700E+00, 0.20377200E+01, -.62785400E+01, 0.46078100E-01, -.64106100E+00, 0.22313700E+00, -.10145600E+01, -.29353300E+01, 0.59571100E+00, -.45948900E-01, 0.11324100E+00, -.10507500E+01, 0.76557500E-01, -.38545300E+01, 0.71424100E+00, 0.31868000E+00, -.46137800E+00, -.19082300E+00, 0.23082900E+00, 0.24180300E-01, 0.23778100E+01, 0.29567900E+01, -.57330900E+00, 0.11889000E+01, 0.50627300E+00, -.29180900E+01, 0.44115500E-01, -.97262500E+00, -.26284400E+00, -.81503200E+00, 0.22600000E+01, -.15381000E-01, 0.25768000E-01, -.19990500E+01, 0.11009400E+02, 0.37240300E+01, 0.12104700E+01, -.72904400E+00, -.18771200E+01, 0.99630400E+00, -.12847700E+01, 0.29796400E+01, -.63314100E+00, 0.60474200E+00, 0.89956800E-01, -.15744400E+01, 0.23091600E+00, 0.85122300E+00, 0.17359700E+01, -.53463600E+00, 0.10425500E-01, -.17312700E+01, -.69132300E+00, 0.56232300E-01, -.40850900E-01, 0.59406000E+00, -.67622300E+00, -.98684000E-01, 0.21794200E+01, -.15819500E+00, -.93678600E+00, -.23966700E-01, 0.41075800E+00, -.14731300E+01, 0.10145700E+00, -.14000600E+00, -.11778000E+01, 0.25156900E+01, 0.41933100E+01, 0.25329900E+01, -.10514700E+01, -.20078300E+01, -.84981300E+00, -.14447800E+00, 0.29182500E+01, -.12580500E+01, -.43789200E+01, -.19218000E+01, 0.78700200E+00, 0.61417700E+00, 0.20192800E+00, -.26014800E+01, 0.15580100E+01, 0.91234900E-01, -.59412900E+00, 0.33322700E+00, -.55008300E+00, 0.75749000E+00, -.25737900E+01, 0.25474400E+01, -.59498300E+00, -.15447500E+01, -.25634900E+01, -.70420700E-01, 0.75103300E-01, 0.48146300E+00, 0.96346500E+00, -.10220700E+00, -.53821400E+01, -.20839100E+01, -.18415900E+00, -.12158400E+01, -.14252100E+01, 0.15152600E+00, 0.20267900E+01, 0.99913500E-01, -.64121700E+00, 0.28177700E+01, -.48490300E+00, -.90029300E-01, -.33530200E+00, -.52785000E+00, 0.51624000E+00, -.57316300E-01, -.54246300E+00, 0.30477200E+00, -.31034400E-01, 0.11620700E+01, 0.35151200E+00, 0.41631800E+00, -.16635200E+01, 0.60870100E+00, -.87899800E+00, 0.49475100E+00, 0.14815300E+01, 0.22083000E+01, 0.43206500E+00, -.40594200E+00, -.12858800E+01, -.31813800E+00, 0.45191900E+00, -.90471200E+00, -.45973100E+00, 0.98733300E+00, -.89200400E-01, -.37480800E+00, -.67251700E-02, 0.11396200E+01, -.37387500E-01, -.91878700E+00, -.21601800E+00, -.77781300E+00, 0.19819600E+00, -.35726200E+00, 0.10916200E+00, 0.11322200E-02, -.22439400E+00, 0.29043400E-01, 0.26443300E+00, 0.15093600E-01, -.28001000E+00, 0.28766000E+00, 0.80062700E+00, -.18716900E+00, -.31032400E+00, -.15271600E+00, 0.69599300E+00, -.15910300E-01, -.62095700E-01, 0.19755700E+01, 0.52106200E-02, -.39450200E+00, -.17303400E+01, -.11676600E+01, -.30560200E+00, 0.88560400E+00, 0.95473800E-01, 0.13955500E+01, 0.72468300E-02, 0.23285700E+00, -.18121500E-01, 0.41813500E+00, -.11232500E+01, 0.92658700E+00, -.12769600E+01, 0.12989100E+01, 0.78772400E+00, -.32022000E+01, -.16345300E+01, 0.17713500E+01, 0.31647800E+00, -.88411900E+00, 0.24098300E+00, -.14729900E+02, 0.79312700E+01, -.12312600E+00, -.31832100E+01, -.18573800E-01, -.27746900E+01, 0.26001900E+00, -.25171800E+01, -.22888300E+00, 0.55130200E+01, 0.10392300E-01, 0.22275600E+02, 0.26652000E+01, -.13633600E+01, -.11761600E+01, 0.65493700E+00, 0.10098900E+01, 0.78397200E+00, -.12822300E+01, 0.23266600E+00, 0.42896400E+01, -.48182300E-01, -.12947200E+01, -.19566600E-01, 0.25089000E+00, 0.70280800E+00, -.35570500E+00, 0.30654700E+00, 0.19118000E+00, -.77861700E-01, 0.16102000E+00, 0.95801500E-01, 0.45509700E-02, 0.22310200E+01, 0.41839500E+01, -.48582300E+00, -.87320200E+00, 0.26706300E+00, 0.15898700E+01, -.52330300E-02, 0.20426400E+01, -.36138400E+00, 0.29774600E+01, -.19474000E+00, -.12785300E+00, -.14277600E+00, -.44525900E+00, -.82326100E+00, -.26930200E+00, -.60093300E+00, 0.84456400E-01, 0.14952000E+01, 0.62219400E+00, 0.63400400E-01, 0.56830300E-02, -.40944100E+00, 0.18972500E+01, 0.44349300E+00, 0.40118400E+00, 0.21997400E+00, 0.44522800E+02, -.13178200E+03, -.43392300E+02, 0.19223000E+02, 0.23607100E+02, 0.21565400E+02, -.14709800E+02, 0.19673500E+02, 0.38985900E+02, -.61189400E+02, 0.10421800E+02, 0.15209300E+02, 0.44712800E+02, -.10746600E+01, -.41186300E+01, 0.17327000E+01, 0.24692400E+01, -.11091800E+00, -.35504700E+00, 0.20291300E+01, -.55800500E+01, -.24576900E+01, -.11202300E+01, 0.42581500E+00, -.14007200E+00, -.83370800E+01, 0.58065500E+00, -.12027500E+01, -.29851800E+01, -.15842300E+00, 0.36662600E+00, -.11655700E+01, -.31941700E+01, 0.18453200E+01, -.25242700E+01, -.13577400E+01, 0.14680100E+01, -.91937400E+01, 0.39456800E+01 },
        { 0.17448300E+01, 0.77984000E+00, 0.96769400E+01, 0.53615000E+00, -.58561400E+01, -.12499700E+01, -.72898200E+01, 0.35959500E+01, 0.15159700E+00, -.20979200E+01, 0.63573400E+00, 0.10865400E+02, -.31888900E+00, 0.17064000E+01, 0.46926600E+01, 0.26537700E+01, 0.97931000E+00, -.67149300E+00, 0.29128300E+01, 0.86456600E+00, -.12451400E+00, 0.60072400E+01, 0.10140100E+01, 0.19369300E+01, -.12159400E+00, 0.11968700E+01, 0.19460100E+01, 0.16696100E+01, -.32627700E-01, -.27962600E+00, 0.15375700E+01, 0.64748600E+00, 0.90703900E-01, -.17921400E+01, -.11540200E+01, -.11701500E+01, 0.28144600E-01, -.27254600E+01, -.21793500E-01, -.42091500E+00, 0.63736700E+00, 0.65023700E+01, -.15180200E+01, -.21795900E+01, 0.33191000E+00, -.33348300E+00, -.52154600E+00, -.46413000E-01, 0.11226800E+01, -.33091900E+01, 0.13927400E+01, -.67045000E+01, -.27503900E+01, 0.84874200E+01, 0.10183500E+01, -.22111000E+00, -.14713000E+01, 0.34322400E+01, 0.64485700E-01, 0.20349300E+01, -.45005700E+01, 0.60164800E+00, -.26173100E+01, 0.23519200E+01, 0.77658900E+00, 0.73953300E+00, -.86529300E+00, -.53419000E+01, 0.13858900E+01, 0.31851100E-02, 0.49466500E+01, -.61701300E+00, -.64055300E+00, 0.85779000E-01, 0.26351000E+01, -.30529200E+01, -.10772300E+01, 0.34676300E+01, -.14672800E+01, 0.79418300E+00, 0.62224300E-01, -.14021800E+01, 0.11717600E+01, 0.71276400E+00, 0.12050900E+01, 0.14441800E+01, -.30160100E+01, -.40556500E+01, -.28779100E+01, 0.14791900E+01, -.16259500E+01, 0.66656600E+00, 0.16460300E+01, -.61722500E+01, -.93481100E+00, 0.10532800E+01, 0.37076500E+01, -.13954600E+01, -.16770100E+01, 0.45383900E+00, 0.91577600E+01, 0.88074100E+00, -.20685600E+00, 0.97876600E+00, -.11623400E+01, 0.29662400E+01, -.17733500E+00, 0.12142700E+00, -.11728300E+00, 0.27934000E+01, 0.26927800E+01, 0.33728100E+01, 0.67863600E-01, -.94362500E-01, 0.59924900E+00, -.17025800E+00, 0.33151800E+00, -.22084200E+01, 0.32870200E+01, -.34350800E+00, 0.18060600E+01, -.77531000E+00, -.95783600E-01, -.12559100E+01, 0.77026200E-01, 0.37626500E+00, -.59652700E+00, 0.16995200E+01, 0.97952700E-01, 0.42365800E+00, 0.10139700E+01, -.31767600E+01, 0.28441600E+00, -.18401200E-01, 0.18034300E+00, 0.37054500E-01, -.54272200E+01, -.91828100E+00, -.13906500E+01, -.14089700E+00, -.17426400E+00, 0.10815200E+01, -.50498700E-01, -.35305700E+01, -.40535200E+01, -.62725500E+00, 0.14403900E+00, 0.27310000E+00, -.28707400E+01, 0.12227700E+01, 0.19996400E+01, -.95314900E+00, -.22442000E+01, 0.23114300E+01, -.11409400E+01, 0.23816500E+00, -.34876800E+01, -.31493500E-01, 0.94586000E+00, 0.63833600E-01, 0.22291600E+01, -.36911700E+00, 0.85577500E+00, 0.90664200E-01, -.10434900E+01, -.17329200E+01, -.31717100E+00, -.91812300E+00, -.20738500E-01, -.12941500E+00, 0.22896000E+00, -.38860600E+00, -.37703300E+00, 0.35257300E+01, -.14854300E+00, -.95037800E+00, 0.11833600E+01, -.90693500E-01, -.25647800E+01, -.61597900E-02, 0.82880500E+00, 0.16062500E+01, 0.33305000E+01, -.52924300E+00, -.13632000E+01, -.82432200E+00, -.30015800E+01, -.54205200E+00, -.21589000E-01, -.21380100E+00, 0.26614000E-02, 0.13604600E+01, -.10107200E+01, 0.45112000E+00, -.37113700E+01, -.15717800E+01, 0.12715500E+01, 0.44862600E-01, -.10146800E+01, -.26513600E+00, -.13713900E+01, -.52746200E-01, 0.26653600E+01, 0.52929400E+01, 0.20433700E+00, 0.14723900E+01, -.10840900E+00, 0.17956500E+01, -.23218700E+00, -.70510400E+00, 0.59585700E+00, -.90706300E+00, 0.64135800E-02, 0.33155300E+01, 0.29771100E+01, -.70875700E+00, 0.39609700E+00, -.76106600E+00, 0.53073700E+00, 0.74170000E+00, -.70620500E+00, -.25812900E+00, -.32418000E+01, -.16942600E-01, 0.36716300E+01, 0.20999300E-01, -.49964900E+00, 0.42016800E-01, 0.36047400E+00, 0.91798900E-01, 0.53005600E-01, 0.15574800E+00, -.15005400E+00, -.10758700E+01, -.54684200E-01, 0.58084100E+00, -.34718400E+01, 0.32677600E+00, -.34675900E+00, -.94989100E+00, 0.13854700E+01, 0.44070000E+00, 0.27891800E+01, 0.28638500E+00, 0.12587000E+01, -.44503000E-02, 0.41732100E+00, -.37288800E+00, 0.28134600E-01, 0.13506900E+00, -.42957700E+00, -.58413900E+00, 0.53606300E+00, 0.14422800E+01, -.99848100E+00, -.85295100E+00, 0.36889800E+00, -.19301500E+00, 0.45985500E+00, -.41356900E-01, -.11208200E+00, 0.19923100E+00, 0.18800400E+00, 0.33652300E+03, 0.51834800E+02, -.22247400E+02, -.48749600E+02, -.25760800E+02, 0.23659900E+02, 0.25535500E+02, -.44293300E+02, -.89072200E+01, -.53947000E+02, 0.16162400E+02, -.27335900E+03, -.25982500E+01, 0.53905100E+01, 0.30487700E+00, 0.94552900E+00, 0.68891900E+01, -.14301500E+01, -.26814800E+01, 0.51908500E+01, 0.10993800E+01, 0.32358900E+01, -.53647900E+00, -.25446600E+01, 0.36592100E+01, -.23338600E+01, -.11495200E+02, -.11175600E+01, 0.16491200E+00, 0.11116600E+01, 0.33006600E+01, 0.26077100E+01, -.38343100E+01, -.23791800E+01, -.46446200E-01, 0.78878300E+00, -.56873600E+00, -.76041500E+01 },
        { 0.12553800E+00, 0.52736700E+00, 0.66947400E+00, -.11216900E+00, -.72403500E+00, -.15125500E+00, -.44618000E+00, 0.86240600E+00, -.37213800E-01, -.35581600E+00, 0.15257500E+00, 0.85113600E+00, 0.98900300E-02, 0.18046700E+00, 0.59236300E+00, 0.21791000E+00, 0.78044100E+00, -.13786700E+00, -.26905900E+00, 0.17846800E+00, -.92477800E-01, 0.33352300E+00, 0.24410700E-01, 0.62092700E-01, 0.15385000E+00, 0.74387600E-01, 0.14833500E+00, 0.24516500E+00, -.70299600E-01, -.24764800E+00, 0.16693700E-01, -.51218500E-02, 0.17438700E+00, -.10588400E+00, -.13608800E-01, -.66842300E-01, 0.99793800E-02, -.13805000E-01, 0.28107300E-01, -.90502700E-01, 0.15370500E+00, 0.62151600E+00, 0.41594500E-01, -.84302500E-01, 0.88549200E-02, 0.65913500E-01, 0.18504700E+00, 0.83280800E-02, 0.67185200E-01, -.44661400E-01, 0.16099400E+00, -.39885500E+00, -.14158100E+00, -.76427900E+00, -.67789700E-01, -.33894300E+00, 0.16415900E+00, 0.25287300E+00, 0.31269700E-01, 0.17588000E+00, -.37341000E+00, 0.13394600E+00, -.65410100E-01, 0.18923700E+00, 0.10391500E+00, 0.11288100E+00, -.11046400E-01, -.24534800E+00, 0.37178900E-01, 0.45230900E-03, 0.54535100E-01, 0.74073500E-01, -.73141100E-01, -.38789100E-01, 0.15096100E+00, -.13386700E+00, -.10559900E+00, 0.26203900E-01, -.21766000E-01, 0.60154800E-01, 0.81518200E-02, -.65419900E-01, 0.81270400E-01, 0.76140500E-01, 0.24303500E-01, 0.57231300E-01, -.42441600E-01, -.36669500E+00, -.62097100E+00, 0.62839600E-01, 0.84524300E-01, 0.90189300E-01, 0.57713600E-01, -.40177900E+00, -.11292100E+00, 0.10187700E+00, 0.25305800E-01, 0.15701300E+00, -.18230500E+00, -.38781900E-01, 0.98324200E+00, -.36544500E-01, -.21943100E-01, 0.21753300E+00, 0.60125100E-02, 0.32568600E+00, -.11200000E-01, -.22051500E-01, -.73915600E-01, 0.14102000E+00, -.11131800E+00, 0.17040000E+00, 0.53293600E-02, -.44775900E-02, 0.40378900E-02, -.90639000E-02, 0.47135700E-02, -.15039100E+00, 0.89317800E-01, -.12130300E-01, 0.17153900E-01, -.71970400E-01, -.37595300E-01, -.10479300E+00, 0.17648400E-01, -.26143800E-01, -.10253500E+00, 0.98872700E-01, -.46357600E-03, 0.25583100E-01, 0.71886900E-01, -.13488900E+00, 0.13553600E-01, 0.16717200E-01, 0.33518400E-01, 0.25984900E-02, -.30911300E-02, -.35730300E-01, -.14906800E-01, -.20467400E-01, -.56323600E-02, 0.40899600E-01, 0.28792100E-02, -.16786500E+00, -.11967500E+00, 0.24062800E-02, -.12210200E-01, 0.32899200E-01, -.93378500E-01, 0.69298800E-01, 0.19181300E+00, -.13941500E+00, -.14570100E-01, 0.17472800E+00, -.50072100E-01, -.11401100E-03, -.10525100E+00, 0.60877600E-03, 0.19537200E-01, 0.16793100E+00, -.10393300E+00, -.34810300E-01, 0.83128200E-02, -.62951700E-02, 0.24761900E-01, 0.13059200E+00, 0.24864100E-01, 0.55811700E-02, 0.14485600E-01, 0.42886400E-01, -.70681300E-01, 0.17349700E-02, 0.17752200E-01, -.69638600E-01, 0.18274200E-01, 0.14989100E-01, 0.32613900E-01, -.34674900E-02, 0.23910900E+00, 0.25510800E-03, 0.95609500E-01, 0.23412700E+00, 0.53562400E+00, -.60529300E-02, -.10738700E+00, 0.71324500E-01, -.47637100E+00, 0.12376200E+00, 0.22743900E-03, 0.11925800E-01, -.52329000E-03, -.22812900E-01, -.81408800E-01, 0.47062400E-01, -.48672500E+00, -.99126000E-01, -.13039000E+00, -.63787600E-01, -.31301200E+00, -.60863100E-01, 0.22714800E+00, -.29797400E-01, -.31987400E+00, -.19107900E+01, -.42183800E-01, -.81994500E-01, -.71380600E-01, -.49950700E+00, 0.83093100E-02, 0.51356900E+00, 0.67960200E-01, -.20592100E+00, -.25061400E-02, -.91502600E+00, -.37070700E+00, -.28062300E+00, -.45818900E-01, 0.18690000E+00, -.53025400E-01, 0.62615000E-01, 0.30882700E+00, -.61820800E-01, 0.56744900E+00, -.84331800E-02, -.42379800E+00, 0.20011200E-01, -.95134900E-01, -.14486700E+00, 0.11425700E-01, 0.30888000E-01, -.39715400E-01, -.51206100E-02, -.10227200E-01, 0.85106500E-01, 0.21272200E-02, -.51626700E-01, 0.26935000E+00, 0.35506200E-01, 0.13095100E+00, 0.79193000E-01, -.44402200E+00, -.29511600E-01, -.24780800E+00, -.10437500E-01, -.51710900E-01, 0.16059100E-02, -.37808200E-01, -.10398000E+00, 0.15927900E-02, -.35489300E-02, -.47953400E-01, 0.11357600E+00, 0.61377900E-01, -.26808600E+00, -.67119300E-01, 0.17088100E-02, 0.39993600E-03, -.71636600E-01, -.14454500E+00, 0.10312900E+00, 0.22481600E+00, 0.20972700E+00, -.48123600E-01, -.53021400E-01, 0.38028500E+02, -.18848600E+02, -.19808600E+02, -.19018400E+02, -.10305200E+02, -.25157100E+01, 0.15507400E+01, 0.38401800E+01, -.12284000E+02, -.21664900E+01, -.12839000E+02, -.14385500E+00, -.51186100E+00, -.42084600E-01, 0.90237500E-01, 0.27484200E+00, 0.11039200E+00, -.21765900E+00, -.44583600E+00, 0.12655300E+00, 0.77657600E-01, 0.42943200E+00, -.41045900E-01, 0.90315800E+00, 0.21390100E+00, -.64597000E+00, -.65702400E-01, 0.18127500E+00, 0.72737100E-01, 0.18079300E+01, 0.32854500E+00, -.91358600E+00, -.27280200E-01, 0.87663900E-02, -.10530500E-01, 0.12878000E+01, 0.66263700E+00 },
        { 0.10966000E+01, 0.50982400E+01, -.83043500E+00, 0.41077400E-01, -.18754600E+01, -.13766300E+01, -.20187300E+01, 0.24350800E+01, -.23660400E+00, -.12583700E+01, 0.15173700E+00, 0.27279000E+01, 0.49346800E+00, 0.33399000E+00, 0.14385600E+01, 0.89904500E+00, 0.74687100E+00, -.36208300E+00, 0.41173300E+00, -.21952400E+00, 0.92394200E-03, 0.27772800E+01, 0.84492500E+00, 0.37957700E+01, -.42592200E+00, 0.15086900E+00, 0.17536400E+01, 0.47542600E+00, 0.22515700E+00, -.46248400E+00, 0.15658500E+01, -.23002900E+00, 0.34809200E+00, -.48324500E+00, -.20251500E-01, -.68536300E+00, 0.99067600E-01, -.83718800E+00, 0.24516500E+00, -.90210300E+00, 0.71666800E+00, 0.18336900E+01, -.41436000E+01, -.15779500E+01, 0.22525100E+01, 0.35584400E-01, 0.95261800E+00, 0.16713900E+00, 0.64973900E+00, -.16565600E+01, 0.28895700E+01, -.26331700E+01, 0.21129300E+00, 0.12958800E+01, -.64478700E+00, -.15635000E+01, 0.20488200E+01, 0.32413200E+00, -.12693600E+00, 0.18750500E+01, -.16033300E+01, 0.94310300E+00, -.97950600E+00, 0.11386800E+01, 0.77729900E+00, -.24173200E-01, 0.17562800E+00, -.41857100E+01, 0.10447500E+01, 0.13993900E-01, -.54762500E+00, -.26904300E+00, -.10237700E+01, -.21858500E+00, 0.36352000E+01, -.97967600E+00, -.98868000E+00, -.52981300E+00, 0.11157200E+01, 0.10341900E+01, 0.91700100E-01, -.92012900E+00, -.10634100E+01, -.75408900E+00, -.77474300E+00, -.75645300E+00, 0.10451600E+01, 0.73130600E+00, 0.18240300E+01, -.44433100E+00, 0.23999100E+01, -.48280300E+00, -.75006900E+00, 0.25039100E+01, 0.59923300E+00, -.25370400E+00, 0.12819300E+01, -.16378400E+00, 0.17769900E+01, 0.41298900E+00, -.37559700E+01, -.31718300E+00, 0.95971300E-01, -.35247700E+00, 0.91107100E-01, -.20135800E+01, -.86418600E+00, 0.25314400E+00, -.71629200E+00, 0.70193900E-01, -.11010100E+01, -.14489400E+01, -.15990700E-01, -.20983200E+00, -.73293400E+00, -.48620800E+00, 0.16183400E+00, 0.44926600E+01, 0.39250200E+00, 0.47058700E+00, -.33908500E+00, 0.71605300E+00, 0.34101200E+00, -.68181800E+00, -.57815400E-01, 0.80963600E+00, 0.21461400E+00, -.26577600E+01, -.20815300E+00, -.20229000E+00, -.98854000E+00, 0.53871100E+00, -.16937600E+00, -.35208400E+00, 0.35135500E+00, -.37718500E-01, 0.20484200E+01, 0.11055000E+01, 0.33409300E+00, 0.33599600E+00, -.28174400E+00, -.14817800E+01, -.40440500E+00, 0.17561500E+01, 0.10596800E+01, 0.44249400E-01, 0.11080700E+00, -.46565700E+00, 0.40181800E+00, -.69863000E+00, -.68393400E+00, 0.40444900E+00, 0.51906200E+00, -.88439400E+00, 0.17272900E+01, -.37463800E+00, 0.23467700E+01, 0.57700100E-01, -.36378600E+00, -.74230100E+00, -.40862100E+00, 0.20046400E+01, -.20147500E+00, 0.21237200E-01, 0.26321900E-01, 0.53937000E+00, 0.51187100E-01, 0.26407400E+00, -.51518300E-01, 0.22768700E+00, 0.20992100E+00, -.33707800E+00, 0.57643300E-01, 0.74608900E+00, 0.11118100E+00, 0.98803500E+00, -.98566200E-01, 0.86308400E-01, -.23507900E+01, 0.97272300E-03, 0.31756800E+00, -.82768100E+00, 0.84414000E-01, -.55897600E-01, -.35022900E+00, -.62854000E+00, 0.18159800E+01, -.11666800E+00, 0.21586700E+00, 0.19412700E+00, 0.18545600E-02, -.10489000E+01, 0.65627100E+00, -.38175800E+00, -.41959000E+00, 0.31408300E+00, -.18563500E+01, -.11303200E+01, -.26939700E+00, 0.43513100E-01, 0.83863300E+00, -.12109400E-01, -.10927600E+01, -.53849700E+01, 0.36061100E+00, -.65728300E+00, -.56251800E+00, -.86681900E+00, 0.85091000E-01, -.33262800E-01, 0.39670600E-01, 0.66012800E+00, 0.28942500E-02, 0.31791300E+01, 0.54229300E+00, -.81129200E+00, -.28552900E+00, 0.14980400E+00, 0.68141500E-01, 0.17556500E+00, -.57101300E+00, 0.16257600E+00, 0.41836200E+01, -.53221900E-02, 0.40237700E+00, -.20410100E+00, -.25671200E-01, 0.19422500E+00, 0.12176000E+00, -.19188800E-01, -.13130200E+00, -.11913800E+00, 0.62393000E-01, 0.94049100E-01, 0.54812600E-01, -.28742900E+01, 0.14373700E+01, -.69937700E-01, -.23741900E-01, 0.93580300E-01, 0.18853200E+01, 0.21473100E+00, -.12345000E+01, -.47277500E-01, -.60011000E+00, 0.16160100E-02, -.12642900E+00, 0.16207600E+00, 0.18108700E+00, 0.32642600E+00, 0.83311900E-01, -.52018000E+00, 0.96564400E-01, -.20748300E+01, -.14699300E+00, 0.27442600E+00, 0.11283100E-01, 0.32006900E+00, 0.99065800E+00, -.23343700E+00, -.24191400E+00, -.32497300E-01, -.18146900E+00, -.71970500E-01, -.17648300E+01, 0.12744700E+02, -.73277400E+01, -.62504500E-01, -.64679100E+01, 0.28137200E+01, -.78201400E+01, -.11765400E+02, -.10927500E+02, 0.64445200E+01, 0.17207500E+01, -.12575200E+00, -.27158100E+01, -.21300900E+00, -.85245100E-01, 0.62304000E+00, -.33844600E+00, -.19177800E+00, -.22909300E+01, -.51724600E+00, 0.13833200E+00, 0.26982900E+00, -.13487500E+00, 0.41307300E+00, -.43146400E-01, -.12082800E+01, -.14318100E+00, 0.50513900E-01, 0.35591700E+00, 0.39330400E+01, 0.16171000E-01, -.32652200E+01, -.61053300E+00, -.18221800E+00, -.27172900E+00, -.22384300E-01, -.50597100E+00 },
        { -.14464300E+00, 0.62785900E+00, -.13468500E+01, -.30504900E+00, 0.50333400E+00, 0.10256200E+00, 0.13822900E+01, 0.91164900E+00, 0.27018500E+00, 0.38021500E-01, 0.12073700E-02, -.83092700E+00, 0.13811800E+00, -.38134300E+00, -.69906300E-01, -.27160700E-01, -.49985900E+00, 0.67008100E-01, -.18731200E+00, 0.30468900E-01, -.20911900E+00, -.86793300E+00, 0.18927700E-01, -.12909100E+00, -.18011600E+00, -.25460000E-01, -.13843000E+00, -.18488200E-01, -.44677300E-01, 0.72422400E-01, 0.25123600E+00, 0.16131900E+00, 0.41536800E-01, -.10453500E+00, -.89571400E-01, 0.59751800E-01, -.69287300E-02, 0.64621700E-02, -.52671800E-01, -.10078600E-01, -.14840900E+00, -.43620400E+00, -.51452500E+00, -.28788400E+00, 0.40511000E+00, -.13231300E-01, -.26082200E-01, 0.54291800E-02, 0.12246200E+00, -.28841700E+00, 0.43645800E-01, 0.20931900E-01, -.22679300E-02, -.47126300E+00, -.30015900E-02, -.32314400E+00, -.16948700E-01, -.15768200E+00, 0.71640600E-01, 0.66262400E-01, 0.20998900E-01, 0.13883400E+00, -.76019600E-01, -.95239500E-01, -.43345300E-02, 0.67152800E-01, 0.46675300E-01, 0.17512600E+00, -.26736000E+00, -.49301700E-03, -.25821000E+00, 0.13279300E+00, 0.42468100E-01, -.27799500E-01, -.27823300E-01, 0.14589900E+00, -.12284000E+00, -.12603300E+00, -.21950300E-01, 0.12773500E+00, 0.11560700E-01, -.32940900E-01, 0.53549100E-01, 0.63854700E-01, -.58194000E-01, 0.19872500E+00, -.80444100E-01, -.13221100E+00, 0.24459100E+00, 0.72411300E-01, -.12563000E+00, 0.14625900E+00, 0.43472400E-01, -.46967900E+00, 0.20053000E-01, -.17985000E+00, 0.11357000E+00, -.23093400E-01, -.21723600E+00, -.16964400E+00, 0.97284500E+00, -.98131500E-01, -.17000500E-01, -.78013800E-01, -.97135600E-01, 0.17298400E+00, 0.12453300E+00, -.18764400E+00, 0.12131400E+00, -.30186900E+00, -.31386400E+00, 0.13189600E+00, -.11317500E+00, 0.11446500E-01, -.19290500E-01, -.87151400E-01, 0.33240600E-01, 0.51286400E+00, -.11857900E+00, -.51151800E-01, 0.55706400E-01, 0.11953700E+00, -.90349300E-01, 0.60433700E-01, 0.41371700E-01, 0.42793100E+00, -.23416000E-01, 0.40605100E-01, 0.62678900E-01, -.16988800E-01, -.10750600E+00, 0.20663600E+00, -.36395400E-01, 0.40704800E-01, 0.10154000E+00, -.31358100E-02, 0.23209400E+00, 0.28089100E-01, 0.23777300E-01, -.15950100E+00, 0.44383000E-02, -.12388900E+00, -.60996400E-02, 0.45493500E+00, 0.21408200E+00, 0.36413700E-01, 0.57876800E-01, -.17866500E+00, 0.59792900E-01, -.12375800E+00, -.21116300E+00, 0.99912200E-01, -.12891900E+00, -.46879000E-01, 0.37911300E+00, -.38000800E-01, 0.82802000E-01, 0.12456600E-01, 0.74532600E-01, -.11254800E+00, -.76544900E-02, 0.74214100E+00, 0.29414100E-01, 0.25686200E-01, -.76646000E-01, -.22366700E+00, -.22979800E-01, -.56772800E-01, -.16668000E-01, -.83080500E-01, -.12606300E+00, -.20340300E+00, -.22378600E-02, 0.22929400E+00, 0.22123500E-01, -.10660300E+00, 0.43313100E-01, 0.61962900E-02, -.29131800E+00, -.75781900E-03, 0.62918000E-01, 0.30719300E+00, 0.16409800E+00, 0.11197200E+00, -.43675900E+00, -.20537500E+00, -.21474500E+00, 0.55383300E-01, -.25172100E-01, -.12534600E+00, -.23422300E-04, -.21796900E+00, -.13382900E+00, 0.15803200E+00, -.44114500E+00, -.35892800E+00, -.54284300E+00, -.19742300E+00, -.40430300E+00, -.76500700E-01, -.29657200E-01, 0.34468100E-01, -.12148600E-01, 0.36864700E+01, -.25557800E-01, -.17248700E+00, 0.87660600E-01, -.17772100E-01, -.95490500E-02, 0.24869800E+00, 0.94768200E-01, -.20800200E+00, 0.19736400E-03, -.15105700E+00, -.54809500E+00, -.11879500E+00, -.16928200E+00, -.77244200E-02, -.20673000E+00, 0.48775100E-01, 0.36876400E+00, 0.20971600E-01, 0.14208900E+01, -.20949000E-02, 0.13523100E+00, 0.25694900E-01, 0.18682000E+00, 0.12674400E+00, 0.88755900E-01, 0.11396900E+00, -.82411900E-01, -.20579600E+00, 0.43749400E-01, 0.68675000E-02, 0.81102600E-01, 0.11374500E+01, 0.10329900E+01, 0.63911400E-01, -.26932400E-02, -.86107100E-01, 0.69299000E+00, 0.31520200E-01, 0.14679700E+00, 0.95183300E-01, -.13408400E+00, 0.23459200E-02, 0.18324300E-01, 0.71528600E-01, 0.35970900E-01, 0.59594200E-01, -.66367100E-02, -.20256700E+00, 0.15280000E+00, -.19039600E-01, -.97291400E-01, -.23302800E-02, -.86335200E-03, -.62626100E-01, -.12673900E+00, -.12551400E-01, 0.46393700E-01, 0.12451600E+00, 0.38763400E-01, -.47633700E-01, -.32675100E+00, 0.16151200E-01, -.82817400E+01, 0.76319000E-02, 0.22610300E+02, 0.53511000E+01, 0.49065600E+01, 0.54848300E+01, -.73414800E+01, 0.40847300E+01, 0.94396500E+01, 0.18926200E+00, 0.42083200E+01, 0.81059600E-02, -.30602200E+00, -.29141500E+00, 0.32905500E+00, -.39655200E-01, 0.35519000E+01, -.38867700E-01, 0.77455900E-01, 0.15148200E+00, 0.59414400E+00, -.54694800E-01, -.17371400E+00, 0.71864600E+00, 0.18107400E+00, -.52215600E+00, 0.20203200E+00, -.23268300E-01, -.78289100E-01, -.28593200E+00, 0.82250700E-01, 0.84751500E-01, 0.96159200E-01, -.63424100E-01, -.13296900E+01 },
        { 0.10977700E+01, 0.31268400E+00, 0.51389400E+01, -.30714800E+00, -.41548900E+01, -.86572300E+00, -.53277000E+01, 0.11076400E+01, -.32573400E+00, -.13216700E+01, 0.32498600E+00, 0.55736700E+01, -.20757200E+00, 0.60110900E+00, 0.22930700E+01, 0.13173700E+01, 0.35209000E+01, -.77682000E+00, 0.11978300E+01, -.64953400E+00, 0.52819600E+00, 0.36652700E+01, 0.49176500E+00, 0.18017300E+01, -.61733300E-01, 0.25309800E+00, 0.15877000E+01, 0.35800400E+00, 0.21824200E+00, -.38349600E+00, 0.88837400E+00, -.33345300E-01, 0.86677700E+00, -.72201200E+00, -.27434800E+00, -.59606700E+00, 0.92283600E-01, -.12971100E+01, -.66578000E+00, -.65218800E+00, 0.78318400E+00, 0.35284600E+01, -.16285000E+01, -.93990400E+00, 0.91434600E+00, -.75029800E+00, -.16332100E+01, 0.16714800E+00, 0.55418700E+00, -.22501000E+01, 0.65962200E+00, -.33835300E+01, 0.85572900E-02, 0.68139200E+00, 0.36185200E+00, -.21425300E+01, 0.33379500E+00, 0.15532000E+01, -.36266000E+00, 0.17964200E+01, -.24191000E+01, 0.60367600E+00, -.96334300E+00, 0.88099000E+00, 0.69609800E+00, 0.24138100E+00, -.11579500E+00, -.19202800E+01, 0.24552200E+00, 0.88020900E-02, 0.20210200E+01, -.50625900E+00, -.59087500E+00, -.12361300E+00, 0.11201500E+01, -.47222500E+00, -.24854000E+00, -.35584000E+00, 0.21675500E-01, 0.20332600E+00, 0.20627600E-01, -.47222100E+00, 0.92469600E-01, -.48749700E-01, 0.62603700E-02, 0.19410400E+00, -.92347300E+00, -.16787800E+01, -.74849800E+00, 0.39839300E+00, 0.82121300E+00, -.27025100E-01, 0.78055300E-01, -.27458600E+01, -.71756800E+00, -.11608400E+01, 0.25677800E+01, -.62763800E+00, 0.29584600E+00, 0.13119700E+00, 0.50259300E+01, 0.30965000E+00, -.71918500E-01, 0.30009300E+00, -.60640200E+00, 0.20830500E+00, -.67475000E+00, 0.41048500E+00, -.83783600E+00, 0.65980500E+00, -.45586400E+00, 0.20763100E+00, -.20207500E+00, -.16854700E+00, -.31212300E+00, -.64840200E+00, 0.28244000E+00, 0.18716500E+01, 0.18395700E+01, 0.17342800E+00, 0.81462300E+00, 0.72898900E+00, -.20480600E+00, -.14560200E+01, 0.87170000E-01, 0.74443400E+00, -.66606000E-01, -.18006500E+01, -.12808100E+00, -.22365700E+00, -.84688500E+00, -.94740300E+00, -.79309300E-01, -.20479300E+00, 0.71309500E+00, -.11813500E-01, -.20459400E+00, 0.40751300E+00, -.65264300E+00, 0.18392200E+00, -.13032000E+00, -.11540900E+01, -.25668200E+00, -.52464000E+00, -.75256300E+00, -.13872000E+00, 0.15162800E+00, -.10734200E+00, -.15110800E+01, 0.36912300E+00, 0.98792500E+00, -.59851300E+00, -.10218600E+00, 0.43565200E+00, 0.73373900E+00, -.34742500E+00, 0.34780400E+00, -.34996400E-01, 0.24651900E+00, -.13043300E+00, 0.76944900E+00, 0.13332500E+01, 0.31235600E+00, -.77322300E-01, -.22029700E+00, -.11368000E+00, -.58193900E-01, -.23178500E+00, -.31083600E-01, -.99045300E-01, -.17183500E-01, 0.39401700E-02, -.52373700E-01, 0.10781400E+01, 0.68973300E-01, 0.43149600E+00, 0.44525100E+00, -.36842300E-01, -.18056700E+01, 0.13295700E-02, 0.65675400E+00, 0.11498100E+00, 0.23113900E+01, -.36879300E+00, -.88851200E+00, -.49299900E+00, -.11312500E+01, -.27500300E+00, 0.66289700E-01, 0.40501100E-01, 0.87435500E-03, 0.12294600E+00, -.20820300E+00, -.68068800E-01, -.17748600E+01, -.44150000E+00, -.13957100E+00, -.51258700E+00, -.12127200E+01, -.14194000E+00, -.79390500E-01, -.32080200E-01, -.12568300E+01, -.50396800E+01, 0.29837000E+00, 0.33789100E+00, -.56127100E+00, -.50964600E+00, -.81813400E-01, 0.57036700E-01, 0.22553000E+00, 0.60101300E+00, -.18828000E-02, 0.24489500E+01, 0.10412300E+01, -.93851300E+00, -.31921100E-01, -.15752300E+00, 0.16515100E+00, 0.41607800E+00, -.36380700E+00, -.10359600E+00, 0.21145900E+01, 0.52941800E-01, 0.17293300E+01, -.18137900E+00, -.42489000E+00, 0.36242900E-01, 0.30358000E+00, 0.31193700E-01, -.88804500E-01, 0.76409100E-01, -.52063400E-01, -.34164500E+00, -.13321900E-01, -.27825400E+01, 0.59434300E-01, 0.99266800E-01, -.11127300E+00, -.33625100E+00, 0.29333600E+01, 0.29309300E+00, -.41634700E+00, 0.80278500E-01, -.22675400E+00, 0.16916300E-01, 0.33648400E-01, 0.18606200E+00, 0.16005000E+00, 0.37233700E+00, -.97574600E-01, -.81427500E+00, 0.30273600E+00, -.15363800E+01, -.43646000E+00, 0.11096500E+00, -.21779100E-01, 0.31304600E+00, 0.15566400E+01, -.20633400E+00, 0.72502900E-01, 0.19459100E+00, -.94285700E-01, 0.14276600E+00, -.14939600E+01, 0.83501300E-01, 0.10516800E+01, 0.34976000E+01, -.34741800E+02, -.81884600E+01, -.25853500E+01, -.19559700E+02, -.34419300E+00, -.16030800E+01, -.93074500E+01, -.66890300E+00, -.62486200E+01, -.19188200E+00, 0.49968400E+00, 0.14232100E+01, -.60359500E+00, -.14657100E-01, -.51783600E+01, -.40651000E+00, 0.23198400E+00, 0.37745100E+00, -.10078300E+01, 0.73171800E+00, 0.88554400E-01, -.28462800E+01, -.61175500E+00, 0.79869800E+00, 0.97306000E-01, 0.38092400E+01, 0.12143500E+00, -.23212000E+01, -.83668700E+00, -.32559100E+00, -.31800500E+00, 0.36499600E+00, 0.14828300E+01 },
        { 0.31067700E+00, -.69982600E+00, 0.43597000E+00, 0.23769700E+00, -.87547400E-01, 0.93536200E-01, 0.18020600E+00, -.33933800E+00, 0.29204000E+00, 0.29455300E+00, -.86117400E-01, 0.26253700E+00, -.47051900E+00, -.13339200E+00, -.41440600E-01, 0.32382700E-01, 0.15826100E+00, -.22908300E-01, -.53961900E+00, -.90107600E-01, -.40445600E-01, -.49815100E+00, -.24658600E+00, -.11602400E-01, 0.11459400E+00, 0.17980200E-01, 0.10629900E+00, -.23043300E-01, -.86116100E-01, -.17248500E+00, -.18425500E-01, -.10034600E+00, 0.39081900E+00, -.12458400E+00, -.25900900E-01, -.16865600E+00, 0.37168000E-01, -.18329400E+00, -.66218400E-01, -.22865500E+00, -.31856800E-01, 0.10157500E+00, 0.66236100E+00, 0.13912200E+00, -.35419400E+00, -.86330400E-01, -.37998100E+00, 0.26088900E-01, -.84291200E-01, 0.31309800E-01, -.37918200E+00, 0.35737700E+00, 0.15286800E+00, 0.10818900E+00, 0.11990100E+00, -.14622700E+00, -.15082000E+00, -.14826100E-01, -.86931900E-01, -.17034000E+00, 0.16880100E+00, -.24862600E-01, 0.12442900E+00, -.42469400E-01, 0.10309300E-01, -.10961600E-01, 0.12265600E+00, 0.18376300E-01, -.11171200E+00, -.67672500E-03, 0.57226400E-01, 0.60082900E+00, 0.18429100E-02, 0.49439400E-01, -.22798800E-01, -.53181300E-01, -.56712000E-01, 0.74702500E-01, 0.18550100E+00, -.42351800E-01, 0.37397700E-02, 0.29438400E-01, 0.22920500E-01, -.40826800E-01, -.97311400E-02, -.16008400E+00, 0.14755000E+00, 0.10201800E+00, -.16324800E+00, -.11285700E+00, 0.14591700E-01, -.54706800E-02, -.11638900E+00, -.17986900E+00, 0.34105500E-01, 0.48594100E+00, -.11493900E+00, 0.11352100E-01, 0.47825700E-01, 0.27272500E-01, -.50692400E+00, -.10232000E+00, 0.71832100E-02, 0.19607100E+00, 0.16506700E+00, -.24943400E+00, -.20664400E+00, -.26007400E+00, -.48666400E-01, 0.55628600E+00, 0.56436000E+00, 0.16162600E+00, 0.11051600E+00, -.20989100E-01, 0.52993000E-01, 0.17416900E+00, 0.50074600E-01, -.66788500E-01, 0.20041800E+00, 0.11508700E-01, -.47156400E-01, -.27162300E+00, 0.27179000E-01, 0.86335500E-01, 0.66059800E-02, -.12967000E-01, -.22629500E+00, 0.32253200E+00, 0.10849300E-01, -.75283000E-01, 0.29924500E+00, 0.10903800E-01, 0.26742400E-01, -.49796000E-01, 0.14795600E+00, 0.53481800E-02, 0.39714200E+00, 0.13515500E+00, 0.16754400E+00, 0.45353100E-01, -.23891200E-01, -.43411700E+00, -.11855000E+00, -.18728900E+00, -.21688400E+00, -.91641200E-01, -.57418300E-01, -.10039100E+00, 0.30756700E-01, 0.11233300E+00, -.91002000E-02, -.46821300E-01, -.40571000E-01, 0.15147700E+00, 0.98444200E-02, -.70850300E-01, 0.30181300E+00, -.15463000E-01, -.40342000E-01, 0.77518200E-01, 0.84573700E-01, -.26611400E+00, 0.23461500E-01, -.26254300E-02, -.99730400E-01, 0.22729600E+00, -.29178300E-01, 0.83503100E-01, 0.23044900E-01, 0.84683800E-01, 0.29439500E+00, 0.12357800E+00, 0.28649400E-01, 0.31362900E+00, -.77041400E-01, 0.30705700E+00, 0.10866800E-01, -.19089100E-01, -.34734700E+00, 0.11817500E-02, -.29655000E-01, 0.14625800E+00, -.12684600E+00, -.54811900E-01, -.11873500E+00, -.12261400E+00, 0.64736700E+00, 0.56377700E-01, 0.72691000E-02, 0.69419600E-01, 0.19051400E-03, 0.19452500E+00, -.51003300E-01, -.52668000E-01, 0.91213500E-01, -.79801900E-01, 0.44020300E+00, 0.40366500E+00, -.27094200E+00, 0.36025100E-01, 0.48871700E-01, -.29852800E-01, 0.35090200E+00, 0.59709500E+00, -.12062500E+00, 0.17336000E+00, 0.25475300E+00, -.21150700E+00, -.16208700E-01, 0.10213800E+01, 0.12215600E-02, -.94457700E-02, 0.35094500E-03, -.25492100E-01, -.25354900E+00, 0.19766800E+00, 0.18139700E-01, 0.34022000E+00, -.22735800E-01, -.11416600E+00, 0.76365300E+00, -.46380400E-01, -.34948300E+00, -.10069700E-01, -.35640100E+00, -.53371800E-02, -.41288800E+00, -.41450400E+00, -.11667000E+00, 0.21129600E-02, -.48071700E-02, 0.36330000E+00, -.69565500E-01, -.45413800E+00, -.13389700E+00, -.28269800E+00, -.53487600E-01, -.10720100E+00, 0.22536300E+00, 0.96934900E-01, -.46404300E+00, 0.13357400E+00, -.38680400E+00, -.95579300E-01, -.63961600E-01, 0.27372900E-01, -.69597100E-01, -.40423900E+00, 0.31654700E-01, 0.19946400E-02, -.48237600E-01, 0.48437400E+00, 0.69821900E-01, 0.20058800E+00, 0.18478400E-01, -.74217000E-01, 0.53250900E-02, -.11196200E+00, -.68155100E+00, 0.24520600E-01, 0.96259900E-01, -.22433000E-01, 0.68719300E-01, 0.15680500E-01, 0.80886500E+00, 0.37175900E-02, 0.83880600E+00, -.18321400E-02, -.31804800E+02, 0.21333000E+01, -.27489400E+02, -.50332600E+01, 0.46771300E+01, 0.63177200E+00, 0.11705200E+02, -.39396200E+00, -.20191900E+01, 0.13370100E+00, 0.16120800E+00, 0.77322400E+00, -.73714100E+00, -.27553100E+00, -.18501900E+01, 0.16024800E+00, 0.15095600E+00, -.26512300E+00, -.78994200E+00, 0.17987000E+00, -.29000800E-02, -.14911700E+01, -.10531000E+00, 0.38654800E+00, -.12884900E+00, -.17490100E+01, 0.45192500E+00, 0.11962200E+01, -.59586200E-01, -.46949300E-01, -.16618500E-01, -.30998500E+00, 0.15623400E+01 },
        { 0.11602300E+00, -.58612900E+00, 0.11420700E+01, 0.15871200E+00, -.72564500E+00, -.13321600E+00, -.10604800E+01, 0.61276000E+00, 0.20475700E+00, -.19661900E+00, 0.10644400E-01, 0.90951900E+00, -.20927700E+00, 0.34833100E+00, 0.21826300E+00, 0.18681900E+00, 0.62698700E+00, -.15455000E+00, 0.58125700E-01, -.17795000E+00, 0.41433300E-01, 0.11883100E+01, -.36631800E-01, -.10124500E+00, 0.19845700E+00, 0.82998200E-01, 0.41933800E+00, 0.29849300E+00, 0.35636300E-01, -.27960200E+00, -.87785800E-01, -.39555500E-01, 0.15263400E+00, 0.84127000E-01, -.13523300E+00, 0.11150700E-01, 0.85019900E-02, 0.12516200E-01, -.27970500E+00, 0.16418800E+00, 0.66137300E-01, 0.48901900E+00, -.19356400E-01, -.80391200E-01, -.69496000E-01, 0.65343500E-02, 0.15037800E+00, 0.42079000E-01, 0.59523700E-01, -.16007000E+00, -.14711600E+00, -.32345200E+00, 0.19017100E+00, -.41999400E+00, 0.86052900E-01, -.42572100E+00, -.43338900E-01, 0.31711700E+00, -.12514700E+00, 0.39321700E-02, -.23159600E+00, 0.72532100E-01, -.75014100E-01, 0.11563000E+00, 0.74977200E-01, 0.76716000E-01, 0.53399100E-01, -.35103900E+00, -.29533900E+00, -.21202600E-02, 0.44516800E+00, 0.25972100E+00, 0.60075000E-01, 0.50898500E-01, 0.49316100E-01, 0.22497400E-01, -.72607100E-01, 0.12231400E+00, 0.45993100E-01, 0.42876500E-01, 0.54742600E-02, -.66841100E-01, 0.29118900E+00, -.78740900E-01, -.62226700E-01, 0.16024500E+00, -.27699700E+00, -.23860700E-01, 0.21011000E+00, 0.20777200E-01, 0.31378700E+00, 0.76155700E-01, -.21841700E+00, -.12262600E+01, -.19332400E+00, -.63949500E-01, 0.36706000E+00, -.19237100E+00, -.63888900E-01, -.20640900E+00, 0.19061800E+01, -.24116300E+00, -.11876500E-01, 0.13859800E+00, 0.60226000E-02, 0.16181700E+00, -.26509000E-01, 0.16531000E-01, -.39372300E-02, -.17917500E+00, 0.86433800E-01, 0.36511200E+00, -.12566000E+00, -.12905200E-01, -.14581400E-01, -.44770200E-01, 0.99794900E-01, -.11852000E+01, -.19781000E-01, -.25764400E-01, 0.80245700E-02, 0.11607100E-01, -.34826900E-01, -.13635400E+00, 0.49554300E-01, 0.55864100E-01, 0.10271800E+00, 0.97850700E-01, 0.43072700E-01, -.83174300E-01, -.15618300E+00, 0.14857000E+00, -.14517400E-01, -.83260400E-01, 0.59775000E-01, -.83894200E-02, 0.32311200E+00, 0.14445800E+00, 0.40198200E-01, -.15325700E+00, -.21732600E-01, -.28373400E+00, 0.72123800E-01, -.52665800E+00, -.32716400E+00, -.35573800E-01, -.12826000E-01, -.10893900E+00, -.12309600E+00, 0.17180900E+00, 0.12108800E+00, -.19562100E+00, 0.17258900E+00, 0.69856600E+00, -.13418200E-01, -.10896400E+00, -.17219900E+00, 0.35926800E-01, -.18047200E-01, 0.12989200E+00, 0.11836400E+00, 0.48265600E+00, 0.28023100E-01, -.15132800E-01, 0.10641900E+00, -.10089900E+00, -.19885200E-01, -.11784700E+00, -.20983900E-01, 0.93120300E-01, -.10080000E+00, 0.59163400E-01, 0.30834600E-01, 0.18095000E+00, -.53466300E-03, 0.19010700E+00, 0.82269300E-01, -.13474100E-01, 0.70894400E+00, -.44515200E-03, 0.51132100E-02, 0.35145300E-01, 0.36232200E+00, -.49935500E-01, 0.42906000E-01, 0.10936900E+00, -.57550400E+00, -.15568300E-01, -.13647200E-01, 0.47515800E-02, -.16767300E-03, 0.19980400E+00, -.34443800E-03, -.10079200E+00, 0.10422700E+00, 0.21218300E+00, 0.34851300E+00, -.69622200E-01, -.10590900E+00, -.24027700E-01, 0.80065200E-02, 0.70287900E-02, -.13161500E+01, -.13642100E+01, 0.27997900E-02, -.20965200E+00, -.35385900E-01, 0.18090500E-01, -.17757800E-01, 0.19875200E+00, 0.11993000E-01, 0.21261200E+00, -.26342800E-02, 0.43685900E+00, -.32846700E-01, -.63749700E-01, -.35763100E-01, -.91417700E-01, -.20451000E-01, 0.29689200E-01, -.55271500E-01, -.50969000E-01, -.37521600E+00, 0.15297200E-01, 0.58164600E-01, 0.15590300E-01, 0.87500000E-01, -.49150300E-01, -.39645500E-02, -.11555300E+00, 0.14174300E-01, -.10049800E+00, 0.23311900E-01, 0.31475300E+00, 0.37014300E-01, -.45588600E+00, -.12364200E+00, -.17163600E-01, 0.62940700E-02, -.18510800E-01, 0.41416800E+00, -.28259900E-02, 0.91131800E-01, 0.28826800E-01, -.74931600E-01, -.54674000E-02, 0.17178800E-01, 0.23743900E-01, 0.60240700E-02, 0.28202500E-01, 0.39485400E-01, -.23397200E+00, -.13589200E-01, -.86661900E-01, 0.31821500E-01, 0.67330700E-01, -.14644500E-02, 0.11234400E+00, 0.63084200E+00, -.29175800E-01, 0.72511300E-01, 0.38712900E-01, 0.73498700E-01, 0.52773100E-01, 0.62149600E+00, -.17124500E-01, 0.49888400E+00, 0.17170300E-03, -.12425900E+00, -.98739400E+01, -.13755700E+02, 0.39935900E+00, 0.92318600E+01, -.98662600E+01, -.46003600E+01, 0.26198500E+00, -.18777200E+01, -.19645100E+00, -.36572300E+00, -.41248900E-01, 0.30147600E+00, -.66922000E-01, -.16457400E+01, 0.29134200E+00, -.19560400E+00, 0.11060900E+00, -.42691100E-01, 0.12536200E+00, 0.59997500E-01, -.27407700E+00, 0.28150100E+00, 0.13298200E+00, -.28036700E+00, -.20507200E+01, 0.32388500E+00, 0.16969800E+01, 0.68586000E+00, 0.13843300E+00, -.82765900E-01, -.59351900E+00, 0.12423300E+01 },
        { -.16111500E+01, 0.56625300E+00, -.98296300E+01, -.90599400E+00, 0.44665000E+01, 0.11674900E+01, 0.36980500E+01, -.18075600E+01, -.52315300E+00, 0.44702500E+00, -.19013600E+00, 0.25932800E+01, 0.74398200E+00, 0.33529700E+01, -.31976000E+01, -.15092000E+01, -.23674700E+01, 0.99587300E+00, 0.18773000E+01, -.13122100E+00, 0.19479300E+00, 0.22048800E+01, 0.41092500E-01, -.18096000E+01, -.44499400E+00, -.95731600E+00, -.61339100E+00, 0.32734900E+01, 0.44958800E+00, -.84080200E+00, 0.73822000E+00, -.64467900E+00, -.35526300E+01, 0.15453700E+01, 0.77223800E+00, -.26354100E+00, -.83646700E-01, 0.58843900E+00, 0.40911700E-01, 0.11197700E+01, 0.13197100E+01, -.34149000E+01, -.20201300E+01, 0.19792100E+01, -.34632000E+01, -.24917600E-01, -.75696600E+00, -.13705000E+00, -.14284800E+01, 0.19221700E+01, -.34257900E+01, 0.32682500E+01, 0.13410800E+01, 0.10348300E+02, 0.15610800E+01, 0.31554800E+01, -.30969500E+01, 0.20107100E+01, -.71465900E+00, -.14102500E+00, 0.14663700E+01, -.14529800E+01, 0.13833600E+00, -.52287800E+00, -.30159800E+00, 0.31294100E+00, 0.10361200E+01, 0.20018800E+01, -.13827200E+01, 0.41650100E+00, 0.17516300E+01, 0.25942300E+01, -.60942800E+00, -.15117100E+00, 0.73696400E+00, -.23680700E+01, -.44952800E+00, 0.28389700E+01, -.13173900E+01, -.20205300E-01, 0.11288000E-01, -.42279400E+00, -.88380700E+00, 0.35316500E+00, 0.59194400E+00, 0.36666400E+00, -.11272700E+01, 0.39748300E+01, -.26033200E+01, -.20351800E+00, -.41769800E+01, -.35806500E+00, -.10522700E+01, 0.73712900E+01, -.25255900E-01, -.37177100E-02, -.52140300E+00, -.88782700E+00, 0.62614200E+00, 0.11809600E+01, -.53398800E+01, 0.15116900E+01, 0.46325600E-01, -.42648100E+00, -.28267500E-01, -.21597400E+01, -.13027700E+01, -.61866300E+00, -.20961400E+01, 0.51103900E+01, -.16292600E+01, -.48341800E+01, 0.12672000E+01, 0.52029000E+00, -.67342000E+00, 0.15720500E+01, 0.10099700E+01, -.49603300E+00, 0.23840800E-03, 0.67695500E+00, -.47629500E+00, 0.89547200E+00, -.49792800E+00, 0.31652900E+01, -.10296500E+01, 0.13779300E+01, -.14340700E+01, -.23644500E+00, -.23202500E+00, -.12713500E+01, 0.61129300E+00, 0.19534200E+00, 0.13939600E+00, -.40047900E+00, 0.12131600E+01, 0.90855700E-01, -.20294100E+00, 0.17927500E+01, -.11305300E+00, 0.52021000E+00, 0.59179300E+00, -.50371300E+01, -.11479300E+01, 0.37628000E+00, 0.49068700E+00, -.44107700E+00, -.12101300E+01, -.64518600E+00, 0.17554500E+01, -.19125900E+00, -.10770200E+01, 0.34916400E+00, 0.36796000E+01, 0.17244200E+01, 0.57367700E-01, -.17582400E+01, 0.30852100E+01, 0.26970100E-01, -.77594200E+00, -.48266200E+00, 0.21201500E+01, 0.75411600E+01, 0.54929600E+00, -.51054700E-02, -.57572500E+00, 0.78037700E+00, -.18438800E+00, 0.42419400E+00, -.23264000E-01, 0.15460300E+01, 0.19119900E+01, 0.12183600E+00, 0.45696800E-01, 0.35115700E+01, -.40643600E+00, 0.30405300E+01, 0.15496400E-01, -.15885100E-01, -.45781400E+00, 0.80558500E-02, 0.33678800E+00, 0.50493200E+00, 0.13199900E+01, -.86046900E+00, -.72095900E+00, -.14071300E+01, 0.11798500E+02, 0.58055500E+00, 0.27446800E+00, 0.13122700E+01, -.11287100E-02, -.21941200E+01, 0.55971200E+00, -.38264000E+00, -.11813400E+00, 0.15443300E+01, -.23778500E+01, -.56536800E+00, 0.21911300E+01, -.21276600E+00, 0.85199800E+00, -.17845000E+00, 0.93102600E+00, -.11251000E+02, 0.38734300E+00, 0.36951800E+00, -.85732800E+00, -.51890900E+00, 0.62453400E-01, -.50897900E+00, 0.13117200E+00, -.17785100E+01, 0.31200200E-03, 0.14223900E+01, -.23149500E+00, 0.63909200E-01, -.23691600E+00, -.11429600E+00, -.23643500E+00, -.24389600E+00, 0.19993600E+01, -.10334700E-01, -.61620800E+00, -.78306700E-02, -.13108100E+01, -.44193700E+00, -.88711800E+00, 0.18178900E+00, -.14734200E+00, 0.19241300E+00, 0.43294100E+00, 0.35061600E+00, -.21638500E+00, 0.24170600E+00, -.13472800E+00, 0.50615600E+00, 0.66736700E+00, -.35027200E+00, 0.85977600E+00, 0.85549200E+00, -.51384500E+01, -.36498900E+00, -.25080600E+01, -.62206700E-01, -.74948500E+00, 0.14038900E-01, -.12241200E+00, -.71131800E-01, -.10699700E+00, -.15604800E+00, 0.20126700E+00, 0.12710900E+01, -.84407800E-02, -.29123700E-02, -.27873900E+00, -.33748000E+00, 0.61700700E-02, -.16482500E+00, -.36554500E+01, -.22996200E+00, -.16138200E+01, -.39890900E+00, -.35946800E+00, 0.26626300E+00, 0.10445100E+01, -.18872700E+00, -.22978100E+01, -.58076500E-02, -.24851200E+01, -.60843800E+01, -.19433700E+03, 0.30604900E+02, 0.35615900E+02, -.19804300E+02, -.18104200E+02, 0.28136200E+01, -.78108600E+01, -.92989000E+00, -.30551000E+01, -.76999500E+00, -.11254000E+00, -.19148800E+01, -.80062400E+01, 0.22665200E+01, -.18353100E+01, -.19341000E+01, -.57555200E+00, -.14602800E+01, 0.25468500E+00, -.27028400E+00, 0.30307200E+01, 0.79644300E-01, -.15387400E+01, -.21347700E+02, 0.26774700E+01, 0.13968300E+02, 0.52223800E+01, 0.13638700E+01, -.56335400E+00, -.52630000E+01, 0.44129500E+01 },
        { -.61435300E+00, 0.11537500E+01, -.89590700E+00, -.52831100E+00, 0.35719400E+00, 0.84264200E-01, 0.21132200E+00, -.50710700E+00, -.59107800E+00, -.37364800E+00, 0.40855600E+00, -.13702700E+01, 0.95658100E+00, -.13516300E+00, -.24342400E+00, 0.26705100E-01, -.58784600E+00, 0.16555500E+00, 0.44418400E+00, 0.20670100E+00, -.33100300E+00, 0.26336800E+00, 0.19401500E+00, -.71202100E+00, 0.33794100E-01, -.72501500E-01, -.58063200E+00, 0.55169100E+00, 0.93947000E-01, 0.33303200E+00, 0.31265200E-01, 0.18632200E+00, -.42740300E+00, 0.16442300E+00, 0.21881600E+00, 0.17120400E+00, -.69049900E-01, 0.47867300E-01, 0.17553300E+00, 0.14335100E+00, 0.33347400E+00, -.27894400E+00, -.60573900E+00, 0.79388100E-01, -.42364000E+00, 0.19423900E+00, 0.51356600E+00, -.12088200E+00, -.24824700E+00, 0.42001700E+00, -.53800800E+00, 0.80719100E+00, 0.14975500E-01, 0.68341200E+00, 0.23922300E-01, 0.22274300E+00, -.12766200E+00, -.58222600E-01, 0.25791700E+00, 0.17442000E+00, 0.28147300E+00, 0.43572200E-01, -.11193100E+00, 0.42470200E-02, -.46649600E-01, 0.12842600E+00, 0.71105700E-01, 0.94720800E+00, -.47905400E+00, -.10187800E-02, -.12693100E+01, -.48963400E+00, 0.87086600E-01, -.11425800E+00, 0.12087400E+00, 0.26841700E+00, -.33939900E+00, -.28391500E+00, -.32028600E-01, 0.70515400E-01, 0.26700500E-01, -.47846100E-01, -.51497900E-01, 0.11716500E+00, -.10425200E+00, 0.83726800E-01, -.43490900E-01, -.48949600E+00, -.16461700E+00, 0.19989300E+00, -.42290400E+00, 0.22252400E+00, 0.55607900E+00, -.60825500E+00, -.26949500E+00, -.70779700E+00, 0.59415200E-01, 0.28102300E+00, -.49332300E+00, -.34582900E+00, 0.19831900E+01, -.29928700E+00, -.31174300E-01, -.89830500E-01, -.11411700E+00, 0.67531700E+00, 0.25835500E+00, 0.53304400E-01, 0.83044000E-01, -.12267500E+01, -.76300600E+00, 0.29887300E+00, -.22179300E+00, 0.25724200E-01, -.23923200E+00, -.48881800E+00, 0.19690100E-01, 0.18915500E+01, -.13219500E+00, 0.53642500E-01, 0.13952900E+00, 0.92404900E+00, -.29742000E+00, -.35614700E+00, 0.53882500E-01, 0.74195700E+00, -.79787400E-01, -.16166800E+00, 0.65648900E-01, 0.29706600E-01, -.29856100E+00, -.46537100E-01, -.12376600E-01, 0.40221400E+00, -.25447400E+00, 0.93465900E-02, -.12852000E-01, -.17728700E+00, -.11341500E+00, 0.71215300E+00, -.13758600E+00, -.60149200E+00, -.96784600E-01, 0.69216400E-01, 0.62203400E+00, 0.14796600E+00, 0.19342900E+00, -.41778500E+00, 0.35496900E+00, -.23218800E+00, 0.44303700E-01, 0.28928600E+00, -.37383600E+00, -.16860000E+01, 0.36635900E+00, -.30670600E-01, -.38926500E-01, -.52447700E-01, 0.38377700E+00, 0.68147400E+00, 0.42901100E+00, 0.21887400E+01, 0.29936200E+00, -.24639800E+00, 0.37816400E+00, 0.54394700E+00, -.11141900E-01, 0.49465700E-01, 0.43293300E-01, -.16456800E+00, -.18908500E+00, 0.57858600E+00, 0.15733100E+00, -.59682700E+00, -.67593300E-01, -.28175500E+00, -.24939300E+00, 0.73985700E-01, 0.11086000E+01, 0.10507200E-02, -.56467800E-01, -.23923700E-01, 0.68983000E-01, -.19436500E-01, -.76530600E-01, -.76457300E-02, 0.27730600E+01, 0.34073900E+00, 0.17304000E+00, 0.34801700E+00, 0.16359700E-02, -.11462900E+00, -.12365600E+00, -.14014200E-01, 0.75115100E+00, 0.10521000E+01, 0.13088300E+01, -.31909300E+00, -.19917200E+00, -.21603200E+00, 0.10408700E+01, -.13597800E+00, 0.34520300E+01, -.10890800E+02, -.56336800E-01, 0.14301900E+00, -.42782000E-01, 0.13052700E+01, -.11095800E+00, -.57511900E+00, 0.15474000E-01, -.70246300E+00, 0.73467100E-02, -.28194900E-01, 0.12980300E+01, 0.66353700E+00, 0.21595900E+00, -.11219800E+00, 0.25656400E+00, -.25816400E+00, -.16785800E+01, 0.39076200E-02, -.35601700E+01, 0.10294500E-01, 0.10973900E+01, 0.80179600E-01, 0.34697500E+00, 0.19901900E-01, -.24852100E+00, -.31314600E+00, -.36315200E-01, -.12432300E+00, 0.12725700E-01, 0.22818100E-01, 0.47688600E-01, 0.76888200E+00, -.28912600E+01, 0.12160800E+00, 0.24506500E+00, -.13344700E+00, -.19567100E+01, 0.98452300E-01, 0.20894100E+01, -.84559400E-01, 0.15162200E+01, -.48141700E-01, 0.16719100E+00, -.62043400E+00, -.11866200E+00, -.19533500E+00, 0.15719500E+00, -.36554800E+00, 0.43785900E-01, 0.22468700E+01, 0.27474200E+00, -.27015500E+00, 0.91098900E-02, 0.91345200E-01, -.70430600E+00, -.16170600E+00, 0.53033300E+00, -.55371500E+00, 0.69203700E-01, -.29636000E-02, -.17414600E+01, 0.44006900E-01, 0.14939200E+01, -.94959700E-03, 0.22670800E+00, 0.49335500E+00, 0.37192800E-01, -.44199800E+02, 0.25997400E+01, 0.40821600E+01, -.23460300E+02, -.39564200E+00, -.32677000E+01, -.15832500E+00, 0.63099000E+00, 0.58553800E+00, -.19145200E+00, -.13019500E+01, -.26883800E+01, 0.13369500E+01, -.12259100E+00, 0.14334500E+00, -.46432100E+00, -.32404100E+00, 0.64370700E+00, -.17506900E+01, -.52406500E+00, 0.10061700E+01, 0.39693100E+00, 0.36219300E+01, 0.13981400E+01, -.17815800E+01, 0.41563700E-01, 0.28743500E+00, 0.35786500E+00, -.10233400E+01, 0.30596900E+00 },
        { -.24990400E+00, 0.12813400E+01, -.24519700E+01, -.33677800E+00, 0.14848500E+01, 0.32113300E+00, 0.20514400E+01, -.89256000E+00, -.34264500E+00, 0.21117300E+00, 0.54625900E-01, -.44528800E+00, 0.53370200E+00, 0.90717600E-03, -.50873800E+00, -.54541600E+00, -.12138400E+01, 0.31047000E+00, -.44406400E+00, 0.43263400E+00, -.50420500E-01, -.87241700E+00, 0.21438900E+00, -.92811100E-01, -.44403900E+00, -.20618400E+00, -.81854700E+00, 0.25006800E+00, 0.36881600E-02, 0.36492600E+00, 0.47049700E+00, 0.85461900E-01, -.70343000E+00, -.74882200E-01, 0.28443800E+00, -.12441100E+00, -.24626400E-01, -.84085200E-01, 0.45215700E+00, -.29405000E+00, 0.43909800E+00, -.88175400E+00, -.19958100E+01, -.20319900E+00, 0.23685500E+00, 0.19095400E+00, 0.28516400E+00, -.70323400E-01, -.17632900E+00, 0.40842800E+00, 0.24032900E+00, 0.42520900E+00, -.18987500E+00, 0.23453300E+00, 0.25096500E+00, 0.35317100E+00, 0.15093200E+00, -.69039200E+00, 0.23446200E+00, -.12172300E+00, 0.55133800E+00, -.66831500E-01, 0.10979800E+00, -.14862900E-02, -.46631400E-01, 0.37155900E-01, -.28696700E-01, 0.45708300E+00, 0.10598600E+00, 0.33936500E-02, -.98035800E+00, 0.71687400E+00, -.72054000E-01, -.19436300E-01, 0.60451400E-01, 0.56248300E-01, 0.14431000E+00, -.25023100E+00, -.70498000E-01, -.11940200E+00, -.11267600E-01, 0.23284300E-01, 0.52807300E-01, 0.15936000E+00, -.82195700E-02, -.21349200E+00, 0.42715300E+00, -.20792300E+00, -.97508300E+00, -.30401400E-01, -.24095800E+00, -.19252000E+00, 0.27948900E+00, 0.26803100E+01, -.65373500E-01, -.69066700E+00, -.82080600E+00, 0.73702000E+00, 0.18156600E+00, 0.15402600E+00, -.16463500E+01, 0.36218200E+00, 0.15398100E-01, -.18860300E+00, 0.74320200E-01, -.54472000E+00, 0.76736900E-01, -.43298500E+00, 0.19075000E+00, 0.57969700E-01, -.17683000E+00, -.50438900E+00, 0.14113000E+00, 0.37175200E-01, 0.61301100E-01, 0.33972500E-01, -.23059000E-01, 0.43383700E+00, 0.15311500E+00, -.78432100E-02, -.54205900E-01, -.29452200E+00, -.26490500E-02, 0.16381800E+00, -.49840200E-01, -.58648400E-01, 0.11158600E+00, 0.43255100E+00, 0.11980600E-01, 0.64421000E-01, 0.30687200E+00, -.80085700E+00, 0.10714500E+00, -.93431500E-01, -.12652100E+00, 0.14425900E-01, 0.13916300E-01, -.63445000E-01, 0.10333400E+00, -.49588800E+00, -.60854100E-01, -.78093300E-03, 0.81111900E-01, -.19952900E-01, -.28377500E+00, 0.57375700E-02, -.20134700E+00, 0.23274700E+00, 0.19948600E-01, 0.19027300E+00, 0.42486200E+00, -.33256300E+00, 0.61536900E+00, 0.67686000E+00, -.31376400E+00, 0.70752900E-01, -.14483100E+00, 0.16492600E-01, -.25715300E+00, 0.16645600E+00, -.17149300E+00, -.48617400E+00, 0.42494600E-01, 0.23868800E-01, 0.19002500E+00, 0.56703100E-01, 0.85373400E-01, 0.12243700E+00, 0.20808300E-01, -.77017500E-01, -.21353200E-01, 0.36393600E+00, -.78522900E-01, -.62588000E+00, -.85116600E-01, -.68926300E-02, -.16147800E+00, -.55379400E-02, 0.24891200E-01, 0.57455900E-03, -.22934400E+00, -.74764300E+00, -.12499100E+01, 0.48317600E-01, 0.36054700E+00, 0.93564800E-01, 0.15322900E+01, 0.14351700E+00, 0.25239600E-01, 0.10481800E+00, 0.73799900E-03, -.31089100E+00, 0.47908600E-02, 0.14657600E+00, -.47392800E-01, 0.27910500E+00, 0.20053500E+00, -.48244800E-01, 0.56371200E+00, -.11639400E-01, -.14392500E+00, 0.24071500E-01, 0.10948900E+01, -.24226600E+01, 0.38541000E-01, -.72909100E-01, 0.38094900E-01, 0.20441300E-02, 0.15313000E-01, -.48620500E+00, 0.59449800E-01, 0.35359600E+00, 0.33622700E-02, 0.13541600E+01, -.47486200E+00, 0.25664700E+00, -.88667500E-01, 0.28415500E-01, -.29327700E-02, -.16706600E+00, 0.12373900E+01, 0.14302600E-01, 0.61772900E+00, -.17830000E-01, -.67906700E+00, -.32397300E-01, -.21209800E+00, 0.41984500E-01, -.17542600E-01, -.32311100E-01, 0.82498400E-01, 0.31877600E+00, -.71727800E-01, -.14653200E+00, -.12935800E+00, 0.65754200E+00, 0.10504900E+01, -.10807200E+00, 0.26364300E+00, 0.18312200E+00, -.40419800E+00, -.90099700E-01, -.72997500E+00, -.44578500E-01, -.43999100E-01, 0.19401600E-02, -.18551600E-01, 0.37190200E-01, -.58804000E-01, -.48398500E-01, 0.16603700E+00, 0.14285900E+00, -.49497900E-01, 0.37191500E+00, 0.12696400E+00, -.12474900E-01, -.81648800E-04, 0.30323200E-01, -.46158900E+00, -.74209500E-01, -.57818400E+00, -.27582500E+00, 0.12387100E+00, 0.67087300E-01, -.77777200E-01, -.19356000E-01, 0.38417200E+00, 0.42611400E-02, 0.49767300E-01, 0.83053700E+00, -.51649500E-01, -.40953400E+00, 0.83048900E+01, -.40645400E+01, -.10525700E+02, 0.15464500E+00, -.20323700E+01, 0.18991300E+00, 0.15014000E+00, -.20809200E+00, -.67837700E+00, -.61484200E+00, -.16607800E+01, 0.69933200E+00, -.21745800E+00, -.13851900E+01, -.19722100E+00, -.64858300E+00, 0.35840400E+00, 0.44839300E+00, 0.40850000E-01, -.69311900E-01, 0.19204900E+00, 0.11563100E+01, 0.45810800E+00, -.15358500E+01, 0.14777500E+00, 0.23715700E+00, 0.36826300E+00, -.12461800E+01, -.45263900E+00 },
        { -.50831500E+00, -.10023500E+01, -.24565700E+01, 0.93143100E-01, 0.19740400E+01, 0.51496800E+00, 0.23687700E+01, -.23333900E+01, 0.67065700E-01, 0.74945200E+00, -.38034100E+00, -.36483600E+01, 0.20896200E-01, -.71802600E+00, -.26626400E+01, -.10791500E+01, -.14990500E+01, 0.34451300E+00, -.12670000E+01, -.15997500E+00, -.46999700E+00, -.16516900E+01, -.40661800E+00, -.85147400E+00, -.60427900E-01, -.34547300E+00, -.38263600E+00, -.65190700E+00, 0.81490100E-01, 0.27727400E+00, -.51539600E+00, -.20462600E+00, -.27459800E+00, 0.87366400E+00, 0.63704900E+00, 0.64302000E+00, -.39783200E-01, 0.15129800E+01, 0.17186500E-01, 0.22719800E+00, -.33173900E+00, -.22482100E+01, -.11174300E+01, 0.25754100E+00, 0.88810300E+00, 0.27639000E+00, 0.11952400E+01, 0.37934600E-01, -.95567300E-02, 0.82480400E+00, 0.37619200E+00, 0.13383400E+01, 0.10602100E+01, -.34523400E+01, -.59054100E+00, 0.32060100E+00, 0.12979000E+01, -.13324600E+01, -.35996100E-01, 0.18601100E-01, 0.10994700E+01, -.20604000E+00, 0.74184300E+00, -.10054000E+01, 0.96279100E-02, -.19897200E+00, 0.49969400E+00, 0.15876300E+01, -.12828100E+01, -.35564400E-02, -.17152400E+01, 0.94110800E-01, 0.26300500E+00, -.25390700E-01, 0.12696600E+00, 0.15954800E+01, 0.41004100E+00, -.19508400E+01, 0.59950100E+00, -.46607300E+00, -.23397900E-01, 0.47420700E+00, -.12930900E+01, -.54372200E+00, -.54281900E+00, -.43337900E+00, 0.71024800E+00, 0.27719200E+01, 0.27623600E+01, -.60602900E+00, 0.11759900E+00, -.46030900E+00, -.10665400E+01, 0.32269900E+01, 0.26814800E+00, -.23179200E+01, -.25772200E+00, -.61058200E+00, 0.10458800E+01, 0.73772600E+00, -.64624500E+01, 0.13086700E+01, 0.98598700E-01, -.13746300E+01, -.15604500E-01, -.11183800E+01, 0.76642500E+00, -.63003300E+00, 0.68789100E+00, -.10019700E+01, -.23315200E+01, -.27687000E+01, 0.26495600E+00, 0.22755600E-01, -.91480400E-01, -.45757100E+00, -.36713400E+00, 0.32240500E+01, -.11217500E+00, 0.30836800E+00, -.76898200E+00, -.14059800E+00, 0.35261900E+00, -.16474000E+01, -.52516800E-01, 0.36433100E+00, 0.53941100E+00, -.80149500E+00, -.90117300E-01, -.22380800E+00, -.60482900E+00, 0.65595100E+00, -.10863900E+00, 0.31715300E-01, 0.31418100E+00, -.73192700E-02, 0.22679100E+01, 0.51927100E+00, 0.52746400E+00, 0.40102400E+00, -.33172100E-02, 0.33101200E+00, -.11902400E+00, 0.17094700E+01, 0.13975800E+01, -.57131900E-01, 0.57482700E-01, -.10607900E+01, 0.51964900E+00, -.62283400E+00, -.12441000E+01, 0.67201000E+00, 0.54475600E-01, -.16974300E+01, 0.18007300E-01, -.44470800E+00, 0.74028600E+00, 0.11878200E+00, -.28241300E+00, 0.66842100E-01, -.52093900E+00, 0.13619000E+01, -.52955800E+00, -.87497800E-01, 0.59876100E+00, 0.59188600E+00, 0.14005800E+00, 0.82961100E-01, -.68122200E-01, 0.35782800E+00, -.42801300E-02, 0.61293900E+00, 0.20788200E+00, -.70993700E-01, 0.36914500E-01, -.70509800E-01, -.17334300E+00, -.17843600E-01, -.13478200E+01, -.33823400E-03, -.12625000E-01, -.14936100E+00, -.19400600E+00, -.39748200E-01, 0.26105600E+00, -.33845700E+00, 0.20500800E+01, 0.91941400E-03, -.36830800E-01, 0.13751800E+00, -.12855200E-02, -.60311100E+00, 0.44385400E+00, 0.17652000E+00, 0.12363600E+00, -.23880400E+00, 0.66552700E-01, 0.27807000E+00, -.30483900E-01, 0.16444600E+00, 0.47543200E+00, 0.89222600E-01, 0.28241300E+00, -.14963000E+00, 0.18282900E-01, -.34910700E+00, 0.44406300E+00, 0.63828600E-01, 0.92100200E-01, -.50488100E+00, -.30573500E+00, 0.99690600E+00, 0.15488600E-02, 0.57627200E+00, 0.74433100E+00, 0.36452400E+00, 0.25125900E-01, 0.18118000E+00, 0.13982100E+00, -.39943400E+00, -.33129800E+00, -.30229000E-01, -.14951600E+01, 0.55319900E-01, -.85812700E+00, 0.59202200E-01, 0.33390900E+00, -.85002700E-01, -.18750000E+00, -.21488300E+00, 0.32901500E-01, -.67153400E-01, 0.67339800E-01, 0.50513900E+00, 0.23029000E-01, -.85816700E+00, 0.46440100E+00, -.10305000E+00, 0.23739500E+00, 0.35688100E+00, -.64162300E+00, -.17198500E+00, -.64868000E+00, -.14390500E+00, -.75420900E+00, 0.49624600E-01, -.78965300E-01, 0.35052400E+00, 0.14849100E+00, 0.62354300E-01, 0.28802300E+00, 0.32904100E+00, -.42338600E+00, 0.56552600E+00, 0.51690900E+00, 0.19384400E+00, 0.14086100E-01, 0.24617100E+00, 0.57470500E+00, -.12307000E+00, 0.24379800E+00, -.61830900E+00, -.69641200E-01, -.13953300E+00, 0.75568500E+00, 0.18814800E-01, 0.57002000E+00, -.23504800E-02, 0.24345800E+00, 0.40688300E+00, -.21214600E-01, -.27059300E-01, 0.97263600E+00, 0.89182500E+01, 0.96688600E+01, -.40772300E+00, 0.79080800E+00, -.41252700E+00, -.16339500E+00, 0.67763800E+00, 0.11022400E+00, 0.61169800E+00, 0.11201000E+01, -.88011200E+00, 0.53292200E+00, 0.86735400E+00, 0.49617300E+00, 0.19698000E+01, -.41488100E+00, -.89746700E+00, 0.73440600E-01, 0.44102200E+00, -.15514400E+00, -.18024500E+00, -.40586400E+00, 0.78295900E+00, -.70134800E+00, -.31399300E+00, -.60083400E+00, 0.23385800E+01, 0.88051100E+00 },
        { -.71958200E+00, 0.10854300E+01, -.57308200E+01, -.76568100E+00, 0.29095600E+01, 0.38573600E+00, 0.25148000E+01, -.56949600E+00, -.60120700E+00, 0.18330500E+00, -.69675400E-01, -.23734700E+01, 0.95925000E+00, 0.19088900E+00, -.14772300E+01, -.75575300E+00, -.20065500E+01, 0.40296900E+00, 0.10468500E+01, -.26505600E+00, -.12966000E+00, 0.43818900E+00, 0.26527000E+00, -.68887500E+00, -.52560200E+00, -.37830200E+00, -.71315800E+00, 0.86660100E-02, 0.24419000E+00, 0.69283200E+00, 0.91352300E-01, 0.87072800E-01, -.13442000E+01, 0.49055400E+00, 0.29901900E+00, 0.33314500E+00, -.81034500E-01, 0.30724200E+00, 0.21474200E+00, 0.41752100E+00, -.97201700E-01, -.79411900E+00, -.54149000E+00, 0.27885100E+00, -.63460700E-01, -.62298300E-01, 0.94959200E-01, -.96612100E-01, -.24651600E-01, 0.38999100E+00, 0.49195300E+00, -.10077000E+00, -.21071600E+00, 0.22846900E+01, -.27693900E+00, 0.12030500E+01, -.24462300E-01, -.20842800E+00, 0.14275900E+00, 0.55327500E+00, -.12428400E-01, -.44094700E+00, -.75754200E-01, -.59099900E-01, -.10010300E+00, 0.15612500E+00, 0.60865700E-01, 0.11518200E+01, -.42484200E+00, 0.78274300E-03, -.89786900E+00, -.11372600E+01, 0.16245100E+00, -.63187700E-01, -.61317300E-01, 0.21059100E+00, 0.10413600E+00, 0.16228600E+00, -.32216300E+00, -.49255400E+00, -.18495300E-01, 0.92586100E-01, 0.11042000E+00, 0.24307700E-01, -.64904800E-01, -.29443200E-01, 0.33432400E+00, 0.10596600E+01, 0.12640200E+01, -.64777300E-01, -.32616600E+00, -.19386900E+00, 0.25432300E+00, 0.15397500E+01, -.17241200E+00, -.15116300E+01, -.35518100E+00, 0.11577700E+00, 0.13579000E+00, 0.56960200E-02, -.75587700E+00, 0.37478100E+00, 0.24060100E-01, -.74631500E+00, -.12989100E+00, -.40204700E+00, 0.43342900E+00, -.26530300E+00, 0.10911300E+01, -.12401900E+01, -.12806300E+01, -.89110700E+00, -.49998800E-01, 0.97144000E-01, 0.11273600E-01, -.30006500E+00, -.20129600E+00, -.57565300E-01, -.55969000E+00, -.14907700E+00, 0.13565600E-01, 0.30204700E+00, -.41099300E-01, 0.17866100E+00, -.47704600E-01, -.25764800E+00, 0.19988800E+00, 0.11654800E+00, 0.93301000E-02, 0.73326400E-01, -.19511300E+00, -.54797100E-01, -.24501300E-01, 0.76010200E-01, -.35875000E+00, -.32950600E-02, -.32593300E+00, -.26091000E+00, -.34927100E-01, -.34271900E+00, -.37541500E-01, 0.10235900E+01, 0.24697500E+00, 0.80085100E+00, 0.49698500E+00, 0.14794600E+00, -.67449900E-01, -.34934200E-01, 0.11455900E+00, -.69488800E-01, -.91918400E-01, 0.11196800E+00, 0.96453700E-01, -.41374500E+00, -.29667700E+00, 0.29921000E+00, -.32197600E+00, -.31011400E-01, -.99275000E-01, -.56688600E-01, -.40611500E-01, -.53860700E-01, -.15351900E-01, -.30610100E-01, 0.17253400E+00, -.34793700E+00, -.28536300E-01, -.64490800E-01, -.15465600E-01, -.16220400E+00, -.54475400E-01, 0.14793100E+00, -.93268900E-01, -.62989400E+00, 0.15520000E-01, -.23848500E+00, -.88388800E-01, 0.24005700E+00, 0.55866000E+00, 0.41968600E+00, -.17406800E+00, -.91121800E+00, -.95475800E+00, -.41320300E-02, 0.56174100E+00, 0.22759400E+00, -.13722900E+01, -.58062200E-01, -.44694100E-01, 0.68334700E-01, -.15298200E-03, 0.35983700E+00, 0.66001400E-01, 0.34507800E+00, 0.29151000E-01, -.63799100E+00, 0.45768400E+00, 0.34329800E+00, 0.11951200E+01, 0.19027300E+00, -.11302500E+01, 0.11631100E+00, 0.19783700E+01, 0.82643200E+01, 0.11139800E+00, 0.36691500E+00, 0.22762200E+00, 0.13204600E+01, 0.32687600E-01, -.15238100E+01, -.93111000E-01, -.29827300E+00, 0.11396800E-02, 0.13061800E+01, 0.16108200E+00, 0.49594900E+00, -.21566500E-02, 0.89275400E-01, 0.20200700E+00, 0.30637900E+00, -.27033200E+00, 0.22267100E+00, -.35496500E+01, 0.37734900E-01, -.28137700E+01, 0.42755500E+00, 0.64166400E+00, 0.17951900E+00, 0.14020700E+00, 0.66155900E-01, -.12952700E+00, 0.39767100E+00, 0.91588400E-02, -.92016900E+00, -.16420100E+00, 0.18722700E+01, -.11934400E+01, -.17735000E+00, -.84233900E+00, 0.10839900E+00, -.18972600E+01, -.55023300E+00, 0.34699000E-01, -.89326400E-01, 0.62875200E-01, 0.47998300E-01, -.22945800E-01, -.31971800E+00, -.17718300E+00, -.25442400E+00, 0.29447200E+00, 0.38987900E+00, -.26570400E+00, 0.76439900E+00, 0.51136800E+00, -.19067500E+00, -.14738800E-01, -.61315400E-01, 0.54515400E+00, 0.97536300E-01, -.16039400E+01, -.68404400E+00, 0.45404400E+00, 0.29146500E+00, -.27295700E+01, -.10307000E+00, -.43284800E+00, 0.11052100E-01, 0.87557000E+00, 0.19118400E+01, -.47049900E+00, -.10090000E+01, 0.12336400E+01, 0.28122000E+00, -.57315100E+02, 0.59969000E+00, 0.36487800E+01, 0.59172300E+00, 0.30183900E+00, -.13626000E+01, 0.11129900E+01, -.65187600E+00, 0.32783700E+01, 0.13847300E+01, -.59637000E+00, 0.13565200E+01, -.76824400E+00, -.65424900E+00, 0.88304800E+00, 0.11438800E+01, 0.71853700E-01, -.45012900E+00, 0.42707800E+00, 0.46142600E+01, 0.78307700E+00, -.45411200E+01, 0.58102200E+00, 0.43755700E+00, 0.91111800E+00, -.73655400E+00, -.16568700E+01 },
        { 0.13474800E+00, -.55929800E+00, -.88683500E-01, -.89950300E-01, 0.39653000E+00, 0.14987000E+00, 0.64994900E+00, -.11696300E+01, -.55374800E-01, 0.26795300E+00, 0.78317100E-01, 0.10310700E+01, -.45805300E+00, 0.17816400E+00, 0.92778500E-01, -.24019200E+00, -.16639500E+00, 0.33301400E-01, 0.11931800E+00, -.98164400E-01, 0.30059100E-02, -.73628400E-01, -.13087000E+00, 0.15002700E+00, 0.80329400E-01, 0.12236200E+00, 0.80465700E-01, -.93645100E-01, -.39005000E-01, 0.83050300E-02, -.23371200E-01, -.10816800E+00, 0.24427400E+00, 0.99720000E-01, 0.26889300E-01, -.14882900E+00, 0.26154000E-01, 0.70904800E-01, 0.13268800E+00, -.18496900E+00, -.25929700E+00, -.63917500E+00, 0.32933600E+00, -.10688900E+00, -.12263900E+00, 0.21683500E-01, 0.82842600E-01, 0.16300000E-01, -.22035800E-01, -.82537400E-01, -.50045700E+00, 0.69860400E+00, 0.19314800E+00, 0.14862600E+00, -.23151900E+00, 0.23263700E+00, -.19302200E+00, 0.12937000E+00, -.99279500E-01, -.27206500E+00, 0.22778500E+00, -.10640900E+00, 0.23716500E+00, -.15816800E+00, -.40816100E-01, -.73455500E-01, 0.31615600E-01, 0.22213400E+00, 0.45816600E-02, -.39891200E-03, 0.38427100E+00, 0.11329000E+00, -.18292500E-01, -.58640900E-02, 0.13302900E+00, -.18148200E+00, 0.20630600E-01, -.74944200E-01, 0.50572100E-01, 0.14607700E+00, 0.19257200E-02, 0.69694800E-02, -.84174100E-01, 0.10012800E+00, 0.32536800E-02, -.38340200E-01, -.10267100E+00, 0.53065500E-01, 0.29802900E-01, -.43854400E-01, 0.31728500E+00, -.65215200E-02, -.23318100E+00, 0.31864000E+00, 0.13776300E+00, 0.70139900E+00, 0.86649600E-01, -.15998000E+00, 0.26903800E+00, 0.91143100E-01, -.10717700E+01, 0.45013700E-02, 0.51127400E-02, 0.13799400E+00, 0.89691900E-01, -.87017500E-01, -.79728500E-01, 0.14411200E+00, -.44353100E+00, 0.19838100E+00, 0.31972300E+00, 0.13773400E-02, 0.20672100E-01, -.72152300E-02, -.47938100E-02, 0.28513500E+00, 0.75003900E-01, -.28705100E+00, -.19832300E+00, 0.26090900E-01, -.16685400E+00, -.26131200E+00, 0.36840200E-01, 0.29474100E+00, -.52419200E-02, -.19592100E+00, 0.11156400E-01, 0.99466900E-01, 0.17546900E-02, 0.23714000E-01, 0.75461500E-01, -.73784300E-01, 0.46939000E-01, -.88196300E-01, 0.41035600E-01, 0.63228000E-02, 0.75238100E-01, 0.60930400E-01, 0.43130400E-01, -.10806400E+00, 0.35897700E-01, -.92714400E-01, 0.30627500E-01, -.82868100E-01, -.25180400E-01, -.35063600E-01, -.71890600E-01, -.49802800E-01, -.13198900E+00, 0.93063100E-01, 0.36775300E-01, -.10700600E+00, 0.87448300E-01, 0.22423200E+00, 0.30778600E+00, -.33211400E-01, 0.31911100E+00, 0.32537600E-01, -.45045700E-01, -.12378300E+00, -.23049800E+00, 0.90318000E-01, -.70864900E-01, 0.42720900E-01, -.98600300E-01, 0.22511600E+00, 0.21373800E-01, 0.21845300E-01, -.96518400E-02, 0.13751800E+00, -.32214600E-01, -.13655900E+00, 0.10445800E+00, -.52450800E-01, 0.32874400E-01, 0.97001300E-01, 0.26774700E-01, -.17149500E-01, 0.35788900E+00, -.15622500E-03, -.25180400E-01, 0.11952700E-01, 0.10565700E+00, -.38364200E-01, 0.50146100E-02, -.68589800E-01, 0.23392900E+00, -.67181500E-01, -.37628900E-02, -.48304100E-02, 0.43058400E-03, -.11620700E+00, 0.87473500E-01, -.62473500E-01, 0.69032900E-01, 0.41561700E-01, -.40173900E+00, 0.39117200E-02, -.51959700E-01, 0.46383100E-01, 0.63621300E-01, 0.14322700E-01, -.50435600E+00, 0.71883100E+00, 0.12839600E-01, -.12736000E-01, -.12011800E+00, -.20799700E+00, 0.15557400E-01, 0.18635600E-01, -.31058800E-01, 0.12468500E+00, -.17689100E-03, -.15614700E+00, 0.62209700E-01, -.12916000E+00, -.28678000E-01, -.14696200E-01, 0.93787500E-02, -.27639400E-01, -.14489700E+00, 0.33260900E-02, 0.55472800E+00, 0.56992400E-02, 0.28554500E+00, -.49354700E-01, -.18744900E-01, 0.40453400E-01, 0.16529800E-01, 0.26279600E-01, 0.91870700E-02, -.81702700E-01, 0.15456000E-01, 0.18143400E+00, 0.32149700E-01, -.54479400E+00, 0.30076200E+00, 0.11773800E-01, -.24155500E-01, -.95832000E-02, 0.52558200E+00, -.61800400E-02, -.14165300E+00, 0.10584100E-01, -.19510700E+00, 0.64952000E-02, -.93917700E-02, 0.76497200E-01, 0.36998100E-01, 0.52737900E-01, -.19399200E-01, 0.12770000E-01, 0.10656300E-01, -.30116900E+00, -.55851200E-01, 0.51361300E-01, 0.84295000E-03, -.33130800E-02, 0.67151000E-01, 0.12843500E-01, 0.12839600E-01, 0.84159600E-01, -.23234200E-01, -.11568000E-01, 0.32835000E+00, 0.86318000E-03, -.16607000E+00, -.14136300E-02, -.32146000E-01, -.15305900E+00, 0.20897100E-01, -.68576700E-01, -.88983200E-01, -.18325600E-01, -.39606800E-01, 0.15309700E+00, -.29262200E-01, -.17102100E-01, -.65761500E-01, -.26033000E+00, 0.40993900E-01, 0.12885500E+00, -.39406000E-01, -.42848500E-01, -.12457900E+00, -.44449800E-01, 0.45359100E-01, -.17310900E-02, 0.42154500E+00, 0.37119600E+00, 0.75803100E-01, -.15668800E-03, -.55397600E-02, 0.92283600E-01, -.15760900E+00, -.67399900E-01, 0.10742400E+00, 0.30044500E-01, -.78115600E-02, -.51598000E-01, -.49990400E-01 },
        { -.22174600E+01, -.70577800E+00, -.10235200E+02, -.59988300E+00, 0.64594400E+01, 0.14871300E+01, 0.65947900E+01, -.36542900E+01, 0.17433300E+00, 0.22807800E+01, -.71613800E+00, -.84301600E+01, 0.29952800E+00, -.21597000E+00, -.49581900E+01, -.24773800E+01, -.34121500E+01, 0.11293000E+01, -.95388200E+00, 0.26174900E+00, -.24166100E+00, -.37483100E+01, -.10578600E+01, -.34672100E+01, 0.64705200E+00, -.12926200E+01, -.29753700E+01, -.11924900E+01, -.19681300E-01, 0.72669400E+00, -.26125100E+01, -.68269000E+00, -.19849400E+01, 0.20555000E+01, 0.10378800E+01, 0.15215900E+01, -.15729000E+00, 0.28933200E+01, 0.69199200E+00, 0.15238500E+01, -.94559700E+00, -.56714400E+01, 0.51560600E+01, 0.29395600E+01, -.35383400E+01, 0.69203400E+00, 0.14103700E+01, -.24777300E+00, -.12335400E+01, 0.51762800E+01, -.14200700E+01, 0.61130400E+01, 0.26222900E+00, -.54338000E+00, -.97567700E+00, 0.44433400E+01, -.26402300E+00, -.23520800E+01, 0.37354100E+00, -.27788900E+01, 0.43059900E+01, -.15479100E+01, 0.18327300E+01, -.14473300E+01, -.13271400E+01, -.10782600E+00, 0.52542500E+00, 0.43734600E+01, -.73481500E+00, -.35276900E-02, -.45023700E+01, -.49237000E+00, 0.12003400E+01, 0.16501300E+00, -.20955400E+01, 0.78504300E+00, 0.36544000E+00, 0.75733800E+00, 0.10674500E+00, -.97282500E+00, -.44249600E-01, 0.10751300E+01, -.20026500E+00, 0.22124400E+00, -.32659300E-01, -.88527700E+00, 0.26286300E+01, 0.38359800E+01, 0.14408300E+01, -.11135200E+01, -.11257200E+01, -.65902100E-01, -.32093300E-01, 0.56583100E+01, 0.94978400E+00, 0.96114700E+00, -.55581500E+01, 0.18249000E+01, -.40967900E+00, -.25372200E+00, -.10228200E+02, -.43098700E+00, 0.12501800E+00, -.50216200E+00, 0.16141300E+01, -.13227200E+01, 0.12358800E+01, -.13300300E+01, 0.32935500E+01, -.22882400E+01, 0.31857800E+00, -.78350400E+00, 0.46230800E+00, 0.37747500E+00, 0.77478800E+00, 0.93673300E+00, -.89050700E+00, -.22230900E+01, -.31254700E+01, -.55890700E+00, -.11763400E+01, -.12590700E+01, 0.34152400E+00, 0.25269200E+01, -.20648600E+00, -.23591900E+01, -.62251100E+00, 0.35372300E+01, 0.14218300E+00, 0.11028200E+00, 0.16388400E+01, 0.24919200E+01, 0.23640000E-01, 0.44710000E+00, -.18010000E+01, 0.19841800E-01, 0.70421800E+00, -.90683700E+00, 0.13344900E+01, -.40692800E+00, 0.19956400E+00, 0.21670100E+01, 0.62733700E+00, 0.13903700E+01, 0.19032200E+01, 0.35318200E+00, -.39383400E+00, -.13608000E+00, 0.24056100E+01, -.50745100E+00, -.16760900E+01, 0.91034400E+00, 0.79880700E+00, -.63994600E+00, -.18131400E+01, 0.71054800E+00, -.58892600E+00, 0.27009700E-01, -.71224100E+00, 0.51170000E+00, -.15333300E+01, -.24655800E+01, -.59080900E+00, 0.90841700E-01, 0.48161800E+00, 0.49822000E+00, 0.13898200E+00, 0.74382400E+00, 0.66627900E-01, -.62874000E-01, 0.30030500E+00, 0.40612800E+00, -.70647200E-02, -.23193800E+01, -.21530700E+00, -.27989600E+00, -.85715300E+00, 0.40245100E-01, 0.30049200E+01, 0.43721400E-02, -.11366400E+01, -.19155900E+00, -.37532600E+01, 0.49106000E+00, 0.14529400E+01, 0.96604900E+00, 0.17037100E+01, 0.53755700E+00, -.84427800E-01, -.39886300E-01, -.55426200E-02, -.21190800E+00, 0.41746400E+00, 0.28308600E+00, 0.44568000E+01, 0.10228700E+01, 0.10066200E+01, 0.14426800E+01, 0.22255000E+01, 0.32079400E+00, -.12025100E+00, 0.62126800E-01, 0.12443400E+00, 0.65487600E+01, -.53776300E+00, -.16428500E+00, 0.75460600E+00, 0.52790100E+00, 0.10143300E+00, -.69059900E+00, -.54635300E+00, -.88009300E+00, -.10683000E-01, -.66364500E+01, -.24429400E+01, 0.19323400E+01, 0.98742800E-01, 0.27903300E+00, -.38520400E+00, -.75690400E+00, 0.58523700E+00, 0.23514100E+00, -.47863900E+01, 0.62351100E-01, -.33081100E+01, 0.20804200E+00, 0.56029200E+00, 0.32381000E-02, -.53031500E+00, -.58380300E-01, 0.24907100E+00, 0.36782300E-01, 0.69657600E-01, 0.47501500E+00, -.28467500E-01, 0.48249400E+01, -.51972500E-01, -.20225100E+00, 0.32401200E+00, 0.69268500E+00, -.55988300E+01, -.55752100E+00, -.95314300E-01, -.14828300E+00, 0.13259300E+00, 0.61981200E-02, -.10530600E+00, -.14098400E+00, -.33378700E+00, -.69780700E+00, 0.29320900E+00, 0.15491300E+01, -.61021000E+00, 0.27181000E+01, 0.90921000E+00, -.13325800E+00, 0.98755200E-02, -.51762100E+00, -.29628100E+01, 0.31811400E+00, -.33234400E+00, -.53164200E+00, 0.19870600E+00, -.31277400E+00, 0.25423200E+01, -.28478000E-01, -.23777700E+01, 0.45569800E+00, -.29240600E+01, -.29126200E+01, 0.59172900E+00, -.42097300E+00, 0.24682800E+01, 0.27432200E+00, -.13498900E+01, 0.44691800E+00, 0.18195800E+02, 0.11656500E+01, 0.15409000E+00, -.22582800E+01, 0.33566100E+01, 0.34245100E-01, 0.15372800E+02, 0.19747600E+01, -.14041600E-01, 0.47967400E+01, -.15849700E+00, -.53842300E-01, 0.19460300E+00, 0.22826500E+01, 0.13751000E+00, -.82447000E+00, -.10943200E+00, -.28095500E+01, 0.10368100E+01, 0.21460800E+01, 0.13999000E+01, 0.51114000E+00, 0.14432100E+01, 0.43771400E+00, 0.26887800E+00 },
        { -.40175500E+00, -.92237500E+00, -.36726500E+01, 0.20665300E+00, 0.13388400E+01, 0.50671400E+00, 0.36907600E+00, -.18024600E+01, 0.10399300E+00, 0.83161900E+00, -.40366400E+00, -.38992800E+01, 0.55932400E+00, -.10097700E+01, -.99222400E+00, 0.70765700E+00, -.20164500E+01, 0.19734300E+00, 0.61922800E+00, -.13112100E+01, -.32007400E+00, 0.24633900E+01, 0.47975600E+00, -.15704000E+01, -.20611800E+01, -.57272900E-01, -.11832100E+00, -.13505600E+00, 0.22122300E+00, 0.37820000E-01, -.86315700E-02, -.10052500E+00, -.21740900E+00, 0.58693600E+00, -.47689300E+00, -.24004700E+00, 0.31192900E-01, -.38311900E+00, 0.17496700E+00, 0.10069100E+00, 0.14307600E+00, -.64373200E-01, -.80500400E+00, 0.14758600E+00, 0.62779400E+00, 0.34962300E+00, 0.63378500E+00, 0.66504900E-01, -.50587300E-01, 0.18114200E+00, 0.78118900E+00, 0.11179400E+00, 0.75785500E+00, -.19516000E-01, -.54312100E+00, -.20387600E+00, 0.34792600E+00, -.14582900E+00, -.21350400E+00, 0.38492700E+00, 0.38979800E-01, 0.28417500E+00, -.29907800E+00, 0.52419100E+00, 0.74771200E-01, -.21850200E-01, -.73542100E-01, -.60508800E+00, 0.51500800E-01, 0.45329400E-02, 0.30912400E-02, 0.27892300E-01, -.87836500E-01, 0.52198300E-01, 0.72919200E+00, -.22174800E+00, -.20159300E+00, -.24899100E+00, 0.24878900E+00, 0.18514500E+00, 0.18525800E-01, -.14415600E+00, -.22653400E+00, -.12784500E+00, -.15242000E+00, -.39547600E+00, 0.28512600E+00, 0.14504800E+01, 0.15045200E+01, -.19350800E+00, 0.63829000E+00, -.19583900E+00, -.35089500E+00, 0.14564700E-01, -.87483400E-01, 0.91960500E+00, 0.30167900E+00, -.20947500E+00, 0.11357500E+01, 0.16420700E+00, -.74211800E+00, -.47113700E+00, 0.78623100E-02, 0.47263200E-01, 0.23014000E-02, -.17704100E+00, -.12433300E+00, 0.28267100E+00, -.79485500E+00, -.86120000E+00, 0.10469600E+01, -.88495100E-01, -.48742300E-01, 0.73865800E-01, -.54987100E-01, 0.31451700E+00, 0.22593800E+00, 0.13458900E+00, -.94384700E+00, 0.17660600E+00, -.28992600E+00, 0.14899400E+01, -.10299200E+00, 0.59272000E+00, -.17650800E-01, 0.23439100E+00, 0.41036800E+00, -.27134600E-01, 0.14927100E-01, 0.16400200E+00, -.13387300E+00, -.28062000E+00, 0.10921600E+00, -.86510600E-01, 0.91750600E-02, 0.17950000E-01, 0.84529300E-01, 0.68107400E-01, 0.11622300E-01, 0.28162100E+00, 0.28656600E-01, -.98661200E-01, -.16777500E+00, 0.59430700E+00, 0.79408600E+00, 0.18854400E+00, -.88107600E-01, -.71435400E+00, 0.16560500E+00, 0.33161200E-01, -.40644700E+00, 0.18491800E+00, -.35768300E+00, -.11250900E+01, 0.81032700E+00, -.20385500E+00, 0.60059900E+00, 0.62054200E-01, 0.46616700E-01, 0.30235300E+00, 0.79377500E-01, 0.16227800E+01, 0.12083600E+00, -.12418700E+00, -.22923200E+00, 0.63748300E+00, -.15092700E+00, 0.12371100E+00, -.53514000E-02, 0.19808300E+00, 0.49091900E+00, 0.68140900E-01, 0.38878300E-02, 0.70655300E+00, -.95325900E-01, -.20542600E+00, 0.79120400E-01, 0.58367200E-01, 0.48207100E+00, -.15984500E-02, 0.93182100E-01, 0.78579500E+00, 0.10843500E+01, -.83677000E-01, -.38817200E+00, -.18733900E+00, 0.67604600E+00, 0.23440700E+00, 0.42904600E-01, 0.53063500E-01, -.17710600E-02, -.38124900E+00, -.46624800E-01, 0.35117400E+00, 0.83852000E+00, -.32148900E+00, -.47153900E+00, 0.13142400E+00, -.89832000E-01, -.72882300E-01, 0.53679000E+00, 0.30549400E-01, 0.69266900E+00, 0.10835100E+01, 0.61751400E-01, 0.24191100E+00, 0.18422700E+00, 0.89089900E-01, -.48811000E-01, 0.38969000E+00, -.98284000E-02, -.13413300E+01, -.85323000E-02, -.26812100E+01, -.46896800E+00, 0.24944700E+00, 0.73248200E-01, 0.33864000E+00, -.79086400E-01, 0.26420000E-01, 0.11022300E+01, 0.12081500E+00, -.36508800E+01, 0.97197500E-01, -.11000000E+01, 0.20020400E+00, 0.36210700E+00, -.41377400E+00, 0.20179000E+00, 0.11126900E+00, -.11292800E+00, -.81564000E-01, 0.21744100E-01, 0.23645900E+00, 0.41609000E-01, 0.81957500E+00, -.20902000E+01, 0.14263200E+00, -.31662300E+00, -.25480800E+00, 0.65112000E+00, -.24985500E+00, 0.73824900E+00, 0.17853100E+00, -.16841200E+00, 0.53614400E-02, 0.71546500E-01, -.13559600E+00, -.18635100E+00, 0.54232700E-01, 0.42305100E+00, -.31434800E-01, -.18560700E+00, -.21907100E+01, -.49940800E-02, 0.13142400E+00, -.55507000E-02, 0.36110500E-01, 0.80483900E+00, 0.17685800E+00, 0.20277200E+00, 0.31171500E-01, 0.16822500E-01, -.49128500E-01, 0.44542300E-01, 0.43505700E-01, 0.13357200E+00, 0.43325300E-02, 0.57518800E-01, -.13539500E+00, 0.72972000E-01, 0.15543400E+00, -.61664100E+00, 0.32343400E-01, -.12855500E+00, 0.90267600E+00, 0.12539700E-01, 0.22049400E+01, 0.92695200E-02, -.49065100E+00, -.36586500E+00, -.20552200E+00, -.57812900E-02, 0.34773900E+00, -.10575300E+00, -.75548300E+00, -.47422300E-01, -.40380300E+00, -.29409100E+00, 0.76312700E+00, -.28056800E-01, -.11706700E+01, 0.24043700E+00, 0.12665300E+01, 0.19163500E+00, -.12025700E+01, 0.12431700E+00, 0.77697700E-01, 0.28870600E+01, -.45715400E+00, -.53091100E+00 },
        { -.31022700E+00, 0.62697200E+00, -.11743100E+01, -.28522000E+00, 0.26983500E+00, 0.59039300E-01, -.51364400E-01, -.28665100E+00, -.38314100E+00, -.94904100E-01, 0.35300300E+00, -.59832700E+00, 0.39026300E+00, -.82938900E-01, 0.53493600E+00, 0.20789700E+00, -.14850200E+00, 0.88682500E-01, 0.41202300E+00, 0.18721000E+00, -.30344000E+00, -.52223700E+00, 0.35027100E-01, -.26764800E+00, 0.94997700E-01, 0.58346200E-01, -.13293200E+00, 0.22031300E+00, -.89787700E-01, 0.17762200E+00, -.27132800E+00, 0.88093000E-01, 0.58827100E-01, -.16029700E+00, 0.24259400E+00, -.19961700E-01, -.12982200E-01, -.68156200E-01, 0.17162400E+00, -.85713800E-01, 0.16253600E-01, 0.11837100E+00, -.94091500E-01, 0.97233200E-02, 0.97216200E-01, 0.26036800E+00, 0.43069100E+00, -.40448500E-01, -.60527000E-01, 0.65990900E-01, -.23748900E+00, 0.12814800E+00, -.60530900E-01, 0.19299100E+00, 0.24720800E-01, -.99862000E-01, -.87085200E-01, -.59004200E-01, 0.10591400E+00, 0.26667300E-01, -.71301700E-02, 0.48389900E-01, -.85111000E-01, 0.32520800E-01, -.15027000E-01, -.24983600E-01, -.78723000E-01, 0.22789000E+00, -.78198800E-01, -.55155300E-03, -.35828800E+00, -.30414600E+00, 0.31848400E-01, 0.21104400E-02, 0.68332900E-01, 0.14730000E+00, -.15904400E+00, -.75074300E-01, -.74744300E-01, -.73159900E-02, 0.11041700E-01, -.48997600E-01, -.38638800E-01, 0.39056400E-01, -.18042700E-01, 0.10207600E+00, -.35311300E-01, -.31003000E+00, -.12859700E+00, 0.96178300E-01, -.71716600E-01, 0.11675500E+00, 0.15846700E+00, -.80282400E+00, 0.25090000E-02, 0.37127400E-01, 0.55662900E-01, 0.60832100E-01, -.16212000E+00, -.17572400E+00, 0.79433200E+00, -.15226400E+00, -.13553800E-01, -.90833700E-01, -.83872100E-01, 0.25491000E+00, 0.87296100E-01, 0.25790700E-01, -.13357900E+00, -.24697100E+00, -.34572900E+00, 0.18544300E-01, -.40828100E-01, 0.15137500E-01, -.50293200E-01, -.18500800E+00, 0.59431700E-02, 0.77272800E+00, 0.31840100E-01, 0.37242800E-01, 0.90461000E-01, 0.10963700E+00, -.74721700E-01, -.23676900E+00, 0.11433700E-01, 0.18755900E+00, -.13535500E-01, -.98929900E-01, 0.13662400E-01, 0.15832100E-01, -.95265400E-01, 0.39492800E-01, -.22078300E-01, 0.13893500E+00, -.54089300E-01, 0.48280500E-03, -.17834700E+00, -.88694900E-01, -.85026600E-01, 0.20686000E+00, -.12975200E-01, 0.21411700E+00, -.19198300E-02, 0.84464700E-01, 0.20377800E+00, 0.71735200E-01, 0.55241700E-01, -.15280800E-01, 0.14367500E+00, -.91840500E-01, 0.50850200E-01, 0.56453300E-01, -.20541800E+00, -.20154200E+00, -.28743200E-01, 0.12144900E-01, -.19202200E+00, -.11684000E-01, 0.99068900E-01, 0.12139500E+00, 0.22375300E-01, 0.31569700E+00, 0.23766000E-01, -.41987900E-01, 0.94693400E-01, 0.24685600E-01, -.86589400E-02, -.24335600E-01, 0.63233900E-02, -.26970600E-01, -.76877700E-01, 0.11543000E+00, -.22816100E-01, -.15752400E+00, -.20810500E-01, 0.73961500E-01, 0.12089000E-01, 0.70050600E-02, 0.46291200E+00, 0.18552100E-03, -.15327100E-01, -.14920000E+00, 0.56673600E-01, -.33051300E-02, -.11785400E+00, 0.11641400E+00, -.60491700E+00, 0.19199500E+00, 0.21734800E-01, 0.37544200E-01, -.35582200E-04, 0.74076000E-01, -.14172200E+00, 0.85388300E-01, 0.39861000E+00, 0.27631500E+00, 0.48480000E+00, -.66415900E-01, 0.19238900E-01, -.63805000E-01, 0.56104600E-01, -.12464900E-01, 0.36852100E+00, -.21612500E+01, -.45656300E-01, -.75802500E-01, 0.11693300E+00, 0.25609900E+00, -.37430400E-01, -.32087400E-01, 0.45387400E-01, -.15986000E+00, 0.94598700E-04, 0.36181200E+00, -.58107500E-01, 0.11875100E+00, 0.37323900E-04, -.25892900E-01, -.12658400E-01, -.43159500E-01, 0.51467500E-01, -.22899700E-01, 0.48001200E+00, 0.71689300E-02, -.10414200E+00, -.34254100E-01, 0.14262900E-01, 0.10922500E+00, -.89910000E-02, 0.48254700E-01, 0.11485200E-01, 0.34431600E-01, -.26368900E-01, 0.58421400E-01, -.13493700E-01, 0.14288500E-01, 0.26309300E+00, -.14812200E-01, -.94290900E-01, 0.35058600E-01, -.13091800E+00, -.12293800E+00, 0.23121700E+00, -.40134400E-01, 0.16821800E+00, -.23081500E-02, -.49245800E-02, -.20742400E-01, -.15609500E-01, -.11464900E-01, -.24318000E-01, 0.45453800E-01, 0.30767200E-01, -.22696900E+00, -.55553200E-01, -.66934200E-01, -.28732000E-02, -.68632100E-01, -.33756300E-01, 0.22516300E-01, 0.11015600E-01, 0.13393700E-01, -.36494400E-02, 0.66575300E-02, 0.52485100E-01, -.75779900E-02, 0.10744800E-01, 0.63274300E-03, 0.12279200E-02, 0.10242200E-01, -.88496900E-02, 0.70232900E-02, 0.79776000E-01, 0.19090900E-01, 0.37186000E-01, -.14012600E+01, 0.12051800E-01, -.17904400E-01, 0.32349700E+00, -.23385400E+00, 0.40923000E-02, 0.16661800E+00, -.29462000E-02, -.98049200E-01, -.12205600E+00, -.15498800E+00, -.73468100E-01, -.58882300E-01, 0.51056700E+00, 0.35872000E+00, -.10466700E+00, 0.13966900E+00, 0.10493200E-01, -.22996400E+00, -.24379600E+00, 0.27400200E+00, 0.79582500E-01, -.11000100E-01, -.59700500E-04, -.86542700E-01, -.68346200E-01 },
        { 0.14064300E+01, -.78835800E+00, 0.99737200E+01, 0.10726600E+01, -.73508500E+01, -.12591500E+01, -.82546200E+01, 0.24568500E+01, 0.13261300E+01, -.88190400E+00, -.58478800E+00, 0.63774200E+01, -.17513900E+01, 0.89446800E+00, 0.57791700E+01, 0.14561400E+01, 0.56431700E+01, -.12483700E+01, -.90027300E+00, 0.35178700E-01, 0.74350000E+00, -.12085700E+01, -.13214300E+01, 0.30522500E+01, 0.17520800E+01, 0.18645900E+01, 0.27326000E+01, -.36034800E+00, -.28289800E+00, -.22017400E+01, -.18543800E+00, -.69020800E+00, 0.38721500E+00, -.80029600E+00, -.20879200E+00, 0.48240400E+00, -.47125800E-01, 0.20097100E+01, -.67442800E+00, 0.95252300E+00, 0.10868700E+00, -.47877300E+01, -.56372200E+01, -.31451400E+01, 0.36382400E+01, 0.12329900E+01, 0.45838200E+01, 0.23248300E-01, 0.17094700E+01, -.10414900E+01, 0.14023900E+01, -.52198600E+00, -.86238100E+00, -.89245800E+01, -.21578400E+01, -.77059500E+00, 0.54521700E+00, 0.16083800E+01, 0.22803500E+00, -.13918600E+01, -.17969500E+00, 0.97578800E+00, -.75236200E+00, 0.20380500E+01, -.30376200E+00, 0.10990800E+01, -.20652500E+00, -.35320600E+01, 0.98285400E+00, -.11906700E+00, 0.16538300E+01, 0.16044700E+01, -.49827700E+00, 0.20458800E+00, 0.18909400E+01, -.14237900E+01, -.65264800E-01, -.62360500E+00, -.85382500E-01, 0.27691100E+01, 0.86961500E-01, -.40564900E+00, -.71400100E+00, 0.12260900E+00, -.24021200E+00, 0.14216000E+01, -.10755900E+01, -.31718300E+01, 0.17840500E+01, 0.49940800E+00, 0.51202600E+01, 0.10576600E+01, -.11362400E+01, -.55980500E+01, 0.16680500E+01, 0.62469200E+01, 0.19024600E+01, -.25397300E+00, 0.93628500E+00, -.40955400E+00, 0.37516600E+01, -.21860500E+01, 0.31262500E+00, 0.24283200E+01, 0.69381200E+00, 0.10354200E+01, -.51260500E+00, 0.34318500E+01, -.15690700E+01, -.78115700E+00, 0.26836400E+01, 0.40350500E+01, -.12390700E+01, 0.19659800E+00, 0.55388600E+00, 0.13577500E+01, -.20762400E+00, -.68350900E+01, -.19527100E+01, -.49448200E+00, -.10475900E+00, -.34059500E+01, 0.87742500E+00, -.10966800E+00, -.18329000E+00, 0.20657500E+01, 0.65711700E+00, 0.42471900E+01, 0.76287100E+00, 0.27688300E+00, 0.49269800E+00, 0.19074200E+01, -.15560800E+00, -.10145300E+01, -.38813700E+00, -.71505500E-01, 0.55175300E+00, 0.53494400E+00, 0.97994900E+00, 0.52792800E+00, -.77922600E+00, 0.68153400E+00, -.21633300E+00, -.32848500E+01, -.43279700E+01, -.15350500E+00, 0.22693900E+00, 0.10122300E+01, -.35029700E+00, -.53675500E-02, -.22435600E+00, 0.32352100E+00, -.74284600E+00, -.19226200E+01, -.13097500E+01, 0.34795100E+00, -.24446000E+01, -.35712400E+00, 0.44132100E+00, -.20618100E+00, -.38663000E-01, -.30726400E+01, -.24079400E+00, -.16412100E-01, 0.70166400E+00, -.35989600E+01, -.62153600E+00, -.21744900E+01, -.10545600E+00, 0.28364800E+00, -.10605000E+01, -.93345100E+00, 0.32236100E+00, -.23271900E+01, 0.63770700E+00, -.17267400E+01, -.42170300E+00, 0.16270700E+00, 0.20475600E+01, -.69662200E-02, -.41576400E+00, -.79453700E+00, -.20034700E+01, 0.39119600E+00, 0.11632100E+01, -.11963700E+00, -.45377100E+00, 0.27227300E-01, -.38533200E-01, -.14737000E+00, -.27505700E-02, 0.11408500E+01, -.44973600E+00, 0.20234600E+00, -.26115100E+01, -.21159700E+01, 0.42988500E+00, -.13765400E+01, 0.33922700E+00, -.54045200E-02, -.72982300E+00, 0.14063800E+00, 0.27531500E+01, 0.13297000E+02, 0.21051300E+00, -.14304400E+01, 0.16606200E+01, 0.13624200E+01, -.31767400E-01, 0.20056800E+01, 0.57555200E+00, -.22988800E+01, -.71926800E-02, 0.94252000E+00, -.17805300E+01, -.87401600E+00, -.23211400E+00, 0.15258800E+01, 0.20091000E+00, 0.15112500E+01, 0.95527500E+00, 0.78366500E-01, 0.16418100E+00, -.18224500E-01, -.40170300E+01, 0.91722000E-01, -.10620000E+01, -.65871700E+00, 0.17350000E+00, -.52221100E+00, -.32044000E-01, 0.18529800E+01, -.39301800E+00, -.31090900E+01, -.69929500E+00, 0.40763400E+01, -.78463800E+00, -.13505400E+00, 0.14335500E+01, 0.46165200E+00, -.53442600E+01, 0.13103100E+00, -.42517400E+01, -.60616500E-01, 0.15876400E+01, -.94748600E-01, -.19544200E-01, -.10813100E+00, -.63283700E+00, -.69481900E+00, -.53932200E-02, -.51517600E+00, 0.30749300E+00, 0.16669900E+01, 0.20178000E+00, -.95449800E-01, -.63501500E-02, 0.36739200E+00, -.10853500E+01, -.17477900E+00, -.76017400E+00, -.47222700E+00, -.21661500E+00, -.31750300E-01, -.22868600E+01, 0.69031800E-01, 0.40991600E+00, 0.16835200E-01, -.81898300E+00, 0.77998300E+00, -.19834800E+00, 0.24321300E+00, 0.14147800E+01, 0.24340200E+00, 0.38398600E+00, -.11648300E+02, -.11585500E+00, 0.46882400E-01, 0.19339800E+01, 0.52389300E+01, 0.28657500E-01, 0.35199900E+00, 0.41684800E-01, -.11645900E+01, 0.99139900E-01, 0.16015700E+01, -.86353900E+00, 0.66497700E+00, 0.12386900E+01, -.12101700E+02, -.25340400E+00, 0.83850600E+00, 0.20921500E+00, 0.38459100E+00, -.82484600E+00, -.46034300E+00, -.59712000E+00, -.39339700E+00, -.29588200E+00, 0.85407800E+00, 0.65791700E+00 },
        { 0.14004100E+01, -.17630500E+01, 0.10175300E+02, 0.15601500E+01, -.45626100E+01, -.96653100E+00, -.49198500E+01, 0.21604600E+01, 0.14024200E+01, 0.34834100E-01, -.52403500E+00, 0.24972700E+01, -.18118500E+01, -.35839100E+00, 0.23538600E+01, 0.41745100E+00, 0.37072600E+01, -.74549300E+00, -.77157700E+00, -.10074500E+00, 0.11870700E+01, -.28964300E+01, -.79753000E+00, 0.21892600E+01, 0.91875100E+00, 0.10542200E+01, 0.18844300E+01, -.16797100E+01, -.77471900E+00, -.10449500E+01, -.30978400E+00, -.12409600E-01, 0.30222500E+01, -.14771300E+01, -.83446500E+00, -.46282700E+00, 0.21127000E+00, -.10138900E+01, -.82867100E+00, -.81629700E+00, -.11102500E+01, 0.79802700E+00, 0.38625900E+01, -.38033700E+00, 0.56961800E-01, -.16821200E+00, -.50746300E+00, 0.27933600E+00, 0.21012100E+00, -.12288400E+01, -.10315300E+01, 0.10290400E+01, 0.28530700E+00, -.55676300E+01, 0.30956500E+00, -.25453500E+01, -.60840500E+00, 0.13838200E+00, -.36838700E+00, -.17441500E+01, 0.12062200E+00, 0.91981400E+00, 0.43859900E+00, -.14974500E+00, -.15067100E+00, -.88251600E+00, -.42235800E+00, -.24703600E+01, 0.11872700E+01, -.49285000E-02, 0.34989300E+01, 0.37068900E+01, -.32171000E+00, 0.31679800E+00, -.67350500E+00, -.25229500E+00, 0.59941700E+00, -.53702100E+00, 0.19463900E+00, 0.43096800E+00, -.29681400E-01, -.27590900E-02, -.27106800E+00, -.13132000E+00, 0.14086900E+00, 0.33722500E+00, -.13980900E+01, -.34183700E+00, -.15235000E+01, -.10486300E+00, -.69932900E+00, -.26883300E+00, -.17190600E+01, 0.22657800E+01, 0.15226900E+01, 0.24522700E+01, -.76530200E+00, -.91021800E+00, 0.78845500E+00, 0.10424700E+01, -.75620900E+01, 0.71037700E+00, 0.77123500E-01, -.27702600E+00, -.25182500E+00, -.62345200E+00, -.38429900E+00, 0.53730800E-01, -.73884100E+00, 0.40114300E+01, 0.23174700E+01, -.69476400E+00, 0.78648500E+00, -.47594000E-01, 0.26355200E+00, 0.26780400E+00, 0.23308800E+00, 0.25169400E+01, 0.32916300E+01, 0.23255600E+00, 0.43499500E+00, -.32308200E+01, 0.18054700E+00, -.15822200E+01, -.16127700E+00, -.29335500E+00, -.17941900E+01, 0.60197400E+00, -.17926800E+00, -.10487800E+00, 0.17240900E+01, -.32375700E+00, -.16031800E-01, 0.29489300E+00, 0.64228800E+00, 0.42659100E+00, -.41945800E+00, 0.80426800E-01, 0.21002000E+00, -.19498000E+00, -.77939700E-01, 0.76324400E+00, -.22471100E+00, -.26116000E+01, -.33441200E+01, -.78495600E+00, -.28564600E+00, 0.10092400E+01, 0.18341100E+00, 0.13398600E+00, 0.15835000E+01, -.97173600E+00, -.50573300E-01, 0.32260400E+01, -.51330600E+00, 0.59293600E+00, -.14723800E+01, 0.13659600E+00, -.33430100E+00, -.25152100E+00, -.10328100E+01, -.39245400E+01, -.82263700E+00, 0.46530200E+00, 0.44007200E+00, -.61740800E+00, 0.32267400E+00, 0.13136700E+00, -.43149300E-01, 0.13588300E+01, 0.56887000E+00, -.50053600E+00, -.15244500E+00, 0.15215100E+00, 0.70949200E-01, 0.11457800E+01, -.11478000E-01, -.65215500E-01, 0.40823900E+00, 0.46608500E-02, 0.24422200E+00, 0.16190000E+01, 0.17616200E+01, 0.27864400E+00, 0.66956400E+00, 0.74457900E+00, -.72255600E+01, -.21701300E+00, -.45886800E+00, -.93612300E+00, -.10883100E-01, -.57085300E+00, 0.33841400E+00, -.12634300E+00, -.92536800E+00, -.61238600E+00, -.23780800E+01, 0.78668700E+00, 0.19829300E+01, 0.14184700E+00, -.14697200E+01, 0.55396800E-01, -.39147700E+01, 0.90401800E+01, -.37871000E-01, -.68747500E-02, 0.49178000E+00, -.25351600E+01, 0.38615400E+00, 0.14850200E+01, -.14412500E+00, 0.70419700E+00, -.22637600E-01, -.70130100E+01, -.31118900E+01, -.36523900E+00, 0.18120000E-01, 0.11925700E+00, -.79487900E+00, -.11006600E-01, 0.36922500E+01, -.32889000E+00, -.36963900E+01, -.70575400E-01, -.14835200E+01, 0.38302500E+00, -.28637400E-02, -.93833500E+00, -.31073400E+00, 0.16335500E-01, 0.53526800E+00, -.89715100E+00, 0.20307000E+00, 0.28288300E+01, 0.29667000E+00, 0.67190100E+01, 0.49680400E+01, -.43175500E+00, 0.35576900E+00, 0.42076200E+00, -.14401400E+00, -.69585100E+00, -.50748900E+00, 0.39477200E+00, -.24316600E+01, 0.95133200E-01, 0.49777400E-01, 0.13878500E+01, -.16031000E+00, -.20058400E+00, -.41702900E+00, 0.18695700E+01, -.52341400E+00, -.22285500E+01, -.14029200E+00, -.11003500E+00, -.28006000E-01, -.59363000E+00, 0.82824100E+00, 0.37655900E+00, -.57972900E+00, 0.12997500E+01, 0.28505500E+00, 0.14399900E+00, 0.50831700E+01, -.27019400E+00, 0.20237200E+01, 0.43534200E-02, 0.74878900E+00, 0.83756100E+00, -.60699500E-01, -.20646500E+01, 0.14724400E+01, -.27067500E-01, 0.56910900E-01, 0.46798100E+01, -.39006900E+00, -.43000600E+00, -.27280800E+01, -.34508500E-01, 0.30357800E+01, -.27909900E+01, -.42409700E+00, 0.44065900E+01, 0.11358100E+00, 0.33042300E+01, -.13856800E+00, 0.27086200E+01, 0.14011400E+01, -.15852100E+01, 0.11336800E+01, 0.76009100E+00, -.45427400E+00, -.11264500E+02, 0.36251400E+01, 0.12877700E+02, 0.25387900E+01, 0.15457000E+01, 0.41151900E+00, 0.45291400E+01, 0.50244900E+01 },
        { 0.19174000E+01, -.28258600E+01, 0.11115200E+02, 0.15556000E+01, -.52505300E+01, -.10894000E+01, -.43544200E+01, 0.36998800E+00, 0.88575200E+00, 0.24654400E+00, -.73473100E-01, 0.43059400E+01, -.21108900E+01, -.11057400E+01, 0.36729400E+01, 0.19581400E+01, 0.52724200E+01, -.78306600E+00, 0.75478400E+00, 0.22355000E-01, 0.12152200E+01, -.56731500E+01, -.60543100E+00, 0.37559900E+01, 0.99851200E+00, 0.95161400E+00, 0.19922900E+01, -.17143000E+01, -.52771900E+00, -.33176500E+00, -.45784900E-01, 0.69216200E-01, 0.29785800E+01, -.15643000E+01, -.11501200E+01, -.54648700E+00, 0.14414700E+00, -.17404800E+01, -.44039800E+00, -.80334000E+00, -.11986400E+01, 0.49064800E+01, 0.64336200E+01, 0.31588600E+00, -.51031800E+00, -.73368100E+00, -.29969900E+01, 0.83468600E-01, 0.45364100E+00, -.22640500E+01, -.94963300E+00, -.21771800E+01, -.11220600E+01, 0.22931800E+01, 0.46290500E-01, -.58970300E-01, -.15138100E+01, 0.29597800E+01, -.43531000E+00, 0.17371200E+01, -.23370600E+01, 0.19867100E-01, -.74113400E+00, 0.27101800E+00, 0.95757900E-02, 0.65463400E+00, 0.19852700E-01, -.97937600E+00, 0.51586300E+00, -.67797900E-03, 0.40139700E+01, -.41167100E+00, -.42051400E+00, -.42326300E-01, -.71418300E+00, -.98463800E+00, -.13894500E+00, 0.82606900E+00, 0.46574900E+00, 0.48772700E+00, 0.15383200E-01, -.18487000E+00, 0.33133800E+00, -.30875700E+00, 0.33680500E+00, 0.14065300E+01, -.16021900E+01, -.48200000E-01, 0.22016900E+01, 0.75459300E-01, 0.26943100E+01, 0.91450200E+00, -.22220400E+01, -.49007800E+01, 0.27158200E+01, 0.84682300E+01, 0.24798300E+01, -.29729500E+01, 0.53231600E+00, -.34979000E+00, 0.22611500E+01, -.30825300E+01, -.33910400E+00, 0.21710600E+01, 0.90798700E+00, 0.39907400E+00, -.14898700E+01, 0.19055300E+01, -.28626200E+01, 0.12110200E+01, 0.14435400E+01, 0.18707200E+00, 0.28724200E+00, 0.48220200E-02, -.93425600E+00, -.24160400E+00, 0.10210600E+01, 0.79118900E+01, 0.15702000E+01, 0.59429300E+00, 0.13203200E+01, 0.28953000E+01, -.95126000E+00, 0.22267300E+01, -.28527500E+00, 0.21872500E+01, -.13764400E+01, -.29621100E+01, -.36599200E+00, -.29013600E+00, 0.39430100E-01, -.14849300E+01, 0.46922400E-03, 0.81292400E-01, 0.70556200E+00, 0.12390200E-02, -.24900900E+01, 0.26305400E+00, -.12940900E+01, 0.14468100E+01, -.19814600E+00, -.21558500E+01, -.80483000E+00, 0.15779600E+01, 0.15612200E+01, -.13538000E+00, 0.31090700E+00, 0.48442800E+00, 0.19136100E+01, -.58583700E+00, -.15259700E+01, 0.11329500E+01, 0.42991300E+00, -.14046900E+01, 0.25893200E+00, -.46843400E+00, 0.19273000E+01, -.28515900E+00, 0.92281900E-01, -.14714500E+00, 0.81578700E+00, -.17921600E+01, 0.36627100E+00, 0.81457000E-01, -.44796100E+00, 0.29769700E+00, 0.22803600E-01, 0.55753000E+00, 0.20282900E+00, -.46279600E+00, 0.59119200E+00, -.18232300E+00, -.10872800E-01, 0.26096300E+01, -.22967800E+00, 0.67732500E+00, 0.13898600E+00, 0.16323100E-01, -.11610400E+01, 0.79754100E-01, -.91241100E-01, 0.13708000E+00, -.10051300E+01, 0.21699200E+00, -.14492800E+00, 0.69929000E+00, 0.34244300E+01, 0.13538400E+00, 0.74832300E-01, 0.89361900E+00, 0.37231000E-01, -.10380000E+01, 0.39016900E+00, 0.46833900E+00, -.17844500E+01, 0.11022200E+01, 0.21654700E+01, 0.16841200E+01, -.17857300E+00, -.10201400E+00, 0.10037600E+01, -.36451100E+00, 0.11550400E+02, -.14751000E+02, 0.12211100E-02, 0.15505400E+01, 0.58036600E+00, 0.11955800E+01, -.12497700E+00, 0.20539900E+01, 0.23590500E-01, 0.14226600E+01, 0.15345900E-01, 0.26832600E+00, 0.10033300E+01, 0.15958700E+01, 0.76304300E+00, -.17449200E+00, -.25266800E-01, -.14635300E+01, 0.26368500E+01, -.40820200E+00, 0.14162600E+01, -.13716500E+00, -.39180100E+01, 0.45358700E+00, 0.53021700E+00, -.17549000E+00, -.35955500E+00, -.39755400E+00, 0.30339200E-01, 0.40061200E-01, 0.74450900E-01, 0.19585800E+01, -.32190200E-01, -.37056800E+01, 0.33911500E+01, -.78145900E+00, -.13566000E+01, 0.86360700E+00, -.72643000E+00, -.97761900E+00, 0.47852600E+00, -.46938700E+00, -.13061300E+01, 0.16281600E+00, -.28715700E+00, -.45785700E+00, 0.28013700E+00, 0.51194000E+00, 0.19269500E+00, 0.14159800E+01, -.41520000E+00, -.93355800E+01, 0.11448200E+00, 0.56368200E+00, -.49865800E-03, 0.37149800E+00, 0.55312300E+01, 0.50646400E+00, 0.63930700E+00, 0.82707800E+00, 0.41601800E-01, 0.11486800E+00, 0.27634700E+01, -.96232000E-01, -.98182300E+00, -.31350800E-01, 0.35309400E+00, -.13360500E+01, 0.29042100E+00, 0.63848300E+00, -.31127900E+01, 0.10640200E+01, 0.12535300E+00, -.13845100E+02, 0.27941200E+00, 0.15838000E+00, 0.18001300E+00, -.35518200E+00, -.11796300E+01, -.30958600E+01, -.38997200E+00, 0.60920000E+01, -.60939000E+00, -.38843000E+01, -.13691500E+01, 0.95092400E+00, 0.79545600E+01, -.25176300E+01, 0.10211100E+01, 0.14968700E+01, 0.66007300E+00, -.70091300E+01, 0.30986900E+01, 0.94158700E+01, 0.29967500E+01, 0.24032100E+01, 0.64267800E+00, 0.11545200E+01, 0.18911400E+01 },
        { 0.85661400E-01, -.37764000E+00, 0.32426300E+00, 0.24556800E+00, -.65634500E+00, -.18386100E+00, -.10150700E+01, 0.13919100E+00, 0.44302100E-02, -.33252400E+00, 0.28668200E-01, 0.40014600E+00, -.64918000E-01, 0.34249200E+00, 0.92755100E-01, 0.41746800E+00, 0.47441500E-01, -.10316600E+00, -.32338200E+00, 0.13000300E+00, -.38990400E-01, 0.13594200E+01, 0.48239400E-01, -.26570000E+00, 0.11804700E+00, -.81215400E-01, 0.70963500E-01, 0.28268100E+00, 0.14192200E+00, -.16672400E+00, -.27613400E+00, -.14178900E+00, -.21063200E+00, 0.29794500E+00, 0.67169300E-01, 0.52336100E-01, -.10300600E-01, 0.35315000E+00, 0.68261700E-02, 0.28500700E+00, 0.18343200E+00, -.32955500E-01, -.14354200E+00, 0.92814200E-01, -.17282500E+00, 0.21454500E+00, 0.57347600E+00, 0.79881600E-02, -.62819400E-01, 0.49185400E+00, 0.17225400E+00, -.28006800E-01, 0.20060300E+00, 0.47910800E-02, -.66363300E-01, 0.37871400E-01, 0.36820500E+00, 0.78936000E-02, -.37647000E-01, -.14046000E+00, 0.15664800E+00, 0.21956400E-02, -.15000600E-01, 0.73157600E-01, 0.13016100E-01, 0.30866500E-02, -.79455100E-03, -.21620500E+00, 0.48102900E-01, -.15045600E-03, 0.12222200E+00, -.32688500E-01, 0.11291400E-01, 0.16715400E-01, 0.52599600E-01, -.68199500E-01, -.18244200E-01, 0.11164200E+00, 0.54500000E-01, 0.86348900E-02, 0.10225400E-02, -.13210500E-01, 0.66793100E-01, -.47832500E-01, -.25809300E-01, -.39061400E-01, 0.70994000E-01, 0.17710700E-01, 0.19723300E+00, -.39783600E-01, 0.11724700E+00, -.15732600E-01, -.38676900E-01, -.17380400E+00, 0.40181600E-01, -.10833800E-01, 0.41604000E-01, -.48995300E-01, 0.12000000E-01, 0.91954600E-02, -.19339800E+00, -.12864300E+00, 0.96182600E-02, 0.37900700E-01, 0.10022700E+00, -.24282200E+00, -.11171400E+00, -.94999300E-01, 0.30165200E+00, 0.49533600E-01, 0.11014600E+00, 0.15446800E-01, -.25225700E-02, -.62526200E-02, 0.12160300E-01, 0.24324100E-02, 0.12793700E-01, 0.17622400E+00, 0.13652700E+00, 0.79610600E-02, 0.15448000E-01, 0.52924400E-01, 0.59826900E-02, 0.79819700E-01, -.10474500E-01, 0.65319200E-02, -.40704600E-01, 0.31282600E-01, -.17620200E-01, -.86617300E-01, 0.24061800E-01, -.89792600E-02, 0.67796500E-02, -.30409000E-01, 0.23910700E-01, 0.15656400E-02, 0.73011400E-01, 0.63524000E-01, 0.44631300E-01, 0.38643500E-01, -.19290100E-01, -.23208000E+00, -.40664200E-01, 0.70094200E-01, 0.60523500E-01, -.71321100E-02, -.19549900E-01, -.80368300E-01, 0.20603400E-01, 0.29693600E-01, -.57794500E-01, 0.15802600E-01, 0.84969000E-01, -.42101400E-01, 0.42068700E-02, -.17703800E-01, 0.25392300E-01, 0.30145400E-02, -.42826100E-01, -.31875900E-02, 0.62485500E-01, 0.21003400E+00, 0.17061900E-01, 0.17922600E-01, -.33790800E-01, -.27378000E-01, -.13823700E-01, 0.21524600E-01, 0.18644800E-02, 0.22131700E-01, 0.64042500E-01, -.57753800E-01, 0.42133600E-02, 0.21223500E+00, -.22787500E-01, 0.20037800E+00, 0.10648800E-01, -.17787000E-02, 0.15535100E+00, 0.46279100E-03, 0.17513500E-01, 0.86996200E-01, 0.15595100E+00, -.31517300E-01, -.28327300E-01, -.11557800E-01, 0.17978900E+00, 0.23041600E-01, 0.80729900E-02, 0.35263700E-01, -.15191600E-03, -.10639100E+00, 0.26998300E-01, -.31792000E-01, -.89533300E-01, 0.55514800E-02, 0.35152000E-01, -.30559500E-02, 0.61567900E-02, 0.69484800E-02, -.19698500E-01, 0.30826000E-02, 0.11460600E+00, 0.36432100E+00, -.45786900E-03, -.26394700E-02, 0.22021300E-01, 0.34234500E-01, 0.42793600E-03, 0.96343100E-01, 0.73363200E-02, -.41427600E-01, -.30665300E-03, 0.32435200E-01, -.47395600E-01, -.25309900E-01, -.12285200E-01, 0.11220700E-01, 0.12998500E-02, 0.17205800E-01, 0.42993700E-01, 0.40724100E-02, 0.15597100E+00, 0.11294600E-02, -.64042700E-01, 0.40345900E-02, 0.15543800E-01, 0.16314600E-01, 0.11613800E-01, 0.11910300E-01, -.45919500E-02, 0.69485300E-03, 0.31722500E-02, -.54824200E-02, -.48470200E-03, 0.26160200E-01, 0.13837400E+00, -.10892300E-01, -.14700500E-01, 0.39616600E-02, 0.25007500E-01, 0.75809600E-02, 0.21838900E-01, -.41103700E-03, 0.26404000E-01, -.68424900E-03, 0.27404100E-02, 0.19750500E-01, -.29596500E-02, -.89977500E-03, -.19996500E-01, -.13030700E-01, 0.14794600E-01, -.24501200E-01, -.42244200E-02, 0.36103000E-02, -.27260400E-03, -.65325100E-02, 0.24910300E-01, 0.99937300E-02, 0.17325600E-01, 0.20497200E-01, 0.13700400E-02, -.85521100E-02, 0.61414000E-02, 0.64474800E-02, -.14519200E-01, 0.47032900E-03, 0.12944500E-01, 0.91946000E-02, -.79091600E-02, -.59748500E-05, 0.30226000E-01, 0.25467000E-01, 0.11270600E-02, -.12326700E+00, 0.21466200E-02, -.17937000E-01, 0.40304300E-01, 0.42412100E-02, 0.11299100E-02, -.46083400E-02, 0.20037500E+00, 0.20185900E-01, -.62705100E-02, -.15721000E-01, -.29076500E-01, -.51031300E-01, 0.29518700E-01, 0.12506100E-02, -.87462200E-02, 0.90751100E-02, -.35905400E-02, -.41102000E-02, 0.32319100E-02, 0.22233600E-01, 0.20084600E-01, 0.61560600E-02, 0.20687700E-03, -.28816900E-01, -.45396500E-01 },
        { 0.25202000E+00, -.88457900E+00, 0.32138500E+01, -.56618000E-01, -.14810700E+01, -.40381100E+00, -.24868700E+01, -.43025400E+00, -.27325200E+00, -.33868300E+00, 0.18172400E+00, 0.21230600E+01, -.53297700E+00, 0.48458400E+00, 0.86815100E+00, 0.10233000E+00, 0.23335300E+01, -.32447700E+00, 0.73488500E+00, 0.28924000E-01, 0.70747100E+00, 0.10050300E+01, -.11489100E+00, 0.49385600E+00, 0.68974200E+00, 0.41903700E+00, 0.50117300E+00, -.13205000E+00, -.66582700E-01, -.30054600E+00, -.24934200E+00, -.98198700E-01, 0.78526100E+00, -.31659800E+00, -.42660100E-01, -.46440400E-03, 0.31882900E-01, -.25507900E+00, -.22495000E+00, -.21545400E+00, 0.15918000E+00, 0.70506200E+00, 0.76452500E+00, 0.11845300E-01, -.40065800E+00, -.28564600E-01, 0.17686800E+00, 0.30574800E-01, -.54092600E-01, -.41138200E-01, -.48996400E+00, 0.34350500E+00, -.23663400E+00, 0.68103000E+00, 0.94932700E-01, -.26568900E+00, -.62784400E-01, 0.27119000E+00, -.17220100E-01, 0.16666600E+00, -.28382400E-01, 0.15336200E+00, -.14132900E+00, 0.42316900E+00, -.87778200E-02, -.10811900E+00, -.41259300E-01, -.53333700E+00, 0.29939700E+00, 0.21488500E-02, 0.30159200E+00, 0.50092800E+00, -.17115800E+00, -.17813900E-01, 0.39096100E-01, -.27369100E+00, -.24701500E-01, -.24065100E+00, -.19185900E-01, 0.24564700E+00, 0.71396500E-02, -.52396800E-01, -.42317700E-01, -.17830200E-01, 0.46435800E-02, 0.90607000E-01, -.21662700E+00, -.65630300E+00, -.53186200E+00, 0.14728100E+00, 0.22040500E+00, 0.11081600E+00, 0.10289600E+00, -.46102600E+00, 0.10074400E+00, 0.83905100E+00, 0.11288400E+00, 0.76330700E-01, -.57394700E-01, -.67652100E-01, 0.27933200E+00, -.41823500E+00, -.15269100E-01, 0.33409700E+00, 0.11094800E+00, 0.34997000E+00, -.14371400E+00, 0.40601200E+00, -.61994800E+00, 0.47269600E+00, 0.70447800E+00, 0.66923800E+00, 0.73418200E-01, -.43950900E-01, -.95320100E-01, -.62383900E-01, 0.79873800E-01, 0.80743800E-01, 0.31403000E+00, 0.64551100E-01, 0.17981800E-03, 0.58524000E-01, 0.91490900E-01, -.12562900E+00, -.27100300E-01, 0.10556700E+00, -.51599400E+00, 0.24398500E+00, 0.22089400E-01, -.18571200E-01, 0.31166900E+00, 0.18080100E+00, -.60770400E-02, 0.71144900E-01, -.32657000E-01, 0.46161800E-02, -.27078100E+00, 0.45447300E-01, -.15297000E-02, 0.54739500E-02, -.14479000E-01, 0.36086500E+00, -.29488100E-02, -.15140300E+00, -.40119100E+00, -.11155600E+00, -.40818600E-01, 0.29761000E+00, -.15648800E-01, 0.87712500E-01, 0.13684500E+00, -.12532700E+00, 0.34658100E-01, 0.49749000E+00, 0.59959300E-01, -.85576400E-01, 0.28786500E+00, 0.15803700E-01, -.22758600E-01, -.53180200E-01, -.11345100E+00, -.28561100E+00, 0.36741900E-01, -.15494800E-01, 0.91277100E-01, 0.32851000E+00, 0.77249800E-01, -.66143300E-01, -.10241500E-01, 0.26844900E+00, -.19381900E-01, 0.26741000E+00, 0.95452400E-01, -.10674900E+00, 0.39711900E-01, -.26511100E+00, -.52302900E-01, 0.12208200E-02, 0.15663800E+00, -.11362800E-03, -.57398700E-01, 0.13760800E-01, -.16895800E+00, 0.36663900E-01, 0.23024800E+00, 0.29080100E-01, 0.24837300E+00, 0.23138100E-01, -.28030100E-01, -.30041200E-01, -.65997000E-03, -.13058900E+00, 0.55021700E-01, 0.86000600E-01, -.25992400E+00, -.51055100E-01, -.44005600E-01, 0.30006000E-01, 0.81172900E-01, -.67356500E-02, 0.80573500E-01, 0.41869500E-02, -.81184300E-01, -.45425800E+00, 0.46097300E-01, 0.10939400E-01, -.21577100E-01, -.13509500E+00, 0.47590900E-01, 0.83028800E-01, 0.14121300E-01, 0.28767300E-01, -.20875400E-02, -.12292800E+00, -.22275300E-01, 0.20512000E-01, 0.35423100E-01, -.64948300E-01, 0.98942700E-02, -.20922900E-01, 0.22048100E+00, -.79667700E-02, -.65452400E+00, 0.12327800E-01, -.16043400E+00, 0.62100200E-01, 0.13586000E+00, -.41144600E-02, 0.12585300E-01, -.77806500E-02, -.40848800E-02, -.10246100E+00, 0.21509300E-01, 0.21349700E+00, 0.36465000E-01, -.10529300E+00, -.15464100E+00, -.10181300E-01, -.92159800E-01, -.18135900E-01, 0.55112500E-01, -.36502300E-01, 0.46067000E+00, 0.10708100E-01, 0.12901000E+00, 0.25672000E-02, 0.20173500E-01, -.44126300E-01, 0.33432900E-02, -.18062200E-01, -.13673200E-01, 0.72379600E-01, -.61706600E-02, 0.90738400E-01, 0.11326000E-01, -.93245000E-02, -.97432500E-03, -.25704700E-01, 0.14868400E-01, 0.30966600E-01, 0.90813600E-01, 0.39667400E-01, 0.12367000E-01, 0.95723800E-02, 0.29348400E+00, -.14704400E-01, -.60108400E-01, 0.40059100E-03, -.12000100E-01, 0.37296100E-01, 0.99516900E-02, 0.95581100E-02, -.29856400E-01, -.59352900E-02, 0.16164100E-02, 0.44103000E+00, 0.65119300E-02, -.69973400E-03, -.22411200E-01, -.85928500E-03, -.72657700E-02, -.14536300E+00, -.25214500E+00, 0.94712000E+00, -.15977100E+00, -.59728400E+00, -.21237200E+00, 0.12677700E+00, 0.11094300E+01, -.34849800E+00, 0.13404100E+00, 0.24480000E+00, 0.56926500E-01, -.12521900E+01, 0.21881900E+00, 0.16845800E+01, 0.55113700E+00, 0.34851500E+00, 0.10502700E+00, 0.20723600E+00, 0.30145700E+00 },
        { -.27934800E+00, 0.20840400E+00, -.18017300E+01, -.24113100E-01, 0.10954200E+01, 0.32896000E+00, 0.13183200E+01, -.18222600E+00, 0.46471700E-02, 0.10052900E+00, -.12099800E+00, -.13068700E+01, 0.34137600E+00, -.24140500E+00, -.93080300E+00, -.35716800E+00, -.15843600E+01, 0.22229600E+00, -.16839900E+00, -.17738500E+00, -.37064600E+00, 0.16342600E+00, 0.60163900E-01, -.75615700E+00, -.42371900E+00, -.28977500E+00, -.45733800E+00, -.49003200E-01, 0.12107200E+00, 0.33564000E+00, 0.24776400E-01, 0.63968300E-01, -.40834400E+00, 0.19767000E+00, 0.13785500E+00, 0.20243800E+00, -.40040400E-01, 0.44918000E+00, 0.20030200E+00, 0.19740500E+00, -.27892200E+00, -.64968800E+00, 0.13707300E+00, 0.30548000E+00, 0.19717700E+00, 0.10813700E+00, 0.24742800E+00, -.46111100E-01, -.37198400E-01, 0.35401600E+00, 0.34368500E+00, 0.11272500E+00, 0.12563300E-01, 0.11822300E+00, -.23819100E+00, 0.79015000E+00, 0.13371100E+00, -.21678200E+00, 0.39065500E-01, 0.18151600E+00, 0.12215000E+00, -.22835700E+00, 0.85771100E-01, -.29037400E+00, -.16220600E-01, 0.19266100E-01, 0.91358400E-01, 0.52381700E+00, -.16812400E+00, -.98341800E-03, -.30301200E+00, -.88527300E-01, 0.60797000E-01, -.23346200E-01, 0.28921900E-01, 0.75113300E-01, 0.69195800E-01, 0.17791700E+00, -.11352700E+00, -.17886900E+00, -.92195200E-02, 0.67794200E-01, -.14217100E+00, -.45789900E-01, -.74897900E-01, -.79477100E-01, 0.37962300E+00, 0.45933800E+00, 0.55582600E+00, 0.12700100E-01, -.53177000E+00, -.13881500E+00, 0.25891100E+00, 0.41062700E+00, -.18725800E+00, -.11485900E+01, 0.48544800E-01, -.31695500E-01, 0.89351000E-01, 0.10019900E+00, -.30850800E+00, 0.43761900E+00, 0.13420800E-01, -.30619300E+00, -.11673700E+00, -.18796900E+00, 0.16550200E+00, -.73996000E-01, 0.60235000E+00, -.14251800E+00, -.71574300E+00, -.33313400E+00, -.65980400E-01, 0.45608400E-02, 0.42648400E-01, 0.45435000E-01, -.15649000E+00, -.51414200E+00, -.33644600E+00, -.85074500E-02, 0.26586900E-03, -.25020000E+00, 0.34503000E-01, -.56442900E-01, 0.60675100E-02, 0.15022700E+00, 0.39418600E+00, -.22717600E+00, -.87554500E-02, 0.13404700E-01, -.23694300E+00, -.19729300E-01, -.16296200E-01, 0.23227000E-01, -.59821700E-02, -.36863800E-02, 0.63128900E-01, -.41939400E-01, -.34284100E-01, 0.40313500E-01, -.11301500E-01, -.40556400E+00, -.20587500E-01, 0.35354900E+00, 0.51305500E+00, 0.76344200E-01, 0.60758500E-01, -.13152600E-01, 0.17896500E+00, -.14228000E+00, -.21782500E+00, 0.17879500E+00, 0.17129800E+00, -.56708900E+00, -.13411900E+00, 0.72757100E-01, -.17306900E+00, -.13820500E-01, 0.32223100E-01, 0.50759100E-01, 0.14341100E+00, 0.67421500E-01, 0.37872900E-01, -.70644500E-02, -.36888500E-01, -.28381700E+00, -.28048500E-01, 0.22149200E-02, 0.35645700E-02, -.16845900E+00, 0.17648500E-01, -.98042200E-01, -.69500100E-01, 0.24980800E-01, -.26730600E-01, -.43266200E-01, -.11070200E-01, 0.85106700E-02, 0.13789400E-01, -.48074400E-03, -.28830900E-01, -.86370500E-01, -.21962100E+00, 0.35394700E-01, 0.19357400E-01, 0.15924800E-01, -.45748500E-02, 0.56529900E-02, 0.24778200E-02, -.30467000E-02, 0.81078800E-04, 0.26557600E-01, -.14289400E-02, -.29800100E-01, 0.17089400E+00, 0.16561900E-01, -.27780500E-01, -.11776700E+00, 0.20161600E+00, 0.14126300E-01, -.15314400E+00, 0.19154300E-01, -.25573000E+00, 0.17089000E+01, -.51906700E-02, -.12821500E+00, 0.51401400E-01, 0.19995700E+00, -.46479300E-02, -.19227100E+00, 0.10342000E-01, -.11080600E+00, 0.69398800E-03, 0.73372000E+00, -.29116400E-01, 0.40913500E-01, -.32554400E-01, -.75393900E-03, -.95518100E-03, 0.70128200E-01, 0.19193600E-01, 0.47746400E-01, 0.48247900E-01, -.17665400E-02, -.25833700E+00, -.86052500E-02, 0.10832900E-01, 0.68836300E-01, 0.27309800E-01, 0.12460300E-01, 0.94289700E-02, 0.84465500E-01, -.15613200E-01, -.14954300E+00, -.32460400E-01, 0.25515600E+00, -.74348700E-02, -.22583500E-01, -.15422400E-01, 0.24136100E-01, -.10468500E+00, -.68833000E-03, -.16526500E+00, 0.39204500E-02, 0.30776300E-02, -.50173700E-02, -.91818400E-02, 0.20959900E-01, -.18368100E-01, -.29129300E-01, 0.23846800E-01, -.50726600E-01, -.14802800E-01, 0.94554900E-01, 0.27246100E-01, -.96500000E-02, 0.40390500E-03, 0.12958600E-01, -.49307500E-02, -.18734900E-01, -.11964800E+00, -.64068500E-01, 0.19979300E-01, 0.10669500E-01, -.31015300E+00, 0.37010100E-02, 0.12089400E-01, -.14056100E-03, -.33272300E-02, 0.12451100E+00, -.26725400E-01, -.50029700E-01, 0.11816300E+00, 0.20887000E-01, 0.30792400E-01, -.84999500E+00, -.25857300E-02, -.21841300E-01, -.78671000E-01, -.27779200E-01, 0.34556900E-02, -.53889400E-02, -.46248200E-01, -.62457500E-01, 0.14749000E+00, -.34544700E-01, -.58507300E-01, 0.35498800E-01, 0.41613700E+00, -.15945100E+00, 0.18532100E-02, 0.12581400E-01, 0.41317300E-01, 0.61029600E-01, -.41189300E-01, -.37422500E-01, -.55890600E-01, 0.17378200E-01, -.10089300E-02, -.36768000E-01, -.36435600E-01 },
        { 0.19337100E+00, 0.38817700E-01, 0.17252900E+01, 0.16602700E+00, -.52429000E+00, -.67664800E-01, -.59876100E+00, -.99279000E+00, -.84302400E-01, 0.23579800E+00, -.41863400E-01, 0.58274600E+00, -.29502300E+00, -.20193600E+00, 0.16116300E+00, -.45791400E-01, 0.35966500E+00, -.42511100E-02, 0.19996800E+00, -.23889100E-01, 0.31780500E+00, -.83884100E+00, -.11039600E+00, 0.83819500E+00, 0.23732400E+00, 0.59467500E-01, 0.98586300E-01, -.48413600E+00, -.61874000E-01, 0.15277600E-01, -.13929100E+00, -.13550600E+00, 0.30747300E+00, -.14760300E-01, 0.67252500E-01, -.91678000E-01, 0.26097300E-01, -.44083900E-01, 0.13562600E+00, -.22602300E+00, -.11989000E+00, -.17342000E-01, 0.57031100E+00, 0.54887700E-01, -.12781000E+00, -.86250500E-01, -.32918700E+00, 0.57730600E-02, -.83411500E-01, 0.75748100E-01, 0.48226300E-01, 0.43322700E+00, -.11855600E+00, 0.17568200E+00, -.11233800E-01, 0.17920100E+00, 0.66889700E-01, -.20013000E+00, 0.19137700E-01, -.12023100E+00, 0.30848400E+00, 0.49696400E-01, 0.13837900E+00, -.20738200E+00, -.77611700E-01, -.20099100E+00, -.49978900E-01, -.12811000E+00, 0.41800400E+00, 0.16152300E-02, -.20316000E+00, -.89751700E-01, -.82958500E-01, -.50327600E-01, -.70623900E-01, -.47146500E-01, 0.71014400E-01, -.25986500E+00, 0.15077600E+00, 0.57794100E-01, -.19095700E-02, 0.32417900E-01, -.17906700E+00, -.87418100E-01, 0.39865200E-01, -.17285700E+00, 0.49820300E-02, 0.32770000E+00, 0.22027900E+00, -.75723600E-01, -.60690800E-02, -.70335200E-01, -.11941300E+00, 0.74192800E+00, 0.34156000E+00, 0.76637800E+00, -.16637300E-01, -.17194400E+00, 0.17567800E+00, 0.22568600E+00, -.19667800E+01, 0.54190000E-02, 0.19952000E-01, 0.82770300E-02, 0.90735800E-01, -.43764000E+00, -.20506300E+00, 0.36657300E-01, 0.21718400E-01, 0.72014000E+00, 0.19041700E+00, -.37380800E-01, 0.13186800E+00, -.42145900E-01, -.15881600E-01, 0.22956100E+00, -.57526400E-01, -.91994600E-01, -.64486800E-02, 0.63285000E-01, -.75477400E-01, -.48960700E+00, 0.12893200E+00, 0.66847200E-01, -.31210600E-01, -.51713800E+00, -.34783100E+00, -.35335600E+00, -.10896400E+00, 0.53678800E-01, 0.42204500E-01, 0.18798900E+00, 0.28580300E-02, -.28005200E-01, 0.35675500E-01, 0.99886900E-03, 0.96471300E-01, 0.68215100E-01, 0.75633300E-01, 0.25421700E+00, 0.15389100E-01, -.14235200E+00, -.82624800E-01, -.11207200E+00, 0.12119000E+00, 0.15459700E-01, 0.86672000E-02, -.13679300E-01, 0.17540700E+00, -.10457700E+00, -.15399100E+00, 0.13745000E+00, -.13540800E+00, -.27996500E+00, 0.65898900E-01, 0.93122600E-02, 0.22661100E+00, -.17334500E-01, 0.43101500E-02, -.23134300E+00, -.97338400E-01, 0.65318100E-01, -.10833300E+00, 0.15707700E-01, -.72204300E-01, 0.20645500E+00, -.15651300E-01, 0.66567600E-01, 0.41481000E-02, 0.58831900E-01, 0.10844600E+00, -.58541900E-01, 0.24437000E-01, 0.17191800E+00, -.43777100E-02, 0.20170900E+00, 0.54863300E-01, -.35219500E-02, -.21215500E+00, 0.58215900E-03, 0.66449400E-01, 0.17798600E+00, 0.37358400E+00, -.69610000E-01, -.18777500E+00, -.96102600E-01, 0.10995200E-01, -.87211700E-01, 0.18711300E-01, 0.17431700E-01, 0.46383800E-03, -.10305400E+00, 0.74544800E-01, -.11939100E-01, 0.15820500E+00, -.10915000E-01, -.15531800E+00, 0.19242600E+00, -.64494500E-01, 0.42645000E-01, 0.32931000E-01, -.84642900E-02, 0.14453100E+00, 0.62235400E+00, -.22116100E-01, 0.20879800E+00, -.11402600E-01, -.10177900E+00, 0.34396100E-02, 0.70942300E-02, -.48666400E-01, 0.14254100E-02, 0.14767200E-02, -.11436100E+01, 0.79930400E-01, 0.83690000E-01, 0.54584100E-01, 0.63915600E-01, -.13958300E-01, -.55874600E-01, -.38512500E+00, 0.94862200E-02, -.10171900E+00, -.13341400E-03, 0.22992200E+00, -.28919800E-01, -.57670800E-01, 0.96124300E-02, -.22950700E-01, 0.33947500E-01, 0.87466200E-02, -.47833900E-02, -.36242400E-02, -.51911300E-01, 0.35237800E-02, -.16752000E+00, -.22052500E+00, 0.14877700E-01, -.10993400E-01, -.14569700E-01, -.83162500E-01, 0.39178500E-01, 0.84603600E-01, -.24963900E-01, 0.10910000E+00, -.36113700E-02, 0.45412900E-02, 0.24840000E-01, 0.25777100E-03, -.34996700E-02, -.27924300E-01, 0.67695900E-01, -.93227600E-03, -.55967000E-01, -.32529400E-01, -.21402300E-01, 0.22702100E-03, -.30174000E-01, -.14792400E+00, 0.60071000E-02, 0.43830900E-01, -.37614900E-02, -.35842200E-01, -.13917300E-01, -.11868100E+00, 0.13170500E-01, -.24277100E+00, -.61792300E-04, -.70268400E-02, -.42391700E+00, 0.31048000E-01, 0.60467700E-01, -.16615000E+00, -.25883500E-01, -.46827900E-01, 0.31460700E+00, 0.23422000E-02, 0.84807900E-02, 0.38756600E-01, -.33239200E-02, 0.73236100E-01, -.58184100E-01, 0.72994100E-01, 0.40664700E-01, -.25771900E+00, -.45586700E+00, 0.37645600E-01, -.14622700E+00, 0.33544900E+00, -.77668400E-01, -.25354600E-01, -.32462100E-02, 0.63454700E-01, 0.66638100E+00, -.85400200E-01, -.68256500E+00, -.72725200E-01, 0.18403900E-01, -.48416300E-02, -.30169200E+00, -.31545200E+00 },
        { 0.27549100E+00, -.28409000E+00, 0.16181300E+01, 0.18833700E+00, -.10410400E+01, -.33154100E+00, -.70079000E+00, 0.10257500E+01, 0.37138900E+00, -.34794400E+00, -.12619600E+00, 0.66904400E+00, -.20616700E+00, 0.13977400E+00, 0.22431200E+00, 0.35794100E-01, 0.10692700E+01, -.10962100E+00, -.32442000E+00, 0.68607500E-01, 0.57221700E+00, -.53944200E+00, -.13166900E-01, 0.50696100E+00, 0.17795200E+00, -.30905800E-01, 0.10186700E-01, -.27417700E-01, -.28929400E-01, -.30491500E+00, 0.58294100E-01, -.89760700E-01, 0.23514800E+00, -.54507200E-01, -.30707400E+00, -.19967500E+00, 0.41212700E-01, -.59742800E+00, -.26143700E+00, -.20391500E+00, 0.25078700E+00, 0.75220600E+00, 0.28676300E+00, 0.25063800E-01, -.69650700E+00, -.16476500E+00, -.73868200E+00, 0.28518500E-01, -.13213300E+00, 0.40133100E-01, -.23567600E+00, 0.14970200E+00, 0.64413000E-01, -.15245400E+01, 0.18489600E+00, -.66010900E+00, -.43374200E-01, -.59075600E-01, -.26500100E-01, -.13985800E+00, 0.75248400E-02, 0.23972400E+00, -.43038200E-03, -.33507200E-01, 0.44878400E-01, -.79012100E-01, 0.21635400E-02, -.24253000E+00, 0.44917300E-01, 0.89716200E-03, 0.46150100E-01, 0.61851500E+00, -.51469100E-01, 0.31416900E-01, -.55227100E-01, 0.58458200E-01, -.78675800E-01, -.12704500E+00, 0.15298000E+00, 0.56968500E-01, 0.76932300E-02, -.23479300E-01, -.51603000E-01, 0.54459100E-01, 0.11537500E-02, -.39971800E-01, 0.28434800E-01, -.45330200E+00, -.62415600E+00, 0.32183000E-01, -.23777200E+00, 0.38878500E-01, 0.60389800E-01, -.32000500E+00, -.51200300E-01, 0.89691400E-01, -.98741900E-01, 0.16021200E+00, -.18917800E-01, -.34117800E-01, 0.51264700E+00, -.18795000E-01, -.14753800E-01, 0.16006200E+00, 0.38708800E-02, 0.13284800E+00, -.64599000E-01, -.16399700E-01, -.10502000E+00, 0.19014800E+00, 0.32653700E+00, 0.32891500E+00, -.37092700E-01, -.51830900E-02, 0.67873700E-01, 0.99022300E-01, -.15987400E-01, -.72001800E+00, 0.51683100E-01, 0.55402700E-02, 0.36997200E-02, -.26846200E+00, -.18866500E-01, -.78587200E-01, 0.19175800E-01, 0.96978900E-01, -.50771800E-01, -.14922000E+00, -.17579600E-01, 0.31064100E-01, 0.42618400E-01, 0.79063600E-01, -.23438200E-01, -.17950000E-01, 0.39776300E-01, -.54556800E-02, -.88177400E-01, 0.37773500E-02, -.44804500E-01, -.15019000E+00, 0.90703600E-01, -.22605000E-01, 0.48228700E-01, -.27202700E+00, -.57333600E-01, -.18770000E-01, 0.24079600E-02, -.98890200E-02, 0.19047000E-01, -.24736500E-01, 0.97655400E-01, -.93679600E-01, -.11192800E+00, 0.19241200E+00, 0.47766900E-01, -.34187000E-01, 0.93209300E-01, 0.30378800E-02, -.89360900E-01, 0.30694000E-01, -.20257500E+00, 0.34879700E+00, -.35680300E-01, 0.42357800E-02, 0.51256900E-01, 0.16164500E+00, 0.10552300E-01, 0.15249500E-01, 0.30002600E-02, 0.35235800E-01, -.10555000E-01, 0.16979600E+00, -.16131300E-01, -.11329100E+00, -.23763300E-01, -.75542200E-01, 0.20977200E-01, -.12736300E-01, -.52564600E+00, 0.82007200E-03, 0.41817900E-01, -.81990700E-01, 0.11709100E+00, -.31325100E-01, -.18510600E+00, -.15106900E+00, 0.60278400E+00, 0.65867700E-01, 0.44931900E-02, 0.41733500E-01, -.29333500E-03, -.21171200E+00, -.62931200E-01, 0.33441900E+00, 0.14876000E+00, -.14151000E+00, -.72185200E-01, 0.23083300E-01, -.20394400E+00, -.26635900E-02, 0.22275900E+00, -.12474400E-01, 0.31297800E+00, -.15452100E+01, 0.35221500E-01, 0.39596600E-01, 0.75648200E-02, -.31197500E+00, 0.17483600E-01, 0.94308400E-01, -.15953100E-01, 0.22133000E+00, -.29646600E-03, -.68365500E+00, -.10062900E+00, 0.31354900E-01, 0.31377900E-01, 0.95680700E-01, -.16740400E-01, -.70392600E-01, 0.52395900E-01, -.38715700E-01, 0.31692300E+00, -.26080600E-03, 0.16720000E-01, -.17243900E-01, -.99088000E-01, -.56811900E-01, -.18085600E-01, 0.36377500E-02, -.10445400E-02, 0.39132200E-01, -.14697600E-01, -.57448500E-01, -.13441100E-01, -.11368800E+00, 0.12894900E+00, 0.36753900E-01, 0.17877900E+00, 0.96395000E-02, 0.15240700E+00, 0.49614200E-01, -.66685400E-01, -.35843700E-01, 0.97806000E-01, -.28592900E-02, -.67019100E-02, 0.40617700E-01, 0.38642000E-02, 0.10072200E-01, -.85590900E-02, -.83028600E-02, 0.41616100E-02, -.43621700E-01, -.21477900E-01, 0.62084300E-02, -.50675300E-03, -.36893400E-02, -.46659400E-01, -.21200000E-02, 0.32618600E-01, 0.16815200E-01, -.17934500E-01, -.11074000E-01, 0.17929100E+00, 0.43349600E-02, -.19690700E-01, 0.10685300E-02, -.36517000E-01, -.10957600E+00, 0.27806200E-01, 0.30909100E-01, -.37289800E-01, 0.17394200E-01, -.63310900E-01, 0.19053000E+00, 0.17247200E-01, 0.61824100E-03, -.17951500E+00, 0.27980100E-02, 0.14051100E-01, -.20700000E-01, -.96256500E-01, 0.35706400E-01, -.30695100E+00, 0.43913900E+00, 0.47716000E+00, 0.27022200E-01, 0.78079400E-01, -.25656500E-01, 0.57220100E-01, -.20249400E-01, 0.54846600E-01, 0.99441700E-01, -.11539600E-01, -.10857100E+00, -.18882700E-01, 0.22440400E-02, 0.15403300E-01, -.40614200E-03, -.19363400E-01 },
        { -.83011500E-01, 0.61438800E+00, 0.42438100E+00, -.23792200E+00, -.12542800E+00, 0.31761800E-01, 0.37885500E+00, 0.60942000E+00, -.37721500E-01, -.29892100E+00, 0.58611400E-01, 0.83866800E+00, 0.17976200E+00, 0.22904100E+00, 0.19524300E+00, -.19410400E+00, -.82096700E-01, 0.97747000E-02, 0.15922400E+00, -.69591400E-01, 0.11149400E+00, 0.18086900E+00, 0.36756600E-01, -.25408500E-01, 0.82918800E-01, 0.22826600E-01, -.11560500E+00, 0.28797500E+00, -.11558100E-01, -.54026200E-01, 0.17525400E+00, 0.50796400E-01, -.13830000E+00, -.77221100E-01, -.79147500E-01, 0.10848100E-01, -.81300400E-02, -.16850000E+00, 0.13438900E-01, -.73207800E-03, 0.11648800E+00, 0.11344500E+00, 0.21178500E+00, 0.47214200E-01, -.30446700E+00, 0.44934500E-02, -.34644500E-01, -.27694800E-01, -.10852300E+00, 0.17529000E+00, -.14828600E+00, 0.15949000E+00, -.27470300E+00, 0.82601000E+00, 0.15353500E+00, 0.13162100E+00, -.42210500E+00, 0.91878100E-01, 0.60968800E-01, -.84304400E-01, 0.60414500E-01, -.23943100E-01, 0.45377700E-01, -.48126900E-01, -.71627200E-01, -.14336700E-01, -.11469600E+00, 0.47840700E-01, 0.21650000E+00, 0.81774000E-03, -.31904100E-01, 0.75763000E-01, -.54992100E-02, -.28688900E-01, -.23173700E+00, -.17427700E+00, -.27207200E-01, 0.27766600E+00, -.16603100E+00, 0.53899200E-01, 0.71581500E-03, -.64374600E-01, 0.37970500E+00, 0.85352700E-01, 0.26777900E-01, 0.10495400E+00, -.21417800E+00, -.38675600E+00, -.42190500E+00, 0.13181200E+00, -.90493800E-01, 0.45750700E-01, 0.13575700E+00, 0.47673600E-02, -.18518500E-01, 0.26725100E+00, 0.38008800E-01, 0.95849100E-01, -.21685500E-01, -.76598900E-01, 0.84080900E+00, -.13469000E+00, -.15859200E-01, 0.21450600E+00, -.55441800E-01, 0.25335300E+00, -.10317000E+00, 0.38089900E+00, -.31359500E+00, 0.13273500E+00, -.23292200E-01, 0.25918300E+00, -.11494700E+00, 0.77933500E-02, -.75185500E-01, 0.15446900E+00, 0.51016800E-01, -.56355600E+00, -.24176100E+00, -.48276100E-01, 0.92406300E-01, -.20313600E+00, -.10253000E+00, 0.31164800E+00, -.18524100E-02, -.96403000E-01, -.15612000E+00, -.10566600E+00, -.29576800E-02, 0.22453000E-01, -.70659200E-01, 0.52043400E-01, -.19198900E-02, 0.42145800E-01, 0.83829000E-02, 0.27020400E-03, -.21083700E+00, -.75927200E-01, -.11945800E+00, -.85952200E-01, 0.57072300E-01, -.16215600E+00, 0.38969200E-01, -.28120100E+00, -.93611900E-01, 0.40712900E-01, 0.78683900E-02, 0.91488700E-01, 0.31154600E-01, -.36244100E-01, 0.19127400E+00, -.90966100E-01, -.64261000E-02, 0.22892700E+00, 0.15533900E+00, 0.79668600E-01, -.14867100E+00, -.68872700E-02, 0.66221600E-01, 0.10365000E-01, -.90493400E-01, 0.17022300E+00, -.32318300E-01, -.63968400E-02, 0.37359500E-02, -.14559200E-01, -.10995500E-01, -.40669900E-01, -.20875100E-03, 0.76735500E-01, -.24254400E-01, -.24656100E-01, 0.66062600E-02, -.20303500E+00, 0.21334000E-01, 0.54923000E-01, 0.12778000E-01, -.19041000E-02, 0.33952900E+00, -.31462500E-03, 0.31100900E-01, 0.44157600E-01, 0.25180600E+00, -.22067900E-01, -.14741900E+00, -.32468800E-01, -.56839100E+00, 0.35658700E-01, 0.74557000E-02, -.60248500E-01, 0.26867600E-03, 0.12146100E+00, -.79940400E-01, -.51778100E-01, 0.22271600E+00, 0.71438100E-01, -.21155600E+00, -.13182700E+00, -.91404200E-01, -.39142700E-01, 0.86360300E-01, -.22195800E-01, -.60902600E+00, -.83958300E+00, -.12433600E-01, -.27246100E-01, -.13640100E+00, -.26037400E+00, 0.72437800E-04, -.98725200E-02, 0.15904200E-01, -.26247900E-01, 0.54404600E-03, -.24432600E+00, 0.12057300E-01, -.13381200E+00, -.51713600E-01, 0.56306200E-02, -.35426800E-01, 0.10559600E+00, -.20997900E+00, 0.21535800E-01, -.74086300E-01, -.11847700E-01, 0.28698200E+00, -.74709300E-02, -.55691600E-01, 0.13828900E-01, 0.41911400E-01, 0.59784500E-01, -.17790900E-01, -.26877400E-01, -.90276300E-02, -.13039200E+00, 0.12037000E-01, 0.29804700E+00, -.24643400E+00, 0.58380200E-01, 0.57014900E-01, -.77810100E-01, 0.51684000E-01, 0.73420200E-01, 0.11635800E-01, 0.38650000E-01, 0.11514100E+00, -.12942900E-01, 0.20052800E-01, 0.19691500E-02, -.32018600E-01, -.27341700E-01, -.10900100E-01, -.11061300E+00, 0.48604900E-01, 0.95578300E-01, -.83147500E-01, -.46688700E-01, -.19971300E-02, -.55448900E-01, -.36173200E+00, -.11572000E-01, -.23436400E-01, 0.15713100E-01, -.10176400E-01, -.95634300E-03, -.33822200E+00, 0.33202600E-02, -.93106000E-01, 0.21085900E-02, -.16311500E+00, -.21761800E+00, 0.27704000E-01, 0.24468100E-01, -.17839900E-01, -.10019000E+00, -.53209900E-01, 0.75419700E+00, 0.42213100E-02, 0.11942800E-01, -.70237300E-01, 0.22008800E-01, 0.35417500E-01, -.18685200E-02, -.16084900E+00, -.12633600E+00, 0.58245300E-01, -.13051300E+00, 0.96160700E-01, 0.12078200E+00, -.18501400E+00, 0.50921600E-01, 0.21655700E-01, -.18426000E-01, 0.37712300E-01, 0.25146400E+00, 0.23972000E-01, -.43317600E+00, -.30729300E-01, -.74742500E-02, -.31050700E-02, 0.18160100E+00, 0.21467600E+00 },
        { -.24149200E+01, 0.16003300E+01, -.18673300E+02, -.30844400E+01, 0.86411000E+01, 0.17915200E+01, 0.11279500E+02, -.99029200E-01, 0.33995500E-02, -.63918400E+00, -.15790500E+01, -.82056600E+01, 0.33655000E+01, 0.33269100E+00, -.91087700E+01, -.37757600E+01, -.83189900E+01, 0.16771800E+01, 0.11257200E+01, -.21740200E+01, 0.60679100E+00, 0.65619800E+01, 0.76966400E+00, -.52394700E+01, -.21159400E+01, -.30156100E+01, -.41074000E+01, 0.85819200E+00, 0.18524100E+01, 0.17547600E+01, 0.72451600E+00, -.87640300E-01, -.46520400E+01, 0.15519700E+01, 0.56222000E+00, 0.15604000E+01, -.18363700E+00, 0.62470400E-01, -.90309000E+00, 0.12994100E+01, 0.26675400E-01, -.11590400E+00, 0.17010200E+01, 0.27304300E+01, -.46045400E+01, -.14089200E+01, -.27672800E+01, -.22454000E+00, -.69253300E+00, 0.25576500E+01, 0.82389100E+00, 0.17587500E+00, 0.64238200E+00, 0.65619100E+00, -.14577900E+01, 0.41639700E+01, 0.33239800E+00, -.13449300E+01, -.18230000E+00, 0.24448100E+01, -.21818700E+00, -.18720100E+01, 0.14559900E+00, -.97663800E+00, 0.57959000E-01, 0.51311400E+00, 0.96494900E+00, 0.58531000E+01, -.27195700E+01, 0.95353100E-03, -.36393000E+01, -.29781300E+01, 0.88207900E+00, -.20627200E-01, -.81745100E+00, 0.12412300E+01, 0.31525400E+00, 0.78434100E+00, -.54313100E+00, -.22290600E+01, -.68654500E-01, 0.90571100E+00, -.33809800E+00, -.26639800E-01, -.32348100E+00, -.16383200E+01, 0.33235900E+01, 0.48922700E+01, 0.37584000E+01, -.69855800E+00, -.29051300E+01, -.99234800E+00, 0.20890500E+01, 0.49934100E+01, -.20815700E+01, -.84553400E+01, -.21128900E+01, 0.12978900E+01, -.13596700E+01, -.43340200E+00, -.26569500E+01, 0.21245200E+01, 0.13170800E+00, -.31481400E+01, -.48207800E+00, -.31644600E+01, 0.78120500E+00, -.34263600E+01, 0.58670400E+01, -.35862400E+01, -.52389700E+01, -.37091600E+01, -.60939400E+00, 0.17095600E+00, 0.24586200E+00, -.89241500E+00, -.80313600E+00, 0.20741400E+01, -.11564700E+01, -.30942300E+00, -.26317200E+00, -.12777500E+01, -.38947500E+00, 0.67306600E+00, 0.10277500E+00, 0.13606500E+01, 0.26638600E+01, -.29657700E+01, -.16558600E+00, -.86112800E+00, -.21102100E+01, 0.16639600E+01, -.48081200E+00, 0.17374700E+00, -.13745900E+00, -.74630800E-01, 0.32256900E+00, 0.92628600E-02, -.23685200E+00, -.77612600E+00, 0.46894600E+00, -.21697300E+01, 0.16891200E+00, 0.37727000E+01, 0.46176100E+01, 0.72561500E+00, 0.22718400E+00, -.13954500E+01, 0.83495500E+00, -.72427300E+00, -.20678700E+01, 0.11716500E+01, 0.83757300E+00, -.33673900E+01, 0.13220300E+01, 0.79238500E+00, -.46836200E+00, 0.14450600E+00, 0.22115500E+00, 0.49146200E+00, 0.66506600E+00, 0.10720700E+01, 0.31881500E+00, 0.24547300E-01, -.80152900E+00, -.82375200E+00, -.20792800E+00, 0.74171900E+00, 0.49981300E-01, -.12379800E+01, 0.10400400E+01, 0.81611400E-01, -.22514200E+00, 0.75063700E+00, -.60235300E+00, 0.22410400E+00, -.43199900E+00, 0.34597700E-01, 0.20880500E+01, -.37608500E-01, -.88551000E-01, -.19066300E+01, -.53375200E-01, -.15153900E+00, 0.10185900E+00, -.90827600E+00, 0.22991600E+01, -.44014300E-01, 0.15366500E+00, -.16090800E+00, -.15476300E+00, -.14235600E+01, 0.85378800E+00, -.27035300E+00, 0.50738600E+01, 0.83703000E+00, -.36594600E+01, -.23186100E+01, 0.11505100E+01, 0.40592200E+00, 0.12487400E+01, 0.87139700E-01, -.45688600E+01, -.68348700E+01, 0.10673700E+01, -.79967700E+00, -.21187100E+01, -.58168400E+00, 0.10742700E+00, -.40591300E+01, -.57097600E+00, -.10768300E+01, -.31770800E+00, -.32966100E+01, 0.94185100E+00, -.17677100E+01, -.50292600E+00, 0.18822500E+00, -.29384500E-01, 0.12204700E+01, -.43927600E+01, 0.61428700E+00, 0.46762400E+01, 0.36525800E+00, 0.10369200E+01, -.69453300E+00, -.17601800E+00, 0.60916700E+00, 0.77941700E+00, -.20293100E+00, -.26558300E+00, 0.24147500E+00, 0.91409600E-01, -.17217500E+01, -.41578000E-01, -.52488300E+01, -.33613200E-01, 0.66655900E-01, 0.69527700E+00, 0.44804300E-01, 0.13748200E+01, 0.12738300E+01, -.61976400E+01, 0.30817400E+00, -.29297400E+01, -.21595800E-01, -.28384500E+00, 0.65894900E+00, 0.43420500E+00, 0.70803800E+00, 0.65640400E+00, -.69034600E+00, -.34814300E-01, -.38808300E+01, 0.18221600E+00, 0.51596100E+00, 0.65186000E-01, 0.99483000E+00, 0.10589800E+01, -.91122600E+00, -.20618300E+01, -.15597200E+01, -.11168900E+00, -.26371800E+00, -.60802700E+01, 0.32467800E+00, 0.16388400E+01, -.38900100E-01, 0.99498400E+00, 0.77196300E+00, -.50792300E-01, -.48050200E-01, -.89976800E+00, 0.26587700E-01, -.11427000E+01, 0.10390400E+02, -.30755900E+00, -.78075900E-01, -.10624900E+01, -.28749200E-01, 0.26283400E+00, 0.69253400E+00, 0.24012100E+01, -.22802900E+01, 0.32727400E+01, -.65412400E+01, 0.35909200E+01, -.15197900E+02, -.83770300E+01, 0.14424500E+01, 0.58198300E-01, -.19028400E+01, 0.20576700E+01, 0.26097400E+02, 0.43541200E+00, -.31336900E+02, -.28618500E+01, -.58310900E+00, 0.10305000E+00, -.15848200E+01, -.20082900E+01 },
        { -.20521500E+00, 0.67673100E+00, -.21906500E+01, 0.18414900E+00, 0.67910400E+00, 0.15360000E+00, 0.10149500E+01, 0.10709300E+01, 0.11135200E+00, -.86700500E-01, -.18131800E+00, -.15512400E+01, 0.62679100E+00, -.23815800E-03, -.31807200E+00, 0.14305300E+00, -.99024000E+00, 0.16334200E+00, -.49876500E+00, 0.15278700E+00, -.34541700E+00, -.14796300E+00, 0.30813200E+00, -.71096600E+00, -.67081000E+00, -.34574800E+00, -.34938800E+00, 0.37203400E+00, 0.99728400E-01, 0.91347400E-01, 0.15177500E+00, 0.14153400E+00, -.74777800E+00, -.23405900E-01, 0.81134100E-01, 0.72719200E-01, -.24556400E-01, -.28263000E+00, 0.87311200E-01, 0.25753000E-01, 0.80697700E-01, -.22763200E+00, -.14888800E+01, -.11363700E+00, 0.22221600E+00, 0.11930000E+00, 0.58106600E+00, -.24304200E-01, -.75065400E-02, 0.73705900E-01, 0.58205600E+00, -.36050800E+00, -.20407700E-01, -.29825900E+00, -.23432600E+00, 0.15995700E+00, 0.23372100E+00, -.36966800E+00, 0.51242100E-01, 0.23291200E+00, -.28628400E+00, -.11935200E+00, -.79647300E-01, 0.12316500E+00, 0.74375600E-01, 0.13891000E-02, -.88323500E-01, 0.27734900E-01, 0.14227400E-01, 0.55539300E-03, -.20590000E+00, -.26125600E+00, 0.75097500E-02, 0.15349900E-01, -.89117400E-01, 0.46961700E-01, 0.20405600E+00, 0.18378900E+00, -.14359300E+00, -.32529100E+00, -.21831100E-01, 0.39933100E-01, 0.79491700E-01, -.21972500E-01, 0.66359100E-02, -.54938200E-01, 0.26677600E+00, 0.21199000E+00, -.18024800E+00, 0.25857700E-01, -.40563200E+00, -.21558000E+00, 0.21799600E+00, 0.10879000E+01, -.17193100E+00, -.95287400E+00, -.15908100E+00, 0.11941000E+00, -.83441700E-01, -.66676500E-02, 0.18299100E+00, 0.32930400E+00, 0.19299300E-01, -.31682300E+00, -.14977600E+00, -.33679800E+00, 0.23101700E-01, -.12060700E+00, 0.20908400E+00, -.24167600E+00, -.62462700E+00, -.63868200E+00, -.39023000E-01, -.33049900E-02, -.51553000E-01, -.90636300E-01, 0.51319100E-02, 0.19758400E+00, -.90527400E-01, 0.43914800E-02, -.96065300E-02, 0.43426400E+00, -.42744600E-01, 0.14759000E+00, 0.50068500E-02, 0.31987100E+00, 0.23927400E+00, -.61330300E-01, 0.29608400E-01, -.39900900E-02, -.81955800E-01, -.14306600E+00, -.18943500E-02, -.14854700E-01, -.41782800E-01, -.87875900E-03, -.18960000E+00, -.26242900E-01, -.69416600E-01, 0.73639300E-01, 0.19568600E-01, 0.13756100E+00, -.27441600E-01, 0.14017900E+00, 0.81447000E-02, 0.47095800E-01, 0.32762300E-01, -.32896000E-01, -.83538600E-01, -.27416300E-01, -.11335900E+00, 0.10965100E+00, -.31402900E-01, -.33571400E+00, -.29972400E+00, 0.49884700E-01, -.24026300E+00, 0.78061800E-02, -.24330200E-01, 0.95459900E-01, 0.21253100E+00, 0.10693900E+00, 0.85020000E-01, -.27367900E-01, 0.33642100E-01, -.13469900E+00, -.18196400E-02, 0.28885700E-01, 0.59885900E-03, -.15610500E+00, 0.35315000E-01, 0.44121300E-01, -.11115900E+00, 0.76283600E-01, -.38625900E-01, 0.26606400E-01, 0.51413100E-02, -.57241900E-03, -.64852800E+00, -.47342100E-03, 0.50704000E-01, -.61128200E-01, -.65105700E-01, -.77907800E-02, -.60207700E-01, -.98903000E-02, 0.60568500E-01, 0.42376300E-01, 0.10069400E-01, 0.25664000E-01, 0.66071200E-04, 0.64794400E-01, -.38764900E-01, 0.58701000E-02, 0.13253200E+00, 0.44310600E-01, 0.17298200E+00, -.25530200E-01, 0.23123400E-01, -.49005900E-02, 0.63355500E-02, 0.65420400E-03, 0.35338800E+00, -.43082500E+00, -.55736600E-02, -.32655100E-01, 0.34352900E-01, 0.91357400E-01, -.87819500E-02, 0.38777500E-01, 0.49739200E-02, -.11489600E+00, -.95494000E-04, -.54503200E-01, -.49245700E-02, 0.31012900E-01, -.41528800E-02, -.11154300E-01, 0.51004700E-02, 0.61220500E-02, 0.22915300E-01, -.40384800E-02, -.14759600E+00, 0.86653600E-02, -.10025100E+00, 0.66285800E-02, 0.19203300E-01, -.68329000E-03, 0.27753600E-01, 0.17673300E-01, -.12741300E-01, 0.29592400E-01, -.64317300E-02, -.50624000E-01, -.10087300E-01, 0.50194500E-01, -.17455100E+00, 0.16133000E-01, -.34648700E-01, -.11527500E-01, -.80875200E-01, -.30898400E-01, 0.63329400E-01, 0.49574700E-02, 0.23811900E-01, 0.20562200E-02, -.12387600E-02, -.12165000E-01, -.53698100E-02, -.11027700E-01, 0.16882200E-01, -.35815800E-01, 0.29838600E-02, 0.16204200E+00, 0.18089100E-01, -.68898800E-02, -.91746700E-03, 0.82441500E-02, -.23431000E-01, -.94520500E-02, -.42490400E-01, -.42130400E-01, 0.95606400E-02, 0.55924400E-02, -.14264800E+00, -.17406900E-02, -.19446900E-02, 0.15538600E-02, 0.28509500E-01, 0.73522700E-01, -.18997100E-01, -.27423900E-02, 0.66468400E-01, 0.17798000E-01, 0.31385900E-01, -.31513800E+00, 0.20349100E-02, -.26503200E-01, 0.12377000E-01, 0.23819800E-01, -.13379200E-01, 0.23770600E-03, 0.92493600E-03, 0.26251700E-01, -.64706600E-01, 0.24152900E-01, 0.73693200E-01, -.13305600E+00, 0.38321400E-02, 0.46793300E+00, -.14277100E-03, 0.10110800E-02, -.11364600E-01, -.76732300E-01, 0.19914100E-01, 0.74488500E-01, -.61486700E-03, 0.49555200E-02, 0.39185000E-01, 0.97705600E-02, 0.21231300E-01 },
        { 0.27393800E+00, -.57026700E+00, 0.25627100E+01, 0.19351400E+00, -.11795700E+01, -.13846300E+00, -.93136000E+00, 0.30068700E+00, 0.34549600E+00, -.15589200E+00, -.12458000E+00, 0.13346100E+01, -.41968400E+00, 0.81387300E-01, 0.17205900E+00, 0.31732300E-01, 0.75195400E+00, -.16883000E+00, -.30230100E+00, -.14766800E+00, 0.26247200E+00, 0.53272000E+00, -.12082000E+00, 0.22561300E+00, 0.23509100E+00, 0.37245700E-01, 0.23430900E+00, -.11904300E+00, 0.48721900E-01, -.23857400E+00, 0.47084700E-01, -.48914900E-01, 0.42964600E+00, -.13175600E+00, -.18797100E+00, 0.15297600E-01, 0.25477300E-01, -.97416900E-01, -.26698300E+00, -.91945000E-02, -.41483200E-02, 0.44739000E+00, 0.93778400E+00, 0.72720700E-01, -.33328300E+00, -.17211100E+00, -.45901700E+00, 0.39048700E-01, 0.85355000E-02, -.54016500E-01, -.12821000E+00, -.20380000E-01, -.57944500E-02, -.60917200E+00, 0.16613800E+00, -.30869400E+00, -.47988800E-01, 0.49610400E-01, -.60025300E-01, -.22177500E+00, 0.49846200E-01, 0.91545800E-01, 0.23428800E-01, -.81029200E-02, -.23906900E-01, -.37210900E-03, 0.34718000E-01, -.32171400E+00, 0.32818500E-01, -.24810300E-03, 0.32012500E+00, 0.36924300E+00, 0.42251300E-02, 0.45630800E-01, -.10097200E+00, -.29481900E-01, -.21070000E-01, -.14130900E-02, 0.16170900E+00, 0.11517000E+00, 0.42454600E-02, -.80605200E-02, 0.80044500E-01, -.40907300E-01, -.37200500E-01, 0.77322600E-01, -.16576400E+00, -.31526000E+00, -.10123900E+00, 0.19101200E-01, 0.22368300E+00, 0.78277600E-01, -.55771000E-01, -.23257100E+00, 0.10422300E+00, 0.66727400E+00, 0.94308300E-01, -.12063300E+00, -.18383600E+00, -.77359700E-02, 0.72932500E-01, -.11331700E+00, -.75780000E-02, 0.20840000E+00, 0.62228400E-01, 0.13927800E+00, -.10986100E+00, 0.20092900E+00, -.36961500E+00, 0.23375700E+00, 0.61224900E+00, 0.39145400E+00, -.54992200E-01, -.12988500E-01, 0.49875800E-01, 0.23198200E+00, 0.76150100E-01, -.56217400E+00, -.21931300E-01, 0.18828400E-02, -.72625800E-01, -.11789100E+00, 0.25257400E-01, 0.21767400E+00, 0.89922000E-02, 0.19052500E+00, 0.16259300E+00, 0.35967800E-01, 0.16280400E-01, -.22999100E-01, 0.94577400E-01, 0.14907200E+00, -.14080300E-01, -.84064800E-01, 0.28733300E-01, -.41494300E-02, -.24547000E+00, 0.77299700E-01, -.34502700E-01, -.19305800E+00, 0.95188200E-01, -.97110700E-01, -.15574400E-01, -.13595700E+00, -.19499200E+00, -.68446200E-01, -.37984300E-02, 0.71612100E-01, -.67359800E-01, -.22850200E-01, -.39383000E-02, -.50846100E-01, -.27641400E-01, 0.36672300E+00, 0.27987200E+00, -.11701800E+00, 0.27505600E+00, 0.13113900E-01, -.30368100E-01, -.17774000E+00, -.11642300E+00, 0.17416700E+00, -.48032200E-01, 0.60850200E-01, -.91731400E-01, -.12255900E+00, 0.28716500E-01, 0.13185200E-01, -.12106900E-01, 0.18909900E-01, -.53815200E-01, -.25433400E+00, 0.21248700E-01, 0.19525200E+00, 0.65495200E-01, -.40551600E-01, 0.42385700E-01, -.10817600E-01, -.14685400E+01, -.23665300E-03, 0.13461800E+00, 0.21535800E+00, 0.19044000E+00, 0.15596100E-01, -.12075100E+00, -.18483800E+00, 0.39187900E+00, -.11220200E+00, -.38489900E-01, -.83421300E-02, 0.67447300E-04, -.17652100E+00, 0.66141600E-01, 0.22063200E+00, -.49698200E+00, -.34739700E+00, -.39293000E+00, 0.18870900E+00, -.20792700E+00, 0.18940100E-01, 0.24474600E+00, -.23863800E-01, 0.14063900E+01, 0.39955600E+00, 0.84469900E-01, 0.27948800E+00, -.19978000E-01, -.16394300E+00, 0.26597000E-01, 0.43277900E+00, -.27554200E-01, 0.78935500E-01, -.74433900E-04, -.92471400E+00, 0.69310300E-01, -.76527300E-01, 0.66102500E-01, -.20678600E-01, -.16450900E-01, -.51998000E-01, 0.12343200E+00, -.23648600E-01, -.54618800E+00, -.56763500E-03, 0.44368700E-01, 0.75086600E-01, 0.94018200E-01, -.52181100E-01, -.17895500E-03, 0.29044300E-01, -.20934200E-01, -.18170400E+00, 0.44434000E-01, 0.15577900E+00, 0.67480400E-01, 0.28291600E+00, 0.11077200E+00, 0.13016900E-01, -.65019000E-01, -.21589700E-01, 0.22618400E+00, 0.39237100E-01, 0.13626400E+00, 0.31186400E-01, -.10296500E+00, 0.67954100E-02, -.68475200E-03, 0.10116300E-01, 0.75444100E-02, -.97774500E-02, -.36266000E-01, 0.29601800E-01, -.18041900E-01, 0.22647100E+00, 0.59968100E-02, -.12889300E-01, -.23780700E-02, -.27509300E-01, -.19738800E-01, 0.18805700E-01, 0.10260200E+00, 0.61719400E-01, -.22981300E-01, -.10018800E-01, 0.22097100E+00, -.24437800E-02, -.33715700E-01, 0.17105500E-02, -.60516700E-01, -.12247200E+00, 0.22738200E-01, 0.28928200E-01, -.52081200E-01, -.11316100E-02, -.23460600E-01, 0.11916600E+01, 0.95795600E-03, 0.16778300E-01, -.27669000E+00, 0.37797500E-01, 0.12113400E-02, 0.27124200E-01, 0.48000400E-02, -.13356200E+00, 0.33197500E+00, -.79212600E-01, 0.19461600E+00, 0.22152500E+00, 0.58419600E-01, 0.26430600E+00, 0.80198300E-01, 0.91309900E-01, -.20425600E+00, -.19707100E+01, 0.45478000E-01, 0.22766500E+01, 0.21162000E+00, 0.19701800E-01, -.26991300E-01, 0.16427600E+00, 0.18353600E+00 },
        { -.33794000E+00, -.18997000E+00, -.16056700E+01, -.32128100E+00, 0.11467400E+01, 0.21809500E+00, 0.11180400E+01, -.55842800E+00, -.25992900E+00, 0.12434900E+00, 0.74055100E-01, -.13042100E+01, 0.38306200E+00, -.14546000E+00, -.36036300E+00, -.16109700E+00, -.95241900E+00, 0.19180500E+00, 0.35681000E+00, -.84071200E-03, -.18327100E+00, -.13920300E+00, 0.62011900E-01, -.48613800E+00, -.14027900E+00, -.85352300E-01, -.34511500E+00, 0.26277400E-01, 0.64817500E-01, 0.25054300E+00, -.26463000E-01, 0.95970100E-01, -.32792200E+00, -.21873900E-02, 0.19405200E+00, 0.58747200E-01, -.24682100E-01, -.16032700E-01, 0.38347100E-01, 0.60799700E-01, 0.28592300E-01, -.46297500E+00, -.45437700E+00, 0.25580300E-01, -.68786800E-01, 0.19428000E-01, 0.10732900E+00, -.37617100E-01, 0.88805200E-02, 0.50886200E-01, -.10339900E+00, 0.21609500E+00, 0.45702300E-01, 0.58366300E+00, 0.34659800E-01, 0.24788900E+00, 0.21979600E-01, -.49901100E-01, 0.83325000E-01, 0.13086700E+00, 0.99815600E-01, -.31140300E-01, -.16543700E-01, -.45327700E-01, -.84084500E-03, -.46533800E-01, -.30504300E-02, 0.37267500E+00, -.10046900E+00, -.84485900E-03, -.33289800E+00, -.19184200E+00, 0.11108100E-01, -.32474800E-01, 0.13270300E-01, 0.12641800E+00, -.53163000E-02, -.11175400E+00, -.56367700E-01, -.31031400E-01, 0.38447600E-03, 0.55350800E-01, -.30121700E+00, 0.30399300E-01, -.22496500E-01, -.91499300E-01, 0.26033700E+00, 0.16045900E+00, 0.36703100E+00, -.26292100E-02, -.49110300E+00, -.51492100E-01, 0.30809600E+00, 0.18973600E+00, -.10638000E+00, -.64048200E+00, -.12579200E+00, 0.89990500E-01, -.12429100E+00, -.40454300E-02, -.29177900E+00, 0.13149500E+00, 0.95163800E-02, -.35800200E+00, -.13352600E+00, 0.15945200E+00, 0.19934200E+00, -.15744200E+00, 0.24697200E+00, -.29953400E+00, -.34894300E+00, -.17921200E+00, -.54614300E-01, 0.10739200E-01, -.41486900E-01, -.11216800E+00, -.31454000E-01, 0.22540700E+00, -.16401500E+00, 0.40191700E-01, -.13815400E+00, 0.17516300E+00, -.56730800E-02, 0.22010100E-01, -.39082900E-02, 0.13347900E+00, 0.22693000E+00, -.14604100E+00, -.23602200E-03, 0.13049300E-01, -.13123800E+00, 0.30763200E-01, -.66848300E-02, 0.64128200E-01, -.44343000E-01, 0.64203400E-03, -.16771200E+00, -.46383400E-01, -.54841800E-01, 0.13959700E+00, 0.31713300E-01, 0.10848600E+00, -.13804400E-01, 0.28620000E+00, 0.35126500E+00, 0.56715700E-01, 0.43011600E-01, -.16095900E+00, -.27177800E-01, -.12989500E-01, -.13471200E+00, 0.13055700E+00, -.24330300E+00, -.38030500E+00, 0.44395100E-01, 0.40903100E-01, -.15311000E-01, -.37605600E-01, 0.88611100E-01, 0.19258400E-01, 0.11553000E+00, 0.51323200E+00, 0.68608500E-01, -.18563400E-01, -.45135300E-01, -.10124600E+00, -.36737700E-01, -.40060400E-01, 0.13579000E-01, -.12751800E+00, 0.34916400E-02, 0.23804800E+00, 0.61736700E-01, -.45920700E-01, 0.51710500E-01, 0.40903900E-02, -.10739700E-01, 0.13241800E-01, -.93652000E-01, 0.33692300E-03, -.40511500E-01, -.35025000E+00, -.27805700E+00, -.31209800E-01, -.10622700E+00, -.71268700E-01, 0.46024000E-01, 0.13762800E+00, 0.43019500E-01, 0.74965000E-01, 0.59165000E-03, 0.12677400E+00, -.55320600E-01, 0.57283000E-01, 0.28428100E+00, 0.12904700E+00, 0.54363200E+00, -.12551700E+00, 0.46301700E-01, -.30318100E-01, -.81067200E-01, -.11085300E-01, -.51265400E+00, -.53490800E+00, -.23369300E-01, -.83158000E-01, 0.47996400E-01, 0.40876900E+00, -.44591200E-01, -.50372200E-01, 0.46102600E-01, -.41455800E+00, 0.86628900E-03, 0.49396500E+00, 0.10045100E+00, 0.19749400E-01, -.17412000E-01, -.42971400E-01, 0.44898100E-01, 0.50259400E-01, -.13866700E+00, 0.18305000E-01, 0.20924500E-02, -.10632400E-02, 0.25860400E+00, -.51245800E-01, -.90337400E-01, 0.23065600E-01, 0.29274100E-01, 0.42490300E-03, 0.82313100E-02, 0.11560000E+00, -.34690000E-01, -.14611600E+00, -.41876500E-01, -.72606400E+00, -.27538400E+00, 0.36627500E-01, 0.57628300E-01, -.53774600E-01, 0.10991100E+00, 0.10346700E-01, -.68695300E-01, 0.80785400E-02, 0.29966400E-01, -.11961400E-01, 0.89946900E-03, -.89875700E-01, -.16178100E-01, 0.77598400E-02, -.46764900E-01, -.75791400E-01, 0.56392600E-01, 0.50818900E+00, -.49167700E-02, -.33927900E-01, 0.10118700E-02, 0.92270000E-02, -.17150000E+00, -.64678500E-01, -.24723600E-01, -.62582200E-01, -.74952800E-02, 0.20350200E-02, -.16850700E+00, -.12879600E-02, 0.17451700E-01, 0.94368300E-04, -.75535100E-02, -.34239100E-01, -.34169000E-02, 0.61928200E-01, 0.10435800E+00, 0.25908700E-01, 0.80460500E-02, -.46500200E+00, 0.13473700E-01, -.10566600E+00, 0.35175300E+00, 0.15989200E-01, -.13377400E-01, 0.96588100E-03, 0.15631400E-01, 0.24565900E-01, -.24234800E+00, -.75621800E-01, -.23496900E-01, 0.36854600E+00, -.13359800E-01, 0.85222200E-01, 0.26907400E-01, 0.25527500E+00, 0.23297800E-01, 0.45105100E+00, -.19362400E-01, -.50249500E+00, -.69281900E-01, -.24751300E-02, 0.94167800E-01, -.10402600E+00, -.13955300E+00 },
        { -.12823200E+00, 0.11395900E+00, -.13613600E+01, -.29873100E-01, 0.37403500E+00, 0.10688600E+00, 0.48937500E+00, 0.48800200E-01, 0.76618700E-01, 0.42533300E-02, 0.27916200E-01, -.49503400E+00, 0.14555800E+00, 0.29764400E-01, -.25981900E+00, 0.46905400E-02, -.29033700E+00, 0.78042500E-01, -.10373300E+00, -.24000200E-01, -.87497900E-01, -.18062600E-01, 0.63073600E-01, -.29443500E+00, -.20961300E+00, -.12277300E+00, -.17776000E+00, 0.19206800E+00, 0.54925500E-01, 0.51950700E-01, 0.64001700E-01, 0.18235000E-02, -.19475700E+00, 0.14687900E+00, 0.16053400E-01, -.17739300E-01, -.71462600E-02, 0.32218700E-02, 0.26407700E-01, 0.69261200E-02, 0.73288300E-02, -.60321700E+00, -.61747600E+00, -.68866200E-01, 0.14454400E+00, 0.27052100E-01, 0.55817100E-01, -.49023600E-02, -.13155900E-01, 0.49768200E-01, -.65894200E-01, 0.20981500E+00, 0.15675900E+00, -.83844600E-01, -.74704300E-01, 0.10962000E-01, -.16767100E-01, -.70138300E-01, -.50447300E-02, -.26097900E-01, 0.94047200E-01, -.40418600E-02, -.47411500E-01, -.41035600E-01, -.17534300E-01, 0.30201700E-01, 0.37338000E-01, 0.19743900E+00, -.18310900E+00, -.16243600E-02, -.51142800E-01, -.71297400E-01, 0.48615400E-01, 0.33893700E-02, -.43843100E-01, 0.88145700E-01, -.28843600E-01, -.82904400E-01, 0.13234400E-01, 0.55491000E-03, 0.27790400E-02, 0.75294100E-02, 0.50869400E-01, 0.32936900E-01, -.47663500E-01, 0.52294700E-01, -.43740400E-01, -.21022400E-01, 0.21930500E+00, 0.10081200E-01, -.34904800E-01, 0.28602500E-01, 0.23635400E-02, -.21942200E+00, -.25161300E-02, -.26088300E+00, 0.96048900E-01, -.10020700E+00, -.20451800E-01, -.69361700E-01, 0.12461300E+00, 0.27008600E-01, 0.12969100E-02, -.17107800E+00, -.79374400E-01, -.12239800E+00, 0.53937700E-01, -.75180700E-01, 0.80160000E-01, -.32177700E+00, -.33079200E-01, -.19923600E-01, -.89495700E-01, 0.17919800E-01, 0.24515600E-01, -.33671300E-01, 0.93424300E-02, 0.29056700E+00, -.70011000E-01, -.87471900E-02, 0.29758400E-01, 0.16559500E+00, -.31654000E-01, 0.29233900E-01, 0.87281400E-02, 0.26785500E+00, 0.19603400E+00, -.11171200E+00, 0.22367200E-01, -.20165700E-02, -.10207500E+00, 0.31642800E-01, -.19728700E-01, 0.50668000E-02, -.10147700E-01, -.35509300E-02, -.85004500E-01, -.21061600E-01, -.51860000E-01, -.11281700E+00, 0.27012600E-01, 0.38267200E-01, 0.28251900E-01, 0.21805300E+00, 0.15416700E+00, 0.26492600E-01, 0.26504600E-01, -.68870700E-01, 0.28285600E-01, -.77996300E-01, -.90453000E-01, 0.58472700E-01, -.42760100E-01, -.62423500E-01, 0.11512700E+00, -.28505100E-01, 0.67583400E-01, 0.62676100E-02, 0.29723800E-02, -.14857200E-01, 0.56161000E-02, 0.27472000E+00, 0.26261600E-01, -.95532200E-03, -.21830500E-01, -.61124300E-01, 0.40117600E-02, 0.64111500E-02, -.53907000E-02, -.49666100E-01, -.32653000E-01, -.46560500E-01, -.56482800E-01, -.25449700E-01, -.16527000E-01, -.12879200E+00, 0.44526200E-02, 0.58553800E-02, -.22151200E+00, -.22942300E-03, -.31299600E-01, -.11594900E+00, -.27796800E+00, 0.35495800E-01, 0.79792800E-02, -.41777400E-01, 0.26953400E+00, 0.32964600E-01, -.50690400E-02, -.14004400E-01, -.32363100E-03, -.69913400E-01, -.16900600E-01, 0.53763800E-01, 0.13262300E+00, 0.15012900E-01, -.10442700E+00, -.13209600E+00, 0.98676000E-01, -.81055700E-02, 0.22321100E-01, 0.11689600E-01, 0.26177700E+00, 0.71697800E+00, 0.10899900E-01, -.16523500E+00, 0.10588000E+00, 0.17269400E+00, -.23855800E-02, 0.29972100E-01, 0.22698600E-01, -.15221400E-01, -.25264700E-03, 0.37693800E+00, -.37274100E-01, 0.38371200E-01, -.18038500E-01, -.56374200E-02, -.12038500E-01, 0.29807000E-01, -.13772700E-01, 0.11090500E-01, -.25715500E-01, 0.48182700E-02, -.11133900E+00, 0.19553500E-01, 0.80590500E-01, 0.38296800E-01, 0.84100700E-02, -.13717600E-01, -.98458700E-02, -.82619300E-02, 0.51516700E-02, -.37643000E-01, 0.31304800E-02, 0.38427800E+00, -.19993500E-02, 0.11739500E-02, -.27608700E-01, -.86712500E-03, 0.31014200E-01, -.53140700E-01, 0.50793900E-01, 0.60211700E-02, 0.21161900E-01, 0.98989800E-03, 0.12988900E-01, 0.35415600E-01, -.69374900E-02, -.58854800E-02, 0.33076600E-01, -.28973000E-01, -.89585200E-02, -.42784800E-01, 0.18803300E-01, -.56737500E-02, -.59053100E-03, 0.14745200E-01, 0.32853300E-01, -.20191700E-01, -.60565000E-01, -.50112500E-01, 0.15460900E-01, 0.63028800E-02, -.29655400E+00, 0.19636300E-02, 0.11217600E+00, 0.61124000E-03, -.68461700E-02, 0.69802300E-01, -.89332100E-02, 0.70905700E-02, 0.13518200E-01, 0.31477700E-02, 0.19910600E-01, -.29726000E+00, -.47534000E-02, 0.50819000E-02, 0.91643500E-01, -.22765400E-02, -.85397200E-02, 0.10185700E-01, -.34183300E-01, -.26067400E-01, 0.19921000E-01, -.13686400E+00, 0.81376100E-01, 0.56058700E-02, -.83521400E-02, -.41366600E-01, 0.14666500E-01, -.11834200E+00, 0.16318200E+00, 0.42412800E+00, -.35868100E-02, -.49601800E+00, -.55179900E-01, -.17323800E-02, 0.54342200E-02, -.36766900E-01, -.49424400E-01 },
        { 0.44022300E+00, -.62601200E+00, 0.37673200E+01, 0.42599600E+00, -.17260500E+01, -.25536400E+00, -.16529100E+01, 0.28338200E+00, 0.32684000E+00, -.70702500E-01, 0.25270400E-01, 0.18424500E+01, -.66648200E+00, 0.11666300E-01, 0.83054900E+00, 0.32154200E+00, 0.13405900E+01, -.27322900E+00, -.38404400E+00, 0.35034200E-01, 0.18158100E+00, -.30561900E+00, -.19534300E+00, 0.67595200E+00, 0.40625500E+00, 0.29981300E+00, 0.61138000E+00, -.13100300E+00, -.14608800E+00, -.39214100E+00, -.58181700E-01, -.60740800E-01, 0.84207800E+00, -.21912900E+00, -.21909200E+00, -.12097700E+00, 0.44721200E-01, -.12640100E+00, -.17146100E+00, -.16444700E+00, -.25069700E-01, 0.29444200E+00, 0.70516400E+00, -.13360500E+00, 0.92607200E-01, -.13147900E-01, -.14383900E+00, 0.60699900E-01, 0.24690200E-01, -.23363700E+00, -.29513000E+00, 0.11196300E+00, 0.46100900E-01, -.66570100E+00, 0.18092600E+00, -.63817500E+00, -.16416900E+00, 0.17352300E+00, -.91525300E-01, -.39400500E+00, 0.62327300E-01, 0.23413500E+00, -.28887800E-02, 0.48424200E-01, -.27311400E-01, -.10475000E+00, -.82855500E-01, -.70632100E+00, 0.24732700E+00, -.15088400E-02, 0.74743600E+00, 0.57347800E+00, -.60051700E-01, 0.58683800E-01, -.47466000E-01, -.85768300E-01, -.41039300E-01, -.13049100E+00, 0.20282100E+00, 0.29386100E+00, 0.98431600E-02, -.81134100E-01, 0.12039000E+00, -.36954800E-01, 0.19336200E-01, 0.18700400E+00, -.47523900E+00, -.64011600E+00, -.61879900E+00, 0.46592800E-01, 0.53896800E+00, 0.16567700E+00, -.36289900E+00, -.56073100E+00, 0.27242800E+00, 0.12970400E+01, 0.25102000E+00, -.18307600E+00, 0.79908900E-01, 0.76020600E-02, 0.39284700E+00, -.32738600E+00, -.18117800E-01, 0.50341600E+00, 0.11273300E+00, 0.22539300E+00, -.25550700E+00, 0.45017800E+00, -.91495400E+00, 0.56880100E+00, 0.94350900E+00, 0.58002700E+00, 0.44854200E-01, -.16062200E-01, -.24455700E-01, 0.23016800E+00, 0.15815800E+00, -.44630900E+00, 0.12104900E+00, 0.44647700E-01, 0.93331000E-02, 0.17927500E-01, -.23515400E-02, 0.18116700E-01, -.37109700E-02, -.52902400E-01, -.24500800E+00, 0.15631600E+00, 0.10735200E-01, -.43340100E-02, 0.19739900E+00, -.62259100E-02, 0.27608800E-01, -.62915300E-01, 0.10496200E+00, 0.33871500E-02, -.39096800E-01, 0.85566100E-01, 0.86288700E-02, -.33323500E-01, 0.10715300E-01, -.32524400E-01, -.69542200E-01, -.45829000E+00, -.54268700E+00, -.10453900E+00, -.28358300E-01, 0.15495800E+00, -.29239700E-01, 0.39291000E-01, 0.15918600E+00, -.12214400E+00, -.90189600E-01, 0.51169300E+00, 0.37058200E+00, -.11297800E+00, 0.30982700E+00, 0.17154100E-01, 0.45561800E-01, -.12466400E+00, -.12783100E+00, -.28294100E+00, -.26515800E-01, 0.37378400E-01, -.71135700E-01, 0.22230300E+00, 0.38375100E-01, 0.43556700E-02, -.17717100E-02, 0.15140600E+00, -.50884700E-01, -.19980100E+00, 0.93066100E-01, 0.10489900E+00, 0.62860900E-01, -.14810400E-01, 0.47444900E-01, -.16081900E-01, -.68063900E+00, -.34963800E-03, 0.91259200E-01, 0.26024900E+00, 0.27313500E+00, 0.14633400E-01, -.42057800E-01, -.57570300E-01, -.60682300E-01, -.86183300E-01, -.38003700E-01, -.30926300E-01, 0.40799600E-03, -.39378300E-01, 0.28582900E-01, 0.36873000E-01, -.57350800E+00, -.19530200E+00, -.21718700E+00, 0.25133600E+00, -.34041400E+00, 0.52158400E-02, 0.31151800E+00, -.36390600E-01, 0.17498000E+01, -.75919400E+00, 0.19040600E-01, 0.29381700E+00, -.66980100E-02, -.15232600E+00, 0.20279400E-01, 0.61464100E+00, -.19996800E-01, 0.13327900E+00, 0.94909200E-03, -.11060700E+01, 0.13824000E+00, -.11871800E+00, 0.63572100E-01, -.61059300E-01, -.28603400E-02, -.10762300E+00, -.14435700E+00, -.58979400E-01, -.33252000E+00, -.13732700E-01, 0.50654100E+00, 0.55647000E-01, 0.94321500E-01, -.56602400E-01, -.41935000E-01, 0.39296900E-03, -.26508400E-01, -.27067300E+00, 0.54073200E-01, 0.28391300E+00, 0.10123500E+00, 0.15988600E+00, -.14089800E-01, 0.26610100E-01, -.68790500E-01, -.59142600E-01, 0.32426200E+00, 0.55814300E-01, 0.46484600E+00, 0.16113300E-01, 0.28536800E-01, 0.43311200E-02, 0.27486900E-01, -.10602600E-01, 0.26268400E-01, 0.26669500E-01, -.59495600E-01, 0.18234000E-01, 0.14742300E-01, 0.18373100E-01, -.46781400E-01, -.12300800E-01, 0.15100400E-04, -.33346400E-01, 0.62923900E-01, 0.39411000E-01, 0.17297600E+00, 0.11941000E+00, -.30172300E-01, -.78061600E-02, 0.42772400E+00, -.85909600E-02, -.30420400E-01, -.26558700E-02, -.47972300E-01, -.13164600E+00, 0.30260600E-01, 0.40324300E-01, -.13369800E+00, -.27016300E-01, -.28985600E-01, 0.19625500E+01, -.46941500E-02, 0.36718700E-01, -.13295500E+00, 0.72247600E-01, 0.32965000E-04, 0.58143400E-01, 0.13836400E+00, -.20880500E+00, 0.63459200E+00, -.25699200E+00, 0.19668900E+00, -.53483100E+00, 0.14491600E+00, 0.57519300E+00, -.11151000E-01, 0.68836100E+00, -.26086100E+01, -.32633800E+01, 0.94740900E-01, 0.37101800E+01, 0.30856800E+00, 0.24984100E-01, -.11924800E+00, 0.39854900E+00, 0.46724800E+00 },
        { -.24223000E+00, 0.95613500E-01, -.16475400E+01, -.57064000E-01, 0.89310500E+00, 0.29300700E+00, 0.16173100E+01, 0.41137900E+00, 0.29039700E+00, 0.32008300E+00, -.17245300E+00, -.18203700E+01, 0.18131100E+00, -.63396500E+00, -.72364700E+00, -.89546700E-01, -.11850500E+01, 0.20201400E+00, -.37097000E+00, -.69106200E-01, -.19200500E+00, -.12629800E+01, 0.32922200E-01, -.61737500E+00, -.52424300E+00, -.28597700E+00, -.47200000E+00, -.93025900E-01, -.53609100E-01, 0.28867800E+00, 0.86904700E-01, 0.17911800E+00, -.24775400E+00, 0.26827000E-01, -.81019100E-01, 0.86233200E-01, -.23743500E-01, 0.12252200E+00, -.64585900E-01, 0.19556200E+00, -.10523400E+00, -.56198900E+00, -.36770400E+00, -.65098900E-01, 0.24598700E+00, 0.35540900E-02, -.24776600E+00, -.14030300E-01, 0.10302700E+00, -.49291500E-01, 0.25560600E+00, -.19190400E+00, 0.79454100E-01, -.64767700E-01, -.17861400E-01, 0.87114300E-01, 0.21803200E+00, -.22235500E+00, 0.55218100E-01, 0.20003500E-01, 0.90982800E-01, -.36179900E-01, 0.78614400E-01, -.28506100E+00, -.23482500E-01, 0.95296400E-01, 0.26756200E-02, 0.22406300E+00, -.26948400E-01, -.22194100E-02, -.50652700E+00, -.77056400E+00, 0.73622500E-01, -.34596500E-01, 0.20804600E-01, 0.12935300E+00, -.97911500E-01, 0.11693900E+00, -.15326600E+00, -.81062900E-02, 0.57882300E-02, 0.46091800E-02, -.17898200E-01, -.15359000E-01, -.44052900E-01, -.98799700E-01, 0.15498300E+00, 0.30822100E+00, 0.74769900E+00, -.98742000E-02, -.22003400E+00, -.17093900E-01, 0.28546900E+00, -.55507200E+00, -.12943900E+00, -.68962500E+00, 0.16237100E+00, -.56177400E-01, -.15586000E+00, -.64653000E-01, -.13172200E+00, 0.91486200E-01, 0.13080200E-01, -.32821300E+00, -.12493600E+00, -.28955500E+00, 0.23537900E-01, -.49509400E+00, 0.74248000E+00, -.31702400E+00, -.24343700E+00, -.15299300E+00, -.86083600E-01, -.17455300E-02, 0.50127800E-01, -.11920400E+00, -.37347900E-01, 0.88380500E+00, 0.34891800E-01, -.33388300E-01, 0.96218500E-01, -.36531300E-01, 0.36737000E-01, -.68973600E-02, 0.18150800E-01, 0.15681600E+00, 0.41541500E+00, -.29386600E+00, -.64426300E-02, 0.42533000E-01, -.24829600E+00, -.26043400E-01, -.30933000E-01, -.10741200E-02, 0.33589700E-01, -.76109600E-02, 0.38541800E-01, -.58318400E-01, -.51659400E-01, -.12778500E+00, 0.42971700E-01, -.66491400E-01, 0.68292600E-01, 0.28677700E+00, 0.43383300E+00, 0.38264400E-01, 0.54547400E-01, -.32078300E+00, -.13483800E-01, -.15956600E+00, -.18467400E+00, 0.13086700E+00, -.23733300E+00, -.59446100E+00, 0.31222100E+00, 0.90520600E-01, -.21330300E+00, 0.11356000E-01, 0.37657000E-01, -.35492600E-01, 0.77667100E-02, 0.54887400E+00, -.24782600E-01, 0.70233100E-01, -.12255300E+00, -.55219100E+00, -.43264600E-01, -.76982000E-01, -.17413300E-01, -.12932100E+00, -.69185000E-01, -.47124400E+00, -.22065900E-01, 0.54827500E+00, -.19343500E-01, 0.31253400E-01, 0.63102100E-01, -.12599100E-01, -.23808500E+00, -.28085200E-03, 0.49392400E-02, 0.10737200E+00, -.51374100E-01, 0.29148600E-01, -.13869800E+00, -.13058100E+00, 0.24514800E+00, -.48783200E-01, -.13992800E-01, 0.53261200E-02, 0.12032500E-03, -.10229900E+00, 0.23881700E-01, 0.86500800E-01, 0.54328100E-01, -.99921400E-02, -.74285100E-01, -.68020100E-01, 0.67316500E-01, 0.40354800E-01, -.93040800E-01, 0.15182300E-01, 0.43487100E+00, 0.26350200E+01, 0.61098400E-02, 0.70222300E-02, 0.17576900E+00, 0.43280900E+00, -.50852400E-02, 0.10807600E+00, -.15719900E-01, -.21040400E+00, 0.11279200E-03, -.19343700E+00, -.79008800E-02, -.24481600E-01, -.53365900E-01, 0.98563400E-01, -.28706500E-01, 0.83300200E-01, -.15087600E+00, 0.33610200E-01, 0.49561900E-01, -.43522300E-02, -.63212600E-01, 0.67310300E-02, 0.29582300E-01, 0.31291100E-01, 0.32591400E-01, 0.62750100E-02, -.15320000E-01, 0.36013600E-01, -.28020600E-02, -.15748400E+00, -.12674400E-01, 0.41076100E+00, -.58149000E-02, 0.11828900E-01, 0.63821500E-01, 0.12427300E-02, -.18169600E+00, 0.32867700E-01, -.16569100E+00, 0.22021600E-01, -.78911900E-01, 0.54492600E-03, 0.15676200E-02, 0.35215500E-01, -.33846100E-02, 0.18984300E-02, 0.26663100E-01, -.31520900E-01, -.15683200E-02, -.17271700E+00, -.43443800E-02, -.49285500E-02, -.88831100E-04, 0.61404400E-02, -.25948300E-01, -.59912900E-02, -.96020200E-01, -.38267900E-01, -.44315700E-02, -.10203500E-01, -.24818800E+00, 0.11080200E-01, 0.79866400E-01, 0.56051900E-03, 0.28237600E-01, -.70012000E-02, -.12582300E-01, -.25036000E-01, 0.55795500E-01, 0.20112600E-01, 0.37227000E-02, -.31911200E+00, -.60685700E-02, -.59002700E-02, -.11536700E+00, -.48211200E-02, 0.11398400E-01, 0.80334100E-01, 0.13497700E+00, -.57616500E+00, 0.76891200E-01, 0.69679900E-03, 0.92855300E-03, 0.15610400E+00, -.77356100E-02, 0.32683100E-01, 0.14230700E-01, -.77783000E-01, 0.17203400E+00, -.56957800E-01, 0.15030000E+00, 0.21954100E-01, -.86430200E-02, 0.77559200E-02, 0.12388500E-01, -.18889000E-01, -.24487800E-01 },
        { -.77441300E-01, -.82159200E+00, -.37982500E+00, 0.23256900E+00, 0.47853600E+00, 0.18370200E+00, 0.12898200E+00, -.15473900E+01, -.32183600E-01, 0.28852700E+00, -.76434300E-01, -.41216100E+00, -.29248900E-01, 0.40324800E-01, -.58077200E+00, -.24293300E+00, -.76609500E+00, 0.14704000E+00, -.13592200E+00, -.80568300E-01, -.13063200E+00, -.53222900E-01, -.62644600E-01, -.40620600E+00, -.14282100E+00, -.14250500E+00, -.23475100E+00, 0.34851400E-01, 0.75720800E-01, 0.13790100E+00, -.16097700E-01, -.26631100E-01, -.29365300E+00, 0.94241900E-01, 0.87622600E-01, 0.52411200E-01, -.13726700E-01, 0.56068700E-01, 0.41700900E-01, 0.41123700E-01, 0.25091200E-03, -.87982900E-01, -.81565800E-01, 0.14541800E+00, -.15100600E+00, -.57306700E-01, -.55942000E-01, -.20818300E-01, -.18284500E-01, 0.11788800E+00, 0.60409700E-01, -.14874200E+00, 0.19856200E-01, 0.77717100E+00, -.13129500E+00, 0.45077300E+00, -.36656300E-01, -.18481700E-01, -.37923100E-01, 0.16371100E+00, -.81735000E-01, -.25908900E+00, 0.91775700E-01, -.38149200E-01, 0.25066000E-01, 0.39525500E-01, 0.63637600E-01, 0.36745500E+00, -.75907500E-01, -.94044700E-04, -.18242400E+00, -.53620800E+00, 0.25526100E-01, -.18894300E-01, 0.26550200E-01, -.10079600E+00, 0.31075800E-02, 0.23800000E+00, -.84025300E-01, -.15767500E+00, -.46664300E-02, 0.40255300E-01, -.61120400E-02, 0.34436500E-01, 0.29003700E-01, -.16921500E+00, 0.28429800E+00, 0.40374400E+00, 0.20201900E+00, -.99751000E-01, -.11574000E+00, -.89723800E-01, 0.98524500E-01, 0.17050500E+00, -.14694900E+00, -.37496900E+00, -.80487800E-01, 0.57054300E-01, 0.67470000E-01, 0.99664000E-02, -.26034300E+00, 0.14077100E+00, 0.10698300E-01, -.10223800E+00, 0.26044900E-01, -.12953300E+00, 0.78657800E-01, -.27944800E+00, 0.42150700E+00, -.23950700E+00, -.10980000E-01, -.82065200E-01, -.12495600E-01, -.86726500E-03, 0.92721700E-01, 0.11078100E+00, -.50476500E-01, -.66135300E+00, -.31753100E+00, -.87151300E-01, -.10101400E+00, 0.22084200E-01, 0.62493200E-01, 0.40071300E+00, 0.19555300E-01, -.62399900E-01, 0.36194400E+00, 0.10914200E+00, 0.83451300E-02, 0.23910400E-01, -.16761000E-02, -.65576600E-01, 0.94542900E-02, -.85068100E-01, -.86451300E-01, -.43987900E-02, -.77611000E-01, -.27941300E-01, 0.74152500E-01, -.22120500E+00, 0.30760300E-01, 0.29098700E+00, 0.72099200E-01, 0.32651200E+00, 0.24189800E+00, 0.34445700E-01, -.32243500E-01, -.17013800E+00, -.12161800E+00, 0.95183400E-01, -.23742100E+00, 0.43918400E-01, -.13576700E+00, -.31304900E+00, -.78991100E-01, 0.35605600E-01, 0.11149800E+00, -.14536600E-01, -.69677200E-01, -.19415200E-01, 0.17316200E-01, -.19873100E+00, 0.75704300E-02, 0.13361600E-01, -.51961000E-01, -.15788100E+00, -.11370800E-01, 0.18876300E-01, 0.54799900E-02, -.11658400E+00, 0.33089400E-01, -.59740200E-01, -.43702200E-01, 0.13927700E+00, -.24170300E-01, -.84878100E-01, 0.22292200E-01, -.24752900E-02, 0.64660200E-02, 0.69684600E-04, -.41370400E-01, 0.18804300E-01, -.15277200E+00, -.75913700E-02, 0.11723400E+00, 0.18811600E-01, 0.19692100E+00, -.15723200E+00, -.62371200E-02, 0.10992600E-01, 0.18559400E-03, 0.79779100E-01, 0.83123200E-01, -.28884500E-01, -.24394600E-01, -.16326900E+00, -.76397400E-01, 0.12815600E+00, 0.11167900E+00, 0.73266100E-01, -.33011800E+00, 0.26819500E-01, -.93744500E+00, 0.29414900E+01, 0.10796500E-01, 0.12969200E+00, -.57509000E-01, 0.12560800E+00, -.77391500E-02, -.33789900E+00, -.45454700E-01, -.12640400E+00, -.58778300E-03, -.47509200E+00, -.73313800E-01, 0.86040900E-01, 0.78512300E-01, -.29017200E-01, 0.82213100E-02, -.12961500E-01, -.78373300E-01, 0.13562300E-01, 0.11343900E+00, -.20314200E-02, 0.12740100E+00, -.58551800E-01, -.90800400E-01, 0.31331600E-01, -.24364500E-01, -.42090100E-01, 0.57924400E-01, 0.57863100E-01, -.68066600E-02, -.24803200E-01, -.22267000E-01, -.24255600E+00, -.24796500E-01, -.14975100E-01, 0.36653300E-01, 0.20860500E-01, -.12180600E+00, 0.13921700E-01, -.99271200E-01, -.33771500E-02, -.14191600E-01, -.15930100E-02, -.52386300E-02, -.42944600E-01, 0.79633000E-02, -.31870400E-03, -.56189400E-02, 0.26118000E-01, 0.12172600E-01, 0.15417300E+00, 0.20568100E-01, 0.10684500E-01, 0.17832700E-02, 0.19484300E-01, -.43523900E-01, 0.35696600E-03, 0.10344900E-01, -.19399900E-01, -.65492900E-02, -.57835800E-02, 0.11765100E+00, 0.37223200E-02, -.57146600E-01, -.34713200E-03, 0.22921300E-01, -.32791300E-01, 0.54796300E-02, 0.31580800E-01, -.63911100E-01, 0.15762200E-01, -.40443800E-02, -.12302200E+00, 0.94726200E-02, 0.62574100E-02, -.34720700E-01, -.10899900E-01, -.15501900E-01, -.24694100E-01, -.11731000E-01, 0.14465200E+00, -.19391800E+00, 0.86670400E-01, -.71791700E-01, -.44346700E+00, -.15812300E-01, -.49980800E-01, -.14313900E+00, -.12352700E+00, 0.12474300E+00, -.15395000E+00, 0.11123000E+00, 0.33279200E+00, 0.46253700E-01, 0.60348000E-02, -.11181800E-01, 0.45362200E-01, 0.45580800E-01 },
        { 0.37995600E+00, -.59228700E+00, 0.27491700E+01, 0.18886500E+00, -.12862700E+01, -.21861900E+00, -.14548800E+01, -.17260100E+00, 0.16353200E+00, -.34902400E-01, 0.22846900E-01, 0.18346500E+01, -.61870200E+00, 0.13644300E+00, 0.96292100E+00, 0.21754100E+00, 0.12601000E+01, -.24390900E+00, -.74357300E-01, -.57872000E-01, 0.23132400E+00, -.19829800E+00, -.33270300E+00, 0.75997800E+00, 0.60811900E+00, 0.41576200E+00, 0.58054100E+00, -.11016900E+00, -.66209200E-01, -.35748900E+00, -.98802000E-01, -.12665600E+00, 0.63793200E+00, -.12313000E+00, -.13627900E+00, -.63540500E-01, 0.38636800E-01, -.15831600E+00, -.16767000E+00, -.16533900E+00, 0.81899900E-02, 0.33371000E+00, 0.63508700E+00, -.78052700E-01, -.10313700E+00, -.83154600E-01, -.20584200E+00, 0.49970200E-01, -.52780100E-01, -.19620500E+00, -.40064300E+00, 0.21632400E+00, 0.99846800E-01, -.44657800E+00, 0.15796500E+00, -.54240400E+00, -.20941300E+00, 0.15387800E+00, -.10522100E+00, -.19724400E+00, 0.25136600E-01, 0.15753500E+00, 0.14913100E-01, 0.56613000E-01, -.17184100E-01, -.15491000E+00, -.83772300E-01, -.44311200E+00, 0.13769100E+00, -.71218600E-04, 0.62624300E+00, 0.40543100E+00, -.16336900E-01, 0.51983100E-01, -.11142000E+00, -.12752400E-01, 0.78217800E-03, -.10763800E+00, 0.19438800E+00, 0.11301200E+00, 0.32234300E-02, -.41320000E-01, 0.13125100E+00, -.32466000E-01, 0.48255300E-01, 0.11506800E+00, -.36853600E+00, -.27637000E+00, -.57198300E+00, -.28087000E-01, 0.55354400E+00, 0.10629700E+00, -.47563800E+00, -.11945900E-01, 0.26733500E+00, 0.11491600E+01, 0.82737100E-01, -.11393900E+00, 0.14907400E+00, 0.54956100E-01, 0.72467000E-02, -.19662700E+00, -.13358800E-01, 0.38441900E+00, 0.10684500E+00, 0.15392100E+00, -.18622100E+00, 0.37142200E+00, -.81184900E+00, 0.42914900E+00, 0.69353600E+00, 0.29370700E+00, 0.65470600E-01, -.14589800E-02, -.10523100E-01, 0.20219600E+00, 0.12191500E+00, -.48228300E+00, 0.11538100E+00, 0.25879100E-01, -.14506300E-01, -.13707300E+00, -.75788400E-02, 0.31124900E-01, -.15609300E-01, -.21709800E+00, -.38535800E+00, 0.17179500E+00, -.86992400E-02, -.31702500E-01, 0.19881200E+00, 0.52693800E-01, 0.22255800E-01, -.61445500E-01, 0.92163900E-01, 0.41497100E-02, 0.41730200E-01, 0.80011900E-01, 0.33292500E-01, 0.15645600E-01, 0.61620100E-02, -.19924700E-01, -.38224300E-01, -.42034900E+00, -.47081700E+00, -.91459500E-01, -.47065100E-01, 0.36597600E-01, -.72852300E-01, 0.10524500E+00, 0.14992400E+00, -.13602900E+00, -.74850000E-01, 0.47781500E+00, 0.16520900E+00, -.70347800E-01, 0.19188000E+00, 0.14261900E-01, -.11749900E-01, -.48465400E-01, -.80909500E-01, -.17153600E+00, -.30909100E-01, 0.25214000E-01, -.41627600E-01, 0.23555600E+00, 0.16278900E-01, 0.32349200E-01, 0.16146900E-02, 0.14956100E+00, 0.36005400E-01, -.28784800E-01, 0.71742600E-01, 0.67157400E-01, 0.20139700E-01, 0.11803400E+00, 0.29248700E-01, -.13577800E-01, -.32188700E-01, 0.39273500E-03, 0.41997400E-01, 0.17788400E+00, 0.28952400E+00, -.26141700E-01, -.65524400E-02, -.22161400E-01, -.30198300E-01, -.61921100E-01, -.17576400E-01, -.18775000E-01, 0.18960800E-04, -.20586300E-01, 0.40346100E-01, -.74846500E-01, -.28139800E+00, -.56818600E-02, -.14576500E+00, 0.16960000E+00, -.16760000E+00, 0.17099100E-02, 0.13057500E+00, -.18511000E-01, 0.46492500E+00, -.55862500E+00, -.10324700E-01, 0.16471900E+00, -.39154500E-01, -.21059900E+00, 0.11924900E-01, 0.36353500E+00, -.16706900E-01, 0.75939100E-01, -.62165600E-03, -.77822200E+00, 0.30117600E-01, -.56902900E-01, 0.40033200E-01, -.35845400E-01, -.23461000E-01, -.79249300E-01, 0.43373500E-01, -.47908900E-01, -.23548800E+00, 0.81883100E-02, 0.21864900E+00, 0.19256900E-01, 0.39785500E-01, -.53517100E-01, -.36708100E-01, 0.11514500E-02, -.82960200E-02, -.16187400E+00, 0.34436800E-01, 0.23307100E+00, 0.61809300E-01, -.87979800E-02, 0.40062400E-02, 0.10605900E-01, -.38391400E-01, -.46113600E-02, -.45912400E-01, 0.15565900E-01, 0.27815700E+00, -.28905000E-02, 0.25301600E-01, 0.34632800E-02, 0.54571900E-02, -.47220800E-01, 0.15194600E-01, 0.10562600E-01, -.32435100E-01, 0.80519800E-01, 0.78358500E-02, -.15398300E+00, -.25517500E-01, -.12618900E-01, -.87270600E-03, -.36927500E-01, 0.80424100E-02, 0.46060400E-01, 0.13138400E+00, 0.81697300E-01, -.13597800E-01, -.12980100E-01, 0.37864800E+00, -.31552300E-02, 0.57278600E-01, 0.76166500E-04, 0.24719100E-01, -.93201800E-01, 0.26563000E-01, 0.36895300E-01, -.11151600E+00, -.29467600E-01, -.42680600E-01, 0.11340600E+01, -.57355400E-02, 0.28078500E-01, -.38748200E-01, 0.31173800E-01, 0.15921300E-01, 0.90140400E-02, 0.90715600E-01, 0.32032000E-01, -.21917700E+00, -.11614000E+00, 0.39051100E-01, 0.65983000E-01, 0.39377100E-01, 0.59493200E-01, 0.14870600E+00, 0.24373900E-01, -.57745400E+00, 0.16719800E+00, -.66498900E-01, 0.12753400E+00, 0.12777500E+00, 0.73265800E-02, 0.12451100E-01, -.28946200E-01, -.47939000E-01 },
        { 0.53960700E-01, -.20986400E+00, 0.25382500E+00, 0.39704400E-01, -.32865500E-01, 0.50947900E-01, 0.11958900E+00, -.10133300E+00, 0.10513300E+00, 0.13224200E+00, -.33560100E-01, 0.91457600E-01, -.15891600E+00, -.10822900E+00, -.24985600E-01, 0.14693000E-01, 0.20061500E-03, -.28111000E-02, -.98939700E-01, -.51898100E-01, 0.21117500E-02, -.31930400E+00, -.72164100E-01, 0.39328800E-01, 0.16222400E-01, 0.12316800E-01, 0.45268800E-01, -.69589100E-01, -.23660500E-01, -.20566500E-01, 0.14571400E-02, -.46435700E-02, 0.16648800E+00, -.30349000E-01, -.39934600E-01, -.13187100E-02, 0.83718400E-02, -.82464400E-02, -.52309800E-01, -.27298100E-01, -.70506200E-01, -.41821300E-01, 0.29139400E+00, 0.39774600E-01, -.12730900E-01, -.44665600E-01, -.14443200E+00, 0.11720600E-01, 0.23476700E-01, -.50653600E-01, -.42430600E-01, 0.20148500E-01, 0.51014200E-01, 0.55407200E-01, -.61510800E-02, -.43965600E-01, -.18630400E-01, -.27770500E-02, -.28887500E-01, -.56864200E-01, 0.35452300E-01, 0.10479200E-02, 0.17955300E-01, -.36398700E-01, -.80305600E-02, -.25009900E-01, -.23207300E-03, -.33677000E-01, 0.40066700E-01, -.32572200E-03, 0.69153100E-01, -.10551000E-01, -.27353800E-02, 0.66832800E-02, -.33303900E-01, -.29492300E-02, -.12707400E-01, -.67644200E-02, 0.27835200E-01, 0.38845000E-01, 0.17811000E-02, 0.48192200E-02, -.19234800E-01, -.97399900E-02, 0.53270000E-02, -.31351900E-02, -.14689900E-01, 0.12179300E-01, 0.35796800E-01, -.21120400E-01, 0.77747200E-01, 0.24859000E-01, -.48575200E-01, -.10185400E+00, 0.52539200E-01, 0.22511500E+00, 0.45020500E-01, -.36843400E-01, 0.98812300E-02, -.14500300E-01, -.28494700E-01, -.70395800E-01, -.23500200E-03, 0.73123100E-01, 0.34535200E-01, -.63268800E-01, -.72721000E-01, -.31630400E-01, -.67251600E-01, 0.10222500E+00, 0.20317200E+00, 0.87627800E-01, 0.52576300E-02, -.42790200E-02, 0.54802000E-02, 0.69186700E-01, 0.37854300E-01, -.15382400E+00, -.24325100E-01, 0.72444200E-02, -.31766100E-01, 0.36997500E-02, 0.12445800E-01, 0.78046800E-01, 0.17299000E-02, -.12011400E-01, 0.50418900E-01, -.47936100E-01, -.72294500E-02, -.15481700E-01, -.54557600E-02, 0.61613200E-01, -.26731900E-02, -.25550700E-01, 0.40990200E-01, -.10413100E-02, 0.13085800E-01, 0.24415200E-01, -.34736800E-03, -.77397400E-01, 0.37101700E-01, -.36097800E-01, 0.70803600E-02, 0.11157900E-01, 0.26258600E-01, -.29125900E-02, -.10177000E-01, -.27840500E-01, -.86221800E-02, -.14085100E-02, -.26841900E-01, -.16404300E-01, -.20761100E-01, 0.68160200E-01, 0.97326600E-01, -.20976800E-01, 0.88017800E-01, 0.47330900E-02, -.16955300E-01, -.55666500E-01, -.48487700E-01, 0.63191500E-01, -.26811400E-01, 0.15605900E-01, -.41257700E-01, 0.17222300E-01, 0.37118700E-02, -.57262100E-02, -.40481200E-02, 0.42977200E-01, -.10512400E-01, -.91982900E-01, 0.18365100E-01, 0.95302400E-01, 0.13192300E-01, 0.45087400E-01, 0.30178100E-01, -.54001900E-02, -.35965700E-01, 0.19500200E-04, 0.19817800E-01, 0.62917900E-01, 0.98195600E-01, -.14246600E-01, -.21597400E-01, -.25986300E-01, -.27444900E-01, -.44047800E-01, -.43486600E-02, 0.27652500E-02, 0.73790700E-04, 0.53308800E-03, 0.24750600E-01, -.30405900E-01, -.91500600E-01, -.59509300E-01, -.13396900E+00, 0.35241500E-01, -.59426200E-01, 0.19809700E-01, 0.52438700E-02, -.50432600E-03, 0.72974600E-01, 0.61510400E+00, 0.46342000E-02, 0.40393700E-01, -.23756900E-01, -.42144300E-01, 0.24838200E-02, 0.68481100E-01, -.10829800E-01, 0.31563600E-02, -.72815200E-04, -.27743800E+00, 0.18218600E-01, -.24988400E-01, 0.66946000E-02, -.13154000E-01, -.13245700E-02, -.17586300E-01, -.45738900E-01, -.60060000E-02, -.42416500E-01, 0.10192300E-03, 0.12048500E+00, -.88084400E-03, 0.29977400E-02, -.85590700E-02, -.26998100E-02, 0.15119300E-02, -.24868600E-02, -.39965400E-01, 0.79794000E-02, 0.44068700E-01, 0.15548800E-01, -.95508900E-02, -.33140300E-01, 0.10312400E-01, 0.11607900E-01, -.11135600E-01, 0.31359600E-01, 0.97887400E-02, 0.49209100E-01, 0.41665800E-02, -.48846100E-02, 0.33259500E-03, 0.38834600E-02, 0.20990300E-02, 0.57842300E-02, 0.74289300E-02, -.78107400E-02, -.34236200E-02, 0.39603300E-02, 0.16915200E-01, -.84147800E-02, 0.19271100E-02, 0.10016500E-03, -.13087500E-02, 0.27809800E-03, 0.24291400E-02, 0.22611900E-01, 0.13863000E-01, -.57133900E-02, -.22895700E-02, 0.56099000E-01, 0.11656200E-03, 0.10109700E-02, -.17990800E-03, -.67036200E-02, -.20880500E-01, 0.50020000E-02, 0.51014900E-02, -.19053700E-01, -.52454200E-02, -.69890500E-02, 0.35688400E+00, -.18785300E-02, 0.65940400E-02, -.39828300E-01, 0.10713200E-01, 0.32488200E-02, 0.78527500E-02, 0.17675400E-01, -.63350200E-01, 0.45981700E-01, 0.82490600E-03, 0.16481300E-01, 0.17030400E-01, 0.14573700E-01, 0.71707500E-01, 0.78489000E-01, 0.57125200E-01, -.20100900E+00, 0.78178700E-01, 0.52585800E-01, 0.16651200E-01, 0.61180800E-01, 0.35686300E-01, 0.43762300E-03, 0.27814400E-03, 0.12510800E-02 },
        { 0.12757300E+00, 0.99226400E+00, -.48524600E+00, 0.13427700E+00, -.58551100E+00, -.84378800E-01, -.38859300E+00, 0.11951200E+01, 0.38972300E-01, -.34960200E+00, 0.18080100E+00, 0.77942300E+00, 0.11350100E+00, 0.42078200E+00, 0.67268600E+00, 0.21229200E+00, 0.61559800E+00, -.81214300E-01, -.61080700E+00, 0.34782100E+00, -.24579800E+00, -.15491000E+00, 0.53870900E-01, 0.13764300E+00, 0.11363500E+00, -.12599900E+00, 0.15274800E+00, 0.31161100E+00, -.24123500E-01, -.18302400E+00, 0.18431600E-01, -.43578100E-01, -.31934400E-01, -.10209100E+00, 0.20172900E+00, 0.18862600E-01, 0.22049100E-02, 0.25724800E+00, 0.12545500E+00, -.12741700E-01, 0.41776400E-02, -.28991000E+00, -.66745300E+00, -.14779000E+00, 0.13793300E+00, 0.10673400E+00, 0.51017400E+00, 0.13036700E-01, 0.77615700E-01, 0.14336300E+00, 0.30346100E+00, -.15812200E+00, -.24217500E+00, -.17659000E+00, -.19974900E+00, 0.18852000E-01, -.16877300E+00, 0.10504900E+00, 0.94239900E-02, -.31643000E-02, -.90214300E-01, -.24270600E-01, -.11494700E+00, 0.14914300E+00, -.22127300E-01, 0.11544000E+00, -.39561500E-01, -.50890500E-01, 0.69558800E-01, 0.10751200E-02, 0.11002900E+00, 0.41018300E-01, -.71796700E-03, 0.14084500E-01, 0.77689300E-02, -.14287000E+00, -.20403900E-01, 0.13002200E+00, -.89663100E-02, -.20455100E-01, 0.73950300E-04, -.54126200E-01, 0.29013900E+00, 0.12149200E+00, 0.57575200E-01, 0.11892000E+00, -.42090000E+00, -.23443700E+00, -.62304300E+00, -.35111900E-01, 0.46870500E+00, 0.48820800E-01, -.37065400E+00, 0.21144400E+00, 0.50285800E-01, 0.43100100E+00, -.23166200E-01, 0.20730800E-01, 0.20669300E+00, 0.41435300E-01, 0.39173900E+00, -.46170900E-01, -.16078400E-01, 0.45100800E+00, 0.16766600E+00, 0.20533200E-01, -.70841100E-01, 0.18802200E+00, -.11061000E+00, -.12922100E+00, 0.14322000E+00, 0.53726100E-01, 0.17708600E-01, 0.19352800E-01, 0.65013400E-01, 0.14211000E+00, 0.26257300E-01, -.49699000E+00, -.66490300E-01, -.12010500E+00, 0.16150300E+00, -.37262000E-01, -.60711500E-01, 0.96667800E-01, 0.19001000E-01, -.35090200E+00, -.23268000E+00, 0.26418200E+00, 0.61065000E-02, -.57786200E-01, 0.92889300E-01, 0.12784700E+00, -.68602800E-02, -.31740400E-01, -.12004600E+00, -.37172600E-02, 0.12891000E+00, 0.62338400E-02, 0.98863700E-01, -.24228000E+00, -.13856500E-01, 0.15337900E+00, 0.10415200E+00, -.28045300E+00, -.31893900E+00, 0.94270100E-02, -.60248800E-01, 0.10849200E+00, -.77467400E-01, 0.23157600E-01, 0.23568900E+00, -.22656500E+00, 0.27378000E+00, 0.47698400E+00, 0.70404100E-01, -.38202100E-01, -.87393700E-02, 0.22555800E-01, -.11016000E+00, -.57170400E-01, -.23112500E+00, -.51787800E+00, -.93231900E-01, 0.54995500E-02, 0.13742400E+00, 0.32892100E-01, 0.60288000E-01, 0.35959300E-01, -.13809300E-01, 0.49696900E-01, -.63664500E-01, -.88492200E-01, -.85166800E-01, 0.62088700E-02, -.61814000E-01, 0.28764800E+00, 0.46149200E-01, -.32799900E-01, -.60542400E+00, 0.27184000E-03, 0.13639500E+00, 0.17755600E+00, 0.46382300E+00, -.61815800E-01, -.55341300E-01, 0.15108200E-01, -.45137400E+00, -.15917900E+00, -.18267500E-01, -.70060400E-01, 0.29850000E-03, -.73609700E-01, 0.52165100E-01, -.27841600E-01, -.17423400E-01, 0.36781800E-01, -.16405000E+00, 0.11112700E+00, -.19966100E+00, 0.42638500E-01, 0.83481800E-01, -.20683200E-01, -.13681100E+00, -.25626700E+01, 0.64191800E-01, 0.15296000E+00, -.23529700E+00, -.50433000E+00, 0.22400000E-01, -.29362600E+00, -.72579000E-01, 0.74815300E+00, 0.18686700E-02, -.13146600E+00, 0.10516500E+00, -.62919700E-01, 0.23454900E-01, -.72344100E-01, -.16135500E-01, -.17712200E-01, -.42192800E+00, -.23364900E-01, 0.62509600E+00, -.22893700E-01, 0.39698400E+00, -.15046300E-01, -.46956100E-01, 0.26091900E-01, -.55012600E-01, -.77338500E-02, -.15537000E-01, -.61835500E-01, 0.19693400E-01, 0.11407200E-01, 0.22092800E-01, 0.82580600E-01, 0.18456900E+00, -.20634600E-01, -.51870200E-01, 0.12962400E-01, -.35771800E-01, 0.54255000E-01, 0.14253200E+00, -.55004300E-01, 0.10039600E+00, 0.65581000E-02, -.81054000E-02, -.10256500E+00, 0.13921700E-01, 0.34309500E-01, -.48392300E-01, 0.34369600E-01, 0.42899900E-01, -.86065500E-01, 0.94900800E-03, -.31049400E-02, 0.91941000E-04, -.44833900E-02, 0.41028700E-01, 0.17629900E-01, 0.24960300E-01, 0.52214600E-02, 0.12698000E-02, -.34488200E-02, 0.50674700E-02, 0.53994500E-02, -.20058900E-02, -.54211600E-03, -.18610800E-01, -.14683200E-01, 0.85251200E-02, 0.15957700E-01, -.45779100E-01, -.47065800E-02, -.10269700E-01, -.55764100E-01, 0.30530200E-02, 0.99477900E-01, 0.21644100E-01, 0.25672400E-02, 0.13359500E-02, -.61851600E-02, 0.14492500E-01, -.63227200E-02, 0.71134700E-01, 0.55559900E-01, -.30039700E-01, 0.41031400E-01, -.45522200E-02, -.29450800E-01, 0.75303800E-02, 0.45311100E-01, 0.17092200E-01, 0.37679500E-02, -.38670800E-01, -.30168700E-01, -.57149600E-01, 0.65643600E-02, -.21337300E+00, 0.91502900E-02, 0.16320300E-01 },
        { -.20341400E+00, 0.34556600E+00, -.84493200E+00, -.25318600E+00, 0.56077600E+00, 0.24999100E+00, 0.16234800E+01, 0.26519300E+00, 0.22462300E+00, -.16000900E+00, -.69516000E-01, -.35267300E+00, 0.14590500E+00, -.12642300E+00, -.64423000E+00, -.49903700E+00, -.10187600E+01, 0.19145500E+00, -.41294300E+00, -.11905000E+00, -.76622900E-01, -.48733400E+00, -.75050100E-01, -.45283000E+00, -.12542100E+00, -.14879600E+00, -.46693300E+00, 0.20010000E+00, 0.12437700E-01, 0.99394600E-01, 0.19157800E+00, 0.45285000E-01, -.12824300E+00, 0.15433300E+00, -.45338500E-01, 0.14389800E+00, -.15153000E-01, 0.95912300E-01, -.88847800E-02, -.39405700E-01, -.36746200E-01, -.56917900E+00, -.12054200E+00, 0.14952000E+00, -.98776400E-01, -.57257600E-02, -.14320400E+00, -.23395600E-01, -.10397300E+00, 0.24132200E+00, -.80894100E-01, 0.48383300E+00, 0.89962100E-01, -.73485900E+00, -.44822100E-01, 0.52767300E-01, -.11130900E+00, -.35432600E+00, 0.61646100E-01, 0.26982400E-01, 0.28198100E+00, -.18375100E-01, 0.16710400E+00, -.28394700E+00, -.55254100E-01, -.57831000E-01, 0.42769300E-01, 0.60372700E+00, -.15753200E+00, 0.93922500E-04, -.24007600E+00, 0.25035100E+00, 0.64419000E-01, -.13194400E-01, -.18732300E+00, 0.58986600E-01, 0.27502900E-01, 0.82340600E-01, -.41310800E-01, -.99955800E-01, -.42260200E-02, 0.44376600E-01, 0.59994000E-01, 0.12352400E-01, -.42713400E-01, -.22633400E-01, 0.20348400E+00, 0.27008700E+00, 0.15247100E+00, -.43594600E-01, -.28945200E+00, -.50162200E-01, -.51589800E-01, 0.68277700E+00, -.34329500E-01, -.45098200E+00, -.42694100E-01, 0.60642900E-01, 0.18275000E+00, 0.85574200E-01, -.27081100E+00, 0.26035000E+00, 0.17844000E-02, -.42269200E-01, -.42602800E-01, -.23239800E-01, 0.71993200E-01, -.77320300E-01, 0.61944800E-01, 0.23570100E-01, -.32638600E+00, -.24366500E+00, 0.32994900E-01, 0.25838600E-02, -.21596500E-01, 0.45527700E-01, -.35425400E-01, -.41420100E+00, -.19477100E+00, 0.28464300E-01, -.27700100E-01, -.20760500E+00, -.20261900E-01, -.15427300E+00, 0.13005000E-01, -.12928100E-01, -.33152400E-01, -.14026200E+00, -.20947400E-01, -.46815700E-01, -.16489600E+00, 0.89284500E-01, -.14405800E-01, 0.64746000E-01, 0.12699100E+00, 0.50877500E-03, 0.39104900E+00, -.48294600E-02, 0.55873000E-02, 0.34838700E-01, 0.16899200E-01, -.35121200E+00, -.16867400E-02, 0.91156300E-01, 0.24592500E+00, 0.42762200E-01, 0.37510900E-01, -.19567300E+00, 0.36644300E-01, -.10060500E+00, -.45434100E-01, 0.32994300E-01, -.35041400E-01, -.26455400E+00, 0.12730900E+00, 0.73943900E-01, -.10131800E+00, 0.65938300E-02, 0.27016500E-01, 0.24370600E-01, -.18204100E-01, 0.57112300E+00, -.53109900E-01, -.22957600E-02, 0.14819200E-01, -.11781100E+00, -.30124800E-01, -.21253900E-01, -.73697100E-02, 0.20622700E-01, 0.72424600E-01, 0.65768300E-01, 0.30472900E-01, 0.91587500E-01, -.90101200E-02, 0.16202100E+00, 0.14455900E-01, -.95568000E-02, 0.21777700E+00, -.19835200E-03, 0.15815600E-01, -.25568300E-01, 0.20157400E+00, -.58199000E-01, -.11864500E+00, -.15390300E+00, 0.12479200E+00, -.78967200E-02, 0.13091700E-01, -.34108300E-03, 0.28378200E-03, 0.12380000E-01, 0.21148300E-01, -.51633000E-01, 0.21627300E+00, 0.12592100E-01, -.14580000E+00, -.11941900E+00, -.19238600E-01, 0.21947100E-01, 0.15201300E-01, 0.85389600E-02, -.62755200E+00, 0.23649000E+00, 0.84277300E-03, -.61851500E-01, -.11076900E+00, -.10085800E+00, 0.99750700E-02, -.22688800E+00, -.39868100E-01, -.81491100E-01, 0.34793100E-03, -.38476900E+00, 0.95779800E-01, -.95119500E-01, -.16473900E-01, 0.13122900E-01, -.72560900E-02, 0.67298100E-01, -.33549500E+00, 0.36964200E-01, 0.10088500E+00, 0.37822900E-02, 0.17014300E-01, -.40398600E-01, -.26427900E-01, 0.76284200E-01, 0.34614300E-01, 0.20976800E-01, 0.19848300E-02, 0.70148400E-02, -.55253200E-02, -.89404400E-01, -.59552200E-03, -.13052700E+00, -.12846100E-01, 0.35499100E-01, 0.16176600E+00, 0.37668800E-01, -.18147600E+00, 0.53063600E-01, -.27771000E+00, 0.49624600E-03, -.12852600E-01, -.32175300E-02, -.10611700E-01, 0.58024800E-01, 0.25443600E-02, -.42788300E-02, 0.50393200E-01, -.47847800E-01, 0.54210300E-03, 0.25738500E-01, 0.21302600E-02, -.82608100E-02, 0.92314600E-03, 0.10805100E-01, -.22305100E+00, -.29874600E-01, -.10101700E+00, -.10371600E+00, -.30671100E-01, -.30987300E-01, -.27158100E+00, 0.19943300E-01, 0.88967700E-01, 0.14209300E-02, -.37709300E-01, -.39384900E-01, 0.40095300E-02, 0.11906800E-01, 0.18278300E+00, 0.86420000E-01, -.45247300E-01, 0.71966400E+00, -.60994300E-02, -.59693300E-02, -.83087100E-01, 0.18417200E-01, 0.34353100E-01, -.68085400E-02, -.19143600E+00, -.83718800E-01, 0.23291100E+00, -.15720200E+00, 0.16331200E+00, 0.23712000E+01, -.26373400E-01, -.83561100E-01, -.13786000E+00, 0.35973900E-01, -.19436200E+00, -.10712200E+00, 0.22442400E-01, 0.67692800E+00, -.69574000E-01, -.12863800E+00, -.96080800E-01, -.33151900E+00, -.49093700E+00 },
        { -.12663600E+00, 0.66253300E+00, 0.90329500E-01, -.25047300E+00, -.62302000E-01, 0.95439900E-01, 0.79876300E+00, 0.66668900E+00, 0.75357400E-01, -.42751800E+00, 0.30437400E-01, 0.68406500E+00, 0.21101000E+00, 0.21098500E+00, -.10679800E+00, -.30804500E+00, -.49279200E+00, 0.56572600E-01, -.21881900E+00, -.11989300E+00, -.65243500E-01, 0.52335800E+00, 0.61345200E-02, -.38869900E+00, 0.17020100E-01, -.77101200E-01, -.27857800E+00, 0.41103400E+00, 0.45740900E-01, -.32466900E-01, 0.27196700E+00, 0.54112700E-01, -.61828400E-01, -.67071300E-01, -.10035300E+00, 0.71679700E-01, -.68459400E-02, -.11634800E+00, 0.68780400E-02, -.23325500E-01, 0.25418700E-01, 0.42865200E-01, 0.78609500E+00, 0.23865000E+00, -.47727600E+00, 0.79362400E-02, -.94000100E-01, -.33184200E-01, -.13094700E+00, 0.36755800E+00, -.13936500E+00, 0.32563700E+00, -.24291100E+00, 0.67267500E+00, 0.12686900E+00, 0.14811800E+00, -.39453600E+00, -.10644800E+00, 0.93869000E-01, -.27634100E+00, 0.24452400E+00, -.71647500E-01, 0.12044500E+00, -.59562600E-01, -.11216600E+00, 0.12977300E-01, -.59316300E-01, 0.26755400E+00, 0.14349800E+00, 0.96265400E-03, -.34009200E+00, 0.21368600E+00, 0.48354200E-01, 0.17611300E-01, -.37658600E+00, -.20168400E+00, -.76027200E-01, 0.49306400E+00, -.12422400E+00, -.21055900E-01, 0.18222900E-02, -.42857800E-01, 0.54482800E+00, 0.38631300E-01, -.33775200E-01, 0.57165300E-01, 0.78707000E-01, -.31276500E+00, -.59512700E-01, 0.78366600E-01, -.17096000E+00, 0.49897300E-01, 0.25250100E+00, -.14973200E+00, 0.44588800E-01, 0.36509200E+00, -.19701700E-01, 0.14770500E+00, -.10236200E+00, -.12196600E+00, 0.88630700E+00, -.23855300E+00, -.11443800E-01, 0.18410300E+00, -.33536200E-01, 0.24410400E+00, -.79655400E-01, 0.16002900E+00, -.13992000E+00, 0.76725600E-01, 0.26426800E+00, 0.42611700E+00, -.12490200E+00, -.30061900E-02, 0.68209200E-03, 0.20550700E+00, 0.57788200E-01, -.94688900E+00, -.31478900E+00, -.25661900E-01, -.13530200E-01, -.81928500E-01, -.52649900E-01, 0.43989400E+00, 0.18458700E-01, 0.16057600E+00, 0.73909500E-01, 0.29045900E-01, 0.18741400E-01, 0.92260600E-01, 0.13048900E+00, 0.31536000E-01, 0.11032600E-02, 0.58026400E-01, -.82996500E-01, -.57211700E-03, -.34830800E+00, -.57733700E-01, -.48507900E-01, -.82653900E-01, 0.16946200E-01, -.29685600E+00, 0.13348100E-01, -.22499700E+00, -.46975900E-01, 0.47824800E-01, 0.70149400E-02, 0.42737700E-01, 0.67863600E-01, -.31159000E-01, 0.17346700E+00, -.89485400E-01, -.11347500E-02, 0.18712900E+00, 0.70764200E-01, 0.88142800E-01, -.23401700E+00, 0.60133900E-03, 0.34875200E-01, 0.22422000E-02, -.69615300E-01, 0.36480500E+00, -.57363000E-01, -.10950800E-01, 0.53286600E-01, -.17308300E-01, -.20527200E-01, -.29318000E-01, -.51819400E-02, 0.12622300E+00, 0.47297100E-01, -.25437600E-01, -.15393300E-01, -.54697300E-01, -.13111200E-01, 0.22317500E+00, 0.19586700E-01, -.48727000E-02, 0.37424600E+00, -.19291200E-03, 0.19311800E-01, 0.94067800E-02, 0.25032100E+00, -.47984900E-01, -.13050900E+00, -.54173000E-01, -.36817600E+00, 0.24167500E-01, 0.16789500E-01, -.32421900E-01, 0.24901800E-03, 0.10768400E+00, -.45402300E-01, -.32663100E-01, 0.36993700E+00, 0.55139500E-01, -.13810800E+00, -.12700400E+00, -.34761400E-01, -.24569400E-02, 0.16850300E-01, -.10169200E-01, -.87845400E+00, -.37606900E+00, -.29020200E-03, -.35262000E-01, -.15971500E+00, -.24215600E+00, -.99395500E-03, -.21903900E+00, -.99637900E-02, -.11241400E+00, 0.72505000E-04, -.62414400E+00, -.59020100E-01, -.86633800E-01, -.42895700E-01, 0.15069700E-01, -.37477600E-01, 0.11459000E+00, -.34697000E+00, 0.40561000E-01, -.14590300E+00, -.59452100E-02, 0.13420400E+00, -.87409800E-02, -.27614200E-01, 0.31472700E-01, 0.43538000E-01, 0.37744200E-01, -.92450800E-02, 0.70274300E-03, -.78106500E-02, -.13445600E+00, 0.12965000E-02, 0.27829900E+00, -.22368900E+00, 0.46735000E-01, 0.11604000E+00, -.42981700E-01, -.76711100E-01, 0.58473700E-01, -.10448600E+00, 0.36165500E-01, 0.67651600E-01, -.11706100E-01, 0.15191800E-01, 0.69488100E-02, -.34630400E-01, -.34684100E-01, 0.20096800E-01, -.79849300E-01, 0.31112300E-01, 0.60957600E-01, -.46711300E-01, -.30349900E-01, -.97288100E-03, -.36039900E-01, -.37088100E+00, -.21948600E-01, -.13392700E+00, -.45925600E-01, -.57000000E-02, -.22896200E-02, -.36528700E+00, 0.85820300E-02, -.93791500E-01, 0.22996800E-02, -.17916500E+00, -.20049100E+00, 0.29856100E-01, 0.12987800E-01, 0.35737000E-01, -.74166200E-01, -.59545400E-01, 0.85981700E+00, 0.72060800E-02, 0.14694200E-01, -.65959700E-01, 0.25784600E-01, 0.39773800E-01, -.82526400E-02, -.60985000E-01, -.98185100E-01, 0.10858600E+00, -.13127400E+00, 0.15495500E+00, 0.13540300E+01, 0.20991600E-03, 0.25825400E-02, -.65484500E-01, 0.37411100E-01, -.14548400E+00, 0.13701600E-01, -.13854100E-01, 0.24325000E+00, 0.19452300E-02, -.57349800E-01, -.49853000E-02, 0.22823600E-01, -.14730500E+00 }
    },
    {
        { 0.25472300E+06, -.12660500E+06, -.10535300E+06, -.12557100E+06, -.21102300E+05, -.28492200E+05, -.18512500E+05, 0.78122200E+05, -.45308300E+05, -.25975300E+05, -.97678300E+05, 0.99686900E+05, -.49554900E+05, -.41085800E+05, -.49167600E+05, -.14289900E+05, -.17466600E+05, 0.14434200E+05, 0.75929200E+05, 0.24887900E+04, -.17253900E+05, -.39597000E+05, 0.12316700E+06, -.61282300E+05, -.50345000E+05, -.61083000E+05, -.13868900E+05, -.20969600E+05, 0.15977300E+05, 0.89158200E+05, 0.15742500E+03, -.20577100E+05, -.55953400E+05, 0.21703200E+06, -.10770900E+06, -.87211200E+05, -.10770700E+06, -.14054300E+05, -.27931200E+05, 0.70805800E+03, 0.99549800E+05, -.30575800E+05, -.25632300E+05, -.95071500E+05, 0.15568100E+06, -.77162100E+05, -.59778500E+05, -.76757900E+05, -.14739600E+05, -.28375200E+05, 0.22207600E+05, 0.11288200E+06, -.37203900E+04, -.25409700E+05, -.76265400E+05, -.18589900E+05, 0.92455300E+04, 0.68798200E+04, 0.88172200E+04, 0.18096100E+04, 0.31553700E+04, -.68110800E+04, -.24597600E+05, -.37139100E+04, 0.35731900E+04, 0.10670700E+05, 0.52154000E+05, -.25838900E+05, -.17499100E+05, -.25839800E+05, -.28369800E+04, -.89671200E+04, 0.17707200E+05, 0.60833600E+05, 0.21023100E+04, -.89473000E+04, -.32008400E+05, 0.23210900E+06, -.11499600E+06, -.86777700E+05, -.11323500E+06, -.20354500E+05, -.39378100E+05, 0.28942500E+05, 0.16087200E+06, -.98224200E+04, -.34870000E+05, -.11781900E+06, -.21383600E+06, 0.10626300E+06, 0.89018700E+05, 0.10560600E+06, 0.18759600E+05, 0.28087000E+05, -.40894600E+03, -.97628600E+05, 0.28216200E+05, 0.25811800E+05, 0.87869500E+05, 0.13288800E+06, -.66043600E+05, -.56422700E+05, -.65620100E+05, -.13110900E+05, -.19005300E+05, -.61966100E+04, 0.46781000E+05, -.14793000E+05, -.15786400E+05, -.52507200E+05, -.13470800E+06, 0.66697200E+05, 0.50136600E+05, 0.64994800E+05, 0.13342700E+05, 0.28914500E+05, -.24018000E+05, -.10681300E+06, -.48271200E+04, 0.24532700E+05, 0.74161300E+05, 0.15952900E+06, -.79115400E+05, -.64476100E+05, -.76898200E+05, -.16835400E+05, -.27971500E+05, 0.24732600E+05, 0.12740300E+06, 0.81218700E+04, -.26177900E+05, -.75298500E+05, 0.13860600E+06, -.68737400E+05, -.53841700E+05, -.69065900E+05, -.57809900E+04, -.16975000E+05, -.21792600E+04, 0.57996500E+05, -.24040200E+05, -.15422400E+05, -.65492500E+05, -.22111100E+06, 0.10986500E+06, 0.84521700E+05, 0.10943300E+06, 0.13540100E+05, 0.29558200E+05, -.21967000E+05, -.14498000E+06, 0.21383400E+05, 0.28035100E+05, 0.10688600E+06, -.15971400E+06, 0.79514200E+05, 0.63346700E+05, 0.79742400E+05, 0.11084000E+05, 0.21420200E+05, 0.13163100E+04, -.66142000E+05, 0.25092400E+05, 0.19524100E+05, 0.71993200E+05, 0.14190100E+06, -.70540300E+05, -.57006100E+05, -.70473000E+05, -.15261400E+05, -.23784700E+05, 0.17136000E+05, 0.99499500E+05, -.19915300E+04, -.22742000E+05, -.62812200E+05, -.17281400E+06, 0.85929400E+05, 0.82024700E+05, 0.84209100E+05, 0.14143400E+05, 0.20810600E+05, 0.36125400E+04, -.78443300E+05, 0.15006300E+05, 0.19921500E+05, 0.70861800E+05, -.10977500E+06, 0.54627900E+05, 0.45517400E+05, 0.54106100E+05, 0.14138900E+05, 0.18952400E+05, -.14503800E+05, -.80515900E+05, -.16001200E+04, 0.18765600E+05, 0.48865600E+05, -.25862200E+06, 0.12818000E+06, 0.98239300E+05, 0.12699900E+06, 0.19649400E+05, 0.45932100E+05, -.30891000E+05, -.17423500E+06, 0.11425100E+05, 0.40436300E+05, 0.14106700E+06, -.21744700E+06, 0.10765000E+06, 0.79001500E+05, 0.10541600E+06, 0.24917300E+05, 0.44258700E+05, -.33394900E+05, -.15857000E+06, 0.42037700E+04, 0.37846800E+05, 0.10806300E+06, -.13926800E+06, 0.69335600E+05, 0.58087600E+05, 0.69506100E+05, 0.10843000E+05, 0.17597100E+05, 0.54141400E+04, -.51702900E+05, 0.21326600E+05, 0.16249100E+05, 0.58227100E+05, -.37180600E+05, 0.18532100E+05, 0.14899100E+05, 0.18563600E+05, 0.24319400E+04, 0.47076300E+04, 0.28226600E+04, -.10320700E+05, 0.71964300E+04, 0.38459500E+04, 0.15695500E+05, 0.32078000E+06, -.15942600E+06, -.12686700E+06, -.15839700E+06, -.26278300E+05, -.42854600E+05, -.84055100E+04, 0.12265400E+06, -.49256600E+05, -.36979200E+05, -.13524800E+06, 0.22484500E+06, -.11150600E+06, -.95242400E+05, -.10960900E+06, -.21272800E+05, -.37067900E+05, 0.21722700E+05, 0.14838900E+06, -.70363100E+04, -.33691800E+05, -.10735200E+06, -.24887200E+06, 0.12365400E+06, 0.10331100E+06, 0.12045000E+06, 0.25200200E+05, 0.34329700E+05, -.73287200E+04, -.12830200E+06, 0.23795900E+05, 0.32575600E+05, 0.10534000E+06, -.33923500E+05, 0.91218700E+04, 0.20821100E+05, 0.12981900E+05, -.23567100E+05, 0.66571500E+04, -.32513300E+05, -.28500600E+05, -.11157600E+05, 0.11170600E+05, -.43860800E+04, -.27003700E+05, -.17766700E+05, 0.37179700E+05, -.26928900E+05, -.14435800E+05, -.11127900E+05, -.12711200E+04, 0.16505000E+05, 0.14002800E+05, 0.10495100E+05, 0.11034900E+05, 0.19008900E+05, -.95658200E+04, 0.37934900E+04, 0.18417900E+05 },
        { 0.32173800E+00, 0.60833700E+04, -.66020900E+04, -.80234300E+04, 0.72090300E+05, 0.45467200E+03, -.26112200E+03, -.18542500E+03, -.49421100E+04, 0.11688600E+05, -.63992900E+05, -.49705500E+05, 0.27719900E+05, 0.21939200E+05, 0.21937700E+05, 0.57138900E+05, 0.30207600E+05, -.28205300E+05, -.43038900E+05, -.87301700E+04, 0.34944500E+05, -.27543800E+05, 0.11182800E+05, -.39312800E+04, 0.11921500E+05, -.76929800E+04, 0.40248900E+05, 0.12378300E+05, -.22274800E+05, -.27853700E+05, -.27528300E+05, 0.19432800E+05, -.54447700E+05, 0.98105600E+05, -.43134600E+05, -.32366200E+04, -.52644400E+05, 0.69349600E+05, -.50358500E+04, -.13583500E+05, 0.16730400E+05, -.38847900E+05, 0.72735900E+04, -.11972400E+06, 0.58440700E+05, -.23477700E+05, -.23013300E+05, -.34016200E+05, 0.81210300E+05, 0.30865900E+05, -.45427700E+05, -.26998000E+05, -.46214900E+05, 0.38600600E+05, -.90361400E+05, 0.13755000E+05, -.63772800E+04, -.18108600E+05, -.47126900E+04, -.27278500E+05, 0.47221900E+04, -.58261700E+04, -.46433700E+04, -.59331300E+04, 0.28462400E+04, 0.23485200E+05, 0.61040900E+05, -.29973400E+05, -.20061700E+05, -.31590800E+05, 0.13091800E+05, -.52908600E+04, -.13037200E+05, -.65905400E+04, -.25821300E+05, -.41807400E+03, -.45631600E+05, 0.90611800E+05, -.37583100E+05, -.32844400E+05, -.57985700E+05, 0.10023700E+06, -.12781000E+05, -.19258300E+05, -.27720500E+04, -.42029300E+05, 0.26748900E+04, -.13123200E+06, 0.86974900E+03, -.48582400E+04, 0.90821000E+04, 0.54636000E+04, -.83262000E+05, -.89852400E+04, 0.13778800E+05, 0.12234400E+05, 0.13178400E+05, -.19765200E+05, 0.65752200E+05, -.36297500E+05, 0.22571700E+05, -.42446500E+04, 0.14474200E+05, 0.49793500E+05, 0.15118100E+05, -.76153000E+04, -.78901000E+04, 0.12178700E+05, 0.18337700E+05, -.14405400E+05, -.73051500E+05, 0.30529300E+05, 0.18703500E+05, 0.47157900E+05, -.66458200E+05, -.59111300E+04, 0.25175400E+05, 0.77093100E+04, 0.42299200E+05, -.13795400E+05, 0.86758600E+05, -.27793700E+05, 0.19448900E+05, 0.22800200E+05, 0.98258600E+03, 0.95208700E+05, 0.18338000E+05, -.19406000E+05, -.27362500E+05, -.13466800E+05, 0.27769200E+05, -.77120700E+05, 0.13820800E+06, -.64055100E+05, -.29604400E+05, -.70147900E+05, 0.30232200E+05, -.12976600E+05, -.92251400E+04, 0.28749900E+05, -.43521000E+05, -.48178300E+04, -.10001000E+06, -.14741400E+06, 0.70934300E+05, 0.48422300E+05, 0.78767900E+05, -.50613500E+05, 0.19154400E+05, 0.21672000E+05, 0.59816600E+03, 0.58068900E+05, 0.37257900E+04, 0.12587700E+06, -.83487100E+05, 0.39597100E+05, 0.33706700E+05, 0.42249500E+05, -.32616200E+05, 0.19103300E+05, 0.13955700E+04, -.17286200E+05, 0.22989100E+05, 0.86908100E+04, 0.69213400E+05, 0.73740100E+05, -.34745800E+05, -.38654200E+04, -.38901900E+05, 0.37208700E+05, -.18188900E+04, -.24271300E+05, -.17083100E+05, -.39202500E+05, 0.90242300E+04, -.93076900E+05, 0.41406800E+05, -.25053100E+05, -.26314000E+05, -.10808700E+05, -.64461200E+05, -.19828500E+05, 0.11068500E+05, 0.13938100E+05, 0.32588200E+04, -.26418400E+05, 0.43760600E+05, 0.70867800E+05, -.37742900E+05, -.27744600E+05, -.32101000E+05, -.61172800E+05, -.38075100E+05, 0.29161700E+05, 0.46060500E+05, 0.85228500E+04, -.41436100E+05, 0.11004200E+05, -.15678600E+06, 0.68971500E+05, 0.62230000E+05, 0.88694300E+05, -.12051000E+06, -.34022600E+05, 0.63859400E+05, 0.12593900E+05, 0.82874000E+05, -.47177600E+05, 0.15265300E+06, -.35052200E+05, 0.87487800E+04, 0.20052600E+05, 0.32457800E+05, -.11235000E+06, -.28834000E+05, 0.48836400E+05, 0.44517200E+05, 0.50976000E+05, -.40854600E+05, 0.96689500E+05, -.33699400E+05, 0.14419200E+05, 0.26033600E+05, 0.17412000E+05, -.30726600E+05, 0.10812500E+05, -.20288200E+04, -.11289500E+05, 0.36862700E+04, 0.32221300E+04, 0.42339900E+05, -.20862900E+05, 0.10270000E+05, 0.88639000E+04, 0.10550500E+05, -.56599300E+04, 0.31818200E+04, 0.80035200E+03, -.47448400E+04, 0.57373600E+04, 0.15503100E+04, 0.13643600E+05, 0.79325600E+05, -.31812100E+05, -.27639600E+05, -.48588800E+05, 0.86669000E+05, -.71180000E+04, -.11859900E+05, 0.65829700E+04, -.29409200E+05, 0.81765300E+04, -.11065400E+06, -.34846200E+04, 0.98776400E+04, 0.10381100E+04, -.10919200E+05, 0.11007100E+06, 0.28584500E+05, -.30848700E+05, -.29140300E+05, -.26195100E+05, 0.39040000E+05, -.88493500E+05, 0.17769300E+06, -.93099800E+05, -.73740700E+05, -.70813100E+05, -.15856600E+06, -.45586600E+05, 0.22998900E+05, 0.50396100E+05, -.12729300E+05, -.57268300E+05, 0.34253900E+05, -.87063100E+03, -.33237700E+05, 0.88176100E+05, 0.11042600E+06, 0.47572800E+05, -.36239700E+05, -.32623100E+04, 0.53683200E+04, 0.30000800E+05, -.19771500E+05, -.28516200E+05, 0.22623900E+05, -.92674500E+04, -.53749400E+05, 0.13877800E+05, 0.41169300E+05, -.96677200E+05, -.19873100E+05, 0.10498000E+06, -.48238900E+05, 0.90242000E+02, -.47975100E+05, -.24455900E+05, 0.28071100E+05, -.15000400E+05, 0.17293500E+05 },
        { -.45664900E-01, 0.36469200E+00, -.87820200E+05, 0.88635700E+04, -.57450700E+05, -.57019900E+05, 0.36548500E+05, 0.60329300E+05, 0.11206300E+06, -.58048000E+05, 0.29956600E+05, 0.50257800E+05, -.26943000E+05, -.87533100E+05, -.21841600E+05, -.69651300E+05, -.94078700E+05, 0.74192800E+05, 0.10134400E+06, 0.10545200E+06, -.90201500E+05, -.23727700E+04, 0.14710600E+05, -.95108100E+04, -.88485900E+05, -.49495100E+04, -.64921000E+05, -.92169300E+05, 0.75288800E+05, 0.10521100E+06, 0.13278700E+06, -.89080400E+05, 0.10641300E+05, -.17581700E+06, 0.85277600E+05, -.43695200E+05, 0.91896700E+05, -.59907900E+05, -.76352300E+05, 0.84011100E+05, 0.56112100E+05, 0.16794600E+06, -.75537800E+05, 0.99117100E+05, -.17101300E+05, 0.74678800E+04, -.84636400E+05, 0.13881600E+05, -.83649900E+05, -.95166200E+05, 0.93023300E+05, 0.11357200E+06, 0.15419800E+06, -.94626600E+05, 0.33950300E+05, 0.14221300E+06, -.66323900E+05, -.14617900E+05, -.73484500E+05, 0.21951800E+05, 0.50840900E+05, -.49387300E+05, -.73631900E+04, -.70691900E+05, 0.43089000E+05, -.58008700E+05, -.10738700E+06, 0.53371200E+05, 0.26423300E+05, 0.54871900E+05, -.27354100E+04, 0.14225300E+04, 0.28467500E+05, 0.16352000E+05, 0.54100000E+05, -.55573900E+03, 0.43783000E+05, -.18638200E+06, 0.89938500E+05, -.57611200E+05, 0.10717300E+06, -.81731000E+05, -.10084600E+06, 0.11580300E+06, 0.11532800E+06, 0.23656200E+06, -.99151900E+05, 0.98397100E+05, 0.74008000E+05, -.35294600E+05, 0.42769500E+05, -.43509800E+05, 0.59047000E+05, 0.62786000E+05, -.64564600E+05, -.63457200E+05, -.12318600E+06, 0.62698500E+05, -.61822000E+05, 0.84968000E+05, -.41613800E+05, -.72802400E+05, -.38414200E+05, -.38011000E+05, -.36507300E+05, 0.17907400E+05, 0.52554200E+05, 0.36266200E+05, -.37953500E+05, -.17593500E+05, 0.19705700E+05, -.93865700E+04, 0.81854200E+05, -.21565300E+05, 0.68584900E+05, 0.77588600E+05, -.76816900E+05, -.11307000E+06, -.15261200E+06, 0.79153100E+05, -.29031800E+05, -.34507900E+05, 0.13777000E+05, -.93002700E+05, 0.31483400E+05, -.97951200E+05, -.13573300E+06, 0.11246900E+06, 0.13410300E+06, 0.18679800E+06, -.12756600E+06, 0.37180100E+05, -.18504800E+06, 0.90371800E+05, -.24602300E+04, 0.93688500E+05, -.23868600E+05, -.29009900E+05, 0.47654100E+05, 0.10677700E+05, 0.11187200E+06, -.29694000E+05, 0.91824700E+05, 0.25204800E+06, -.12528400E+06, -.31607900E+05, -.13159700E+06, 0.15843100E+05, -.15748300E+04, -.61557900E+05, -.35635500E+05, -.14666800E+06, 0.50785000E+04, -.11755500E+06, 0.13859300E+06, -.69112500E+05, 0.23157800E+03, -.69860300E+05, -.15031400E+03, -.19459900E+05, -.16010400E+05, 0.62182600E+03, -.69665400E+05, -.11997300E+05, -.68614200E+05, -.41220500E+05, 0.18595000E+05, -.76298700E+05, 0.22920000E+05, -.59800200E+05, -.83012100E+05, 0.77926700E+05, 0.96910500E+05, 0.14754200E+06, -.81255800E+05, 0.36252100E+05, -.76317700E+05, 0.39895400E+05, 0.85474000E+05, 0.27252800E+05, 0.77272900E+05, 0.10135600E+06, -.64560800E+05, -.10068900E+06, -.10577100E+06, 0.96027600E+05, 0.10870000E+05, -.73930500E+05, 0.39269500E+05, 0.10363100E+06, 0.33183300E+05, 0.78918100E+05, 0.10901400E+06, -.81387600E+05, -.11511200E+06, -.11513500E+06, 0.10404800E+06, 0.12297400E+05, 0.10362100E+06, -.48552100E+05, 0.12165000E+06, -.63226700E+05, 0.12730300E+06, 0.15062000E+06, -.14877400E+06, -.16120000E+06, -.26574200E+06, 0.14842400E+06, -.80436600E+05, -.52265200E+05, 0.25196200E+05, 0.13200600E+06, 0.96998400E+04, 0.10349600E+06, 0.10019300E+06, -.10299600E+06, -.17171100E+06, -.19534100E+06, 0.10626900E+06, -.11105500E+05, 0.71474800E+05, -.35797800E+05, 0.75326900E+04, -.36365100E+05, 0.38011700E+04, -.83578500E+04, -.97412500E+04, -.49066500E+04, -.45217800E+05, -.41395000E+04, -.38965700E+05, 0.25162600E+05, -.12479300E+05, 0.11281100E+04, -.12713100E+05, -.48754100E+02, -.43986200E+04, -.12423800E+04, 0.20033800E+04, -.12171600E+05, -.29162800E+04, -.13599900E+05, -.62330500E+05, 0.31894900E+05, -.95004900E+05, 0.41031200E+05, -.54080300E+05, -.35468400E+05, 0.46598700E+05, 0.71218500E+05, 0.14689700E+06, -.44589300E+05, 0.58733800E+05, 0.10225600E+05, -.69632500E+04, -.10579900E+06, 0.88462000E+04, -.10875100E+06, -.13291900E+06, 0.11158100E+06, 0.15591000E+06, 0.19503900E+06, -.12931600E+06, 0.24688800E+05, -.29520900E+05, 0.20101700E+05, 0.14832000E+06, -.50643100E+04, 0.15111900E+06, 0.20255300E+06, -.15287700E+06, -.16806100E+06, -.22011000E+06, 0.19177200E+06, -.23037700E+05, 0.15048400E+05, 0.77014400E+05, -.42104000E+05, -.55856100E+05, -.49056800E+05, 0.47647200E+04, -.12242500E+05, -.70249100E+05, -.42262000E+05, 0.80007300E+05, 0.10199100E+06, 0.11486200E+05, 0.25138700E+04, 0.53499400E+05, -.76843300E+05, -.11410900E+06, 0.55350800E+05, 0.12958600E+05, -.47804800E+05, 0.19815300E+05, -.29787600E+05, 0.11807500E+06, 0.10288500E+06, -.87495100E+05, 0.38284900E+04, -.18909200E+05 },
        { 0.57452200E+00, 0.29935700E-01, 0.97498700E+00, -.91901800E+04, 0.56677200E+05, 0.51443100E+05, -.36176300E+05, -.63230400E+05, -.10707300E+06, 0.53832600E+05, -.28276700E+05, -.19037700E+05, 0.11303500E+05, 0.31052000E+05, 0.61087600E+04, 0.66517000E+05, 0.89056300E+05, -.87136300E+05, -.11779700E+06, -.11707500E+06, 0.86043200E+05, -.39695600E+04, 0.20448300E+05, -.79660000E+04, 0.22015500E+05, -.12720800E+05, 0.59817800E+05, 0.86279400E+05, -.90304900E+05, -.12508100E+06, -.14678500E+06, 0.84481000E+05, -.14890000E+05, 0.20241400E+06, -.98582200E+05, -.55344400E+05, -.10534200E+06, 0.53132500E+05, 0.68248200E+05, -.94279500E+05, -.71344700E+05, -.17481900E+06, 0.69316100E+05, -.10209600E+06, 0.70448500E+05, -.34125300E+05, -.15668100E+05, -.40752400E+05, 0.79713200E+05, 0.87831300E+05, -.11350900E+06, -.13679000E+06, -.17306000E+06, 0.88663200E+05, -.44077400E+05, -.14098400E+06, 0.65805700E+05, 0.24646200E+05, 0.72957000E+05, -.21251400E+05, -.50400700E+05, 0.53648100E+05, 0.16996600E+05, 0.71421500E+05, -.43030000E+05, 0.53479100E+05, 0.13552700E+06, -.67371100E+05, -.60611400E+05, -.68985400E+05, 0.24877700E+03, -.36061800E+04, -.43426600E+05, -.35796900E+05, -.66653600E+05, -.74203000E+03, -.48253400E+05, 0.23537100E+06, -.11448700E+06, -.87688800E+05, -.13218200E+06, 0.78642500E+05, 0.95583800E+05, -.14439000E+06, -.15344400E+06, -.25522700E+06, 0.95208800E+05, -.10049200E+06, -.11410200E+06, 0.55271000E+05, 0.53977900E+05, 0.63796500E+05, -.54892400E+05, -.53658900E+05, 0.75472400E+05, 0.75295500E+05, 0.13521300E+06, -.55827900E+05, 0.73549200E+05, -.70222300E+05, 0.34173800E+05, 0.18137300E+05, 0.30891200E+05, 0.38146900E+05, 0.33893400E+05, -.20359500E+05, -.50679100E+05, -.36350600E+05, 0.35733600E+05, 0.14040900E+05, -.66522300E+05, 0.32844400E+05, 0.17801800E+05, 0.45404500E+05, -.65767200E+05, -.74629900E+05, 0.98274800E+05, 0.13582700E+06, 0.16884000E+06, -.76481200E+05, 0.34270700E+05, 0.67410400E+05, -.30450000E+05, 0.13133800E+05, -.48458200E+05, 0.95057600E+05, 0.13248500E+06, -.13460900E+06, -.16508200E+06, -.19897100E+06, 0.12515600E+06, -.33952700E+05, 0.19478000E+06, -.95260700E+05, -.63136300E+05, -.98597700E+05, 0.20714900E+05, 0.24804900E+05, -.52786700E+05, -.19732800E+05, -.11339800E+06, 0.26539800E+05, -.90140000E+05, -.32348900E+06, 0.16072400E+06, 0.15077100E+06, 0.16752300E+06, -.79030900E+04, 0.12460200E+05, 0.89445500E+05, 0.67383400E+05, 0.17326600E+06, 0.25108800E+04, 0.13488300E+06, -.18006100E+06, 0.89559900E+05, 0.10427200E+06, 0.90615200E+05, 0.29199200E+04, 0.25746700E+05, 0.25739600E+05, 0.25177800E+04, 0.80079400E+05, 0.16641400E+05, 0.80464100E+05, 0.80941000E+05, -.38326100E+05, -.24545400E+04, -.42867100E+05, 0.54819600E+05, 0.76905800E+05, -.94914900E+05, -.11834200E+06, -.16279700E+06, 0.76467400E+05, -.43153300E+05, 0.39918100E+05, -.21549400E+05, -.54109900E+05, -.86516700E+04, -.69771300E+05, -.91809400E+05, 0.71172000E+05, 0.10728400E+06, 0.11663400E+06, -.88867000E+05, -.10289800E+04, 0.42661600E+05, -.23631100E+05, -.44613700E+05, -.17407100E+05, -.74716500E+05, -.10335600E+06, 0.94375400E+05, 0.13260200E+06, 0.12701900E+06, -.99440700E+05, -.87262900E+04, -.17837100E+06, 0.85918500E+05, 0.42334400E+05, 0.10102300E+06, -.12134200E+06, -.13977900E+06, 0.17881300E+06, 0.19641400E+06, 0.29182600E+06, -.13971500E+06, 0.89399600E+05, -.16269600E+05, 0.90484800E+04, 0.24826500E+05, 0.25171800E+05, -.10063700E+06, -.95678200E+05, 0.13356400E+06, 0.20470200E+06, 0.21870700E+06, -.10182400E+06, 0.21031000E+05, -.10053900E+06, 0.50180200E+05, 0.66184700E+05, 0.50920300E+05, -.26064500E+04, 0.13316400E+05, 0.15273700E+05, 0.50655100E+04, 0.51589700E+05, 0.76570500E+04, 0.48106500E+05, -.33285600E+05, 0.16465000E+05, 0.20983400E+05, 0.16779400E+05, 0.25771600E+03, 0.56168500E+04, 0.21328100E+04, -.39413300E+04, 0.13089300E+05, 0.39481400E+04, 0.16631700E+05, 0.10253700E+06, -.51834100E+05, -.62709800E+05, -.61498000E+05, 0.49525600E+05, 0.26342700E+05, -.57392100E+05, -.78523700E+05, -.15326400E+06, 0.37070200E+05, -.67597800E+05, 0.65552100E+05, -.31084100E+05, 0.17845600E+04, -.47248900E+05, 0.99688700E+05, 0.12134700E+06, -.13686100E+06, -.18267000E+06, -.22172400E+06, 0.12019300E+06, -.40994200E+05, -.14069500E+05, 0.17259200E+04, -.40946600E+05, 0.27587900E+05, -.14346400E+06, -.19049100E+06, 0.16662600E+06, 0.18908700E+06, 0.23400300E+06, -.18224800E+06, 0.31128700E+05, -.24119200E+05, -.85204500E+05, 0.40922800E+05, 0.57352400E+05, 0.59691900E+05, -.32357200E+04, 0.26963800E+04, 0.65254300E+05, 0.40163200E+05, -.80151600E+05, -.10810400E+06, -.66325000E+04, -.83481200E+04, -.60787100E+05, 0.78078400E+05, 0.11450700E+06, -.55650200E+05, -.20169600E+05, 0.48748300E+05, -.17898400E+05, 0.22054000E+05, -.11921800E+06, -.10146900E+06, 0.95450900E+05, -.69513000E+04, 0.25453800E+05 },
        { -.67072600E+00, -.34392100E-01, 0.91538900E+00, 0.45335300E+00, 0.55988200E+05, 0.87409600E+05, -.44979500E+05, 0.28817800E+04, -.15047000E+05, 0.71603900E+05, 0.22808800E+05, -.61045700E+05, 0.32984900E+05, 0.46557000E+05, 0.30497700E+05, 0.63998300E+05, 0.10090000E+06, -.43253400E+05, 0.26813000E+04, -.14272300E+05, 0.87969400E+05, 0.30688700E+05, -.33452100E+05, 0.19610300E+05, 0.41831700E+05, 0.16699800E+05, 0.58504600E+05, 0.99916500E+05, -.38174900E+05, 0.14116300E+05, -.21139100E+05, 0.85689000E+05, 0.17170700E+05, 0.67048100E+05, -.29986500E+05, 0.45899900E+03, -.33533800E+05, 0.68052100E+05, 0.12154700E+06, -.64068100E+05, 0.24455700E+05, -.40331000E+05, 0.10139800E+06, -.15198300E+05, -.12866100E+06, 0.65277800E+05, 0.74504900E+05, 0.64316500E+05, 0.85047400E+05, 0.11240700E+06, -.35295100E+05, 0.85758300E+04, 0.93932500E+04, 0.98441800E+05, 0.50845400E+05, -.18757100E+06, 0.86628600E+05, 0.48891100E+05, 0.93780300E+05, -.18656900E+05, -.68317600E+05, 0.49669200E+05, -.31135500E+05, 0.66413800E+05, -.54327000E+05, 0.70802200E+05, 0.98728500E+04, -.49613300E+04, -.28256600E+04, -.49346700E+04, 0.47370500E+04, 0.44905600E+04, 0.13636300E+05, 0.45629600E+05, 0.11882800E+05, 0.11592600E+04, -.61791400E+04, 0.25460700E+05, -.81460400E+04, 0.86788200E+04, -.12720500E+05, 0.80657600E+05, 0.14603300E+06, -.47451200E+05, 0.55512200E+05, -.25111500E+05, 0.12110100E+06, -.20698900E+02, 0.19075600E+05, -.11642600E+05, -.83681800E+04, -.95416200E+04, -.66764100E+05, -.10500900E+06, 0.46731800E+05, -.17163800E+05, 0.39526500E+04, -.86897900E+05, -.20864200E+05, -.95600300E+05, 0.46549500E+05, 0.28278300E+05, 0.47796000E+05, 0.41247100E+05, 0.46553600E+05, -.17936100E+05, -.16535600E+05, 0.20396000E+05, 0.42931400E+05, 0.46439800E+05, 0.98305400E+05, -.49676500E+05, -.52233900E+05, -.49165300E+05, -.60274300E+05, -.85526300E+05, 0.16875200E+05, -.99188000E+04, -.67006400E+04, -.77049400E+05, -.34142100E+05, 0.89220700E+05, -.39084100E+05, -.23418000E+04, -.44591900E+05, 0.74890100E+05, 0.13916600E+06, -.65552000E+05, 0.43585000E+05, -.62829100E+05, 0.11759100E+06, -.35792800E+05, 0.69201100E+05, -.32410700E+05, -.90354300E+04, -.34605600E+05, 0.34189000E+05, 0.61787200E+05, -.33220600E+05, 0.23508000E+05, -.25898900E+05, 0.49685300E+05, -.26053700E+05, -.43944500E+04, 0.24796200E+04, 0.43282100E+04, 0.21908200E+04, -.28562300E+05, -.36500400E+05, -.13691500E+05, -.87617400E+05, -.32460200E+05, -.23175100E+05, -.80885100E+04, 0.77400100E+05, -.37918000E+05, -.16318400E+05, -.38698200E+05, -.26334500E+05, -.30429400E+05, -.45587200E+04, -.18083900E+05, -.46021000E+05, -.21646900E+05, -.44703400E+05, -.13726700E+05, 0.97141500E+04, 0.35854900E+05, 0.68415800E+04, 0.53974000E+05, 0.98374100E+05, -.35718100E+05, 0.26405700E+05, -.19882200E+05, 0.83384000E+05, 0.13415200E+05, -.57694400E+05, 0.26209800E+05, -.78650000E+04, 0.28837500E+05, -.52505200E+05, -.88942800E+05, 0.59446800E+05, -.48872200E+04, 0.51667700E+05, -.76947100E+05, 0.22656700E+05, 0.71924100E+05, -.39051900E+05, -.54306600E+05, -.35927000E+05, -.74794500E+05, -.11464100E+06, 0.50863800E+05, 0.32937500E+04, 0.17932300E+05, -.10019100E+06, -.28220900E+05, 0.13457100E+06, -.70908500E+05, -.10264800E+06, -.67266200E+05, -.13568100E+06, -.18803800E+06, 0.65658100E+05, -.18366100E+05, 0.41985200E+04, -.16243200E+06, -.35449200E+05, 0.27940800E+06, -.13790700E+06, -.11068100E+06, -.13972800E+06, -.97786800E+05, -.11472300E+06, 0.14711900E+05, 0.47074100E+03, -.50735100E+05, -.10507900E+06, -.11606500E+06, 0.46223100E+05, -.22330900E+05, -.22164100E+04, -.23109100E+05, -.20956500E+05, -.24901000E+05, 0.15345900E+04, -.12701300E+05, -.30683900E+05, -.17473500E+05, -.32664700E+05, 0.99076300E+04, -.48831400E+04, -.17356700E+04, -.49537400E+04, -.42018400E+04, -.38206700E+04, 0.27408400E+03, -.17859200E+04, -.72429300E+04, -.28653600E+04, -.64303900E+04, -.13809500E+06, 0.67069500E+05, 0.45894300E+05, 0.69045700E+05, 0.70030900E+05, 0.87131100E+05, -.21258800E+05, 0.71351100E+04, 0.41916600E+05, 0.74534500E+05, 0.80520800E+05, -.43412300E+05, 0.24241900E+05, 0.49334700E+05, 0.21716500E+05, 0.91357900E+05, 0.13497400E+06, -.50243300E+05, 0.22957600E+05, -.24944300E+05, 0.11703700E+06, 0.15952000E+05, -.21361800E+05, 0.25580200E+04, -.43508900E+05, 0.10639100E+05, -.14030300E+06, -.24752000E+06, 0.14454200E+06, 0.13932600E+05, 0.82949500E+05, -.21255800E+06, -.68989700E+04, 0.85965400E+04, -.36960400E+05, 0.13985100E+05, 0.23854400E+05, 0.21490300E+04, 0.28691000E+05, 0.46555400E+05, 0.88591200E+05, 0.36161400E+05, -.31903700E+05, -.43520200E+05, -.19152300E+05, 0.40348400E+05, 0.16027900E+04, 0.76672600E+05, 0.72114400E+05, -.30760300E+05, 0.63576700E+05, 0.10579700E+05, 0.15196400E+05, 0.66325100E+05, -.67472800E+05, -.85736900E+05, 0.58316900E+05, 0.57909700E+05, -.11963400E+05 },
        { -.42894100E+00, -.80459500E+00, 0.36510700E+00, 0.79554300E+00, -.29268700E-01, -.11005900E+06, 0.54268100E+05, 0.61011700E+05, 0.83148700E+05, -.83553400E+05, -.40994600E+05, -.15607200E+06, 0.71576300E+05, 0.24719700E+05, 0.78087400E+05, -.17414300E+05, -.10282300E+06, 0.83202800E+05, 0.50069600E+05, 0.12709800E+06, -.80444000E+05, 0.31770400E+05, -.13483800E+06, 0.58523600E+05, 0.22062300E+05, 0.67483300E+05, -.29785400E+05, -.12848600E+06, 0.99064800E+05, 0.74106800E+05, 0.13566200E+06, -.10279100E+06, 0.17593100E+05, -.21798800E+06, 0.97941300E+05, 0.79044100E+05, 0.10901000E+06, -.12534500E+05, -.18128300E+06, 0.13794000E+06, 0.90798400E+05, 0.16476100E+06, -.14438900E+06, 0.24731100E+05, -.42828200E+05, 0.19919700E+05, -.30875200E+04, 0.21439300E+05, -.86593100E+04, -.96040400E+05, 0.78938200E+05, 0.10198600E+06, 0.10732500E+06, -.73616600E+05, -.37845500E+05, 0.44118700E+06, -.19738100E+06, -.11117900E+06, -.22058300E+06, 0.21202700E+05, 0.16977300E+06, -.14700600E+06, -.42506000E+04, -.18515000E+06, 0.13678700E+06, -.14659700E+06, 0.47045500E+03, 0.97118500E+02, 0.17849500E+05, -.23838300E+03, 0.92312100E+04, -.98559000E+04, 0.25368300E+05, 0.47789900E+05, 0.16805200E+05, -.60389300E+04, -.30136500E+05, -.29081400E+06, 0.13092600E+06, 0.10730300E+06, 0.14538800E+06, -.40794600E+04, -.24072900E+06, 0.19814200E+06, 0.15317600E+06, 0.24281400E+06, -.19132300E+06, 0.16457500E+05, 0.14842500E+06, -.67151900E+05, -.62575500E+05, -.74204700E+05, -.99039400E+04, 0.11946700E+06, -.91895000E+05, -.67919500E+05, -.12260100E+06, 0.90932000E+05, -.17280200E+05, 0.74549400E+05, -.33012800E+05, -.22460400E+05, -.37266700E+05, 0.10663900E+05, -.25104900E+05, 0.61837700E+04, 0.47292400E+05, 0.25471700E+05, -.19647700E+05, -.48529600E+05, 0.28895800E+05, -.13705900E+05, -.20720000E+05, -.14423300E+05, 0.21786800E+04, 0.10950900E+06, -.94500300E+05, -.13274900E+06, -.11423400E+06, 0.91792700E+05, 0.45807500E+05, -.37540300E+06, 0.17060200E+06, 0.85728600E+05, 0.18767300E+06, -.22063900E+05, -.23256900E+06, 0.19637800E+06, 0.11433200E+06, 0.26022900E+06, -.18554100E+06, 0.73479600E+05, -.90390300E+05, 0.39284400E+05, 0.30924000E+05, 0.45204200E+05, -.14148400E+05, -.10680800E+06, 0.77539800E+05, 0.58296400E+05, 0.79916700E+05, -.84769200E+05, 0.32671300E+04, -.29285600E+05, 0.13665400E+05, -.42928100E+05, 0.14655800E+05, -.27530800E+05, 0.43253300E+05, -.58396200E+05, -.11382700E+06, -.46065800E+05, 0.28371600E+05, 0.83842300E+05, -.64838700E+05, 0.30769200E+05, -.29855900E+05, 0.32415700E+05, -.20285000E+05, 0.20312100E+05, -.15286000E+05, -.53057700E+05, -.64888300E+04, 0.13203400E+05, 0.61350200E+05, -.11610100E+06, 0.49076500E+05, 0.24799700E+05, 0.58100400E+05, -.30739900E+05, -.14245400E+06, 0.10453700E+06, 0.83408300E+05, 0.13774800E+06, -.11265200E+06, -.36843900E+04, 0.12946600E+06, -.57315100E+05, 0.24205900E+05, -.64714200E+05, 0.88974300E+04, 0.11816100E+06, -.91865000E+05, -.83877000E+05, -.13822100E+06, 0.94605500E+05, -.12491500E+05, 0.17736700E+06, -.80035600E+05, -.22786800E+05, -.88760300E+05, 0.22099200E+05, 0.11353000E+06, -.92962200E+05, -.57433300E+05, -.14086500E+06, 0.89828800E+05, -.50635100E+05, 0.13717000E+06, -.59572900E+05, 0.73565100E+04, -.68613300E+05, 0.28845200E+05, 0.20546000E+06, -.15940300E+06, -.16972500E+06, -.20491600E+06, 0.15986500E+06, 0.16194500E+05, -.12239100E+06, 0.54518700E+05, -.11633100E+05, 0.61242100E+05, -.19532800E+05, 0.74166900E+05, -.65911400E+05, -.16969000E+06, -.86770400E+05, 0.58998400E+05, 0.13125400E+06, -.47871100E+05, 0.22003000E+05, -.10559300E+05, 0.23930500E+05, -.16202000E+05, 0.17783100E+05, -.10886400E+05, -.40558000E+05, -.12665200E+05, 0.11380900E+05, 0.45038800E+05, -.22841200E+05, 0.11359300E+05, -.25105000E+04, 0.11420400E+05, -.28429800E+04, 0.29271400E+04, 0.10618900E+04, -.75698100E+04, 0.33369400E+04, 0.17435500E+04, 0.12662000E+05, 0.15739800E+06, -.72426500E+05, 0.36873600E+04, -.78694800E+05, 0.23631800E+05, -.72754800E+05, 0.35303100E+05, 0.11601900E+06, 0.45512900E+05, -.55861700E+05, -.12996700E+06, -.18322400E+06, 0.85019400E+05, 0.10953100E+05, 0.91591200E+05, -.74695800E+03, -.16336200E+06, 0.14585600E+06, 0.14875900E+06, 0.20289900E+06, -.13006600E+06, -.32809800E+04, 0.60046500E+06, -.27375000E+06, -.14792100E+06, -.30015900E+06, 0.79142500E+04, 0.31304300E+06, -.24971400E+06, -.95941000E+05, -.34845000E+06, 0.24796900E+06, -.16021000E+06, 0.57102500E+05, 0.72391700E+05, 0.71613600E+05, 0.75619300E+05, 0.10167700E+05, -.74827900E+05, -.34178700E+05, -.11949800E+06, -.25482400E+05, 0.74921400E+05, 0.97469000E+05, 0.57519100E+05, -.29812800E+05, -.21512600E+05, -.11536200E+06, -.10424900E+06, -.61008200E+05, -.44731100E+05, 0.80951200E+05, -.62498400E+05, -.69837600E+05, 0.97451700E+05, 0.11618800E+06, -.10013500E+06, -.51521300E+05, -.80487300E+04 },
        { -.46317900E+00, -.44007100E-01, 0.17144600E+00, 0.14385000E+00, 0.74876400E-01, 0.12996000E+00, 0.12767000E+05, 0.46923400E+04, -.60040400E+04, -.10640000E+04, -.39857400E+04, 0.21328800E+05, -.99817400E+04, -.89746300E+04, -.10669700E+05, -.15704500E+05, -.19249000E+05, 0.36749000E+05, 0.32051300E+05, 0.52075400E+04, -.20173100E+05, -.15596200E+05, 0.16258800E+04, 0.12266000E+03, 0.12548600E+04, -.81951500E+03, -.76959900E+04, -.10629000E+05, 0.31977000E+05, 0.28481000E+05, 0.78170000E+04, -.11912700E+05, -.13310300E+05, 0.48162400E+04, -.12983700E+04, 0.12877400E+04, -.24097200E+04, -.22440300E+04, -.38191300E+04, 0.26257800E+05, 0.22384800E+05, -.73950100E+03, -.56947300E+04, -.12108200E+05, 0.89639800E+04, -.42381000E+04, -.41278300E+04, -.44845800E+04, -.15823500E+05, -.23778100E+05, 0.48931000E+05, 0.40599500E+05, 0.10560700E+05, -.24166800E+05, -.14555700E+05, -.11691800E+05, 0.36125900E+04, -.29103000E+04, 0.58448200E+04, -.45756500E+04, -.10910200E+05, 0.80809800E+03, -.81232000E+04, 0.47146800E+04, -.81982500E+04, 0.10056900E+05, -.30910800E+05, 0.15498400E+05, 0.15246000E+05, 0.15455800E+05, 0.23383700E+04, -.16232300E+03, 0.15594200E+05, 0.14408700E+05, 0.11747500E+05, 0.90345500E+02, 0.53490100E+04, -.41277400E+05, 0.22057400E+05, 0.22850800E+05, 0.20640800E+05, 0.35192400E+04, 0.33888600E+04, 0.39790300E+05, 0.34201500E+05, 0.14799200E+05, 0.90545900E+03, -.12062300E+04, -.45750900E+04, 0.15684800E+04, 0.33204000E+04, 0.22867300E+04, 0.73458000E+04, 0.99514700E+04, -.30599800E+05, -.22709200E+05, -.58859800E+03, 0.10946500E+05, 0.88512900E+04, 0.38442900E+04, -.23646100E+04, -.58220900E+04, -.19229700E+04, -.86601400E+04, -.12029100E+05, 0.19656700E+05, 0.71944700E+04, -.21451800E+04, -.12336700E+05, -.36442300E+04, 0.38277900E+05, -.19222500E+05, -.15283400E+05, -.19141600E+05, 0.13829100E+04, 0.58015100E+04, -.33918900E+05, -.24037400E+05, -.17886300E+05, 0.66149400E+04, -.42063100E+04, -.15036300E+05, 0.91240800E+04, 0.13853600E+05, 0.75210600E+04, -.23019400E+04, -.16751500E+04, 0.35212400E+05, 0.32820900E+05, 0.11799500E+05, -.45483400E+04, -.10033900E+05, -.11908500E+05, 0.66073500E+04, 0.83597200E+04, 0.59533600E+04, 0.50645500E+04, 0.47153500E+04, 0.95547400E+04, 0.72209100E+04, 0.57384800E+03, 0.35315800E+04, -.17397800E+04, 0.73731900E+05, -.36942500E+05, -.33691000E+05, -.36867300E+05, -.81096900E+04, -.29148800E+04, -.33608000E+05, -.23462700E+05, -.21549200E+05, -.30197600E+04, -.15110800E+05, 0.34910800E+05, -.17378800E+05, -.12764300E+05, -.17455000E+05, -.45129300E+04, -.23359700E+04, -.14385100E+05, -.42244400E+04, -.62636800E+04, -.24239700E+04, -.78019400E+04, -.84822300E+04, 0.51770600E+04, 0.67799400E+04, 0.42360200E+04, -.58538400E+04, -.74825700E+04, 0.31724500E+05, 0.27112400E+05, 0.81123000E+04, -.88890600E+04, -.80169400E+04, -.11257600E+05, 0.49037800E+04, -.21699000E+04, 0.56268100E+04, 0.76801000E+04, 0.94838700E+04, -.21986200E+05, -.17001600E+05, -.69792200E+03, 0.10674800E+05, 0.12468100E+05, -.29686400E+05, 0.13932600E+05, 0.12872100E+05, 0.14851100E+05, 0.17403500E+05, 0.22507300E+05, -.40570500E+05, -.36086600E+05, -.46716500E+04, 0.23529500E+05, 0.22574800E+05, -.11162000E+05, 0.45330500E+04, 0.12864100E+04, 0.55838100E+04, 0.17047600E+05, 0.27275300E+05, -.67587400E+05, -.57901900E+05, -.12309800E+05, 0.28851600E+05, 0.24146700E+05, 0.20470800E+05, -.96443000E+04, -.36673100E+04, -.10240400E+05, 0.18164900E+05, 0.30479500E+05, -.65436700E+05, -.48225200E+05, -.22189200E+05, 0.29386600E+05, 0.69738400E+04, 0.28910700E+05, -.14306600E+05, -.10028900E+05, -.14454800E+05, -.36807200E+04, -.25198200E+04, -.98996900E+04, 0.24177800E+02, -.39765100E+04, -.24601700E+04, -.76413300E+04, 0.60538000E+04, -.30394400E+04, -.21527400E+04, -.30268800E+04, -.10025500E+04, -.89165600E+03, -.12456100E+04, 0.13674200E+04, -.16024300E+03, -.88726400E+03, -.21092500E+04, -.32500700E+05, 0.15711700E+05, 0.95578700E+04, 0.16249900E+05, -.11041400E+04, -.65960400E+04, 0.31845800E+05, 0.11714100E+05, 0.38877600E+04, -.66956200E+04, 0.40219300E+04, -.22491900E+05, 0.11913900E+05, 0.15200200E+05, 0.11248200E+05, -.62734300E+04, -.11299800E+05, 0.45240900E+05, 0.36650500E+05, 0.16097400E+05, -.12799400E+05, -.64655300E+04, -.10260700E+06, 0.48735200E+05, 0.38514900E+05, 0.51296000E+05, 0.33027600E+05, 0.36350900E+05, -.60126800E+05, -.61132800E+05, 0.10356900E+05, 0.38979900E+05, 0.53521500E+05, -.36784700E+04, 0.17926700E+05, 0.69134000E+03, -.90240100E+04, -.15029400E+05, 0.13686800E+04, 0.17146000E+04, -.49281600E+04, -.10758600E+05, 0.10181900E+05, 0.11105800E+05, -.17602000E+05, -.32033500E+04, 0.19257000E+05, -.90288900E+04, -.95577500E+04, 0.76594600E+04, 0.28887600E+04, -.38323800E+04, 0.89188900E+04, -.80678100E+03, 0.11084900E+05, 0.12278500E+05, -.12476200E+05, -.25555900E+04, -.55623800E+04 },
        { 0.16220700E+00, -.14011900E+00, 0.73313800E-01, -.93614300E-01, -.11302500E+00, 0.26495900E-01, -.45410200E+00, -.10508400E+05, -.14681400E+05, 0.22693200E+04, 0.69748600E+04, -.17749800E+05, 0.72823700E+04, 0.27818900E+04, 0.87972400E+04, -.15877600E+04, -.39569400E+04, 0.18875500E+04, -.14907200E+05, -.67205900E+04, -.11590500E+04, 0.14435000E+05, -.10920000E+05, 0.43203400E+04, 0.29640800E+04, 0.53716300E+04, -.13652800E+04, -.42075000E+04, -.14848600E+03, -.16840700E+05, -.11890800E+05, -.60996100E+03, 0.11796700E+05, 0.11144700E+05, -.64498900E+04, -.13624100E+05, -.55985900E+04, -.16844700E+05, -.11281300E+05, -.33961600E+04, -.23173300E+05, -.20625500E+05, -.44969400E+04, 0.12182900E+05, -.96836100E+04, 0.35735100E+04, -.48326600E+04, 0.48005800E+04, -.50299700E+04, -.87147300E+04, 0.18775200E+04, -.18279100E+05, -.14101600E+05, -.40702400E+04, 0.11360900E+05, 0.16890300E+04, 0.26927400E+03, 0.14687600E+05, -.86125100E+03, 0.22752700E+05, 0.85591200E+04, 0.42565200E+04, 0.17576400E+05, 0.37583400E+04, 0.40913300E+04, -.22085400E+05, 0.23639100E+05, -.11725000E+05, -.71467000E+04, -.11814200E+05, -.36363000E+03, -.58647500E+02, -.55681300E+04, -.30973500E+04, -.11882800E+05, 0.25056600E+03, -.67317900E+04, 0.35026900E+05, -.18443500E+05, -.21304500E+05, -.17481900E+05, -.14402800E+05, -.27612600E+03, -.15450100E+05, -.32344800E+05, -.37017100E+05, 0.54920700E+04, 0.98240800E+04, -.11631800E+05, 0.61035500E+04, 0.83002600E+04, 0.58033000E+04, 0.62178200E+04, 0.29285500E+04, 0.28990600E+04, 0.15362000E+05, 0.18383900E+05, -.46142200E+01, -.42251500E+04, -.72236300E+04, 0.35008700E+04, 0.41464400E+04, 0.35991400E+04, 0.40426200E+04, 0.30012300E+04, 0.13060600E+04, -.71644900E+04, -.64841900E+04, 0.35436700E+04, 0.30297100E+04, -.90908400E+04, 0.53478800E+04, 0.63538700E+04, 0.45050100E+04, 0.22901700E+04, -.37150600E+04, 0.10121600E+05, 0.25537300E+05, 0.23363500E+05, -.75014600E+04, -.46129800E+04, -.86949700E+04, 0.30212400E+04, -.11264700E+05, 0.43976500E+04, -.18444400E+05, -.31881000E+04, -.95285000E+04, -.36119600E+05, -.19327200E+05, 0.24270300E+04, 0.27990500E+05, 0.57468100E+04, -.42879700E+04, -.81719400E+04, -.28875000E+04, -.11955700E+05, -.11890200E+05, -.12771600E+03, -.13157300E+05, -.10959300E+05, -.65608800E+04, 0.58738700E+04, -.55076000E+05, 0.27363300E+05, 0.15776700E+05, 0.27516700E+05, -.29657100E+03, 0.29393600E+03, 0.10887500E+05, 0.67801000E+04, 0.30711600E+05, -.10584500E+04, 0.15745600E+05, -.27237200E+05, 0.13512000E+05, 0.53383000E+04, 0.13624200E+05, -.13885000E+04, 0.22431800E+04, 0.19893400E+04, 0.72610600E+03, 0.15452300E+05, 0.81194900E+03, 0.10311500E+05, 0.20315200E+04, -.19057500E+04, -.15035200E+04, -.10864100E+04, -.31444200E+04, -.55495000E+04, -.13523100E+04, -.15233800E+05, -.15866100E+05, -.18458600E+04, 0.80933700E+04, 0.11602000E+05, -.46891600E+04, 0.87170300E+04, -.58313500E+04, 0.67123300E+04, -.21169200E+04, 0.54428200E+04, 0.22850500E+05, 0.12535700E+05, -.54660800E+04, -.15897600E+05, 0.26618000E+05, -.11597000E+05, -.59873300E+04, -.13196800E+05, 0.11537200E+04, 0.49943400E+04, -.32465900E+04, 0.17861700E+05, 0.57963400E+04, 0.15344900E+04, -.16835200E+05, 0.22019400E+05, -.84130300E+04, 0.75144900E+04, -.10960400E+05, 0.13974000E+05, 0.20640000E+05, -.49086800E+04, 0.33201300E+05, 0.20436700E+05, 0.11139600E+05, -.20232700E+05, -.28233500E+05, 0.14359600E+05, 0.36762900E+04, 0.14039600E+05, -.81892800E+04, -.78483900E+04, 0.11466100E+05, 0.22537900E+05, 0.36122300E+05, -.10460000E+05, 0.72625000E+04, -.14440100E+05, 0.71716600E+04, 0.36955800E+04, 0.72276600E+04, -.16875200E+04, -.11272200E+03, 0.13581200E+04, 0.17136000E+04, 0.98286400E+04, -.59533100E+03, 0.42067100E+04, -.31378500E+04, 0.15337200E+04, -.25937600E+02, 0.15692200E+04, -.62736400E+03, 0.59424700E+03, -.21567600E+03, 0.48629800E+02, 0.23170800E+04, 0.24872200E+03, 0.19286200E+04, 0.27495200E+05, -.13752100E+05, -.16855800E+04, -.13753700E+05, 0.60484800E+04, 0.25758400E+04, -.38118800E+04, -.10561300E+05, -.28155600E+05, 0.53643400E+04, -.80867800E+04, -.68692000E+04, 0.19647700E+04, -.11067500E+05, 0.34686000E+04, -.59440700E+04, 0.23176300E+04, -.92854700E+04, -.33788400E+05, -.23845800E+05, 0.73965100E+04, 0.18737900E+05, -.34254700E+04, 0.27026300E+04, 0.22237200E+05, 0.15888400E+04, 0.26955500E+05, 0.54337900E+04, 0.91669000E+04, 0.42180900E+05, 0.28951100E+05, -.20700100E+04, -.29766500E+05, -.23722500E+04, -.55220900E+04, -.65780100E+04, -.72705000E+04, 0.27487600E+04, -.13666300E+04, -.71251700E+04, 0.30699600E+04, -.19437900E+04, -.69977700E+04, -.92217700E+04, -.50117800E+01, -.33125200E+04, -.19108800E+04, 0.39454000E+04, 0.11986900E+05, 0.73377900E+04, -.61704400E+04, -.69037300E+04, 0.14700200E+04, -.12764600E+04, -.12359800E+05, -.90211800E+04, 0.64207300E+04, -.53711400E+04, 0.15609100E+04 },
        { 0.21706500E+01, -.18263400E+01, -.58328400E+00, 0.98849200E+00, 0.11885200E+01, 0.68971300E+00, 0.14845700E+01, 0.18268800E+01, 0.12248500E+06, -.99206200E+04, -.48809100E+05, 0.45032200E+06, -.23197700E+06, -.16107300E+06, -.22493900E+06, -.13814400E+05, 0.56984500E+04, -.12592400E+06, -.51101700E+05, -.52308700E+05, -.49684800E+04, -.20349400E+06, 0.50206600E+06, -.26214500E+06, -.18201800E+06, -.25077500E+06, -.34197600E+05, -.11610600E+01, -.13867400E+06, -.54388300E+05, -.50858400E+05, -.12010100E+05, -.20257800E+06, 0.27073000E+06, -.14986800E+06, -.43895000E+05, -.13529000E+06, 0.35744700E+05, 0.78720600E+05, -.12248700E+06, -.79306600E+05, -.13223600E+05, 0.55398800E+05, -.14116200E+06, 0.45188300E+06, -.22664000E+06, -.16665000E+06, -.22582500E+06, -.16540100E+05, 0.50736900E+04, -.16463600E+06, -.12485100E+06, -.40694100E+05, -.11587900E+05, -.16745900E+06, -.37602800E+06, 0.21901300E+06, 0.60303400E+05, 0.18806000E+06, -.72181900E+05, -.12470200E+06, 0.12170400E+06, 0.25629900E+04, 0.13208800E+06, -.99898700E+05, 0.17455100E+06, -.54711700E+05, 0.26806200E+05, 0.47307900E+04, 0.27341100E+05, 0.54512800E+04, 0.17336500E+05, -.82136500E+05, -.19284200E+06, -.23244600E+05, 0.18958000E+05, 0.47047300E+05, 0.55910100E+06, -.29878600E+06, -.21597100E+06, -.27963800E+06, 0.97317500E+04, 0.49260600E+05, -.23534100E+06, -.18547100E+06, -.70903000E+05, 0.20714200E+05, -.21174200E+06, -.11108900E+06, 0.65313100E+05, 0.36118100E+05, 0.55579300E+05, -.25082500E+05, -.42829700E+05, 0.90784700E+05, 0.10856900E+06, -.17277600E+05, -.29473900E+05, 0.71013200E+05, 0.22948000E+05, -.48777900E+04, -.26719500E+05, -.11438200E+05, -.13073900E+05, -.23786700E+05, -.58615900E+04, -.53955400E+04, 0.53212100E+05, -.26524000E+05, -.19309700E+05, -.49781100E+06, 0.24871700E+06, 0.20537200E+06, 0.24901800E+06, 0.40681500E+05, 0.27039200E+05, 0.15209400E+06, 0.91788600E+05, 0.51132300E+05, 0.39888300E+05, 0.16482400E+06, 0.72749700E+06, -.38549900E+06, -.23603900E+06, -.36388900E+06, 0.18770400E+05, 0.58230800E+05, -.21856500E+06, -.92331000E+05, -.12040300E+06, 0.31083800E+05, -.30415800E+06, 0.12362200E+06, -.68273100E+05, 0.25135000E+04, -.61770300E+05, 0.27595700E+05, 0.65127400E+05, -.73158800E+05, -.58874100E+05, -.10404900E+05, 0.49069400E+05, -.60775600E+05, 0.20775200E+06, -.10331600E+06, -.55589200E+05, -.10381700E+06, -.11387200E+05, -.33559700E+05, 0.14156500E+06, 0.37739500E+06, -.13639300E+05, -.35060300E+05, -.10802000E+06, 0.20466000E+06, -.10427200E+06, -.70936400E+05, -.10234600E+06, -.11672200E+05, -.14953800E+05, 0.26636700E+05, 0.14160800E+06, -.40496200E+05, -.18290400E+05, -.83205200E+05, 0.48793000E+06, -.25565300E+06, -.17454400E+06, -.24376000E+06, -.22175600E+05, 0.97511000E+04, -.15280700E+06, -.84226600E+05, -.54421600E+05, -.22879200E+04, -.20785100E+06, -.25423100E+06, 0.13586000E+06, 0.29352000E+05, 0.12720100E+06, 0.92087300E+04, 0.51267300E+04, 0.49869500E+05, 0.85769300E+04, -.32574300E+05, 0.15883000E+05, 0.12885200E+06, -.50614400E+06, 0.26285100E+06, 0.18038800E+06, 0.25275000E+06, 0.26794100E+05, -.59307700E+04, 0.13313900E+06, 0.36630900E+05, 0.53216600E+05, 0.77299700E+04, 0.20831700E+06, -.79660300E+06, 0.40791500E+06, 0.26885800E+06, 0.39816200E+06, 0.17471400E+05, -.49582400E+05, 0.27480600E+06, 0.15388900E+06, 0.84209300E+05, -.12824700E+05, 0.27112200E+06, -.40425600E+06, 0.19279800E+06, 0.25370200E+06, 0.20234200E+06, 0.71263700E+05, 0.80310900E+05, 0.16597900E+06, 0.19988700E+06, -.33033100E+05, 0.87888900E+05, 0.11653400E+06, 0.16726200E+06, -.86325700E+05, -.62985600E+05, -.83652600E+05, -.11551200E+05, -.70467900E+04, 0.63658600E+04, 0.92635100E+05, -.42439700E+05, -.10791200E+05, -.54518300E+05, 0.62873100E+05, -.31347200E+05, -.22936900E+05, -.31437400E+05, -.34321300E+04, -.59329800E+04, -.40392700E+04, 0.17705200E+05, -.16690700E+05, -.49416100E+04, -.23578600E+05, -.11155000E+06, 0.64400200E+05, 0.50757100E+04, 0.55792400E+05, -.18713200E+05, -.24996200E+05, -.34659400E+05, -.13217200E+06, 0.13568300E+06, -.29563300E+05, 0.28610600E+05, 0.56202700E+06, -.28817500E+06, -.17547400E+06, -.28110800E+06, -.23670100E+05, -.30971100E+04, -.18615700E+06, -.13218000E+06, -.35514500E+05, -.23078200E+05, -.21782500E+06, -.66468700E+06, 0.36845300E+06, 0.19676600E+06, 0.33269000E+06, -.43875200E+05, -.80193800E+05, 0.17164500E+06, 0.28399000E+04, 0.21067200E+05, -.39929600E+05, 0.32449800E+06, -.10658400E+06, -.60887300E+05, -.65092600E+04, 0.26992500E+05, 0.19999600E+05, 0.22146500E+05, -.35364100E+05, 0.21527500E+05, 0.30457400E+05, -.19620300E+05, -.12652000E+05, 0.32222400E+05, 0.29475400E+04, -.31834100E+05, 0.34684600E+05, 0.68798600E+04, -.37209500E+04, -.24581400E+05, 0.26297500E+05, -.13343700E+05, 0.16427200E+05, -.97822200E+04, -.90917700E+04, 0.34571300E+05, 0.35564500E+04, 0.62070300E+05 },
        { -.18369100E+00, -.17938300E+00, -.17918000E-01, 0.73644600E+00, 0.55614700E+00, -.68675500E-01, -.34970300E-01, 0.34145800E+00, 0.16937300E-01, -.59420100E+04, -.13398900E+05, 0.13800100E+05, -.69676400E+04, -.97586500E+04, -.68407200E+04, -.75547500E+04, -.10750200E+05, 0.10719800E+05, 0.11513000E+05, 0.28652600E+04, -.14971100E+05, -.20985100E+05, 0.63581100E+04, -.33482700E+04, -.53126000E+04, -.31119700E+04, -.45177000E+04, -.75110700E+04, 0.87832300E+04, 0.10816200E+05, 0.38034600E+04, -.13007600E+05, -.24118700E+05, -.43346900E+04, 0.20576700E+04, 0.16519100E+03, 0.21876300E+04, -.11626900E+04, -.78774400E+04, 0.92374000E+04, 0.11006000E+05, 0.76599300E+04, -.14943200E+05, -.16658200E+05, 0.11481200E+05, -.56904400E+04, -.54992400E+04, -.57089700E+04, -.61382500E+04, -.76820300E+04, 0.12237300E+05, 0.15042200E+05, 0.46173000E+04, -.13483600E+05, -.21571500E+05, 0.26863200E+05, -.13123400E+05, -.53445700E+04, -.13418900E+05, -.13848600E+04, 0.11582700E+05, -.11371400E+05, -.52939700E+04, -.12528500E+05, 0.12641500E+05, -.28699100E+03, 0.13691300E+05, -.68047000E+04, -.28526700E+04, -.68497000E+04, 0.55188800E+03, 0.18403600E+04, -.11539400E+03, 0.98149200E+04, -.30957300E+04, -.98822300E+03, -.11409100E+05, -.24754700E+05, 0.12249600E+05, 0.10252500E+05, 0.12353300E+05, 0.21918900E+04, -.86035500E+04, 0.16128900E+05, 0.16910400E+05, 0.15123200E+05, -.17030900E+05, -.20044000E+05, -.14271400E+04, 0.79585400E+03, 0.21540700E+04, 0.72310700E+03, 0.10530500E+04, 0.31759400E+04, -.56876900E+04, -.79675500E+04, -.37493100E+04, 0.10236800E+05, 0.15889900E+05, -.74430000E+04, 0.38748300E+04, 0.40464600E+04, 0.37311800E+04, -.11205400E+04, -.12134600E+04, 0.43527900E+04, -.13703100E+04, 0.25101300E+04, -.38429800E+04, -.55283700E+04, 0.15888500E+05, -.80141200E+04, -.86348800E+04, -.79135600E+04, 0.34962800E+03, 0.51513000E+04, -.12724900E+05, -.12052600E+05, -.10566200E+05, 0.10479300E+05, 0.12379300E+05, -.16509000E+05, 0.81105800E+04, 0.15471800E+04, 0.82158300E+04, -.16500000E+04, -.14254000E+05, 0.18603300E+05, 0.15400100E+05, 0.12613700E+05, -.20636000E+05, -.20606900E+05, 0.15528700E+03, 0.74672100E+02, -.90158700E+03, -.66784100E+02, 0.59341800E+03, -.14086700E+04, 0.19336500E+04, 0.54351200E+04, 0.30167300E+04, -.60950400E+04, -.90295600E+04, -.16441900E+05, 0.81804500E+04, -.20007800E+04, 0.82370600E+04, -.33890600E+04, -.88690300E+04, 0.22065500E+04, -.14594100E+05, 0.46634300E+04, -.18002600E+03, 0.22024200E+05, 0.18666800E+05, -.93357200E+04, -.12907500E+05, -.93377000E+04, -.22940200E+04, -.76687200E+04, 0.54890000E+03, 0.76650200E+03, -.61783000E+04, -.27096400E+04, -.40346400E+04, -.19693300E+04, 0.73437700E+03, -.77822000E+03, 0.10384600E+04, -.33805300E+04, -.58590800E+04, 0.87464000E+04, 0.87399100E+04, 0.52818100E+04, -.11605500E+05, -.19406500E+05, -.10358600E+05, 0.51875600E+04, 0.11908500E+05, 0.52024200E+04, 0.30006800E+04, 0.80043300E+04, -.76475900E+04, -.11113400E+05, -.13832900E+04, 0.13762400E+05, 0.20637200E+05, -.20727600E+05, 0.10448200E+05, 0.13786200E+05, 0.10278400E+05, 0.86805700E+04, 0.12263600E+05, -.11272600E+05, -.14309200E+05, -.18053500E+04, 0.17196500E+05, 0.27563500E+05, -.14206100E+05, 0.70786500E+04, 0.10701400E+05, 0.70648500E+04, 0.88131000E+04, 0.12596000E+05, -.17840000E+05, -.24032000E+05, -.91097500E+04, 0.22026200E+05, 0.30246100E+05, -.53906600E+04, 0.25170500E+04, -.50872400E+04, 0.27539100E+04, 0.52511600E+04, 0.60290300E+04, -.15840500E+05, -.17887200E+05, -.68279300E+04, 0.13426200E+05, 0.26136900E+05, 0.11313200E+05, -.57307000E+04, -.72544400E+04, -.56624200E+04, -.18241000E+04, -.61876100E+04, 0.15810700E+04, 0.18919700E+04, -.29014200E+04, -.18386400E+04, -.63261700E+03, 0.52164500E+04, -.25879600E+04, -.45022900E+04, -.26084500E+04, -.49157500E+03, -.13238400E+04, 0.47503100E+02, 0.12874900E+04, -.10469000E+04, -.71609700E+03, -.17250300E+04, -.13778000E+05, 0.70600600E+04, 0.14887200E+05, 0.68936400E+04, 0.10620600E+04, 0.39648900E+04, 0.36239200E+04, 0.47603200E+03, 0.50342900E+04, -.34971100E+04, -.11395600E+05, 0.48412600E+04, -.23391900E+04, -.69585000E+04, -.24463900E+04, -.30186900E+04, -.90464000E+04, 0.13484300E+05, 0.19817800E+05, 0.69650000E+04, -.17678400E+05, -.27984600E+05, -.92234300E+04, 0.50954100E+04, 0.15961800E+05, 0.47064700E+04, 0.11726200E+05, 0.33557200E+05, -.29918300E+05, -.27918500E+05, -.17153100E+05, 0.41264400E+05, 0.31257000E+05, 0.15623600E+04, 0.82441000E+04, 0.16358600E+04, -.24147600E+04, -.29439700E+04, -.23439400E+04, -.57059300E+04, -.19273400E+04, -.62875600E+04, 0.81114100E+04, 0.52311200E+04, -.38114700E+04, -.61143000E+04, 0.27463800E+04, -.49439400E+04, -.35623400E+04, 0.20780900E+04, -.32365100E+04, 0.10117000E+04, -.17054400E+04, -.11376800E+04, 0.60646500E+04, -.12262800E+04, -.45968100E+04, -.39178800E+04, -.22573800E+04 },
        { 0.15192800E+01, 0.14170700E+01, -.97725700E+00, -.23499800E+01, 0.17925400E+00, -.12021600E+01, -.10343600E+01, 0.58712600E+01, 0.15655000E+00, 0.13769400E+01, -.10468100E+06, 0.16794000E+06, -.70875900E+05, -.20284600E+05, -.83685700E+05, 0.18748300E+05, 0.42602400E+05, -.56432800E+05, -.91712000E+04, -.67860800E+05, 0.32460200E+05, -.15398900E+06, 0.13137400E+06, -.53275600E+05, -.24594300E+05, -.65370500E+05, 0.23590900E+05, 0.55619800E+05, -.57317400E+05, -.17914700E+05, -.56795500E+05, 0.41956200E+05, -.13481300E+06, 0.79181700E+05, -.27626800E+05, 0.24982500E+05, -.39492000E+05, 0.92944100E+05, 0.73679500E+05, -.30204000E+05, 0.38858700E+05, -.21939400E+05, 0.47062900E+05, -.20131500E+06, 0.19679200E+06, -.90071600E+05, -.25634600E+05, -.98242800E+05, 0.29568700E+05, 0.56934800E+05, -.73426100E+05, -.15754700E+05, -.75376200E+05, 0.41959800E+05, -.15537300E+06, -.75488100E+05, 0.17089400E+05, -.99266600E+05, 0.37805300E+05, -.13822000E+06, -.72643900E+05, 0.13806500E+05, -.57773100E+05, 0.23359200E+05, -.45446900E+05, 0.22377000E+06, -.44341000E+05, 0.21802100E+05, -.10706600E+04, 0.22150800E+05, -.34737000E+04, -.56012000E+04, -.78654500E+04, -.41519600E+05, 0.10483000E+05, -.10823300E+04, 0.12183600E+04, 0.92723800E+04, 0.96263500E+04, 0.39725500E+05, -.47517600E+04, 0.84825200E+05, 0.26260300E+05, -.15414700E+05, 0.99323600E+04, -.20992500E+04, 0.51998700E+04, -.22400100E+06, -.84145800E+05, 0.35790800E+05, 0.19222400E+05, 0.42118800E+05, -.20897100E+05, -.81309800E+04, 0.19047400E+05, -.12347400E+05, 0.26857500E+05, -.50449800E+04, 0.14695800E+06, 0.52432000E+05, -.28595700E+05, -.33095900E+05, -.26169400E+05, -.32774000E+05, -.22800000E+05, -.38234400E+04, 0.11306300E+05, -.14209200E+05, -.19865500E+05, -.35508300E+05, -.72056800E+05, 0.31167400E+05, 0.19762500E+05, 0.36176200E+05, -.22158500E+05, -.97881300E+04, 0.21207200E+05, -.16161600E+05, 0.18611100E+05, 0.42654900E+04, 0.96062000E+05, 0.13542200E+06, -.50103800E+05, 0.70223000E+05, -.67900400E+05, 0.12665200E+06, 0.73609100E+05, -.39953300E+05, 0.37613000E+05, -.47218800E+05, 0.46956500E+05, -.27047700E+06, 0.79720500E+05, -.28223300E+05, 0.11894300E+03, -.39807700E+05, 0.66710800E+05, 0.75481100E+05, -.33672600E+05, 0.26951900E+05, -.24719300E+05, 0.52431100E+05, -.11178200E+06, 0.80271300E+05, -.39603500E+05, 0.30227200E+05, -.40058300E+05, 0.24085500E+05, 0.28293600E+05, 0.10384700E+05, 0.76118600E+05, -.20961600E+05, 0.15163600E+05, 0.36217500E+05, -.68126200E+04, 0.43224500E+04, 0.75631000E+05, 0.33857500E+04, 0.34848900E+05, 0.24109800E+05, 0.34801600E+04, 0.14993900E+05, -.44437700E+03, 0.16530400E+05, 0.24180800E+05, 0.71143400E+05, -.24393700E+05, -.10346200E+05, -.35316700E+05, 0.34418800E+05, 0.57474500E+05, -.52879900E+05, -.33361200E+05, -.41613500E+05, 0.44418300E+05, -.13379100E+06, -.75294300E+05, 0.27058400E+05, -.80246500E+05, 0.37758600E+05, -.53714400E+05, -.27422300E+05, 0.71515700E+04, -.39172100E+05, 0.21030800E+05, -.13201900E+05, 0.13458100E+06, -.23813800E+06, 0.10386600E+06, 0.42955000E+05, 0.11866200E+06, -.15335300E+05, -.58234000E+05, 0.71907300E+05, -.27589100E+04, 0.89633500E+05, -.43908800E+05, 0.16045200E+06, -.41188600E+06, 0.18529800E+06, 0.59339500E+05, 0.20575500E+06, -.79644600E+05, -.14905400E+06, 0.14313600E+06, -.90495200E+04, 0.15394800E+06, -.10992400E+06, 0.26182800E+06, -.15123100E+05, 0.10248300E+05, 0.83286200E+05, 0.78440000E+04, 0.50419600E+05, 0.36326000E+05, 0.19778500E+05, 0.39360800E+05, 0.34127100E+04, 0.35270700E+05, 0.51888300E+05, -.86612800E+04, 0.55289700E+04, 0.38508300E+05, 0.43027100E+04, 0.28071600E+05, 0.25585200E+05, -.27909800E+04, 0.68267700E+04, 0.35278800E+04, 0.16328100E+05, 0.31171700E+05, -.12084500E+05, 0.60699900E+04, 0.23980300E+05, 0.60412000E+04, 0.81086700E+04, 0.31899200E+04, 0.17516100E+04, -.20512900E+04, 0.82748400E+03, 0.29115400E+04, 0.38471800E+04, -.23193600E+05, 0.80591400E+04, -.81652700E+05, 0.11619000E+05, -.56946100E+05, -.41746800E+05, 0.21463300E+04, -.16600200E+05, 0.13579800E+05, -.36617500E+05, -.56669900E+05, 0.18468600E+06, -.80279700E+05, 0.34415900E+05, -.92466800E+05, 0.43747100E+05, 0.28044600E+05, -.42715800E+05, 0.20404500E+05, -.62848600E+05, 0.10699800E+05, -.21894700E+06, -.14314900E+06, 0.49241300E+05, -.10824600E+06, 0.72034200E+05, -.15160800E+06, -.60921600E+05, 0.15578000E+05, -.96025000E+05, 0.36394200E+05, -.30079500E+05, 0.36111200E+06, -.23749900E+05, -.17460100E+05, 0.40644000E+05, 0.49987900E+05, 0.16147700E+05, 0.10259600E+05, 0.16723100E+05, -.50339200E+04, 0.24572900E+05, -.97458300E+04, -.13609800E+05, -.76258600E+04, -.12127600E+05, -.21747100E+05, 0.61798900E+04, -.14935300E+05, -.44336200E+05, -.15034500E+05, 0.51832600E+05, -.13396900E+05, -.65162500E+03, 0.11372100E+05, 0.15603100E+05, 0.11512400E+05, -.17064000E+04, 0.18148800E+05 },
        { -.23125200E+01, -.22891000E+00, 0.18038800E+01, 0.12998400E+01, 0.41107300E+00, 0.64203900E+00, 0.12761500E+01, -.68188500E+01, 0.99003000E-01, -.21757800E+01, -.40986300E+00, -.32138700E+06, 0.15474600E+06, 0.91067400E+05, 0.16066300E+06, 0.37226000E+04, -.32122100E+05, 0.90149900E+05, 0.22973800E+05, 0.13032600E+06, -.24572300E+05, 0.10300600E+06, -.37337900E+06, 0.18262300E+06, 0.11010100E+06, 0.18667000E+06, 0.96142700E+04, -.40199100E+05, 0.11101300E+06, 0.35612000E+05, 0.15747300E+06, -.31052700E+05, 0.10305900E+06, -.14952300E+06, 0.74219800E+05, 0.71026300E+04, 0.74747900E+05, -.51800300E+05, -.50460900E+05, 0.45986500E+05, -.17639300E+05, 0.50758000E+05, -.31167100E+05, 0.64163500E+05, -.26828700E+06, 0.12859500E+06, 0.77618100E+05, 0.13412200E+06, 0.21589500E+04, -.33444700E+05, 0.98620700E+05, 0.60720200E+05, 0.11013300E+06, -.21545400E+05, 0.59961300E+05, 0.12343300E+06, -.65330300E+05, 0.35419800E+05, -.61725500E+05, 0.10639300E+06, 0.71392500E+05, -.29404300E+05, 0.51439000E+05, -.47563100E+05, 0.50787000E+05, -.87318000E+05, 0.37893000E+05, -.18510800E+05, 0.39302200E+04, -.18943500E+05, 0.71645300E+04, -.33571600E+04, 0.35539500E+05, 0.90842400E+05, 0.71375000E+04, -.59834500E+04, -.44651400E+05, -.13651500E+06, 0.69391700E+05, 0.29406200E+05, 0.68274000E+05, -.52557500E+05, -.26333900E+05, 0.77439800E+05, 0.58174400E+05, 0.72980200E+05, -.11097900E+05, 0.22310500E+05, 0.87171800E+05, -.44753300E+05, -.28842800E+05, -.43592800E+05, 0.12115300E+05, -.16777000E+04, -.25536100E+05, -.97147000E+04, -.25040100E+05, -.35209500E+04, -.29341000E+05, -.56503500E+05, 0.26133600E+05, 0.38810300E+05, 0.28245700E+05, 0.26131900E+05, 0.28184300E+05, 0.45018100E+03, -.13865800E+05, 0.67382500E+04, 0.27137700E+05, 0.58198600E+04, 0.13863000E+06, -.65826800E+05, -.49474800E+05, -.69336500E+05, 0.82865900E+03, -.46595300E+04, -.53247700E+05, -.33742200E+05, -.57455200E+05, -.15975000E+05, -.72701900E+04, -.22204100E+06, 0.11153700E+06, 0.13977000E+05, 0.11105300E+06, -.86046100E+05, -.61928900E+05, 0.80925900E+05, 0.14528300E+05, 0.10138500E+06, -.42046000E+05, 0.65602300E+05, -.82892800E+05, 0.36489800E+05, -.62229400E+04, 0.41440100E+05, -.37038600E+05, -.52111600E+05, 0.35305800E+05, -.59758400E+04, 0.31256700E+05, -.35468000E+05, 0.32358200E+05, -.92020700E+05, 0.45717100E+05, -.98585500E+04, 0.45999100E+05, -.26748300E+05, -.10364400E+05, -.56770500E+05, -.16822900E+06, -.36026700E+04, -.12607500E+04, 0.84882500E+05, 0.81073600E+04, -.32223800E+04, -.32672800E+05, -.40512900E+04, -.26284000E+05, -.22831400E+05, -.15261600E+05, -.46256800E+05, -.17371400E+05, -.15313200E+05, 0.57804200E+04, -.32340100E+06, 0.15906000E+06, 0.97727000E+05, 0.16168100E+06, 0.23194800E+04, -.44073300E+05, 0.10926600E+06, 0.49289200E+05, 0.14477900E+06, -.35274900E+05, 0.89779200E+05, 0.47741200E+05, -.21589500E+05, 0.58691500E+05, -.23886600E+05, 0.31683500E+05, 0.12723400E+05, -.78527700E+04, 0.85711000E+04, -.23223100E+05, 0.36762200E+04, -.48564400E+04, 0.39428700E+06, -.19088500E+06, -.11097200E+06, -.19710500E+06, -.92935400E+04, 0.38365600E+05, -.10524400E+06, -.19245100E+05, -.15667100E+06, 0.28229900E+05, -.11925500E+06, 0.43104700E+06, -.20619000E+06, -.98951600E+05, -.21549300E+06, 0.29074600E+05, 0.93603600E+05, -.16309600E+06, -.77809600E+05, -.18345200E+06, 0.63781300E+05, -.99091100E+05, 0.12014800E+06, -.56429600E+05, -.11675900E+06, -.60116700E+05, -.55107000E+05, -.39057800E+05, -.70486700E+05, -.10687000E+06, -.55512900E+05, -.40577700E+05, 0.41071500E+05, -.69606100E+03, 0.12480400E+04, -.12939500E+05, 0.35115300E+03, -.18312200E+05, -.23094700E+05, -.24913000E+04, -.24972900E+05, -.98045900E+04, -.14739800E+05, 0.10813000E+03, -.11265700E+05, 0.56248600E+04, -.36799800E+04, 0.56329700E+04, -.42742100E+04, -.10619200E+04, 0.51981800E+03, -.52408300E+04, 0.24743800E+04, -.11150700E+04, 0.65031800E+04, -.44491600E+04, -.56363800E+03, 0.59166100E+05, 0.22222700E+04, 0.50264300E+05, 0.40737000E+05, 0.14156300E+05, 0.41366900E+05, 0.27276000E+04, 0.37730700E+05, -.34105900E+05, -.20758700E+06, 0.99512000E+05, 0.22199500E+05, 0.10381100E+06, -.19281300E+05, -.15417600E+05, 0.75049400E+05, 0.46748100E+05, 0.87377800E+05, -.15383900E+04, 0.34682400E+05, 0.19886500E+06, -.10473000E+06, 0.19076500E+05, -.99503600E+05, 0.11418100E+06, 0.45681000E+05, -.31588700E+05, 0.66861800E+05, -.67225300E+05, 0.22121500E+05, -.10661000E+06, 0.39476500E+05, 0.28034000E+05, -.26696300E+05, -.29825400E+05, -.25427800E+05, -.26894700E+04, 0.15120300E+04, -.12448300E+04, -.14631200E+05, 0.23806200E+05, 0.23884500E+05, 0.42174400E+04, 0.97197500E+04, 0.27291300E+05, -.13356000E+05, 0.23921800E+04, 0.27292500E+05, 0.19124200E+05, -.29915900E+05, 0.66805700E+04, 0.11220500E+05, 0.27781100E+04, -.80084300E+04, -.18653700E+05, 0.85109400E+04, -.30393100E+05 },
        { -.22955300E+01, -.22800600E-01, -.13539300E+00, -.38312100E+00, 0.17196400E+01, 0.92015100E-01, -.83319000E-01, 0.42224700E+01, -.38299400E+00, -.41294500E+00, 0.96505100E+00, 0.64000600E-01, -.98776700E+04, -.17149500E+04, 0.35186700E+02, -.55558400E+04, -.28201900E+03, 0.12632200E+05, 0.23067900E+04, 0.16086300E+04, -.91793300E+03, 0.82927800E+04, -.34099500E+05, 0.47406600E+04, 0.15442600E+05, 0.17080700E+05, 0.53974600E+04, 0.13092600E+05, 0.69228600E+04, -.86591100E+04, 0.11109500E+04, 0.10724200E+05, 0.17426600E+05, -.26426500E+05, -.99856000E+03, 0.52369500E+04, 0.13227800E+05, -.29266000E+04, -.13699700E+05, 0.18190400E+05, 0.16057300E+05, 0.22939900E+05, -.10899300E+05, 0.35652900E+05, -.72762700E+04, 0.25643700E+03, 0.37814400E+03, 0.36599500E+04, -.15319900E+05, -.19341900E+05, 0.22473100E+05, 0.71921200E+04, 0.15694900E+05, -.17707400E+05, 0.92090800E+03, -.32090800E+04, 0.31502000E+05, 0.12513800E+05, 0.16130800E+04, 0.21152700E+04, 0.86137000E+03, -.64788900E+04, -.19084900E+05, -.17706200E+04, -.16235500E+04, -.65377800E+05, -.20229700E+05, 0.10285500E+05, 0.85421700E+04, 0.10112000E+05, 0.23524300E+04, 0.25281900E+03, 0.45498200E+04, 0.11174700E+04, 0.92085400E+04, 0.41274200E+03, 0.48333500E+04, -.32090300E+05, -.26459500E+04, 0.11184700E+05, 0.16029200E+05, -.90865600E+03, -.14775600E+05, 0.21472600E+05, 0.21173100E+05, 0.19257100E+05, -.10918800E+05, 0.50175000E+05, 0.22673700E+05, -.23720000E+04, -.11001800E+05, -.11330500E+05, 0.18878000E+04, 0.11206600E+05, -.14992000E+05, -.94258900E+04, -.19279500E+05, 0.93021600E+04, -.11317700E+05, 0.13615700E+05, -.77163000E+03, -.12654400E+04, -.68016000E+04, -.28672400E+03, -.45074700E+04, -.24315200E+03, 0.10257700E+04, 0.30699800E+04, -.44706600E+04, -.26804300E+05, 0.21633700E+05, -.93096200E+04, -.14205700E+05, -.10796400E+05, 0.54034900E+04, 0.20032200E+05, -.20330500E+05, -.11939200E+05, -.14770400E+05, 0.18264300E+05, -.23817300E+04, -.35823200E+05, -.42667600E+04, 0.60057700E+04, 0.17881600E+05, -.58933100E+04, -.19670100E+05, 0.30772800E+05, 0.16331600E+05, 0.17774000E+05, -.16179100E+05, 0.47272000E+05, -.26610300E+05, 0.61026000E+04, 0.82544700E+04, 0.13312200E+05, -.24072600E+04, -.12483200E+05, 0.11682900E+05, 0.72487200E+04, 0.19459200E+05, -.97267900E+04, 0.21183600E+05, 0.44024300E+05, -.22751500E+05, -.24341800E+05, -.22001600E+05, -.54789000E+04, -.11778700E+04, -.72243900E+04, -.27385100E+03, -.20340400E+05, -.12481700E+04, -.83217200E+04, 0.54942200E+04, -.51742500E+04, -.81662300E+04, -.27497700E+04, -.40503900E+04, -.70380700E+03, 0.22366400E+04, -.18672700E+04, -.98387300E+04, -.27903100E+03, 0.10829800E+05, -.25329900E+05, -.15780500E+03, 0.98381800E+04, 0.12692200E+05, 0.58654500E+04, 0.15753300E+05, 0.34601600E+04, -.61416900E+04, 0.17620200E+03, 0.13582200E+05, 0.24833700E+05, 0.52634600E+05, -.16192200E+05, -.14855700E+05, -.26301900E+05, 0.58710700E+04, 0.23601800E+05, -.29066100E+05, -.27962700E+04, -.22094300E+05, 0.20052000E+05, -.20693100E+05, 0.22837300E+05, 0.10225200E+04, -.10832800E+05, -.11465700E+05, 0.40662800E+04, 0.28238000E+04, -.17753700E+05, 0.21389400E+04, -.66675600E+04, 0.34759700E+04, -.34619300E+04, 0.46634000E+05, -.94174100E+04, -.14525400E+05, -.23347100E+05, 0.21433500E+05, 0.40317400E+05, -.41149300E+05, -.13429100E+05, -.38042700E+05, 0.35182000E+05, -.14107700E+05, 0.67475900E+03, -.84284500E+04, -.10174900E+05, -.29764100E+03, 0.12538100E+05, 0.23406900E+05, -.27056900E+05, -.87683300E+04, -.15521600E+05, 0.22783400E+05, 0.28265500E+05, 0.45291300E+03, -.33669000E+04, -.51103100E+04, -.22997900E+03, -.29797300E+04, 0.37015000E+03, 0.18643600E+04, -.14404300E+04, -.66734100E+04, 0.58722200E+03, 0.11997200E+05, 0.83110900E+03, -.43123200E+03, -.33610600E+04, -.41566600E+03, -.41627100E+03, -.72804400E+02, 0.46193300E+03, -.64653200E+02, -.13239500E+04, -.13466200E+03, 0.34376000E+04, 0.91790800E+04, 0.39064600E+04, 0.54150000E+04, -.45868700E+04, 0.89156800E+03, -.38305000E+04, -.11432800E+04, -.57174900E+03, 0.71512700E+04, -.43821200E+04, -.27884300E+05, -.44785400E+05, 0.13269300E+05, 0.16030000E+05, 0.22376000E+05, -.10274000E+05, -.27131900E+05, 0.31972000E+05, 0.11881200E+05, 0.25900300E+05, -.23390300E+05, 0.20923400E+05, 0.61129900E+04, 0.31902100E+05, 0.18746500E+05, -.29888100E+04, 0.23015500E+05, 0.48233800E+05, -.57568300E+05, -.46658900E+05, -.33634400E+05, 0.43146200E+05, -.59066100E+05, 0.25618500E+04, 0.10973100E+05, -.32479600E+04, -.65869300E+04, -.51491800E+04, -.41380600E+04, -.27169100E+04, -.10855300E+05, -.81546200E+04, 0.10472000E+05, 0.12687400E+05, 0.10791700E+03, -.18086700E+04, 0.48640100E+04, -.11605600E+05, -.14246100E+05, 0.40092300E+04, -.31186200E+04, -.55355200E+04, -.80550400E+03, -.89744200E+04, 0.13699500E+05, 0.12851600E+05, -.11915200E+05, -.66957800E+04, -.29176500E+04 },
        { 0.13744400E+01, 0.14151700E+01, 0.14382700E+01, -.41072300E-01, -.19041000E+00, -.14330600E+01, -.12283000E+01, 0.20265200E+01, -.11052200E+00, 0.36480000E+00, -.22002200E+00, -.25427900E+00, -.62359500E+00, -.86734800E+05, 0.18884700E+03, -.11297900E+04, -.18847400E+04, 0.72269100E+04, 0.82558100E+03, 0.60542700E+04, -.58797000E+03, 0.88090400E+04, -.53201700E+05, 0.24577000E+05, -.82121400E+05, 0.26809500E+05, 0.84382400E+04, 0.87478200E+04, 0.80426600E+04, -.67281700E+04, 0.19501600E+05, 0.85098400E+04, 0.31906500E+05, -.31826600E+04, -.10641300E+04, -.91636300E+05, 0.16588600E+04, 0.21842700E+05, 0.51310200E+04, 0.73527700E+04, 0.23016600E+05, 0.10676900E+05, 0.36626800E+04, 0.88151700E+04, 0.10076700E+05, -.33007600E+04, -.43804900E+05, -.49358100E+04, -.12990600E+04, -.11250000E+04, 0.50668400E+04, 0.73448600E+03, 0.41195900E+04, -.23525800E+04, -.26326700E+04, -.11128200E+05, 0.12861400E+05, 0.17859900E+06, 0.56039400E+04, -.22925400E+05, 0.11306800E+05, -.13206400E+05, -.36047500E+05, -.99331000E+04, 0.63486000E+04, -.20470400E+05, 0.21470300E+04, -.10667500E+04, 0.27511200E+04, -.10864700E+04, 0.42885200E+04, 0.65930100E+04, -.39444000E+04, -.14780400E+04, -.19777200E+04, 0.39256300E+04, -.15988400E+04, 0.11655300E+05, -.97508700E+04, -.86878800E+05, -.59030400E+04, 0.19628100E+05, -.12917700E+05, 0.10695700E+05, 0.27386500E+05, 0.72956000E+04, -.10915900E+05, 0.36383200E+04, -.25701300E+05, 0.15065000E+05, 0.21142700E+05, 0.12880300E+05, -.11784100E+05, -.11281600E+05, 0.43132800E+04, -.10263400E+05, 0.59557400E+04, -.69379300E+04, 0.15017900E+05, -.64079600E+04, 0.55621200E+04, 0.49945700E+05, 0.32348100E+04, -.62778900E+04, -.13213700E+02, 0.14830900E+04, -.90421600E+04, -.29066800E+04, -.55926800E+03, -.85321900E+04, 0.10168500E+05, -.64071300E+04, 0.74320600E+04, -.49879000E+04, -.53623800E+04, 0.78338000E+04, -.10790600E+05, -.65406300E+04, -.60356700E+04, 0.90724900E+04, 0.28153000E+04, 0.36850800E+05, -.22684500E+05, -.18019500E+06, -.18553200E+05, 0.18646100E+05, -.17809300E+05, 0.14488500E+05, 0.29138900E+05, 0.12998600E+04, -.14196500E+05, -.64193800E+04, -.61406300E+04, 0.42715300E+04, -.61128200E+05, 0.31059900E+04, 0.14635300E+05, 0.32887900E+04, 0.33635700E+04, 0.11689900E+05, 0.86757000E+04, 0.26459300E+04, 0.57476400E+04, 0.19398700E+05, -.97901300E+04, -.43105800E+05, -.96493700E+04, -.93451400E+04, -.21581200E+05, 0.74654400E+04, 0.53381600E+04, -.33442200E+04, -.12729500E+05, -.56591000E+04, 0.51908100E+05, -.26550500E+05, -.10493000E+06, -.25967800E+05, 0.44657300E+03, -.11957700E+05, -.10982600E+04, 0.11720800E+05, -.13246200E+05, -.86921200E+04, -.17155800E+05, -.54838200E+05, 0.24553500E+05, -.80266400E+05, 0.27588100E+05, 0.10542500E+05, 0.10437900E+05, 0.60223000E+04, -.94878900E+04, 0.19610900E+05, 0.10367400E+05, 0.38426500E+05, 0.55343800E+05, -.26880600E+05, 0.10623300E+06, -.27598800E+05, -.42580300E+04, 0.26395600E+05, -.23865100E+05, -.44069300E+04, -.26573300E+05, 0.20867800E+05, -.24253400E+05, 0.15715300E+05, -.72211400E+04, 0.95700000E+05, -.81268500E+04, 0.36876300E+03, 0.27090300E+04, -.11030600E+05, -.16982100E+04, -.11876500E+05, 0.12574000E+04, -.83100600E+04, 0.24750700E+05, -.13657700E+05, 0.11474700E+06, -.12503900E+05, -.35727900E+04, 0.15269100E+05, -.18800500E+05, -.75156500E+04, -.24071500E+05, 0.12590800E+05, -.10114300E+05, -.37729100E+05, 0.15566600E+05, -.78785700E+05, 0.19048500E+05, 0.98167300E+04, -.14093400E+04, 0.48704000E+03, 0.10315300E+05, 0.12395200E+05, 0.23337900E+04, 0.30769800E+05, 0.30810500E+05, -.16466900E+05, -.75278600E+05, -.15423900E+05, 0.20978400E+04, -.85317800E+04, 0.47133400E+03, 0.97237100E+04, -.64447900E+04, -.56011200E+04, -.76680500E+04, 0.13462400E+05, -.66347600E+04, -.25145900E+05, -.67318600E+04, 0.52561000E+03, -.19119200E+04, -.90623500E+03, 0.34592500E+04, -.27468600E+04, -.16568000E+04, -.37932500E+04, -.39391800E+05, 0.22691400E+05, 0.11185500E+06, 0.19710500E+05, -.36938100E+04, 0.90770700E+04, 0.25545000E+04, -.16762300E+05, 0.87816800E+04, 0.56992400E+04, 0.63824600E+04, -.34983400E+05, 0.17947200E+05, -.10231800E+06, 0.17411600E+05, 0.46701800E+04, -.19723300E+05, 0.19770400E+05, 0.71018200E+04, 0.19935300E+05, -.16599300E+05, 0.16145600E+05, -.35239300E+04, 0.11261500E+05, 0.21235900E+06, 0.20667600E+04, -.14467200E+05, 0.50428600E+05, -.45935700E+05, -.56556400E+05, -.35449300E+05, 0.43034700E+05, -.14691400E+05, -.92603100E+03, 0.51405900E+04, 0.11039700E+05, 0.12412800E+05, 0.83082000E+04, -.27267000E+04, -.26576100E+05, 0.54294300E+04, -.49310700E+04, 0.60184700E+04, 0.50365500E+04, -.21718900E+02, -.10700400E+05, -.41754900E+04, -.59728400E+03, -.14205900E+04, -.14669700E+05, 0.74473200E+04, 0.10012300E+05, -.98216700E+03, 0.17873900E+04, 0.29225300E+04, -.56677700E+04, -.56734200E+04, -.27114200E+04, 0.18921000E+04 },
        { 0.22689100E+01, -.17660300E+00, -.28249800E+00, -.17427100E+00, -.16504500E+01, -.42264100E+00, 0.17353300E+00, -.34662100E+01, 0.31021300E+00, -.90010500E+00, -.69743400E+00, -.26969200E+00, -.39981900E+00, 0.13706500E+00, 0.29575200E+03, -.17085000E+05, -.25455200E+05, 0.16958600E+05, 0.10283500E+05, 0.91901200E+04, -.21383000E+05, -.81917000E+04, 0.39696500E+04, -.41504700E+03, 0.10327700E+03, -.16291000E+04, -.16856700E+05, -.24193200E+05, 0.14382800E+05, 0.13372900E+05, 0.11506200E+05, -.20093600E+05, -.10192200E+05, -.13057600E+05, 0.93779300E+04, 0.51862200E+03, 0.66229400E+04, -.23359000E+05, -.24143500E+05, 0.72132500E+04, -.11337100E+05, -.13159200E+04, -.18498100E+05, -.89751500E+03, 0.43861300E+04, -.35765100E+04, -.73957300E+04, -.20429700E+04, -.10760500E+05, -.15965000E+05, 0.14797700E+05, 0.12121400E+05, 0.13037600E+04, -.12458900E+05, -.95355100E+04, 0.66215500E+05, -.40522200E+05, -.19450600E+05, -.33046200E+05, 0.34766000E+05, 0.43123500E+05, -.17065200E+05, 0.22338400E+05, -.24336900E+05, 0.34011900E+05, -.12890900E+05, 0.74336400E+05, -.37012500E+05, -.21648200E+05, -.37187400E+05, 0.69134200E+03, 0.13875900E+04, -.83991900E+04, 0.20448900E+05, -.24373200E+05, -.45231100E+02, -.35516600E+05, 0.11451300E+05, -.14341400E+04, -.66133000E+04, -.58422100E+04, -.19541500E+05, -.16535900E+05, 0.39366700E+04, 0.75923600E+03, -.19945800E+04, -.12590200E+05, -.22239800E+05, -.59884200E+04, 0.73784900E+03, 0.71573800E+04, 0.30406000E+04, 0.77013000E+04, 0.60677400E+04, -.27367600E+04, 0.23834200E+03, 0.38522100E+04, 0.59553600E+04, 0.48007100E+04, -.17623000E+05, 0.68637700E+04, 0.47490300E+04, 0.88586200E+04, 0.64160900E+04, 0.76489700E+04, 0.48436500E+04, -.21100200E+04, 0.26165800E+04, 0.68337800E+04, 0.10636200E+05, -.80507800E+04, 0.49562400E+04, 0.50515900E+04, 0.41745600E+04, 0.26704300E+04, -.40551800E+04, 0.54876700E+03, -.77726100E+03, 0.29684100E+04, -.56828900E+04, 0.10880500E+05, -.64702400E+04, 0.80128200E+04, -.73887200E+04, 0.30601000E+04, -.35271200E+05, -.36206300E+05, 0.11906000E+05, -.30682300E+04, 0.97864800E+04, -.28436300E+05, -.97282600E+04, -.65394100E+04, 0.31064300E+04, -.94994700E+03, 0.33218300E+04, -.13517600E+05, -.12996500E+05, 0.10912000E+04, -.81913800E+04, -.39467900E+04, -.93021900E+04, 0.49899900E+03, -.13838900E+06, 0.69224400E+05, 0.37870400E+05, 0.69273500E+05, -.71605200E+04, -.12485300E+05, 0.19675000E+05, -.37531800E+05, 0.46064300E+05, -.77299800E+04, 0.64233700E+05, 0.15495700E+05, -.69000300E+04, -.88471100E+04, -.77688700E+04, -.89096600E+04, -.16307900E+05, 0.16019300E+04, -.28576600E+04, -.51346400E+04, -.12215900E+05, -.10841600E+05, -.75457100E+04, 0.58705600E+04, 0.60200900E+04, 0.40520700E+04, -.13973200E+05, -.20552400E+05, 0.13386800E+05, 0.87793200E+04, 0.98534500E+04, -.17002800E+05, -.74411900E+04, -.59677700E+05, 0.28552500E+05, 0.43659800E+05, 0.29950700E+05, 0.15260800E+05, 0.62073700E+04, 0.72813000E+04, -.83387100E+04, 0.14760600E+05, 0.48600800E+04, 0.26950700E+05, -.16167900E+05, 0.74717500E+04, 0.74065600E+04, 0.76485100E+04, 0.22566600E+05, 0.31372000E+05, -.18673600E+05, -.16576400E+05, -.97783800E+04, 0.26503800E+05, 0.12905400E+05, 0.60653300E+04, -.24703000E+04, 0.89003500E+04, -.32032300E+04, 0.25842100E+05, 0.32304800E+05, -.23091500E+05, -.10673800E+05, -.61704200E+04, 0.24877600E+05, 0.96458100E+04, -.63034400E+05, 0.34432400E+05, 0.17286700E+05, 0.31800200E+05, -.10500000E+05, -.14031900E+05, 0.11639400E+04, -.23635800E+05, 0.19133500E+05, -.12467200E+05, 0.33356000E+05, 0.90861500E+04, -.35771800E+04, -.24737500E+04, -.45719200E+04, -.63712600E+04, -.13591000E+05, 0.28190900E+04, -.12080600E+04, -.29910900E+04, -.96444000E+04, -.87903100E+04, 0.33804700E+04, -.16707000E+04, -.24885600E+04, -.16914300E+04, -.21524900E+04, -.20112800E+04, -.63697200E+02, -.10492800E+03, -.10053300E+04, -.17325200E+04, -.22426200E+04, 0.12450400E+05, -.89453400E+04, 0.83611600E+04, -.62017000E+04, 0.15957800E+05, 0.21866200E+05, -.36312200E+04, 0.75525400E+04, -.85632100E+04, 0.19303900E+05, -.39002900E+04, 0.40516900E+05, -.19867200E+05, -.30887700E+05, -.20385100E+05, -.99640100E+04, -.46390900E+04, -.21553600E+04, 0.90464800E+04, -.12042500E+05, -.21449500E+04, -.27517700E+05, 0.10805600E+05, -.14438500E+05, 0.10587200E+05, -.49566000E+04, 0.51714600E+05, 0.55604500E+05, -.23659400E+05, 0.12299500E+05, -.13310000E+05, 0.45704900E+05, 0.96295500E+04, 0.13187000E+04, 0.56372400E+04, -.78638000E+04, -.12728600E+05, -.46320500E+04, -.16472000E+04, -.17898500E+05, 0.28810500E+04, -.60430500E+04, 0.51199600E+04, 0.30080200E+04, 0.22929000E+03, -.82767600E+04, 0.42112900E+04, -.16459000E+03, 0.83145400E+04, 0.13308900E+05, -.79526300E+04, -.84103100E+04, 0.13004100E+04, 0.38029500E+04, -.52799500E+04, -.16942800E+05, -.11801500E+04, -.53943400E+04, -.52555100E+03 },
        { 0.14390500E+00, -.13145900E-01, -.44276100E-01, -.41760200E-02, -.43094200E-01, -.61852200E-02, -.13536200E+00, -.20373100E-01, 0.11541000E-01, 0.71949700E-01, -.15597100E-01, -.15626900E-01, -.26306600E-01, 0.31386300E-02, -.21216900E-01, -.15999500E+04, -.23535700E+04, 0.30617000E+04, 0.16322700E+04, 0.85734900E+03, -.22041400E+04, -.24620500E+03, -.36537500E+04, 0.18975100E+04, 0.18443300E+04, 0.18272300E+04, -.63252000E+03, -.12264900E+04, 0.24917000E+04, 0.72030900E+03, 0.15208900E+04, -.10929200E+04, 0.85929000E+03, -.23146200E+02, 0.16971100E+03, -.19062700E+03, 0.11436200E+02, -.13714800E+04, -.16450100E+04, 0.13725900E+04, 0.64845500E+03, 0.45980800E+03, -.13246700E+04, 0.86485300E+01, 0.16642800E+04, -.90141400E+03, -.12694200E+04, -.83226900E+03, -.19404800E+04, -.30725200E+04, 0.32301400E+04, 0.23977500E+04, 0.74492100E+03, -.27611800E+04, -.10885200E+04, 0.16218100E+04, -.12045000E+04, -.98949200E+03, -.81091900E+03, 0.11422500E+04, 0.38492900E+03, -.33949100E+03, 0.50183300E+03, -.53542800E+03, 0.16295800E+03, -.70940600E+03, 0.18974200E+04, -.94648400E+03, -.85805300E+03, -.94869700E+03, -.40054800E+02, -.55337800E+03, 0.24140500E+03, 0.14648600E+04, -.34222500E+01, -.45500700E+03, -.10098600E+04, -.92081100E+03, 0.69279900E+03, 0.66441200E+03, 0.46043400E+03, -.80476600E+03, -.61312300E+03, 0.10708700E+04, 0.86008000E+03, 0.67229800E+03, -.29591900E+03, -.22648900E+03, -.20528600E+04, 0.90617000E+03, 0.10727700E+04, 0.10264300E+04, 0.12615300E+04, 0.16205400E+04, -.14325900E+04, -.12701300E+04, 0.14778400E+02, 0.14398200E+04, 0.82881400E+03, 0.22853200E+04, -.12337400E+04, -.13777700E+04, -.11426700E+04, -.48710300E+03, -.83096900E+03, 0.90984200E+03, 0.83406700E+03, -.46732600E+03, -.81843400E+03, -.11336900E+04, -.24413000E+03, 0.16208400E+03, 0.24147100E+03, 0.12203100E+03, 0.45089500E+03, 0.77783200E+03, -.11101600E+04, -.10432100E+04, -.29715700E+03, 0.51750000E+03, 0.72580800E+03, -.11067700E+04, 0.81510200E+03, 0.75860600E+03, 0.55369500E+03, -.17290900E+04, -.16492300E+04, 0.20829800E+04, 0.10813900E+04, 0.11347400E+04, -.12483400E+04, -.71036200E+02, -.85849300E+03, 0.44640100E+03, 0.22992300E+03, 0.42920300E+03, -.44721300E+03, -.76486700E+03, 0.33021200E+03, 0.19585000E+03, 0.42731500E+03, -.49348600E+03, 0.32006400E+03, -.51840700E+04, 0.26028800E+04, 0.22424700E+04, 0.25920300E+04, -.68145300E+02, 0.11682600E+04, 0.12165600E+03, -.28875800E+04, 0.41844700E+03, 0.92064100E+03, 0.25170700E+04, -.44465000E+04, 0.22665100E+04, 0.25368500E+04, 0.22232600E+04, -.11909100E+03, 0.11630300E+03, 0.10593900E+04, -.15145500E+04, 0.12720600E+03, 0.30085200E+03, 0.14398300E+04, -.29861500E+04, 0.15846100E+04, 0.16055100E+04, 0.14932500E+04, -.54246200E+03, -.10388700E+04, 0.20891100E+04, 0.83902400E+03, 0.12447700E+04, -.93582500E+03, 0.72583900E+03, -.10845900E+04, 0.46905400E+03, 0.40843400E+03, 0.54225400E+03, 0.11723200E+04, 0.13959100E+04, -.14738000E+04, -.98711600E+03, -.38391900E+03, 0.11449700E+04, 0.62522200E+03, 0.80825100E+03, -.43355600E+03, -.37603900E+03, -.40429400E+03, 0.17448700E+04, 0.26734100E+04, -.36524100E+04, -.16665200E+04, -.12434300E+04, 0.24656200E+04, 0.14944700E+03, -.12354500E+04, 0.63769000E+03, 0.10706700E+04, 0.61809100E+03, 0.27703700E+04, 0.42791200E+04, -.44651500E+04, -.31158100E+04, -.13471900E+04, 0.37036000E+04, 0.11431400E+04, -.41491700E+04, 0.22265200E+04, 0.22589900E+04, 0.20744900E+04, 0.12719400E+04, 0.24231100E+04, -.27851700E+04, -.32343400E+04, -.10949200E+03, 0.23033800E+04, 0.24696900E+04, -.27532900E+04, 0.14209300E+04, 0.16725500E+04, 0.13766500E+04, -.13435000E+03, 0.20238200E+02, 0.71481100E+03, -.98962300E+03, -.74186800E+01, 0.14079100E+03, 0.81317200E+03, -.25130700E+04, 0.12574400E+04, 0.11378100E+04, 0.12565300E+04, 0.87991500E+02, 0.23699700E+03, 0.38202900E+03, -.61450200E+03, 0.48024100E+03, 0.24195400E+03, 0.99140800E+03, 0.38073500E+04, -.20385700E+04, -.19680800E+04, -.19036700E+04, 0.11830100E+03, -.43923100E+03, -.12566100E+03, 0.14540200E+04, -.55534800E+03, -.50098400E+03, -.17782900E+04, -.15289700E+03, 0.10900500E+03, 0.51351900E+02, 0.76447500E+02, -.11646800E+04, -.17716500E+04, 0.22222800E+04, 0.16727300E+04, 0.86816700E+03, -.14015000E+04, -.48241000E+03, -.65104600E+04, 0.27918600E+04, 0.27283900E+04, 0.32548200E+04, 0.49846200E+04, 0.46747000E+04, -.46711100E+04, -.26533800E+04, 0.86897300E+02, 0.42668600E+04, 0.24004800E+04, -.51099600E+03, 0.98062400E+03, -.45212600E+03, -.11220100E+04, -.98688500E+03, -.18971700E+03, -.52159400E+03, -.16951000E+04, -.80375100E+03, 0.81316600E+03, 0.71439800E+03, -.64782400E+03, -.55271700E+03, 0.10583500E+04, -.13013300E+04, -.10118400E+04, 0.10386500E+04, -.51230600E+03, -.74017700E+03, 0.45490600E+03, -.60257600E+03, 0.93870000E+03, 0.51257300E+03, -.93545500E+03, -.63294200E+03, -.14701400E+03 },
        { 0.28721700E+00, -.26825800E-01, -.23661700E+00, -.16641400E+00, -.25660400E+00, -.10614600E+00, -.15147400E+00, -.16125400E+00, 0.65294500E-02, -.19743900E+00, 0.21422400E-01, 0.47516200E-01, 0.27774900E-01, 0.24290900E-01, -.53431300E-01, -.35838300E+00, -.15097900E+04, 0.45484100E+03, 0.52141700E+03, -.77845300E+03, -.11469500E+04, -.87995500E+03, 0.47434400E+04, -.22699100E+04, -.13248700E+04, -.23696400E+04, -.53492500E+03, -.22100700E+04, 0.20982500E+03, 0.19384700E+04, -.15794700E+04, -.18260300E+04, -.26718200E+04, -.68842000E+04, 0.35182400E+04, 0.21297200E+04, 0.34412000E+04, -.18444300E+04, -.36474200E+04, 0.27783000E+04, 0.52601600E+03, 0.22092500E+04, -.34469500E+04, 0.21270100E+04, -.33176900E+04, 0.15741000E+04, 0.48960500E+03, 0.16580900E+04, 0.57158900E+03, 0.51533100E+03, 0.51434500E+03, 0.18589500E+03, -.59283600E+03, 0.55116200E+03, 0.14495600E+03, 0.15328000E+05, -.78898600E+04, -.58579900E+04, -.76640100E+04, 0.31010500E+04, 0.74671500E+04, -.50772100E+04, 0.63577300E+03, -.64601600E+04, 0.64017000E+04, -.51336300E+04, 0.75757300E+04, -.37865000E+04, -.32024100E+04, -.37878000E+04, -.62053900E+03, 0.65368600E+02, -.75880100E+03, 0.25517600E+04, -.18409600E+04, -.40705800E+03, -.28704100E+04, -.73173600E+04, 0.37668100E+04, 0.25942000E+04, 0.36586800E+04, -.10689400E+04, -.31140300E+04, 0.29178900E+04, 0.13346000E+04, 0.32293100E+04, -.28669300E+04, 0.11454500E+04, 0.24019100E+04, -.12585500E+04, -.49949800E+03, -.12009100E+04, 0.66164600E+03, 0.12682800E+04, -.12583100E+04, -.38202500E+03, -.38106900E+03, 0.13975400E+04, -.76930900E+03, -.11543300E+04, 0.47541600E+03, 0.76289400E+01, 0.57709800E+03, 0.61221800E+03, 0.92859900E+03, 0.64508200E+03, -.12746700E+03, -.36386300E+03, 0.90163000E+03, 0.40162900E+03, 0.72617700E+04, -.35654800E+04, -.22304800E+04, -.36308700E+04, -.14710700E+04, -.13382000E+04, -.98142300E+03, 0.91193300E+02, -.13097700E+04, -.11944900E+04, -.16095200E+04, -.12038700E+05, 0.61389100E+04, 0.45906100E+04, 0.60211600E+04, -.12371800E+04, -.42990000E+04, 0.32569400E+04, 0.44250800E+03, 0.38683100E+04, -.35692700E+04, 0.34658000E+04, -.37223500E+04, 0.17517300E+04, 0.90660300E+03, 0.18608700E+04, -.14634300E+04, -.19944000E+04, 0.14376500E+04, 0.48322600E+03, 0.14497800E+04, -.20645400E+04, 0.15353800E+04, -.16577300E+05, 0.82994500E+04, 0.67758800E+04, 0.82888000E+04, 0.13911900E+04, -.64717400E+03, 0.15795900E+04, -.56432700E+04, 0.37546900E+04, 0.53170800E+03, 0.60457700E+04, -.48584300E+04, 0.24785700E+04, 0.91216200E+03, 0.24292500E+04, 0.12178700E+04, -.59231700E+03, 0.18192500E+03, -.14652200E+04, 0.12894600E+04, 0.18728500E+02, 0.81207900E+03, 0.49348900E+04, -.23193900E+04, -.15765100E+04, -.24664200E+04, -.89285400E+03, -.26764600E+04, 0.49066600E+03, 0.23432500E+04, -.89862600E+03, -.23025900E+04, -.30435800E+04, -.10369000E+04, 0.51265400E+03, 0.17492500E+04, 0.51833400E+03, -.60771700E+03, -.33830200E+03, 0.63954100E+03, -.13559100E+04, 0.91430000E+03, -.18477700E+03, 0.11685900E+04, -.14819200E+04, 0.71512200E+03, 0.56258000E+03, 0.73993000E+03, 0.11574100E+03, 0.17582500E+04, -.42678600E+03, -.90811700E+03, 0.14097200E+04, 0.13640300E+04, 0.11792000E+04, 0.80686900E+04, -.39350900E+04, -.21475200E+04, -.40320300E+04, 0.34600800E+03, 0.11210600E+04, -.21996600E+04, -.33330200E+03, -.10719700E+04, 0.89235700E+03, -.13441200E+04, -.81800300E+03, 0.53106100E+03, -.12983500E+03, 0.40891400E+03, -.26567300E+04, -.41845600E+04, 0.14059400E+04, -.60839200E+03, 0.29137400E+04, -.37367100E+04, 0.17319600E+04, -.48559300E+04, 0.24974500E+04, 0.18142700E+04, 0.24279800E+04, 0.86318400E+03, -.48518900E+03, 0.38975600E+03, -.13323100E+04, 0.10940200E+04, 0.16726200E+02, 0.85521700E+03, -.16601200E+04, 0.82932800E+03, 0.14155000E+02, 0.83004700E+03, 0.48511800E+03, 0.14578700E+03, 0.13173500E+03, -.22767700E+03, 0.52033300E+03, 0.19639400E+03, 0.32343300E+03, 0.38027100E+04, -.20395900E+04, -.86170700E+03, -.19013100E+04, 0.29114700E+03, 0.20322800E+04, -.13690700E+03, 0.16976900E+04, -.13097400E+04, 0.15882700E+04, -.12866800E+04, -.44115700E+04, 0.21511500E+04, 0.10525500E+03, 0.22055700E+04, 0.14222600E+04, 0.89556100E+03, 0.43327000E+03, 0.89848000E+03, -.93537200E+02, 0.75509800E+03, 0.53262700E+01, 0.16908300E+05, -.87914100E+04, -.80661000E+04, -.84561700E+04, 0.16516800E+04, 0.59917900E+04, -.41012600E+04, 0.18177900E+04, -.34351700E+04, 0.48155300E+04, -.44512000E+04, 0.21621400E+04, 0.96935400E+03, 0.93683500E+03, 0.78499000E+03, 0.18663900E+03, -.83382600E+03, -.99585400E+03, -.26055600E+03, -.54900700E+03, 0.74506900E+03, 0.43604400E+03, 0.69145500E+03, -.54175400E+03, -.29702000E+03, -.55703900E+03, 0.46799200E+02, -.47160800E+03, -.56255700E+03, 0.10252600E+04, -.71250700E+03, 0.11000900E+03, 0.25106000E+03, -.87379900E+03, -.37135600E+03, -.59897900E+03, -.76719000E+03 },
        { -.37940200E+00, -.25324500E+00, 0.45857400E+00, 0.10813300E+00, -.12658500E-01, 0.33176300E+00, 0.78162000E+00, -.98175100E+00, -.39580200E-01, -.44209700E+00, -.14903300E-01, 0.29886700E-01, 0.89561400E-01, 0.58121500E-02, -.26741100E+00, 0.16644100E+01, 0.11298000E+01, -.79049900E+04, -.68636900E+04, 0.15188200E+04, 0.77317500E+03, -.95832200E+03, 0.16006900E+05, -.74725700E+04, -.60405600E+04, -.80010800E+04, -.42663000E+04, -.47708800E+04, -.64410400E+04, -.35672400E+04, -.10305000E+04, -.34536400E+04, -.68685500E+04, 0.71463400E+04, -.26892200E+04, -.33750600E+04, -.35732500E+04, -.71811000E+04, -.11873400E+04, -.88746200E+04, -.14472600E+05, -.82894000E+04, 0.12682700E+04, -.14338200E+04, 0.10869800E+04, -.10278500E+04, -.32398000E+04, -.54429800E+03, -.50448800E+03, -.14422500E+04, -.94086900E+04, -.11607400E+05, -.18066800E+04, 0.74520300E+02, 0.15131900E+04, -.13787100E+05, 0.44705500E+04, 0.92530500E+04, 0.68927900E+04, 0.11972700E+05, 0.18891900E+03, 0.81121900E+04, 0.11478600E+05, 0.79298700E+04, -.81409700E+03, 0.45060400E+04, 0.89186700E+04, -.44382200E+04, -.85815400E+03, -.44591200E+04, 0.11840900E+04, 0.15279700E+04, -.59117800E+04, -.92465300E+04, -.78463200E+04, 0.19231000E+04, -.33524600E+04, 0.41974800E+05, -.19647800E+05, -.19294400E+05, -.20986100E+05, -.91493800E+04, 0.16985600E+04, -.18250100E+05, -.17889200E+05, -.18930300E+05, 0.23908100E+04, -.13424100E+05, -.98713000E+03, -.23110500E+03, 0.13534000E+04, 0.49291700E+03, -.11663300E+04, -.58828400E+04, 0.97397800E+04, 0.11793400E+05, 0.59845200E+04, -.60457800E+04, -.85070600E+03, -.15025500E+05, 0.67865900E+04, 0.63070100E+04, 0.75124800E+04, 0.54384400E+04, 0.53978200E+04, -.32110900E+04, -.40487800E+04, 0.27115700E+04, 0.50050100E+04, 0.80416000E+04, -.27679900E+05, 0.14213400E+05, 0.12500700E+05, 0.13838300E+05, 0.47460500E+04, 0.52925100E+02, 0.12172300E+05, 0.11406600E+05, 0.98359600E+04, -.10208300E+04, 0.73226100E+04, 0.28429500E+05, -.12726400E+05, -.17114800E+05, -.14213000E+05, -.12875200E+05, -.15210500E+03, -.16222300E+05, -.17119400E+05, -.10989500E+05, 0.77868100E+03, -.72457700E+04, 0.29556800E+04, -.17413600E+04, -.10163300E+04, -.14777300E+04, -.61633500E+04, -.39372300E+04, -.24107000E+04, -.83192200E+04, -.57822400E+04, -.16274300E+04, -.20821600E+03, -.13173200E+05, 0.66234800E+04, -.34276400E+03, 0.65855900E+04, -.41388200E+04, -.42524700E+04, 0.10216500E+05, 0.17734900E+05, 0.15283400E+05, -.49307600E+04, 0.48096700E+04, 0.11000800E+05, -.52388300E+04, -.61142000E+04, -.55003500E+04, -.46558700E+04, -.18635400E+04, -.60376100E+03, 0.71505200E+04, 0.28421800E+04, -.27954000E+04, -.40586500E+04, 0.16197800E+05, -.73234000E+04, -.50242000E+04, -.80975200E+04, -.38456900E+04, -.40837900E+04, -.70567200E+04, -.54075100E+04, -.40176500E+04, -.27950800E+04, -.77321000E+04, -.10806500E+05, 0.50482600E+04, 0.94088700E+04, 0.54021700E+04, 0.57907600E+04, -.15809100E+04, 0.78901700E+04, 0.79403600E+04, 0.28248800E+04, -.22743200E+04, 0.23396200E+04, -.37615600E+04, 0.17038600E+04, 0.19486800E+04, 0.18800900E+04, 0.11727100E+04, 0.98092100E+03, 0.85261000E+04, 0.59650400E+04, -.24783700E+04, -.38545100E+02, 0.10838000E+04, -.99266400E+04, 0.52299800E+04, 0.93139100E+04, 0.49643000E+04, 0.61448500E+04, 0.52527300E+04, 0.14081900E+05, 0.18362100E+05, 0.54132100E+04, 0.22299600E+04, -.76760500E+03, -.21912700E+05, 0.11984300E+05, 0.74256600E+04, 0.10952800E+05, -.56879900E+04, -.48979600E+04, 0.16263600E+05, 0.12929200E+05, 0.89610600E+04, -.52581900E+04, 0.56901200E+04, 0.12179800E+05, -.57281100E+04, -.52489100E+04, -.60898700E+04, -.38336600E+04, -.25066300E+04, -.75205100E+03, 0.52441700E+04, 0.89819900E+03, -.27847400E+04, -.50588900E+04, 0.76348500E+04, -.38237500E+04, -.28504400E+04, -.38174200E+04, -.16768400E+04, -.90091300E+03, -.11007500E+04, 0.16768000E+04, -.12874900E+04, -.96781700E+03, -.28061800E+04, -.60540300E+04, 0.20566800E+04, 0.70554900E+04, 0.30269900E+04, 0.70781200E+04, 0.46422100E+04, -.38419800E+04, -.64660900E+04, -.45167900E+04, 0.51815500E+04, 0.36386000E+04, 0.23674800E+05, -.11843700E+05, -.14809400E+05, -.11835900E+05, -.56499700E+04, 0.10855000E+04, -.14792100E+05, -.15923200E+05, -.82723300E+04, 0.21410200E+04, -.55725200E+04, -.10149700E+05, 0.20010700E+04, 0.11765700E+05, 0.50702700E+04, 0.75012100E+04, -.10082200E+05, 0.23892200E+05, 0.22218300E+05, 0.61438800E+04, -.10696700E+05, 0.77898700E+03, -.37368300E+04, -.52368300E+04, -.50456400E+04, -.31386700E+04, 0.19440200E+04, 0.99598400E+03, -.43974700E+04, 0.57028400E+04, 0.17177700E+04, -.42495400E+04, -.47966500E+04, 0.33585600E+04, -.51214000E+03, -.24925600E+04, 0.57227500E+04, 0.89857300E+04, 0.41734800E+04, -.20006500E+04, -.33134700E+04, -.20349800E+03, 0.16016600E+04, -.88251800E+04, -.68794900E+04, 0.54535700E+04, 0.15372200E+03, 0.28903600E+04 },
        { -.52934600E+00, 0.37810700E-01, 0.26811700E-01, -.10164300E+00, 0.28640500E-01, 0.73811900E-01, 0.63458600E+00, -.68898400E+00, -.85719900E-01, -.84131200E+00, 0.13301000E+00, 0.28301300E+00, 0.16636800E+00, -.94121100E-01, 0.63052000E-02, -.30311700E+01, -.12162700E+01, -.87448300E+00, 0.64135800E+04, 0.42192700E+03, 0.15675300E+04, -.45488500E+04, 0.28454500E+05, -.13709000E+05, -.75389600E+04, -.14224300E+05, -.47333900E+04, -.52423900E+04, 0.18524800E+03, 0.12027000E+05, -.71386100E+04, -.28680200E+04, -.18379700E+05, -.92900600E+04, 0.50180300E+04, 0.61615800E+03, 0.46442200E+04, -.81878500E+04, -.40694500E+04, 0.27188000E+04, -.17573500E+04, 0.98940700E+03, -.11609700E+04, 0.15147600E+04, -.41468800E+05, 0.20315100E+05, 0.13272000E+05, 0.20733300E+05, -.39160900E+03, -.23307500E+04, 0.89582300E+04, 0.29054100E+04, 0.13794000E+05, -.26077100E+03, 0.12076000E+05, -.54452300E+04, 0.16804600E+04, 0.16839800E+05, 0.27222100E+04, 0.10019400E+05, 0.53665400E+03, 0.20228100E+04, 0.16050000E+04, 0.26220300E+04, -.10697800E+04, -.19044100E+04, -.42395300E+05, 0.21134900E+05, 0.20109800E+05, 0.21197800E+05, 0.14222700E+04, 0.91001300E+03, 0.11489700E+05, 0.51351200E+03, 0.14270200E+05, 0.18715600E+04, 0.13063600E+05, -.16029400E+05, 0.85172500E+04, 0.34701600E+04, 0.80154000E+04, -.64242200E+04, 0.67912200E+03, 0.77178500E+04, 0.68107700E+04, 0.66647800E+04, 0.21676900E+04, 0.35369600E+04, 0.16671900E+05, -.86201100E+04, -.54149700E+04, -.83362700E+04, -.12875000E+04, -.40501200E+04, -.95927800E+03, 0.89792600E+03, -.41045700E+04, -.42398900E+04, -.53215000E+04, -.94006200E+04, 0.43086600E+04, 0.44038400E+04, 0.47001100E+04, 0.49239700E+04, 0.30448200E+04, -.17158800E+04, -.15849500E+04, 0.25096200E+04, 0.25395000E+04, 0.41128600E+04, 0.16457000E+05, -.79418700E+04, -.77666800E+04, -.82294000E+04, 0.30698100E+04, 0.11558400E+04, -.60267100E+04, -.33555800E+04, -.58356500E+04, -.60338000E+03, -.30443500E+04, -.25960200E+05, 0.13546400E+05, -.24049800E+04, 0.12982600E+05, -.63631700E+04, 0.17509000E+04, 0.49912500E+04, 0.22488300E+04, 0.78929700E+04, 0.39776900E+04, 0.74657700E+04, -.69119900E+04, 0.30709700E+04, 0.21276300E+04, 0.34557900E+04, -.81750900E+04, -.66365300E+04, 0.41343600E+04, -.19970900E+04, 0.70076600E+03, -.41093000E+04, 0.87582600E+03, 0.63157400E+05, -.31439800E+05, -.33644500E+05, -.31579100E+05, -.24958400E+04, -.13951900E+04, -.19262100E+05, -.22221900E+04, -.21091800E+05, -.23227800E+04, -.18443800E+05, 0.63029600E+04, -.30153700E+04, -.15902100E+05, -.31514300E+04, -.93944000E+03, 0.38781800E+04, -.57718500E+04, 0.47706400E+01, 0.14023300E+04, 0.24707700E+04, 0.32894900E+04, 0.23078800E+05, -.10869300E+05, -.46920300E+04, -.11537800E+05, -.53603100E+04, -.55327500E+04, 0.22323500E+04, 0.12569700E+05, -.55863500E+04, -.31299200E+04, -.15869500E+05, 0.19563300E+05, -.98116500E+04, 0.29429700E+04, -.97823200E+04, 0.14091000E+04, -.34480000E+04, 0.22754600E+03, 0.46052500E+04, -.44980500E+04, -.49821400E+04, -.55922800E+04, -.10883400E+05, 0.52786600E+04, 0.42195000E+04, 0.54404700E+04, 0.83922500E+03, 0.95223600E+03, 0.18992000E+04, -.73861400E+04, 0.26673800E+04, -.89630500E+03, 0.10218800E+05, 0.53255400E+05, -.26162400E+05, -.13266000E+05, -.26625200E+05, 0.54142300E+04, 0.71771200E+04, -.12982200E+05, -.26397000E+04, -.17920200E+05, 0.33434600E+04, -.13914800E+05, 0.49357900E+05, -.24100100E+05, -.29651000E+05, -.24680900E+05, -.76650100E+04, -.45452700E+04, -.95481000E+04, -.45258400E+04, -.16544300E+05, -.55767100E+04, -.12528400E+05, 0.51089700E+04, -.23385600E+04, -.95694900E+04, -.25544500E+04, -.13112600E+04, 0.20827300E+04, -.35527700E+04, 0.46173200E+03, 0.88217400E+03, 0.11851900E+04, 0.12566100E+04, 0.64730900E+03, -.33078200E+03, -.33713800E+04, -.32366000E+03, -.79906200E+02, 0.66111900E+03, -.42578900E+03, 0.88085300E+03, 0.77747100E+03, 0.57126800E+03, 0.10442800E+03, -.10390900E+05, 0.46495600E+04, 0.15625200E+05, 0.51954800E+04, 0.30562300E+04, -.89314900E+03, 0.39483200E+04, 0.17621800E+04, 0.24288100E+04, -.52369300E+03, 0.54472800E+03, -.44466100E+05, 0.22003500E+05, 0.57678300E+04, 0.22233700E+05, -.41667800E+03, 0.22831800E+04, 0.85935000E+04, 0.72247300E+03, 0.15251900E+05, 0.42185000E+04, 0.13503000E+05, 0.33767300E+05, -.18348100E+05, 0.39830600E+04, -.16887900E+05, -.52387600E+03, -.11076800E+05, 0.69347100E+04, 0.76777800E+04, -.65309600E+04, -.12877300E+05, -.13222000E+05, 0.60104700E+04, 0.17798300E+04, -.27173800E+04, -.36361300E+04, -.30619600E+04, 0.12281200E+04, 0.34361800E+04, 0.25742400E+04, -.12865600E+03, 0.15220800E+04, 0.19626200E+04, 0.10297300E+04, 0.32941600E+04, 0.40603200E+04, -.23839300E+02, -.93673300E+03, 0.43253300E+04, 0.60599500E+04, -.25426900E+04, 0.16600600E+04, 0.10175600E+04, 0.42000300E+03, 0.62340500E+04, -.17505700E+04, 0.36177600E+04, -.40767800E+04 },
        { -.23498000E+01, -.55744400E+00, 0.40608500E+00, 0.52867300E+00, 0.99405100E+00, 0.53729300E+00, 0.72817400E+00, 0.16061500E+01, 0.35881600E-01, 0.78602000E+00, 0.20402100E+00, 0.14767500E+00, -.25264600E+00, -.13546400E+00, 0.18109100E+00, -.17688100E+01, -.21226500E+01, -.23267900E+01, 0.20276900E+01, 0.15346900E+05, -.16613700E+04, 0.81475300E+04, -.25729800E+05, 0.11823400E+05, 0.52329800E+04, 0.12860200E+05, 0.33094400E+04, 0.26708300E+04, 0.21163700E+04, -.33436600E+04, 0.23903900E+05, 0.36765200E+02, 0.20193400E+05, 0.13297100E+05, -.81749900E+04, 0.51351500E+04, -.66465300E+04, 0.16232100E+05, 0.88707400E+04, -.52342400E+04, 0.55906600E+04, -.34130300E+04, 0.69398600E+04, 0.17175000E+04, 0.68216800E+05, -.33059000E+05, -.17936500E+05, -.34106700E+05, -.24748600E+04, -.27507300E+04, -.11690200E+05, 0.48960800E+04, -.94904400E+04, -.42761400E+04, -.22912700E+05, -.11763300E+05, 0.99534200E+04, -.14620600E+05, 0.58817000E+04, -.16822400E+05, -.10278900E+05, 0.77131500E+03, -.10325900E+05, 0.49331300E+04, -.79320000E+04, -.47831200E+04, 0.66265900E+05, -.32783100E+05, -.22233000E+05, -.33133100E+05, 0.22102400E+03, -.29046500E+04, -.15150300E+05, -.60721600E+03, -.29728000E+05, -.19101800E+04, -.26548200E+05, 0.42329400E+05, -.23381800E+05, -.99780900E+04, -.21164800E+05, 0.62159100E+04, -.75337000E+04, -.58570700E+04, 0.59315300E+04, -.11022000E+05, -.72457900E+04, -.59524600E+04, 0.71240900E+04, -.23372500E+04, -.72891600E+04, -.35621100E+04, -.61921200E+04, -.21467300E+04, 0.33809600E+04, 0.51303000E+04, 0.88035300E+03, -.32825300E+04, -.48540800E+04, -.25999400E+05, 0.13752300E+05, 0.12248600E+05, 0.12999900E+05, -.14627800E+04, 0.49593100E+04, -.33332500E+04, -.11111800E+05, 0.55516500E+04, 0.38119300E+04, 0.83773100E+04, -.43640300E+05, 0.21249300E+05, 0.14026800E+05, 0.21820200E+05, 0.63334000E+04, 0.14078400E+05, 0.34138900E+03, -.11077000E+05, 0.44733100E+01, 0.15568300E+05, 0.13926300E+05, 0.52981200E+05, -.29118600E+05, -.15959800E+04, -.26494800E+05, 0.10824800E+04, -.11491100E+05, 0.24518200E+04, 0.16766500E+05, -.10770000E+04, -.13578200E+05, -.99622200E+04, 0.13749500E+05, -.69681900E+04, 0.40379800E+03, -.68740800E+04, 0.13412700E+05, 0.82571200E+04, -.44695500E+04, 0.40084900E+04, -.80637700E+04, 0.69633600E+04, -.26781600E+04, -.82408100E+05, 0.40479500E+05, 0.24757100E+05, 0.41203800E+05, -.31778400E+04, 0.30771100E+04, 0.26152600E+05, 0.15601700E+05, 0.50885500E+05, -.84648800E+03, 0.33633000E+05, 0.40517100E+05, -.20428800E+05, 0.34072800E+04, -.20258700E+05, -.65226700E+04, -.13674100E+05, 0.79612500E+04, 0.21943500E+05, -.30974900E+04, -.11909100E+05, -.20377100E+05, -.25850400E+05, 0.11822900E+05, 0.63440900E+04, 0.12922900E+05, 0.66462800E+04, 0.68409100E+04, -.15031400E+04, -.80810700E+04, 0.16934200E+05, 0.44206100E+04, 0.21813000E+05, -.16707400E+05, 0.89858500E+04, -.76424600E+04, 0.83540600E+04, 0.47221000E+04, 0.18200700E+05, -.12202800E+05, -.15414500E+05, -.10369000E+05, 0.18604300E+05, 0.36232800E+04, 0.13418600E+05, -.62146900E+04, -.46910400E+04, -.67069600E+04, -.34288100E+03, 0.11560200E+04, -.31724300E+04, -.72807100E+03, -.24465900E+05, 0.31780700E+04, -.12399100E+05, -.92022000E+05, 0.45316200E+05, 0.20552100E+05, 0.46005800E+05, -.27493800E+04, 0.27039900E+04, 0.14886500E+05, -.11598500E+05, 0.11009100E+05, 0.52665200E+04, 0.30289500E+05, -.87295200E+05, 0.41820300E+05, 0.41777700E+05, 0.43648100E+05, 0.19423700E+05, 0.21963200E+05, 0.60344300E+04, -.89684300E+04, 0.99490400E+04, 0.22093600E+05, 0.33925300E+05, 0.45832100E+05, -.23073600E+05, -.77153800E+04, -.22916100E+05, -.50118900E+04, -.10580700E+05, 0.30675000E+04, 0.18548800E+05, -.55773700E+04, -.91301900E+04, -.19865800E+05, 0.69992400E+04, -.35423700E+04, 0.17763800E+04, -.34995900E+04, -.12977000E+04, -.21585600E+04, 0.60341100E+02, 0.26533500E+04, -.10767800E+03, -.20824300E+04, -.16464000E+04, -.13273800E+05, 0.79088100E+04, -.65172700E+03, 0.66367800E+04, 0.14908700E+04, 0.76123900E+04, -.10582600E+05, -.19532400E+05, -.76919600E+04, 0.68339000E+04, 0.50814000E+04, 0.74036700E+05, -.37142700E+05, -.76859400E+04, -.37018000E+05, -.10233200E+05, -.21447300E+05, -.64446200E+02, 0.16859500E+05, -.58790200E+04, -.21607000E+05, -.24102200E+05, -.58408600E+05, 0.33801700E+05, 0.67600300E+04, 0.29209200E+05, -.18828100E+04, 0.17994500E+05, -.11947400E+05, -.36569300E+05, -.14733000E+05, 0.19035400E+05, 0.11910800E+05, -.10878100E+05, -.12833000E+04, 0.42704300E+04, 0.76140300E+04, 0.29642000E+04, -.17565100E+04, -.56225300E+04, -.52533800E+04, -.50040600E+03, -.88650200E+03, 0.17238400E+04, -.73572000E+03, -.44981400E+04, -.44975200E+04, -.47615500E+03, 0.51818100E+04, -.77481800E+04, -.80745300E+04, 0.54178600E+04, -.27327800E+04, -.34230900E+04, -.29416300E+04, -.14058500E+05, 0.95954900E+03, -.49605700E+04, 0.73825300E+04 },
        { 0.40718500E+00, 0.40820600E+00, 0.61303900E+00, -.56160000E+00, -.83884600E+00, -.26027300E+00, -.41602100E+00, -.17096400E+01, -.20787800E-01, -.97248100E+00, -.19040600E+00, 0.36366600E-01, 0.49845500E-03, -.14699300E-01, -.19522400E-01, -.16921900E+01, 0.15736400E+01, -.43991400E+00, -.45535800E+00, -.15637600E+00, 0.88976000E+03, -.28098200E+04, -.14570400E+03, 0.28202500E+03, 0.39130900E+02, 0.73187900E+02, 0.44713600E+03, 0.10881800E+04, -.11941300E+03, 0.33799900E+03, 0.24211100E+03, 0.22280300E+04, -.34298000E+04, 0.94119100E+04, -.43402900E+04, -.46695100E+04, -.47051500E+04, -.28199900E+04, 0.82146200E+03, -.38675000E+04, -.50499400E+04, -.59735000E+04, 0.29054800E+04, -.81503500E+04, -.38262000E+04, 0.17322300E+04, 0.19202000E+04, 0.19130400E+04, -.53967500E+03, -.20932300E+04, 0.13736400E+04, -.83031400E+03, -.44538400E+03, -.62552300E+03, -.35906600E+03, -.16150900E+05, 0.71497200E+04, 0.94604500E+04, 0.80747000E+04, 0.45722300E+04, -.32788100E+04, 0.70276700E+04, 0.60652600E+04, 0.82654500E+04, -.48179600E+04, 0.13647400E+05, -.51445000E+04, 0.26196200E+04, 0.64221500E+04, 0.25724100E+04, 0.21602300E+04, 0.34370700E+03, 0.17434400E+04, -.52140500E+03, -.87679200E+02, 0.10948800E+04, -.12023100E+04, 0.10759400E+05, -.48651400E+04, -.40649100E+04, -.53784200E+04, -.10363400E+04, 0.41216600E+04, -.48755900E+04, -.45634400E+04, -.76610100E+04, 0.57128800E+04, -.11985400E+05, -.59977600E+04, 0.27480600E+04, 0.26281000E+04, 0.29981800E+04, 0.12077600E+04, -.13337000E+04, 0.19790300E+04, 0.12537400E+04, 0.27200600E+04, -.18377200E+04, 0.33308700E+04, 0.19596900E+04, -.13229700E+04, -.42899900E+03, -.98003900E+03, -.11270300E+04, -.10514500E+04, 0.27854400E+03, 0.11113600E+04, 0.12059200E+04, -.16051000E+04, 0.24244300E+04, -.92033000E+04, 0.47586100E+04, 0.20784800E+04, 0.45999600E+04, 0.46699600E+03, -.29871800E+04, 0.44563800E+04, 0.41015600E+04, 0.65726300E+04, -.43701300E+04, 0.50835600E+04, 0.13084600E+05, -.59711100E+04, -.75607000E+04, -.65423400E+04, -.34409400E+04, 0.40036200E+04, -.66731000E+04, -.72323200E+04, -.90326000E+04, 0.62592300E+04, -.12095500E+05, 0.58118600E+04, -.30847100E+04, -.26285900E+04, -.29055300E+04, -.19694800E+04, -.10983100E+03, -.22280000E+04, -.37417000E+04, -.43321700E+04, 0.16978200E+04, -.49562700E+04, 0.13608200E+05, -.68253400E+04, -.14002700E+05, -.68052600E+04, -.53547500E+04, -.18670600E+04, -.29137200E+04, 0.22323900E+04, -.91263200E+03, -.30272300E+04, -.34008600E+03, 0.26010300E+05, -.12788900E+05, -.10097600E+05, -.13005200E+05, -.41732400E+04, -.30504800E+04, -.28562000E+04, 0.37307500E+04, -.70661600E+04, -.25578400E+04, -.10625900E+05, 0.65831600E+03, 0.23815400E+02, 0.29749400E+03, -.32877900E+03, 0.40527600E+03, 0.65473200E+03, 0.39877000E+02, 0.37396800E+02, -.13326500E+03, 0.17734500E+04, -.50723900E+04, -.65452100E+04, 0.31386300E+04, 0.60848300E+04, 0.32716400E+04, 0.16861800E+04, -.25980400E+04, 0.41397700E+04, 0.52768100E+04, 0.57941300E+04, -.42742000E+04, 0.36733600E+04, -.15293400E+04, 0.71935200E+03, 0.10069600E+04, 0.76498600E+03, -.89804000E+02, -.96701300E+03, 0.65729800E+03, -.50005700E+03, 0.62884500E+03, -.20332600E+04, 0.21511300E+04, -.92085800E+03, 0.57071800E+03, 0.14236400E+04, 0.45911800E+03, 0.18637400E+04, 0.11180300E+04, 0.96857900E+03, 0.32628500E+04, 0.49936000E+04, -.16818100E+04, 0.27358800E+04, 0.10945000E+04, -.14941700E+03, -.49954900E+04, -.55072000E+03, -.36567800E+04, -.23357400E+04, 0.66627100E+03, 0.11335100E+04, 0.21855600E+04, -.29385300E+04, 0.19886300E+02, 0.19825900E+05, -.96544700E+04, -.78707900E+04, -.99129500E+04, -.27416400E+04, -.20995700E+04, -.22808400E+04, 0.30040700E+04, -.55598000E+04, -.17362300E+04, -.85385200E+04, 0.65515500E+04, -.32733900E+04, -.20145400E+04, -.32757600E+04, -.13314500E+04, -.10162500E+04, -.51771600E+03, 0.11623200E+04, -.15976100E+04, -.80560200E+03, -.28787100E+04, -.37506700E+04, 0.13985400E+04, 0.49694800E+04, 0.18752600E+04, 0.23043200E+04, 0.52679900E+03, 0.72743300E+03, -.19407400E+03, 0.21765500E+04, 0.50595100E+01, 0.28599400E+04, 0.69423000E+04, -.34982700E+04, -.26690400E+04, -.34694600E+04, -.76140500E+03, 0.29198800E+04, -.43571400E+04, -.53991200E+04, -.70902900E+04, 0.50726100E+04, -.58878900E+04, -.11268900E+05, 0.43710300E+04, 0.10596300E+05, 0.56318700E+04, 0.40046300E+04, -.45782700E+04, 0.75410200E+04, 0.88549700E+04, 0.91280700E+04, -.66512000E+04, 0.11288400E+05, -.18419500E+04, -.18305200E+04, -.13951700E+04, -.10555600E+04, -.53038500E+03, 0.11514900E+04, -.15777900E+04, 0.31539800E+04, 0.12993400E+04, -.16223100E+04, -.17172900E+04, -.47659700E+03, -.56385900E+03, 0.79443800E+03, 0.25146900E+04, 0.23187600E+04, 0.14947600E+04, -.46884600E+03, -.99939200E+03, 0.12340100E+04, 0.18476700E+04, -.18329200E+04, -.20696600E+04, 0.18332600E+04, 0.36064000E+03, 0.84756400E+03 },
        { -.19798100E+01, -.68374200E-01, 0.57795800E+00, 0.46397000E+00, 0.44700300E-01, -.45342200E-01, 0.64635800E+00, -.48580200E+01, -.19671300E+00, -.10005600E+01, -.82047800E+00, 0.39663400E-01, -.11693100E+00, -.20248100E+00, 0.79904500E-01, -.48942200E+01, -.47877200E+01, -.20440100E+01, 0.30926300E+00, -.10842400E+00, 0.25655700E+01, 0.88865600E+04, 0.14783400E+05, -.70486400E+04, -.85590600E+04, -.73852200E+04, -.15254100E+04, -.15882400E+04, -.32476800E+04, -.47299100E+03, -.39716500E+04, -.13674600E+04, 0.10316300E+05, -.34214000E+05, 0.17684200E+05, 0.92323600E+04, 0.17104100E+05, -.16994700E+04, -.11546500E+05, 0.10179300E+05, 0.54657000E+04, 0.14374600E+05, -.13474800E+05, 0.17594300E+05, -.77726600E+04, 0.33576200E+04, -.33911700E+04, 0.38839600E+04, -.15725800E+04, 0.48442800E+04, -.96930300E+03, -.17623700E+04, 0.36803300E+04, 0.35975000E+04, 0.22595600E+05, 0.54758300E+05, -.29220700E+05, -.29146900E+05, -.27379100E+05, 0.17180400E+04, 0.26762200E+05, -.19028800E+05, -.39043000E+04, -.27828800E+05, 0.27293500E+05, 0.46632700E+04, 0.29345300E+04, -.19315100E+04, -.17592800E+05, -.14670700E+04, -.94330300E+04, 0.20285000E+04, -.33662800E+04, 0.49185600E+04, 0.78592700E+04, -.13205000E+04, 0.35869200E+05, -.36841100E+05, 0.19307700E+05, 0.10751700E+05, 0.18420500E+05, -.52367000E+04, -.18468000E+05, 0.14163200E+05, 0.87679400E+04, 0.26115600E+05, -.20838400E+05, 0.20826300E+05, 0.91907400E+04, -.51099700E+04, -.48697100E+04, -.45951900E+04, 0.10261000E+03, 0.16726800E+04, -.34950500E+04, -.22821900E+04, 0.73374800E+03, 0.25550000E+04, -.10196500E+05, -.11466200E+05, 0.55465800E+04, 0.83446900E+04, 0.57328700E+04, 0.65649000E+04, 0.75538400E+04, -.23726700E+03, -.63797800E+04, -.76386600E+04, 0.95554000E+04, 0.35615300E+04, 0.26318700E+05, -.12926800E+05, -.73605100E+04, -.13159200E+05, -.30906400E+04, -.73962200E+03, -.50982500E+04, -.10535800E+04, -.11616500E+05, 0.27260000E+03, -.19108300E+05, -.15113000E+05, 0.87624600E+04, 0.52238200E+04, 0.75622100E+04, -.38914000E+04, -.14676100E+05, 0.59028500E+04, 0.83845500E+04, 0.16731100E+05, -.17817600E+05, 0.13099200E+05, -.14830700E+05, 0.74497700E+04, 0.64495000E+03, 0.74143600E+04, -.29083100E+04, -.47362300E+04, 0.33661200E+04, 0.42823300E+04, 0.82352900E+04, -.67215800E+04, 0.16007500E+05, -.44848300E+05, 0.23224200E+05, 0.50618800E+05, 0.22424600E+05, 0.21186200E+05, -.64892400E+03, 0.82075000E+04, -.19354600E+05, -.33133100E+04, 0.56737400E+04, -.48537900E+05, -.10643100E+06, 0.53134500E+05, 0.37543100E+05, 0.53215600E+05, 0.18378800E+05, 0.13499700E+05, 0.83395600E+04, -.18866800E+05, 0.31137400E+05, 0.12145000E+05, 0.15598200E+05, 0.87019400E+04, -.40262200E+04, -.76496300E+04, -.43477800E+04, -.23463900E+04, -.36774700E+04, -.15970700E+04, 0.18990600E+04, 0.16899400E+03, -.39237900E+04, 0.10932400E+05, -.21398300E+05, 0.10424700E+05, 0.84062300E+04, 0.10698800E+05, -.26496300E+04, -.35420000E+04, 0.48235200E+04, -.10849300E+05, 0.32398600E+03, 0.27128500E+03, -.27490600E+03, -.11934100E+05, 0.57794500E+04, 0.49244400E+04, 0.59637900E+04, 0.54043200E+03, -.10096600E+04, 0.20110800E+04, 0.75695100E+03, 0.39192400E+04, -.16019600E+04, -.97442300E+04, 0.95136600E+04, -.43566900E+04, 0.26143900E+04, -.47494800E+04, 0.49443300E+04, -.25866000E+04, -.22285700E+03, 0.23795200E+04, -.10140100E+05, -.13671100E+04, -.30483700E+05, 0.47047300E+04, -.14039000E+04, 0.66932700E+04, -.23525100E+04, 0.48295200E+04, -.82389700E+04, 0.13102800E+04, 0.49284000E+03, -.30929000E+04, -.72897700E+04, -.37186000E+05, -.81707200E+05, 0.40756200E+05, 0.29123000E+05, 0.40853600E+05, 0.12603300E+05, 0.86435300E+04, 0.71052000E+04, -.15120900E+05, 0.24010700E+05, 0.76847400E+04, 0.12783200E+05, -.24186700E+05, 0.12112600E+05, 0.73564100E+04, 0.12093300E+05, 0.52161500E+04, 0.40691700E+04, 0.15616800E+04, -.49419700E+04, 0.57258300E+04, 0.36784100E+04, 0.56611200E+04, 0.23036700E+05, -.12005700E+05, -.16556300E+05, -.11518200E+05, -.47994000E+04, 0.27787000E+04, -.32942500E+04, 0.43833400E+04, -.11975600E+05, 0.41655200E+04, 0.12665500E+05, -.10317800E+05, 0.51833100E+04, -.10380100E+04, 0.51581300E+04, 0.25240100E+04, 0.57214800E+04, -.15532300E+04, 0.31834100E+04, 0.82353400E+04, 0.20650700E+04, 0.23488300E+05, 0.59010800E+05, -.31408900E+05, -.35342000E+05, -.29511700E+05, 0.31785300E+04, 0.30882100E+05, -.25203600E+05, -.11000100E+05, -.32550700E+05, 0.31822900E+05, -.30072200E+04, 0.80101400E+04, 0.56834100E+04, 0.24269600E+03, 0.23023100E+03, 0.11341500E+04, -.27952000E+04, -.41324000E+04, -.45617800E+04, -.40688200E+04, 0.43668200E+04, 0.31353400E+04, 0.39295500E+04, -.63760100E+03, -.20589700E+04, -.52104900E+04, -.51172300E+04, -.59551000E+03, 0.15882400E+03, -.76846200E+03, -.13409400E+04, -.22161200E+04, 0.30924100E+04, 0.80992000E+04, -.46761000E+04, -.89924500E+03, -.31420900E+04 },
        { 0.56484800E+01, 0.92741000E+00, 0.42351200E+01, 0.35750200E+01, -.21439100E+01, -.15034500E+01, 0.23176900E+00, -.79196200E+01, 0.65795400E+00, -.17125900E+00, -.18571200E+01, -.85147800E+00, -.15421100E+01, 0.16972100E+01, 0.87324500E+00, -.12405500E+01, 0.25168600E+01, 0.98426700E+00, 0.13370700E+01, 0.44385000E+00, -.42350800E+01, -.18898800E+01, 0.88405600E+05, -.39627400E+05, -.33794000E+05, -.44164800E+05, -.33905800E+03, 0.66506400E+04, -.21595000E+05, 0.98495200E+04, -.20069400E+05, 0.65786700E+04, -.23026700E+05, -.30219200E+05, 0.20874300E+05, 0.59020700E+05, 0.15100100E+05, -.54070800E+05, -.48760600E+05, 0.35131700E+04, -.42691800E+05, -.93863700E+04, -.39065300E+05, -.91128600E+04, -.65659100E+05, 0.28517800E+05, 0.11337000E+05, 0.32816400E+05, -.15954100E+05, -.98831300E+04, 0.15595700E+05, -.92108200E+04, 0.54111500E+04, -.41407300E+04, 0.59920200E+05, 0.13470500E+06, -.82931200E+05, -.18632000E+06, -.67358000E+05, 0.79437300E+05, 0.82128000E+05, -.19388200E+05, 0.75142800E+05, -.42208200E+05, 0.69215200E+05, 0.69747300E+05, 0.85468800E+05, -.43245100E+05, -.50931300E+05, -.42732200E+05, -.12727600E+05, 0.41843800E+04, -.11764400E+05, 0.34886700E+05, -.16548900E+05, -.18537200E+04, 0.20920400E+05, -.17196600E+05, 0.17001800E+05, 0.59052500E+05, 0.86074700E+04, -.45996200E+05, -.21419300E+05, -.36607800E+04, -.29414700E+05, 0.19648900E+04, -.18576900E+05, -.36854700E+05, -.12148200E+05, 0.15656100E+04, 0.41462000E+04, 0.60699800E+04, 0.31181600E+05, 0.18557800E+05, -.64840200E+04, 0.47015000E+04, 0.14613600E+05, 0.15902300E+05, -.52500700E+04, -.10536300E+05, 0.97919100E+03, -.30914200E+05, 0.52656800E+04, 0.99361200E+04, 0.10997300E+05, 0.10906700E+05, 0.21198100E+04, -.56773900E+04, 0.12601500E+05, 0.32722200E+05, 0.37213300E+04, 0.88460100E+03, -.52280900E+04, -.18724400E+04, -.31390300E+04, -.32191400E+05, 0.23583800E+05, 0.30533700E+05, 0.22339500E+05, -.37451400E+05, -.17539700E+05, -.11332600E+05, 0.15275200E+05, 0.10646300E+06, 0.56965800E+04, -.76336600E+05, -.36216600E+05, -.19216000E+05, -.54693800E+05, -.94201000E+04, -.26470000E+05, -.26822000E+05, -.94176300E+04, 0.29167200E+04, 0.32720200E+05, 0.47065900E+04, -.37359500E+05, -.25577700E+05, -.68221900E+04, -.29913900E+05, -.10580200E+05, -.19687000E+05, 0.10668300E+05, -.20985600E+06, 0.10643400E+06, 0.13001800E+06, 0.10492200E+06, 0.17817700E+05, -.11857800E+05, 0.26571100E+05, -.80509000E+05, 0.43553100E+05, -.26469800E+03, -.19334500E+05, -.78031900E+05, 0.40798100E+05, 0.89125800E+05, 0.39016400E+05, -.20032500E+04, -.43340200E+04, 0.40507600E+04, -.32042200E+05, 0.19699600E+05, 0.73203000E+03, -.33347700E+05, 0.86228900E+05, -.37378200E+05, -.70755300E+04, -.43094100E+05, -.63991500E+04, -.65623200E+04, -.14090100E+05, 0.14411100E+05, -.17718300E+05, -.63323700E+04, -.43530000E+05, -.19844200E+06, 0.97267400E+05, 0.14492400E+05, 0.99212400E+05, 0.25208100E+05, -.34692600E+05, 0.63148700E+05, 0.43078000E+04, 0.81422500E+05, -.30433600E+05, 0.65772700E+05, -.55681600E+05, 0.26047800E+05, 0.38200100E+05, 0.27825600E+05, -.11795900E+04, -.12828600E+05, 0.14838000E+05, -.35131300E+04, 0.16183400E+05, -.12362800E+05, -.72153000E+04, 0.47190400E+05, -.20145000E+05, -.47378200E+05, -.23565200E+05, 0.45925100E+05, 0.10158300E+05, -.62423300E+03, 0.39239300E+05, 0.14428700E+05, 0.20224100E+03, -.65478200E+05, -.42532700E+05, 0.28411400E+05, 0.79923800E+05, 0.21240300E+05, -.25932400E+05, -.49001900E+05, 0.13584800E+05, -.21149000E+05, 0.32950800E+05, -.48709600E+05, -.67910700E+05, -.57486900E+05, 0.30896500E+05, 0.80617200E+05, 0.28743800E+05, -.24926600E+04, -.71337400E+04, 0.51370200E+04, -.23943300E+05, 0.11078100E+05, -.24617900E+04, -.29435300E+05, -.13344800E+05, 0.67346800E+04, 0.11032700E+05, 0.66723500E+04, 0.67771300E+03, 0.66919600E+03, 0.47389500E+03, -.55409300E+04, 0.23213300E+04, 0.14365600E+04, -.66157200E+04, 0.73423700E+05, -.43061100E+05, -.89618500E+05, -.36711500E+05, 0.21185800E+05, 0.23001400E+05, -.41003200E+04, 0.33420400E+05, -.23117500E+05, 0.22201200E+05, 0.34654300E+05, 0.95984300E+05, -.48563500E+05, 0.19894000E+05, -.47983900E+05, -.17860400E+05, 0.40426200E+05, -.50803900E+05, -.24863200E+05, -.64356600E+05, 0.40619300E+05, -.19314800E+05, 0.74263500E+05, -.56554400E+05, -.17446400E+06, -.37184400E+05, 0.10090800E+06, 0.66772100E+05, -.89424300E+04, 0.85366300E+05, 0.87982100E+04, 0.54412500E+05, 0.70795000E+05, 0.95496900E+04, 0.46481400E+04, -.22823900E+05, -.21649700E+05, -.93842800E+04, 0.91353300E+03, -.16058900E+05, 0.58540500E+04, -.58628400E+04, 0.18286400E+04, -.26162200E+04, 0.39580100E+04, -.68654700E+04, 0.40070800E+04, 0.17903200E+04, 0.10960100E+05, 0.24194000E+05, -.20169900E+05, -.23962600E+05, 0.67774600E+04, 0.71442400E+04, -.87921800E+04, -.11054200E+05, 0.26409800E+04, -.55587800E+04, -.46115500E+04 },
        { -.83035700E+00, 0.60799100E-01, 0.64239700E-01, 0.23775200E+00, -.35718400E+00, 0.15826600E-01, -.38648900E+00, -.64785200E+00, -.97807700E-01, -.68568600E-01, -.22375200E-01, 0.10825500E+00, -.10602400E+00, -.92991000E-01, 0.27666500E-01, 0.27196800E+01, -.17785100E+01, -.84401800E+00, 0.72284600E+00, 0.66607200E-01, -.11145600E+00, 0.93621200E-01, 0.99002500E-01, -.60785900E+03, 0.16161500E+03, -.33386500E+01, 0.12779300E+03, 0.14512900E+04, -.10307500E+04, -.11557200E+04, -.15863800E+04, 0.12621500E+04, -.18221000E+04, 0.53545300E+05, -.27631500E+05, -.28078200E+05, -.26772400E+05, -.31508400E+04, 0.20239100E+05, -.24611000E+05, -.18960600E+05, -.22381500E+05, 0.21814200E+05, -.13060700E+05, 0.12477700E+05, -.56168900E+04, 0.74934800E+03, -.62377400E+04, 0.35524600E+04, 0.76737700E+04, -.21590100E+04, 0.58518400E+04, -.24323500E+04, 0.61534100E+04, -.88072200E+04, -.50554100E+05, 0.27692200E+05, 0.37788300E+05, 0.25278000E+05, 0.62189500E+04, -.12048900E+05, 0.25312300E+05, 0.28822900E+05, 0.27312700E+05, -.17115300E+05, 0.91183000E+03, 0.21822700E+05, -.10761600E+05, -.19056000E+04, -.10911600E+05, 0.26812300E+04, 0.29984800E+04, -.26484800E+03, 0.11791600E+05, -.60930000E+04, 0.12484400E+04, -.16897100E+05, 0.45883400E+05, -.24242600E+05, -.25537200E+05, -.22943300E+05, -.36455300E+04, 0.20985500E+05, -.20655200E+05, -.17596800E+05, -.22699000E+05, 0.23328900E+05, -.72873500E+04, -.13192300E+05, 0.73154300E+04, 0.66447200E+04, 0.65969200E+04, -.48921400E+03, -.99030100E+04, 0.81942100E+04, 0.49607300E+04, 0.27440700E+04, -.95509800E+04, 0.52114100E+04, 0.34107600E+04, -.10934000E+04, 0.33539600E+04, -.17050500E+04, -.61589100E+03, 0.21974900E+04, -.13129200E+04, 0.72486700E+03, 0.27768500E+04, 0.19063500E+04, -.40123500E+04, -.39910100E+05, 0.19593300E+05, 0.15066800E+05, 0.19957100E+05, 0.30426200E+04, -.18442500E+05, 0.18430500E+05, 0.13871800E+05, 0.17604100E+05, -.19105200E+05, 0.12982700E+05, 0.60072100E+05, -.31534400E+05, -.40224100E+05, -.30038500E+05, -.52935300E+04, 0.13557400E+05, -.23888700E+05, -.23649600E+05, -.29429800E+05, 0.17526200E+05, -.15497700E+05, 0.36667000E+05, -.18105700E+05, -.18205900E+05, -.18333600E+05, -.10213300E+04, 0.13704600E+05, -.16530000E+05, -.12071900E+05, -.15021200E+05, 0.14267000E+05, -.11249200E+05, -.85429800E+04, 0.39875100E+04, -.15030000E+05, 0.42727000E+04, -.84362700E+04, -.13109600E+05, -.32272700E+04, -.18874000E+05, 0.32441100E+03, -.89174600E+04, 0.18958000E+05, 0.45341300E+05, -.22824400E+05, -.29156400E+05, -.22670700E+05, -.65698200E+04, -.12627800E+05, -.71756300E+04, -.17141600E+04, -.17019100E+05, -.99205500E+04, -.11447100E+05, -.47967400E+04, 0.16109600E+04, 0.66942300E+03, 0.23964500E+04, 0.81439200E+03, 0.22994500E+04, 0.31887000E+03, -.85768100E+03, 0.96440000E+03, 0.21329300E+04, 0.21133500E+04, -.52894400E+05, 0.26750200E+05, 0.37893400E+05, 0.26448500E+05, 0.60128200E+04, -.73881600E+04, 0.20671500E+05, 0.16655100E+05, 0.24103300E+05, -.97488300E+04, 0.16403600E+05, -.22362900E+04, 0.13484200E+04, 0.31179700E+03, 0.11192000E+04, 0.19268300E+03, -.11524500E+03, 0.18999700E+04, 0.17154000E+04, 0.23646400E+04, -.17718000E+03, 0.38406400E+04, -.25352200E+05, 0.12209100E+05, 0.10822900E+05, 0.12674500E+05, -.37783700E+04, -.13791700E+05, 0.10027900E+05, 0.10079300E+04, 0.95043000E+04, -.13200500E+05, 0.15702000E+05, -.27078000E+05, 0.12439700E+05, -.54991800E+04, 0.13543400E+05, -.20013300E+04, -.12922500E+05, 0.60300500E+04, -.48560200E+04, 0.83655800E+04, -.11409100E+05, 0.17682800E+05, 0.25071100E+05, -.12768300E+05, -.17849300E+05, -.12535600E+05, -.39536700E+04, -.81743900E+04, -.34736100E+04, -.84119300E+03, -.10172500E+05, -.59856900E+04, -.46426600E+04, 0.15978700E+05, -.79709500E+04, -.85160000E+04, -.79893600E+04, -.20212400E+04, -.30397000E+04, -.17467500E+04, 0.20553800E+04, -.48585000E+04, -.27039500E+04, -.55152800E+04, -.11579300E+05, 0.66790000E+04, 0.21465900E+05, 0.57897000E+04, 0.39802200E+04, 0.12394400E+05, 0.13740100E+04, 0.23339800E+04, 0.72080400E+04, 0.10605400E+05, -.17184800E+04, 0.62551800E+05, -.31213000E+05, -.32568700E+05, -.31277600E+05, -.35815100E+04, 0.14270200E+05, -.21378800E+05, -.11023300E+05, -.25162300E+05, 0.15739500E+05, -.23035300E+05, -.71218700E+05, 0.38552200E+05, 0.57526400E+05, 0.35615300E+05, 0.96836000E+04, -.22393500E+05, 0.36698700E+05, 0.39697300E+05, 0.35967200E+05, -.27613900E+05, 0.71292800E+04, -.77696300E+04, -.70555200E+04, -.58201700E+04, -.58595500E+04, -.21014500E+04, 0.87096800E+04, -.20054500E+04, 0.17639400E+05, 0.40492700E+04, -.56334200E+04, -.66537600E+04, -.47527600E+04, 0.30617800E+04, 0.44267400E+04, 0.12774000E+05, 0.12153600E+05, 0.56383300E+04, 0.31115600E+04, -.56452700E+04, 0.70620500E+04, 0.14272000E+05, -.98445600E+04, -.17252700E+05, 0.86946600E+04, 0.64715700E+04, 0.29636700E+04 },
        { -.37187400E+01, -.24840200E+01, -.40849300E+01, -.22592400E+01, 0.13340700E+01, 0.20143400E+01, 0.20571800E+01, -.43381300E+00, 0.21548300E+00, -.16726300E+01, 0.61573600E+00, 0.41305000E+00, 0.27962400E+00, -.65618600E+00, -.10967100E+00, 0.80149400E+01, 0.32549400E-01, 0.59259500E+00, -.46663600E+00, -.95730500E-01, 0.11842700E+01, 0.38928000E+00, 0.17713500E+00, 0.15456800E+01, 0.23795500E+05, -.86541200E+01, -.49928400E+04, -.10393700E+05, 0.85692800E+04, 0.30221300E+04, -.43558900E+04, -.97541800E+04, -.83232400E+04, -.11264100E+06, 0.55700100E+05, 0.85057200E+05, 0.56321800E+05, 0.11180300E+05, -.30478900E+05, 0.55963000E+05, 0.51604600E+05, 0.60046600E+05, -.34206500E+05, 0.53294800E+05, -.67951600E+05, 0.33870100E+05, 0.36682700E+05, 0.33978700E+05, -.19168900E+04, -.16866300E+05, 0.12935700E+05, -.14941100E+05, 0.31682700E+05, -.15467800E+05, 0.15331000E+05, 0.34140000E+05, -.15904400E+05, 0.16018300E+05, -.17067900E+05, -.27367200E+05, -.13666400E+05, -.36965400E+05, -.81543700E+05, -.30018700E+05, 0.87113600E+03, -.82957200E+05, -.87808000E+05, 0.43564300E+05, 0.52057600E+05, 0.43903300E+05, -.16696200E+04, -.96299200E+04, 0.11810900E+05, -.31080500E+05, 0.28752200E+05, -.39513700E+04, 0.21982900E+05, -.11730000E+06, 0.57896200E+05, 0.60122400E+05, 0.58646500E+05, 0.15170900E+05, -.33078900E+05, 0.51912000E+05, 0.44016700E+05, 0.57839500E+05, -.37438600E+05, 0.72602200E+05, 0.73950400E+05, -.36655600E+05, -.29231000E+05, -.36973400E+05, -.10925900E+05, 0.10230600E+05, -.18758700E+05, -.76607500E+04, -.34710400E+05, 0.10331300E+05, -.27983100E+05, 0.28678500E+04, -.92981900E+03, -.11310600E+05, -.14331400E+04, 0.80924800E+04, -.31616500E+04, -.91526200E+04, -.47842800E+03, 0.30274600E+04, -.33287800E+04, -.22667700E+05, 0.10357500E+06, -.51912300E+05, -.66563900E+05, -.51783000E+05, 0.10964500E+04, 0.57903400E+05, -.56791200E+05, -.38022600E+05, -.55441800E+05, 0.59881500E+05, -.23203400E+05, -.16786600E+06, 0.83178300E+05, 0.56155300E+05, 0.83926500E+05, 0.29721600E+05, -.17216000E+05, 0.69049000E+05, 0.60062200E+05, 0.77045900E+05, -.27401200E+05, 0.88496900E+05, -.10388000E+06, 0.51871900E+05, 0.81229600E+05, 0.51940000E+05, 0.32744300E+04, -.32328000E+05, 0.49217900E+05, 0.31902100E+05, 0.51699200E+05, -.32843200E+05, 0.38863300E+05, 0.11609300E+06, -.57641600E+05, -.81903600E+05, -.58043800E+05, 0.13957300E+05, 0.36614900E+05, -.18912700E+05, 0.55075500E+05, -.38764200E+05, 0.23169100E+05, -.20014400E+05, -.95417400E+05, 0.47241100E+05, 0.20505000E+05, 0.47708600E+05, 0.10196700E+05, 0.31797200E+05, 0.11287000E+05, 0.79913000E+03, 0.27096600E+05, 0.23362000E+05, 0.67424700E+05, 0.14545000E+05, -.74601200E+04, 0.23213100E+05, -.72774000E+04, -.52235100E+04, -.58388300E+04, 0.27067300E+04, 0.24635700E+04, -.11236400E+05, -.49890300E+04, -.17227900E+04, 0.25184700E+06, -.12559500E+06, -.10049200E+06, -.12592000E+06, -.94948800E+04, 0.40847600E+05, -.82359600E+05, -.22567900E+05, -.10421600E+06, 0.41385500E+05, -.86192000E+05, 0.30887700E+05, -.15484600E+05, -.16573600E+05, -.15440900E+05, 0.18993800E+03, 0.92577000E+04, -.10871500E+05, -.99515500E+02, -.11916100E+05, 0.90405300E+04, 0.41210300E+04, 0.16707600E+06, -.83135100E+05, -.82209100E+05, -.83542900E+05, -.33910400E+04, 0.45239100E+05, -.51148900E+05, -.42820000E+04, -.81744000E+05, 0.45027000E+05, -.52049300E+05, 0.10789600E+06, -.54265500E+05, -.62418800E+05, -.53938000E+05, 0.65128100E+04, 0.47848500E+05, -.30399000E+05, 0.18388000E+05, -.48096100E+05, 0.44725500E+05, 0.68784500E+04, -.52606200E+05, 0.25805500E+05, 0.15349500E+05, 0.26303000E+05, 0.43492900E+04, 0.21291800E+05, 0.52811200E+04, -.38273700E+03, 0.14389400E+05, 0.14840500E+05, 0.42880800E+05, -.33184500E+05, 0.16546500E+05, 0.14104000E+05, 0.16592300E+05, 0.30937700E+04, 0.68191400E+04, 0.32799500E+04, -.41911300E+04, 0.84845400E+04, 0.54251900E+04, 0.19238600E+05, 0.35250800E+05, -.16986600E+05, 0.11764800E+05, -.17625400E+05, -.13126700E+05, -.37030400E+05, -.33451300E+04, -.65435200E+04, -.79158200E+04, -.31934200E+05, -.52085200E+05, -.24881500E+06, 0.12418800E+06, 0.90648400E+05, 0.12440400E+06, 0.37655900E+04, -.55589600E+05, 0.84452700E+05, 0.23004400E+05, 0.11095100E+06, -.56894900E+05, 0.88306600E+05, 0.16259600E+06, -.79688100E+05, -.24193500E+05, -.81283200E+05, -.46179900E+05, 0.13433700E+05, -.74040200E+05, -.99372100E+05, -.96147300E+05, 0.27005600E+05, -.11048000E+06, 0.20744400E+05, 0.16673200E+05, 0.13820500E+05, 0.12505100E+05, 0.18658100E+04, -.19851700E+05, 0.18799400E+05, -.44215100E+05, -.80972400E+04, 0.15786600E+05, 0.20120300E+05, 0.12312200E+05, 0.34557500E+04, -.64196600E+04, -.32987100E+05, -.33423600E+05, -.12467700E+05, 0.65031700E+04, 0.14639800E+05, -.19253400E+05, -.32737500E+05, 0.26646900E+05, 0.46688800E+05, -.23339300E+05, -.97095600E+04, -.11465900E+05 },
        { 0.72793400E+01, 0.21745100E+01, 0.24772800E+00, 0.11415800E+01, -.50597700E+01, -.33770800E+01, -.36523300E+00, -.21667500E+02, 0.86183000E+00, -.40594900E+01, -.32646000E+01, 0.91643900E-01, -.79294500E+00, 0.44600600E+00, 0.91004700E+00, 0.81579300E+01, 0.20181300E+01, 0.28316500E+01, -.27009300E+00, -.17195600E+01, -.29011200E+01, -.56815200E-01, -.15404800E-01, -.82650200E+00, 0.36057200E+00, 0.97609400E+02, 0.23262700E+05, 0.37827800E+05, -.25496100E+05, -.11906600E+05, -.10965000E+05, 0.33228600E+05, 0.90112700E+03, 0.73960900E+05, -.37577200E+05, -.53916100E+05, -.37059000E+05, -.24566100E+05, -.16382300E+05, -.35087800E+05, -.45265200E+05, -.47968100E+05, -.75953200E+04, -.59804700E+05, 0.10086800E+06, -.49712800E+05, -.39155900E+05, -.50471000E+05, -.53443200E+04, 0.23453000E+05, -.10731600E+05, 0.34105800E+05, -.46654600E+05, 0.21700200E+05, -.23694000E+05, 0.18167800E+06, -.87646200E+05, -.94732000E+05, -.90809500E+05, 0.67877200E+05, 0.15008400E+06, -.41012900E+05, 0.93429700E+05, -.56079400E+05, 0.11128000E+06, 0.49137400E+05, 0.36506500E+06, -.18131900E+06, -.11197200E+06, -.18253500E+06, -.10588500E+04, 0.14728800E+05, -.45477600E+05, 0.96483400E+05, -.12515400E+06, 0.40929800E+04, -.15419100E+06, 0.60067100E+05, -.31644600E+05, -.17272300E+05, -.30082600E+05, -.18446200E+05, -.29750300E+05, -.51031100E+04, 0.80517700E+03, -.33009000E+05, -.17808700E+05, -.10272700E+06, -.63807400E+05, 0.33001700E+05, 0.30222200E+05, 0.31933200E+05, 0.21162500E+05, 0.52073500E+04, 0.73934600E+04, -.90607400E+04, 0.21843400E+05, 0.71309400E+04, 0.30737600E+05, -.43444700E+05, 0.21431100E+05, 0.23473900E+05, 0.21726200E+05, -.57710300E+04, 0.24785500E+05, 0.12644300E+05, -.70066600E+04, 0.15046000E+05, 0.21376700E+05, 0.51975000E+05, -.78738800E+05, 0.39364300E+05, 0.37238800E+05, 0.39434800E+05, -.11427000E+05, -.70779700E+05, 0.45800700E+05, 0.16656600E+05, 0.50306700E+05, -.69781600E+05, 0.21398100E+05, 0.16144700E+06, -.83019400E+05, -.60736700E+05, -.80626300E+05, -.81762800E+05, -.99401200E+05, -.16014000E+05, -.21238900E+05, -.54753700E+05, -.72115400E+05, -.11447000E+06, 0.11106100E+06, -.56228700E+05, -.71876500E+05, -.55561900E+05, -.83057200E+04, 0.19101300E+05, -.50305600E+05, -.34986300E+05, -.60710900E+05, 0.20359000E+05, -.52665900E+05, -.56562300E+06, 0.28102700E+06, 0.15617700E+06, 0.28286300E+06, -.24116000E+05, -.83202900E+05, 0.85915300E+05, -.15743500E+06, 0.20039900E+06, -.54102100E+05, 0.24072400E+06, 0.27444300E+06, -.13619400E+06, -.84294200E+05, -.13721900E+06, -.43897900E+05, -.10823400E+06, -.13736600E+05, 0.23357800E+05, -.82825500E+05, -.83477500E+05, -.15100800E+06, -.12588400E+05, 0.66813500E+04, 0.66671000E+04, 0.63343600E+04, 0.19662000E+05, 0.22924300E+05, -.11757300E+05, -.69902700E+04, 0.29574400E+04, 0.19896500E+05, -.15842400E+05, -.42760200E+06, 0.21445000E+06, 0.22125500E+06, 0.21385100E+06, 0.37034300E+05, -.10244800E+05, 0.94927100E+05, -.24884100E+05, 0.15269400E+06, -.10147900E+05, 0.15520300E+06, -.31307400E+05, 0.15926000E+05, 0.17571800E+05, 0.15587100E+05, -.10169500E+05, -.26639000E+05, 0.23445200E+05, 0.57282500E+04, 0.21906800E+05, -.23676600E+05, -.97349200E+04, -.14904400E+06, 0.74200900E+05, 0.68365900E+05, 0.74694800E+05, 0.13568000E+05, -.44464200E+05, 0.45113900E+05, -.48969700E+04, 0.91374400E+05, -.47061300E+05, 0.42971200E+05, -.28893000E+06, 0.14297700E+06, 0.80887500E+05, 0.14459300E+06, -.20895300E+05, -.10859100E+06, 0.52681000E+05, -.72409800E+05, 0.11899200E+06, -.95834800E+05, 0.57189200E+05, 0.17945600E+06, -.88596200E+05, -.48671000E+05, -.89727500E+05, -.28342300E+05, -.79119500E+05, -.40271200E+04, 0.20949900E+05, -.56172900E+05, -.58081400E+05, -.10208800E+06, 0.78070300E+05, -.39004400E+05, -.30143500E+05, -.39036600E+05, -.10997200E+05, -.19079100E+05, -.69624800E+04, 0.12029300E+05, -.20420700E+05, -.16511100E+05, -.37618800E+05, -.21826400E+05, 0.10879400E+05, 0.38021100E+05, 0.10918500E+05, 0.41332000E+05, 0.11109000E+06, -.11714400E+05, 0.90985300E+04, -.14808800E+03, 0.95450300E+05, 0.51909600E+05, 0.41846700E+06, -.20973300E+06, -.16349700E+06, -.20931000E+06, -.27334000E+05, 0.37245600E+05, -.91472300E+05, 0.35117000E+05, -.16922000E+06, 0.38716400E+05, -.16852600E+06, 0.97311500E+04, -.23252000E+04, -.15154000E+05, -.48732100E+04, 0.10875900E+06, 0.17096500E+06, -.27942400E+05, 0.67526100E+05, 0.12759600E+05, 0.13167300E+06, 0.74418900E+05, -.31460700E+04, 0.85309900E+03, -.88402600E+04, -.52160300E+04, 0.79653100E+03, 0.10805100E+05, -.74519000E+05, 0.56499300E+05, -.47075400E+04, 0.13134700E+04, -.33724900E+04, -.80469300E+04, -.32130200E+05, -.11918000E+04, 0.33896400E+05, 0.52763700E+05, 0.59928600E+04, -.34959900E+05, -.99735000E+04, 0.12025400E+05, 0.45070900E+05, -.32352600E+05, -.10731900E+06, 0.17838300E+05, -.89183900E+04, 0.12476700E+05 },
        { -.10412900E+01, -.29834000E+00, 0.40012000E+00, 0.46299000E+00, -.10723400E+00, 0.52664400E+00, 0.17726400E+01, -.16989900E+01, -.75120600E-01, -.11500400E+01, 0.53634900E-01, 0.50500900E+00, 0.22685100E+00, -.24918900E-01, -.21852700E+00, 0.16938500E+01, 0.33441500E+01, -.31895400E-01, 0.35365300E+00, 0.24243900E+00, 0.11536700E+01, -.14687200E-01, -.13658500E+00, 0.69499700E+00, -.33047000E-01, -.29485100E-01, -.58493200E+04, -.86241500E+04, 0.77868800E+04, 0.40625200E+04, 0.76812000E+03, -.72909100E+04, 0.34090900E+04, -.24377900E+05, 0.12927000E+05, 0.26394900E+05, 0.12187400E+05, 0.65898800E+04, -.56957900E+04, 0.11262200E+05, 0.12752000E+05, 0.13115400E+05, -.94636200E+04, 0.35005100E+04, 0.49254400E+03, -.56771200E+03, -.14627800E+04, -.24641200E+03, 0.10871000E+04, 0.13740900E+04, -.56725000E+04, -.78820300E+04, 0.17375900E+04, 0.75176700E+03, 0.91902900E+04, 0.23834400E+05, -.14294600E+05, -.38083400E+05, -.11916000E+05, -.15438900E+05, -.25379800E+04, -.13278100E+05, -.21140600E+05, -.13843800E+05, 0.59811000E+04, 0.19198600E+05, -.40994300E+05, 0.20166900E+05, 0.45878000E+04, 0.20496900E+05, -.38132700E+04, -.65819700E+01, -.11706000E+03, -.18644400E+05, 0.13280500E+05, 0.13247000E+04, 0.33452200E+05, -.26912700E+05, 0.14741800E+05, 0.20940400E+05, 0.13454300E+05, 0.42871700E+04, -.88823500E+04, 0.81713900E+04, 0.39848100E+04, 0.13625000E+05, -.13964400E+05, 0.54523500E+04, 0.62544700E+04, -.38707300E+04, -.30040900E+04, -.31261000E+04, -.31701500E+04, 0.20304200E+04, 0.12702100E+03, -.64914200E+03, -.37974900E+04, 0.22127200E+04, -.44401500E+04, 0.48122600E+03, -.51242100E+03, -.92590100E+04, -.24033300E+03, 0.31621800E+04, -.11762600E+04, -.33222300E+04, 0.15486200E+03, -.99570400E+03, 0.27423000E+03, 0.39617200E+04, 0.15632700E+05, -.76724600E+04, -.59769100E+04, -.78136400E+04, 0.77791500E+03, 0.14671900E+05, -.10711500E+05, -.85894100E+04, -.11425400E+05, 0.16237400E+05, -.11424200E+05, -.13025800E+05, 0.81160200E+04, 0.27556600E+05, 0.65135700E+04, 0.10146100E+05, 0.92252700E+03, 0.74044200E+04, 0.15419200E+05, 0.11629400E+05, -.72536400E+04, 0.74692000E+02, -.19979700E+05, 0.10268000E+05, 0.20014000E+05, 0.99891000E+04, 0.35812500E+04, -.30470500E+04, 0.89463400E+04, 0.85130500E+04, 0.97198800E+04, -.54747700E+04, 0.78086200E+04, 0.46408800E+05, -.22659000E+05, 0.11080700E+05, -.23202500E+05, 0.12019600E+05, 0.86219700E+04, 0.17535700E+04, 0.29377400E+05, -.16211400E+05, 0.47172600E+04, -.50347300E+05, -.56806000E+05, 0.28268200E+05, 0.34879600E+05, 0.28403100E+05, 0.89350100E+04, 0.16743800E+05, 0.62819400E+04, -.96573500E+03, 0.18809900E+05, 0.11552800E+05, 0.12571900E+05, -.11689300E+04, 0.58940200E+03, 0.48849300E+04, 0.58412000E+03, -.46094100E+04, -.68068300E+04, 0.44976600E+04, 0.13133200E+03, -.22708000E+04, -.58025500E+04, 0.11175600E+04, 0.20166200E+05, -.10572700E+05, -.33911300E+05, -.10081000E+05, -.50101300E+04, -.44761600E+03, -.11088000E+05, -.14048300E+05, -.13297500E+05, 0.40331100E+04, -.91894500E+04, -.63549300E+03, 0.24966600E+03, 0.25851000E+04, 0.31693600E+03, 0.21563300E+04, 0.21870600E+04, -.42002900E+04, -.46063200E+04, -.25573700E+04, 0.18775600E+04, -.47870700E+04, -.12011500E+03, 0.36463000E+02, -.10900900E+05, 0.62882100E+02, -.43372400E+04, -.56612500E+04, 0.41338100E+04, 0.30544400E+04, -.41731700E+04, -.17511900E+04, -.14957200E+05, 0.30230300E+05, -.14132600E+05, 0.16221600E+05, -.15109700E+05, 0.75300100E+04, 0.15197600E+05, -.37119900E+04, 0.10660300E+05, -.16610300E+05, 0.13404000E+05, -.34819000E+05, -.38653400E+05, 0.19187300E+05, 0.25545900E+05, 0.19326700E+05, 0.56861100E+04, 0.11715600E+05, 0.36035500E+04, -.21152300E+04, 0.12985400E+05, 0.75697500E+04, 0.79819900E+04, -.99844800E+04, 0.49954100E+04, 0.59078200E+04, 0.49922000E+04, 0.16495400E+04, 0.27904900E+04, 0.63097600E+03, -.15235200E+04, 0.22127000E+04, 0.21327500E+04, 0.26787300E+04, 0.58667100E+04, -.34325800E+04, -.27106900E+05, -.29332300E+04, -.72825900E+04, -.15298300E+05, -.10459500E+04, -.29830200E+04, -.22876300E+04, -.11448100E+05, 0.11247100E+05, -.26852400E+05, 0.13728600E+05, 0.21711700E+05, 0.13423400E+05, 0.27950500E+04, -.49908300E+04, 0.88483400E+04, 0.57688200E+04, 0.16797300E+05, -.93967000E+04, 0.19366700E+05, 0.27501700E+05, -.16185400E+05, -.47282800E+05, -.13747400E+05, -.20346400E+05, -.50661700E+04, -.11168100E+05, -.25039000E+05, -.22087500E+05, 0.52522200E+04, 0.12231200E+05, 0.27103400E+04, 0.18175900E+04, 0.45836100E+04, 0.33659600E+04, 0.21877900E+04, -.45295900E+04, 0.66652300E+04, -.96555500E+04, -.80626100E+03, 0.20312000E+04, 0.31771800E+04, 0.30170000E+04, 0.40466600E+03, -.39162300E+04, -.65103900E+04, -.99582900E+04, -.36819900E+04, 0.52712800E+03, 0.40388100E+04, -.46926100E+04, -.99586900E+04, 0.63252400E+04, 0.17958400E+05, -.46255400E+04, -.16766700E+04, -.12004400E+04 },
        { 0.73373300E-01, -.93077000E+00, -.12131100E+00, -.10183200E+00, -.14699700E+00, 0.18352100E-01, 0.26294800E-02, 0.30509100E+00, 0.12360100E+00, -.21343100E+00, 0.10714600E+00, 0.81006600E-01, -.93496600E-01, 0.18082100E-01, -.45330100E-01, 0.18421000E+01, 0.26950800E+00, 0.98694300E-01, 0.29252000E+00, -.96176900E-02, 0.12583000E-01, 0.61619300E-01, 0.38554200E-01, 0.57652100E+00, 0.50211200E-01, -.23364600E-02, -.56579900E-01, -.12121700E+04, 0.76909100E+03, 0.62177900E+03, 0.32058400E+03, -.13168900E+04, -.60136700E+03, -.29217900E+05, 0.14475700E+05, 0.12612800E+05, 0.14608700E+05, 0.32391400E+04, -.10026000E+05, 0.13796900E+05, 0.12079700E+05, 0.13633900E+05, -.11456500E+05, 0.12359600E+05, -.36828400E+04, 0.18485100E+04, -.75082500E+03, 0.18414400E+04, -.12677200E+04, -.21353800E+04, 0.54308700E+03, -.13589700E+04, 0.72271600E+03, -.19151600E+04, 0.93533800E+03, 0.35468300E+05, -.17459000E+05, -.18973700E+05, -.17733900E+05, -.47171500E+04, 0.96322400E+04, -.17795700E+05, -.18061000E+05, -.18018100E+05, 0.11661300E+05, -.17411200E+05, 0.12047000E+04, -.59299900E+03, -.28459400E+04, -.60240100E+03, -.13996800E+04, -.68990300E+03, -.16495300E+04, -.29097700E+04, -.17139600E+04, -.39228100E+03, 0.13666300E+04, -.27502300E+05, 0.13587400E+05, 0.13133200E+05, 0.13750800E+05, 0.23988700E+04, -.12941900E+05, 0.14341400E+05, 0.13894300E+05, 0.14055700E+05, -.13976200E+05, 0.12293800E+05, 0.14826300E+05, -.73357700E+04, -.70399300E+04, -.74129200E+04, -.11871700E+04, 0.50740700E+04, -.56809700E+04, -.32764000E+04, -.51151800E+04, 0.51193800E+04, -.59876700E+04, -.47834200E+04, 0.24370800E+04, 0.82138000E+03, 0.23917700E+04, 0.55834200E+03, -.44592100E+03, 0.36846900E+03, -.15802300E+04, 0.54473700E+03, -.52833500E+03, -.90291500E+03, 0.27249400E+05, -.13639100E+05, -.99989800E+04, -.13624200E+05, -.17252700E+04, 0.10656300E+05, -.12932400E+05, -.10321700E+05, -.12715100E+05, 0.11770700E+05, -.75498100E+04, -.40298700E+05, 0.19950600E+05, 0.21519700E+05, 0.20149400E+05, 0.40827000E+04, -.10982100E+05, 0.18137900E+05, 0.15827900E+05, 0.18607900E+05, -.12898100E+05, 0.17727400E+05, -.18787000E+05, 0.93204300E+04, 0.73538700E+04, 0.93933600E+04, 0.15627900E+04, -.67986800E+04, 0.93367400E+04, 0.76509000E+04, 0.90606200E+04, -.77381400E+04, 0.75364700E+04, -.50112400E+04, 0.24688900E+04, 0.80111200E+04, 0.25059900E+04, 0.34243200E+04, 0.29872200E+04, 0.38869600E+04, 0.70037200E+04, 0.50945700E+04, 0.21617100E+04, -.14385400E+04, -.63797200E+04, 0.31474600E+04, 0.65068200E+04, 0.31898600E+04, 0.13699600E+04, 0.15449500E+04, 0.30597900E+04, 0.41483800E+04, 0.43353700E+04, 0.12295200E+04, 0.20763000E+04, 0.25424700E+04, -.12765400E+04, -.12677000E+04, -.12713000E+04, -.47710100E+03, -.10745300E+04, 0.18146600E+03, 0.57444500E+03, -.50465700E+03, -.11476500E+04, -.41011600E+03, 0.31441800E+05, -.15642700E+05, -.18043300E+05, -.15720500E+05, -.37202600E+04, 0.67034700E+04, -.13365900E+05, -.10503800E+05, -.13590200E+05, 0.80882300E+04, -.97692400E+04, 0.44308400E+04, -.22151000E+04, -.20746600E+04, -.22155400E+04, -.52756200E+03, 0.84214400E+03, -.13135800E+04, -.29471200E+03, -.17101700E+04, 0.95667300E+03, -.15575200E+03, 0.16845600E+05, -.83632100E+04, -.62964800E+04, -.84224100E+04, 0.45020000E+03, 0.72848000E+04, -.69902600E+04, -.40183700E+04, -.79695400E+04, 0.77415500E+04, -.52901400E+04, 0.11963900E+05, -.60847600E+04, 0.50835700E+03, -.59808400E+04, 0.10522000E+04, 0.49973100E+04, -.36319500E+04, -.20229000E+03, -.42375000E+04, 0.51072000E+04, -.59790100E+03, -.26076300E+04, 0.12704000E+04, 0.36871700E+04, 0.13038100E+04, 0.79251000E+03, 0.10101800E+04, 0.15532200E+04, 0.28469200E+04, 0.25523600E+04, 0.78038700E+03, 0.11113700E+04, -.73856200E+03, 0.36097000E+03, 0.69120800E+03, 0.36927400E+03, 0.18287900E+03, 0.24331900E+03, 0.22304400E+03, 0.52588900E+03, 0.70224900E+03, 0.17193800E+03, 0.72607500E+03, 0.42261900E+03, -.12278700E+03, -.61495600E+04, -.21128300E+03, -.12199000E+04, -.29426400E+04, -.81058300E+03, -.32006100E+04, -.14390400E+04, -.28338300E+04, -.21525400E+04, -.32815000E+05, 0.16346100E+05, 0.14783500E+05, 0.16407000E+05, 0.18685500E+04, -.10054200E+05, 0.14327600E+05, 0.10970000E+05, 0.14217700E+05, -.11259700E+05, 0.11279100E+05, 0.45917500E+05, -.22661400E+05, -.29728700E+05, -.22957900E+05, -.80277700E+04, 0.14669800E+05, -.22606500E+05, -.23836400E+05, -.23138400E+05, 0.16806200E+05, -.18976000E+05, 0.54476100E+04, 0.45460000E+04, 0.38249300E+04, 0.38513700E+04, 0.13942100E+04, -.45816600E+04, 0.10430400E+04, -.75889100E+04, -.27582400E+04, 0.38617600E+04, 0.49406100E+04, 0.23074500E+04, -.14857600E+04, -.23026300E+04, -.61836800E+04, -.57566000E+04, -.37414900E+04, -.13505700E+04, 0.39322200E+04, -.41113500E+04, -.68592900E+04, 0.55084300E+04, 0.57033100E+04, -.49668400E+04, -.34051000E+04, -.19736000E+04 },
        { -.41951300E+00, 0.45572200E-01, 0.13052200E+00, 0.16193900E+00, 0.20374900E+00, 0.12997600E+00, 0.28535800E+00, -.39857800E+00, -.14811000E-01, 0.18162600E-02, 0.10007300E-01, 0.33404500E-01, 0.65818900E-01, -.66099800E-02, -.47818400E-02, 0.14087300E+01, -.82190900E-01, 0.18903600E+00, 0.11248000E+00, 0.14712300E-01, -.22255300E+00, -.13200600E+00, 0.44808800E-02, -.35630500E+00, -.62347900E-01, -.31906800E-01, -.74875500E-01, -.59066000E+00, 0.11298800E+04, 0.12848900E+04, -.60680200E+03, -.20761800E+03, -.86453100E+03, -.38202200E+04, 0.18635400E+04, -.19273300E+04, 0.19081400E+04, 0.94618400E+02, -.96747400E+03, 0.18012200E+04, 0.16907000E+04, 0.25627300E+04, -.94822800E+03, 0.19604000E+04, -.86678600E+03, 0.44942600E+03, -.49069600E+03, 0.43329300E+03, 0.89648600E+03, 0.64606200E+03, 0.69839100E+03, 0.20479000E+04, 0.13467900E+04, 0.46902500E+03, -.17000500E+04, 0.61582300E+04, -.29549500E+04, 0.20437000E+04, -.30775300E+04, 0.15263400E+04, 0.43906900E+04, -.27949700E+04, -.27666300E+03, -.25188700E+04, 0.38458700E+04, -.64651900E+04, 0.24784400E+04, -.12239900E+04, -.81300900E+03, -.12395200E+04, 0.23031800E+04, 0.18888500E+04, 0.92549000E+02, 0.27627000E+04, -.85323900E+03, 0.15157200E+04, -.37060500E+04, -.30433600E+04, 0.14560400E+04, -.85455700E+03, 0.15190000E+04, 0.10763600E+04, -.79337300E+03, 0.28843700E+04, 0.38603000E+04, 0.19697100E+04, -.10975400E+04, 0.10434900E+04, 0.34735800E+04, -.17073600E+04, -.15559900E+04, -.17353200E+04, -.16440500E+04, -.88703900E+03, -.17765300E+03, -.78703000E+03, -.22752800E+04, -.59415800E+03, -.25307800E+02, -.33703100E+04, 0.17194900E+04, 0.35093400E+04, 0.16855400E+04, 0.83536100E+03, 0.98016300E+03, -.41976900E+03, -.92935900E+03, 0.17428600E+04, 0.92138200E+03, -.11073600E+03, 0.34282600E+04, -.17229300E+04, -.11156200E+04, -.17106100E+04, -.45909000E+03, 0.39213000E+03, -.23766300E+04, -.24719100E+04, -.22597000E+04, 0.80723200E+03, 0.78437500E+03, -.28581900E+04, 0.13430900E+04, -.34665600E+04, 0.14297500E+04, -.36663000E+03, -.38029600E+04, 0.35941200E+04, 0.25671400E+04, 0.19408400E+04, -.37039300E+04, 0.16201800E+04, -.14144600E+04, 0.72073300E+03, -.18965900E+04, 0.70629200E+03, -.28618000E+03, -.84212200E+03, 0.13802800E+04, 0.10750500E+04, 0.14283400E+04, -.87388100E+03, 0.18502600E+03, 0.41152900E+04, -.20876000E+04, -.23346000E+04, -.20551900E+04, -.54921400E+04, -.57384600E+04, -.14985800E+04, -.45799800E+04, -.12371400E+04, -.46166500E+04, 0.39523800E+04, 0.19117600E+05, -.95855700E+04, -.10445800E+05, -.95587700E+04, -.31120500E+04, -.34191000E+04, -.36458400E+04, 0.77268700E+03, -.58752500E+04, -.34059300E+04, -.39311200E+04, -.11654700E+04, 0.56519900E+03, -.27282200E+03, 0.58229400E+03, 0.19025600E+03, 0.40224900E+03, 0.11299100E+04, 0.45777500E+03, -.18706000E+03, 0.25653900E+03, 0.38032000E+02, -.31466600E+04, 0.15968200E+04, 0.59453500E+04, 0.15760200E+04, -.26299500E+03, 0.11945500E+04, -.32810400E+03, -.17190400E+04, 0.10125400E+04, 0.13723100E+04, 0.15557100E+04, 0.12235900E+04, -.61817500E+03, -.10483200E+04, -.61278800E+03, -.80294000E+02, 0.13084100E+03, -.39344800E+03, -.70794100E+03, -.94998900E+02, 0.25966100E+03, 0.49764000E+03, 0.78711700E+04, -.39389700E+04, -.55626000E+03, -.39321300E+04, -.72998600E+03, 0.85395300E+03, -.30309800E+04, -.34171600E+04, -.43309000E+04, 0.10427400E+04, 0.68814400E+03, 0.14738900E+04, -.79575400E+03, -.30083200E+04, -.72974100E+03, -.32712500E+04, -.31396800E+04, -.59681400E+03, -.20651800E+04, -.14975600E+04, -.25722900E+04, 0.37318100E+04, 0.11086200E+05, -.55736200E+04, -.71348200E+04, -.55431100E+04, -.20127600E+04, -.22538400E+04, -.19564200E+04, 0.92721500E+03, -.31650900E+04, -.21864600E+04, -.15254700E+04, 0.66309700E+04, -.33144700E+04, -.29792500E+04, -.33155300E+04, -.79183800E+03, -.93092500E+03, -.82488900E+03, 0.12287200E+04, -.18090600E+04, -.98438100E+03, -.21021000E+04, -.10911800E+05, 0.55167300E+04, 0.67838400E+04, 0.54560500E+04, 0.27664700E+04, 0.35604400E+04, 0.18195000E+04, -.61102200E+03, 0.41960700E+04, 0.33017200E+04, 0.12997600E+04, 0.22050300E+04, -.11076200E+04, -.45147200E+04, -.11061000E+04, 0.11291800E+04, -.79147500E+03, 0.16780300E+04, 0.44149800E+04, 0.59658100E+03, -.11889800E+04, -.27654500E+04, 0.94359600E+04, -.45618100E+04, 0.18055600E+04, -.47132000E+04, -.51993800E+03, 0.33665200E+04, -.19616600E+04, -.49400700E+03, -.50293400E+04, 0.29940700E+04, -.72874200E+04, 0.13326800E+04, 0.74945600E+03, 0.59086400E+03, 0.41901500E+03, 0.40690900E+02, -.37114400E+03, -.12300800E+04, 0.35418400E+04, -.34741400E+03, 0.95261500E+03, 0.12725500E+04, 0.19360800E+03, -.29935000E+03, 0.27857700E+03, 0.14173500E+04, 0.92636700E+03, -.54664200E+03, 0.32501500E+03, 0.55896000E+03, -.50621900E+03, 0.12061600E+04, -.42728500E+03, -.14473300E+04, -.31396900E+03, 0.11990800E+03, -.48539000E+03 },
        { 0.77418000E+01, 0.68754200E+00, -.12310700E+01, 0.33145600E-01, -.43437000E+01, -.22528500E+01, 0.69064800E-01, -.13756300E+02, 0.11862400E+01, -.22468800E+01, -.23080100E+01, -.68935700E+00, -.13755800E+01, 0.42540000E+00, -.20225800E+01, 0.43350800E+02, 0.11419500E+01, 0.79493300E+01, 0.50417800E+01, -.12091800E+01, -.72848200E+01, -.13393600E+01, -.21440900E+00, -.12742100E+01, -.99181700E+00, 0.64502800E+00, -.10202000E+01, -.27386100E+00, 0.61991300E+01, 0.15323600E+05, 0.18611500E+05, -.39376800E+04, 0.22362600E+05, -.22459200E+06, 0.11233700E+06, 0.15946500E+06, 0.11231500E+06, 0.20308600E+05, -.68540800E+05, 0.89694300E+05, 0.60881200E+05, 0.95887700E+05, -.81126500E+05, 0.72958700E+05, -.56680700E+05, 0.27841800E+05, 0.54998200E+05, 0.28342900E+05, 0.11671300E+05, 0.26352900E+05, -.94313700E+04, -.30988300E+05, -.88318500E+04, 0.22115700E+05, 0.33964200E+05, 0.33603900E+06, -.16923300E+06, -.18472900E+06, -.16803300E+06, -.24517400E+05, 0.12791000E+06, -.14118500E+06, -.83538000E+05, -.16604800E+06, 0.13066600E+06, -.65589500E+05, 0.19193400E+06, -.96385700E+05, -.57657900E+05, -.95964300E+05, -.31027300E+05, -.76592500E+04, -.35621100E+05, 0.31438500E+05, -.49716200E+05, -.16312100E+05, -.24584400E+05, -.26646800E+06, 0.13394700E+06, 0.14981100E+06, 0.13325700E+06, 0.20788300E+05, -.10469000E+06, 0.10927100E+06, 0.74516800E+05, 0.12985100E+06, -.11102800E+06, 0.76679800E+05, 0.81956100E+05, -.41338400E+05, -.36327000E+05, -.40990800E+05, 0.15637600E+03, 0.33410500E+05, -.36938400E+05, -.25723600E+05, -.33241400E+05, 0.36864300E+05, -.37491000E+05, -.11295800E+05, 0.60468600E+04, -.16368900E+05, 0.56449600E+04, 0.55227000E+04, 0.13452600E+05, 0.19783500E+03, -.10975200E+05, -.92167600E+04, 0.15439000E+05, 0.14997800E+04, 0.21896800E+06, -.10957600E+06, -.12547800E+06, -.10951400E+06, -.37467500E+05, 0.20359700E+05, -.62405600E+05, -.32588300E+05, -.69486500E+05, 0.30089600E+05, -.68959500E+05, -.27780100E+06, 0.14004200E+06, 0.16925800E+06, 0.13889100E+06, 0.33229500E+05, -.90764400E+05, 0.10473700E+06, 0.68544200E+05, 0.12025000E+06, -.98122100E+05, 0.87795300E+05, -.13976700E+06, 0.70403000E+05, 0.10609600E+06, 0.69892100E+05, 0.11627600E+05, -.33831100E+05, 0.52747900E+05, 0.38236700E+05, 0.66773800E+05, -.46194100E+05, 0.62234000E+05, -.39137600E+06, 0.19651200E+06, 0.12827300E+06, 0.19566700E+06, 0.70661500E+05, 0.20122200E+05, 0.68903600E+05, -.62554300E+05, 0.97552900E+05, 0.34978600E+05, 0.52166700E+05, -.16684000E+06, 0.83306400E+05, 0.10253800E+06, 0.83419700E+05, 0.37420200E+05, 0.30484000E+03, 0.32126400E+05, -.20093700E+05, 0.42652000E+05, 0.97172700E+04, 0.41538000E+04, -.34013600E+05, 0.16554500E+05, 0.25207000E+05, 0.17010700E+05, 0.41697200E+04, 0.18502900E+04, 0.17753000E+04, 0.39013800E+04, 0.25439200E+05, -.32101600E+04, 0.33090800E+05, 0.13719700E+06, -.69033900E+05, -.82308200E+05, -.68631100E+05, -.23774800E+05, 0.30402200E+05, -.55373400E+05, -.60253800E+05, -.57295700E+05, 0.41356200E+05, -.42800100E+05, -.30787700E+05, 0.15066800E+05, 0.17773500E+05, 0.15423000E+05, 0.63116600E+04, 0.62218300E+04, -.23625300E+04, -.18254400E+05, -.14406900E+04, 0.63100800E+04, 0.10901000E+04, 0.18157700E+06, -.90379600E+05, -.13688800E+06, -.90823100E+05, -.21987600E+05, -.94330100E+04, -.26889600E+05, 0.17461400E+05, -.42244400E+05, -.44320400E+03, -.86627500E+05, 0.15032600E+05, -.71317500E+04, -.14861600E+05, -.75777500E+04, -.87838400E+04, -.30817400E+05, 0.76432100E+04, 0.10721200E+05, 0.29082900E+05, -.24295300E+05, -.22158500E+05, -.13763800E+06, 0.68351800E+05, 0.92072700E+05, 0.68818700E+05, 0.29590600E+05, 0.10689800E+04, 0.23632800E+05, -.21587000E+05, 0.30514800E+05, 0.85956300E+04, 0.66167500E+04, -.27123000E+05, 0.13645100E+05, 0.19136000E+05, 0.13561900E+05, 0.75417700E+04, 0.14107800E+04, 0.26700900E+04, -.60721900E+04, 0.45546100E+04, 0.20441000E+04, 0.17721300E+04, 0.12844000E+06, -.64123300E+05, -.52926700E+05, -.64221200E+05, -.21881300E+05, 0.68382500E+04, -.19845400E+05, 0.98218300E+04, -.38626500E+05, 0.37182800E+04, -.21947700E+05, -.19419700E+06, 0.97597100E+05, 0.12112900E+06, 0.97129800E+05, 0.27912100E+05, -.24556400E+05, 0.56372200E+05, 0.37803100E+05, 0.52159900E+05, -.35321500E+05, 0.64576600E+05, 0.43510500E+06, -.21813300E+06, -.23481400E+06, -.21758800E+06, -.47076500E+05, 0.15755900E+06, -.17998300E+06, -.10408700E+06, -.17858300E+06, 0.15807600E+06, -.76823200E+05, 0.51567200E+05, 0.30728600E+05, 0.28132800E+05, 0.28484100E+05, 0.15637800E+05, -.34262700E+05, -.72880000E+04, -.51645300E+05, -.14959400E+05, 0.26339400E+05, 0.26688500E+05, 0.23004800E+05, -.13367900E+05, -.29005900E+05, -.41848300E+05, -.32321500E+05, -.29818300E+05, -.19666700E+05, 0.27244700E+05, -.34980500E+05, -.28554500E+05, 0.34598600E+05, 0.12414700E+05, -.27585700E+05, -.27163900E+05, -.16953300E+05 },
        { 0.12412200E+01, 0.12644900E+00, -.41302800E+00, -.38700600E+00, 0.59734800E-01, -.31879600E+00, -.32358800E+01, 0.30492200E+01, 0.20265000E-01, 0.15175500E+01, 0.28284200E-01, -.50256100E+00, -.23191800E+00, 0.11011000E+00, 0.30627600E+00, -.44932700E+01, 0.16398300E+01, 0.11740400E+00, -.20818800E+01, -.20686700E+00, 0.56806600E-01, 0.15287200E+00, -.12919500E+00, -.11437300E+01, 0.79671500E-01, 0.32788100E-01, 0.75091300E-01, -.18853100E+01, 0.32248100E+00, -.97257600E-03, 0.34684500E+04, 0.72035500E+03, -.38892200E+04, 0.45068900E+05, -.22738200E+05, -.16974000E+05, -.22532000E+05, -.77752900E+04, 0.89416400E+04, -.16264900E+05, -.16148400E+05, -.23829400E+05, 0.12772000E+05, -.46591700E+04, 0.71936200E+04, -.35571200E+04, -.35315200E+04, -.35965900E+04, -.52049700E+03, -.43233800E+04, -.15806300E+04, -.13807400E+04, -.61871300E+04, -.31129900E+04, -.71920500E+04, -.66267900E+05, 0.33529300E+05, 0.20294200E+05, 0.33132100E+05, 0.90810300E+04, -.25643600E+05, 0.29996600E+05, 0.22580600E+05, 0.34830600E+05, -.27945400E+05, -.56840600E+04, -.58769500E+04, 0.31424000E+04, 0.42247800E+04, 0.29388200E+04, 0.51268600E+04, 0.70991100E+02, 0.26261800E+04, -.52543400E+03, -.31245900E+04, 0.13305300E+04, -.43929500E+04, 0.58985200E+05, -.29711500E+05, -.20991400E+05, -.29489400E+05, -.48898400E+04, 0.19916400E+05, -.24551700E+05, -.18613300E+05, -.30860300E+05, 0.23513400E+05, -.38882900E+04, -.48652400E+04, 0.25944500E+04, 0.16022900E+04, 0.24308800E+04, 0.29063000E+04, -.13523700E+04, 0.16238800E+04, 0.72472500E+04, 0.73826200E+04, -.29776500E+04, -.30348400E+03, 0.45379800E+04, -.24613100E+04, -.53798700E+04, -.22694200E+04, -.48610200E+04, -.69884400E+04, 0.54231700E+04, 0.26629900E+04, 0.10009200E+04, -.85609300E+04, -.70890000E+04, -.42912800E+05, 0.21497800E+05, 0.18751700E+05, 0.21452300E+05, 0.41188200E+04, -.60010300E+04, 0.17400200E+05, 0.14206600E+05, 0.19302200E+05, -.88189300E+04, 0.14822400E+05, 0.34879000E+05, -.17740900E+05, -.64356500E+04, -.17440500E+05, -.44476600E+04, 0.22923200E+05, -.27573900E+05, -.31172500E+05, -.28840400E+05, 0.26867900E+05, 0.16766100E+04, 0.23617500E+05, -.12281100E+05, -.84918600E+04, -.11807600E+05, -.38791100E+04, 0.34657000E+04, -.97695500E+04, -.11948300E+05, -.14176900E+05, 0.71591700E+04, -.38367400E+04, 0.42303500E+05, -.21444700E+05, -.25309100E+05, -.21154700E+05, -.14239800E+05, -.20672700E+04, -.88163400E+04, 0.54899100E+04, -.10814900E+04, -.52186400E+04, -.25588000E+04, 0.57306900E+05, -.28397500E+05, -.20357500E+05, -.28653500E+05, -.11963400E+05, -.86479600E+04, -.46877900E+04, 0.84825800E+04, -.13676900E+05, -.66339600E+04, -.15995300E+05, 0.10781900E+05, -.52159900E+04, -.18120900E+04, -.53903900E+04, -.99797000E+03, 0.59679700E+03, -.10167400E+04, 0.82936900E+03, -.13424600E+04, 0.12416600E+04, -.42775700E+04, -.10699600E+05, 0.54670900E+04, -.34083700E+04, 0.53467200E+04, 0.36720400E+04, -.80922500E+04, 0.15841900E+05, 0.23547400E+05, 0.15835300E+05, -.12056700E+05, 0.63298300E+03, 0.88560900E+04, -.43622400E+04, -.24865100E+04, -.44267800E+04, -.50037100E+03, 0.15144600E+04, -.14491700E+04, 0.14136600E+04, -.36748600E+04, 0.10904500E+04, 0.16897400E+04, -.27964400E+05, 0.14087600E+05, 0.10259700E+05, 0.13977900E+05, 0.49032600E+04, 0.70178700E+04, 0.57768400E+04, 0.47071600E+04, 0.14355100E+05, 0.35004500E+04, 0.16194000E+05, -.18721400E+05, 0.91980400E+04, 0.10861600E+05, 0.93522800E+04, -.72510400E+04, -.19537500E+04, 0.12694200E+05, 0.69255900E+04, 0.12288000E+05, -.25120600E+04, 0.19092100E+05, 0.50991200E+05, -.25188300E+05, -.17692100E+05, -.25495600E+05, -.89565700E+04, -.64485700E+04, -.44616200E+04, 0.91448700E+04, -.12037500E+05, -.50445700E+04, -.14875300E+05, 0.96586100E+04, -.48324700E+04, -.45184100E+04, -.48292500E+04, -.28390900E+04, -.18336700E+04, -.25200200E+03, 0.22438500E+04, -.97190300E+03, -.13743100E+04, -.20311700E+04, -.10571500E+05, 0.50928800E+04, 0.29483300E+04, 0.52855700E+04, 0.54875400E+04, -.40975100E+03, 0.23753800E+04, -.17109900E+04, 0.17876100E+04, -.18238700E+04, -.53044800E+04, 0.34131400E+05, -.17238700E+05, -.71943900E+04, -.17061500E+05, -.32691100E+04, 0.74174100E+04, -.18747800E+05, -.19500000E+05, -.21120000E+05, 0.11669700E+05, -.10193900E+05, -.76775300E+05, 0.38466400E+05, 0.26285700E+05, 0.38382400E+05, 0.11013000E+05, -.30773000E+05, 0.38805800E+05, 0.29958300E+05, 0.47319300E+05, -.33440000E+05, 0.13178600E+04, -.10598900E+05, -.75167600E+04, -.51075400E+04, -.48431700E+04, -.15006200E+04, 0.47237100E+04, 0.28857900E+04, 0.95095200E+04, 0.36539600E+04, -.77185600E+04, -.77794100E+04, -.33587100E+04, 0.27712100E+04, 0.30798800E+04, 0.88599100E+04, 0.10131400E+05, 0.53738900E+04, -.14121700E+04, -.46943700E+04, 0.48581000E+04, 0.45807900E+04, -.83956900E+04, -.11188400E+05, 0.75804100E+04, 0.27352300E+04, 0.49033300E+04 },
        { -.10803800E+01, 0.31682100E+00, 0.35301600E+00, 0.78888000E-02, 0.87043700E+00, 0.11548200E+00, 0.46906100E+00, 0.13184500E+01, -.12354100E+00, 0.28753000E+00, 0.25596300E+00, -.95502600E-02, 0.25418000E+00, -.11444700E-01, -.21642100E-01, 0.46765200E+00, 0.66213900E+00, 0.36180200E+00, -.44856800E+00, 0.13971500E+00, -.17835300E-01, 0.32568700E-01, -.46294800E-01, -.11287900E+00, -.79522900E-01, 0.16740700E-01, 0.37800600E+00, -.21520200E-01, -.15046400E+01, -.31620400E-01, -.13585600E+00, -.44694600E+03, -.18318700E+04, 0.80171700E+04, -.41657600E+04, -.17456400E+04, -.40098100E+04, 0.46493600E+04, 0.76271600E+04, -.26118200E+04, 0.11495200E+04, -.17470500E+04, 0.76874000E+04, -.26456400E+04, -.37852700E+04, 0.19390200E+04, 0.73226100E+04, 0.18926400E+04, 0.53569100E+04, 0.47442900E+04, 0.22242200E+04, 0.60820200E+04, 0.25367300E+04, 0.37007600E+04, -.67625700E+04, -.23202400E+05, 0.12009900E+05, 0.18797900E+05, 0.11602300E+05, -.10670200E+04, -.70587800E+04, 0.74625000E+04, 0.19763900E+04, 0.10219700E+05, -.78977800E+04, -.10545800E+05, -.15952300E+05, 0.80233900E+04, 0.11344200E+05, 0.79759600E+04, 0.54442200E+04, 0.14816800E+04, 0.69379800E+04, 0.56597900E+04, 0.59868600E+04, 0.18721700E+04, -.52653500E+04, -.45929800E+03, 0.98879800E+02, -.67384400E+03, 0.22786800E+03, 0.49419300E+04, 0.78734700E+04, 0.19987500E+04, 0.53423200E+04, -.30071800E+03, 0.82063400E+04, 0.37931600E+04, 0.34983400E+04, -.17105500E+04, -.28153700E+04, -.17482000E+04, -.27711000E+04, -.27157900E+04, -.98638700E+03, -.25108800E+04, -.38698200E+04, -.26802600E+04, 0.17146600E+04, 0.36203900E+04, -.15229800E+04, 0.15115200E+04, -.18099300E+04, -.18224900E+04, -.12171400E+04, -.46529600E+03, 0.12106400E+04, 0.20300400E+04, -.15993400E+04, -.49403600E+04, -.13682500E+04, 0.56336400E+03, -.35894900E+04, 0.68645600E+03, -.18328300E+04, -.34244700E+04, -.12743200E+04, -.33793900E+04, 0.22061800E+02, -.31398100E+04, 0.56818200E+04, 0.48448700E+03, -.43763200E+03, -.48425400E+04, -.24199400E+03, 0.62754000E+04, 0.62236300E+04, 0.99682000E+03, 0.11436300E+04, -.26608000E+04, 0.72500400E+04, 0.19898700E+04, 0.63591000E+04, -.27987200E+04, -.44687800E+03, -.31801500E+04, 0.41035900E+04, 0.45957100E+04, -.14419200E+04, 0.68236800E+03, -.10132900E+04, 0.44359200E+04, -.57113500E+04, 0.40905600E+05, -.20568200E+05, -.27779700E+05, -.20451200E+05, -.11648100E+05, -.54735100E+04, -.14514200E+05, -.10084300E+05, -.15398900E+05, -.55560200E+04, 0.64091100E+04, 0.41930000E+05, -.21170800E+05, -.23676600E+05, -.20965000E+05, -.56727100E+04, -.43015000E+04, -.88402500E+04, -.17140800E+03, -.15169700E+05, -.42506500E+04, -.37738500E+04, -.65853000E+04, 0.30430100E+04, 0.25155400E+04, 0.32923600E+04, 0.10409400E+04, 0.19400800E+04, 0.10287100E+04, -.13662100E+04, 0.12248400E+04, 0.15317500E+04, 0.30835600E+04, 0.28382700E+04, -.14068100E+04, 0.39909800E+04, -.14179000E+04, -.34265700E+04, -.18246700E+04, 0.92998200E+03, 0.36152900E+04, 0.21700700E+04, -.28495600E+04, 0.22333100E+04, -.60913900E+03, 0.18535300E+03, 0.29749500E+02, 0.30457900E+03, 0.27807800E+03, 0.14634500E+04, 0.58683900E+03, 0.10910200E+03, 0.93250600E+02, 0.16112200E+04, 0.36742400E+04, 0.98451000E+04, -.49881700E+04, -.88139700E+04, -.49204800E+04, -.90693200E+04, -.60866800E+04, -.33059000E+04, -.74605400E+04, -.43515900E+04, -.47594400E+04, 0.90572200E+04, 0.16252300E+05, -.84057900E+04, -.16760000E+05, -.81213500E+04, -.46143000E+04, -.29415000E+04, -.58117100E+04, -.52125000E+04, -.65277600E+04, -.27507800E+04, 0.99602600E+04, 0.26894200E+05, -.13744500E+05, -.16494500E+05, -.13447100E+05, -.35499200E+04, -.23706500E+04, -.55828400E+04, 0.79364300E+03, -.94614300E+04, -.24760000E+04, -.13332400E+04, 0.83405900E+04, -.41670900E+04, -.36836600E+04, -.41703300E+04, -.10850600E+04, -.11102200E+04, -.94827600E+03, 0.13963500E+04, -.24290500E+04, -.11102000E+04, -.17381800E+04, -.16066200E+05, 0.84533000E+04, 0.14901200E+05, 0.80332200E+04, 0.19513900E+04, 0.21792600E+04, 0.48584700E+04, 0.16399000E+04, 0.91703800E+04, 0.15358300E+04, -.52226100E+04, -.10066400E+04, 0.65451600E+03, -.36287500E+02, 0.50096100E+03, 0.48954400E+04, 0.32351700E+04, 0.28054500E+04, 0.50457200E+04, 0.31820500E+03, 0.37392700E+04, -.75180900E+04, -.84141200E+04, 0.49572300E+04, 0.15361200E+05, 0.42104600E+04, -.49251800E+04, -.93871900E+04, 0.65267700E+04, 0.32476000E+04, 0.53165100E+04, -.10780100E+05, -.10292700E+05, -.71906300E+02, -.56807600E+03, 0.99110600E+03, 0.10112300E+04, -.78704400E+03, 0.15014100E+04, 0.22267400E+04, 0.67113000E+04, 0.14662000E+04, -.29189600E+03, 0.21624700E+03, -.21042600E+04, 0.22797900E+04, 0.12445900E+04, 0.35045500E+04, 0.11984900E+04, -.11605200E+04, 0.32157100E+04, 0.12415700E+04, 0.44171300E+03, 0.45179300E+04, -.48683400E+03, -.10526000E+04, 0.86186000E+03, 0.26768600E+04, -.42508800E+03 },
        { 0.19084200E+01, -.26898300E+00, 0.35684000E+00, -.50640100E+00, -.39549200E+00, -.98687400E-01, -.52226700E+00, 0.34237900E+01, 0.23715400E+00, 0.39390000E+00, -.58668100E-01, -.41664400E+00, -.71788000E+00, 0.86094300E-01, 0.45399100E-01, -.37741500E+01, -.15791200E+01, -.94763000E+00, -.33934400E+00, 0.76785100E+00, 0.92792000E+00, -.23530200E+00, 0.44908700E-01, -.79105900E+00, 0.37918300E+00, 0.13144400E+00, 0.40368800E+00, -.11752000E+01, -.66249300E+00, 0.10910900E+00, -.13412000E+00, -.14446000E+01, -.79218500E+04, 0.64942100E+05, -.32801600E+05, -.51607600E+05, -.32472400E+05, -.37032800E+04, 0.30449200E+05, -.30156900E+05, -.22940000E+05, -.27487400E+05, 0.33582700E+05, -.62789600E+04, -.10383700E+04, 0.69638400E+03, -.76587200E+04, 0.51907500E+03, 0.94146700E+04, 0.91967100E+04, 0.51499600E+04, 0.15819700E+05, 0.68983700E+04, 0.68307400E+04, -.18024600E+05, -.94234900E+05, 0.48168700E+05, 0.73226600E+05, 0.47118500E+05, 0.13643400E+05, -.25829700E+05, 0.43144500E+05, 0.40372700E+05, 0.47710300E+05, -.32972200E+05, -.32982000E+05, -.53749100E+05, 0.27000000E+05, 0.15329700E+05, 0.26874400E+05, 0.14061700E+05, 0.78502800E+04, 0.17150300E+05, 0.11040400E+05, 0.20031100E+05, 0.66383500E+04, -.30423700E+04, 0.68912900E+05, -.34856800E+05, -.49309200E+05, -.34458300E+05, -.18676600E+04, 0.37961600E+05, -.26074700E+05, -.16253800E+05, -.29817700E+05, 0.41263100E+05, 0.14032400E+04, -.86984400E+04, 0.45258800E+04, 0.47132500E+04, 0.43502200E+04, -.49939900E+04, -.13849300E+05, 0.72414100E+04, 0.59051500E+04, 0.25270600E+04, -.13773100E+05, 0.66929100E+04, 0.30520700E+04, -.92576000E+03, 0.86510200E+04, -.15257900E+04, -.15642200E+03, 0.12037700E+03, 0.78945500E+03, 0.18431000E+04, 0.27448400E+04, -.33478300E+03, -.14856100E+05, -.54964900E+05, 0.27230000E+05, 0.31819000E+05, 0.27484900E+05, 0.24131300E+04, -.22843000E+05, 0.20171600E+05, 0.12381900E+05, 0.19326100E+05, -.24125900E+05, 0.26992200E+05, 0.61996200E+05, -.31539800E+05, -.58970900E+05, -.30997500E+05, -.27736700E+04, 0.27464300E+05, -.27519500E+05, -.29820800E+05, -.32264100E+05, 0.33127300E+05, -.21271000E+04, 0.44628400E+05, -.21557400E+05, -.36080500E+05, -.22314900E+05, -.72684200E+03, 0.17265100E+05, -.19001300E+05, -.13479900E+05, -.17591000E+05, 0.19079700E+05, -.13958600E+05, 0.12488900E+06, -.62669500E+05, -.48943000E+05, -.62443000E+05, -.30608800E+05, -.22794400E+05, -.37750600E+05, -.26662800E+05, -.48045700E+05, -.17773200E+05, -.31572700E+03, 0.81458700E+05, -.41062500E+05, -.66608000E+05, -.40729300E+05, -.11518600E+05, -.80396800E+04, -.23871100E+05, -.11186400E+05, -.30225500E+05, -.68353200E+04, -.59563500E+03, -.25751500E+04, 0.81366300E+03, -.34214600E+04, 0.12872800E+04, 0.55517100E+03, 0.29180200E+04, 0.63255200E+03, 0.88778800E+02, 0.15576900E+03, 0.28354400E+04, 0.14124500E+04, -.59519000E+05, 0.29792600E+05, 0.49989400E+05, 0.29760200E+05, 0.42240700E+04, -.15144700E+05, 0.28105400E+05, 0.27236800E+05, 0.30116200E+05, -.19249900E+05, 0.22019500E+05, 0.54550800E+04, -.29390500E+04, -.51284400E+04, -.27294700E+04, 0.24330600E+01, 0.29754000E+04, -.18814300E+02, 0.24303000E+04, -.15477200E+04, 0.27014000E+04, 0.10063200E+05, -.11370700E+05, 0.54690100E+04, 0.26253400E+05, 0.56878000E+04, -.10586400E+05, -.12745400E+05, -.81480600E+03, -.14336800E+05, -.46404900E+04, -.11808600E+05, 0.33783000E+05, -.87048400E+03, -.21713700E+03, -.12581100E+05, 0.44011700E+03, -.11629500E+05, -.14407300E+05, -.16616200E+04, -.98877800E+04, -.63502700E+04, -.12861800E+05, 0.38161300E+05, 0.44832900E+05, -.22947600E+05, -.43084000E+05, -.22416500E+05, -.72197400E+04, -.44666000E+04, -.13494000E+05, -.56810500E+04, -.16371700E+05, -.37888000E+04, 0.56223800E+04, 0.17571200E+05, -.87413500E+04, -.16551000E+05, -.87856300E+04, -.15998300E+04, -.18930000E+04, -.22482400E+04, 0.24870200E+04, -.45322800E+04, -.16221500E+04, -.32966900E+04, -.44565100E+05, 0.23125200E+05, 0.36238700E+05, 0.22282700E+05, 0.89794200E+04, 0.10994900E+05, 0.13405300E+05, 0.90165300E+04, 0.21085800E+05, 0.87917600E+04, -.11742500E+05, 0.62069900E+05, -.30718700E+05, -.54830500E+05, -.31037400E+05, 0.24719000E+04, 0.22194100E+05, -.20623900E+05, -.92503500E+04, -.20756700E+05, 0.24570600E+05, -.31495600E+05, -.11782000E+06, 0.60644400E+05, 0.87605600E+05, 0.58913200E+05, 0.13897600E+05, -.48387400E+05, 0.60223500E+05, 0.54028700E+05, 0.55685100E+05, -.55161200E+05, -.16293500E+05, -.11188200E+05, -.91511000E+04, -.77651800E+04, -.76815700E+04, -.48112000E+04, 0.13416500E+05, 0.31601500E+04, 0.31774700E+05, 0.59152500E+04, -.77614500E+04, -.90497600E+04, -.86248100E+04, 0.89693200E+04, 0.97160200E+04, 0.20156100E+05, 0.14707900E+05, 0.76583900E+04, 0.11293100E+05, -.69355900E+04, 0.10929700E+05, 0.21497400E+05, -.12744400E+05, -.11310300E+05, 0.11394100E+05, 0.13335800E+05, 0.27227300E+04 },
        { -.43457900E+00, -.19163800E-01, 0.79101500E-01, 0.90193200E-01, 0.12273200E+00, 0.36729500E-01, 0.19636100E+00, -.51256100E+00, -.20973400E-01, -.33443600E+00, 0.67531900E-02, 0.27957600E-01, 0.11210600E+00, 0.16821700E-01, -.66850500E-01, 0.26547000E+01, 0.56650900E+00, 0.41356800E+00, 0.35037900E+00, -.98723000E-02, -.28485600E+00, 0.28370200E-01, -.45642500E-01, -.22942200E-01, -.35978500E-01, -.12059400E-01, -.12595700E+00, -.89843200E-01, 0.38306200E+00, 0.18711600E-01, 0.12830300E-01, -.20448500E+00, -.30207300E-01, 0.93002900E+04, -.45580900E+04, 0.20440700E+04, -.46505500E+04, 0.95679600E+03, 0.17937700E+04, -.27106700E+04, -.73537900E+03, -.35224300E+04, 0.16484300E+04, -.60415500E+04, 0.40723800E+04, -.20836100E+04, 0.17809600E+04, -.20362100E+04, 0.21088400E+04, 0.36982500E+04, -.11231800E+04, 0.23365500E+04, -.16383800E+04, 0.31899900E+04, -.14580000E+04, -.10845700E+04, 0.23173600E+03, -.72866300E+04, 0.54261300E+03, 0.54644300E+03, 0.23746500E+04, 0.85831600E+03, 0.36362400E+04, 0.15339700E+04, 0.21222100E+04, 0.66236200E+04, 0.14599400E+04, -.73187500E+03, 0.18916100E+04, -.73003300E+03, 0.14126300E+04, 0.23115600E+04, 0.62240000E+03, 0.29364500E+04, -.13385300E+04, 0.26102500E+04, -.10862700E+04, 0.26723900E+04, -.11392300E+04, 0.38239400E+04, -.13367500E+04, 0.11845800E+04, 0.20437700E+04, -.21609100E+03, 0.13073700E+04, -.20033900E+04, 0.17319200E+04, -.46279500E+04, -.20357100E+04, 0.91690900E+03, -.12523500E+03, 0.10181600E+04, 0.10489200E+03, -.74047300E+03, 0.20602500E+03, -.12146800E+04, -.20055200E+03, -.67401100E+03, 0.15462700E+04, 0.81722400E+03, -.42279700E+03, -.17696800E+04, -.40853300E+03, -.10346300E+04, -.60191000E+03, 0.51312200E+03, 0.84492000E+03, 0.13655300E+04, -.76886000E+03, 0.11823700E+04, -.50625600E+04, 0.25394800E+04, -.12838100E+04, 0.25320100E+04, -.10694000E+04, -.30826100E+04, 0.14374300E+04, -.94127100E+03, 0.24014100E+04, -.27867200E+04, 0.22100800E+04, 0.12384200E+05, -.59529600E+04, 0.22541700E+04, -.61919600E+04, -.26702400E+03, 0.41114900E+03, -.24286400E+04, -.79840700E+03, -.62112300E+04, 0.48096300E+03, -.80241100E+04, 0.82924900E+04, -.40563300E+04, 0.88306000E+03, -.41464300E+04, 0.15322600E+04, 0.27908500E+04, -.28548000E+04, -.11088100E+04, -.33562500E+04, 0.25613500E+04, -.45717200E+04, 0.49971300E+04, -.24669400E+04, -.61865900E+04, -.24980600E+04, -.41767500E+04, -.72328500E+04, -.15096400E+04, -.46076900E+04, 0.16820100E+02, -.71901400E+04, -.95420700E+03, 0.28039300E+05, -.13999800E+05, -.88789800E+04, -.14019700E+05, -.41295700E+04, -.49604000E+04, -.38071200E+04, 0.21464000E+04, -.85418900E+04, -.49279700E+04, -.11022500E+05, -.14591600E+04, 0.69139000E+03, 0.26896900E+04, 0.72949200E+03, 0.50245300E+02, -.62144400E+02, 0.60702000E+03, -.48961700E+03, 0.31243200E+03, 0.80776200E+01, -.55584500E+03, -.21799300E+05, 0.10807600E+05, 0.53331300E+04, 0.10900400E+05, 0.11211700E+03, -.30649500E+04, 0.54190500E+04, -.61395100E+03, 0.98019900E+04, -.27103300E+04, 0.84384900E+04, -.10375200E+04, 0.48259400E+03, 0.17653100E+04, 0.51828500E+03, -.28800300E+03, -.68383400E+03, 0.88876000E+03, -.11337100E+03, 0.65981000E+03, -.52959200E+03, -.78232700E+03, -.72467700E+04, 0.36179000E+04, -.36381500E+04, 0.36240900E+04, -.36329100E+04, -.68001900E+04, 0.33878400E+04, -.16579500E+04, 0.41384100E+04, -.57441800E+04, 0.34215800E+04, 0.55347900E+03, -.18435100E+03, 0.68809300E+02, -.27524800E+03, -.19955400E+04, -.46676400E+04, -.11706000E+03, -.31701500E+04, 0.17882700E+02, -.45444100E+04, -.30796100E+04, 0.18813700E+05, -.94228300E+04, -.52964400E+04, -.94068400E+04, -.27537000E+04, -.34535400E+04, -.23686400E+04, 0.21193200E+04, -.55340900E+04, -.34242400E+04, -.74085300E+04, 0.92525400E+04, -.46118900E+04, -.30588800E+04, -.46262800E+04, -.12019200E+04, -.13868600E+04, -.95849900E+03, 0.14992200E+04, -.26653800E+04, -.13503400E+04, -.37247600E+04, -.75673800E+04, 0.37298800E+04, 0.22176000E+04, 0.37837200E+04, 0.18000600E+04, 0.33585600E+04, 0.15255300E+04, 0.57438100E+03, 0.36359300E+04, 0.31090600E+04, 0.45756700E+04, 0.22335700E+05, -.11078500E+05, -.25926700E+04, -.11168600E+05, 0.55060000E+03, 0.41958800E+04, -.46144600E+04, 0.32470400E+04, -.93204200E+04, 0.37798200E+04, -.96009400E+04, -.54558400E+04, 0.24414100E+04, -.41768600E+04, 0.27289200E+04, 0.73050700E+03, 0.65279300E+03, 0.29055200E+04, 0.33761700E+04, 0.38653000E+04, 0.60286800E+03, 0.62370500E+04, -.69901100E+03, -.57113000E+03, 0.20426400E+03, 0.23207600E+03, -.21374100E+03, 0.86819700E+03, -.13705600E+04, 0.61035500E+04, 0.54069100E+03, -.44082800E+03, -.26720000E+03, -.12060500E+04, -.54041300E+03, 0.48837200E+02, 0.34293000E+04, 0.21560500E+04, -.17762700E+03, -.76174600E+03, 0.13666700E+03, 0.45082200E+03, 0.28380600E+04, -.14693400E+04, -.31776900E+04, 0.10370000E+04, 0.58815600E+03, 0.62477900E+03 },
        { -.82297800E+01, 0.21023700E+01, 0.94379000E+00, -.20032900E+01, 0.20826900E+01, -.28529000E+00, -.15346700E+01, 0.73212400E+01, -.19433900E+01, 0.10158800E+01, 0.17631600E+01, 0.81166900E+00, 0.14674600E+01, -.28789200E+00, -.65229400E+00, -.43994500E+01, 0.66486500E+00, -.98876900E+00, -.27458700E+01, -.19333900E+00, 0.43286500E+01, 0.12622900E+01, -.89472400E+00, -.89824000E+00, -.17639700E+00, -.66873700E-01, 0.60403400E+00, 0.16895100E-02, -.43798500E+01, -.22678300E+00, -.11999200E+01, -.16017800E+01, 0.10213600E+01, 0.46493400E+01, -.11327300E+05, 0.65034400E+05, -.28924300E+01, -.41585100E+04, -.26435100E+04, 0.46412300E+04, 0.78145100E+03, -.24089300E+04, 0.78490900E+03, 0.61592600E+04, -.20433300E+05, 0.11278500E+05, 0.37712400E+05, 0.10216700E+05, 0.16733100E+04, -.35835400E+04, 0.32753100E+04, -.58230900E+04, 0.21845500E+04, -.32199000E+04, -.66752500E+03, -.48972800E+05, 0.50477700E+05, -.50588000E+05, 0.24488900E+05, 0.26080600E+04, -.27746900E+05, 0.19816600E+05, 0.18622100E+04, 0.23542700E+05, -.27834300E+05, -.15606100E+05, 0.35036000E+04, -.14985700E+04, 0.79417700E+04, -.17523000E+04, 0.11642400E+04, -.84386900E+04, 0.36310700E+04, 0.51993100E+04, 0.12127200E+04, -.84955000E+04, -.79209400E+04, -.24780600E+05, -.36065600E+04, 0.53792300E+05, 0.12386000E+05, -.53185700E+03, 0.58993200E+04, 0.17165200E+04, -.51677900E+04, 0.38067700E+04, 0.90822900E+04, 0.27925900E+05, 0.34335600E+05, -.85265700E+04, -.19281600E+05, -.17165500E+05, 0.46620900E+04, 0.83183700E+04, -.10376000E+05, 0.35502100E+04, -.10874700E+05, 0.52686900E+04, -.16008500E+05, 0.35832900E+04, 0.14729600E+04, -.23415800E+05, -.17910000E+04, -.21303800E+04, -.44141200E+04, 0.12635700E+04, 0.60405300E+03, 0.19408000E+04, -.56440700E+04, -.67924700E+04, 0.83790600E+04, -.48570200E+04, -.31770100E+05, -.41840100E+04, 0.52156100E+02, 0.18450700E+04, 0.65280000E+03, 0.57967700E+04, 0.24785500E+04, -.51395400E+03, 0.93858800E+03, -.47204300E+05, 0.55672700E+04, 0.93663500E+05, 0.23602700E+05, 0.76156600E+04, 0.19438300E+05, -.42710400E+04, -.15093800E+05, 0.20821500E+04, 0.21904800E+05, 0.31038700E+05, -.17487800E+05, 0.58885500E+03, 0.58930400E+05, 0.87424900E+04, -.27172000E+04, -.44954800E+04, 0.64390900E+04, -.15701700E+04, 0.50411700E+04, -.20423900E+04, 0.87126300E+04, 0.11234700E+05, -.64018600E+04, -.19749200E+05, -.56135200E+04, -.20728900E+04, 0.21579500E+05, -.10660200E+05, -.15600700E+04, -.40064200E+04, 0.17499200E+05, 0.87583300E+04, 0.26212000E+04, -.14076700E+04, 0.34817800E+05, -.13105500E+04, -.50886000E+04, 0.83482600E+03, 0.14139900E+04, 0.42039800E+04, 0.56170100E+02, 0.25853800E+04, 0.41944500E+04, 0.62020800E+04, -.26970600E+04, 0.13690400E+05, -.31017600E+04, 0.90575800E+03, 0.24454400E+04, -.89884500E+03, 0.11229800E+04, -.27399100E+04, 0.24746800E+04, 0.10690300E+04, 0.55262000E+05, -.21069900E+05, -.83014300E+05, -.27629300E+05, -.48132200E+04, -.43784100E+04, -.34270400E+04, 0.15002900E+05, -.10204300E+05, -.61274200E+04, -.16526600E+05, 0.19500700E+04, -.24182100E+03, 0.65967000E+04, -.96855600E+03, 0.23006000E+04, 0.52270000E+04, -.21969000E+04, 0.31934700E+03, -.19628900E+04, 0.47398300E+04, 0.30163600E+04, 0.36815100E+05, -.13500700E+05, -.82815800E+05, -.18402700E+05, 0.15256700E+04, 0.10134500E+05, -.87254800E+04, 0.85572200E+04, -.76468400E+04, 0.81206400E+04, -.50952000E+04, 0.35948600E+05, -.26522200E+05, 0.34243900E+04, -.17962900E+05, -.77242000E+04, 0.99555400E+04, -.51175800E+04, 0.74649300E+04, -.51194300E+04, 0.84583600E+04, 0.75513300E+04, 0.17254700E+05, -.82901900E+04, 0.24934000E+05, -.86273600E+04, -.44711300E+04, 0.82390200E+02, -.83067000E+03, 0.47063700E+04, -.52346300E+04, 0.13926100E+04, -.36463400E+04, -.89444900E+04, 0.43573500E+04, 0.11864200E+05, 0.44721700E+04, -.72282400E+03, 0.68685100E+03, 0.10757200E+04, -.73195400E+03, 0.35277200E+04, 0.78032200E+03, 0.47894000E+04, 0.19853000E+05, -.50052900E+04, -.27280400E+05, -.99262100E+04, 0.19358800E+03, -.91612100E+04, -.69605100E+03, -.19870300E+03, -.57913000E+04, -.92210000E+04, -.20444700E+05, -.51656900E+05, 0.19976800E+05, 0.86512400E+05, 0.25822900E+05, 0.44807100E+04, 0.21181800E+04, 0.30771600E+04, -.14431800E+05, 0.84545300E+04, 0.45903900E+04, 0.13240300E+05, 0.17147900E+05, 0.17629200E+05, -.68075800E+05, -.85657500E+04, -.50048200E+03, -.14464500E+05, 0.18756000E+04, 0.46909900E+04, 0.84247000E+04, -.17252200E+05, -.24971000E+05, 0.10706500E+04, -.60312500E+03, -.75315100E+03, -.90626400E+03, -.32534200E+04, -.34355800E+04, 0.16040500E+05, -.13165100E+05, 0.28175500E+04, -.18444400E+04, 0.12303300E+03, 0.18797600E+04, 0.64986300E+04, -.20304300E+03, -.58433400E+04, -.23390400E+04, 0.91067300E+03, -.50371600E+04, -.51202900E+03, -.41410400E+04, -.62112600E+04, 0.31561000E+04, 0.30286200E+04, -.20231100E+03, -.21943800E+04, -.54681600E+03 },
        { -.65523700E+01, -.13136000E+01, -.48674700E+01, -.43337500E+01, 0.25809900E+01, 0.18936900E+01, 0.27954800E+00, 0.97780500E+01, -.68978900E+00, 0.93142400E+00, 0.21517800E+01, 0.63656600E+00, 0.15903400E+01, -.15923100E+01, 0.26749900E+00, -.32217600E+01, -.39961800E+01, -.27254300E+01, -.13746800E+01, 0.29967300E+00, 0.38583500E+01, 0.12782600E+01, -.48325200E+00, 0.32258800E+01, 0.13219600E+01, 0.18777800E+00, 0.12590900E+01, 0.32035100E+00, -.50853800E+01, 0.44025000E-01, 0.15613500E+01, 0.13427700E+01, -.15510500E+01, 0.58153600E+01, -.60158400E-01, -.12103600E+06, 0.14900700E+01, -.94500200E+04, 0.23600200E+05, -.17101700E+05, -.17991300E+05, -.37493400E+04, 0.26555800E+05, 0.14108800E+05, -.36215100E+05, 0.18142700E+05, -.61182100E+05, 0.18107300E+05, -.47575300E+04, -.16270200E+05, 0.19124100E+05, 0.11812400E+05, 0.29470400E+05, -.15232300E+05, 0.28796100E+04, -.91610900E+05, 0.46208500E+05, 0.14876200E+06, 0.45803900E+05, 0.12182200E+05, -.36150700E+05, 0.40533600E+05, 0.18620700E+05, 0.33155900E+05, -.39666900E+05, -.17241100E+05, -.18468000E+06, 0.91862100E+05, 0.12562800E+05, 0.92340500E+05, 0.12614000E+05, 0.29069400E+04, 0.27044400E+05, -.26088900E+05, 0.75251300E+05, -.14639200E+04, 0.63949500E+05, 0.64371700E+05, -.32551600E+05, -.11369100E+06, -.32183200E+05, -.83650400E+04, 0.35570600E+05, -.32871500E+05, -.25864100E+05, -.12746000E+05, 0.34925000E+05, -.35830200E+04, -.39886300E+05, 0.20070000E+05, 0.25885700E+05, 0.19941700E+05, -.91426700E+04, -.17513300E+05, 0.17095000E+05, 0.11029700E+05, 0.24789600E+05, -.15872500E+05, 0.18961200E+05, -.10504000E+05, 0.56726600E+04, 0.41079300E+05, 0.52515400E+04, 0.95770700E+04, 0.62993000E+04, -.19824300E+04, -.61412800E+04, -.18413400E+05, 0.10258400E+05, -.17821000E+04, -.31913400E+05, 0.15875400E+05, 0.75715400E+05, 0.15953300E+05, 0.86338900E+04, -.11117700E+05, 0.15133000E+05, 0.16607900E+05, 0.38474200E+04, -.13875200E+05, 0.10127100E+05, 0.24138000E+05, -.12372000E+05, -.13388200E+06, -.12068700E+05, -.26468000E+04, 0.32426600E+05, -.21159900E+05, -.11741000E+05, 0.11403700E+05, 0.32957400E+05, 0.67913900E+04, 0.17672000E+04, -.37870000E+03, -.94627200E+05, -.88283700E+03, -.10340400E+05, 0.50280500E+04, -.65871100E+04, -.89170300E+02, 0.43081100E+03, 0.67759200E+04, 0.20849000E+04, 0.24709800E+06, -.12286000E+06, 0.11067700E+05, -.12355100E+06, -.12553700E+05, 0.10717500E+05, -.49247900E+05, 0.15704100E+05, -.11647000E+06, 0.20602400E+05, -.77892800E+05, -.16247300E+06, 0.80815000E+05, -.16574800E+05, 0.81236400E+05, 0.31528300E+05, 0.54450400E+05, -.11713800E+05, -.44089400E+05, 0.46348100E+05, 0.45964000E+05, 0.93946200E+05, -.12316900E+05, 0.58609800E+04, -.18352700E+05, 0.61588100E+04, 0.11701400E+04, 0.97697400E+03, -.11951500E+04, 0.12911800E+04, 0.27560900E+04, 0.71003700E+03, 0.94081100E+04, 0.21831600E+05, -.10798400E+05, 0.65239500E+05, -.10919600E+05, -.41033400E+03, -.12668100E+05, 0.74896700E+04, 0.20640300E+05, -.23430400E+05, -.15190900E+05, -.96367800E+04, -.14399700E+05, 0.71265800E+04, -.59371200E+04, 0.71990000E+04, 0.32619800E+04, 0.29143600E+04, -.16340500E+04, -.62044400E+03, 0.33434100E+03, 0.23996800E+04, 0.10669700E+05, 0.67975600E+04, -.34931200E+04, 0.13175700E+06, -.34010500E+04, 0.12955300E+05, 0.18281800E+05, -.18916500E+05, -.19922200E+05, -.32119200E+05, 0.15015700E+05, 0.13536300E+05, 0.47147500E+05, -.23524900E+05, -.11390000E+05, -.23580900E+05, 0.42466800E+04, 0.17326300E+05, -.16156200E+05, 0.76669900E+04, -.35472700E+05, 0.16353800E+05, 0.34706400E+04, -.13680000E+06, 0.67970200E+05, -.14298800E+05, 0.68400100E+05, 0.22561200E+05, 0.39277500E+05, -.40657100E+04, -.34477200E+05, 0.42070200E+05, 0.32348200E+05, 0.73623700E+05, -.54672100E+05, 0.27346800E+05, 0.13117500E+04, 0.27336100E+05, 0.11405600E+05, 0.12526600E+05, 0.32013700E+04, -.10015600E+05, 0.15305700E+05, 0.11524000E+05, 0.21871300E+05, -.47955100E+05, 0.24412400E+05, 0.25664000E+05, 0.23977400E+05, -.57877200E+04, -.19073600E+05, 0.17885800E+05, 0.84710500E+04, 0.68930700E+04, -.14902300E+05, 0.38319300E+04, -.68813200E+05, 0.34362500E+05, -.95182500E+05, 0.34410000E+05, 0.59708900E+04, 0.12342800E+05, 0.22452100E+04, -.25025700E+05, 0.45616200E+05, 0.13448200E+05, 0.27107700E+05, -.13156300E+06, 0.66693300E+05, 0.14531600E+06, 0.65775600E+05, 0.16883200E+05, -.67005500E+05, 0.55792400E+05, 0.36175400E+05, 0.34915100E+05, -.68266000E+05, 0.74365300E+04, -.10046200E+05, -.63170900E+04, -.11808500E+05, -.11988200E+05, -.54168500E+04, 0.13808300E+05, 0.82923900E+04, 0.53765800E+04, 0.30315600E+04, -.57376200E+04, -.10952200E+05, -.39743700E+04, 0.13472500E+05, 0.14888900E+05, 0.38691200E+04, -.30847000E+04, 0.11333000E+05, 0.28345900E+05, -.11434700E+05, 0.15676200E+05, 0.76419200E+04, -.49679400E+04, 0.34790000E+05, 0.47074000E+04, 0.17820900E+05, -.25430700E+04 },
        { -.70714000E+01, -.92463700E+00, 0.11561900E+01, 0.24018200E+00, 0.40448100E+01, 0.22642200E+01, 0.28738600E+00, 0.11921100E+02, -.10245400E+01, 0.19711100E+01, 0.22361900E+01, 0.61862000E+00, 0.13994800E+01, -.33606000E+00, 0.14682600E+01, -.31403900E+02, -.11616000E+01, -.53460300E+01, -.28679000E+01, 0.10882200E+01, 0.41341200E+01, 0.10484500E+01, 0.40427600E+00, 0.19434200E+01, 0.56741700E+00, -.86756300E+00, 0.76518600E-01, -.38517400E+00, -.40323700E+01, -.80305800E+00, 0.28819700E+00, 0.18929500E+01, -.13261900E+01, 0.15418100E+01, -.22224300E-01, 0.28163400E+00, -.27411700E+02, 0.46393000E+04, -.44443500E+04, 0.21331500E+04, 0.45948300E+04, -.99937800E+03, -.72300200E+04, 0.40391400E+04, 0.35852700E+05, -.17672400E+05, -.17562400E+05, -.17945200E+05, -.59771200E+03, 0.57585300E+04, -.10890000E+05, -.18749200E+04, -.15492800E+05, 0.41334000E+04, -.87237100E+04, 0.55570200E+05, -.27345300E+05, -.31576100E+05, -.27780200E+05, -.66465700E+04, 0.22417500E+05, -.22195100E+05, -.79116400E+04, -.22228600E+05, 0.21023100E+05, -.17507400E+05, 0.58433700E+05, -.28925600E+05, -.23460700E+05, -.29216600E+05, -.44638500E+04, 0.66577100E+03, -.13414000E+05, -.10389600E+04, -.26267700E+05, -.92081100E+02, -.21988900E+05, 0.58906600E+04, -.30314700E+04, -.19695100E+04, -.29527600E+04, 0.15667100E+04, -.14890500E+05, 0.32284300E+04, 0.49233200E+04, -.31650400E+04, -.15178000E+05, 0.26004600E+04, 0.22922900E+03, -.62993100E+02, 0.28534300E+04, -.10877000E+03, 0.24749400E+03, 0.53588300E+04, -.11725400E+04, -.14628400E+04, -.14426900E+04, 0.61670900E+04, -.27250000E+04, -.72983200E+04, 0.37770700E+04, -.33737800E+04, 0.36474600E+04, -.20751600E+04, 0.55759200E+03, 0.20576900E+04, -.57921700E+03, 0.46346500E+04, -.68234200E+02, 0.43113200E+04, -.63885900E+04, 0.30557200E+04, 0.10060100E+05, 0.32045300E+04, 0.39682900E+03, 0.38891400E+04, -.11962000E+04, -.59409800E+04, 0.12813800E+03, 0.63919300E+04, -.55817700E+04, 0.77019400E+04, -.40975800E+04, 0.21376100E+04, -.38154700E+04, -.26508700E+04, -.20056800E+05, 0.81632300E+04, 0.97652700E+04, 0.89873900E+03, -.20462500E+05, 0.45680400E+04, 0.73749300E+04, -.32950900E+04, -.43836500E+04, -.36995600E+04, 0.47859700E+04, 0.28579000E+04, -.23247700E+04, 0.14991200E+04, -.54614300E+04, 0.62643000E+02, -.41241200E+01, -.89864200E+05, 0.44444300E+05, 0.35912300E+05, 0.44942300E+05, 0.73811600E+04, -.58387200E+04, 0.25368000E+05, 0.72906500E+04, 0.44013900E+05, -.35865700E+04, 0.32946400E+05, 0.35707000E+05, -.17893800E+05, -.41842400E+04, -.17851500E+05, -.34426800E+04, -.15193200E+05, 0.67684800E+04, 0.16159300E+05, -.61741800E+04, -.10982800E+05, -.21391000E+05, -.19996100E+04, 0.88553000E+03, -.48615700E+03, 0.99053100E+03, 0.45083800E+03, 0.28774600E+03, -.31295200E+03, -.19881200E+04, -.14631300E+04, 0.40881200E+03, 0.32631000E+03, -.37780000E+05, 0.18858800E+05, 0.12315100E+05, 0.18898600E+05, 0.41302000E+04, 0.67616800E+04, 0.21066300E+03, -.14382900E+05, 0.96705300E+04, 0.90421600E+04, 0.10447700E+05, -.19815600E+04, 0.95194300E+03, -.18377100E+03, 0.10161000E+04, -.21588700E+03, -.20600800E+03, -.49403200E+02, -.18421900E+04, -.67057600E+03, 0.26193300E+03, 0.11170200E+03, -.47290700E+05, 0.23286300E+05, 0.20054900E+05, 0.23702100E+05, -.24790000E+04, -.83558100E+04, 0.13640700E+05, -.93122900E+03, 0.21188400E+05, -.44779100E+04, 0.91280400E+04, -.60487800E+05, 0.29841600E+05, 0.36499200E+05, 0.30265000E+05, 0.73290300E+04, -.37901500E+04, 0.14714600E+05, -.17419900E+04, 0.21632300E+05, -.12925000E+04, 0.12971200E+05, 0.25837500E+05, -.13001400E+05, -.12429400E+04, -.12916700E+05, -.21046500E+04, -.10788000E+05, 0.43487700E+04, 0.11344000E+05, -.54357100E+04, -.73031600E+04, -.14341500E+05, 0.12384300E+05, -.61857800E+04, -.64393600E+04, -.61925100E+04, -.15989600E+04, -.28305900E+04, -.41711100E+03, 0.31438100E+04, -.20459200E+04, -.23335700E+04, -.47086800E+04, 0.62984500E+03, -.79843300E+01, -.74329700E+04, -.31497500E+03, -.73930600E+03, 0.87966700E+04, -.55393500E+04, -.61002500E+04, -.31508700E+04, 0.66655000E+04, 0.37602200E+04, 0.56100700E+05, -.27831900E+05, -.25435100E+05, -.28064800E+05, -.62800900E+04, -.70259100E+04, -.58652800E+04, 0.11729700E+05, -.17757200E+05, -.96540000E+04, -.13533700E+05, 0.10553400E+05, -.46748700E+04, -.20709100E+05, -.53018200E+04, -.28026400E+04, 0.28116600E+05, -.16333300E+05, -.18905500E+05, -.10464900E+05, 0.28292900E+05, -.69836000E+04, -.65424100E+03, 0.10208900E+04, 0.44517300E+04, 0.44569000E+04, 0.41839200E+04, -.18353600E+04, -.86214200E+04, -.34895600E+03, -.24854500E+04, 0.11858600E+04, 0.18744300E+04, -.28566600E+03, -.62863100E+04, -.48517900E+04, -.31346700E+02, 0.28319200E+04, -.44662400E+04, -.70560700E+04, 0.44121900E+04, -.20418200E+04, -.16495100E+04, 0.53690700E+02, -.12642600E+05, 0.27216000E+03, -.45632100E+04, 0.33650100E+04 },
        { -.10266300E+01, -.36169800E+00, 0.37632000E+00, 0.48762300E+00, 0.72011000E-01, 0.49177100E+00, 0.12065200E+01, -.15747200E+01, -.10508300E+00, -.11333700E+01, 0.65154900E-01, 0.30530500E+00, 0.36365000E+00, 0.17461700E-01, -.14905700E+00, -.30769300E+01, 0.21791800E+01, 0.98906600E+00, -.25890000E+00, -.25060000E+00, 0.74772600E-01, 0.12363700E+00, -.57209600E-02, -.80411300E-01, 0.14578200E+00, -.29384400E-01, -.21036800E-01, -.72966200E+00, 0.11847700E+01, 0.10608200E-01, -.93863900E-02, -.63456300E+00, 0.20098800E+00, -.24420600E+01, -.19549200E-01, -.17156700E+00, 0.28422600E-01, 0.59466100E+04, 0.22184300E+04, 0.28296600E+04, 0.51265500E+04, 0.14305600E+04, 0.19787900E+04, -.11390300E+05, -.24862500E+04, 0.12179400E+04, -.91753200E+03, 0.12436100E+04, 0.31924000E+04, 0.76219500E+03, 0.21717600E+04, 0.55216000E+04, 0.79195300E+03, 0.10052000E+04, 0.17653200E+03, -.11574700E+04, 0.47094300E+03, -.10730300E+05, 0.57921300E+03, -.60481900E+04, -.59520500E+04, -.73559000E+03, -.23434500E+04, 0.17503900E+04, -.41730700E+04, 0.21034900E+05, -.18051100E+05, 0.90970700E+04, 0.62891000E+04, 0.90254300E+04, 0.45032500E+04, 0.90957600E+03, 0.58190500E+04, 0.27296800E+04, 0.41902600E+04, 0.30210100E+04, 0.18420600E+04, -.85507900E+04, 0.43974800E+04, 0.93274400E+04, 0.42745600E+04, 0.67903900E+04, 0.65396200E+04, 0.45228000E+04, 0.61676200E+04, 0.21100200E+03, 0.57689400E+04, -.11945100E+05, -.36708200E+04, 0.17748200E+04, 0.31160100E+03, 0.18358200E+04, -.10242000E+04, 0.90553500E+01, -.17549800E+04, -.53585600E+04, -.13602000E+04, -.52460500E+03, 0.46804200E+04, 0.57356200E+04, -.28519200E+04, -.44214800E+04, -.28676200E+04, -.44266200E+04, -.46467400E+04, 0.11455600E+04, 0.21698600E+04, 0.22433100E+04, -.52749300E+04, 0.48894700E+04, 0.56727200E+04, -.28592800E+04, -.10682400E+04, -.28352800E+04, -.19599900E+04, 0.58429000E+03, -.49957600E+04, -.71835200E+04, -.22044600E+04, 0.86452400E+03, -.11991700E+04, -.11396400E+04, 0.68635700E+03, 0.11105400E+05, 0.56909500E+03, 0.63279500E+04, 0.52843100E+04, 0.41570300E+04, 0.64532200E+04, -.17680200E+04, 0.48206000E+04, -.13570400E+05, 0.24574400E+04, -.11247000E+04, -.25701700E+04, -.12287500E+04, 0.55316000E+04, 0.23229100E+04, 0.18552800E+04, 0.36486900E+04, -.63913700E+02, 0.22575500E+04, -.88077000E+04, 0.44644000E+05, -.22419600E+05, -.14928100E+05, -.22321300E+05, -.10222300E+05, -.23359400E+04, -.11219000E+05, -.25392300E+04, -.10732100E+05, -.62737800E+04, -.80544700E+04, 0.47870800E+05, -.23914800E+05, -.14729200E+05, -.23935500E+05, -.71014900E+04, -.37682600E+04, -.61053900E+04, 0.52448800E+04, -.14215900E+05, -.45993800E+04, -.16179800E+05, -.69509200E+04, 0.33819400E+04, 0.54899400E+04, 0.34755500E+04, 0.29926800E+03, -.34279500E+03, 0.20586900E+04, -.22740900E+04, 0.11426600E+04, -.66042600E+02, -.10952000E+04, -.57330700E+04, 0.28112900E+04, -.61089300E+04, 0.28675500E+04, -.34210700E+04, -.27684000E+04, -.74612600E+03, -.53312000E+04, 0.54429100E+04, -.26520200E+04, 0.39374500E+04, -.46287700E+04, 0.22471300E+04, 0.41847800E+04, 0.23129200E+04, -.70359100E+03, -.20955100E+04, 0.24612600E+04, -.12165000E+04, 0.19243800E+04, -.15851900E+04, -.24835800E+04, -.42759000E+03, 0.21479500E+03, 0.20488600E+03, 0.21356200E+03, -.85435000E+04, -.84111200E+04, 0.71501800E+02, -.78473300E+04, 0.43100400E+04, -.71431300E+04, 0.20521700E+04, 0.22540300E+05, -.11297500E+05, -.30594200E+04, -.11267900E+05, -.25783900E+04, 0.24781800E+04, -.75031000E+04, -.74443800E+04, -.90673100E+04, 0.16273900E+04, -.14306600E+05, 0.37846500E+05, -.18950000E+05, -.12410600E+05, -.18923300E+05, -.49221400E+04, -.21942500E+04, -.51581200E+04, 0.54653500E+04, -.10526300E+05, -.32027800E+04, -.13264700E+05, 0.93818500E+04, -.46813300E+04, -.31415700E+04, -.46909400E+04, -.15601600E+04, -.13028700E+04, -.58968000E+03, 0.18987700E+04, -.23186800E+04, -.12444400E+04, -.38946600E+04, -.17164800E+05, 0.86034500E+04, -.15473100E+04, 0.85824500E+04, 0.73765900E+03, -.33165400E+04, 0.47603400E+04, -.56921500E+03, 0.94316800E+04, -.34189900E+04, 0.10981400E+05, 0.30373500E+04, -.14289700E+04, 0.58335000E+04, -.15196600E+04, 0.38853000E+04, 0.67532300E+03, 0.49126700E+04, 0.12305000E+05, -.22507800E+04, 0.86949700E+03, -.58461300E+04, -.59076800E+04, 0.28895900E+04, -.14349800E+05, 0.29563800E+04, -.80666300E+04, -.13467000E+05, 0.45467400E+04, -.14672400E+04, 0.66685200E+04, -.11476100E+05, 0.18946200E+05, -.11604700E+03, -.14692600E+03, 0.20787500E+04, 0.21342400E+04, -.75731900E+03, 0.96328900E+02, 0.43995600E+04, 0.31632300E+04, 0.15430400E+04, -.67761600E+02, 0.11408600E+04, -.24191300E+04, 0.56029600E+03, 0.94274500E+03, 0.15779400E+04, -.13381100E+04, -.19990300E+04, 0.15795600E+04, 0.18497500E+04, 0.46008400E+03, 0.21140900E+03, 0.15715300E+04, 0.14788200E+04, -.60485800E+03, 0.14596400E+04, -.68516000E+03 },
        { -.56974100E+01, 0.27444400E+01, 0.12301300E+01, -.15014500E+01, 0.15058000E+01, -.11392300E+01, -.12614900E+01, 0.40436600E+01, -.12519800E+01, 0.27510100E+01, 0.38694600E+00, -.21397000E+00, 0.16058400E+01, -.40870100E+00, 0.27644200E+00, -.87300700E+01, 0.27937800E+01, -.17889000E+01, 0.31766900E+01, 0.21105400E+01, -.12062000E+01, -.15564100E+01, -.41696800E+00, -.11582600E+01, -.91823100E+00, 0.13846300E+00, 0.16627500E+01, -.14256700E+00, -.50308700E+01, -.41396100E-01, 0.12873100E+01, 0.59054200E+00, -.12462700E+01, 0.51622200E+00, 0.14468000E+00, 0.32796500E+00, 0.79814200E-01, 0.15704500E+01, 0.21284100E+05, -.13362900E+05, -.10888600E+05, 0.17951100E+04, 0.16748100E+05, -.10275500E+04, -.45626600E+05, 0.22155300E+05, 0.40586700E+05, 0.22814100E+05, 0.20633400E+05, 0.37324500E+05, 0.62793200E+04, 0.11619400E+05, 0.24659700E+05, 0.28770700E+05, 0.16871400E+05, 0.76525700E+03, -.22529700E+04, 0.71552400E+05, -.38182500E+03, 0.97278400E+04, 0.36863900E+05, 0.65289200E+04, 0.30981600E+05, -.13023300E+05, 0.29055100E+05, 0.85030000E+04, 0.78039000E+03, -.15230900E+04, 0.39190700E+04, -.39041000E+03, -.69787300E+04, 0.10408900E+05, 0.94031000E+04, 0.41291800E+05, 0.33721200E+05, -.18718700E+04, 0.28483200E+05, -.56525800E+05, 0.29044400E+05, -.13004600E+04, 0.28261500E+05, 0.25985600E+04, 0.32893200E+04, 0.17195800E+05, 0.82417000E+04, 0.52089000E+05, -.99142200E+03, 0.13786500E+05, -.92947700E+04, 0.40622100E+04, 0.30272400E+04, 0.46480700E+04, -.78190700E+04, -.21932900E+05, 0.76853200E+04, -.33775800E+04, 0.64431100E+04, -.15519800E+05, 0.50838400E+04, -.22396600E+05, 0.11799300E+05, 0.36697800E+05, 0.11198600E+05, 0.21364000E+05, 0.28175200E+05, -.55943600E+04, -.11714700E+05, -.20839900E+05, 0.33789200E+05, -.52143000E+04, 0.27307800E+05, -.13620800E+05, -.36359300E+05, -.13652100E+05, -.20183300E+05, -.46398900E+05, 0.98410400E+04, 0.14080200E+05, -.10063100E+05, -.42736700E+05, 0.31385600E+04, 0.37012300E+05, -.17046400E+05, -.85330900E+05, -.18507500E+05, 0.67966000E+04, -.63466100E+03, -.12552800E+05, -.44189600E+04, 0.15395900E+05, -.30269500E+04, -.21385400E+05, 0.10581500E+05, -.49422600E+04, 0.32181500E+04, -.52908000E+04, -.26169000E+04, 0.17360500E+05, -.13452000E+05, -.40700000E+04, 0.41503800E+04, 0.11640300E+05, 0.31826200E+04, -.66122500E+05, 0.34903000E+05, 0.15108700E+05, 0.33062400E+05, 0.20403000E+05, -.25396600E+05, -.21928500E+05, -.11410700E+06, -.54263700E+05, 0.24227500E+04, -.22596800E+05, -.20404600E+06, 0.10122000E+06, 0.27698600E+05, 0.10202300E+06, 0.34030600E+05, 0.23582400E+05, -.12237200E+05, -.94434800E+05, 0.32595100E+05, 0.24397600E+05, 0.68829200E+05, -.15048300E+05, 0.71543000E+04, -.17536400E+04, 0.75242200E+04, -.15235700E+03, -.12259200E+04, 0.33586600E+04, 0.46624100E+04, 0.11739600E+05, -.30170200E+04, 0.11689300E+05, -.77321100E+05, 0.38172000E+05, 0.98433700E+05, 0.38660800E+05, -.94913200E+02, -.18518000E+05, 0.32532800E+05, 0.10571900E+05, 0.11676300E+05, -.14653800E+05, 0.24115400E+05, -.11695300E+05, 0.55738300E+04, -.52887000E+03, 0.58452700E+04, 0.12978000E+04, -.29327200E+03, 0.24713700E+04, 0.28407700E+04, 0.63960100E+04, -.26098900E+04, 0.93679900E+04, 0.85771100E+05, -.42384900E+05, -.39627800E+05, -.42886000E+05, -.25574100E+05, -.44715100E+05, -.99823200E+04, -.52511000E+04, -.52782100E+05, -.37923100E+05, -.24813000E+05, 0.29415100E+05, -.13732300E+05, -.72844900E+05, -.14703900E+05, -.15076000E+05, -.53601200E+05, -.53221700E+04, -.11965800E+05, -.17022400E+05, -.45873700E+05, -.15646800E+05, -.19656500E+06, 0.97241700E+05, 0.38691400E+05, 0.98282400E+05, 0.26723900E+05, 0.17003100E+05, 0.29061600E+04, -.70709700E+05, 0.40128700E+05, 0.18041300E+05, 0.66031700E+05, -.39292400E+05, 0.19722300E+05, 0.14524200E+05, 0.19646200E+05, 0.88121200E+04, 0.62197200E+04, 0.58326400E+03, -.14706200E+05, 0.27480800E+04, 0.56847800E+04, 0.98716100E+04, 0.26142600E+05, -.12833500E+05, 0.50271000E+05, -.13071200E+05, -.18221100E+03, 0.28450300E+05, 0.98146000E+04, 0.37788400E+05, -.80697000E+04, 0.28571100E+05, -.82230400E+04, -.12664000E+04, 0.10291800E+04, -.39761000E+05, 0.63157200E+03, 0.19322700E+05, 0.46283500E+05, -.17804500E+05, -.96968700E+04, 0.12978700E+05, 0.38047200E+05, -.11427700E+04, 0.39759700E+05, -.20959000E+05, 0.96515600E+05, -.19875500E+05, 0.62083600E+04, 0.21558400E+05, 0.13099700E+04, 0.38580100E+05, -.35242200E+05, 0.15270300E+05, -.68954200E+04, 0.11959800E+05, 0.35840200E+04, -.30258400E+04, -.29307700E+04, -.25901600E+04, 0.74948100E+04, -.10409400E+05, 0.24674300E+05, 0.14638800E+04, 0.32471500E+04, -.52187000E+04, 0.15550300E+04, 0.92692900E+04, 0.34066000E+04, 0.94228700E+04, 0.69809200E+04, 0.24977000E+04, 0.18168400E+05, -.26168700E+04, 0.25829800E+04, 0.30441500E+05, -.88390300E+04, 0.54377000E+03, 0.30970200E+04, 0.14024800E+05, -.78514200E+04 },
        { -.19761200E+01, -.55762000E-02, 0.16201100E+01, 0.93215800E+00, 0.66783500E+00, 0.66829600E+00, 0.97599900E+00, -.34296100E+01, 0.74087900E-01, -.11545900E+01, -.21892600E+00, 0.68403800E+00, -.12251000E+00, -.63447600E-01, 0.42240300E+00, -.58088700E+01, -.29006000E+01, -.14232300E+01, 0.19559000E+00, 0.37751600E+00, 0.15669400E+00, 0.34041000E+00, 0.31179200E+00, 0.54477600E+00, 0.24380700E+00, -.12939400E+00, -.17439300E+00, -.73675000E+00, -.64265900E+00, -.24974700E+00, -.43053300E+00, 0.98097500E+00, -.30774200E+00, -.26499200E+01, 0.11521700E-01, -.80466400E-02, 0.66729600E-01, 0.11634500E+01, -.31997700E+00, -.36437800E+04, -.28975000E+04, -.14923600E+04, -.34766500E+04, 0.12790900E+05, 0.15809800E+05, -.79604500E+04, 0.26442600E+04, -.79038400E+04, 0.60936900E+04, 0.19188700E+05, -.10042600E+05, -.29019400E+04, -.81713200E+04, 0.14825800E+05, -.36494900E+04, 0.47301600E+05, -.23959000E+05, 0.51072100E+04, -.23649800E+05, 0.25161800E+04, 0.38315000E+05, -.17167400E+05, 0.37210700E+04, -.26213100E+05, 0.33425800E+05, -.31817100E+05, 0.57634100E+05, -.29049200E+05, -.16649500E+05, -.28817300E+05, -.70804300E+04, 0.65333100E+04, -.11537700E+05, 0.11758600E+05, -.13420900E+05, 0.72764600E+03, -.87871500E+04, -.12828900E+05, 0.65328900E+04, -.46748800E+04, 0.64126700E+04, -.37064000E+03, -.15471800E+05, 0.71487900E+04, 0.51838100E+04, 0.16519800E+05, -.16766500E+05, 0.18456500E+05, 0.31830800E+04, -.16822700E+04, -.85656400E+03, -.15906700E+04, -.22186500E+04, -.24504300E+04, 0.98004200E+03, 0.54573500E+03, 0.27574200E+04, 0.78317400E+03, -.47330100E+04, -.17115400E+05, 0.87563000E+04, 0.14789700E+05, 0.85581100E+04, 0.69629700E+04, 0.11504300E+05, 0.25250200E+03, -.64009800E+04, -.60804200E+04, 0.12892400E+05, -.42908800E+04, 0.65238200E+04, -.32909200E+04, -.98410700E+04, -.32596500E+04, -.80007700E+04, -.14433900E+05, 0.61324400E+04, 0.71092900E+04, -.58724900E+03, -.11067100E+05, -.17463600E+04, 0.94077800E+04, -.44292100E+04, -.27040300E+05, -.47056400E+04, -.11558000E+02, -.18503700E+05, -.10447200E+04, -.21836500E+04, 0.65436800E+04, -.19331000E+05, 0.10508600E+05, 0.93316400E+04, -.45458000E+04, -.18143100E+04, -.46659100E+04, -.86358400E+03, 0.51452000E+04, -.75276300E+04, -.30702200E+04, -.30190900E+04, 0.14031200E+04, 0.76347700E+04, -.11038100E+06, 0.55597100E+05, 0.30836800E+05, 0.55191900E+05, 0.14967400E+05, -.19518700E+05, 0.18572000E+05, -.32367100E+05, 0.22258000E+05, -.57547300E+04, 0.18529600E+05, -.48377200E+05, 0.24003000E+05, 0.76359800E+04, 0.24188500E+05, 0.11210600E+05, -.41932000E+04, 0.99108100E+03, -.20807800E+05, 0.96823400E+04, -.46633800E+03, 0.93449500E+04, 0.65440000E+03, -.34827400E+03, -.50717000E+04, -.32710300E+03, -.42420300E+03, 0.32148400E+02, -.21849200E+03, 0.21431300E+04, 0.27485400E+04, -.73799300E+03, 0.50829000E+04, -.41326700E+05, 0.20509200E+05, 0.42862000E+05, 0.20663200E+05, 0.15882200E+04, -.27443800E+03, 0.12405800E+05, -.82695700E+02, 0.92144600E+04, 0.22191100E+04, 0.11396400E+05, 0.14693500E+04, -.74980800E+03, -.37477500E+04, -.73328400E+03, 0.50616500E+03, 0.17244700E+04, -.12005700E+04, 0.80288500E+03, 0.15570000E+03, 0.85936900E+03, 0.51947500E+04, -.58028000E+04, 0.28850100E+04, -.74686500E+03, 0.29007500E+04, -.60771100E+04, -.15969600E+05, 0.79568100E+04, 0.39797700E+04, -.19683700E+04, -.11873500E+05, 0.67204100E+03, -.41788600E+05, 0.21015700E+05, -.30610400E+04, 0.20899000E+05, -.31470100E+04, -.30173300E+05, 0.18554400E+05, 0.62888800E+04, 0.20721300E+05, -.24729700E+05, 0.15762500E+05, -.55924600E+05, 0.27702800E+05, 0.14223500E+05, 0.27962200E+05, 0.92595500E+04, -.29161000E+04, 0.51632900E+04, -.16604700E+05, 0.13245700E+05, 0.45582000E+03, 0.15213000E+05, 0.10340600E+04, -.47482600E+03, -.10934000E+04, -.51705200E+03, 0.18025200E+04, -.62459800E+03, -.92167200E+03, -.20046500E+04, -.22535900E+04, -.41969500E+03, -.17127400E+04, 0.14523000E+05, -.71390200E+04, 0.16006100E+05, -.72613700E+04, -.34204000E+03, 0.20371000E+05, -.26407600E+04, 0.73351100E+04, -.10029400E+05, 0.18282900E+05, -.74214700E+04, 0.37898000E+05, -.18772200E+05, -.30417200E+05, -.18951100E+05, 0.30702500E+04, 0.11996200E+05, -.15935500E+05, -.54125700E+04, -.12841200E+05, 0.73737700E+04, -.83187300E+04, 0.39668600E+05, -.19908100E+05, 0.18739900E+05, -.19828600E+05, 0.14221300E+04, 0.41008300E+05, -.16962700E+05, 0.22503200E+03, -.25784500E+05, 0.37547700E+05, -.28844600E+05, 0.48713800E+04, 0.21624600E+04, 0.23084800E+04, 0.23039200E+04, 0.41763700E+04, 0.11945600E+03, -.14007500E+05, 0.11364400E+05, -.23572700E+04, 0.16860500E+04, -.14931700E+04, 0.24863800E+04, -.23644800E+04, -.46859300E+04, 0.45826400E+04, 0.64775400E+04, -.25097100E+04, -.18965100E+04, 0.26326900E+04, -.23337000E+04, 0.95530200E+04, -.45272700E+04, -.11601400E+05, 0.19330000E+04, -.75462600E+03, 0.56907500E+03 },
        { 0.68592500E+00, -.28304200E-01, -.13409200E+00, 0.24207200E-01, -.21775300E+00, -.14848700E+00, -.82460700E+00, -.25604200E+00, 0.63563900E-01, 0.70888600E+00, -.19628000E+00, -.12015300E+00, -.18324200E+00, 0.12246200E-01, -.87091200E-01, 0.40230000E+01, -.47556800E+00, 0.30644700E-01, -.15493600E+00, -.82990400E-01, 0.12880400E+00, -.24844400E-01, -.69096100E-02, 0.22321200E+00, -.67414600E-01, 0.14697100E-01, 0.48412300E-01, 0.60518700E+00, -.60000400E+00, 0.17840100E-01, -.12356700E+00, -.15295000E+00, 0.34728500E-01, 0.57982200E-01, 0.10158200E-01, -.44937300E-02, 0.12568800E-01, 0.15755600E-01, 0.83102300E-03, -.84077200E-01, 0.98217100E+03, 0.32598300E+03, -.45613100E+03, 0.14384600E+04, 0.12880600E+03, -.93695700E+02, 0.11537700E+04, -.64121400E+02, 0.48529700E+03, 0.10012000E+04, -.47740000E+03, -.25585500E+03, 0.61680900E+03, 0.61391500E+03, -.67671200E+03, -.40071900E+04, 0.19437300E+04, 0.77748700E+04, 0.20038700E+04, 0.17302300E+03, 0.10409000E+04, 0.88657500E+03, -.10536600E+04, 0.23113200E+03, 0.13232100E+04, -.42814700E+04, -.39140700E+04, 0.18856000E+04, 0.13508100E+04, 0.19569600E+04, 0.37452200E+03, 0.14188700E+04, -.96542300E+02, -.57064400E+03, 0.23902500E+04, 0.63632400E+03, 0.18317200E+04, 0.11359100E+03, -.45834200E+02, -.25849900E+04, -.57277800E+02, 0.16291200E+03, -.14133100E+04, 0.19861600E+03, 0.16127000E+04, 0.23258300E+04, -.19987400E+04, 0.28658300E+04, -.15668100E+04, 0.76945800E+03, 0.18254300E+03, 0.78364400E+03, -.46324200E+03, -.51134300E+03, 0.51190300E+03, -.58537600E+02, 0.96216400E+03, 0.45613500E+02, 0.61056100E+03, -.21493400E+04, 0.11040900E+04, 0.39347300E+04, 0.10747800E+04, 0.70397600E+03, 0.48642400E+03, 0.25437200E+03, -.83980000E+03, -.16269600E+04, 0.97294000E+03, -.11512600E+04, -.66148700E+03, 0.33263600E+03, -.20336200E+04, 0.33136900E+03, -.20005600E+03, 0.37111200E+03, 0.21102600E+03, -.10469400E+02, -.51054000E+03, 0.41721500E+03, 0.12593600E+04, 0.24329100E+04, -.11738700E+04, -.65794600E+04, -.12168800E+04, 0.77715000E+03, -.11596000E+03, -.12591400E+04, 0.78299200E+03, 0.89680300E+03, -.86006800E+03, 0.22497200E+04, -.58523000E+03, 0.30085700E+03, 0.10632200E+04, 0.29259900E+03, -.13805400E+03, 0.39561100E+02, -.15445300E+03, 0.47775500E+03, 0.41476200E+03, -.22230600E+03, 0.78401500E+03, 0.40445800E+04, -.19146800E+04, -.90393500E+03, -.20219000E+04, -.31969700E+02, -.31482700E+04, 0.42084000E+03, 0.39632800E+03, -.35117100E+04, -.14347000E+04, -.26318300E+04, -.84067200E+04, 0.41585800E+04, -.90030100E+03, 0.42033400E+04, 0.13871400E+04, 0.15890800E+04, -.14418800E+03, -.14072800E+04, 0.26364300E+04, 0.10207100E+04, 0.52165400E+04, -.73269300E+03, 0.35915900E+03, -.47470600E+03, 0.36639500E+03, 0.15127600E+03, 0.28434700E+03, 0.52755700E+02, 0.29088800E+03, 0.34309800E+03, 0.22356500E+03, 0.11139200E+04, 0.26023400E+04, -.13076300E+04, 0.35252700E+04, -.13007200E+04, -.59885000E+03, -.43979600E+02, 0.19573700E+03, 0.78958000E+03, -.20844000E+04, 0.27288800E+03, -.10480300E+04, -.33247400E+03, 0.16463500E+03, -.51182400E+03, 0.16560500E+03, 0.34415100E+03, 0.64780800E+03, -.18692300E+03, 0.18369500E+03, -.18612500E+02, 0.54187000E+03, 0.10712500E+04, 0.97517700E+03, -.45986200E+03, -.23299000E+03, -.48773000E+03, 0.10743300E+03, 0.91366100E+03, -.47750100E+03, -.24155700E+03, -.25167400E+04, 0.10873200E+04, 0.71652900E+03, 0.43196200E+04, -.21105100E+04, -.55098800E+04, -.21585300E+04, -.93408000E+03, -.18354100E+04, 0.61877100E+03, 0.23078500E+04, -.16999000E+04, -.16832600E+04, 0.11794600E+04, -.97702800E+04, 0.48380100E+04, 0.41828000E+01, 0.48851000E+04, 0.12154600E+04, 0.10447400E+04, 0.73599000E+03, -.15336100E+04, 0.32348000E+04, 0.79665000E+03, 0.50503000E+04, 0.93586700E+03, -.46982300E+03, 0.21414600E+02, -.46793900E+03, 0.21221300E+03, 0.17570200E+03, -.40314700E+03, 0.15554800E+03, -.40821700E+03, -.77852000E+01, -.63240600E+02, -.56424600E+04, 0.28348300E+04, 0.65074300E+04, 0.28212700E+04, 0.42155500E+03, 0.11513700E+04, 0.79820300E+03, -.10629100E+04, -.29594000E+03, 0.17376300E+04, -.23439600E+03, -.25047700E+04, 0.12490900E+04, -.19860600E+04, 0.12518100E+04, 0.10970300E+04, 0.10210200E+04, -.78030000E+03, -.15444600E+04, 0.23976100E+04, 0.45742600E+03, 0.93815700E+03, 0.18556400E+04, -.95061900E+03, 0.90297200E+04, -.92633500E+03, -.25073100E+02, 0.37291900E+04, -.18179000E+04, -.31785400E+04, -.36681700E+04, 0.43222700E+04, -.54820700E+04, 0.13625600E+03, 0.40437100E+03, 0.34747200E+03, 0.32475300E+03, 0.32761600E+03, -.27782900E+03, -.15464900E+04, 0.17109600E+04, -.40616300E+03, 0.32529100E+03, 0.74789800E+01, 0.55550600E+03, -.91383600E+02, -.37023700E+03, 0.50455800E+03, 0.17478600E+03, -.38275500E+03, 0.44449600E+03, 0.40142500E+03, -.53307800E+03, 0.38654200E+03, -.47425900E+03, 0.10519200E+04, -.29311400E+03, 0.28514500E+02, 0.16301400E+03 },
        { 0.26366700E+01, 0.12520100E+01, -.37983100E+00, -.11461900E+01, -.10223300E+01, -.90327800E+00, -.88144800E+00, -.14383800E+01, -.10842700E+00, 0.53458900E-01, -.33756900E+00, -.33286500E+00, 0.40215700E+00, 0.13195600E+00, -.79708700E-01, -.17656700E+01, 0.39352400E+01, 0.27492200E+01, -.17594500E+01, -.55422600E+00, -.37268100E+00, 0.95716200E-01, -.26732100E+00, -.19079700E+01, -.70393300E-01, -.51962200E-02, -.35016500E+00, -.21584500E+01, 0.33184900E+00, 0.25308500E-01, 0.42472600E+00, -.75554500E+00, -.63221700E-01, 0.33623800E+01, -.32097400E-02, 0.52361700E-01, 0.40472700E-01, 0.26976300E+00, 0.25931400E+00, -.50210000E+00, 0.13032100E+01, -.34916700E+04, -.10854500E+04, 0.10172000E+05, 0.23525400E+05, -.11468700E+05, -.14070900E+05, -.11762100E+05, -.47872300E+04, -.35591100E+04, -.66017100E+04, -.56801200E+04, -.12680400E+05, -.33569900E+04, -.65333900E+04, 0.28877000E+05, -.13758400E+05, -.24279400E+05, -.14437900E+05, -.45127600E+04, 0.10085900E+04, -.10227900E+05, -.69752300E+04, -.10141100E+05, 0.14480900E+03, -.22085900E+05, 0.41132000E+05, -.20278900E+05, -.17060700E+05, -.20566200E+05, -.55552300E+04, -.60298500E+04, -.11367400E+05, -.93079100E+04, -.20848600E+05, -.59465700E+04, -.16537700E+05, 0.12345800E+05, -.65118600E+04, -.54336400E+04, -.61738700E+04, -.36181800E+04, -.36545500E+04, -.75002000E+04, -.10656700E+05, -.11342300E+05, -.22740500E+04, 0.10518000E+05, 0.84234800E+04, -.40040800E+04, -.17320100E+03, -.42112500E+04, 0.25415800E+04, 0.50947600E+04, -.95883800E+03, 0.57601000E+04, 0.17060100E+03, 0.44775600E+04, -.81094300E+04, -.51487400E+04, 0.24478800E+04, -.82591400E+04, 0.25746000E+04, -.22911300E+04, -.88584300E+03, 0.87891800E+03, -.18362300E+03, 0.35984500E+04, -.20951700E+04, 0.17925000E+04, -.44576500E+03, 0.19159200E+03, 0.12566700E+05, 0.22413800E+03, 0.33487000E+04, 0.36447600E+04, 0.13749300E+04, 0.23752600E+04, 0.24589500E+04, 0.48648200E+04, -.83776900E+04, -.18096500E+05, 0.84982200E+04, 0.19697000E+05, 0.90472900E+04, -.91267700E+03, -.43323700E+04, 0.34707700E+04, -.15935200E+04, 0.27843100E+04, -.39734400E+04, 0.19389500E+05, -.21865600E+04, 0.10183800E+04, -.14709800E+03, 0.10932300E+04, 0.82561200E+03, 0.65272600E+03, 0.76646700E+03, 0.21182900E+04, -.21570400E+04, -.67307600E+03, 0.64389400E+04, -.65253900E+05, 0.32116000E+05, 0.30868800E+05, 0.32627700E+05, 0.11441900E+05, 0.14163800E+05, 0.20979800E+05, 0.23951800E+05, 0.38001600E+05, 0.12726500E+05, 0.25800900E+05, 0.45857300E+04, -.21678600E+04, 0.18786800E+05, -.22929100E+04, 0.13313900E+04, -.52680800E+04, 0.10419300E+05, 0.17387700E+05, 0.62490200E+04, -.18621600E+04, -.80558000E+04, 0.44632000E+04, -.20659200E+04, -.34825500E+04, -.22315500E+04, -.96143500E+02, 0.60478100E+03, -.21560600E+04, -.13703400E+03, -.22058000E+04, 0.58801500E+03, -.14184900E+03, 0.11327500E+05, -.55084400E+04, -.18952100E+05, -.56640200E+04, 0.13154200E+04, 0.49985600E+04, -.68594500E+04, -.45789500E+04, -.50823100E+04, 0.58868100E+04, -.60766800E+04, 0.36250900E+04, -.16836100E+04, -.28455000E+04, -.18106600E+04, -.50016200E+02, 0.11407000E+04, -.23888100E+04, -.42187000E+03, -.22320000E+04, 0.13074800E+04, 0.50357900E+03, -.34106900E+05, 0.16771100E+05, 0.12170100E+05, 0.17053100E+05, 0.46539900E+04, 0.35428900E+04, 0.75128300E+04, 0.32706900E+04, 0.17062400E+05, 0.44906600E+04, 0.63859800E+04, -.41481300E+05, 0.20408900E+05, 0.37982800E+05, 0.20743300E+05, 0.10153100E+05, 0.10463000E+05, 0.89050900E+04, 0.46196600E+04, 0.19189500E+05, 0.11271300E+05, 0.14659900E+05, 0.14513900E+05, -.70199500E+04, 0.10322700E+05, -.72570200E+04, 0.39333900E+03, -.39252300E+04, 0.48669000E+04, 0.12207900E+05, 0.70906200E+01, -.12052700E+04, -.88423200E+04, -.27810800E+04, 0.13556000E+04, 0.21737100E+04, 0.13905300E+04, -.94221300E+02, -.50547200E+03, 0.11226900E+04, 0.94686800E+03, 0.29034700E+04, 0.17650500E+02, 0.15715500E+04, 0.13532300E+05, -.67371300E+04, -.24012700E+05, -.67660900E+04, -.49092800E+04, -.25551100E+04, -.70008500E+04, -.64303700E+04, -.88895700E+04, -.43801100E+04, -.40342600E+04, 0.55742900E+04, -.28981200E+04, 0.18155300E+03, -.27883000E+04, -.64548700E+04, -.95052100E+04, 0.21149100E+03, -.25849200E+04, -.50279900E+04, -.97906500E+04, 0.52353700E+04, -.13083800E+05, 0.70253000E+04, -.23241700E+05, 0.65450600E+04, -.54694000E+03, -.14765700E+04, -.11472000E+04, -.34850700E+04, 0.88676500E+04, -.20892600E+04, -.80832200E+04, -.28668300E+04, -.17887200E+04, 0.17251800E+03, 0.12646300E+03, 0.15939300E+04, -.40759500E+03, 0.25848200E+04, -.11523100E+05, -.56600600E+03, -.20524100E+04, -.11263100E+04, -.83395400E+03, -.12414300E+04, -.12937400E+04, -.39133200E+04, 0.83956300E+03, -.19770000E+03, -.38907900E+04, 0.26231800E+03, 0.18216500E+03, -.60300500E+04, 0.88114700E+03, -.65794300E+04, 0.17281900E+04, -.31077100E+04, 0.21092100E+04 },
        { 0.10844100E+02, 0.39361900E+01, -.36894300E+01, -.87776800E+01, -.17928400E+01, -.32813100E+01, -.37534000E+01, 0.29036500E+02, 0.92506700E+00, 0.51393700E+01, 0.49004900E+01, 0.75597800E-01, 0.63770400E+00, 0.91260000E+00, -.30407300E+00, -.82399700E-01, 0.11816600E+02, 0.54684400E+01, -.17782400E+01, 0.96605700E-01, -.58925500E+01, 0.94447300E+00, 0.13565200E+00, 0.33025100E+01, 0.55777400E-01, 0.16828000E+00, 0.26198800E+01, 0.56281500E+01, -.33979700E+01, -.36520400E-02, 0.29641500E+01, 0.70350000E+01, -.16110900E+01, 0.49181100E+01, 0.22223500E+00, 0.10709200E+01, -.19898900E+00, -.57801100E+01, -.15803900E+00, -.36738200E+01, -.10596100E+02, 0.13814100E+00, -.13756500E+05, 0.46446300E+05, 0.25372200E+05, -.12799400E+05, 0.16515900E+05, -.12680300E+05, 0.25460300E+05, 0.57528300E+05, -.29225800E+05, -.19430900E+05, -.21647700E+05, 0.45787500E+05, -.10974200E+05, 0.16109100E+06, -.81568300E+05, 0.54497800E+05, -.80539900E+05, 0.81010600E+03, 0.11464000E+06, -.66712600E+05, -.50860800E+04, -.91754300E+05, 0.10518800E+06, -.14129400E+06, 0.11786400E+06, -.59585700E+05, -.13262700E+05, -.58933400E+05, -.10688000E+05, 0.33006200E+05, -.29861300E+05, 0.14491800E+05, -.34978100E+05, 0.20273800E+05, -.19026600E+05, -.28451900E+05, 0.14399600E+05, -.30130700E+05, 0.14216100E+05, 0.34513800E+04, -.42768900E+05, 0.20954800E+05, 0.16489100E+05, 0.46143900E+05, -.47863600E+05, 0.68513000E+05, 0.65676100E+04, -.32519700E+04, -.45835500E+04, -.32789300E+04, -.34685800E+04, -.60002200E+04, 0.19786900E+04, 0.47434100E+04, 0.12445900E+05, 0.52289200E+04, -.11922000E+05, -.40378700E+05, 0.20008600E+05, 0.46601100E+05, 0.20191700E+05, 0.10538000E+05, 0.18062700E+05, 0.59924100E+04, -.15746300E+05, -.21307400E+05, 0.21406600E+05, -.26233600E+05, 0.48319000E+05, -.24046600E+05, -.44692800E+05, -.24146700E+05, -.24782300E+05, -.28459900E+05, 0.50328600E+04, 0.20901900E+05, -.10135300E+05, -.18206900E+05, -.38116400E+04, -.83855200E+04, 0.49609400E+04, -.10019500E+06, 0.41836700E+04, 0.17527600E+05, -.42281500E+05, 0.44389400E+04, -.13029600E+05, 0.22235900E+05, -.48675900E+05, 0.57952000E+05, 0.10421500E+05, -.64875100E+04, 0.87994100E+04, -.52111400E+04, -.24942500E+04, 0.81039100E+04, -.66645700E+04, -.33790200E+04, 0.76776800E+03, -.29923700E+04, 0.28776400E+05, -.19755800E+06, 0.10009000E+06, 0.38005500E+05, 0.98787000E+05, 0.28388700E+05, -.89396900E+05, 0.50892100E+05, -.43059500E+05, 0.49745600E+05, -.52752700E+05, 0.14632900E+05, -.19912400E+05, 0.10321600E+05, -.16920400E+05, 0.99557300E+04, 0.16455100E+05, -.21902000E+05, -.31134500E+04, -.30484700E+05, -.19168200E+04, -.13453400E+05, -.35400800E+04, 0.12988000E+05, -.55377700E+04, -.28471900E+05, -.64931200E+04, -.45310900E+04, -.41000900E+04, 0.41629600E+04, 0.10896200E+05, 0.12374400E+05, -.52724500E+04, 0.12391200E+05, -.50004400E+05, 0.24655400E+05, 0.12124000E+06, 0.25007700E+05, -.64992700E+03, -.26141900E+04, 0.17531800E+05, 0.79671900E+04, 0.13859300E+05, 0.46237300E+04, 0.11390200E+05, 0.20081000E+05, -.95501800E+04, -.26163300E+05, -.10048500E+05, -.62230900E+03, 0.46244200E+04, -.26392400E+04, 0.53113500E+04, 0.90423900E+03, 0.32019000E+04, 0.13785600E+05, 0.29030900E+05, -.14360600E+05, -.14071600E+05, -.14518500E+05, -.29222900E+05, -.37665200E+05, 0.93278800E+04, 0.12913900E+05, -.23410300E+05, -.25507200E+05, -.15683200E+04, -.29772600E+05, 0.15533500E+05, -.42229700E+05, 0.14912500E+05, -.28086700E+05, -.93194200E+05, 0.49089800E+05, 0.44209600E+05, 0.37524400E+05, -.78016600E+05, 0.41269700E+05, -.97280200E+05, 0.49033500E+05, 0.94696300E+04, 0.48639400E+05, 0.19076500E+05, -.13476400E+05, 0.13332600E+05, -.28910300E+05, 0.24965500E+05, -.47928800E+04, 0.31637300E+05, 0.69351900E+05, -.34562500E+05, -.10687200E+05, -.34676100E+05, -.39579300E+04, -.94611800E+04, -.88691700E+04, 0.67873500E+04, -.25444500E+05, -.88888200E+04, -.27472100E+05, -.21029800E+05, 0.96705300E+04, 0.62054200E+05, 0.10515700E+05, -.13868700E+03, 0.52769300E+05, 0.20890200E+04, 0.24358700E+04, -.11462400E+05, 0.47149200E+05, -.11175000E+05, 0.50287400E+05, -.25155500E+05, -.91996100E+05, -.25155400E+05, 0.13932100E+05, 0.30384600E+05, -.29205100E+05, -.23257500E+05, -.23614400E+05, 0.16697100E+05, -.60544000E+04, 0.10268500E+06, -.52831100E+05, 0.10839300E+06, -.51311500E+05, -.17925700E+05, 0.86571000E+05, -.38230000E+05, -.21347600E+04, -.64669100E+05, 0.86385800E+05, -.10340700E+06, 0.13532900E+05, 0.51451700E+04, 0.11064600E+05, 0.10994300E+05, 0.13124300E+05, -.26359100E+04, -.35384600E+05, 0.53685500E+05, -.71678300E+04, 0.34027500E+04, -.49657300E+04, 0.71992900E+04, -.45399900E+04, -.12582600E+05, 0.22121300E+05, 0.16818700E+05, -.11238500E+05, 0.22473100E+04, 0.12077600E+05, -.10508500E+05, 0.24421600E+05, -.10805300E+05, -.27377500E+05, 0.49326700E+04, -.17685600E+04, 0.25420300E+03 },
        { 0.44637900E+01, 0.76266600E+00, -.22295900E+01, -.20757000E+01, -.20844200E+01, -.77436300E+00, -.17093900E+01, 0.44083300E+01, 0.14288300E+00, -.25756400E+00, 0.12123500E+01, 0.35521600E+00, 0.62153700E+00, 0.29503800E+00, -.46118000E+00, 0.47024000E+01, 0.15917300E+01, 0.37885100E+01, -.40310600E+00, -.16250400E+01, -.39359800E+01, 0.14667800E+01, -.34062700E+00, 0.13674100E+00, -.69667900E-01, 0.49059500E-01, -.48090200E+00, 0.57227100E+00, 0.36773500E+00, 0.19876300E+00, -.26880800E+00, -.30239000E+00, 0.11459900E+01, 0.35709400E+01, 0.61640800E-01, -.23253800E+00, -.15991000E+00, -.22383100E+01, -.28182900E+00, -.16123400E+01, -.13402200E+01, 0.17116900E+01, 0.16402100E+00, -.22104800E+05, -.32255900E+05, 0.15476600E+05, 0.17124200E+05, 0.16126400E+05, 0.37174000E+04, -.78314400E+03, 0.65814100E+04, 0.10644400E+04, 0.13823200E+05, -.47230700E+03, 0.14436800E+05, -.50696200E+05, 0.23524400E+05, 0.42273500E+05, 0.25346600E+05, 0.11923700E+04, -.12574000E+05, 0.16244000E+05, 0.36114700E+03, 0.13607600E+05, -.93589800E+04, 0.47872400E+05, -.47231300E+05, 0.23041900E+05, 0.15986800E+05, 0.23616000E+05, 0.73561800E+04, 0.58141800E+04, 0.77313500E+04, 0.58000600E+04, 0.28369100E+05, 0.28112900E+04, 0.12406400E+05, -.10866800E+05, 0.61273200E+04, 0.38902000E+04, 0.54360800E+04, 0.62576900E+04, 0.88685700E+04, 0.15229700E+04, 0.74669900E+04, 0.12987200E+05, 0.48841500E+04, -.21660800E+05, -.36550800E+05, 0.17876700E+05, 0.93478400E+04, 0.18274100E+05, 0.78121300E+03, -.19734800E+04, 0.36483300E+04, -.98497500E+04, 0.11563800E+05, -.42092200E+03, 0.24550700E+05, 0.21918400E+04, -.15270600E+04, 0.17336600E+05, -.10965500E+04, 0.21038300E+04, -.13564600E+04, 0.26916800E+04, -.20213200E+04, -.13211500E+05, 0.10738200E+04, 0.30200400E+04, 0.26816600E+03, 0.21174200E+03, -.17982800E+05, -.13753100E+03, -.50802200E+04, -.36463700E+04, 0.22479800E+04, 0.15241100E+04, -.11125500E+04, -.47940000E+04, 0.29505300E+04, 0.19547500E+05, -.86218400E+04, -.28481600E+05, -.97713100E+04, 0.55127100E+04, 0.15581200E+05, -.98881200E+04, 0.18635900E+04, 0.56443400E+04, 0.12830400E+05, -.23586600E+05, -.29298400E+04, 0.33939700E+03, 0.35443500E+04, 0.14650200E+04, -.11476800E+04, -.25271700E+04, -.47604500E+03, -.22299500E+04, 0.18349900E+04, -.17040700E+04, -.13560900E+05, 0.80081400E+05, -.39015600E+05, -.25275500E+05, -.40042800E+05, -.13468800E+05, -.72604400E+04, -.18261200E+05, -.18540400E+05, -.52373400E+05, -.24661600E+04, -.13806600E+05, -.65973000E+05, 0.33114300E+05, 0.61843800E+04, 0.32986600E+05, 0.20595700E+04, 0.20367100E+05, -.67000800E+04, -.30642400E+05, 0.11964400E+05, 0.15806100E+05, 0.51440100E+05, -.25221200E+04, 0.15970400E+04, 0.48662000E+04, 0.12608200E+04, -.75204700E+03, -.25950200E+04, 0.30090000E+04, -.21292200E+03, 0.16609500E+04, -.22845100E+04, -.53079800E+04, 0.22265400E+05, -.11313000E+05, 0.94863600E+04, -.11132400E+05, -.21881400E+04, -.60121900E+04, 0.27055600E+04, 0.82771000E+04, -.11606700E+05, -.66106000E+04, -.11265300E+05, -.52924500E+04, 0.26827100E+04, 0.53160400E+04, 0.26458600E+04, -.35668400E+03, -.31326300E+04, 0.36185000E+04, -.57237700E+03, 0.33605800E+04, -.28813900E+04, -.41016000E+04, 0.44816700E+05, -.21597000E+05, -.11476100E+05, -.22407500E+05, -.48818000E+04, -.28833800E+04, -.49961700E+04, 0.28504800E+04, -.15449000E+05, -.38622200E+04, -.19095700E+05, 0.63046500E+05, -.30425200E+05, -.49161100E+05, -.31530300E+05, -.13662400E+05, -.92960400E+04, -.56190000E+04, 0.50341100E+04, -.25209500E+05, -.86715500E+04, -.34443100E+05, -.60930000E+05, 0.30662300E+05, 0.41166100E+04, 0.30465200E+05, 0.21790300E+04, 0.14877700E+05, -.17279400E+04, -.21543200E+05, 0.15825100E+05, 0.11408700E+05, 0.42208400E+05, -.78357300E+03, 0.41268400E+03, 0.60459200E+04, 0.39181700E+03, -.10084000E+04, 0.15033800E+04, -.89562900E+03, -.27236700E+04, -.33234900E+04, 0.91969800E+03, 0.28138700E+04, -.18483300E+05, 0.83173600E+04, 0.25605100E+05, 0.92414500E+04, 0.59899700E+04, -.61402000E+04, 0.10456900E+05, 0.46941200E+04, 0.43906300E+04, -.30342500E+04, -.10327200E+04, -.42121400E+05, 0.20763700E+05, 0.13427600E+05, 0.21063900E+05, 0.10027900E+05, 0.11954900E+05, 0.57419300E+03, -.74675800E+04, 0.17499800E+05, 0.11220300E+05, 0.13163000E+05, -.44916700E+03, -.21349100E+04, 0.45067800E+05, 0.21632600E+03, -.32429700E+04, -.12505800E+05, 0.85456800E+04, -.10987400E+04, -.69933300E+04, -.80896000E+04, 0.15400300E+05, 0.79198300E+03, 0.49851800E+03, -.13047800E+02, -.77813700E+02, -.11790200E+04, -.70280500E+03, -.34629800E+03, 0.57216100E+04, 0.17582900E+04, 0.37188200E+03, -.25985300E+04, 0.15956500E+04, 0.33925800E+04, 0.30025600E+02, 0.48680400E+03, -.20502400E+04, 0.39741500E+03, 0.72068700E+04, -.43603000E+03, -.35482200E+03, 0.37213300E+04, -.15031500E+04, 0.14538900E+05, -.16234500E+04, 0.40280200E+04, -.18715100E+04 },
        { 0.19279400E+01, 0.11619900E+01, -.80067600E+00, -.15554400E+01, 0.18453100E+00, -.16379000E+01, -.39067200E+01, 0.37602000E+01, 0.26131900E-01, 0.18736300E+01, 0.81391200E-01, -.16690200E+00, -.41220700E+00, -.74232200E-01, 0.50249300E+00, -.17300900E+02, -.25854800E+01, -.17329500E+01, -.96227200E+00, -.30155500E+00, -.14504500E+01, -.21479100E+00, -.20559600E+00, -.21200100E+01, -.72417500E-01, 0.66033600E-01, -.25700500E+00, -.28937200E+01, 0.80172600E+00, -.86321100E-01, 0.14867400E+01, 0.99930700E+00, -.94801800E+00, 0.53134300E+00, 0.23301400E-01, 0.16473700E+00, -.75534900E-01, -.59281000E+00, 0.27049300E+00, -.21255500E+00, -.17876200E+01, -.41108200E+00, 0.21594000E+00, -.29114200E+00, 0.13034300E+05, -.64191200E+04, -.17694400E+05, -.65191200E+04, -.71922500E+04, -.10148700E+05, -.55578000E+03, 0.26006900E+04, -.24020600E+04, -.90405500E+04, -.17337900E+04, 0.12578100E+05, -.58126500E+04, -.41071800E+05, -.62909900E+04, -.22674500E+04, -.10927600E+05, -.22218800E+04, -.18809100E+04, -.25512900E+03, -.93506800E+04, -.22686600E+02, 0.89618400E+04, -.43288500E+04, -.19781100E+05, -.44804100E+04, -.12225500E+04, -.52304300E+04, -.47536100E+04, -.43268900E+04, -.44673800E+04, -.46215300E+04, -.44922300E+04, 0.16313700E+05, -.82935100E+04, 0.43720400E+02, -.81534600E+04, -.49904800E+04, 0.38660100E+04, -.80818700E+04, -.80749700E+04, -.12432200E+05, 0.43744400E+04, -.17579500E+04, -.59317300E+04, 0.30288300E+04, 0.35002900E+04, 0.29642000E+04, 0.33266300E+04, 0.63492100E+04, -.44143500E+03, -.61054300E+03, -.17440900E+04, 0.44240400E+04, 0.95244300E+03, 0.71145200E+04, -.33429200E+04, -.13915200E+05, -.35580500E+04, -.29829400E+04, -.45786800E+04, 0.10807800E+04, 0.26375300E+04, 0.31323400E+04, -.50251000E+04, 0.20667000E+03, -.15787800E+05, 0.77840400E+04, 0.19013500E+05, 0.78895300E+04, 0.71568700E+04, 0.83740000E+04, -.17631500E+04, -.73641700E+04, 0.13456400E+04, 0.84018800E+04, -.10037800E+04, -.75460700E+04, 0.34939200E+04, 0.32142300E+05, 0.37760500E+04, -.64806400E+04, -.30872700E+03, 0.48725600E+04, 0.53277900E+04, 0.27023500E+04, -.74801900E+03, 0.69438800E+04, -.46210300E+04, 0.28512300E+04, -.17100600E+04, 0.23106200E+04, 0.24899100E+04, -.36320000E+03, 0.15318900E+04, 0.21477900E+04, 0.51851500E+03, -.55185900E+03, -.56560900E+03, -.15207200E+05, 0.73278400E+04, 0.36735400E+05, 0.76008600E+04, 0.14133800E+04, 0.15200100E+05, 0.10714100E+05, 0.14651900E+05, 0.10399800E+05, 0.11529200E+05, 0.10323800E+05, -.13246100E+05, 0.65184500E+04, 0.21517700E+05, 0.66232200E+04, -.15867700E+04, 0.19043500E+04, 0.98372800E+04, 0.10132700E+05, 0.66998800E+04, 0.23422000E+04, 0.58644900E+04, -.25758100E+04, 0.98157900E+03, 0.65274000E+04, 0.12875600E+04, 0.11692200E+04, 0.12009400E+04, -.16658700E+04, -.37151400E+04, -.40090500E+04, 0.14971900E+04, -.14594000E+04, -.32230000E+04, 0.16727700E+04, -.27674400E+05, 0.16080600E+04, 0.18803400E+04, 0.22509700E+04, -.54148100E+04, -.11860900E+05, -.23788900E+04, 0.36820500E+04, 0.26280500E+03, -.37178900E+04, 0.17283900E+04, 0.52884300E+04, 0.18633300E+04, 0.34065500E+03, 0.64403800E+02, -.58084300E+03, -.26158900E+04, -.15778900E+04, 0.47352300E+03, -.14935200E+04, -.28206300E+05, 0.13965000E+05, 0.14144600E+05, 0.14104200E+05, 0.72384800E+04, 0.67716900E+04, 0.42105100E+04, -.47480800E+04, 0.11250100E+05, 0.68868800E+04, 0.37369200E+04, -.15010300E+05, 0.72031900E+04, 0.36764700E+05, 0.74961700E+04, 0.99243100E+04, 0.19419200E+05, -.35401400E+04, -.10779400E+05, -.25268100E+04, 0.18810600E+05, -.13800900E+04, 0.34561200E+04, -.19072900E+04, 0.13229400E+05, -.17278200E+04, -.21387900E+04, 0.93270400E+03, 0.39741700E+04, 0.76011300E+04, 0.35579400E+03, 0.11193900E+04, -.13012600E+03, -.92561300E+04, 0.46294200E+04, 0.77862900E+03, 0.46281000E+04, 0.20423800E+03, 0.95757400E+03, 0.17987700E+04, -.25841700E+03, 0.38818700E+04, 0.10171000E+04, 0.48673100E+04, 0.10787500E+05, -.50245800E+04, -.32696300E+05, -.53940000E+04, -.73255800E+03, -.88421400E+04, -.42891500E+04, -.34558800E+04, -.16287000E+04, -.87168900E+04, -.41187700E+04, 0.12074800E+05, -.59199700E+04, 0.71183600E+04, -.60334000E+04, -.76599600E+04, -.10490500E+05, 0.45725000E+04, 0.12391000E+05, 0.15368700E+04, -.10657500E+05, -.25276200E+03, -.38452400E+05, 0.20011900E+05, -.36586900E+05, 0.19215800E+05, 0.89245100E+04, -.16494700E+05, 0.10339200E+05, -.20920100E+03, 0.14631400E+05, -.14532100E+05, 0.69743400E+04, -.50288300E+04, -.14447500E+04, -.23720600E+04, -.23973000E+04, -.21892600E+04, 0.10380800E+04, 0.77607600E+04, -.11803300E+05, -.75198000E+02, -.98232700E+03, 0.30870100E+02, -.28277800E+04, 0.60621400E+03, 0.19896400E+04, -.47536300E+04, -.23006600E+04, 0.24228100E+04, -.14664900E+04, -.25255700E+04, 0.26323300E+04, -.66606100E+04, 0.18649300E+04, 0.44411900E+03, 0.14284000E+03, -.25082200E+03, 0.13274900E+04 },
        { -.17783700E+01, -.89525600E-01, -.14403400E+01, -.14277800E+01, -.83289000E-02, 0.20394000E+00, 0.76500700E+00, -.13482500E+01, -.68562200E-01, -.13292600E+01, 0.17713200E+00, 0.38495900E+00, 0.20511200E+00, -.30281900E+00, 0.14972800E-01, -.97864800E-01, -.18239100E+01, -.12234100E+01, 0.15566700E+01, -.53420200E-01, 0.48976000E+00, 0.10443800E+00, -.13542400E-01, 0.72450600E+00, 0.30243700E+00, 0.12152400E-01, -.24310800E+00, 0.31764800E+00, 0.10415500E-01, 0.21713100E-02, 0.20151300E+00, -.31908600E+00, -.33293000E+00, 0.19946400E+01, -.93715900E-02, 0.85737200E-01, -.17640200E-01, 0.29432600E+00, 0.51623300E-01, 0.27966200E+00, 0.97342100E+00, 0.58928500E-01, -.10598800E+00, -.12778200E+00, -.87405500E-01, -.17624900E+03, 0.82912100E+04, -.83271000E+00, -.21051000E+04, -.35793500E+04, 0.10875800E+04, 0.13451700E+02, 0.77095000E+03, -.29637000E+04, -.10023100E+04, -.22113000E+04, 0.90983600E+03, 0.95731000E+04, 0.11048300E+04, -.94279700E+03, -.23534600E+03, -.13501800E+04, -.34023400E+04, -.31998400E+03, -.75624300E+03, -.21972400E+04, -.52595100E+04, 0.22272100E+04, 0.33496100E+05, 0.26299700E+04, -.99242500E+03, -.73270400E+03, -.67901100E+02, -.31780500E+04, 0.19086100E+04, -.88955900E+03, -.12870200E+03, -.40728600E+03, 0.17496200E+03, 0.61345600E+04, 0.20506700E+03, -.29597300E+03, 0.67695500E+03, -.52932800E+03, -.80739700E+03, 0.15697300E+04, 0.87691100E+03, 0.12174800E+04, -.10006000E+04, 0.53003600E+03, 0.23359500E+04, 0.49959800E+03, 0.49606500E+03, 0.72092500E+03, -.18586300E+02, -.35797000E+03, -.15095500E+03, 0.10458100E+04, 0.70051900E+03, 0.12063400E+04, -.45010300E+03, -.52316500E+04, -.60350800E+03, 0.13554800E+03, -.15881700E+03, 0.18550400E+03, 0.68394700E+02, -.18502900E+04, 0.15803800E+02, -.14037300E+04, -.22926800E+03, 0.12446900E+03, -.32074300E+03, 0.11278900E+03, 0.20382200E+03, 0.10812600E+04, -.39762600E+03, -.32126600E+03, -.92059700E+03, 0.10295200E+04, 0.60013000E+03, -.12368700E+04, 0.80547900E+03, 0.40273200E+04, 0.61971400E+03, 0.66814200E+03, -.64766100E+02, 0.13170200E+04, 0.17453400E+04, 0.30129100E+04, 0.34753200E+03, 0.45993800E+03, -.33233200E+04, 0.16378200E+04, -.42153500E+02, 0.16617100E+04, -.27039500E+03, -.11905300E+04, 0.10044800E+04, 0.42277400E+03, 0.15912900E+04, -.11468500E+04, 0.91074200E+03, -.11573600E+05, 0.64870400E+04, -.51221500E+05, 0.57856400E+04, 0.36351400E+04, 0.49443700E+04, 0.28945400E+04, 0.34735600E+04, 0.34939100E+04, 0.48348500E+04, 0.99199100E+04, -.15438000E+05, 0.76817700E+04, 0.24314000E+05, 0.77190900E+04, 0.18758700E+04, 0.37529000E+04, 0.19062800E+04, -.30297800E+04, 0.34055000E+04, 0.38718900E+04, 0.86057700E+04, 0.12450500E+04, -.66304500E+03, -.52746600E+03, -.62266200E+03, -.49044900E+02, -.30382900E+01, -.36885000E+03, 0.13451500E+03, -.51734600E+03, 0.35472600E+02, -.17404000E+03, 0.26124700E+05, -.13093400E+05, -.52227100E+04, -.13063700E+05, 0.14931500E+04, 0.45085600E+04, -.63782700E+04, 0.74212600E+03, -.12988300E+05, 0.40863300E+04, -.10637100E+05, 0.18644100E+04, -.94332500E+03, 0.81426000E+02, -.93085600E+03, 0.45702700E+02, 0.46558000E+03, -.80970000E+03, -.21045300E+03, -.10052500E+04, 0.47977200E+03, -.15482600E+03, 0.24123000E+04, -.98740600E+03, -.50353200E+04, -.12057200E+04, 0.30630600E+04, 0.62295900E+04, -.33823000E+04, -.17415500E+04, -.28404300E+04, 0.51423800E+04, -.10349100E+03, 0.56875200E+04, -.25846600E+04, -.23038500E+05, -.28475300E+04, 0.13384000E+04, 0.13373300E+04, -.59028900E+03, 0.10291400E+04, -.37199300E+04, 0.18704200E+04, 0.43691100E+03, -.11588700E+05, 0.57002000E+04, 0.19167400E+05, 0.57944300E+04, 0.13403200E+04, 0.29772000E+04, 0.10014800E+04, -.28863800E+04, 0.22938000E+04, 0.30131800E+04, 0.65461400E+04, -.17152200E+04, 0.88955000E+03, 0.42923100E+04, 0.85762500E+03, 0.37990800E+03, 0.31572700E+03, 0.42172100E+03, -.75023000E+03, -.20297200E+03, 0.51843800E+03, 0.67058100E+03, 0.19652200E+05, -.98816400E+04, 0.27475600E+04, -.98261900E+04, -.15752400E+04, -.38050800E+04, -.25226100E+04, 0.11332200E+04, -.82889500E+04, -.33386000E+04, -.11993700E+05, -.15551200E+05, 0.77423800E+04, 0.14545400E+05, 0.77772700E+04, -.25942900E+04, -.57968500E+04, 0.48603000E+04, -.32438500E+03, 0.85926400E+04, -.51812500E+04, 0.55666000E+04, -.38436200E+04, 0.18854100E+04, 0.24309000E+04, 0.19174200E+04, 0.92121700E+03, -.20720000E+04, -.88597100E+02, -.18603400E+04, -.13443900E+04, -.21966000E+04, -.95385000E+03, -.51819700E+03, 0.36033800E+02, -.14743900E+03, -.15681400E+03, -.32182000E+03, -.61406700E+03, 0.14814000E+03, -.47621800E+04, 0.15450100E+03, 0.65541200E+02, -.62387100E+03, 0.21081400E+03, 0.57029400E+03, 0.23332400E+03, -.31384400E+04, -.14397100E+04, 0.15367800E+03, 0.17403400E+03, -.13337400E+03, -.28971500E+03, -.48668300E+03, 0.12828200E+04, 0.24939100E+04, -.40013100E+03, -.77286300E+03, -.30593400E+02 },
        { 0.16617100E+02, 0.12318400E+01, -.22596400E+01, -.10679300E+01, -.63796200E+01, -.33754300E+01, -.13405900E+01, -.11366500E+02, 0.26007100E+01, -.10627800E+01, -.36161700E+01, -.22570800E+01, -.40790200E+01, 0.59714700E+00, 0.23496900E+01, -.27690600E+01, -.59916600E+01, -.17217300E+01, 0.31244000E+01, 0.87704800E+00, -.41758700E+01, -.19665500E+01, 0.18162500E+01, 0.10524300E+01, 0.66863700E+00, 0.13885500E+00, -.13611800E+01, 0.13143600E+01, 0.93060600E+01, 0.26220900E+00, 0.20846500E+01, 0.47484100E+01, -.21569500E+01, -.87582800E+01, -.23223800E+00, 0.10195000E+01, -.41224800E+00, 0.61303600E+00, -.13691600E+01, 0.49809500E+01, -.26488500E+01, -.45526800E+01, 0.58801700E-01, 0.17992600E+00, 0.49307500E+01, -.54334500E+01, 0.93377000E+05, -.19069100E+01, -.32048100E+04, 0.11268100E+04, -.29320700E+02, -.23836000E+05, -.77114900E+04, 0.52092500E+04, 0.25112200E+04, 0.28031100E+05, -.13751600E+05, 0.15444800E+06, -.14017300E+05, -.11472800E+05, 0.43310600E+05, -.29883700E+05, -.25374600E+05, -.24355300E+05, 0.33186600E+05, 0.98124600E+04, 0.56194000E+05, -.29749300E+05, 0.23574200E+06, -.28096500E+05, -.26970900E+05, -.11157800E+05, -.58457500E+04, -.28444400E+05, -.37726800E+05, -.41496100E+04, -.26913900E+05, -.42760800E+05, 0.20553300E+05, 0.26503800E+05, 0.21383500E+05, 0.20987900E+03, -.26715300E+05, 0.13456400E+05, -.97218100E+04, 0.20735100E+05, -.19831800E+05, -.16022200E+04, 0.30914100E+05, -.14929700E+05, 0.84406200E+04, -.15458600E+05, 0.70582100E+02, -.15395800E+05, 0.68328300E+04, 0.17697800E+05, -.17281200E+04, -.10116200E+05, -.18069200E+05, -.16650000E+05, 0.88520900E+04, -.88602200E+04, 0.83241500E+04, 0.86342900E+04, 0.19063100E+05, -.13177400E+05, -.29051900E+04, -.35619200E+03, 0.17544700E+05, 0.12600700E+05, 0.66952400E+05, -.33600900E+05, -.42456500E+05, -.33480100E+05, -.10635700E+05, -.10738300E+05, -.39563300E+03, 0.26979700E+05, -.10896900E+05, -.11673600E+05, -.23793200E+05, 0.24112200E+05, -.12103700E+05, -.81002000E+05, -.12053700E+05, 0.94112000E+04, -.24216900E+05, 0.48262000E+04, -.93593000E+03, -.45953600E+04, -.15768100E+05, -.37315200E+05, -.70938400E+04, 0.30736300E+04, 0.69394600E+04, 0.35469700E+04, -.92131500E+04, -.37500700E+04, 0.59695800E+04, 0.20443600E+04, 0.55437200E+04, -.35642600E+04, 0.13909200E+05, -.24583000E+06, 0.12557200E+06, -.35881400E+06, 0.12291200E+06, 0.66300800E+05, 0.23913400E+05, 0.37452500E+05, 0.41510900E+05, 0.11528200E+06, 0.16793100E+05, 0.93372900E+05, -.20640400E+05, 0.10112300E+05, 0.10945500E+06, 0.10320400E+05, 0.15736400E+05, -.10253000E+05, 0.15637100E+05, 0.57636400E+04, 0.44358700E+04, -.48418200E+04, -.23900300E+05, 0.28324000E+05, -.13644800E+05, -.44743200E+05, -.14164200E+05, -.67941500E+04, -.83310300E+04, -.41583700E+03, 0.15981600E+05, 0.87832600E+04, -.86628300E+04, -.55334800E+04, 0.14925900E+06, -.74637800E+05, 0.54783000E+05, -.74625500E+05, 0.16261300E+05, 0.35531700E+05, -.41792100E+05, 0.21314500E+05, -.67614300E+05, 0.28519100E+05, -.62099600E+05, 0.37337600E+05, -.18214400E+05, -.32790400E+05, -.18677600E+05, -.60043400E+04, -.54431100E+04, -.44669500E+04, 0.11575900E+05, -.20571000E+04, -.55921300E+04, -.76476500E+04, 0.43650600E+05, -.21763400E+05, -.62146900E+05, -.21824600E+05, 0.42835700E+04, 0.14422000E+05, -.17829100E+05, 0.25304400E+05, -.18111600E+05, 0.59950300E+04, -.24234500E+05, -.30234600E+05, 0.15780800E+05, -.18435600E+06, 0.15109300E+05, 0.16817500E+05, -.18387100E+05, 0.10558200E+05, 0.37296900E+05, 0.29302600E+05, -.18544900E+05, 0.11487100E+05, -.15136200E+05, 0.74591800E+04, 0.80097400E+05, 0.75684100E+04, 0.11734400E+05, -.67148100E+04, 0.93250800E+04, -.26534500E+04, -.10443200E+04, -.16804900E+04, -.16355800E+05, -.35747300E+03, 0.17891000E+03, 0.36346800E+05, 0.17877800E+03, 0.65854000E+03, -.24213700E+04, 0.15066100E+04, -.39500600E+04, -.40670200E+04, -.48107600E+03, -.65897000E+04, 0.14182000E+06, -.71057300E+05, 0.75242500E+05, -.70910500E+05, -.22234600E+05, 0.68038200E+04, -.31967700E+05, 0.16397600E+04, -.66579200E+05, 0.60042400E+04, -.40377300E+05, -.97896500E+05, 0.48695100E+05, 0.47375600E+05, 0.48951900E+05, -.19394700E+05, -.29524300E+05, 0.23733100E+05, -.42724300E+05, 0.27612900E+05, -.21348700E+05, 0.40511800E+05, 0.96015600E+05, -.47497700E+05, 0.10713900E+06, -.48017000E+05, -.24502900E+05, 0.51459000E+05, -.53246800E+05, -.14316300E+05, -.40062100E+05, 0.39760100E+05, 0.15600500E+05, 0.10163400E+05, 0.22672500E+04, 0.53321000E+04, 0.55997800E+04, 0.70278900E+04, -.76736000E+04, -.26984500E+05, -.24212600E+05, -.64416200E+03, 0.21303700E+04, -.10074800E+04, 0.10582200E+05, -.88018100E+04, -.56002500E+04, -.14561800E+05, -.29698800E+03, -.55528200E+04, -.36308700E+04, 0.55578400E+04, -.88795500E+04, 0.38755600E+04, 0.43835500E+04, -.12081500E+05, -.14514500E+04, -.13098900E+05, -.23372300E+04 },
        { -.97977500E+01, -.19733200E+01, 0.22706800E+01, 0.13958900E+01, 0.56981100E+01, 0.29783200E+01, 0.13279900E+01, 0.10965300E+02, -.10534400E+01, 0.18646400E+01, 0.24073200E+01, 0.56381400E+00, 0.15554300E+01, -.37596000E+00, 0.40379200E+00, -.16110000E+02, -.12765500E+01, -.40926200E+01, 0.10679500E+01, 0.12998000E+01, 0.16200500E+01, -.47100900E+00, 0.51571800E+00, 0.18633000E+01, 0.37122300E+00, -.77434500E+00, 0.68202900E-01, -.37987000E+00, -.22380100E+01, -.24985800E+00, 0.33172900E+00, 0.33010900E+00, -.56345600E+00, 0.13506100E+01, -.56358400E-01, 0.34821900E+00, 0.29311600E+00, 0.11517700E+00, -.24165700E+00, 0.55537600E+00, 0.20551600E+01, -.80711300E+00, -.12189600E-01, 0.33708600E+00, 0.44035000E+00, -.10316500E+01, 0.10879700E+00, 0.24844200E+02, -.31028800E+04, -.23062900E+04, 0.13121100E+03, 0.69301300E+02, -.30874100E+04, -.17731000E+04, 0.67867100E+04, 0.31070500E+05, -.15452500E+05, -.25671700E+05, -.15530000E+05, -.25813800E+04, 0.33085100E+04, -.94643400E+04, 0.83647600E+03, -.76576700E+04, 0.11826700E+04, 0.14995100E+05, 0.59717700E+05, -.29856400E+05, -.11464400E+05, -.29860200E+05, -.86398600E+04, -.61626800E+04, -.10299400E+05, 0.82197500E+04, -.21392100E+05, -.70635700E+04, -.88699500E+04, -.58868300E+04, 0.29184400E+04, 0.10892400E+05, 0.29341800E+04, -.24604300E+04, -.12509300E+04, 0.55497700E+03, -.33540000E+04, -.34448500E+04, 0.45849800E+03, -.40290300E+04, 0.11073300E+05, -.55129300E+04, -.11612900E+04, -.55321100E+04, 0.21883200E+04, 0.54510700E+03, -.14736200E+04, 0.15092400E+04, -.29237800E+04, -.33820000E+03, -.85621800E+04, 0.62054400E+03, -.25437300E+03, -.11509000E+05, -.30809300E+03, -.15642100E+04, 0.74041100E+03, 0.27073500E+03, 0.35912300E+03, 0.51726800E+04, -.42735500E+03, 0.49304500E+04, 0.14689100E+05, -.73706200E+04, 0.29295300E+04, -.73325300E+04, -.78040000E+03, -.28700400E+04, -.20117500E+04, -.45994700E+03, -.19687900E+04, -.20921100E+04, -.92430700E+04, -.52202300E+04, 0.25941100E+04, 0.15619400E+05, 0.26019900E+04, -.34948900E+04, -.37982300E+04, 0.25744200E+04, -.76462300E+03, -.51657400E+04, -.21231500E+04, -.68693300E+04, 0.18456500E+04, -.81510600E+03, -.33403400E+04, -.92310800E+03, 0.70655700E+03, 0.16110900E+04, -.92910100E+02, 0.16393100E+04, 0.43784400E+03, 0.86542000E+03, 0.38636400E+04, -.90792900E+05, 0.45408300E+05, 0.13282300E+05, 0.45403900E+05, 0.13704500E+05, 0.12305100E+05, 0.18087800E+05, -.67651400E+04, 0.36935700E+05, 0.11730900E+05, 0.94956500E+04, 0.44410400E+04, -.22125700E+04, 0.20049500E+05, -.22209800E+04, -.91406200E+03, -.10328700E+05, 0.80558100E+04, 0.55031800E+04, 0.45291800E+03, -.54461000E+04, -.28128500E+05, 0.30104100E+04, -.15589600E+04, -.17553500E+04, -.15040300E+04, -.13545200E+04, -.17308900E+04, -.27419400E+03, 0.44657300E+03, 0.15221400E+04, -.19103100E+04, -.20075000E+04, -.12656300E+05, 0.63104800E+04, -.34102600E+04, 0.63448300E+04, 0.42344500E+04, 0.23583600E+04, 0.54330500E+03, -.62778400E+04, 0.66999900E+04, 0.31162300E+04, 0.18097300E+04, 0.28402000E+04, -.14506300E+04, -.13575500E+04, -.14241700E+04, -.20222800E+04, -.29503700E+04, 0.22271800E+02, 0.30880200E+03, 0.12038900E+04, -.29269400E+04, -.32681600E+04, -.21903800E+04, 0.10906000E+04, -.15770600E+04, 0.10925500E+04, 0.14379300E+04, -.25853200E+04, 0.11483700E+04, -.69973300E+03, 0.56849900E+04, -.25619300E+04, -.89548300E+04, -.30316700E+05, 0.15105400E+05, 0.15366000E+05, 0.15182800E+05, 0.67596600E+04, 0.29805600E+04, 0.17997300E+04, -.10934400E+05, 0.12465700E+05, 0.46142500E+04, -.51989500E+04, 0.16430600E+05, -.82451800E+04, 0.12585000E+05, -.82159700E+04, -.13541100E+04, -.74139500E+04, 0.28258900E+04, 0.50555700E+04, -.51216800E+04, -.38800500E+04, -.24734600E+05, -.26251100E+04, 0.13220700E+04, 0.31980900E+04, 0.13124500E+04, -.42942200E+03, -.15595600E+04, 0.12204400E+04, -.55169100E+03, 0.14208500E+04, -.69597800E+03, -.28190400E+04, 0.30320300E+05, -.15098200E+05, -.19821000E+05, -.15159400E+05, -.28005900E+04, 0.15169000E+04, -.68909900E+04, 0.13036800E+04, -.65042400E+04, -.97738200E+03, 0.67314200E+04, 0.86338900E+04, -.42627700E+04, 0.56325700E+04, -.43279400E+04, -.69690200E+04, -.50556000E+04, 0.10739100E+04, 0.73873500E+04, -.76146500E+04, -.47939800E+04, 0.27426100E+04, 0.47875000E+04, -.22365700E+04, -.26521100E+05, -.23654300E+04, 0.90587800E+03, -.24340800E+04, -.50377000E+03, 0.78524400E+04, 0.93241500E+04, -.49649700E+04, 0.21353000E+05, 0.72457000E+03, -.52676800E+03, -.11868800E+04, -.11362100E+04, -.60214200E+03, 0.22485600E+03, 0.21984000E+04, -.10137400E+05, 0.31894600E+03, -.59762400E+03, 0.43654900E+03, -.12909300E+04, -.16413900E+04, 0.10398500E+04, -.35505600E+04, 0.14412500E+04, 0.12717600E+04, -.27134800E+04, -.13357100E+04, 0.14547100E+04, -.17039700E+04, 0.87397500E+03, -.11075600E+05, 0.86962700E+03, -.11028000E+04, -.51925100E+03 },
        { 0.24788500E+00, 0.16994400E-01, -.17377800E-01, -.14424900E+00, 0.68101700E+00, -.17730700E+00, 0.10191000E-02, 0.11864000E+01, 0.18873800E+00, 0.18933800E+00, 0.88666000E-01, 0.26923000E-01, -.20788800E+00, 0.14945200E-01, 0.28253100E+00, -.21020400E+01, -.50306800E+00, -.78624100E+00, -.57568900E+00, -.28534200E-01, 0.45503200E+00, 0.15224400E+00, 0.87923400E-01, 0.56455600E+00, 0.96481300E-01, 0.22089600E-01, 0.17133300E+00, 0.99474800E+00, 0.73645200E-01, -.70295400E-01, -.88780000E-01, 0.65075700E+00, -.61945700E-01, -.16266700E+01, -.43405000E-02, -.20418800E-01, -.52557000E-01, -.34650300E+00, -.99129100E-01, 0.14155600E+00, -.87329600E+00, -.26388200E+00, 0.45103200E-04, -.13503600E-01, 0.84414900E-01, -.59581800E-01, 0.24544400E-01, -.10776800E-01, 0.18414300E+04, 0.27548500E+04, 0.12951400E+03, 0.12188400E+04, 0.61157600E+03, 0.23141800E+04, -.12279600E+04, 0.45456100E+03, -.20235400E+03, -.16766200E+02, -.22748800E+03, 0.17188600E+04, 0.44409900E+04, -.14328900E+03, 0.22601300E+04, -.49154000E+03, 0.39265400E+04, -.27390400E+04, -.80826600E+04, 0.40369400E+04, 0.35773100E+04, 0.40413900E+04, 0.18175000E+04, 0.21247000E+04, 0.26039800E+04, 0.68195300E+03, 0.29722200E+04, 0.25023900E+04, 0.14019400E+04, -.89139100E+03, 0.43827700E+03, 0.25383900E+03, 0.44605700E+03, 0.85196400E+03, 0.15713200E+03, 0.16181700E+04, 0.17173200E+04, 0.15039500E+04, -.14436700E+03, 0.60471800E+03, 0.14074300E+03, -.64180700E+02, -.68859400E+03, -.70549700E+02, -.64759900E+03, -.59580400E+03, -.15368500E+03, -.52338600E+03, -.26836500E+03, -.40387600E+03, 0.32050900E+03, -.43267100E+03, 0.25132300E+03, 0.13521500E+04, 0.21625400E+03, 0.77444900E+03, 0.98811300E+03, -.31068000E+03, 0.61859000E+03, -.97701800E+02, 0.96713300E+03, -.40019700E+03, -.22093900E+04, 0.10932200E+04, -.34274300E+03, 0.11042200E+04, -.13126800E+04, -.19172400E+04, 0.31959600E+03, -.47734800E+03, 0.32438100E+03, -.16384700E+04, 0.19262400E+04, 0.46446300E+04, -.23285100E+04, -.27610800E+04, -.23220100E+04, -.95835200E+02, -.15542100E+04, 0.74319200E+02, 0.18073000E+03, -.71781700E+03, -.14669300E+04, -.14153800E+04, 0.16869200E+04, -.78758100E+03, -.58848800E+03, -.84345200E+03, 0.16980900E+02, 0.39438200E+03, -.43187200E+03, 0.73666000E+01, -.71072700E+03, 0.40364600E+03, -.11045700E+04, 0.11072900E+05, -.55263900E+04, -.39407600E+04, -.55367600E+04, -.33419300E+04, -.57083000E+04, -.49024600E+04, -.47450100E+04, -.56943000E+04, -.53112900E+04, -.12719700E+04, 0.78616600E+04, -.39362900E+04, -.43574500E+04, -.39308100E+04, -.98751200E+03, -.60750000E+03, -.34620500E+04, -.29848900E+04, -.44370800E+04, -.10648000E+04, -.13378300E+03, -.21854300E+04, 0.10593800E+04, 0.11602000E+04, 0.10927100E+04, 0.31879500E+03, 0.34785100E+03, 0.41241700E+03, -.10857400E+03, 0.40096800E+03, 0.34025000E+03, 0.80191900E+03, -.11333800E+05, 0.56639200E+04, 0.65631600E+04, 0.56655300E+04, 0.28170000E+01, -.13499900E+04, 0.24894100E+04, 0.11578400E+03, 0.38439500E+04, -.12553000E+04, 0.46699100E+04, -.19773500E+04, 0.97369500E+03, 0.10159200E+04, 0.99006300E+03, 0.31011900E+03, 0.32669700E+03, 0.44385200E+03, -.10650500E+03, 0.29640700E+03, 0.33932600E+03, 0.68858000E+03, 0.57143900E+03, -.29091200E+03, 0.17375300E+02, -.28562200E+03, -.19636400E+04, -.26802700E+04, -.36306000E+03, -.14412100E+04, -.14954000E+04, -.21584300E+04, 0.18684100E+04, 0.14650200E+04, -.74916900E+03, -.12573700E+04, -.73347200E+03, -.29602900E+04, -.45256800E+04, -.15027500E+03, -.40937100E+03, -.10150000E+04, -.42115800E+04, 0.11847500E+04, 0.20586600E+04, -.10496000E+04, -.21012700E+04, -.10293100E+04, -.37431500E+03, -.47907900E+03, -.14503200E+04, -.18602700E+04, -.16529100E+04, -.80650800E+03, 0.89241700E+03, 0.14312900E+04, -.71292400E+03, -.12981200E+03, -.71563900E+03, -.92883800E+02, 0.90177500E+01, -.34212000E+03, -.12823800E+03, -.91758000E+03, -.91615500E+02, -.21541300E+03, -.49634300E+04, 0.25124900E+04, 0.26513400E+04, 0.24816900E+04, 0.16419300E+04, 0.28632400E+04, 0.16524900E+04, 0.29225300E+04, 0.25874900E+04, 0.26397000E+04, 0.17116800E+03, 0.10222200E+05, -.50932800E+04, -.46382100E+04, -.51106600E+04, 0.14272100E+04, 0.29500700E+04, -.18420700E+04, 0.72555400E+03, -.29779900E+04, 0.25028700E+04, -.52710100E+04, 0.15461600E+04, -.70431600E+03, 0.12567500E+04, -.77416900E+03, 0.16097500E+04, 0.39074400E+04, -.72066100E+03, 0.98754700E+03, -.21117100E+04, 0.36068300E+04, -.31169500E+04, 0.43154100E+03, 0.35353400E+03, 0.33980200E+03, 0.34948000E+03, -.24013100E+01, 0.33137600E+03, -.17949200E+04, 0.48740700E+04, -.12276900E+03, 0.30119900E+03, 0.16196300E+02, -.24205300E+03, -.28330600E+02, 0.74359300E+02, 0.21301000E+04, 0.69694400E+03, -.38630300E+03, 0.21499400E+03, 0.35623100E+03, -.65866300E+02, 0.24566100E+04, -.65901600E+03, 0.30657300E+03, 0.27436300E+03, 0.43294500E+03, -.64255400E+02 },
        { 0.57678100E+01, 0.93303400E+00, -.17042800E+01, -.21450100E+01, -.19826400E+01, -.13112000E+01, -.75949000E+00, 0.28577800E+01, 0.86262500E+00, 0.14614100E+01, 0.14392400E+01, 0.13140400E+00, 0.23932400E+00, 0.43170000E+00, 0.71542900E+00, 0.10053100E+02, 0.63458500E+01, 0.37519600E+01, 0.26479800E+01, -.45911800E+00, -.56420500E+01, -.24879400E+01, 0.82263500E+00, 0.49905300E+01, -.10868000E+00, 0.15414200E+00, 0.12392200E+01, 0.96738500E+01, -.23332800E+01, -.15976500E+00, 0.23407600E+01, 0.56742300E+01, -.22740200E+01, -.41716200E+01, 0.61265900E-01, 0.85319500E+00, -.29361300E+00, -.36001000E+01, -.37654400E+00, -.13289800E+00, 0.16544000E+01, -.19442800E+01, 0.34900500E+00, 0.31542900E+00, 0.11054000E+01, 0.46969900E+00, -.26298500E-02, -.54866800E-01, 0.28572200E+01, 0.10348700E+05, -.49227200E+04, -.24930000E+04, -.97499300E+04, 0.10343600E+05, 0.26120300E+05, 0.92235400E+05, -.46002700E+05, -.52892200E+05, -.46118100E+05, -.39311100E+04, 0.28624500E+05, -.29045600E+05, 0.81285200E+04, -.30672800E+05, 0.24733200E+05, 0.61126800E+05, 0.10222200E+06, -.51028000E+05, -.38502300E+05, -.51110700E+05, -.20717100E+05, -.42481400E+04, -.17210500E+05, 0.17776500E+05, -.41540400E+05, -.23605700E+04, 0.22849200E+05, -.24841000E+05, 0.12359200E+05, 0.14106300E+05, 0.12421300E+05, -.64930900E+04, -.68871000E+04, 0.59176300E+04, -.82542900E+04, -.20535300E+04, -.29449700E+04, -.10276000E+05, 0.35556500E+05, -.17667300E+05, -.97145400E+04, -.17778600E+05, -.14188400E+03, -.95025200E+04, -.17973400E+04, 0.68672800E+04, -.40042400E+04, -.11043200E+05, -.27099000E+05, -.82761300E+04, 0.40760900E+04, -.94958800E+04, 0.41378700E+04, -.81536800E+03, 0.62813200E+04, -.17264300E+04, -.49054200E+04, 0.12145300E+05, 0.30468300E+04, 0.14073800E+05, 0.48719900E+05, -.24332000E+05, -.10022700E+05, -.24360900E+05, -.51454600E+04, -.15176200E+05, -.26467400E+04, 0.71327800E+04, -.43124400E+04, -.13801300E+05, -.28401900E+05, 0.12783100E+05, -.63932700E+04, 0.94747000E+03, -.63909100E+04, -.83389500E+04, -.12483300E+05, -.84337400E+01, -.69126300E+04, -.22374800E+05, -.10191800E+05, -.31894400E+05, 0.11002500E+05, -.55622000E+04, -.61736200E+04, -.55012300E+04, 0.97938500E+03, 0.57952000E+04, -.12088300E+04, 0.36527800E+04, -.39342800E+03, 0.47628400E+04, 0.12995300E+05, -.14622500E+06, 0.73123600E+05, 0.49134400E+05, 0.73111800E+05, 0.31516100E+05, 0.22063900E+03, 0.30173100E+05, -.20227600E+05, 0.70175100E+05, -.37356200E+04, -.59269900E+05, 0.45432300E+05, -.22418200E+05, -.91687500E+04, -.22716100E+05, 0.20315600E+04, -.27498800E+05, 0.81984400E+04, 0.15744900E+05, -.26110000E+04, -.20797200E+05, -.10091800E+06, 0.49956900E+04, -.25063000E+04, -.78288800E+04, -.24980500E+04, -.50136800E+04, -.77510000E+04, 0.17339000E+04, 0.25235000E+04, 0.77786800E+04, -.80716200E+04, -.39193800E+04, -.77349400E+05, 0.38615900E+05, 0.29422300E+05, 0.38677000E+05, 0.58027200E+04, -.53924200E+04, 0.13771300E+05, -.15229900E+05, 0.40070000E+05, -.38269600E+04, 0.14885400E+05, 0.69524800E+04, -.34983500E+04, -.71739500E+04, -.34763400E+04, -.66578100E+04, -.11222600E+05, 0.19384500E+04, 0.16348200E+04, 0.58110200E+04, -.11391500E+05, -.83121600E+04, 0.26161800E+04, -.12639900E+04, -.67649900E+04, -.13078600E+04, -.73761900E+04, -.25867000E+05, 0.91710300E+04, 0.40286200E+04, 0.11515700E+05, -.25468200E+05, -.34412000E+05, -.51465800E+05, 0.25684200E+05, 0.28447600E+05, 0.25730900E+05, 0.13874700E+05, -.10255000E+05, 0.54557000E+04, -.14818900E+05, 0.30918900E+05, -.92323300E+04, -.46767300E+05, 0.62464600E+05, -.31010100E+05, -.13589500E+05, -.31232200E+05, -.66302600E+03, -.20816900E+05, -.18942300E+03, 0.15779100E+05, -.12720400E+05, -.16395200E+05, -.82799900E+05, 0.41538600E+04, -.20170900E+04, -.54408400E+04, -.20769200E+04, 0.15439600E+03, -.39538300E+04, 0.96902500E+03, 0.76286500E+03, 0.10293500E+04, -.24079400E+04, -.12976200E+05, 0.46713800E+05, -.23525700E+05, -.26159400E+05, -.23357000E+05, -.10432000E+05, 0.12715200E+05, -.12721300E+05, 0.36532900E+03, -.88450400E+04, 0.72581300E+04, 0.46770800E+05, 0.45362700E+05, -.22627400E+05, -.16941800E+05, -.22680400E+05, -.86097400E+04, 0.61837900E+04, -.91682100E+04, 0.12827700E+05, -.35747000E+05, 0.69516500E+04, 0.94106300E+04, 0.42184000E+05, -.21058200E+05, -.40339200E+05, -.21094300E+05, -.36548300E+04, 0.62019300E+04, -.60865800E+04, 0.28979700E+05, 0.97809900E+04, 0.22182200E+03, 0.57067100E+05, 0.59192900E+04, -.91095200E+03, -.13476700E+04, -.11601500E+04, 0.10109300E+03, 0.17376900E+04, -.23508600E+04, -.90141700E+03, 0.46652900E+03, -.14367300E+04, 0.12134700E+04, -.13545800E+04, -.51821200E+04, 0.15417000E+04, 0.34598300E+04, 0.69568500E+04, 0.15891300E+04, -.33495600E+04, -.18164300E+04, 0.33928600E+04, 0.20803800E+04, -.23364200E+04, -.26967300E+05, 0.24971400E+04, -.18833300E+03, -.28133800E+04 },
        { -.86026900E+00, -.26723800E+00, 0.35724000E+00, 0.43599700E+00, -.13583400E+00, 0.47035800E+00, 0.18124700E+01, -.14469300E+01, -.35910600E-01, -.95562400E+00, 0.23906100E-01, 0.35130000E+00, 0.22314600E+00, 0.17310800E-01, -.23320200E+00, 0.68051300E+01, 0.14623800E+01, 0.34237600E+00, 0.70940200E+00, 0.97666200E-01, 0.48342300E+00, 0.43800700E+00, -.39517600E-01, 0.76935300E+00, -.40233900E-01, -.61181500E-01, 0.30218700E+00, -.42921900E-01, -.93074100E+00, -.19132500E-01, -.61955400E+00, 0.49982800E+00, 0.92815500E-01, 0.67250900E+00, 0.26193400E-01, -.30452200E-01, 0.42439900E-01, 0.26215100E+00, -.15762200E+00, 0.21069400E+00, -.73329200E+00, 0.29876600E+00, 0.43998500E-01, 0.83137800E-01, 0.10175500E+00, 0.29847000E-01, 0.96132100E-02, 0.29631000E-01, -.91943900E-01, -.14418900E+00, -.17252400E+04, -.35233000E+04, -.14194100E+04, 0.19819800E+03, 0.35764100E+04, -.49174500E+04, 0.23687600E+04, 0.35134500E+04, 0.24592100E+04, -.23112700E+04, -.37705200E+04, 0.17344100E+04, -.74616500E+03, 0.26244800E+04, -.21960000E+04, 0.11810000E+05, 0.37187600E+04, -.18153500E+04, -.37458700E+04, -.18595000E+04, -.52874300E+03, 0.28243000E+03, -.20103900E+04, -.24185200E+04, -.34186600E+04, 0.48484500E+03, 0.47768300E+04, 0.12358100E+04, -.60038100E+03, -.14351700E+04, -.61875400E+03, 0.10360900E+04, 0.81752600E+03, -.19917700E+04, -.25889400E+04, -.25289500E+04, 0.14948400E+03, -.26736500E+04, 0.43511400E+04, -.21727200E+04, -.14058200E+04, -.21751500E+04, -.15567800E+04, -.28793600E+04, 0.12494100E+04, 0.24898400E+04, 0.43928400E+02, -.27569700E+04, -.37065000E+04, -.33314200E+04, 0.14935700E+04, 0.23733400E+04, 0.16659100E+04, -.53216900E+02, 0.72852700E+02, -.98758000E+03, -.12832800E+04, 0.19057300E+04, -.44165900E+00, 0.40248900E+04, 0.35875900E+04, -.17364600E+04, -.21023500E+04, -.17926900E+04, 0.45381700E+03, 0.10029800E+04, 0.92773600E+03, 0.36643000E+04, 0.85506200E+03, 0.74685900E+03, -.31618100E+04, 0.57772500E+04, -.28731400E+04, -.61049000E+04, -.28893600E+04, 0.15383500E+04, 0.26419700E+04, -.39238800E+04, -.34436800E+04, -.60257100E+04, 0.15261300E+04, -.46595100E+04, -.72466300E+03, 0.89044000E+02, 0.95613600E+03, 0.36230900E+03, -.68533200E+03, -.35568000E+03, 0.75153100E+03, -.12544800E+03, 0.35465500E+03, -.12342900E+03, 0.21197100E+04, 0.67669600E+04, -.34499500E+04, 0.20218900E+03, -.33828000E+04, 0.25921100E+03, -.10179300E+04, 0.11497000E+04, 0.67840500E+04, 0.29686500E+04, -.19769900E+04, -.15198000E+05, 0.14690900E+05, -.72381800E+04, -.10188600E+05, -.73455000E+04, -.58922200E+03, -.22553700E+04, -.12249700E+04, 0.63367400E+04, -.63184400E+03, -.28718500E+04, -.13511500E+05, 0.96916100E+03, -.33723700E+03, -.90082000E+03, -.48448600E+03, -.70956700E+03, -.93055600E+03, 0.43106900E+03, 0.54599800E+03, 0.87739100E+03, -.96887800E+03, -.70287100E+03, 0.38817600E+04, -.19218800E+04, -.40100200E+03, -.19392100E+04, -.11991100E+03, 0.36679800E+03, 0.11100600E+03, 0.22879400E+04, 0.15365800E+04, 0.23098400E+03, -.37447500E+04, 0.18170100E+04, -.84375800E+03, -.14665900E+04, -.91113600E+03, -.83368300E+03, -.15530600E+04, 0.47742800E+03, 0.58971000E+03, 0.63070400E+03, -.16026300E+04, -.16339900E+04, 0.19450600E+04, -.93725900E+03, -.25623000E+03, -.97275700E+03, -.33679700E+03, -.12331300E+04, 0.24491000E+04, 0.48778200E+04, 0.13854300E+04, -.14302400E+04, -.61614800E+04, -.12728000E+04, 0.70228200E+03, 0.10440900E+04, 0.63864900E+03, 0.27623000E+03, 0.64497800E+03, 0.29898400E+04, 0.63495900E+04, 0.36484600E+04, -.13034000E+03, -.71818900E+04, 0.13332000E+05, -.64977300E+04, -.88501300E+04, -.66660400E+04, -.61959600E+03, -.15901400E+04, -.13322200E+04, 0.47569700E+04, -.13639200E+04, -.20961700E+04, -.10895700E+05, 0.48443600E+04, -.24349500E+04, -.21114500E+04, -.24221900E+04, -.40436700E+03, -.66169200E+03, -.72985300E+03, 0.14055800E+04, -.58387800E+03, -.75321500E+03, -.30094500E+04, -.91450700E+04, 0.43784400E+04, 0.52665900E+04, 0.45726000E+04, -.88900400E+03, -.53344700E+02, 0.19651500E+03, -.45075900E+04, 0.15543500E+04, 0.47582200E+03, 0.11576200E+05, -.30992700E+04, 0.14524000E+04, -.57032300E+03, 0.15486200E+04, 0.49896600E+03, 0.16911400E+03, -.20091000E+04, -.48560300E+04, -.23530300E+04, 0.32713300E+03, 0.50460600E+04, 0.66887300E+04, -.36572700E+04, 0.37534000E+04, -.33417800E+04, -.56136700E+04, -.34752000E+04, 0.12876500E+04, 0.21614600E+04, 0.14220300E+04, -.23557100E+04, 0.43563700E+04, 0.29705900E+03, -.88188000E+03, 0.33503500E+03, 0.36093100E+03, 0.98480300E+03, -.63742200E+03, 0.18666900E+03, 0.10339900E+04, 0.47185900E+03, -.80641700E+03, 0.19030000E+03, 0.99913300E+03, -.63204600E+03, -.82500800E+03, 0.12325400E+04, 0.89669800E+03, -.32154300E+03, -.62099700E+03, 0.24298000E+03, -.50348700E+03, -.11371800E+04, -.84030800E+03, -.10969600E+04, 0.25848800E+03, -.45564800E+03, 0.11556800E+02 },
        { 0.16682400E+01, -.25128100E+00, -.11427600E+01, -.63270000E+00, -.13885300E+01, -.50501000E+00, -.61111000E+00, -.12916000E+01, 0.50366000E-01, -.89152100E+00, 0.23076700E-02, 0.17927900E+00, 0.60287200E-01, 0.81544100E-01, -.23488400E+00, -.19145200E+01, 0.37757200E+01, 0.50572800E+00, -.27369700E+00, -.28230800E+00, 0.69459300E+00, 0.24146200E+00, -.10135300E+00, 0.25459800E+00, 0.56580500E-02, 0.31047000E-01, -.68179500E-01, 0.86321100E+00, -.41042100E+00, 0.43472200E-01, 0.25651700E-01, 0.28899200E-01, -.19474600E-01, 0.12900300E+01, 0.28390500E-01, 0.52085800E-01, -.17483700E-01, -.71745200E+00, 0.22971500E-01, -.22978800E+00, -.28839300E+00, 0.44688000E-01, 0.30370000E-01, 0.79373000E-01, 0.15808300E+00, -.25365600E+00, 0.15988300E-01, 0.14021500E-01, -.68212900E-01, -.10566800E+00, 0.48353100E+00, 0.14744200E+04, -.15481400E+03, 0.19480800E+03, 0.12776900E+04, 0.11518800E+05, -.56137900E+04, -.79623400E+04, -.57594500E+04, -.21050900E+03, 0.27369900E+04, -.37428300E+04, 0.13615300E+04, -.44515200E+04, 0.21230600E+04, 0.15215200E+04, 0.60339800E+04, -.30626600E+04, 0.12153400E+04, -.30169800E+04, -.13344100E+04, -.83636000E+03, -.20457600E+03, 0.29626800E+04, -.22618200E+04, -.39940800E+03, 0.92338600E+03, -.19553400E+04, 0.87709900E+03, 0.33886400E+04, 0.97771900E+03, -.66072200E+03, 0.10349100E+03, 0.94901900E+03, -.15216200E+03, 0.82792900E+03, 0.84287700E+03, -.27412600E+03, 0.21134500E+04, -.97333600E+03, -.56243400E+03, -.10567500E+04, 0.55920400E+03, 0.26243800E+03, -.77984600E+03, -.25081900E+03, 0.48126000E+03, -.60388500E+02, -.14881100E+04, -.10204000E+04, 0.56231900E+03, -.23958400E+04, 0.51018900E+03, -.15670300E+03, 0.25396700E+03, 0.72557300E+03, -.10904300E+04, -.61246300E+03, 0.30182500E+02, 0.66079400E+03, 0.46253400E+04, -.23227500E+04, 0.51654600E+03, -.23127300E+04, -.99029300E+03, -.12209200E+04, -.89411600E+03, -.66534400E+03, -.18196900E+04, -.11361300E+04, -.27235000E+04, -.36802100E+04, 0.17679900E+04, 0.59655900E+04, 0.18401600E+04, -.35123100E+03, -.12275500E+04, 0.19964000E+04, -.39413000E+02, 0.21050100E+04, -.64448100E+03, -.17183900E+03, -.40407800E+02, 0.49601700E+02, -.11107700E+04, 0.20207300E+02, 0.46358300E+03, 0.27803300E+03, 0.16713000E+02, 0.60129300E+03, 0.65310700E+03, 0.13174000E+03, 0.10194300E+04, -.14472200E+05, 0.73556200E+04, -.14014800E+04, 0.72360600E+04, 0.27569600E+04, 0.19302400E+04, 0.19314600E+04, -.48135400E+04, 0.63313900E+04, 0.11733500E+04, -.78953700E+03, -.46613500E+04, 0.24095400E+04, 0.62194800E+04, 0.23306800E+04, 0.18883200E+04, -.63762000E+03, 0.23109300E+04, -.12633800E+04, 0.18032400E+04, 0.23559600E+03, -.38536000E+04, 0.30357000E+03, -.17556800E+03, 0.34496900E+03, -.15176900E+03, -.43812300E+03, -.80761100E+03, 0.33176800E+03, 0.18380700E+03, 0.89517100E+03, -.81782600E+03, -.52103500E+03, -.41732300E+04, 0.21023500E+04, -.66296700E+03, 0.20862000E+04, 0.42155000E+03, -.31650100E+03, 0.32347100E+03, -.22552000E+04, 0.11529500E+04, -.20338600E+03, 0.30219200E+03, 0.30203000E+03, -.15109800E+03, 0.46006700E+03, -.15048200E+03, -.50459300E+03, -.82616200E+03, 0.22853000E+03, -.25120600E+02, 0.67367200E+03, -.81483400E+03, -.70058300E+03, 0.11589400E+04, -.55447500E+03, -.84827500E+03, -.57944500E+03, -.95986300E+03, -.13754700E+04, -.93617200E+02, -.23395500E+04, -.54219800E+03, -.14602700E+04, -.24490200E+04, -.27336300E+04, 0.13455700E+04, 0.73437600E+03, 0.13666800E+04, 0.62988000E+03, -.38800900E+03, -.20709200E+03, -.42415700E+04, 0.40611400E+03, -.23013600E+03, -.27165800E+04, -.65938700E+03, 0.37546900E+03, 0.44615700E+04, 0.32969600E+03, 0.11778000E+04, -.36436600E+03, 0.73067100E+03, -.33689200E+03, 0.68203000E+03, 0.12588100E+03, -.35413600E+04, -.16401400E+04, 0.84357200E+03, 0.17216200E+03, 0.82007300E+03, 0.14549400E+03, -.15376400E+03, 0.66278400E+03, -.46386300E+03, 0.55067700E+03, 0.13130800E+03, -.19724100E+03, 0.10406100E+05, -.52164200E+04, -.56610700E+04, -.52030300E+04, -.14929300E+04, -.46760100E+03, -.17220200E+04, 0.10624000E+04, -.34549300E+04, -.10092600E+04, -.62106700E+03, 0.35161700E+04, -.17656800E+04, 0.72364800E+03, -.17580300E+04, -.90496100E+03, -.87671500E+03, 0.10155400E+04, 0.41129300E+04, -.10476400E+04, -.53868700E+03, 0.41065000E+03, -.92376800E+03, 0.65068300E+03, -.88021800E+04, 0.46171800E+03, 0.69224100E+03, -.26376900E+04, 0.15056100E+04, 0.29935300E+04, 0.16151500E+04, -.31593800E+04, 0.46457000E+04, 0.13479100E+03, -.65445500E+02, -.20146900E+03, -.19276800E+03, -.45785100E+03, 0.28332800E+03, 0.11433100E+04, -.13329900E+04, 0.24051500E+03, -.27217300E+03, -.42269400E+03, -.33778600E+03, 0.45042400E+03, 0.51751900E+03, -.54173500E+03, 0.86314000E+02, 0.26583300E+03, 0.18410400E+03, -.24450100E+03, 0.52047300E+03, 0.22411300E+03, 0.28272000E+03, -.22540500E+04, 0.18726600E+03, 0.31691500E+03, -.29238800E+03 },
        { 0.16227200E+01, -.47376200E-01, -.60632200E+00, 0.55218900E+00, -.70972900E+00, -.75630400E+00, -.41456000E+00, -.75667600E+00, -.93794700E-01, 0.63937200E+00, -.20045200E+00, -.23745500E+00, 0.12748900E+00, 0.12340800E+00, -.47018300E+00, 0.61030600E+01, 0.30812700E+01, 0.12330400E+01, -.86538900E-01, -.28061700E+00, 0.23211200E+00, 0.10636800E+00, -.15399000E+00, 0.31930100E+00, -.12833000E+00, 0.83691100E-01, 0.88223400E-01, 0.38312000E+00, -.69838300E+00, 0.19914200E+00, -.84687800E-01, -.10421800E+01, 0.46726500E+00, 0.45537200E+01, 0.31990700E-01, 0.37157000E-01, -.44460000E-01, -.32014500E+00, -.49371600E-01, -.33513400E+00, 0.16945700E+01, 0.44959600E+00, -.63810200E-01, 0.20848300E+00, 0.36735100E-01, -.18740600E+00, 0.65551000E-02, -.19627000E-01, 0.11274000E+01, 0.32696800E-02, 0.23609900E+00, -.11494800E+01, -.20411500E+04, 0.28532000E+02, 0.15402000E+04, 0.14646000E+05, -.74069500E+04, -.45877900E+04, -.73232900E+04, -.85411700E+03, 0.33603600E+04, -.52671800E+04, -.48234300E+03, -.47843600E+04, 0.15644700E+04, 0.99723600E+03, 0.11400500E+05, -.57664200E+04, 0.11033200E+04, -.57001700E+04, -.42932000E+04, -.44034600E+04, -.12278800E+04, 0.12614600E+04, -.40390800E+04, -.43757000E+04, 0.70608500E+03, -.43633500E+04, 0.21385200E+04, 0.28569400E+04, 0.21821700E+04, -.53572700E+03, -.24066400E+04, 0.98856100E+03, -.18218100E+04, -.60988700E+03, -.90324200E+03, -.22326000E+03, 0.31922900E+04, -.15220300E+04, 0.18687700E+04, -.15963900E+04, 0.14150200E+04, 0.12519600E+04, -.88585200E+03, 0.46507500E+03, -.38451000E+03, 0.84339000E+03, -.24724300E+04, -.26529800E+03, -.45359300E+02, -.66711000E+04, 0.13252700E+03, -.64418100E+03, 0.53553600E+03, 0.82358200E+03, -.68834100E+03, 0.68701700E+03, 0.39695500E+03, 0.10822200E+04, 0.86387800E+04, -.42649400E+04, 0.44538400E+04, -.43200200E+04, -.15776000E+04, -.21901700E+04, -.66061800E+03, 0.87819800E+03, -.30839300E+03, -.21305900E+04, -.50470300E+04, -.81390500E+04, 0.41094000E+04, 0.41990300E+04, 0.40700500E+04, 0.33449800E+03, -.10431400E+04, 0.16297200E+04, -.22783200E+04, -.14928800E+04, 0.53698300E+03, -.35323800E+03, 0.79577500E+03, -.83009100E+03, -.10654700E+04, -.39785800E+03, 0.32825300E+03, 0.12993800E+04, -.58374100E+03, 0.95427000E+02, 0.24471300E+03, 0.66471900E+03, 0.18119800E+04, -.32787400E+05, 0.16564700E+05, 0.25751900E+04, 0.16393300E+05, 0.88431500E+04, 0.96592000E+04, 0.53772600E+04, -.17595700E+04, 0.12776000E+05, 0.94092200E+04, 0.30321100E+04, -.15311100E+05, 0.78805600E+04, 0.13381600E+05, 0.76555700E+04, 0.40712000E+04, -.75024200E+03, 0.57171000E+04, -.15259600E+04, 0.47203200E+04, 0.18171400E+04, -.66428900E+04, 0.59552900E+04, -.27194300E+04, -.49198300E+04, -.29776700E+04, -.97529700E+03, -.11112500E+04, -.76529200E+03, 0.13589100E+04, 0.27998400E+03, -.12647900E+04, -.16027900E+04, -.76687800E+04, 0.38277100E+04, 0.99552200E+03, 0.38349500E+04, 0.25351800E+02, -.23817600E+04, 0.18857100E+04, -.14001000E+04, 0.50961700E+04, -.20081800E+04, 0.40815300E+04, 0.50356500E+04, -.23885300E+04, -.39702300E+04, -.25183000E+04, -.10629800E+04, -.10698000E+04, -.92935300E+03, 0.77805100E+03, -.12428500E+03, -.11772100E+04, -.12697300E+04, -.13489500E+04, 0.73143600E+03, 0.34208600E+02, 0.67468000E+03, -.16729300E+04, -.25813400E+04, 0.56642600E+03, -.34505200E+03, 0.35388100E+04, -.23484300E+04, -.22731800E+04, -.99064800E+04, 0.50775100E+04, 0.64428900E+04, 0.49519100E+04, 0.40306000E+04, 0.23039000E+04, 0.21665600E+03, -.32819400E+04, 0.61807200E+04, 0.25285600E+04, -.12450800E+04, -.47460900E+04, 0.26471400E+04, 0.90091500E+04, 0.23730800E+04, 0.23949500E+04, -.55721200E+03, 0.23057800E+04, -.78996300E+03, 0.83045000E+03, 0.11769200E+04, -.66100300E+04, -.10348800E+05, 0.51914100E+04, 0.36150400E+04, 0.51744100E+04, 0.11110300E+04, 0.58594000E+03, 0.19203100E+04, -.21714300E+04, 0.31894500E+04, 0.11886800E+04, 0.17499600E+04, 0.19142500E+05, -.98949900E+04, -.10731300E+05, -.95713100E+04, -.40101500E+04, -.15932100E+04, -.32309300E+04, 0.81791900E+03, -.56668300E+04, -.24884000E+04, -.37739500E+03, 0.18474600E+03, -.20212200E+03, -.32661400E+04, -.91795300E+02, -.15698000E+04, -.59060400E+03, 0.84384800E+03, 0.22518800E+04, -.34498300E+04, -.40356900E+03, 0.12760400E+04, 0.44916600E+04, -.26068400E+04, -.12098700E+05, -.22474700E+04, -.15375100E+04, 0.54528200E+03, -.18548800E+04, 0.26404300E+04, 0.43788600E+04, -.17241100E+04, 0.95374300E+04, 0.58910000E+03, -.25453900E+03, 0.24692100E+03, 0.27245900E+03, 0.20034200E+03, -.11816700E+03, 0.59119100E+03, -.69467300E+04, 0.21247300E+03, -.29850000E+03, -.26340400E+03, -.39602200E+03, -.79735800E+03, -.90846600E+02, -.27668500E+04, -.56919000E+03, -.18878400E+03, -.57725600E+03, 0.27149800E+03, 0.26035200E+03, -.13569300E+04, 0.12961800E+04, -.33498700E+04, 0.35516400E+03, -.47305000E+03, -.19984300E+02 },
        { -.47377800E+00, -.40447800E-01, 0.15995000E+00, 0.18480700E+00, 0.14287900E+00, 0.44914900E-02, 0.75405300E-01, -.90489200E+00, -.19908600E-01, 0.20672600E+00, -.12506500E+00, -.76009700E-02, 0.36338000E-01, -.97803400E-02, -.11980900E+00, 0.17673400E+01, 0.23749700E+00, 0.20206300E+00, 0.15222700E+00, -.85384700E-02, -.20715500E-01, -.10632200E+00, 0.15283500E-03, -.82590400E-01, -.83227100E-01, -.36049100E-02, -.69375200E-02, 0.82852900E-01, 0.16380400E+00, 0.14410500E-01, -.83602100E-02, -.11412200E-01, -.36924700E-01, 0.59748500E+00, -.58870500E-04, 0.31697300E-01, 0.23695600E-03, -.10931100E+00, 0.12415200E-01, -.38906900E-01, 0.29415300E+00, -.51168200E-01, 0.14739800E-01, 0.29657400E-01, 0.42410600E-01, -.27335600E-01, 0.10752900E-01, 0.24147200E-02, 0.11076500E+00, 0.20731000E-01, -.48190200E-01, 0.53235300E-01, -.32031800E-01, -.21067700E+03, -.77117800E+02, -.14248000E+04, 0.70863800E+03, 0.15055800E+03, 0.71249300E+03, -.18222100E+02, -.87802300E+03, 0.81583300E+03, 0.37979100E+03, 0.96952800E+03, -.10240500E+04, 0.59178100E+03, 0.32618200E+04, -.16380900E+04, -.23883200E+04, -.16309400E+04, -.37006800E+03, -.52772000E+02, -.66726200E+03, 0.82181300E+03, -.59827700E+03, -.69677200E+03, -.88752700E+03, 0.10554900E+03, -.63396400E+02, -.16776100E+03, -.52934800E+02, 0.38604700E+02, 0.32065700E+03, -.60135200E+02, 0.14440000E+03, -.15418500E+03, 0.11054700E+03, -.25314600E+03, 0.50395800E+03, -.24181600E+03, -.13706100E+03, -.25190000E+03, -.18900600E+03, -.22118400E+03, -.97809800E+02, 0.66848200E+02, -.13633500E+03, -.13287500E+03, -.10672500E+03, -.12865500E+04, 0.61638400E+03, 0.67367300E+03, 0.64331400E+03, 0.20408600E+03, 0.25480800E+03, 0.23486800E+03, -.28287800E+03, 0.46502600E+03, 0.19248500E+03, 0.49230500E+03, -.70460300E+03, 0.36164200E+03, 0.13616600E+03, 0.35251100E+03, 0.86329900E+01, -.24523300E+03, 0.37546400E+03, 0.29253300E+03, 0.31388300E+03, -.36287400E+02, 0.22305800E+03, 0.24617100E+03, -.12679100E+03, -.99454600E+02, -.12321300E+03, -.41242700E+02, 0.48238900E+03, -.71030300E+03, -.37500200E+03, -.51098300E+03, 0.38480100E+03, -.36809000E+02, 0.51228200E+01, -.52767600E+02, -.16555300E+02, -.25647300E+01, -.52334200E+02, -.48575600E+02, -.90920800E+02, -.12516400E+03, 0.10083600E+02, -.81607800E+02, 0.14755800E+03, -.21651100E+04, 0.10981800E+04, 0.18912800E+04, 0.10826900E+04, 0.19745000E+03, 0.26812600E+03, -.55030200E+02, -.16344200E+04, 0.11953400E+03, 0.11274000E+04, 0.82975300E+03, -.14152800E+04, 0.73054300E+03, -.50674200E+03, 0.70763200E+03, -.23674600E+03, -.40494500E+03, -.14053600E+03, -.58824900E+03, 0.74368500E+03, 0.64248000E+01, 0.25095300E+03, 0.68803600E+02, -.84535200E+01, -.11913700E+02, -.34365100E+02, 0.59110200E+02, 0.15148900E+03, -.11637400E+03, -.54020000E+02, -.10459100E+03, 0.96826200E+02, 0.13686300E+03, -.95917200E+02, 0.53501400E+02, -.12700900E+03, 0.48074400E+02, 0.46924900E+02, 0.14040100E+03, 0.58073800E+03, 0.34276700E+03, 0.21931400E+03, 0.20435800E+03, -.28300200E+03, 0.10251300E+02, 0.97462600E+01, 0.37145200E+02, -.52747800E+01, 0.82361500E+02, 0.17561200E+03, -.13676600E+03, -.38418300E+02, -.71524200E+02, 0.11148300E+03, 0.16466700E+03, -.62391500E+02, 0.40615700E+02, -.10707000E+02, 0.31157400E+02, 0.15528300E+03, 0.19989900E+03, -.59553500E+02, 0.16437700E+03, 0.15384300E+03, 0.36185400E+03, 0.15418700E+03, -.24892000E+04, 0.12610000E+04, 0.10729000E+04, 0.12450200E+04, 0.77527200E+02, -.24088000E+03, 0.86755400E+03, 0.26194400E+03, 0.10871100E+04, 0.26775000E+03, 0.74729400E+03, -.10732900E+03, 0.86373800E+02, -.47033200E+03, 0.53652100E+02, -.26048700E+03, -.40704100E+03, -.12585000E+02, -.20261200E+02, 0.31743500E+03, -.77395700E+02, -.23562400E+03, -.12056200E+04, 0.60229800E+03, 0.69679200E+02, 0.60281000E+03, 0.11504500E+03, 0.88842500E+02, 0.10279500E+03, -.13819100E+03, 0.50915400E+03, 0.12336900E+03, 0.37678600E+03, -.14043700E+04, 0.66495200E+03, 0.12638900E+04, 0.70219800E+03, 0.47890200E+03, 0.58227700E+03, 0.42829600E+03, 0.39555900E+02, 0.27211500E+03, 0.35257900E+03, 0.47130500E+03, -.21547600E+03, 0.86774200E+02, 0.22803800E+03, 0.10754500E+03, 0.15939600E+03, 0.29839500E+03, -.60978500E+03, -.47879000E+03, -.91848300E+02, 0.53350800E+02, 0.14674700E+03, 0.71419200E+02, -.74582600E+02, 0.40261500E+03, -.35233600E+02, -.13821200E+02, 0.37592000E+01, 0.34167400E+03, 0.32775400E+03, 0.67848200E+03, -.16519100E+03, 0.34682500E+03, 0.20989900E+02, -.21299000E+00, -.49650000E+02, -.54738100E+02, -.18580600E+02, 0.73784100E+01, 0.13043400E+03, -.94138500E+02, -.68400800E+01, -.28289000E+01, 0.54367500E+02, -.11075800E+03, 0.10520600E+02, -.48464600E+01, -.37799500E+02, 0.49391700E+03, 0.41405400E+02, -.12912200E+03, -.37680300E+02, 0.16855000E+02, 0.12802500E+03, -.30523100E+03, -.67307800E+03, 0.10510500E+03, 0.56135700E+02, 0.64281000E+01 },
        { -.41571800E+01, -.14748900E+00, -.20509800E+00, -.19999100E+00, 0.17935300E+01, 0.70205200E+00, -.10882500E+01, 0.85356100E+01, -.56547300E+00, 0.18805300E+01, 0.12370200E+01, 0.28410100E+00, 0.45806500E+00, -.28728400E+00, -.10208400E+01, 0.26549300E+01, -.50255100E+01, -.72877800E+00, -.91358100E+00, -.52505000E+00, 0.17393600E+01, 0.11989600E+01, -.35441400E+00, 0.11230300E+01, -.18310400E+00, -.67008100E-02, 0.54660100E-01, 0.29698900E+01, -.26086700E+01, -.13402300E+00, -.40556800E+00, 0.11095300E+01, -.58823000E-01, -.15599600E+01, 0.57837700E-01, -.37851400E+00, 0.29661700E-01, 0.58995100E+00, 0.34666100E+00, -.67332400E+00, 0.26192700E+01, 0.67222600E+00, -.10623500E+00, 0.20425000E+00, 0.64281700E-01, -.11819800E+01, 0.58444900E-01, -.17728000E-01, 0.33447300E+01, -.14022800E-01, -.13012600E+01, 0.20528600E+01, 0.90490300E+00, 0.20438400E+01, -.68962000E+04, -.10317000E+05, 0.52440000E+04, -.27205600E+04, 0.51595800E+04, -.30688700E+04, -.67652400E+04, 0.36927000E+04, -.31056000E+04, 0.47386800E+04, -.45965300E+04, -.68567300E+04, -.36652600E+04, 0.18409900E+04, 0.55069600E+04, 0.18323400E+04, 0.44734600E+04, 0.46176000E+04, -.25104700E+04, -.22271700E+04, -.13762300E+04, 0.28570600E+04, -.72767400E+04, -.76939900E+04, 0.37484400E+04, 0.63778300E+04, 0.38450800E+04, 0.49768600E+04, 0.26124500E+04, 0.12959100E+04, 0.46162000E+04, 0.31510000E+04, 0.57878400E+03, -.99914100E+03, 0.13134100E+05, -.64970600E+04, -.37259700E+04, -.65660800E+04, -.46923800E+04, -.25073500E+04, 0.21220200E+03, 0.22003600E+04, -.59292000E+04, -.15125100E+04, -.27688800E+04, -.35552000E+04, 0.16919800E+04, -.10119600E+04, 0.17780400E+04, -.40141500E+03, -.85839000E+03, -.17093400E+04, -.15257300E+04, 0.39040500E+04, -.62036900E+03, 0.16852900E+04, 0.46156100E+03, -.17031500E+03, -.52002600E+04, -.22829000E+03, 0.24477200E+04, 0.22416000E+04, -.10525200E+03, 0.87818300E+03, 0.61301700E+03, 0.21362300E+04, 0.75680500E+04, -.11653400E+05, 0.57224500E+04, 0.11876300E+05, 0.58250100E+04, 0.45875900E+04, 0.21372600E+04, 0.17727600E+04, 0.12373400E+04, 0.18245600E+04, 0.79271400E+03, 0.61005700E+03, 0.11159600E+04, -.76011400E+03, -.33993500E+03, -.55804200E+03, -.22190500E+04, -.11566400E+03, -.32585100E+03, -.18316200E+04, -.12046100E+04, -.11708800E+03, -.10441600E+04, 0.40988600E+05, -.20468600E+05, -.27297700E+05, -.20492800E+05, -.85154600E+04, -.86634000E+04, -.32848000E+04, 0.77047100E+04, -.10066100E+05, -.66514000E+04, -.48976200E+03, 0.57725400E+05, -.28782300E+05, -.26476200E+05, -.28862800E+05, -.38354700E+04, -.31647000E+04, -.12766500E+05, 0.12272000E+05, -.11981500E+05, -.48258600E+04, -.11845800E+05, 0.91925400E+01, 0.13698100E+03, 0.26150100E+04, -.44933300E+01, 0.52516700E+03, 0.11788500E+04, 0.61920700E+03, 0.21729600E+04, 0.47136300E+02, 0.11738700E+04, 0.82435000E+03, 0.24856100E+05, -.12370500E+05, -.12036400E+05, -.12424300E+05, -.83569200E+03, 0.56786900E+04, -.36288100E+04, 0.51331000E+04, -.66398200E+04, 0.46279700E+04, -.49065000E+04, -.85297300E+03, 0.51107400E+03, 0.15295900E+04, 0.42124100E+03, 0.12571600E+04, 0.16753800E+04, 0.51366900E+03, 0.17639300E+04, 0.86753200E+02, 0.15610600E+04, 0.25132000E+04, 0.72510000E+03, -.31271400E+03, -.14683000E+04, -.36310000E+03, 0.25413800E+04, 0.18576200E+04, -.42215000E+03, 0.54313300E+03, -.36674500E+03, 0.19501000E+04, 0.13263500E+05, 0.12166300E+05, -.60662900E+04, -.68537700E+04, -.60781000E+04, -.31808100E+04, -.18926200E+04, 0.57427400E+03, 0.70768700E+04, -.29970500E+04, -.25898300E+04, 0.10781400E+05, 0.30477700E+05, -.15123600E+05, -.12731600E+05, -.15239000E+05, -.21406900E+04, -.49149900E+03, -.73023400E+04, 0.64462200E+04, -.74003900E+04, -.19078700E+04, -.41836800E+04, 0.26162300E+05, -.13065700E+05, -.14143800E+05, -.13081200E+05, -.14134800E+03, -.24605500E+04, -.40302600E+04, 0.64147800E+04, -.58139000E+04, -.27802200E+04, -.10080600E+05, -.25524400E+05, 0.12651600E+05, 0.14938900E+05, 0.12762300E+05, -.49207100E+03, -.64173500E+03, 0.51268600E+04, -.55479500E+04, 0.74483800E+04, 0.64923600E+03, 0.37174300E+04, -.15908600E+05, 0.78403100E+04, 0.11367500E+05, 0.79520300E+04, 0.28664500E+04, -.15054800E+04, -.35399400E+03, -.50893900E+04, 0.39402800E+04, -.12444100E+04, -.43172700E+04, 0.19261400E+05, -.96632000E+04, -.70369000E+04, -.96248800E+04, -.11530200E+05, -.26842300E+04, -.23797800E+04, -.26956200E+04, -.75060400E+04, -.79794600E+03, -.84849200E+04, 0.21998200E+04, 0.54990300E+02, 0.10868400E+04, 0.10740500E+04, 0.97827700E+03, -.47568500E+03, 0.30001000E+04, 0.53110700E+04, 0.93947600E+03, 0.68317200E+03, 0.22435500E+04, 0.14442500E+04, 0.68578200E+03, -.69406600E+03, 0.20223100E+04, -.10710500E+04, -.11659900E+04, -.15454900E+04, 0.12251900E+04, -.14577400E+04, -.37838900E+03, 0.15350900E+04, 0.47374800E+04, -.78115400E+03, -.53994200E+03, -.80731500E+03 },
        { -.25619300E+00, -.48890100E+00, 0.27488500E+00, 0.47797200E+00, -.74296700E-01, 0.65216500E+00, -.12853100E+00, 0.60919600E-01, -.11476300E-01, 0.60841900E+00, -.89278000E-01, -.67009100E-02, -.16402100E+00, -.65145700E-01, 0.30292600E-01, -.31569500E+01, -.70164600E+00, -.39728700E+00, -.77090700E+00, -.79814400E-01, 0.52652500E+00, 0.98994900E-01, 0.59606400E-01, 0.17537300E+00, 0.54284600E-01, 0.38809400E-02, 0.12813800E+00, 0.42416500E+00, 0.27257500E+00, -.35668600E-01, 0.12866100E+00, 0.37622800E+00, -.25455100E+00, -.11785200E+01, 0.12645200E-01, 0.50911200E-01, -.34677300E-01, 0.28542600E+00, 0.61721600E-02, 0.17021200E+00, -.47333600E+00, -.67684400E-01, 0.22289300E-01, -.95530900E-02, 0.26390400E-01, -.47459200E+00, 0.47177700E-01, -.47360400E-01, -.69984100E+00, -.98212800E-01, -.63166600E+00, 0.95074000E-01, -.12208300E+00, -.15059900E+01, -.21511200E+00, -.84728000E+04, 0.43938400E+04, 0.28832900E+03, 0.42359400E+04, -.28519400E+03, -.39826900E+04, 0.32995000E+04, 0.11458100E+04, 0.54459200E+04, -.15898000E+04, 0.60868700E+04, -.68332300E+04, 0.33786400E+04, 0.60471400E+04, 0.34167400E+04, 0.13074800E+04, 0.16898900E+04, 0.69000100E+03, -.20707700E+04, -.40115300E+03, 0.21668600E+04, 0.41304000E+04, 0.43576300E+04, -.22982300E+04, 0.78592800E+03, -.21780300E+04, 0.13813500E+04, 0.25552600E+04, -.91112500E+03, 0.10233100E+04, -.36858400E+04, 0.93246800E+03, -.40362100E+04, 0.87547300E+04, -.42804400E+04, -.19844000E+04, -.43777500E+04, -.29333200E+04, -.33404200E+04, 0.31007300E+03, 0.19265400E+04, -.33779300E+04, -.30908800E+04, -.41344100E+04, -.39767400E+04, 0.19761500E+04, -.49145900E+03, 0.19881900E+04, 0.37430800E+03, 0.25628600E+03, -.10035000E+04, -.24352100E+02, 0.49433500E+04, 0.75881000E+02, 0.34037800E+04, -.25840300E+04, 0.13018000E+04, 0.12629800E+04, 0.12910100E+04, 0.16090900E+04, 0.19465800E+04, -.76406400E+02, -.46965000E+02, 0.12600000E+04, 0.18227400E+04, 0.13143800E+04, 0.61395400E+04, -.31659000E+04, -.58151800E+03, -.30689800E+04, -.55372900E+03, 0.12673800E+04, -.18707900E+04, -.88788400E+03, -.62693700E+04, -.41263300E+03, -.45075200E+04, 0.50835300E+03, -.31517700E+03, -.53982100E+03, -.25413400E+03, -.62827900E+03, -.13832600E+03, 0.25096400E+03, -.65908300E+03, -.90055300E+03, 0.77462000E+02, 0.68890200E+03, 0.22865000E+05, -.11332100E+05, -.19093100E+05, -.11433100E+05, -.40716200E+04, -.39250000E+04, -.45276700E+04, 0.33077000E+04, -.23983100E+04, -.50890900E+04, -.10675800E+05, 0.34483600E+05, -.17140700E+05, -.17987500E+05, -.17241800E+05, -.35825200E+04, -.38601000E+04, -.64667900E+04, 0.72107700E+04, -.63183700E+04, -.50768900E+04, -.15003300E+05, -.11823200E+04, 0.62315500E+03, 0.10740600E+04, 0.59123400E+03, 0.21322100E+03, 0.38237000E+03, 0.54587300E+02, 0.13567600E+03, 0.49846300E+02, 0.25683500E+03, 0.60738800E+03, -.28080700E+02, 0.55172000E+02, -.67523600E+03, 0.14104600E+02, 0.10616600E+04, 0.16211300E+04, 0.79795500E+03, 0.20933900E+04, 0.25867700E+04, 0.16110200E+04, -.10668300E+04, -.63366200E+03, 0.35043300E+03, 0.29127900E+03, 0.31676600E+03, 0.47643100E+02, -.11601300E+03, 0.20727500E+03, 0.31000200E+03, 0.18153500E+03, -.24109100E+03, 0.21903600E+03, -.26170800E+03, 0.17492400E+03, 0.42655500E+03, 0.13116200E+03, 0.62991700E+03, 0.16663900E+03, 0.13746600E+03, 0.60885300E+03, 0.96013500E+03, 0.37085500E+03, 0.84381000E+03, -.13672900E+04, 0.67896600E+03, -.23188100E+04, 0.68155400E+03, -.39501700E+03, 0.15964500E+03, 0.89716100E+03, 0.19321200E+04, 0.15179000E+04, -.99690100E+03, -.10374900E+04, 0.27168200E+05, -.13486800E+05, -.12085100E+05, -.13584100E+05, -.27566200E+04, -.28797900E+04, -.45275900E+04, 0.59962200E+04, -.56724200E+04, -.38818300E+04, -.12422600E+05, 0.60849500E+04, -.30294100E+04, -.52446800E+04, -.30424700E+04, 0.47071000E+02, -.54671100E+03, -.10204500E+04, 0.19950200E+04, -.48902100E+03, -.72944300E+03, -.28870100E+04, -.13714700E+05, 0.67923900E+04, 0.10502900E+05, 0.68573100E+04, 0.12091300E+04, 0.78992900E+03, 0.23990700E+04, -.16067600E+04, 0.42580000E+04, 0.17380400E+04, 0.75020200E+04, 0.32734700E+04, -.16981200E+04, 0.81822400E+03, -.16358200E+04, -.39579600E+02, -.29121800E+03, -.15240500E+04, -.12363700E+04, -.26244300E+04, -.49583900E+03, -.12605000E+04, 0.57337000E+04, -.27430700E+04, -.15083200E+04, -.28693800E+04, -.30698900E+04, -.24051500E+04, 0.14777500E+04, 0.24212300E+04, 0.10785200E+04, -.76434600E+03, 0.70115200E+03, 0.54768600E+03, -.26115400E+03, 0.22003000E+03, 0.24082500E+03, 0.33990400E+03, -.17621100E+03, 0.12118200E+03, 0.34976400E+04, 0.81753600E+02, 0.28553500E+02, 0.15659500E+04, 0.34125500E+02, -.63720600E+03, -.15205200E+03, 0.19534700E+04, 0.12116100E+04, -.30262900E+03, -.10666100E+04, 0.22622800E+03, -.20511000E+03, 0.15008100E+03, -.85809800E+03, -.21130900E+03, -.15146600E+03, -.22784300E+03, -.30453300E+03 },
        { -.25481200E+01, -.70667200E+00, 0.47445500E+00, 0.88235600E+00, 0.22275900E+01, 0.35381700E+00, 0.84220700E+00, 0.57024700E+00, 0.13322800E-02, 0.43498500E+00, 0.38107300E+00, 0.19397900E+00, 0.20646100E+00, -.43585400E-01, -.29480300E+00, 0.59653100E+01, 0.97503000E+00, 0.75792800E-01, 0.71729100E+00, 0.29416700E+00, -.44526800E+00, -.23090900E+00, 0.10952900E+00, -.38954400E+00, -.22652900E+00, -.57544600E-01, 0.15644800E+00, -.38638500E-01, -.35388400E+00, -.67903900E-01, -.68451400E+00, 0.15071000E+01, 0.21426400E+00, 0.52220000E+00, 0.23373900E-01, 0.35465400E-01, -.32742500E-01, -.96909300E+00, -.11908100E+00, -.33030900E-01, -.58459200E+00, -.20550000E+00, 0.12413400E+00, -.15800600E-01, 0.26586600E+00, 0.11656300E+00, 0.77895900E-01, 0.15972200E-01, -.14776100E+01, 0.18950400E+00, -.23410500E+00, 0.42534100E+00, -.57256100E+00, 0.62578300E+00, 0.25369400E+00, 0.15480200E+01, -.46382800E+03, 0.36930600E+04, 0.40583300E+00, 0.18398300E+04, 0.36466100E+04, -.19960500E+03, 0.60172500E+03, -.27803400E+04, 0.55555100E+03, -.89574500E+04, 0.18412100E+05, -.89186600E+04, -.26111700E+05, -.92061700E+04, -.70153900E+03, -.42158900E+04, 0.36721500E+03, 0.80130400E+04, 0.89612000E+03, -.48532900E+04, -.11534300E+05, -.38151900E+04, 0.22412300E+04, -.38091600E+04, 0.19069000E+04, -.18735900E+04, -.51956200E+04, 0.25293300E+04, 0.39394600E+03, 0.48684900E+04, -.28608700E+04, 0.72690900E+04, -.18650200E+05, 0.91026200E+04, 0.26068700E+04, 0.93254400E+04, 0.49588400E+04, 0.63037600E+04, -.89376700E+03, -.55638300E+04, 0.55386300E+04, 0.56443400E+04, 0.85748600E+04, 0.72812700E+04, -.39329500E+04, 0.69539900E+04, -.36404600E+04, 0.12978200E+03, 0.93056800E+02, 0.17310800E+04, 0.10350400E+04, -.85028400E+04, 0.81421500E+03, -.69679700E+04, -.50711500E+02, 0.99321900E+02, -.19573100E+04, 0.26213800E+02, -.26101800E+04, -.21154800E+04, 0.35352500E+03, -.45921000E+03, -.12463900E+04, -.24024300E+04, -.16926700E+04, -.43805200E+04, 0.24100600E+04, -.49736100E+04, 0.21895000E+04, -.80074300E+01, -.13128500E+04, 0.45601900E+03, -.12616200E+04, 0.66608000E+04, 0.12662300E+04, 0.92868900E+04, -.55675200E+03, -.27796600E+02, 0.14488800E+04, 0.27832700E+03, 0.57005900E+03, -.21876300E+03, -.47402700E+03, 0.25067100E+03, 0.82148000E+03, -.22164800E+03, -.19279600E+04, -.45114300E+05, 0.22021700E+05, 0.56481500E+05, 0.22557700E+05, 0.25578500E+04, 0.70886300E+04, 0.37360500E+04, -.15213800E+05, 0.88931800E+03, 0.88901600E+04, 0.23822800E+05, -.70271600E+05, 0.35157000E+05, 0.26294900E+05, 0.35135800E+05, 0.41019600E+04, 0.55370100E+04, 0.12570400E+05, -.18661400E+05, 0.96111600E+04, 0.79016500E+04, 0.32573200E+05, -.13769000E+04, 0.84729900E+03, 0.93526700E+03, 0.68850600E+03, 0.61401200E+03, 0.76173300E+03, -.27576300E+02, -.19075500E+04, -.86704000E+03, 0.88391100E+03, 0.32345400E+03, -.89226700E+04, 0.44070000E+04, 0.34381900E+04, 0.44590500E+04, -.20722200E+04, -.40521400E+04, 0.20125400E+04, -.89169700E+03, 0.73118800E+03, -.41363700E+04, 0.42288300E+04, -.27776800E+04, 0.13969900E+04, 0.22811400E+04, 0.13920700E+04, 0.56950800E+03, 0.97751600E+03, 0.29584700E+03, -.16158600E+04, -.24767900E+03, 0.11246700E+04, 0.46551000E+03, 0.14220300E+04, -.74712200E+03, -.30126000E+03, -.71133600E+03, 0.71150000E+02, 0.83808300E+03, 0.24211600E+02, 0.41499200E+03, -.89883100E+03, 0.16085400E+03, -.33741000E+04, -.57321800E+04, 0.29174800E+04, 0.89509500E+04, 0.28679300E+04, -.21522600E+04, -.16410000E+04, 0.10506800E+04, -.39680500E+04, 0.55675600E+03, 0.90957700E+02, 0.55612100E+04, -.54506800E+05, 0.27370500E+05, 0.15768900E+05, 0.27253400E+05, 0.35163500E+04, 0.37316200E+04, 0.94009700E+04, -.13851000E+05, 0.97516400E+04, 0.57672200E+04, 0.25537100E+05, -.18624800E+05, 0.92614400E+04, 0.12205400E+05, 0.93124100E+04, -.68106800E+03, 0.15795100E+04, 0.26816500E+04, -.56758500E+04, 0.23344200E+04, 0.16669400E+04, 0.91351400E+04, 0.15276700E+05, -.78287600E+04, -.14248600E+05, -.76382900E+04, 0.24600200E+04, 0.19274100E+04, -.31162500E+04, 0.45725900E+04, -.27634200E+04, 0.50971000E+03, -.12029000E+05, 0.34346600E+04, -.17281400E+04, -.49477900E+04, -.17181200E+04, 0.12637500E+04, 0.23935500E+04, 0.32314900E+03, 0.13586500E+04, 0.96449800E+03, 0.23929800E+04, -.50071400E+03, -.63805900E+04, 0.23948100E+04, 0.77542000E+04, 0.31926200E+04, 0.65457400E+04, 0.86914600E+04, -.27947500E+04, -.50675600E+04, -.23724600E+04, 0.62549400E+04, -.75846500E+04, -.78030700E+03, 0.93886400E+03, -.20785700E+03, -.20854500E+03, -.22522700E+03, -.37831800E+02, -.20428400E+04, -.55229000E+04, -.72293200E+03, 0.35188200E+03, -.20198300E+04, 0.32523500E+03, 0.44389500E+03, -.14601400E+03, -.29689800E+04, -.11029400E+04, 0.25093900E+03, 0.87558800E+03, -.19489200E+03, 0.78561200E+02, 0.25206200E+03, 0.27041700E+03, -.21116800E+04, -.19219600E+02, 0.90823600E+02, 0.94917500E+03 },
        { 0.55688900E+01, -.31412200E+00, -.45742700E+01, -.22229900E+01, -.18633600E+01, -.77637200E+00, -.15730500E+01, 0.10651600E+02, 0.11405700E+00, 0.29680300E+01, 0.82877900E+00, -.93978100E+00, -.54825600E+00, 0.10707800E+00, 0.77901300E-01, -.65122900E+01, -.47023300E+00, 0.69731300E-01, -.23700900E+01, 0.20421600E+00, 0.18845100E+01, 0.10589900E+01, -.14074400E+00, 0.10729100E+01, -.23652600E+00, 0.28037400E+00, 0.19082100E+01, 0.38720800E+01, -.39122600E+01, 0.61391700E-01, 0.23586400E+00, 0.18736600E+00, 0.12615800E+01, -.17539500E+01, 0.63212000E-01, -.12001500E+00, -.19389600E+00, -.19034100E+00, 0.12851500E+00, -.19058300E+01, 0.41350800E-02, 0.13719200E+01, 0.13606200E+00, 0.18793200E+00, -.67104400E+00, 0.47779500E+00, 0.70884300E-01, -.14381000E+00, 0.10711500E+01, 0.54937900E-01, 0.10603400E+00, -.97983200E+00, 0.61963200E+00, 0.22012000E+01, 0.11084300E+01, 0.42365700E+01, 0.17094100E+01, 0.28444700E+05, -.25958200E+01, 0.69191700E+04, 0.87683300E+04, -.36837000E+04, -.67667000E+04, -.10053300E+05, 0.55399200E+04, -.29627600E+05, -.55316900E+05, 0.27491400E+05, 0.15596800E+05, 0.27659100E+05, 0.16429600E+04, -.59899800E+03, 0.91934800E+04, -.10335200E+05, 0.22807900E+05, 0.30132600E+04, 0.11628400E+05, 0.99399500E+04, -.46742900E+04, -.21423700E+05, -.49654300E+04, -.61540100E+04, -.12086100E+04, -.51450500E+04, -.62938100E+04, -.24028800E+03, 0.20977500E+04, 0.16435700E+05, -.35039400E+05, 0.17181300E+05, 0.11956700E+05, 0.17517500E+05, 0.66899600E+04, 0.69044800E+04, 0.54514400E+03, -.69183700E+04, 0.95196700E+04, 0.66634000E+04, 0.16336200E+05, 0.20170700E+05, -.90883100E+04, 0.23200600E+03, -.10086400E+05, -.17921800E+04, -.34197000E+04, 0.26654600E+04, 0.39967600E+04, -.12847900E+05, -.36604800E+04, -.17257500E+05, -.16058300E+05, 0.76601800E+04, 0.11077400E+04, 0.80232200E+04, -.80754800E+03, -.18706300E+04, 0.23939900E+04, -.35673100E+04, 0.43346500E+04, -.16626500E+04, -.71053200E+03, -.95131500E+04, 0.50150300E+04, -.17388100E+05, 0.47602800E+04, -.24022600E+04, -.25813700E+04, 0.50040900E+04, 0.62970800E+04, 0.18791800E+05, -.45691900E+03, 0.23112700E+05, -.37626200E+04, 0.36993000E+04, 0.56905500E+04, 0.18814000E+04, 0.39750500E+04, -.11403600E+04, -.71530500E+03, 0.73564200E+03, 0.12823000E+04, -.89154400E+03, -.66737900E+04, 0.27120600E+05, -.13449400E+05, 0.86523600E+04, -.13563900E+05, 0.25542600E+04, 0.35653100E+04, -.20017500E+04, 0.85431900E+04, -.21314900E+05, 0.11653500E+04, 0.94977000E+04, -.83327900E+05, 0.40688700E+05, 0.22162400E+05, 0.41664200E+05, 0.12090500E+05, 0.20075800E+05, 0.10462100E+05, -.15389300E+05, 0.17877100E+05, 0.17244600E+05, 0.51849400E+05, 0.36931900E+01, -.10136000E+04, -.51216000E+04, -.27994100E+01, 0.50996400E+03, 0.36618000E+03, -.14686400E+04, -.20672700E+04, -.16624000E+04, 0.65571200E+03, 0.13558600E+04, 0.20381400E+05, -.10438400E+05, 0.65052700E+04, -.10196500E+05, -.59939700E+04, -.43767200E+04, -.70970000E+04, -.42050300E+04, -.16253000E+05, -.47345300E+04, -.29719200E+04, -.98535500E+03, -.71381400E+01, -.34790000E+04, 0.50343900E+03, 0.10461900E+04, 0.27022800E+04, -.19619100E+04, -.19002700E+04, -.74189500E+03, 0.27842900E+04, 0.27191100E+04, -.88579800E+04, 0.40831300E+04, 0.44328100E+04, 0.44300600E+04, -.15398200E+04, 0.37200700E+04, 0.15203100E+04, -.51499700E+03, 0.46301800E+04, 0.26796900E+04, -.15168900E+04, 0.34347900E+05, -.17510100E+05, -.20495600E+05, -.17185900E+05, 0.17457200E+04, 0.35283900E+04, -.99960300E+04, -.11007300E+04, -.13216900E+05, 0.35757600E+04, -.64700900E+04, -.63133400E+05, 0.30257300E+05, 0.11859500E+05, 0.31567100E+05, 0.84791000E+04, 0.13259900E+05, 0.68211100E+04, -.12122100E+05, 0.15669000E+05, 0.11200600E+05, 0.39979100E+05, -.24633100E+05, 0.12342800E+05, 0.97987000E+04, 0.12316600E+05, 0.24335300E+04, 0.44300600E+04, 0.34666800E+04, -.61693700E+04, 0.40134700E+04, 0.42967700E+04, 0.13642800E+05, 0.36030800E+05, -.16678800E+05, -.11178300E+05, -.18015800E+05, -.52798800E+04, -.93575600E+04, -.35354500E+04, 0.73280100E+04, -.10275600E+05, -.99895600E+04, -.35581600E+05, -.20108600E+05, 0.10815500E+05, -.86573000E+04, 0.10059700E+05, 0.20854400E+04, 0.77129100E+03, 0.72047700E+04, 0.12216900E+04, 0.12950300E+05, 0.19375300E+04, 0.10489800E+05, -.34733900E+05, 0.18745000E+05, 0.38073200E+05, 0.17353400E+05, 0.16124800E+05, 0.14064700E+04, 0.19975500E+04, -.67719800E+04, -.20390000E+04, -.36699100E+03, -.24706600E+05, -.38472500E+04, 0.22562400E+03, -.12141300E+04, -.13935400E+04, -.15394300E+04, 0.10111500E+04, -.26050500E+04, -.32786900E+04, -.14254800E+04, 0.10319300E+02, -.50992400E+04, -.24109000E+04, 0.25903000E+04, 0.11629400E+03, -.27683800E+04, -.50388800E+04, 0.13521300E+04, 0.64506700E+04, -.10735500E+04, 0.14223400E+04, -.18249500E+03, 0.16552400E+04, 0.10884500E+05, 0.34852000E+02, 0.18598200E+04, 0.94316400E+03 },
        { 0.22137200E+01, 0.13307100E+01, -.81060200E+00, -.11959900E+01, -.81687200E+00, -.18664400E+01, -.55420700E+00, -.20537200E+01, 0.29748400E+00, -.50152500E+00, -.61781000E+00, -.74392900E-01, -.51405500E+00, 0.65146000E-01, 0.78333400E+00, -.52047300E+01, -.16321000E+01, -.17072100E+01, -.98767900E+00, -.13553600E+00, 0.18089600E+01, 0.26229200E+00, 0.12051400E+00, 0.72156500E+00, 0.28356800E+00, 0.19612200E+00, 0.31205300E+00, 0.18610400E+01, -.53479100E+00, -.89888300E-01, -.52349400E-01, 0.49448500E+00, 0.41337900E-01, -.19418200E+01, -.10813400E-01, -.30605900E-02, -.17712600E-01, -.44319900E+00, -.13705500E+00, 0.19882400E+00, 0.69579900E+00, -.32893200E+00, -.10296600E+00, 0.12406600E-01, -.24492700E+00, -.11652900E+00, 0.36285000E-01, -.36737100E-02, 0.13296400E+01, 0.12110400E+00, -.23790300E+00, 0.56656400E+00, -.51795800E+00, 0.20987200E+01, 0.34767300E+00, 0.12210900E+00, 0.32819900E+00, 0.54948400E-01, 0.19175600E+02, -.25593300E+02, 0.27631300E+04, -.16917700E+04, -.21034100E+04, -.16888900E+04, 0.23414800E+04, -.10881300E+04, -.13149000E+05, 0.64482000E+04, 0.10980100E+05, 0.65745700E+04, -.11183100E+04, -.20760300E+04, 0.22096800E+04, -.38222500E+04, 0.41230900E+04, -.59611800E+03, 0.47163300E+04, 0.13674400E+04, -.69754700E+03, 0.71351800E+03, -.68325400E+03, -.10853300E+04, -.16253500E+04, -.90658700E+03, -.22457000E+04, -.20523100E+03, -.84156800E+03, 0.94701200E+03, -.29076500E+04, 0.14622200E+04, 0.27983200E+04, 0.14536000E+04, 0.11335600E+04, 0.17009700E+04, -.13652100E+03, -.22580000E+03, 0.15652100E+04, 0.13376900E+04, 0.97573700E+03, 0.78344300E+03, -.26986100E+03, -.41842500E+04, -.39183400E+03, -.12219200E+03, 0.12563300E+03, 0.48203600E+03, -.33178200E+03, -.21984200E+04, 0.35733600E+03, -.53759300E+03, 0.19696500E+04, -.10348400E+04, 0.25034600E+04, -.98541600E+03, -.63154200E+03, -.70847800E+03, -.28665600E+03, -.22543000E+03, -.33550000E+03, -.96571400E+03, -.17023400E+04, -.13547900E+04, 0.72859400E+03, 0.27988300E+04, 0.67786400E+03, 0.13705500E+03, -.57840700E+03, 0.75198000E+03, 0.44124400E+03, 0.13955200E+04, -.13011200E+03, 0.20599300E+03, -.11772800E+04, 0.69038700E+03, -.18036000E+03, 0.58866400E+03, 0.85072000E+03, 0.84489600E+03, -.80433100E+01, 0.46920600E+03, 0.72842900E+03, 0.54761800E+03, 0.17760900E+02, -.46497500E+04, 0.25384400E+04, -.69516400E+04, 0.23245000E+04, 0.33869400E+04, 0.44654400E+04, 0.18686000E+04, 0.40328700E+04, 0.21940000E+04, 0.27904300E+04, 0.28083600E+04, -.18416100E+05, 0.91453100E+04, 0.13164600E+05, 0.92080900E+04, 0.23903700E+04, 0.34663100E+04, 0.34022700E+04, -.25620100E+04, 0.53253500E+04, 0.27509300E+04, 0.67601400E+04, 0.29988800E+04, -.15341600E+04, -.23233800E+04, -.14994700E+04, -.44182900E+03, -.57935300E+03, -.73173400E+03, 0.11489000E+03, -.55585200E+03, -.51760000E+03, -.72273300E+03, -.17339700E+04, 0.82412400E+03, -.91770200E+03, 0.86360500E+03, -.66138900E+03, -.33875900E+04, 0.19290800E+03, -.17135200E+04, -.29544700E+03, -.26824300E+04, 0.29925300E+04, 0.28582100E+04, -.14337800E+04, -.19450700E+04, -.14293500E+04, -.42992600E+03, -.29068900E+03, -.93169500E+03, -.13792200E+03, -.72066100E+03, -.22714900E+03, -.31884600E+03, -.16943000E+04, 0.82300500E+03, 0.63678900E+03, 0.84733400E+03, -.51923300E+03, -.46524500E+03, -.13408300E+01, -.99630300E+03, 0.11741700E+03, -.22647600E+03, 0.27085900E+03, 0.10375000E+05, -.51724500E+04, -.51483900E+04, -.51887500E+04, 0.21816200E+04, 0.26512800E+04, -.30021400E+04, -.27262100E+02, -.30117600E+04, 0.15430200E+04, -.42880400E+04, -.96285700E+04, 0.47132700E+04, 0.89951000E+04, 0.48143200E+04, 0.11998700E+04, 0.18033100E+04, 0.14452000E+04, -.18054100E+04, 0.28951800E+04, 0.13109900E+04, 0.34646600E+04, -.96001400E+04, 0.48166600E+04, 0.35568400E+04, 0.48000800E+04, 0.96790700E+03, 0.13117800E+04, 0.14469600E+04, -.20840300E+04, 0.24801800E+04, 0.13214000E+04, 0.37018500E+04, 0.11829100E+05, -.58354900E+04, -.61391600E+04, -.59145900E+04, -.18307000E+04, -.21153100E+04, -.22149600E+04, 0.15257400E+03, -.59039200E+04, -.13905300E+04, -.53385400E+04, -.97282400E+03, 0.55955900E+03, 0.86545100E+03, 0.48695300E+03, -.81722900E+03, 0.60268200E+03, 0.11799000E+04, 0.17626200E+04, 0.10388800E+04, 0.48941400E+03, -.31681500E+02, -.48862700E+04, 0.25706400E+04, -.49381300E+04, 0.24416300E+04, 0.28435800E+04, 0.17404100E+04, -.32727100E+03, 0.28023800E+03, 0.98299100E+03, 0.98218300E+03, 0.13764700E+04, -.65366900E+03, -.10744100E+03, 0.50037400E+02, 0.40082000E+02, -.42732500E+02, 0.68948400E+01, -.84978600E+03, -.32516200E+04, -.83212500E+02, -.18573000E+03, -.87219200E+03, -.13607000E+02, -.20708500E+03, 0.93916200E+01, -.12550700E+04, -.36251400E+03, 0.11997300E+01, 0.51440000E+03, 0.63473000E+02, 0.34808000E+02, -.10306600E+04, -.15338600E+03, 0.62042100E+03, 0.12423500E+03, -.13242900E+03, 0.50481600E+03 },
        { -.21640100E+01, 0.70699700E-01, 0.61782700E-01, -.11967000E+00, 0.14839500E+01, 0.37740100E+00, 0.56202600E-01, 0.38441700E+01, -.31088300E+00, 0.73027700E+00, 0.88436100E+00, 0.23676300E+00, 0.64539500E+00, -.57207800E-01, -.57808700E+00, 0.10929900E+01, 0.10246400E+01, 0.17646000E+00, -.31309100E+00, 0.55854400E-01, -.12914900E+00, -.46374100E-01, 0.13151200E-01, 0.74924200E-02, -.10748900E+00, -.12273900E-01, 0.21376600E+00, 0.20760100E+00, -.22420400E+00, -.35125600E-01, -.88661500E-01, 0.95659300E+00, -.22909000E+00, 0.14870800E+01, 0.32373400E-01, 0.15786500E+00, -.40146000E-01, -.11153700E+01, 0.37530200E-02, -.68015500E+00, -.12556800E+01, 0.61740300E-01, 0.13618100E+00, -.67867500E-01, -.30040800E+00, 0.34113100E+00, -.43487700E-01, -.18640400E-01, -.88199900E+00, 0.95316500E-01, -.41319300E-01, 0.17272400E+00, -.81164200E+00, 0.12139600E+01, -.10209800E+00, 0.29110500E+00, 0.26360800E+00, 0.84994000E-01, -.24027400E-01, -.21683100E+04, -.10787000E+04, -.15643800E+03, -.83037600E+02, 0.82938700E+03, -.75404700E+03, 0.78852300E+03, -.15767700E+04, 0.72105100E+03, 0.80408900E+04, 0.78850700E+03, -.10678600E+04, -.16034200E+04, 0.82102800E+03, -.76045500E+03, -.97663300E+01, -.14001100E+04, -.27748200E+03, -.30636400E+04, 0.14710700E+04, 0.38882600E+04, 0.15326300E+04, 0.13559000E+04, 0.14460100E+02, 0.70144500E+03, -.25409800E+03, 0.48116200E+03, -.73973100E+02, 0.68524600E+02, 0.38014700E+04, -.18363400E+04, 0.17947700E+04, -.19011300E+04, -.90122300E+03, -.20817600E+03, -.20450000E+03, 0.23182900E+03, -.22830200E+04, -.15611500E+03, -.21193800E+04, -.91770300E+03, 0.40342600E+03, -.52268300E+04, 0.45865600E+03, 0.55560000E+03, 0.60071700E+03, -.46667700E+03, -.17965900E+03, 0.11381800E+04, 0.87181600E+03, 0.16969300E+04, 0.12860200E+04, -.61717100E+03, 0.32583400E+04, -.64404600E+03, 0.35455200E+03, 0.38662000E+03, -.35711800E+03, 0.83977500E+02, -.32468200E+03, 0.15769400E+03, -.16262200E+04, -.13310800E+04, 0.66352800E+03, 0.15482700E+04, 0.66628600E+03, 0.10813700E+04, 0.74704000E+01, 0.53048800E+03, -.72044400E+03, -.11153800E+04, 0.10439400E+03, -.71755700E+03, -.20154400E+03, -.10449900E+03, -.53071100E+03, 0.10080100E+03, -.27082500E+03, 0.69044800E+03, -.18920700E+03, -.35190600E+03, -.16271600E+03, 0.44952600E+03, 0.75188800E+03, -.36888700E+04, 0.19991300E+04, -.14099500E+05, 0.18437800E+04, 0.29145600E+04, 0.41252900E+04, -.94476400E+03, -.25026000E+03, 0.16993500E+04, 0.35924800E+04, 0.31070000E+04, -.20898300E+04, 0.11624300E+04, 0.42877500E+04, 0.10449600E+04, 0.14256100E+04, 0.25255600E+03, 0.22494700E+03, -.11242800E+04, 0.11493800E+03, 0.69003200E+03, -.50581300E+03, 0.64488200E+03, -.19286100E+03, -.43284400E+03, -.32259400E+03, 0.17302600E+03, 0.21171800E+03, -.20898000E+03, 0.46635000E+03, -.34241900E+03, 0.15886000E+03, -.18576200E+03, -.13396800E+03, 0.69402000E+02, -.45868400E+03, 0.66800800E+02, 0.14780100E+04, 0.78520400E+03, 0.31132400E+03, 0.94945800E+03, 0.51416700E+03, 0.68547300E+03, -.27546100E+03, -.36327600E+03, 0.25879400E+03, -.32673200E+03, 0.18183100E+03, 0.17992700E+03, 0.14058100E+03, -.62229100E+02, 0.11723000E+03, -.97405200E+02, 0.66969800E+02, 0.17518100E+03, -.71528800E+03, 0.39332800E+03, 0.12222200E+04, 0.35789600E+03, -.40722800E+03, -.12368500E+04, 0.31695500E+03, -.15789700E+03, 0.66881800E+03, -.97783300E+03, -.20704700E+03, -.40654400E+04, 0.20971600E+04, -.16123000E+02, 0.20305800E+04, 0.16557100E+04, 0.11868900E+04, 0.10457800E+04, 0.22016100E+03, 0.13738400E+04, 0.68693400E+03, 0.59441100E+03, -.14738300E+04, 0.86957600E+03, 0.54482700E+04, 0.73697900E+03, 0.89877400E+03, 0.45038100E+03, -.51624800E+02, -.11769700E+04, -.66139000E+03, 0.64151600E+03, -.58056700E+03, -.31754400E+04, 0.16044400E+04, -.24042000E+03, 0.15877300E+04, 0.77585800E+03, 0.31645100E+03, 0.47423300E+03, -.64783000E+03, 0.10507600E+04, 0.44857800E+03, 0.58742100E+03, 0.59735500E+04, -.31406900E+04, 0.66811400E+02, -.29868500E+04, -.16802100E+04, -.14261100E+04, -.59984400E+03, 0.79030400E+03, -.20434400E+04, -.90883800E+03, -.15372500E+04, -.11463300E+03, -.20922100E+01, -.13038600E+04, 0.58270400E+02, -.11373900E+04, -.12177100E+04, 0.23283900E+03, -.14751100E+03, 0.16824200E+03, -.11613100E+04, 0.30193200E+03, 0.42780400E+04, -.22465000E+04, -.44287300E+04, -.21415500E+04, -.29205400E+04, -.28944000E+03, -.69052100E+03, 0.13582400E+03, -.42578600E+03, -.26298000E+03, 0.58987000E+03, 0.55353000E+03, -.16632300E+02, 0.46224600E+03, 0.47959800E+03, 0.37193800E+03, -.13249600E+03, 0.60865200E+03, -.26347900E+04, 0.25335900E+03, 0.20103500E+03, 0.53252000E+03, 0.28177800E+03, -.10895700E+03, -.25124800E+03, -.12584700E+04, -.71700500E+03, -.49422200E+03, -.44026000E+03, 0.49305100E+03, -.13132500E+03, -.55339700E+03, 0.86695900E+03, 0.49714800E+02, -.23133000E+03, -.20537000E+03, -.98007200E+02 },
        { -.60027900E+01, 0.30242700E+01, 0.17848200E+01, -.18489900E+01, 0.24110700E-01, -.18049700E+01, -.12255300E+01, -.32858800E+01, -.15877800E+01, -.14854300E+01, 0.14934200E+00, 0.19142600E+00, 0.19319900E+01, -.52916700E-01, -.24442700E+00, -.26960600E+00, 0.11648300E+02, 0.18635200E+01, 0.87073900E-01, 0.22014300E+00, 0.27943700E+00, -.90642900E+00, -.33288400E+00, 0.19334700E+01, -.46685000E+00, 0.92686100E-01, 0.11071300E+01, 0.20765200E+01, -.26837400E+01, 0.67558700E-01, 0.10147200E+01, -.11826900E+01, -.98223200E+00, -.24299400E+01, 0.11639000E+00, -.38135900E-01, 0.71334500E-01, 0.26916100E+01, 0.58947200E+00, 0.51038900E+00, 0.10774300E+01, -.38668800E+00, -.29992000E+00, 0.46638700E-01, -.53160300E+00, -.13196800E+01, 0.57109000E-01, -.54149800E-01, 0.86576500E-01, -.42210600E+00, -.83227400E-02, 0.55280600E+00, 0.89077400E+00, -.54557000E+00, -.46378500E+00, -.88217900E+00, -.20127200E+01, 0.53697000E-01, 0.96679500E-02, -.20745500E+01, 0.78678600E+04, -.15706800E+04, -.41608400E+03, -.24489700E+04, 0.51041200E+04, -.45907000E+04, -.36259300E+03, 0.15290100E+03, 0.97382700E+03, 0.18149500E+03, 0.14021700E+04, -.25718900E+04, 0.25771000E+04, 0.35776400E+04, 0.65684500E+04, -.23741700E+04, -.12120100E+04, -.27800300E+04, 0.13813900E+04, 0.37760400E+04, 0.13913900E+04, 0.95201100E+03, -.43924100E+04, 0.13498400E+04, -.11792100E+04, 0.32339200E+04, -.29513800E+04, 0.60256800E+04, -.19253800E+05, 0.96067200E+04, 0.61575300E+04, 0.96262500E+04, 0.30400300E+04, 0.64865200E+04, -.44942700E+03, -.65938600E+04, 0.22604900E+04, 0.59900600E+04, 0.79774600E+04, 0.16322700E+05, -.81695000E+04, -.51827000E+04, -.81616700E+04, -.11459800E+04, -.16880200E+04, 0.10976300E+04, 0.51959300E+04, -.74190300E+04, -.36538800E+03, -.95567200E+04, -.72137100E+04, 0.36116300E+04, 0.14788900E+04, 0.36050300E+04, -.22766700E+04, -.16554100E+04, 0.87030200E+03, -.10651600E+04, 0.24073800E+04, -.20798600E+04, 0.39677500E+04, 0.76221100E+04, -.38486200E+04, -.35991100E+04, -.38100000E+04, 0.20846500E+03, -.26872500E+04, -.11665700E+04, -.14654100E+04, -.17306900E+04, -.72323500E+03, 0.22487600E+04, -.27934300E+04, 0.13775800E+04, 0.49385100E+03, 0.13967300E+04, 0.79815000E+03, 0.91472500E+03, 0.88323700E+02, 0.44246800E+03, 0.11649500E+04, 0.85563700E+03, -.92857900E+03, -.34831700E+05, 0.17399300E+05, 0.15846900E+05, 0.17414800E+05, -.11203600E+04, 0.42872000E+04, 0.26608400E+04, -.12256300E+05, -.35499900E+04, 0.49879800E+04, 0.16946600E+05, -.53594700E+05, 0.26715300E+05, 0.30815700E+05, 0.26797400E+05, -.24475500E+03, 0.50171800E+04, 0.76943000E+04, -.19134900E+05, 0.13176400E+04, 0.55251800E+04, 0.27304600E+05, -.59142000E+04, 0.30724400E+04, 0.63106000E+04, 0.29569600E+04, 0.17794100E+04, 0.19453800E+04, -.18885200E+03, -.38772700E+04, -.29716800E+04, 0.22679500E+04, 0.14778900E+04, -.15744800E+05, 0.79013900E+04, 0.77014600E+04, 0.78684100E+04, 0.24430000E+04, -.35970900E+04, 0.29548600E+04, -.12409800E+04, 0.39858800E+04, -.31021100E+04, 0.60254300E+04, -.65154800E+04, 0.33030600E+04, 0.57985600E+04, 0.32632500E+04, 0.11417800E+04, 0.11852000E+04, 0.40367500E+03, -.35085300E+04, -.18112900E+04, 0.15371000E+04, 0.95582900E+03, 0.11823000E+04, -.60317600E+03, 0.22805600E+04, -.59088100E+03, 0.43288700E+03, 0.42393500E+02, -.45652200E+03, -.16278100E+04, -.16134700E+04, -.31596700E+03, -.18280000E+04, -.27323200E+04, 0.13778500E+04, -.10104300E+04, 0.13625200E+04, -.35421600E+04, -.28373200E+04, 0.18537400E+04, -.15900300E+04, -.33999500E+03, -.16920200E+04, 0.35325300E+04, -.46542800E+05, 0.23234400E+05, 0.24286900E+05, 0.23271500E+05, 0.68065800E+03, 0.33702700E+04, 0.65060400E+04, -.15359300E+05, 0.38900800E+04, 0.40466500E+04, 0.22153300E+05, -.15936900E+05, 0.79380500E+04, 0.11418700E+05, 0.79684700E+04, -.90562800E+03, 0.16880100E+04, 0.19767700E+04, -.56189700E+04, 0.91327700E+03, 0.13943300E+04, 0.81925800E+04, 0.23144000E+05, -.11542000E+05, -.11885000E+05, -.11572100E+05, 0.32898000E+04, 0.39381100E+03, -.26727800E+04, 0.79755100E+04, -.30249700E+04, 0.85820600E+03, -.15678700E+05, 0.14377300E+05, -.72357800E+04, -.59523500E+04, -.71869600E+04, -.16283600E+04, 0.13352600E+04, -.80091200E+03, 0.32490300E+04, -.16800400E+04, 0.72166800E+03, -.51667600E+04, -.93103100E+04, 0.46238100E+04, 0.47942000E+04, 0.46511500E+04, 0.85159800E+04, 0.11342900E+05, -.19240900E+04, -.40329500E+04, -.31189000E+04, 0.97934600E+04, -.70665200E+04, -.14607000E+04, 0.48957200E+03, 0.81076200E+03, 0.83759700E+03, 0.33689900E+03, -.45355800E+03, -.45175400E+04, -.37316500E+04, -.37014000E+03, 0.43536300E+03, -.18828800E+04, 0.26271200E+03, -.10614400E+04, -.43684700E+03, -.21612300E+04, -.10552800E+04, -.86532500E+03, -.39479100E+03, 0.76998900E+03, -.34682200E+03, 0.88006200E+03, -.23184100E+03, 0.32521700E+03, 0.16885600E+03, -.64784900E+03, 0.17384700E+04 },
        { -.17116200E+01, 0.65247900E+00, 0.16076000E+01, 0.35235700E+00, 0.12382700E+01, 0.12873100E+00, -.97672000E-02, 0.50511900E+00, -.44643900E-01, 0.71953400E+00, -.18328100E+00, -.17090700E+00, -.12839100E+00, -.16440700E+00, 0.61414100E+00, -.35136900E+01, -.29728000E+01, -.17905700E+01, 0.25834700E-01, 0.37111600E+00, 0.66887100E+00, -.15958500E+00, 0.78164900E-01, -.39095000E-01, 0.84620700E-02, -.45421000E-01, 0.12318100E+00, -.16412400E+00, -.21061700E+00, -.80464300E-01, -.30963300E+00, -.41213600E+00, 0.21908200E+00, -.19676000E+01, -.29046600E-01, -.11313300E+00, 0.24520700E-01, 0.53071200E+00, 0.10169600E-01, 0.36548400E+00, -.36018300E+00, -.15562200E+00, -.79201900E-01, -.51637500E-01, 0.51126100E-02, 0.16240400E+00, 0.12810500E-01, 0.27330500E-01, 0.89190600E+00, -.45856500E-01, 0.41906800E+00, -.12995600E+00, 0.45957900E+00, -.40407400E+00, 0.92229400E-01, 0.52495800E+00, 0.16086800E+00, 0.15160600E+00, 0.58498100E-01, -.24238800E-01, -.75455700E-01, 0.10427100E+04, 0.14778500E+04, 0.75498100E+03, -.18743500E+03, 0.10495500E+04, 0.12225100E+05, -.60637000E+04, -.83593100E+04, -.61128300E+04, -.71843000E+02, 0.79453600E+03, -.19615400E+04, 0.38892900E+04, -.26234100E+04, -.43109100E+03, -.28088200E+04, -.93724200E+03, 0.50005000E+03, -.14294000E+03, 0.46677700E+03, 0.30839400E+03, -.57214900E+03, 0.54867500E+03, 0.13596700E+04, 0.73225500E+03, -.82074400E+03, -.15815400E+03, 0.26772300E+03, -.18563600E+03, -.20167100E+04, -.13295200E+03, -.92407000E+02, -.18600600E+03, -.12347000E+03, 0.22850700E+03, -.27085000E+03, -.13514600E+03, 0.21710900E+03, -.12147500E+04, 0.62404700E+03, 0.41395100E+04, 0.60781100E+03, 0.36666100E+03, 0.20210100E+03, 0.35699600E+03, 0.17671300E+03, 0.12482200E+04, 0.29209200E+03, -.97792900E+03, -.19228100E+04, 0.96088900E+03, -.18573100E+04, 0.96377600E+03, -.16680500E+03, 0.16465400E+03, 0.27903100E+03, -.38264400E+03, -.49511500E+02, 0.20224900E+03, 0.28505900E+04, 0.39063100E+04, -.19798000E+04, -.27939600E+04, -.19549000E+04, -.12585200E+03, 0.24559100E+03, -.20360300E+04, 0.15230800E+02, -.16609700E+04, -.13586000E+02, -.91159000E+03, 0.33810200E+03, -.53611300E+02, 0.69999000E+02, -.16913000E+03, -.13650700E+03, -.10280000E+03, -.10433600E+03, 0.10389100E+03, -.24085500E+03, 0.46371000E+02, 0.24386200E+03, -.11278700E+05, 0.55025400E+04, 0.12175900E+05, 0.56408400E+04, -.51092200E+03, -.22514500E+04, 0.17891700E+04, -.46700100E+04, 0.15148300E+04, -.59411300E+03, 0.76075300E+03, -.91685000E+03, 0.34187700E+03, -.74782600E+03, 0.45833700E+03, -.11230900E+04, -.16196700E+04, -.22422300E+01, -.11563000E+03, -.12997800E+02, -.11792700E+04, 0.53030800E+03, -.25192700E+04, 0.11992600E+04, 0.19438200E+04, 0.12597500E+04, 0.42907100E+03, 0.51070900E+03, 0.28439300E+03, -.43400900E+03, 0.18310900E+03, 0.47921400E+03, 0.86675900E+03, -.16584300E+04, 0.85149900E+03, 0.21020600E+04, 0.83074900E+03, 0.43412800E+03, 0.62892900E+03, 0.99671800E+03, 0.14269500E+03, 0.64053900E+03, 0.67140200E+03, -.72910800E+03, -.17463400E+04, 0.83765300E+03, 0.14575400E+04, 0.87241900E+03, 0.31707400E+03, 0.25846100E+03, 0.32656900E+03, -.10520400E+03, 0.12675100E+03, 0.19162400E+03, 0.34473600E+03, 0.10918600E+04, -.56710000E+03, 0.16961100E+02, -.54655600E+03, 0.65194800E+03, 0.94157000E+03, -.60965000E+03, 0.80866200E+02, -.78625700E+03, 0.48777500E+03, 0.42785200E+03, -.54141800E+04, 0.26740400E+04, 0.29690300E+04, 0.27119900E+04, -.17483300E+04, -.21340100E+04, 0.18200100E+04, -.38915000E+03, 0.19857300E+04, -.14002600E+04, 0.32502200E+04, -.31691400E+04, 0.14839100E+04, -.10212700E+04, 0.15844400E+04, -.54689000E+03, -.11928600E+04, 0.79826000E+03, -.31923500E+03, 0.65258600E+03, -.70917200E+03, 0.12921900E+04, 0.21990000E+04, -.11267400E+04, 0.15079600E+04, -.10995200E+04, -.41205500E+03, -.32525100E+03, -.57761600E+03, 0.35093000E+03, -.83398000E+03, -.44076200E+03, -.46117400E+03, -.55660600E+04, 0.28960800E+04, 0.16348000E+04, 0.27831800E+04, 0.23232600E+04, 0.27458900E+04, 0.49129700E+03, -.40965000E+03, 0.26013100E+04, 0.24816300E+04, 0.15674500E+04, 0.14967300E+04, -.74507600E+03, 0.19493000E+03, -.75053500E+03, 0.53066100E+03, 0.72405400E+03, -.14368200E+04, -.81162700E+03, -.63512000E+03, 0.51683000E+03, -.48675100E+03, 0.47892400E+02, 0.28961800E+02, 0.44185700E+04, -.18133800E+02, 0.84052800E+03, 0.20344700E+04, -.48177500E+03, -.51771400E+03, 0.20662000E+03, 0.20749200E+04, 0.62454400E+03, -.10982300E+03, 0.18206900E+03, 0.34745500E+02, 0.29260000E+02, 0.75817500E+02, -.15606600E+03, -.73710000E+03, 0.13631700E+04, -.96547800E+02, 0.14569100E+03, 0.52617000E+03, 0.16884600E+03, -.40190800E+03, -.61809200E+02, 0.58608400E+03, 0.88129300E+03, -.69745800E+02, -.46261700E+03, 0.24336400E+02, -.16477700E+03, 0.57414500E+03, -.65118000E+03, -.11472700E+04, 0.56672000E+02, -.15052100E+03, 0.18610000E+03 },
        { 0.39334400E+01, -.49370600E+00, -.71478400E+00, -.21453400E+01, -.17611500E+01, -.61419100E+00, -.10515100E+01, 0.69479800E+01, 0.35623500E+00, 0.23730400E+00, 0.33158600E+00, -.47779200E+00, -.80227500E+00, 0.28926600E+00, -.10652400E+01, 0.88616700E+01, 0.40043900E+01, 0.10339200E+01, -.98370000E+00, 0.84740300E+00, 0.15128500E+01, 0.12503000E+00, -.14085600E+00, 0.68262400E-01, 0.15388800E+00, 0.38223400E+00, 0.15128400E+01, 0.12912800E+01, -.25781900E+01, 0.31669400E+00, -.64872500E+00, -.12168200E+01, 0.20160000E+01, 0.12494800E+01, 0.65165700E-01, -.86767800E-01, -.24689800E+00, -.82602800E+00, -.13389800E-01, -.13649200E+01, 0.15233800E+01, 0.85568400E+00, 0.72917500E-01, 0.11295000E+00, -.68203400E+00, 0.33146600E+00, -.73895500E-02, -.20685900E+00, 0.42915900E+00, -.39836000E-01, -.17237000E+00, 0.52431400E+00, -.12318700E+00, 0.22346000E+01, -.11760800E+00, 0.67748800E+00, 0.71563300E+00, -.20549400E+00, -.23092200E+00, -.17869600E+00, 0.27537200E+00, -.20129300E+01, -.30654400E+04, -.12936800E+04, 0.13850900E+04, 0.53126800E+04, -.31102500E+04, 0.14440400E+04, -.46548100E+02, 0.15557000E+04, -.78268600E+03, 0.30309900E+04, -.24814400E+04, -.15157100E+04, 0.88129800E+02, 0.26973100E+04, 0.90146000E+04, 0.27436000E+04, -.12395400E+04, -.37745500E+04, -.13679500E+04, -.82557500E+03, 0.38943200E+04, -.32597600E+04, -.95328700E+03, -.14611400E+04, 0.27628400E+04, -.17166700E+04, 0.60346400E+04, -.32072900E+04, -.35184800E+04, -.30192100E+04, -.18011400E+04, -.35160800E+04, 0.42433700E+03, 0.32165400E+04, -.46978300E+03, -.33029500E+04, -.19122400E+04, -.40604600E+04, 0.25543800E+04, 0.42664900E+04, 0.20293100E+04, 0.16893400E+04, 0.71476300E+03, 0.33212200E+02, -.57334400E+03, 0.41174300E+04, 0.14584700E+01, -.22347100E+04, -.11674000E+04, 0.41535300E+03, -.59844300E+04, 0.57871700E+03, -.11831300E+04, -.17387800E+04, 0.35620700E+02, -.23796800E+04, -.36726100E+03, -.60845900E+03, 0.62670400E+04, 0.29980700E+04, -.13878700E+04, -.24318600E+04, -.14956800E+04, 0.39699400E+03, 0.82665600E+03, -.15062800E+04, 0.47042000E+04, 0.11113100E+04, -.11456000E+04, -.45266200E+04, -.14895600E+01, 0.97326800E+03, 0.86458800E+03, 0.85814000E+00, 0.50900100E+03, -.95795600E+03, 0.19793100E+03, 0.12456100E+04, 0.46262700E+03, -.67643100E+03, 0.29524000E+03, 0.15075600E+05, -.74632600E+04, -.35079200E+04, -.75408800E+04, -.49122700E+03, -.65589000E+04, 0.21063300E+04, 0.40728500E+04, -.29419400E+04, -.60585500E+04, -.17525500E+05, 0.16608900E+05, -.89165900E+04, -.13438800E+05, -.83042700E+04, -.43859700E+03, 0.33999100E+03, -.60801500E+04, 0.56226600E+04, 0.75116700E+03, -.16250500E+04, -.76577000E+04, 0.40800500E+02, -.55366100E+03, -.94853200E+03, -.21119200E+02, 0.23935300E+03, 0.50374900E+03, -.59178700E+03, 0.94570800E+03, 0.36839900E+02, 0.33830100E+03, 0.96745100E+03, 0.98203900E+04, -.50242900E+04, -.92491300E+03, -.49100100E+04, -.37473200E+04, 0.53073800E+02, -.17794000E+04, -.31501600E+04, -.45917000E+04, 0.82165900E+03, -.86792200E+03, 0.11472100E+04, -.82106000E+03, -.15070300E+04, -.56973000E+03, 0.44181400E+03, 0.76396800E+03, -.81691700E+03, 0.91094700E+03, -.30865400E+03, 0.32853900E+03, 0.10198300E+04, -.32661800E+03, -.21485100E+02, -.22454000E+03, 0.16438800E+03, 0.15363200E+04, 0.33714500E+04, -.10627300E+04, -.40025300E+03, -.97610400E+03, 0.22827900E+04, 0.38256800E+04, 0.12310200E+05, -.63154700E+04, -.80445200E+04, -.61652700E+04, -.12316900E+04, -.38072300E+03, -.40739600E+04, -.61345400E+03, -.29997300E+04, -.26164700E+03, -.22612600E+04, 0.11903600E+05, -.67180400E+04, -.10305100E+05, -.59515100E+04, -.10253600E+04, -.25536200E+03, -.39823900E+04, 0.36923000E+04, -.49806300E+03, -.17386700E+04, -.52482000E+04, 0.84608400E+04, -.42254200E+04, -.46084300E+04, -.42303700E+04, 0.81355800E+03, -.33939400E+03, -.18412300E+04, 0.21529800E+04, -.18180700E+04, -.62202100E+03, -.32566200E+04, -.61381300E+04, 0.38352200E+04, 0.64303700E+04, 0.30687400E+04, 0.11034300E+04, 0.89943900E+03, 0.18136400E+04, -.39952600E+03, 0.25425300E+04, 0.58479300E+03, 0.98779500E+03, -.11136300E+05, 0.59461900E+04, 0.63359600E+04, 0.55727100E+04, 0.39972000E+04, 0.23957700E+04, -.14048600E+03, -.21896400E+03, 0.27929400E+04, 0.17709900E+04, 0.80901700E+03, -.65710000E+04, 0.40399900E+04, 0.11540100E+05, 0.32737300E+04, 0.52159900E+04, -.27388800E+04, 0.23846200E+04, 0.57323300E+04, 0.22116800E+04, -.21516800E+04, 0.18096300E+04, -.70777400E+03, -.43726800E+03, -.68461400E+03, -.73905500E+03, -.59891700E+03, 0.23384000E+03, 0.88873000E+02, 0.43995000E+04, 0.10875400E+03, -.28210700E+03, 0.10833800E+03, -.93369400E+03, 0.88810300E+02, 0.44844200E+03, 0.25723200E+04, 0.14413700E+04, 0.64182000E+03, 0.11422900E+04, -.61560900E+03, 0.19060600E+03, 0.86254800E+03, -.16568700E+04, 0.19485200E+04, 0.66394300E+03, 0.65736600E+03, -.51434200E+03 },
        { 0.34773100E+01, 0.74096400E+00, 0.50552800E+01, 0.47922900E+01, -.62438300E+00, -.68118100E+00, -.45011300E+00, -.45409300E+00, -.14660000E+00, 0.10234200E+01, -.36893000E+00, -.20381300E+00, 0.96599400E-01, 0.77827600E-01, 0.42266000E-01, -.10317800E+02, 0.10747500E+01, 0.13756100E+00, -.11265100E+01, -.12780400E+00, 0.13916400E+01, -.62838200E-01, 0.80415500E-01, 0.35555100E+00, 0.83857400E-01, 0.58505900E-01, 0.62431400E+00, 0.61903000E+00, -.21341300E+01, 0.39926400E-01, 0.55962400E-02, -.10720600E+01, 0.53216900E+00, 0.71620200E-01, -.41607000E-03, -.24202800E-01, 0.57697800E-01, 0.90329900E+00, 0.66942600E-01, 0.30963900E-01, 0.31444200E+01, 0.84148400E+00, -.16476000E+00, 0.10811100E+00, -.34930400E+00, 0.84336000E+00, -.10090300E-02, 0.11062500E-01, 0.10926300E+01, 0.69289400E-01, 0.69186300E+00, 0.19336700E+01, -.10399500E+01, 0.23058200E+01, 0.66447700E+00, -.83559700E+00, 0.71770400E+00, 0.18361900E+00, -.65275300E-01, -.30254200E+00, -.17815800E+00, -.10480100E+01, -.14038700E-01, 0.29693400E+04, 0.18852200E+04, 0.77273700E+04, -.25638900E+04, 0.11458200E+04, 0.68322900E+03, 0.12820700E+04, -.27627100E+04, -.41708900E+03, -.10901700E+04, -.12985400E+04, -.60796500E+03, -.64011300E+03, 0.10680800E+05, 0.49006900E+04, -.24841500E+04, -.21001100E+04, -.24495500E+04, -.81979300E+03, -.39451900E+04, -.82313000E+03, 0.10461600E+04, -.35583200E+04, -.45215200E+04, -.75076500E+04, 0.10330400E+05, -.51295900E+04, 0.15328100E+04, -.51655700E+04, -.17861100E+04, -.20120200E+04, 0.80871400E+03, 0.39138500E+04, -.32800700E+04, -.23812500E+04, -.48919000E+04, -.88011500E+04, 0.44348200E+04, -.33847800E+04, 0.44003800E+04, 0.14319600E+04, 0.13184400E+04, -.33882600E+03, -.25319300E+04, 0.61313300E+04, 0.16465700E+04, 0.31146200E+04, 0.10119300E+04, -.52392000E+03, 0.52375600E+04, -.50695900E+03, 0.17468000E+04, 0.30526900E+04, -.16074000E+04, -.46539500E+03, 0.64599300E+03, 0.20712500E+04, 0.50237700E+04, 0.81605600E+04, -.40239500E+04, -.47181300E+04, -.40794300E+04, -.17839900E+04, 0.18798200E+03, -.28655600E+04, -.10501800E+04, -.11237500E+05, -.93410900E+03, -.95758600E+04, 0.16986800E+04, -.92078100E+03, 0.98761400E+03, -.84929300E+03, -.45355600E+03, 0.18479500E+04, -.92070300E+03, -.13201200E+04, -.13477800E+04, 0.15398800E+04, 0.20777600E+04, 0.17895900E+04, -.62262800E+03, -.71697700E+04, -.89542700E+03, 0.34648200E+04, -.70321400E+02, 0.37306900E+04, 0.65358400E+04, 0.55260700E+04, -.22413600E+03, -.18317600E+05, 0.13030900E+05, -.65097100E+04, -.19535400E+03, -.65154000E+04, -.25174100E+04, -.44915700E+04, 0.10339900E+04, 0.89264900E+04, 0.23188900E+04, -.46393900E+04, -.15989800E+05, 0.49526500E+04, -.23717400E+04, -.59636700E+04, -.24763200E+04, -.25165200E+03, -.24026600E+03, -.86628400E+03, 0.15076500E+04, -.82644900E+03, -.46176000E+03, -.39024800E+03, -.18150900E+05, 0.90328800E+04, 0.53910100E+04, 0.90781000E+04, -.42115100E+03, -.48129500E+04, 0.47852400E+04, -.11347500E+04, 0.11388700E+05, -.36501200E+04, 0.99160900E+04, 0.44047300E+04, -.21244500E+04, -.60202200E+04, -.22045300E+04, -.38730300E+03, -.60215600E+03, -.79574300E+03, 0.14048400E+04, -.77943000E+03, -.97260900E+03, 0.59609300E+02, -.46964900E+04, 0.23520600E+04, -.62761400E+03, 0.23485800E+04, 0.69482900E+03, 0.21728300E+03, 0.90461900E+03, 0.79160600E+03, 0.13435100E+04, 0.11585400E+03, 0.52390100E+04, 0.32870900E+04, -.15900800E+04, 0.98334800E+03, -.16456600E+04, 0.25610700E+04, 0.20688000E+04, -.11068900E+04, 0.26010200E+03, 0.47828500E+03, 0.13576800E+03, -.23962200E+04, 0.16358300E+05, -.81956300E+04, -.11330200E+03, -.81790700E+04, -.25466600E+04, -.40907300E+04, -.32916200E+03, 0.68259700E+04, -.15150200E+04, -.39901500E+04, -.14417800E+05, 0.64768000E+03, -.28654000E+03, -.83228500E+04, -.32383100E+03, 0.70166600E+03, -.20771000E+03, 0.17551000E+03, 0.16415400E+04, 0.17087600E+04, -.15454100E+03, -.18427200E+04, -.53632800E+04, 0.26512900E+04, 0.27526200E+04, 0.26815800E+04, 0.96130300E+03, 0.10309200E+04, -.37246400E+03, -.44636000E+04, -.61303400E+03, 0.28134700E+04, 0.80970000E+04, 0.70156800E+04, -.34767600E+04, -.64458300E+04, -.35069300E+04, -.40691900E+03, 0.20976100E+04, -.20112800E+04, 0.14668200E+04, -.51430400E+04, 0.15591300E+04, -.52210000E+04, 0.92770500E+04, -.46341100E+04, -.60876500E+04, -.46411400E+04, -.27265200E+04, 0.46791300E+04, -.27034700E+04, 0.27639900E+03, 0.14336200E+04, 0.48809000E+04, 0.11171300E+05, 0.58687500E+03, -.71251400E+02, 0.64272900E+03, 0.68684300E+03, 0.86626100E+03, -.60954300E+03, -.20985800E+04, -.49909100E+03, -.35706500E+03, 0.52835700E+03, 0.22620300E+04, 0.78695200E+03, -.28697700E+04, -.64653500E+03, 0.48856300E+03, 0.19960200E+04, -.72571900E+03, -.13687400E+04, 0.73560500E+03, -.81673900E+03, -.18514700E+04, -.13813800E+04, -.37570500E+04, -.24158000E+03, -.86726700E+03, 0.45061300E+03 },
        { 0.11078400E+01, 0.97717400E+00, -.76594100E+00, -.12078500E+01, -.34082100E+00, -.12911800E+01, -.65680000E+00, 0.76909000E+00, 0.18859900E-01, 0.59603800E-01, -.10424100E+00, -.22095700E+00, -.19017000E+00, 0.30368600E-01, 0.19816600E+00, 0.44518600E+00, -.11467300E+00, -.50544700E+00, -.59205100E-01, 0.19774900E+00, 0.68402100E+00, -.24453500E-01, -.30840000E-01, 0.11740100E+00, 0.33858300E-01, 0.19087200E-01, -.54964900E-02, 0.42135700E+00, -.29635000E+00, 0.15122100E-01, 0.41453900E-01, -.17908200E+00, 0.10141800E+00, 0.15411200E+01, -.14503400E-01, 0.31197500E-01, -.13487000E-01, -.68483500E+00, -.68382500E-01, 0.94671600E-01, 0.10250700E+01, -.29536400E+00, -.86707600E-01, 0.10306700E-02, 0.27309300E+00, 0.50776500E-01, 0.38814600E-01, 0.44360500E-01, 0.22629700E+01, 0.85736200E-01, 0.33921500E+00, 0.80138400E-01, -.43003800E-01, 0.23127800E+01, 0.21863000E+00, -.38072900E+00, 0.40265700E+00, 0.17253500E-01, 0.22821000E-01, 0.35054400E+00, 0.60714600E-01, -.58182600E+00, 0.17840400E+00, 0.57744100E+00, -.12983100E+04, -.21032000E+04, 0.72029500E+04, -.35376600E+04, -.15229600E+04, -.36019900E+04, 0.44464100E+03, -.35502100E+03, -.97473300E+03, 0.14408700E+04, -.17974500E+04, -.86435100E+03, -.55267700E+04, -.16362300E+04, 0.82523000E+03, 0.12561100E+04, 0.81475800E+03, 0.64452700E+02, 0.67260500E+03, 0.50347200E+03, 0.33001400E+03, 0.16700100E+04, 0.11676500E+04, 0.25211300E+04, -.20620200E+04, 0.10191300E+04, -.17491000E+04, 0.10326700E+04, 0.93737000E+03, 0.10454200E+04, -.58699500E+03, -.87081000E+03, 0.10323200E+04, 0.11746700E+04, 0.12451000E+04, 0.35401700E+04, -.18244700E+04, 0.16204000E+04, -.17692900E+04, -.11075100E+04, -.74429100E+03, 0.50524900E+03, 0.74608400E+03, -.18367000E+04, -.77855400E+03, -.12405400E+04, 0.17189800E+04, -.83939900E+03, -.26245800E+04, -.85515100E+03, -.88227500E+03, -.13612900E+04, 0.49293800E+03, -.14266600E+03, -.18009900E+04, -.11606100E+04, -.26555200E+04, -.19547400E+03, 0.59565100E+02, 0.10818900E+04, 0.94671100E+02, 0.32338100E+03, -.53781000E+03, 0.62746200E+03, 0.16884000E+04, 0.45239400E+04, 0.98800000E+02, 0.18809500E+04, -.72935400E+03, 0.33586100E+03, -.81530900E+03, 0.36455600E+03, 0.26136500E+03, -.42753100E+03, 0.37556400E+03, 0.52258300E+03, 0.72549900E+03, -.48661500E+03, -.41013400E+03, -.92511600E+04, 0.44890700E+04, 0.55517200E+04, 0.46282700E+04, -.44951200E+02, 0.10145500E+04, 0.12662300E+04, -.20455200E+04, 0.11140700E+04, 0.18380000E+04, 0.85632800E+04, -.14109800E+04, 0.71278600E+03, -.16543000E+04, 0.70532500E+03, 0.14990800E+04, 0.82332400E+03, -.17671900E+03, -.96709600E+03, -.86777900E+03, 0.14412600E+04, 0.25078700E+04, 0.43664300E+03, -.22834700E+03, 0.15132700E+04, -.21798000E+03, -.54619300E+03, -.68007400E+03, 0.38317000E+03, 0.75590300E+02, 0.68041500E+03, -.54953400E+03, -.68348100E+03, 0.68392100E+04, -.33858400E+04, -.13196700E+04, -.34173700E+04, 0.51498000E+03, 0.22491700E+04, -.19638400E+04, -.96733100E+03, -.56756100E+04, 0.20734100E+04, -.36485000E+04, 0.10334600E+04, -.53471900E+03, 0.14547600E+04, -.51979600E+03, -.38064000E+03, -.35497500E+03, 0.52708200E+02, 0.34099900E+02, 0.37627400E+03, -.12921200E+03, -.77356100E+03, 0.28692200E+04, -.14266700E+04, 0.28102200E+03, -.14356500E+04, -.35073100E+03, -.19069700E+03, -.82014500E+03, -.52783900E+03, -.78751300E+03, -.12129300E+03, -.23030400E+04, -.35668600E+04, 0.17720200E+04, 0.28745100E+03, 0.17923400E+04, -.56073200E+03, -.36286200E+03, -.42996700E+02, -.15458100E+04, -.92636100E+03, 0.48141200E+03, 0.16631400E+04, -.41741000E+04, 0.21250700E+04, -.12484200E+04, 0.20868100E+04, 0.14208100E+04, 0.11822000E+04, 0.71723000E+02, -.14795900E+04, 0.15884600E+03, 0.15538900E+04, 0.35922900E+04, 0.15676300E+04, -.80974000E+03, 0.39722500E+04, -.78385500E+03, -.29317100E+03, -.23096800E+03, -.33572700E+03, -.12155800E+03, -.92424500E+03, -.17116500E+03, -.42002300E+03, 0.22792300E+04, -.11588700E+04, -.16897300E+04, -.11393400E+04, -.10637200E+04, -.96734300E+02, -.19466300E+03, 0.26764100E+00, 0.64553200E+03, -.92977700E+03, -.17193000E+04, -.37869700E+04, 0.18459600E+04, 0.36692600E+04, 0.18895100E+04, -.28093000E+02, -.83318800E+03, 0.66650600E+03, 0.18031700E+03, 0.30713000E+04, -.66341300E+03, 0.25779800E+04, -.22196700E+04, 0.10546300E+04, 0.10781100E+04, 0.11202700E+04, 0.50969600E+03, -.87834500E+03, -.18146100E+03, -.81776900E+03, -.13478000E+03, -.13476500E+04, -.21155500E+04, -.14449800E+03, 0.51206000E+00, -.24735200E+03, -.28966900E+03, -.24498200E+03, 0.14469500E+03, 0.42167500E+03, -.99422600E+03, 0.20403400E+03, -.25956500E+03, -.58582400E+03, 0.80872100E+01, 0.90023500E+03, 0.21154800E+03, -.66777900E+03, -.10632400E+04, 0.35766800E+03, 0.48996300E+03, -.32192300E+03, 0.24132500E+03, 0.69011800E+03, 0.10834900E+04, 0.12330600E+04, 0.63480700E+02, 0.27546200E+03, -.97396900E+02 },
        { -.22971400E+01, 0.19508700E+00, -.12726200E+00, -.54291300E+00, 0.18622800E+01, -.80398100E-01, -.48062600E+00, 0.47138200E+01, -.41551400E+00, 0.11149400E+01, 0.85520700E+00, 0.94112800E-02, 0.76530800E+00, -.11262500E+00, -.17325100E+00, -.54270800E+01, -.30018200E+01, -.87365200E+00, -.94857200E+00, -.19534800E+00, -.30560700E+00, -.20283300E+00, 0.10741600E+00, -.10012600E+01, 0.67738000E-01, -.60332800E-02, -.55294600E+00, -.14221600E+01, 0.15175900E+01, -.10263700E+00, 0.27787400E+00, 0.98557000E+00, -.76464900E+00, -.58195200E+00, 0.43640500E-01, 0.18683800E+00, -.72503300E-01, -.65075700E+00, -.25216900E-01, 0.37259600E+00, -.25057700E+01, -.50431000E+00, 0.95223200E-01, -.12606200E+00, 0.21864200E+00, 0.34883500E-01, -.51915800E-01, -.31731100E-01, -.27853300E+00, 0.26150700E-01, 0.23968700E+00, -.45584400E+00, -.36642200E+00, -.19736600E+01, -.30236400E+00, -.80144600E+00, -.67207500E+00, -.15421000E+00, -.45639100E-01, 0.10577800E+00, -.20505100E-01, -.15605700E+00, -.19586800E+00, -.40303300E-01, 0.53909700E+00, -.36972600E+04, -.99252200E+04, 0.49202700E+04, 0.81593300E+03, 0.49631900E+04, -.15125000E+04, -.93961400E+03, 0.20878200E+04, -.12739300E+04, 0.38915000E+04, -.65016200E+03, 0.28322300E+04, 0.76839100E+03, -.35666000E+03, -.19558200E+04, -.38041000E+03, -.13994200E+04, -.14721300E+04, -.45373600E+03, -.11976200E+04, -.10559700E+04, -.96047300E+03, 0.20142300E+04, -.17561400E+04, 0.84717400E+03, 0.22473900E+04, 0.87620500E+03, 0.91056700E+03, 0.14700700E+04, -.19544400E+03, -.67560500E+02, -.87530400E+02, 0.10602100E+04, 0.55053600E+03, -.25927500E+04, 0.14208800E+04, -.61053700E+03, 0.12954800E+04, 0.10207700E+04, 0.49588800E+03, 0.32363400E+03, -.75569800E+03, 0.47372300E+03, 0.53353000E+03, 0.11390400E+03, -.24206600E+04, 0.11649600E+04, 0.44942000E+04, 0.12054300E+04, 0.84755000E+03, 0.13768000E+04, -.34689100E+03, -.46804500E+03, 0.84355400E+03, 0.10180500E+04, -.41796600E+03, -.21708100E+04, 0.11261800E+04, 0.87249900E+03, 0.10888500E+04, -.49193900E+03, 0.51887400E+03, -.78390000E+02, -.40968200E+03, -.81436000E+03, 0.75753400E+03, 0.37418900E+04, -.44045300E+03, 0.42296000E+03, 0.60546400E+03, 0.22035800E+03, 0.45270200E+03, 0.47454800E+03, -.36521600E+03, -.16285300E+03, -.41079700E+03, 0.41577900E+03, -.60441200E+03, 0.36808000E+04, -.17756700E+04, 0.25917900E+04, -.18434400E+04, 0.35967700E+04, 0.25409800E+04, -.64067500E+03, 0.18320100E+04, -.15554300E+04, 0.22020100E+04, 0.56032900E+03, -.19159000E+05, 0.94745200E+04, 0.94285800E+04, 0.95796700E+04, 0.16511200E+04, 0.21465600E+04, 0.43870600E+04, -.73358900E+03, 0.64778200E+04, 0.21893400E+04, 0.96660400E+04, -.61025000E+03, 0.20801000E+03, -.13564600E+04, 0.30470900E+03, 0.30747500E+03, 0.10154200E+03, -.16626500E+03, 0.34214500E+02, -.16580500E+03, 0.10465500E+03, 0.22024300E+03, -.49683400E+04, 0.24473800E+04, -.96372600E+03, 0.24806900E+04, -.13560100E+04, -.34378200E+04, 0.16613400E+04, -.51903000E+03, 0.28921300E+04, -.30372200E+04, 0.23125400E+04, -.23670100E+04, 0.11465000E+04, -.30685200E+03, 0.11887800E+04, 0.48032200E+03, 0.42112200E+03, 0.15767700E+03, 0.27277700E+02, 0.44970500E+03, 0.35328300E+03, 0.78241000E+03, -.56965700E+04, 0.28118800E+04, 0.10828800E+04, 0.28494400E+04, 0.33639600E+02, 0.24058000E+03, 0.10863800E+04, 0.22672000E+03, 0.26499900E+04, 0.16392200E+03, 0.14347800E+04, 0.60892700E+04, -.30715100E+04, 0.86549900E+03, -.30546800E+04, 0.13389600E+04, 0.11813700E+04, -.30939800E+03, 0.10927500E+04, -.12138000E+04, 0.82556600E+03, -.22388500E+04, -.11385200E+05, 0.55402500E+04, 0.63638600E+04, 0.56928500E+04, 0.87278300E+03, 0.81279000E+03, 0.28897100E+04, -.20690200E+03, 0.41821900E+04, 0.10049200E+04, 0.58823900E+04, -.74133100E+04, 0.37191300E+04, 0.64481200E+02, 0.37067000E+04, 0.79815400E+03, 0.10585900E+04, 0.11454000E+04, -.10162300E+04, 0.23523400E+04, 0.10807400E+04, 0.35355000E+04, 0.30978400E+04, -.14012000E+04, -.33369800E+04, -.15492300E+04, 0.14482300E+03, -.76741900E+03, -.13198300E+04, -.35421300E+03, -.23625300E+04, -.46237500E+03, -.41596900E+04, 0.48731600E+03, -.14697900E+03, -.20276400E+04, -.23917400E+03, 0.35911200E+03, 0.15283500E+04, -.14615700E+03, 0.90995700E+02, -.54686600E+03, 0.13137400E+04, 0.40898400E+03, -.33588000E+04, 0.18503700E+04, -.27378700E+04, 0.16676500E+04, 0.13127400E+04, 0.95536000E+03, 0.28936800E+03, -.89113600E+03, 0.18705600E+04, 0.66852500E+03, -.25872700E+04, -.44847700E+03, 0.10656800E+03, 0.92937200E+02, 0.90356800E+02, 0.11298800E+02, 0.40318500E+02, 0.29714500E+02, -.14475200E+04, -.32730700E+03, 0.18836100E+03, 0.13700500E+03, -.18797500E+03, -.16860000E+03, -.13783100E+03, -.75578200E+03, 0.28591700E+02, -.11196600E+03, 0.33529800E+03, 0.13793500E+03, 0.76925600E+02, -.10377800E+04, -.24248100E+03, -.18748100E+03, -.92055200E+02, 0.51073800E+02, 0.43581400E+03 },
        { -.10760000E+01, -.22556000E+00, 0.45102500E+00, 0.46245600E+00, -.15814000E+00, 0.38208600E+00, 0.23855100E+01, -.23518100E+01, -.62525000E-01, -.14095300E+01, 0.11676700E-01, 0.39402300E+00, 0.33005300E+00, 0.33008500E-01, -.32218300E+00, 0.64907500E+01, -.29552600E-02, 0.42227300E+00, 0.16749500E+01, 0.57919700E-01, -.57994200E+00, -.14440800E+00, 0.11590200E+00, 0.71310800E+00, -.15144000E-02, -.43778200E-01, -.11128000E+00, 0.38904500E+00, 0.31944200E+00, 0.24162300E-01, -.59557100E+00, -.34976400E+00, 0.60916100E-01, 0.83488300E-01, 0.40562100E-02, 0.58377500E-02, 0.35061600E-01, 0.45543300E+00, -.65179700E-01, 0.15474600E+00, -.30463200E+00, 0.32996500E-01, 0.18358300E-01, 0.62559200E-01, 0.46582100E-01, -.17619100E+00, 0.27744900E-01, 0.14808300E-01, -.50017200E+00, -.59961300E-02, 0.43592900E-01, -.40942900E+00, 0.82409000E-01, -.11033700E+00, -.11108300E+00, -.27114200E+00, -.31866200E+00, -.39536900E-01, 0.10527300E-01, 0.21081600E-01, 0.23051300E-01, 0.41553000E+00, -.22295000E-01, -.19224500E+00, -.19527500E+00, 0.39657500E+00, 0.73357300E+04, -.36165600E+04, -.28985900E+04, -.36681000E+04, 0.84758300E+03, 0.38730700E+03, -.14960300E+04, 0.82818300E+03, -.24791700E+04, -.16434900E+02, -.23043000E+04, -.63225400E+03, 0.31687600E+03, 0.10984200E+04, 0.31457200E+03, 0.81927700E+03, 0.45318600E+02, 0.42615100E+03, 0.58617000E+03, 0.84404400E+03, -.15143200E+03, 0.16269500E+03, 0.83857700E+03, -.41700800E+03, -.92076800E+03, -.41852500E+03, -.36276000E+03, -.26252600E+03, 0.24569000E+02, -.79979300E+02, 0.42985200E+02, -.18124800E+03, -.55904000E+03, 0.61725100E+03, -.36823300E+03, 0.56724100E+03, -.30825300E+03, -.31203400E+03, 0.87655800E+01, -.31865000E+03, -.19300500E+03, -.69580600E+03, 0.10659000E+03, -.14427500E+03, 0.61249100E+03, -.28152100E+03, -.11853900E+04, -.30423600E+03, -.80854300E+02, -.19793500E+03, 0.37383700E+03, 0.83166000E+03, -.20599200E+03, -.17917700E+03, -.18510900E+03, 0.12338200E+03, -.86572700E+02, 0.48077300E+02, -.63067900E+02, 0.51756600E+03, -.25091800E+03, -.91631900E+02, -.43452500E+03, 0.59745300E+03, -.32626700E+03, 0.20049100E+03, 0.11070300E+03, -.13566400E+03, -.15921000E+03, -.55398400E+02, -.22311900E+03, 0.84851200E+02, -.32450900E+02, -.25629500E+03, 0.15589300E+03, 0.57237200E+02, 0.16288700E+03, -.38399300E+04, 0.18390000E+04, 0.73058300E+03, 0.19212100E+04, -.17194300E+04, -.10094900E+04, 0.41863600E+03, -.16433300E+04, 0.77226000E+03, -.47906000E+03, 0.43097200E+03, 0.59519100E+04, -.29332100E+04, -.34207100E+04, -.29760400E+04, -.82284600E+02, -.10251000E+04, -.13942600E+04, -.28457200E+03, -.25464600E+04, -.71785900E+03, -.34217800E+04, 0.48351600E+01, 0.34656400E+02, 0.92255000E+03, -.21194000E+01, -.14412200E+03, -.79149700E+02, 0.28319800E+03, 0.63755300E+02, 0.40331500E+03, -.12842500E+03, 0.12338100E+03, 0.24183700E+04, -.11910900E+04, -.23557200E+03, -.12083600E+04, 0.30946700E+03, 0.12682800E+04, -.31287500E+03, 0.85817200E+03, -.10508700E+04, 0.10029300E+04, -.14201700E+04, 0.13070200E+03, -.59112200E+02, 0.61396000E+03, -.67275300E+02, -.13327100E+03, -.20337500E+03, 0.25960500E+03, 0.66536500E+02, 0.32559200E+03, -.21612600E+03, -.61407100E+02, 0.19970600E+04, -.98608000E+03, -.35897800E+03, -.99897100E+03, -.25526100E+01, -.36074200E+03, -.14315000E+03, 0.20195000E+03, -.78700600E+03, -.29184000E+03, -.89957600E+03, -.46934600E+04, 0.23433300E+04, 0.55716700E+03, 0.23508400E+04, -.98483200E+03, -.11116800E+04, 0.18398500E+04, 0.91653700E+03, 0.15517400E+04, -.89353100E+03, 0.16788400E+04, 0.22808500E+04, -.10785200E+04, -.17800600E+04, -.11405500E+04, 0.29462100E+03, -.22641300E+03, -.78662200E+03, -.38023300E+03, -.11973300E+04, -.78630300E+02, -.17820200E+04, 0.35128400E+04, -.17596300E+04, -.10775500E+04, -.17564400E+04, -.38994500E+03, -.57749600E+03, -.45593600E+03, 0.55003300E+03, -.11163300E+04, -.55344500E+03, -.17017300E+04, -.13170000E+04, 0.60337300E+03, 0.15282700E+04, 0.65863400E+03, -.11540600E+03, 0.50754100E+03, 0.32004000E+03, -.97394400E+02, 0.83793700E+03, 0.37753000E+03, 0.12279400E+04, -.24093300E+03, 0.82062400E+02, 0.43246600E+03, 0.11862100E+03, 0.48848000E+02, -.62825200E+03, -.20488900E+03, -.62483100E+03, 0.12214400E+03, -.48741100E+03, 0.14534800E+03, 0.34138300E+04, -.17831500E+04, -.32974300E+03, -.17021300E+04, -.15327800E+04, 0.25412100E+03, -.25656000E+03, -.19984000E+03, -.14948200E+04, 0.33264700E+03, -.12000200E+04, 0.36343600E+03, -.12584400E+02, 0.14585400E+03, 0.14692000E+03, 0.19551700E+03, -.16302400E+03, -.59565400E+02, 0.45227100E+03, 0.11682500E+03, -.57325800E+02, -.41661200E+02, 0.37968200E+03, 0.12034200E+03, -.14116600E+03, 0.16992900E+03, -.14686500E+03, -.13668800E+03, -.33522100E+03, 0.13022700E+03, -.17864100E+03, 0.29523300E+03, 0.32120800E+03, -.34436000E+03, -.11040000E+02, -.14665600E+03, -.57361800E+02 },
        { -.67248100E+01, -.31283800E+01, -.64013400E+01, -.30065400E+01, 0.16493700E+01, 0.26104200E+01, 0.23341900E+01, -.13947000E+01, 0.62979100E-01, -.13757200E+01, 0.10155300E+01, 0.86723500E+00, 0.50534400E+00, -.42159800E+00, -.13617500E+01, 0.31432900E+02, -.29055200E+01, 0.24725900E+01, 0.27788300E+01, -.52818300E+00, -.39205100E+01, 0.41085700E+00, 0.47097300E-01, 0.14459300E+01, -.73652600E+00, -.11204400E+00, -.29524900E+00, 0.23369300E+01, 0.23278500E+01, -.10004900E+00, -.11837400E+01, 0.19640400E+01, -.72808500E-01, -.51813000E+01, 0.29973600E-01, -.37770200E+00, -.22004900E+00, -.99844000E+00, -.43135800E+00, -.49182500E+00, 0.16225000E+00, -.12637800E+01, 0.14992900E+00, -.32035600E+00, 0.27559300E+00, 0.11424800E+01, -.88903400E-01, -.79630100E-01, 0.21223800E+01, 0.47489400E+00, 0.15617900E+00, -.16922400E+01, 0.46558600E+00, 0.13616200E+01, 0.46835600E+00, 0.22040400E+00, 0.77652600E+00, 0.13724000E+00, -.69962100E-01, 0.13329800E+01, -.31240900E+00, 0.93207100E+00, -.77266900E-01, -.10523000E+01, -.54818900E+00, -.10276200E+01, 0.19568500E+01, -.37782100E+03, 0.14046700E+05, 0.14671500E+01, -.60545300E+04, -.55202600E+04, 0.11365700E+04, -.13269500E+02, 0.39366800E+04, -.49746900E+04, -.35182600E+04, -.19856100E+04, 0.89219600E+03, 0.11316900E+04, 0.10024600E+04, -.21357900E+04, -.23792300E+04, -.21294200E+04, -.33418800E+04, -.31496300E+03, -.18206400E+04, -.94708400E+03, -.77036200E+04, 0.38708600E+04, 0.10333200E+05, 0.38470500E+04, 0.41184700E+04, 0.48716000E+04, 0.91534800E+02, 0.37731100E+03, 0.62439900E+03, 0.37117100E+04, 0.39741600E+04, 0.47651300E+04, -.21761700E+04, -.15184600E+05, -.23848600E+04, 0.16321600E+04, 0.74198600E+03, 0.11660700E+03, 0.34905800E+04, 0.20226700E+03, 0.10574000E+04, -.23608900E+04, -.11159900E+04, 0.49816600E+03, 0.15029000E+05, 0.54551100E+03, -.92622600E+03, 0.42710100E+02, 0.12889000E+03, -.28647100E+04, -.38248200E+03, -.13941500E+03, -.72058800E+03, -.64755800E+03, 0.36976200E+03, 0.18998900E+04, 0.33251300E+03, -.82502800E+03, 0.27933100E+04, -.23558000E+04, -.78421900E+03, -.55889900E+03, 0.24424200E+04, -.46190100E+02, 0.25183600E+04, -.11033500E+04, 0.50775100E+03, -.12588500E+04, 0.93515100E+03, 0.20890600E+04, -.16935500E+04, 0.82675500E+03, -.57035400E+03, 0.13607600E+04, -.10936000E+04, -.32380600E+05, 0.16760500E+05, 0.30451300E+03, 0.16182500E+05, 0.11978400E+05, 0.14080700E+05, 0.37648900E+04, 0.23041400E+03, 0.50845400E+04, 0.12360800E+05, 0.20476500E+05, -.56697700E+05, 0.28097100E+05, 0.64885300E+05, 0.28349300E+05, 0.15519700E+04, 0.65105700E+04, 0.76986400E+04, -.11925400E+05, 0.13397800E+05, 0.65426100E+04, 0.26911000E+05, 0.28619200E+04, -.14408100E+04, -.64581800E+04, -.14321800E+04, 0.22737600E+03, -.92553700E+02, -.14342900E+04, -.24974000E+03, -.19834800E+04, -.69606600E+02, -.13173900E+04, -.12514100E+05, 0.62315500E+04, -.22668100E+04, 0.62533700E+04, 0.25103400E+04, -.58547500E+04, 0.37802700E+04, 0.38370700E+03, 0.34808900E+04, -.43896500E+04, 0.47459600E+04, 0.15250400E+04, -.71353200E+03, -.56025700E+04, -.75259600E+03, 0.92199800E+02, 0.27383600E+03, -.11385800E+04, -.36127500E+03, -.15817200E+04, 0.28340100E+03, -.20061300E+03, -.91705100E+04, 0.45565100E+04, -.58670900E+03, 0.45881700E+04, -.20106200E+04, -.28619500E+04, 0.25970900E+04, -.16664000E+04, 0.30847900E+04, -.18956700E+04, 0.38703700E+04, 0.52452600E+04, -.24818500E+04, 0.13735400E+05, -.26482300E+04, 0.45570800E+04, 0.34070100E+04, -.25325700E+04, -.33848400E+04, -.13343000E+04, 0.27999500E+04, -.28197200E+04, -.34801600E+05, 0.17146200E+05, 0.43402400E+05, 0.17401500E+05, 0.53982200E+03, 0.36304100E+04, 0.47066100E+04, -.80152300E+04, 0.77119500E+04, 0.39766100E+04, 0.17219100E+05, -.16892200E+05, 0.84499000E+04, 0.14005400E+05, 0.84462000E+04, 0.24948800E+03, 0.17236400E+04, 0.22453000E+04, -.47092300E+04, 0.29463300E+04, 0.19339800E+04, 0.77696100E+04, 0.30205000E+05, -.14939700E+05, -.34190700E+05, -.15103300E+05, 0.55632000E+03, -.39196300E+04, -.27549600E+04, 0.78512800E+04, -.88805600E+04, -.27245900E+04, -.16436800E+05, 0.43947900E+03, -.18448900E+03, 0.96404200E+03, -.20829400E+03, -.35033900E+04, 0.13927000E+04, 0.13479100E+03, -.11304400E+04, -.32047500E+03, 0.83712200E+03, 0.33454400E+03, -.95202700E+04, 0.49714800E+04, -.10829300E+05, 0.47302200E+04, 0.39244900E+04, 0.20706100E+04, -.63001700E+03, -.19814700E+04, 0.45130500E+04, 0.19744300E+04, 0.60989000E+04, -.12343700E+04, -.83349300E+02, -.41085300E+02, -.21826000E+02, -.11269600E+03, 0.44048300E+03, 0.73484200E+02, -.92065400E+04, -.21540500E+03, 0.35982600E+03, -.71042200E+03, -.48046400E+03, -.45418900E+03, 0.12854200E+01, -.41746300E+04, -.62379400E+03, 0.59747600E+01, 0.15604700E+03, 0.27997500E+02, 0.33741600E+03, -.21344900E+04, 0.29500500E+03, 0.10766600E+04, 0.45140900E+03, -.13876200E+03, 0.81010000E+03 },
        { -.13604000E+01, 0.98055700E-02, 0.53388600E+00, 0.15750800E+00, 0.32981900E+00, 0.15296300E+00, 0.52749900E+00, -.24706800E+01, -.10498900E+00, -.89660200E+00, -.11323000E-01, 0.32339800E+00, 0.22556600E+00, -.11340800E+00, -.21795000E+00, 0.10880900E+01, -.17695400E+01, -.46772200E+00, 0.55293000E+00, -.48681000E+00, 0.52356500E+00, -.88289000E-02, 0.86219600E-01, 0.52440400E+00, -.89606900E-01, -.14203000E-01, 0.12041600E+00, 0.95115900E+00, -.20496200E+00, 0.36664100E-01, -.38351400E+00, -.57061900E-01, 0.34283800E+00, -.34454200E+00, 0.56259000E-02, -.33891600E-01, 0.22962700E-02, -.37619400E+00, -.13641000E+00, -.25605600E+00, 0.22915800E+01, -.21157700E+00, -.57878400E-02, 0.12264400E+00, -.77320000E-01, 0.34458800E+00, -.37796800E-01, 0.12174400E-01, 0.16327600E+00, 0.16463100E+00, 0.22265400E+00, -.12019700E+00, 0.20185600E+00, 0.11075800E+01, 0.38720900E+00, -.63426900E+00, -.21265200E+00, 0.27875100E-01, -.19012500E-01, -.41468200E+00, 0.64159700E-01, -.10930800E+00, -.24609900E+00, -.93681100E-01, -.24281100E+00, -.10589400E+00, -.17812000E+00, 0.20656600E+00, -.46632200E+04, -.15143200E+00, -.50245600E+03, -.14481600E+04, 0.89245000E+03, 0.14312700E+04, 0.16243600E+04, -.70663300E+03, -.11922100E+04, 0.14755000E+04, -.75193700E+03, -.26097900E+03, -.73872500E+03, -.33102500E+03, 0.13793100E+04, -.38242600E+03, -.51661400E+03, -.99870800E+03, 0.15207100E+04, 0.36844500E+03, -.48847900E+03, 0.25890300E+03, -.14903100E+04, 0.24471900E+03, 0.28423900E+03, 0.21624200E+03, -.64731100E+03, -.24495800E+03, 0.44014200E+03, -.13912600E+03, 0.29875500E+03, 0.82677100E+03, -.43576300E+03, 0.23710400E+04, -.41315100E+03, 0.31316600E+03, 0.86869300E+03, -.13098100E+03, 0.26391800E+03, 0.20123200E+03, 0.42023400E+03, -.28234600E+03, -.16463400E+03, 0.90888700E+02, -.10493500E+04, 0.83558900E+02, -.79512800E+03, -.93692800E+03, 0.64814400E+02, -.62751000E+03, -.73936500E+03, -.60338600E+03, -.11440100E+04, 0.14286500E+03, -.80688600E+02, -.72781400E+03, -.72381500E+02, 0.38113000E+02, -.58471200E+03, 0.25401300E+03, 0.10826900E+04, 0.16420100E+04, -.44866500E+03, -.63266400E+02, -.13104300E+04, 0.59887300E+03, -.19833800E+03, 0.65517200E+03, 0.32328200E+03, -.58140100E+03, 0.50415100E+03, 0.70034900E+03, 0.71501700E+03, -.54660100E+03, 0.14708100E+03, -.75400000E+04, 0.37673400E+04, 0.88223000E+04, 0.37707800E+04, 0.85295200E+03, 0.29966300E+04, -.78706800E+03, -.44701300E+04, -.45514900E+03, 0.17596900E+04, 0.62221300E+04, -.12401300E+05, 0.62390200E+04, -.33787000E+04, 0.62005900E+04, 0.96004100E+03, 0.94904000E+03, 0.13663100E+04, -.23575600E+04, 0.31142100E+04, 0.76850200E+03, 0.59172000E+04, -.93782300E+03, 0.47513500E+03, 0.82235500E+03, 0.46900900E+03, 0.17020600E+03, 0.37691100E+03, -.22213500E+03, -.42682800E+03, -.57834300E+01, 0.31212200E+03, 0.33806600E+03, 0.47088200E+03, -.22666700E+03, 0.24591300E+03, -.23606500E+03, -.12127100E+04, 0.72060900E+01, -.40325400E+03, -.15965300E+04, -.13484100E+04, 0.16537000E+03, 0.13236500E+03, -.44662200E+03, 0.22433100E+03, 0.10558400E+04, 0.22457400E+03, 0.88673200E+02, 0.30333300E+03, -.21421200E+03, -.27624700E+03, -.74724600E+02, 0.30591100E+03, -.91672100E+01, 0.18357500E+04, -.90588800E+03, 0.62741000E+03, -.91822100E+03, 0.22158800E+03, 0.78023300E+03, -.78773600E+03, -.52139700E+02, -.30384500E+03, 0.75226900E+03, -.15805000E+04, -.55177500E+04, 0.27732100E+04, -.76419600E+03, 0.27614600E+04, 0.17707300E+03, 0.67933900E+03, 0.37382500E+03, -.15329700E+04, 0.20666800E+04, 0.69582500E+03, 0.20610200E+04, -.29418000E+04, 0.15214600E+04, -.44416200E+04, 0.14708300E+04, 0.16005500E+03, -.23004400E+03, 0.40937900E+03, -.35469500E+03, 0.87061800E+03, -.32123400E+03, 0.15930800E+04, -.10360100E+05, 0.51721300E+04, 0.33414500E+04, 0.51800400E+04, 0.62930100E+03, 0.12497200E+04, 0.10944600E+04, -.21340600E+04, 0.26806800E+04, 0.11257700E+04, 0.46312600E+04, 0.72848600E+04, -.36885700E+04, 0.25858000E+03, -.36423500E+04, -.12703700E+03, 0.24199900E+03, -.13162900E+04, 0.22102700E+04, -.71886400E+03, -.38546000E+03, -.36940400E+04, -.72790400E+03, 0.33861600E+03, 0.66635100E+03, 0.36281200E+03, 0.11082300E+04, 0.74642900E+03, 0.10273500E+03, 0.63351500E+03, 0.38941000E+03, 0.54887800E+03, 0.26940100E+03, -.23550000E+04, 0.11379900E+04, 0.25526100E+04, 0.11806100E+04, 0.27277700E+04, 0.81503100E+02, 0.57070200E+03, 0.20933500E+04, 0.19988900E+04, -.51972000E+03, -.11849500E+04, -.17881600E+03, 0.38226000E+02, -.31968800E+03, -.33110000E+03, -.26288700E+03, 0.10894900E+03, -.14524900E+03, -.16141800E+04, -.68938300E+02, -.14424600E+03, -.26998100E+03, -.35283700E+03, 0.14750700E+03, 0.18240700E+03, -.63270000E+03, 0.28014800E+03, 0.30364700E+03, 0.34778100E+03, -.32336400E+03, 0.21051500E+03, 0.35570900E+03, -.51768100E+03, -.60469500E+03, 0.91159600E+02, 0.16228500E+03, -.10176100E+03 },
        { -.25063200E+01, -.28957000E-02, 0.45184500E+00, -.20167700E+00, 0.65533100E+00, 0.29998000E+00, 0.80888900E+00, -.59278500E+00, -.25061200E+00, -.75282500E+00, 0.30408600E+00, 0.34534700E+00, 0.38170500E+00, -.19484500E+00, -.33202100E+00, -.11248400E+01, -.20535400E+01, -.97810700E+00, 0.14852500E+01, 0.79231900E-02, 0.69609700E+00, -.14118200E+00, 0.33061400E-01, 0.22794000E+00, -.18042000E+00, -.97435500E-01, 0.11159400E+00, 0.66708800E+00, -.21649500E+00, 0.66567100E-01, -.19240000E+00, -.34860300E+00, 0.30318500E+00, 0.96172600E+00, 0.85665800E-03, 0.17007300E-01, 0.16608100E-01, -.29389700E+00, -.14328500E-01, -.24600000E+00, 0.21046600E+01, 0.93509700E-01, -.27173000E-01, 0.14933300E+00, -.20143600E+00, 0.24255600E+00, -.40201700E-01, 0.47052800E-02, 0.11419300E+00, 0.11078000E+00, 0.18285700E+00, 0.41014400E+00, 0.45172700E-02, 0.15220700E+01, 0.33354600E+00, -.70108300E+00, -.20920200E+00, 0.43086700E-01, -.28109900E-01, -.37575000E+00, 0.77065200E-01, -.47836300E+00, -.19991100E+00, 0.28873200E+00, 0.12050000E+00, 0.73679500E-01, -.26727300E+00, 0.60474800E-01, 0.48530900E+00, 0.19504400E+02, -.13012100E+03, -.61663500E+03, 0.51653700E+03, 0.90155100E+02, -.92584300E+02, -.20278600E+03, -.14083100E+04, 0.20259600E+03, -.89977800E+02, -.15884900E+03, -.10089300E+03, -.17553300E+01, 0.60000200E+03, -.37993900E+02, -.25523100E+02, -.49474500E+03, 0.55096600E+03, 0.11782900E+03, -.55246700E+03, 0.25453900E+03, -.87131400E+03, 0.27603500E+03, 0.36180500E+03, 0.19089400E+03, -.12920900E+03, -.83934400E+01, 0.81452200E+02, 0.10039200E+03, 0.33212200E+03, 0.10831900E+04, -.50892000E+03, 0.90041500E+03, -.54169100E+03, -.29825900E+02, 0.29213800E+02, -.15042200E+03, 0.92951100E+03, 0.54736000E+03, -.13339000E+03, -.85842100E+02, -.49802400E+03, 0.23612100E+03, 0.42076100E+03, 0.24847900E+03, -.23767000E+03, -.12328000E+03, -.13707800E+03, -.81093300E+03, -.31359500E+03, 0.10575000E+03, -.35911100E+03, 0.19470300E+03, -.10165800E+03, -.48665300E+03, -.97037900E+02, -.13897900E+03, -.41484500E+03, 0.30277200E+03, 0.63830900E+03, 0.60484200E+03, -.40221300E+03, 0.72633800E+02, -.21114100E+02, 0.92325000E+02, -.33770300E+03, 0.10562200E+02, 0.13336700E+03, -.32700900E+03, 0.27285600E+03, 0.49293700E+03, -.24857200E+02, -.24741600E+03, -.32337000E+03, -.25943500E+04, 0.12612400E+04, 0.38786000E+04, 0.12968500E+04, 0.20340400E+03, 0.11431800E+04, -.66863500E+03, -.91220100E+03, 0.65047500E+03, 0.44168800E+03, 0.38589800E+04, -.43923100E+03, 0.15472200E+03, 0.11690900E+03, 0.21963600E+03, -.27376100E+03, 0.92645300E+02, -.22659400E+03, -.63193800E+03, -.56506300E+03, -.30653500E+02, 0.14899500E+04, -.16241900E+04, 0.75851900E+03, 0.90366800E+03, 0.81200400E+03, 0.21965500E+03, 0.31204700E+03, 0.86592400E+02, -.45843100E+03, 0.11213100E+03, 0.32316900E+03, 0.33568000E+03, 0.98496800E+02, -.43835500E+02, -.86469500E+02, -.48043600E+02, 0.98741100E+02, 0.45780200E+03, -.31369300E+03, -.30937300E+03, -.52493800E+03, 0.48218100E+03, -.33124100E+03, -.99058000E+03, 0.46878200E+03, 0.83210900E+03, 0.49649600E+03, 0.67807000E+02, 0.12021100E+03, 0.15912800E+03, -.30938800E+03, -.14091300E+02, 0.18969600E+03, -.67546400E+02, 0.84787100E+03, -.43866100E+03, 0.20024700E+03, -.42385300E+03, -.45795800E+02, 0.11470800E+03, -.33609100E+03, -.32042900E+03, -.12780400E+03, 0.21191200E+03, -.62394400E+03, -.37756800E+04, 0.18738700E+04, 0.29271200E+04, 0.18867700E+04, 0.42968700E+02, 0.50360700E+03, 0.26602700E+03, -.11393600E+04, 0.11234100E+04, 0.56211400E+03, 0.16155200E+04, 0.20425200E+03, -.16375300E+03, -.98148300E+03, -.10209500E+03, -.22162600E+03, -.10389400E+03, -.55948700E+02, -.26162300E+03, -.57478100E+03, -.19279200E+03, 0.72473200E+03, -.26554000E+04, 0.13089400E+04, 0.40192700E+04, 0.13277100E+04, 0.18669800E+01, 0.38147500E+03, 0.14886700E+03, -.80633500E+03, 0.48151800E+03, 0.30741200E+03, 0.13662300E+04, 0.26963300E+03, -.64584800E+02, -.19544600E+04, -.13485100E+03, 0.45915900E+03, 0.41006800E+03, -.15518800E+03, 0.95038000E+03, 0.10317800E+04, 0.13359700E+03, -.57269800E+03, 0.11105300E+04, -.54276300E+03, 0.18283000E+03, -.55477500E+03, -.14369400E+03, -.24715100E+03, 0.58601400E+02, 0.22693400E+03, -.26051300E+03, -.36122100E+03, -.44575200E+03, -.19698300E+04, 0.10387400E+04, 0.14680700E+04, 0.98372500E+03, 0.14887100E+04, 0.94590200E+02, 0.35388900E+03, 0.66259000E+03, 0.80213900E+03, 0.10351300E+03, -.73644100E+03, -.19707900E+03, 0.32305300E+02, -.15444100E+03, -.14589700E+03, -.13838200E+03, 0.74169200E+02, -.99515300E+02, -.45401200E+03, -.67251300E+02, -.26514000E+02, 0.64946000E+02, -.26435400E+03, -.13065800E+02, 0.14056200E+03, -.10675100E+03, -.88277700E+02, 0.12759800E+03, -.38393500E+02, -.16594100E+03, 0.11749700E+03, 0.11544900E+03, 0.18009900E+02, 0.53727200E+03, 0.47023900E+02, -.72539500E+01, -.27886200E+00 },
        { -.70353000E+01, 0.23115700E+01, 0.92129800E+00, -.18059600E+01, 0.17801300E+01, -.36985100E+00, -.16615500E+01, 0.63208800E+01, -.17425200E+01, 0.10514600E+01, 0.14452300E+01, 0.59321900E+00, 0.12475600E+01, -.28290700E+00, -.67415600E+00, -.52013600E+01, -.11415900E+00, -.70091800E+00, -.57151200E+00, 0.26512400E+00, 0.18389700E+01, 0.87982800E+00, -.36191800E+00, 0.38274100E+01, -.24726600E+00, 0.12313900E+00, 0.19615200E+01, 0.42700100E+01, -.62922000E+01, -.26857800E-01, 0.34058700E+00, -.16120200E+00, -.16494000E+00, -.25092000E+01, 0.65838200E+00, 0.77407300E-01, 0.17872300E-01, 0.27346600E+01, -.59856500E-01, -.10077000E-01, 0.66347600E+01, 0.17439800E+00, -.19056300E+00, 0.23537300E+00, -.13592500E-02, 0.11892300E+01, -.46441300E-01, -.24715200E-01, 0.49812100E+01, -.32389500E-02, 0.54866200E+00, -.31141000E+01, 0.21709300E+01, -.34003900E+01, 0.10850300E+00, -.20713800E+01, -.15819000E+01, 0.24805200E+00, 0.72421500E-01, -.11036200E+01, -.26078000E+00, 0.10133100E+01, -.38887900E+00, -.63599900E+00, -.14619500E+01, -.28680800E+01, 0.12632300E+01, -.78245200E+00, 0.42995800E+01, 0.17485100E+00, -.11480700E+05, -.72663800E+04, 0.19597300E+04, -.24938800E+04, -.99958600E+03, -.75999900E+04, 0.34611900E+04, -.20568700E+04, 0.10645900E+04, -.92356700E+04, 0.10506900E+04, -.52618500E+04, -.15643600E+05, 0.12032100E+04, -.13865900E+04, -.13581200E+03, -.13444600E+05, -.59141300E+04, -.63915500E+04, 0.31450200E+04, 0.18842500E+05, 0.31848200E+04, 0.41546600E+04, 0.64859000E+04, 0.74014000E+03, 0.87378300E+03, -.38026300E+03, 0.52611300E+04, 0.45786800E+04, -.64966500E+04, 0.31959900E+04, -.18817400E+05, 0.32430400E+04, 0.54074100E+04, 0.11059500E+04, 0.25816900E+04, -.17365800E+02, 0.17003700E+04, 0.27740200E+04, -.36303800E+04, -.16230600E+04, 0.84230900E+03, 0.22942500E+05, 0.78282700E+03, 0.19169400E+04, 0.59191700E+04, -.20796200E+04, -.23877300E+04, 0.10853600E+04, 0.39047700E+04, 0.43696700E+04, -.42900100E+04, 0.21795900E+04, -.35799000E+04, 0.21655100E+04, -.53434500E+04, 0.20993500E+04, -.16073700E+04, -.52200800E+04, -.70544000E+04, 0.24242800E+04, 0.22520100E+04, 0.68721500E+04, -.35768200E+04, 0.43467100E+04, -.34352600E+04, -.43780900E+03, 0.46706800E+04, -.49958700E+04, -.37090100E+04, -.40401200E+04, 0.39291900E+04, -.76376500E+03, -.30050500E+05, 0.15099100E+05, 0.17477500E+05, 0.15007400E+05, 0.21034200E+05, 0.15491700E+05, 0.58968100E+04, 0.79205600E+04, 0.14933100E+05, 0.16101900E+05, 0.53462800E+04, -.77843600E+05, 0.38820300E+05, 0.80744700E+05, 0.38922900E+05, 0.34921000E+04, 0.62256600E+04, 0.17007500E+05, -.15569100E+05, 0.21008700E+05, 0.92359200E+04, 0.29226300E+05, 0.14064500E+05, -.66386200E+04, -.18143000E+05, -.70348200E+04, -.17905700E+03, -.18921800E+04, -.28220400E+04, 0.20491600E+04, -.51764200E+04, -.17239800E+04, -.47915900E+04, -.37465000E+05, 0.18689600E+05, 0.85672200E+03, 0.18724800E+05, 0.57299700E+04, -.12512700E+05, 0.10335400E+05, 0.31884000E+04, 0.19453600E+05, -.11306300E+05, 0.15211200E+05, 0.37800100E+04, -.16295900E+04, -.13948700E+05, -.18745600E+04, 0.60890500E+03, 0.98533700E+01, -.16250200E+04, 0.54581500E+03, -.24589300E+04, -.41175100E+03, 0.11956500E+04, -.22324600E+05, 0.11193200E+05, -.23869500E+04, 0.11169300E+05, -.15392500E+04, -.33496200E+04, 0.67986000E+04, 0.65286700E+03, 0.70549500E+04, -.32837100E+04, 0.12211600E+05, 0.10971200E+05, -.54693300E+04, 0.29333000E+05, -.55446700E+04, 0.96323000E+04, 0.58045100E+04, -.24762900E+04, -.19935600E+04, -.21418900E+04, 0.44723800E+04, -.37935900E+04, -.59198900E+05, 0.29482300E+05, 0.59382000E+05, 0.29601100E+05, 0.21140200E+04, 0.44743700E+04, 0.11381900E+05, -.13094500E+05, 0.14846700E+05, 0.69014700E+04, 0.24054800E+05, -.14289500E+05, 0.72214100E+04, -.98896400E+03, 0.71449900E+04, 0.74294600E+03, 0.85420500E+03, 0.37382000E+04, -.33652800E+04, 0.38416200E+04, 0.19708700E+04, 0.56045700E+04, 0.24060000E+05, -.11999500E+05, -.37814300E+05, -.12031800E+05, 0.26771500E+04, -.39593200E+04, -.25495900E+04, 0.42328600E+04, -.13117000E+05, -.12775500E+04, -.16063100E+05, 0.11627300E+05, -.57570800E+04, -.15310000E+05, -.57873400E+04, -.74256300E+04, 0.19441000E+04, 0.18474800E+02, 0.32022600E+03, -.58804400E+04, 0.19946400E+04, -.44641300E+04, -.12365400E+04, 0.53946500E+03, -.15094400E+05, 0.54886200E+03, -.12956900E+04, 0.11693300E+05, -.60973400E+04, -.11425900E+05, -.12127300E+04, 0.11356800E+05, 0.11424500E+05, -.78477100E+03, 0.78222200E+03, 0.17834900E+04, 0.18597100E+04, 0.11777000E+04, -.26376600E+03, -.17468300E+04, -.11100600E+05, -.14434900E+04, 0.18510900E+04, 0.91498300E+03, 0.11916000E+04, -.30791700E+04, -.14078600E+04, -.51154600E+04, 0.57056500E+02, -.17124800E+04, -.13954300E+04, 0.20493500E+04, -.77314800E+03, -.59800700E+04, 0.21524900E+03, -.43093100E+04, -.32795400E+03, -.12347600E+04, 0.21264200E+04 },
        { -.47705600E+00, 0.23572600E-01, 0.10972500E+00, 0.14472800E-01, 0.11030600E+00, -.13465300E-01, 0.10143400E+00, 0.22120200E-01, -.35844300E-01, 0.16626900E+00, -.89307300E-02, 0.94043400E-02, 0.29417500E-01, -.37967300E-01, 0.37535000E-01, -.14981200E+01, 0.29456100E+00, -.41493500E+00, 0.36865600E+00, 0.20867600E+00, 0.19444700E+00, -.57791300E-01, -.23135800E-01, -.17815700E+00, -.38818700E-01, 0.13705600E-02, 0.40089000E-01, -.11085300E+00, -.13076500E+00, 0.64448100E-02, 0.40698600E-01, -.27317400E-01, 0.84184800E-02, 0.31445700E+00, -.53069300E-02, 0.11392000E-01, 0.11311400E-01, -.36536300E-01, 0.45239300E-01, -.14953900E-01, -.23275100E+00, 0.65542000E-01, -.49166800E-03, 0.25578700E-01, -.24259400E-01, -.45956300E-01, 0.55945800E-02, 0.78598400E-02, -.23304700E+00, -.37526100E-01, 0.16238600E-01, 0.10745700E+00, -.10332500E+00, -.48435600E-03, -.65046000E-01, -.52853200E-01, -.59515100E-01, -.92158400E-02, 0.50561000E-02, 0.14178000E-01, 0.12953600E-01, 0.19312100E-01, -.55808700E-02, 0.48596400E-01, -.30194900E-01, 0.13512700E-01, 0.22006700E+00, -.12565900E-01, 0.54561400E-01, 0.14239900E-02, 0.90632000E-02, 0.43528900E+03, -.21420800E+03, -.72931800E+02, -.39278100E+03, 0.30385100E+03, 0.35395600E+03, 0.75595100E+03, -.36127500E+03, -.48847100E+03, -.37799600E+03, -.24153800E+03, -.17491600E+02, -.13811400E+03, 0.78082300E+02, -.30833500E+03, 0.24395400E+02, -.14446500E+03, -.22727100E+03, 0.98273800E+02, -.29487700E+03, 0.11364600E+03, -.77776800E+02, -.19173100E+03, 0.12055200E+03, 0.18345200E+02, 0.15044500E+03, -.11534300E+03, 0.12548000E+03, -.92381100E+03, 0.49941200E+03, 0.10789800E+04, 0.46190900E+03, -.64147800E+02, -.18915000E+03, 0.24265600E+03, -.32537400E+03, 0.81926900E+02, -.15606200E+03, 0.27352600E+03, -.62227200E+02, 0.13747000E+02, -.61245000E+03, 0.31140600E+02, 0.15891100E+03, 0.19431200E+03, -.18692600E+03, -.70630000E+02, 0.17885700E+03, 0.12802600E+03, 0.20355700E+03, 0.25225800E+03, -.11301300E+03, -.87624400E+02, -.12615000E+03, -.14803600E+03, -.33188500E+02, 0.98004400E+02, 0.24136700E+03, -.32253000E+03, -.53953900E+02, 0.39725700E+02, -.19489500E+03, 0.17376900E+03, 0.53031000E+02, 0.97445700E+02, 0.53659900E+02, -.10713800E+03, 0.11175800E+03, 0.57633700E+02, -.24014300E+02, -.66222700E+02, 0.25124100E+02, 0.15339800E+04, -.77457600E+03, 0.10386700E+03, -.76697400E+03, -.15592300E+03, -.11736500E+04, 0.54149100E+03, 0.10140700E+04, 0.51675800E+03, -.87897200E+03, -.14730500E+04, 0.31147200E+04, -.15957300E+04, -.19765300E+04, -.15573600E+04, -.31894000E+03, -.39296600E+03, -.16232600E+01, 0.14069600E+04, -.96621100E+02, -.38656900E+03, -.15732100E+04, -.71482000E+02, -.69115900E+01, 0.85134100E+02, 0.35721200E+02, -.19775500E+02, -.75800500E+02, 0.35190100E+02, 0.58005800E+02, 0.59365700E+02, -.47641900E+02, 0.39594300E+02, 0.18600800E+03, -.10351200E+03, 0.15538600E+03, -.93030600E+02, -.89594600E+02, -.52332500E+02, -.22443700E+03, -.28050000E+03, 0.93031300E+02, 0.13796700E+02, -.65654500E+02, -.42886600E+02, 0.14584200E+01, 0.11293900E+03, 0.21554000E+02, 0.22945800E+01, -.10834800E+02, -.26432000E+01, 0.41994600E+02, 0.28067700E+02, -.65707000E+01, 0.16603700E+02, -.65564400E+02, 0.18664300E+02, 0.14845600E+03, 0.32772300E+02, 0.10424100E+03, 0.29947500E+03, -.14813500E+03, -.17458800E+02, 0.39052800E+02, 0.20005400E+03, 0.14102100E+03, 0.20359000E+04, -.10366500E+04, -.71527300E+03, -.10179000E+04, -.22870100E+02, 0.36804800E+02, -.56204800E+03, -.60922000E+02, -.83420200E+03, 0.16322900E+02, -.72337300E+03, 0.16609200E+04, -.88316500E+03, -.15403200E+04, -.83046000E+03, -.21413200E+03, -.22815900E+03, 0.23740700E+02, 0.80148900E+03, 0.71197400E+02, -.20811500E+03, -.83420300E+03, 0.23487000E+04, -.11748200E+04, -.41638100E+03, -.11743500E+04, -.90647600E+02, -.27120400E+03, -.21627700E+03, 0.68036000E+03, -.41930400E+03, -.24741100E+03, -.10673100E+04, -.31594100E+04, 0.16361500E+04, 0.13761800E+04, 0.15797000E+04, 0.21039700E+03, 0.37155700E+03, 0.17683700E+03, -.11871400E+04, 0.35463800E+03, 0.41156700E+03, 0.14358100E+04, 0.12065800E+03, -.26978100E+02, 0.16162300E+03, -.60352900E+02, 0.37808500E+02, 0.31867500E+02, 0.11633700E+03, 0.28400300E+03, -.40718900E+02, 0.26119700E+02, -.80338900E+02, -.96262900E+03, 0.53739200E+03, 0.10326300E+04, 0.48137900E+03, 0.26823500E+03, -.30341600E+03, 0.15219000E+03, -.24164000E+02, 0.19455600E+03, -.24270200E+03, 0.22936900E+03, -.12143900E+03, -.16827400E+02, -.35521500E+02, -.37091600E+02, -.58745800E+02, 0.21704300E+02, -.19302500E+02, 0.70471000E+03, -.20703300E+02, -.28271500E+02, 0.44079200E+02, -.79579300E+02, -.42545000E+02, 0.50508400E+02, 0.35993400E+03, 0.23073700E+03, 0.40216800E+02, 0.91607500E+02, -.36432700E+02, 0.30830300E+02, 0.13964300E+02, -.18802900E+03, -.23784000E+03, 0.14424000E+02, 0.29467800E+02, 0.58241800E+01 },
        { 0.10101300E+01, 0.43085800E+00, -.20964700E+00, -.46163100E+00, 0.11150400E+00, -.61576200E+00, -.17631400E+01, 0.18151100E+01, 0.35310300E-01, 0.11891400E+01, -.50055000E-01, -.25534500E+00, -.29212100E+00, -.34785800E-01, 0.27418300E+00, -.44912300E+01, -.20110000E+01, -.11449700E+01, -.67317400E+00, -.16031700E+00, 0.12119000E+00, 0.12620300E+00, -.59282300E-01, -.24219200E+00, -.89016800E-01, 0.42305400E-01, 0.41826000E-01, -.12543200E+00, -.25771100E+00, -.50559600E-02, 0.63110100E+00, 0.41371600E+00, -.34227700E+00, 0.12807300E+01, 0.17824200E-01, 0.10461000E+00, -.38366400E-01, -.64698500E+00, 0.49807000E-01, -.20009400E+00, 0.36932700E+00, -.35685900E-01, 0.11452000E-01, -.80511100E-01, 0.65275400E-01, -.30541900E-01, -.20043500E-01, -.17524900E-01, 0.11044600E+01, 0.46477200E-01, -.26087100E+00, -.68672100E+00, 0.39225300E+00, 0.13554000E+00, -.10318000E-01, 0.27115400E-01, 0.28572600E-01, -.88512500E-01, -.48677400E-02, -.18930000E-01, 0.28188500E-01, -.16157000E+00, 0.12410600E+00, -.25109200E+00, 0.39515500E-01, 0.38857300E+00, 0.25984700E+00, 0.19786900E+00, 0.41073200E-02, -.25518500E-01, -.56061300E-01, 0.13918500E+00, -.61581300E+03, -.46639700E+03, -.47983700E+03, -.16289600E+02, 0.41692300E+03, -.20919100E+02, 0.14939300E+02, -.46256300E+03, 0.84464300E+01, 0.88975200E+02, -.15088000E+04, 0.10952800E+03, 0.45633500E+03, 0.50522200E+03, -.12353300E+04, -.25439300E+03, 0.15449800E+04, -.76971300E+03, 0.78428000E+03, -.77149700E+03, -.29373900E+03, 0.32429000E+02, 0.33538100E+02, 0.35167400E+03, -.95311000E+02, 0.31786100E+02, -.38118900E+03, -.90399300E+03, 0.45521100E+03, -.15311800E+04, 0.45246700E+03, -.15516400E+03, -.45460000E+02, 0.13966900E+03, -.95244600E+03, -.28118200E+03, 0.48784900E+02, 0.36310800E+03, 0.19994900E+04, -.10017600E+04, 0.11655800E+04, -.99713300E+03, 0.30528300E+03, 0.16272800E+03, -.22197100E+02, 0.41743200E+03, -.79328600E+03, -.93243800E+02, -.12197100E+04, 0.20133700E+03, -.87674700E+02, -.41234100E+03, -.10248500E+03, -.35455000E+03, -.13544800E+03, -.38442200E+03, -.15097900E+03, 0.37844700E+03, -.10362200E+03, -.25824100E+03, 0.45325600E+03, -.23771200E+03, -.38041600E+02, -.22669700E+03, -.58474100E+02, 0.62605400E+03, -.35045900E+03, -.57853600E+03, -.40126300E+02, 0.48499100E+03, 0.25741800E+03, 0.34778600E+03, -.15181300E+03, -.12933300E+04, -.17227900E+03, 0.24809300E+03, -.40721400E+02, 0.17960100E+04, 0.23416700E+04, 0.13780100E+04, 0.35593200E+02, -.10093300E+04, 0.20517200E+04, -.10118600E+04, -.16998900E+04, -.10259600E+04, 0.45816800E+03, -.18236500E+03, 0.12240800E+02, 0.17648600E+04, 0.10478900E+04, -.29828100E+03, -.14690500E+04, 0.21742200E+04, -.10698300E+04, -.14477300E+04, -.10869600E+04, -.35809800E+03, -.41163800E+03, -.24078200E+03, 0.36612200E+03, -.23200800E+03, -.37178500E+03, -.60088100E+03, -.23707100E+04, 0.11723000E+04, 0.27756200E+03, 0.11881500E+04, 0.42987000E+03, -.73803600E+03, 0.14133400E+04, 0.24209500E+03, 0.57545300E+03, -.54593300E+03, 0.10948800E+04, 0.20778000E+04, -.10278100E+04, -.14747000E+04, -.10429500E+04, -.28358400E+03, -.29402600E+03, -.44805600E+03, 0.19710800E+03, -.30979900E+03, -.25854600E+03, -.24642700E+03, -.83448100E+03, 0.41823900E+03, -.34205400E+03, 0.41663500E+03, -.15768900E+03, -.43702800E+03, 0.20327100E+03, 0.26111400E+02, 0.58570300E+01, -.30242400E+03, 0.37419600E+03, 0.26697600E+04, -.13390500E+04, -.10849600E+04, -.13295300E+04, 0.93140000E+03, 0.50124400E+03, -.78633500E+03, 0.19393400E+03, -.10595600E+04, -.81520600E+02, -.17827500E+04, 0.20207900E+04, -.10089900E+04, -.52599900E+03, -.10105400E+04, 0.18073700E+03, -.83417000E+02, -.32799700E+03, 0.98192200E+03, 0.35507000E+03, -.15582700E+03, -.81448000E+03, 0.20289400E+04, -.99911300E+03, -.31798200E+04, -.10144900E+04, 0.10663500E+03, -.26281400E+03, -.14018000E+03, 0.64704500E+03, -.24067400E+03, -.19540100E+03, -.10104600E+04, 0.56029800E+03, -.28788000E+03, 0.81441100E+02, -.27999000E+03, -.93204500E+03, -.52407500E+03, -.22205300E+03, -.17665400E+04, -.14867400E+04, -.16047900E+03, 0.59030000E+03, -.12223300E+04, 0.62793200E+03, -.10502400E+04, 0.60877700E+03, -.34420600E+03, 0.28135500E+03, -.55894900E+03, -.93314500E+02, 0.67473600E+03, 0.36449600E+03, 0.12008200E+04, 0.28442400E+04, -.14241300E+04, -.35754300E+04, -.14159000E+04, -.17298300E+04, 0.13975300E+04, -.13605500E+04, -.18190400E+04, -.15684400E+04, 0.12950400E+04, 0.18648800E+04, 0.19391000E+03, 0.25060200E+02, 0.21488000E+03, 0.19901100E+03, 0.27883400E+03, -.19383200E+03, -.20586800E+03, -.49272400E+03, 0.16965800E+02, 0.79173700E+02, 0.79567500E+02, 0.50634400E+03, -.19958000E+03, -.23048900E+03, -.19093700E+03, 0.27017000E+02, -.16676400E+03, -.22469200E+03, 0.21528300E+03, -.22933100E+03, -.61464500E+03, 0.62416100E+02, -.29451500E+03, -.13591000E+03, -.10012500E+03, 0.18725800E+03 },
        { 0.64126800E+00, -.16680400E-01, -.49484700E+00, -.32826100E+00, -.31357000E+00, -.44704900E-01, -.14964600E+00, 0.11922000E+01, 0.34846900E-01, 0.12899000E+00, 0.97802500E-01, 0.42288300E-02, -.12209100E+00, 0.22610800E-02, 0.12596600E+00, -.36208300E+01, -.75361500E+00, -.70442900E+00, 0.63236200E-01, 0.17881900E+00, 0.18222200E-01, 0.49048200E-01, 0.16798500E-01, -.12684500E+00, 0.68365300E-01, 0.16790700E-01, 0.11977100E+00, -.10184900E+00, -.26913300E+00, -.22969800E-01, 0.10520700E+00, 0.13145700E+00, 0.10367500E-01, -.73681600E+00, -.28354600E-03, 0.57806600E-02, -.53707200E-02, -.20283800E-01, 0.27345200E-01, 0.34172700E-01, -.48013400E+00, 0.66466900E-02, 0.36866500E-02, -.18262400E-02, 0.68859100E-01, 0.47908100E-04, -.22781300E-02, 0.45965800E-02, 0.24202200E+00, -.43198100E-01, 0.15238300E+00, -.59257200E-03, 0.72895300E-01, -.53878800E+00, -.11781200E-01, -.10646500E+00, -.12626200E+00, 0.51818200E-02, 0.75737000E-02, -.17467900E+00, -.17185800E-01, 0.22058900E+00, -.70890900E-01, -.22666400E-02, -.61963700E-01, 0.72985300E-01, 0.63160800E-01, 0.22732000E-01, 0.29610900E+00, 0.21825200E-02, -.18934200E-01, 0.93602300E+00, 0.25986500E+00, -.26806700E+03, -.23345600E+03, -.43366200E+02, -.23112400E+03, -.91357500E+03, 0.44413100E+03, 0.73145300E+02, 0.45802400E+03, 0.18607900E+03, -.17977500E+03, 0.27730100E+03, 0.26536300E+02, 0.22079400E+03, -.22867800E+03, -.83612400E+02, 0.17577500E+03, -.74076500E+02, 0.77069700E+03, -.88496200E+02, -.15495000E+02, -.32466500E+02, 0.40896300E+02, -.13399600E+03, -.34741400E+03, 0.50309400E+02, -.77620600E+02, -.94447300E+02, 0.13011800E+02, -.10851300E+04, 0.46930700E+02, 0.12404400E+03, 0.25216100E+02, 0.41481500E+02, 0.22268600E+03, 0.13851800E+03, 0.32349200E+02, 0.15047000E+01, -.38506800E+03, 0.20589100E+03, 0.63344000E+03, 0.19094000E+03, -.28325300E+02, -.47695400E+01, 0.10368600E+03, 0.11783500E+03, 0.41546300E+03, 0.69808900E+01, 0.30818800E+03, -.60619400E+03, 0.29552700E+03, -.12247900E+02, 0.30424200E+03, -.57462200E+02, 0.37628300E+02, 0.13648700E+03, -.48779400E+03, -.31474300E+03, 0.10868300E+03, 0.20865000E+03, 0.51470900E+03, -.32408100E+03, 0.12060300E+03, -.25730700E+03, -.15268200E+03, 0.56341400E+02, -.18272000E+03, -.24704600E+03, -.29811100E+03, 0.10163600E+03, -.13847100E+03, 0.51588200E+03, -.25185400E+03, -.92196100E+03, -.25893200E+03, -.23265300E+03, 0.18326600E+03, -.72320900E+03, -.48610700E+03, 0.11441100E+03, 0.17991100E+03, 0.57448100E+03, 0.20421500E+04, -.98577900E+03, 0.66869100E+03, -.10210100E+04, -.70000800E+03, -.70395800E+03, -.41028900E+03, -.52931300E+03, -.10237000E+04, -.49239000E+03, -.15118100E+03, 0.46826000E+03, -.18565300E+03, -.48079800E+03, -.23424600E+03, 0.19970600E+02, 0.19542000E+02, -.16154700E+02, 0.13483000E+02, -.22400500E+03, 0.22938900E+02, -.20955200E+03, -.35121800E+03, 0.18161200E+03, 0.20816700E+02, 0.17504000E+03, 0.43479800E+03, 0.22064700E+03, 0.11090900E+03, 0.48785700E+03, 0.53110500E+03, -.68814500E+01, 0.35713200E+02, 0.16870300E+02, 0.16175700E+02, -.40943000E+03, -.75903500E+01, 0.41542600E+02, 0.27181200E+02, 0.74880800E+02, -.19571900E+02, -.61044200E+02, 0.16689700E+02, 0.36854400E+02, -.43639200E+03, 0.22931200E+03, -.24926800E+03, 0.21859100E+03, -.82121300E+02, -.23321300E+03, 0.32759500E+03, 0.13619500E+03, 0.26334700E+03, -.23870900E+03, 0.31903600E+03, -.21187600E+04, 0.10726800E+04, 0.16165300E+04, 0.10561000E+04, -.91067500E+01, 0.25380400E+02, 0.54572700E+03, 0.12103800E+03, 0.86305100E+03, 0.97559800E+02, 0.10449900E+04, 0.10982000E+04, -.50277200E+03, 0.10277700E+04, -.54901200E+03, -.41926500E+03, -.49498200E+03, -.11990600E+03, -.30426900E+03, -.74969300E+03, -.32380400E+03, -.11255500E+03, -.60370400E+03, 0.30107400E+03, -.62584800E+03, 0.30186600E+03, -.18189700E+03, 0.87603000E+02, -.22003300E+02, -.16027900E+03, 0.38728500E+03, 0.16480900E+02, 0.55111900E+03, 0.33560600E+02, -.64675900E+02, -.30330600E+03, -.16880400E+02, 0.35887500E+03, -.38009500E+02, 0.47131400E+03, 0.70002600E+03, -.59302500E+02, -.57469200E+02, -.56388200E+03, 0.81759400E+03, -.43417000E+03, -.90894000E+03, -.40733600E+03, -.35943100E+03, -.31432600E+03, -.60909200E+02, -.41352900E+02, -.34459700E+03, -.23988900E+03, -.43393200E+03, 0.99228300E+03, -.54371400E+03, -.35680500E+03, -.50000200E+03, -.38542800E+03, 0.23076000E+03, -.71150500E+02, -.74201900E+02, -.40246200E+03, 0.31245900E+03, -.42640700E+03, 0.13080000E+03, 0.35040400E+02, 0.74858800E+02, 0.83226000E+02, 0.58950900E+02, 0.42054200E+01, 0.35240300E+02, -.19841900E+01, -.12671100E+02, 0.92505000E+02, 0.31191900E+02, -.78084500E+01, -.27758300E+02, -.54279900E+02, -.26327500E+02, 0.20120000E+03, -.76452800E+02, -.13690600E+03, 0.83637600E+02, -.21622700E+02, -.19760600E+02, -.37501900E+02, -.18610800E+03, 0.31407500E+02, -.19679000E+02, -.23845400E+02 },
        { 0.10457900E+01, 0.25801100E+00, -.41277700E+00, -.50547000E+00, 0.18335800E-01, -.40585600E+00, -.20362700E+01, 0.27029600E+01, 0.86194100E-01, 0.99518700E+00, 0.88821000E-01, -.40366000E+00, -.22129000E+00, 0.71700900E-01, 0.26362800E+00, 0.17905800E+01, 0.54760000E-01, -.30664500E+00, -.11755300E+01, -.53079500E-01, 0.63134600E+00, 0.21371800E+00, 0.10783500E-01, 0.56471100E+00, 0.12495900E-01, 0.21883800E-01, 0.19890300E+00, 0.60982600E+00, -.13778200E+01, 0.14796200E-01, 0.10579800E+00, -.34400800E+00, 0.35718700E+00, 0.94739100E+00, 0.11824900E-01, -.31952500E-02, 0.22149200E-01, -.35575100E+00, 0.16925900E-01, -.32845600E+00, -.20812300E+00, 0.43510400E+00, -.45484800E-01, 0.85827300E-01, -.51728700E+00, 0.47126600E+00, -.44218400E-01, 0.16369800E-01, 0.53887300E+00, -.64987000E-01, 0.64035600E+00, -.88622100E-01, 0.26869300E+00, 0.84370000E+00, 0.24238700E+00, 0.86175200E-02, 0.73752700E-01, 0.17363300E+00, 0.12868600E-01, -.38415000E+00, 0.13749100E+00, -.28901500E-02, 0.14654900E+00, 0.12709800E-01, -.51763500E+00, 0.26271600E+00, 0.48240800E+00, -.76113500E-01, -.44142800E+00, -.20089600E-01, 0.30875300E-01, -.19596600E+01, -.94300700E+00, -.14234400E+01, -.14533600E+04, 0.60019800E+03, -.17340200E+04, 0.18896000E+04, -.96623400E+03, -.12009900E+04, -.94822500E+03, -.78309000E+03, -.43856900E+03, -.30957700E+03, 0.37018900E+03, -.75132800E+03, -.52158800E+02, -.29865000E+03, 0.98437300E+03, -.45689200E+03, -.79095600E+03, -.49049800E+03, 0.31064700E+02, -.51502100E+03, -.22140500E+03, 0.32023600E+03, 0.78056100E+03, -.37346700E+03, 0.67130600E+02, -.20444100E+04, 0.95364300E+03, 0.14540500E+04, 0.10230000E+04, -.10692200E+04, -.46881900E+03, 0.84005600E+03, -.97690200E+03, -.23857600E+03, -.71264700E+03, 0.16614200E+04, 0.30522500E+04, -.15155700E+04, -.12158400E+04, -.15216800E+04, 0.53269700E+02, -.36320000E+03, 0.49622200E+02, 0.10867900E+03, -.10465200E+04, -.49672400E+03, -.25494000E+04, 0.23802200E+03, -.12205600E+03, -.54521200E+03, -.12213100E+03, -.11250900E+04, -.85179000E+03, 0.37446100E+03, 0.13427900E+04, 0.13088800E+04, -.78183200E+03, -.21365500E+03, -.80144700E+03, 0.27262100E+03, -.36665100E+03, 0.40059900E+03, 0.36192500E+03, -.24244200E+03, 0.56887300E+03, 0.29120300E+03, 0.45635700E+03, -.11818900E+03, 0.16294500E+03, -.21872800E+04, 0.11004200E+04, 0.19764600E+04, 0.10963900E+04, -.41707500E+03, -.91429700E+03, 0.18340700E+04, 0.28430200E+04, 0.53500000E+04, -.17810000E+04, 0.37617400E+04, 0.12331900E+05, -.60697400E+04, -.10181600E+05, -.61661100E+04, -.15871900E+04, -.25298000E+04, -.25032300E+03, 0.64046200E+04, 0.46136900E+03, -.30619300E+04, -.39326800E+04, 0.15725500E+04, -.73269800E+03, -.71279200E+03, -.78611400E+03, -.48518200E+03, -.55801500E+03, -.18129800E+03, 0.37306600E+02, 0.33809000E+02, -.44010400E+03, -.74482600E+03, 0.41841300E+03, -.19730400E+03, 0.60378500E+03, -.20520300E+03, 0.86784200E+03, 0.56111700E+03, -.32883300E+03, -.11565900E+04, -.12902200E+04, 0.73804100E+03, 0.33989500E+02, 0.28569400E+04, -.13965600E+04, -.90766400E+03, -.14332200E+04, -.51859100E+03, -.33883300E+03, -.64062800E+03, 0.16357700E+03, -.41232400E+03, -.16000700E+03, -.81579600E+03, 0.14835500E+04, -.71340100E+03, 0.23991200E+03, -.74284200E+03, -.28483600E+03, 0.47627800E+03, -.64709800E+03, -.66790500E+02, -.52188400E+03, 0.55449600E+03, -.96794600E+03, 0.23940800E+04, -.11747700E+04, -.21159600E+04, -.11879400E+04, 0.16860500E+04, 0.20063800E+04, -.29063300E+04, -.19505800E+04, -.13767500E+04, 0.11039700E+04, -.86330000E+03, 0.13244500E+05, -.65071000E+04, -.87839300E+04, -.66224800E+04, -.15751500E+04, -.24750600E+04, -.78618800E+03, 0.50247600E+04, -.94443800E+03, -.26584700E+04, -.42830600E+04, 0.15263600E+04, -.77427500E+03, -.29566800E+03, -.76321800E+03, -.41206000E+03, -.14164300E+03, -.30399200E+03, 0.10325600E+04, 0.79443200E+03, -.34882600E+03, -.59744600E+01, -.50254500E+04, 0.24047700E+04, 0.35578200E+04, 0.25129900E+04, -.41878300E+03, 0.76180200E+03, 0.44866600E+02, -.40202000E+04, -.15898600E+04, 0.98017800E+03, 0.25268400E+04, -.11458600E+04, 0.52555300E+03, 0.25036800E+03, 0.56886800E+03, -.10150600E+04, -.47525100E+03, 0.20898600E+03, 0.12731600E+04, 0.12711900E+04, -.29716600E+03, 0.12536700E+04, -.10629400E+04, 0.43791100E+03, 0.59339700E+03, 0.54208100E+03, 0.70837300E+03, 0.10741100E+03, -.79371800E+03, -.53425700E+03, 0.72960100E+03, 0.12186000E+03, 0.20488900E+04, -.12687300E+03, 0.65649900E+02, -.28467100E+03, -.31446500E+03, -.18482400E+03, 0.87962700E+02, -.16774700E+03, 0.40816000E+03, -.12800900E+03, -.11814500E+03, -.22207100E+02, 0.65901400E+01, -.10900000E+03, 0.18892200E+03, 0.43186300E+03, 0.13308800E+04, 0.36343800E+03, 0.14088400E+03, -.31497200E+03, 0.13557400E+03, -.34172700E+03, -.10241300E+04, -.16112800E+04, -.40132900E+02, 0.98936400E+02, -.61251500E+02 },
        { -.12832000E+01, -.55287100E+00, 0.27248300E+00, 0.57970400E+00, 0.11067200E+01, 0.35438300E+00, 0.90018500E+00, 0.14101800E+00, 0.50941700E-01, -.82638500E+00, 0.29890700E+00, 0.94441700E-01, 0.13043200E+00, 0.48916200E-01, -.10424600E+00, 0.72836600E+01, 0.14981000E+01, 0.49445200E+00, 0.72050900E+00, 0.19849400E+00, -.22689000E+00, 0.30198600E-01, 0.15362400E-04, 0.41551000E+00, -.13559900E-01, -.38370700E-01, -.14088500E+00, 0.33177100E+00, -.20913000E+00, -.18982400E-01, -.38191900E+00, 0.24514700E+00, 0.10580400E+00, 0.18799600E+01, 0.33480700E-01, 0.15228500E-01, -.13751300E-01, -.44985400E+00, -.10013600E+00, 0.14667600E+00, 0.35396200E-01, -.13674300E-01, -.38963100E-01, -.42221100E-01, 0.22108800E-01, 0.46603600E+00, -.25187700E-01, 0.20734500E-01, 0.33061000E+00, 0.15571100E+00, 0.20129800E+00, -.51524400E+00, -.12196600E+00, -.12193700E+01, 0.26521800E+00, -.37938000E+00, 0.23202100E+00, 0.95857700E-01, 0.10227900E-01, 0.26412800E+00, -.14648100E+00, 0.64949100E+00, -.21806800E+00, 0.40708400E-01, -.34937000E+00, -.27573200E+00, 0.56705200E+00, 0.10832000E+00, 0.50210800E+00, 0.14511200E-01, 0.75177900E-01, 0.16991700E+01, 0.29653100E+00, -.19678200E+00, -.11827800E+00, -.58071400E+03, 0.52091900E+03, 0.25533000E+03, -.17672000E+03, 0.65520500E+03, -.12704100E+03, 0.40061300E+02, 0.25163000E+03, 0.20277800E+03, -.94759200E+02, 0.90078500E+02, -.23800900E+02, -.39888800E+03, 0.12447100E+04, -.56754000E+03, -.83234700E+03, -.62266600E+03, -.25372800E+03, -.56231800E+03, -.12215200E+03, 0.19912400E+03, 0.18730300E+03, -.37035300E+03, -.64716400E+03, -.19111700E+04, 0.84206900E+03, 0.10480400E+04, 0.95543900E+03, 0.18864700E+03, 0.31619500E+03, 0.26344400E+03, -.48537400E+03, -.25330700E+02, 0.40402200E+03, 0.40526000E+03, 0.74995400E+03, -.33109600E+03, -.49858200E+03, -.37577500E+03, -.46350300E+03, -.44030800E+03, 0.22838500E+03, 0.55763900E+03, -.36671300E+03, -.32339300E+03, -.15221900E+03, -.23292000E+03, 0.86678700E+02, 0.33067000E+03, 0.11709100E+03, 0.15142400E+03, -.17739000E+03, -.82501400E+02, -.72120400E+02, 0.91707200E+03, -.43376100E+03, 0.15900000E+03, -.97979800E+03, 0.26808000E+03, -.45839800E+03, 0.48993300E+03, 0.79644000E+02, -.78385800E+02, 0.33619900E+03, 0.80920300E+01, 0.39204400E+03, 0.28009900E+02, 0.49051500E+03, -.17377400E+04, 0.89305900E+03, -.20792900E+04, 0.86836800E+03, -.13663500E+03, 0.31003200E+03, -.47525700E+03, -.14975800E+04, 0.77666100E+03, 0.11073900E+04, 0.46310000E+03, 0.12653600E+04, -.49176600E+03, -.51758700E+04, -.63265100E+03, -.24923300E+03, -.89416800E+03, -.39037700E+03, -.35213000E+03, -.50481200E+02, -.51366900E+03, -.97868800E+03, 0.45355600E+03, -.11271100E+03, 0.32315100E+03, -.22675800E+03, -.16295900E+03, -.14975900E+03, 0.76671800E+02, 0.10342900E+03, 0.29532600E+03, -.25720700E+03, -.35613500E+02, 0.21128700E+04, -.10293800E+04, -.37876100E+03, -.10569900E+04, -.99734200E+02, 0.48900500E+03, -.87581000E+02, -.64649200E+02, -.12617100E+04, 0.54273300E+03, -.96172900E+03, 0.10036500E+04, -.44755700E+03, 0.17745500E+03, -.50179500E+03, -.14561600E+03, -.93805300E+02, -.88999700E+02, 0.16665400E+03, 0.16315400E+03, -.19881300E+03, -.76809700E+02, 0.17637900E+04, -.83942200E+03, 0.16380900E+03, -.88164900E+03, 0.18812300E+02, 0.18263700E+03, -.55961500E+03, -.49413500E+01, -.47387700E+03, -.24951400E+02, -.71155800E+03, -.33067000E+04, 0.17041600E+04, -.18340800E+04, 0.16516800E+04, -.63812600E+03, -.11777900E+03, 0.10367200E+04, 0.28731600E+03, 0.10903000E+04, 0.16950500E+03, 0.20104200E+04, 0.17813900E+04, -.71369000E+03, -.26437100E+04, -.89065200E+03, -.18673400E+03, -.87719900E+03, -.19467400E+03, 0.10659300E+03, -.25199700E+03, -.51486700E+03, -.13532000E+04, -.23204800E+04, 0.11574200E+04, -.28725900E+03, 0.11602500E+04, -.11200500E+03, 0.27121700E+03, 0.13797400E+03, -.43502800E+03, 0.10166700E+04, 0.18476800E+03, 0.11452400E+04, -.19730300E+04, 0.80771500E+03, 0.48051500E+04, 0.98646500E+03, 0.46483000E+03, 0.49283100E+03, 0.41665600E+03, -.36709700E+03, -.25087300E+03, 0.45637100E+03, -.82293400E+02, -.10434200E+04, 0.42772200E+03, 0.29040900E+03, 0.52244000E+03, 0.23628100E+03, -.17875600E+03, -.81363400E+02, 0.16449700E+03, 0.87991500E+03, -.34286100E+03, 0.17101500E+03, 0.54816600E+03, -.43240400E+03, -.29329100E+03, -.27609600E+03, 0.22476400E+02, -.60515000E+03, 0.93019600E+03, 0.12730200E+04, 0.37280500E+03, -.43628100E+03, -.88712200E+03, 0.89456800E+02, -.50388200E+02, 0.54212300E+01, -.76173700E+00, -.10988700E+02, -.19129400E+02, 0.73387800E+02, -.45826000E+02, 0.17863300E+02, -.15168300E+03, -.58853800E+02, 0.41977900E+02, 0.17398600E+03, 0.45081600E+02, -.41500400E+02, 0.71302800E+03, 0.87431900E+01, 0.35083500E+02, 0.41401100E+01, 0.54221200E+01, 0.28087700E+03, -.48278800E+03, -.87205400E+03, 0.10435100E+03, 0.75339900E+02, -.67244500E+02 },
        { -.51427600E+01, -.23439200E+01, 0.23855600E+01, 0.35845800E+01, 0.15677300E+01, 0.15400700E+01, 0.26399900E+01, -.98652400E+01, -.26158900E+00, -.27338500E+01, -.12174400E+01, 0.17575900E+00, 0.13863700E+00, -.53976300E-01, -.47812700E+00, 0.65406500E+01, 0.32993800E+01, 0.66396400E+00, -.32125900E-01, 0.78152200E-01, 0.23453800E+01, 0.22659600E-02, 0.90500900E-01, -.51502800E-01, 0.12753100E+00, -.76170900E-01, -.29721100E+00, -.16533200E+01, 0.23451200E+01, 0.98128600E-01, -.73390400E+00, -.17900800E+01, 0.43792200E+00, -.14289500E+01, -.38168300E-01, -.17921100E+00, 0.10005500E+00, 0.14717100E+01, -.72591700E-01, 0.87279300E+00, 0.97045600E+00, -.51968300E+00, -.20786600E+00, -.49836300E+00, -.10137400E+01, 0.99352500E+00, -.15746200E+00, -.32327800E-01, -.31082800E+01, -.23120000E+00, 0.24811600E-01, -.94523800E+00, 0.23239100E+00, -.48772500E+01, -.10033800E+01, 0.13448400E-02, -.50131200E-02, -.56798500E+00, -.64889200E-01, 0.14507300E+00, -.13226800E+00, 0.26232400E-01, 0.35134300E+00, -.61123700E+00, -.23822200E+00, -.12388800E+01, -.17707100E+01, -.87848300E-01, 0.84671200E+00, 0.33228300E-01, -.12396500E-03, 0.33485300E+01, 0.88510100E+00, 0.30427300E+01, -.15081200E+01, -.16928400E+01, -.72585100E+04, 0.50893100E+04, -.25663900E+04, -.11264500E+04, -.25464200E+04, -.15869900E+04, -.47670500E+03, -.16126700E+04, -.15732400E+04, -.24095500E+04, -.38055000E+03, -.31724400E+04, -.42105600E+04, 0.21499500E+04, 0.24409200E+04, 0.21061500E+04, 0.84243100E+03, 0.64362300E+03, 0.29274300E+03, -.21244500E+03, 0.18087100E+04, 0.77373300E+03, 0.37030700E+04, -.33687000E+04, 0.16264300E+04, 0.74469600E+03, 0.16847600E+04, -.78209000E+03, 0.39843700E+02, 0.91673500E+03, -.20287100E+04, -.11736400E+04, -.23044500E+03, 0.14845400E+04, -.12734600E+04, 0.65185800E+03, -.14362300E+03, 0.63903500E+03, 0.89100200E+03, 0.44027300E+03, 0.12497100E+04, 0.11438900E+04, -.44042900E+02, 0.22425100E+03, -.29060100E+04, 0.24052500E+04, -.11925900E+04, 0.16665800E+03, -.12042000E+04, -.20311000E+04, -.12832500E+04, 0.55158500E+03, 0.31887100E+04, 0.31214600E+04, -.17665600E+04, -.20113000E+03, -.51130500E+04, 0.24438200E+04, 0.97191100E+03, 0.25564700E+04, 0.13947600E+04, 0.69197500E+03, 0.88157300E+03, -.23044600E+02, 0.15388500E+04, 0.75758600E+03, 0.17337000E+04, -.91342200E+04, 0.46160600E+04, -.27518100E+04, 0.45685300E+04, -.20276600E+01, -.61545300E+02, 0.31755300E+04, 0.23692900E+04, 0.60393700E+04, -.67965700E+02, 0.18125300E+05, -.41071000E+04, 0.21931400E+04, -.49840300E+04, 0.20534700E+04, -.16963700E+04, -.16537000E+04, 0.34232500E+04, 0.50453900E+04, 0.55903800E+04, -.21682600E+04, 0.10057800E+05, 0.85226700E+03, -.39167800E+03, 0.14146900E+03, -.42607500E+03, -.88735200E+03, -.17123300E+04, 0.46940300E+03, 0.24585300E+03, 0.12484100E+04, -.16501600E+04, -.17332800E+04, 0.20797000E+04, -.10426500E+04, 0.24365600E+03, -.10382500E+04, 0.18130700E+04, 0.56417100E+03, -.13620000E+04, -.29341200E+04, -.37936500E+04, 0.90217600E+03, -.35316800E+04, 0.25806600E+04, -.12723200E+04, -.45748600E+03, -.12939300E+04, -.85454300E+03, -.11650200E+04, -.15961500E+03, 0.82334000E+03, 0.12148200E+04, -.10360300E+04, -.92352300E+03, 0.18397000E+04, -.88721200E+03, 0.20191500E+03, -.92037800E+03, -.11837100E+04, -.45520900E+03, -.37270000E+03, 0.67748500E+02, 0.64570600E+03, -.23085800E+03, -.18131000E+04, 0.44873500E+04, -.22125900E+04, -.91195500E+04, -.22389700E+04, 0.11270300E+04, 0.95720000E+03, -.99752400E+03, 0.84359600E+03, -.16457200E+04, 0.69847000E+03, -.13419400E+04, 0.57819600E+04, -.27586400E+04, -.46592100E+04, -.28911000E+04, -.17919200E+04, -.26915700E+04, 0.14474900E+04, 0.57155400E+04, 0.28373700E+04, -.25447400E+04, 0.43095000E+04, -.38232900E+04, 0.19283500E+04, -.34217600E+04, 0.19116200E+04, -.67184400E+03, 0.27085300E+03, 0.80440000E+03, 0.30175200E+03, 0.21538000E+04, 0.56773000E+02, 0.40630400E+04, 0.18605000E+03, -.22743500E+03, 0.80630700E+04, -.92890000E+02, 0.33957400E+03, 0.40933400E+03, -.14085800E+04, -.39877600E+04, -.52651600E+04, 0.10382100E+04, -.60015400E+04, -.24796600E+04, 0.12132300E+04, 0.14112800E+04, 0.12377200E+04, -.16591100E+04, -.57875000E+03, 0.91267900E+03, 0.15358500E+04, 0.29836500E+04, -.57160400E+03, 0.34191100E+04, -.37171700E+04, 0.17764800E+04, 0.36186000E+03, 0.18640200E+04, 0.40416300E+03, -.15128600E+04, 0.17978100E+04, -.48584000E+03, 0.20898800E+04, -.10412900E+04, -.12661100E+04, -.56747800E+03, -.21753800E+03, 0.35894500E+02, -.40884200E+02, -.11883300E+03, 0.81453500E+02, -.38211300E+03, -.25017500E+03, -.15230300E+03, -.23716100E+03, -.61794300E+03, 0.50715700E+02, 0.27942300E+02, -.97110700E+01, -.23282300E+03, 0.25194200E+04, 0.15554400E+03, 0.74069800E+03, -.45414600E+02, 0.16216200E+03, -.28680400E+03, -.21833000E+04, -.43564100E+04, 0.19327400E+03, 0.17454500E+03, 0.30566200E+03 },
        { 0.13821200E+01, 0.40967200E+00, -.33439300E+00, -.45880600E+00, -.13308200E+00, -.72102700E+00, -.20463400E+01, 0.11641600E+01, 0.76306300E-01, 0.13477600E+01, -.11354800E+00, -.22755600E+00, -.23887800E+00, 0.93029700E-01, -.96871300E-02, 0.98303300E-01, 0.64397700E+00, -.30178800E-01, -.47931500E+00, 0.99706200E-01, -.16491900E+00, -.54501500E+00, 0.30349600E-01, -.42911500E+00, -.12623600E+00, 0.16483100E-01, 0.19441400E+00, -.48517400E-01, -.17477900E+00, -.10759400E-01, 0.26713000E+00, 0.40933800E+00, -.33495900E+00, 0.34028100E+00, 0.22702400E-02, 0.14371800E+00, 0.13782000E-01, -.15376600E+00, 0.84490400E-01, 0.21734700E-01, 0.90809500E+00, -.38380200E+00, 0.44755500E-01, -.92960000E-01, 0.29977000E+00, -.24711100E+00, 0.33115500E-01, 0.88123000E-02, 0.11863000E-01, -.38906300E-01, -.16350600E+00, 0.40540800E+00, 0.28209500E+00, 0.32965200E+00, 0.46119300E-01, 0.33292800E+00, 0.11465900E+00, -.45961800E-01, 0.11891100E-01, -.15219500E+00, -.67086800E-01, 0.11569200E+00, 0.86122200E-01, -.68879300E-01, 0.84254600E-01, -.11793000E+00, -.55152600E+00, -.25618000E-01, -.88875800E-01, -.16746600E-02, 0.30049400E-01, -.12505800E+01, 0.88392300E-01, 0.12142400E+01, 0.30640500E+00, -.33527600E+00, -.20783000E+00, 0.33953300E+04, -.16771400E+04, -.64001600E+03, -.16990000E+04, -.75728300E+03, 0.56453500E+03, -.91452700E+03, -.86593900E+03, -.14388900E+04, 0.57469500E+03, -.43301100E+03, -.17617100E+04, 0.86690900E+03, -.41444700E+03, 0.88151200E+03, 0.31983700E+01, -.12128700E+03, 0.42373500E+03, 0.40069700E+02, 0.57534500E+03, -.66669900E+02, 0.11141800E+04, -.35787300E+03, 0.23553000E+03, 0.15468200E+04, 0.17925900E+03, -.24970100E+03, -.19779900E+03, 0.98702700E+02, -.40393100E+03, -.14743200E+03, -.25655600E+03, -.22650400E+03, -.13790000E+04, 0.66515900E+03, -.93764600E+03, 0.69121900E+03, 0.34779100E+03, 0.26749300E+03, 0.47009900E+02, 0.12068500E+03, 0.28269600E+03, 0.18033800E+03, -.17904100E+03, 0.16831300E+04, -.81925400E+03, -.10969400E+03, -.84279200E+03, -.26072900E+03, -.36280700E+03, 0.13842100E+03, 0.91695800E+03, 0.40987900E+03, -.55454900E+03, 0.33589400E+03, -.24331500E+04, 0.13274300E+04, 0.20121100E+03, 0.12165300E+04, 0.55550100E+03, -.34721200E+02, 0.69451200E+03, 0.31485700E+03, 0.71791500E+03, -.57005400E+01, 0.64217000E+03, -.14180100E+04, 0.71157000E+03, -.15918100E+04, 0.71008100E+03, -.33156700E+03, -.31067500E+03, 0.95748700E+03, 0.93335900E+03, 0.10440400E+04, -.26059000E+03, 0.18896200E+04, 0.78844500E+02, -.66365700E+02, -.39615600E+04, -.39491300E+02, -.79059500E+03, -.32461900E+03, 0.96553300E+03, 0.17042600E+04, 0.99825100E+03, -.44372400E+03, 0.10464700E+04, -.10077000E+04, 0.41937900E+03, 0.13344900E+04, 0.50409200E+03, -.17166900E+03, -.39146900E+03, 0.30063200E+03, -.17297300E+03, 0.57372600E+03, -.35774700E+03, 0.20998200E+03, 0.15030900E+04, -.77008800E+03, -.15993200E+02, -.75263800E+03, -.20749400E+03, 0.73674600E+02, -.86298100E+03, -.10387900E+04, -.12993600E+04, 0.35592200E+03, -.16156300E+04, -.19397700E+03, 0.50996300E+02, 0.10571000E+04, 0.97013600E+02, -.21068200E+03, -.35144300E+03, 0.14955400E+03, 0.12363200E+03, 0.54951200E+03, -.29966700E+03, 0.87037800E+01, 0.10879900E+04, -.56097200E+03, 0.38694100E+03, -.54441000E+03, -.11223200E+03, 0.16207900E+03, -.52781100E+03, -.10713800E+03, 0.63003500E+02, 0.15200500E+03, -.68498300E+03, 0.45922700E+03, -.25150500E+03, -.37024000E+04, -.22607000E+03, -.28842200E+03, 0.11697800E+03, 0.17820000E+03, 0.26953500E+03, -.56486400E+03, 0.20868500E+03, -.63799600E+03, 0.27560000E+04, -.14328000E+04, -.33912500E+04, -.13781000E+04, -.67338700E+03, -.54870700E+03, 0.23958000E+03, 0.18230600E+04, 0.41753100E+03, -.53579800E+03, -.25129300E+03, 0.54125700E+03, -.26446600E+03, -.64235800E+03, -.27064400E+03, -.26936500E+03, -.22900300E+03, 0.22356900E+03, 0.48717100E+03, -.10721700E+01, -.17952500E+03, 0.77738900E+02, -.28168700E+03, 0.20137900E+03, 0.38146300E+04, 0.14095900E+03, 0.23977700E+03, 0.63198100E+02, -.67165500E+03, -.11191500E+04, -.52302500E+03, 0.19539500E+03, -.12103400E+04, 0.54757700E+02, 0.23517600E+02, 0.68798100E+03, -.28959800E+02, 0.81411900E+02, -.10977200E+03, 0.40845800E+03, 0.56314100E+03, 0.58970000E+03, -.21768000E+03, 0.64606600E+03, -.29201200E+04, 0.15388800E+04, 0.17825600E+04, 0.14642300E+04, 0.85033200E+03, -.15289300E+04, 0.17212900E+04, 0.83908700E+03, 0.97889000E+03, -.12751900E+04, -.13777100E+04, -.41336600E+03, -.25633300E+03, -.48963900E+02, -.66834900E+02, -.11740900E+03, 0.42875300E+02, -.83041700E+02, 0.14243500E+03, 0.23118600E+02, -.24295500E+03, -.26200600E+03, -.15861300E+03, 0.12317600E+03, 0.89519600E+02, 0.13136000E+03, 0.65146900E+03, 0.78652900E+02, 0.39150500E+03, -.80246000E+02, 0.87815800E+02, 0.21196200E+03, -.67537800E+03, -.13758400E+04, 0.14912600E+03, 0.10002000E+03, 0.11030200E+03 },
        { 0.21050700E+01, 0.14552600E+00, -.17850100E+01, -.11463100E+01, -.73300800E+00, -.79755800E+00, -.11559800E+01, 0.40123600E+01, -.11302400E+00, 0.13683900E+01, 0.36248500E+00, -.74793700E+00, 0.25893100E+00, 0.48572300E-01, -.76068200E+00, 0.10763500E+02, 0.22384500E+01, 0.24348200E+01, 0.44057400E+00, -.72065700E+00, -.10622000E+01, -.30929300E-01, -.36600400E+00, -.19481000E+00, -.44730400E+00, 0.77313800E-01, -.39467900E+00, 0.54132000E+00, 0.10723200E+01, 0.26564700E+00, 0.13833400E+00, -.24577300E+00, -.14819300E+00, 0.25366300E+01, 0.96096100E-02, -.41738100E-01, -.30865300E-01, -.11147400E+01, 0.22370900E+00, -.10284200E+01, -.83865800E-01, 0.24792000E+00, 0.64358900E-01, 0.13965000E+00, 0.65831300E-01, 0.34186800E+00, -.77493200E-01, 0.25094800E-01, 0.12398700E+01, 0.15050000E-01, 0.36812600E+00, 0.81964600E-03, 0.35361600E+00, -.14291400E+00, 0.73296600E-01, -.21496300E+00, -.16325600E+00, -.13356400E-01, 0.28210900E-01, 0.84888500E-01, -.65547200E-01, 0.33160200E+00, -.36066600E-01, -.75511700E-01, 0.18957000E+00, 0.80862400E+00, 0.59852900E+00, -.15309400E+00, -.90975000E+00, -.80322200E-02, 0.10555600E+00, -.52735600E+01, -.46128300E+00, -.60561200E+00, 0.13278100E+01, 0.15143800E+00, -.60923400E-01, 0.78231000E+00, 0.10037000E+03, 0.51377300E+02, 0.17340800E+01, 0.82764100E+03, 0.16471900E+04, -.19802900E+03, 0.43120400E+02, -.58450800E+03, 0.14873400E+04, -.28188700E+03, 0.15814600E+03, -.19039800E+03, -.63398000E+03, -.79924000E+02, -.39206700E+03, -.46090000E+03, 0.54046900E+02, -.20647600E+03, -.45274900E+03, -.41218700E+03, -.58675800E+03, -.41820300E+03, 0.46637600E+03, 0.13225600E+04, 0.20868300E+03, 0.68665400E+03, 0.44782100E+03, -.19993500E+03, 0.51930300E+03, 0.11611300E+04, 0.42887900E+03, 0.11211800E+04, -.94762900E+03, 0.38035600E+03, -.17772400E+04, 0.47157800E+03, -.64744500E+03, -.55576600E+03, -.66093300E+03, -.91138700E+03, 0.83645300E+03, -.28075800E+03, 0.61557400E+03, -.10096400E+04, 0.57067300E+03, 0.49310400E+03, 0.50635500E+03, 0.10652900E+04, -.20065000E+03, 0.78575600E+03, 0.23667300E+03, -.57913900E+03, 0.32447200E+02, -.47034100E+03, 0.13300200E+04, -.16778800E+03, 0.84094000E+02, -.66495300E+03, -.22171600E+03, -.22229900E+03, -.47284900E+03, 0.22749000E+03, -.72182800E+03, -.33418600E+03, -.49531400E+03, 0.14962400E+04, -.80271600E+03, 0.57378300E+03, -.74950800E+03, -.65348800E+02, -.17606300E+03, -.87831700E+03, -.15998300E+04, -.14958500E+04, -.64505900E+00, -.14523000E+04, 0.28545100E+04, -.17177100E+04, -.39941600E+03, -.14271600E+04, 0.24037100E+03, 0.39433100E+03, -.12229300E+04, -.18594200E+04, -.21714200E+04, 0.75388800E+03, -.33435700E+04, -.20624100E+04, 0.76392700E+03, 0.23517400E+03, 0.10308600E+04, 0.35500000E+03, 0.61302900E+03, 0.25034300E+03, 0.54197900E+03, 0.86601700E+03, 0.49133300E+03, 0.94477400E+03, 0.63484400E+03, -.38489400E+03, 0.17699800E+03, -.31799900E+03, -.14865300E+04, 0.40289400E+03, -.81313900E+03, -.70327200E+02, 0.53758500E+03, 0.27312900E+03, 0.47871300E+03, -.29025900E+04, 0.13107900E+04, 0.76157000E+03, 0.14517000E+04, 0.37152500E+03, 0.33763900E+03, 0.63397900E+03, 0.33963800E+03, 0.10746800E+04, 0.19903200E+03, 0.57646400E+03, -.10871000E+04, 0.44185500E+03, 0.14286200E+02, 0.54406200E+03, 0.51069100E+03, 0.32079200E+03, 0.17704200E+03, 0.11934400E+03, 0.79975600E+03, 0.21942400E+03, 0.56444700E+03, -.16601800E+04, 0.71326100E+03, 0.15222700E+04, 0.82550900E+03, -.12771000E+04, -.65866200E+03, 0.39994500E+03, -.62585100E+03, 0.10466200E+04, -.37583700E+03, 0.66166700E+03, -.53418900E+03, -.10677700E+03, -.19738200E+03, 0.26722700E+03, 0.25973400E+03, 0.72007500E+03, -.56429300E+03, -.19313900E+04, -.13277300E+04, 0.78750900E+03, -.17787700E+04, 0.24824400E+03, -.12323700E+03, 0.12028500E+04, -.12410200E+03, 0.65835000E+03, 0.30982900E+02, 0.67632400E+01, -.11162300E+03, -.23736100E+03, 0.18343800E+03, -.13116600E+04, -.13411500E+04, 0.10596800E+04, 0.12394900E+03, 0.67042200E+03, 0.39285000E+03, 0.60406600E+03, 0.36961100E+03, 0.19606700E+04, 0.21547300E+04, 0.14006600E+03, 0.22031300E+04, 0.20697600E+04, -.82249600E+03, 0.24666300E+03, -.10328200E+04, 0.14061700E+04, 0.17178200E+03, 0.64940700E+02, -.11301200E+03, -.16134700E+04, 0.14213400E+03, -.21418800E+04, -.89354000E+03, 0.80726000E+03, 0.30451200E+04, 0.44143200E+03, 0.89206900E+03, -.43168600E+03, 0.25328300E+03, 0.16801200E+04, 0.70444200E+03, -.85510700E+03, -.66286500E+03, -.63206300E+02, -.75781900E+02, -.62237500E+02, -.52154800E+02, -.45526100E+02, 0.17120400E+01, 0.11212300E+03, 0.50250900E+03, 0.17526100E+03, -.55573800E+02, 0.90922900E+02, -.48714300E+03, -.22161000E+02, 0.95980300E+00, 0.41151800E+03, -.32974700E+03, -.13874800E+02, -.10013300E+03, -.38521400E+02, 0.22249600E+02, 0.50397100E+03, 0.28191000E+03, 0.71260100E+03, 0.20768100E+03, -.80058600E+02, -.12053600E+03 },
        { 0.62010600E+01, 0.27606400E+01, 0.55499300E+01, 0.18625200E+01, -.10112400E+01, -.19649000E+01, -.26966300E+01, 0.61475600E+01, 0.25940500E+00, 0.17115300E+01, -.40748700E+00, -.11115300E+01, -.10629800E+01, 0.73798100E+00, 0.11279700E+01, -.17036000E+02, -.93557100E+00, -.13854500E+01, -.17315600E+01, 0.89453200E+00, -.43499700E+00, -.37930800E+00, 0.24502000E-01, -.14333700E+01, 0.46348100E-01, 0.92114800E-02, 0.28146900E+00, -.25971800E+01, -.18557300E+00, 0.20418100E-01, 0.12157800E+01, 0.23119500E+00, -.26709000E+00, 0.11720500E+01, -.50758700E-01, 0.32008400E+00, 0.11568600E+00, -.57397600E+00, -.33244600E-02, 0.61010000E+00, -.30057900E+01, -.24887000E+00, -.72472400E-02, 0.20668600E+00, 0.15065500E+01, 0.12896500E+00, 0.42536000E-01, 0.25297600E+00, 0.64946700E+01, -.23638300E+00, 0.26797600E+01, 0.79004600E+00, 0.12792500E+01, -.10469900E+01, 0.75628800E+00, -.11778000E+01, 0.22118100E+00, 0.31577400E+00, 0.24187600E+00, -.54575500E+00, -.82295500E+00, 0.44431400E+00, -.20988900E+00, 0.12295300E+01, 0.74547700E+00, 0.74025900E+00, 0.89660300E+00, -.33422800E+00, -.18552600E+00, -.14228100E-01, 0.13409000E+00, -.21930300E+01, -.21026700E+01, -.64756400E+01, 0.12622800E+01, 0.17960600E+01, 0.29332400E+00, -.18439600E+01, 0.11408300E+01, -.52022000E+04, -.17988800E+01, -.92167700E+03, -.39407300E+04, 0.37335400E+03, 0.12336500E+03, -.40481900E+03, -.31280800E+04, 0.32720000E+03, -.95676000E+04, 0.48093000E+04, 0.10743700E+05, 0.47846800E+04, 0.20380700E+04, 0.37118900E+04, 0.15697900E+04, -.25762500E+04, -.19041800E+04, 0.35329800E+04, 0.52853700E+04, 0.13999700E+05, -.70742900E+04, -.15101000E+05, -.69994200E+04, -.25846000E+04, -.46587000E+04, 0.47383000E+03, 0.54897700E+04, -.15106300E+04, -.40389800E+04, -.72438500E+04, -.88643900E+04, 0.44362600E+04, 0.17590900E+05, 0.44345000E+04, 0.25183600E+04, 0.37780200E+04, -.50423900E+03, -.21538500E+04, 0.29520100E+04, 0.25942800E+04, 0.47708800E+04, 0.37189600E+04, -.18344700E+04, -.62933100E+04, -.18611000E+04, -.23120100E+04, 0.14260600E+04, -.10576000E+04, -.22651000E+04, -.44634200E+04, 0.18410500E+04, 0.23515600E+04, 0.11220700E+04, -.69251200E+03, 0.11996900E+04, -.56109800E+03, 0.36776100E+03, 0.96419200E+03, -.18576500E+03, -.13488100E+04, -.16710700E+04, 0.13537600E+04, -.14907500E+04, 0.72016700E+04, -.35790100E+04, -.64786500E+03, -.35993900E+04, -.23585000E+04, 0.92626200E+02, 0.76068000E+01, 0.33812600E+04, -.32089900E+04, -.73408700E+03, 0.10171200E+04, 0.13922400E+05, -.68762900E+04, 0.66296500E+04, -.69612900E+04, -.93225100E+04, -.39814000E+04, 0.51469300E+03, 0.11245200E+04, -.82729800E+04, -.39892900E+04, 0.48594700E+04, -.32698200E+03, 0.36024200E+03, -.14866100E+04, 0.16385500E+03, 0.10460400E+04, 0.95552700E+03, -.46158700E+03, -.28839500E+04, -.39223300E+04, 0.14452700E+04, -.75004000E+03, -.15595100E+05, 0.77864200E+04, 0.10525600E+04, 0.77977500E+04, 0.37935300E+04, -.37646600E+04, 0.53924200E+04, 0.29681600E+04, 0.75128600E+04, -.37194300E+04, 0.35258200E+04, -.12913200E+04, 0.75503000E+03, -.15946100E+04, 0.64469400E+03, 0.53552000E+03, 0.48581500E+03, 0.12653600E+03, -.22019100E+04, -.26618900E+04, 0.95671400E+03, 0.10348200E+03, -.78455900E+04, 0.39483400E+04, 0.18822900E+03, 0.39222400E+04, -.78057100E+03, -.13190000E+04, 0.19579400E+04, -.58684100E+03, 0.30947200E+04, -.10742900E+04, 0.47670600E+04, 0.86005100E+03, -.42278400E+03, 0.12256800E+05, -.42527800E+03, 0.59097600E+03, 0.23657800E+03, 0.14953000E+04, 0.55750700E+03, -.17665700E+04, -.27584600E+03, -.51837200E+03, 0.51944700E+04, -.25025500E+04, 0.88457900E+04, -.25973800E+04, -.58693700E+04, -.24003700E+04, 0.98251600E+03, -.52873900E+03, -.55299600E+04, -.20297700E+04, 0.53800500E+04, 0.12128100E+05, -.60617500E+04, -.62320500E+04, -.60640700E+04, -.37637300E+04, -.18654300E+04, -.14176000E+04, 0.20892300E+04, -.34196500E+04, -.22540400E+04, -.13864600E+04, 0.39930000E+04, -.20963500E+04, -.13076500E+05, -.19963400E+04, 0.23313500E+04, -.36636000E+04, 0.15403000E+04, 0.29303600E+04, 0.12519700E+04, -.21181100E+04, -.76226100E+04, 0.10147800E+05, -.50940800E+04, -.12690600E+05, -.50760400E+04, -.42417800E+04, -.41917500E+03, -.18228600E+04, 0.30315500E+03, -.21603800E+04, -.25400900E+03, -.22328600E+04, -.41066500E+04, 0.19379200E+04, -.45499900E+04, 0.20589100E+04, 0.62248700E+03, 0.38896500E+04, 0.33681200E+03, -.71145100E+04, -.42475300E+04, 0.55931500E+04, -.12265800E+04, -.83452800E+03, 0.19155300E+03, 0.40959100E+03, 0.46136900E+03, 0.28994400E+03, 0.11253400E+03, -.82456300E+03, -.85162500E+03, -.52462700E+03, 0.10474100E+04, 0.14442100E+03, -.43395000E+02, -.84569700E+03, -.26889800E+03, -.77371200E+03, -.33630100E+03, -.42938300E+03, -.55779300E+03, 0.40966100E+03, -.32614500E+02, -.15609300E+04, 0.46211200E+03, -.22480600E+03, -.51873500E+03, 0.50668400E+02, 0.10613000E+04 },
        { -.10216900E+02, -.27438700E+01, 0.28929300E+01, 0.21026200E+01, 0.68181800E+01, 0.40238600E+01, 0.20448700E+01, 0.16066000E+02, -.65034700E+00, 0.39895600E+01, 0.25042100E+01, -.24436700E+00, 0.37200600E+00, -.49051600E+00, -.47341300E+00, 0.71763700E+01, -.39689800E+01, -.35454200E+01, 0.22460400E+01, 0.24773000E+01, 0.16560300E+01, -.47814300E+00, 0.20221400E+00, 0.98536600E+00, -.37082400E+00, -.94989500E+00, -.51747800E+00, -.13810800E+00, 0.42746900E+00, -.10995400E+00, -.80609500E+00, -.45204600E+00, 0.13690000E+00, 0.40252400E+01, -.61922200E-01, 0.70362700E-01, 0.16526300E+00, -.13761700E+01, -.98098400E-01, 0.18841000E+00, 0.21304900E+01, -.78083700E+00, -.93722200E-01, -.46054400E-01, 0.39266100E+00, -.36808400E-04, 0.20868700E-01, -.72416400E-01, 0.13041500E+01, 0.17275400E+00, 0.28949200E+00, 0.14267100E+00, 0.79378100E+00, 0.17720700E+01, 0.10250000E+00, 0.16606800E+00, 0.71729300E+00, -.21126500E+00, 0.37372000E+00, 0.35732200E-01, -.41482700E+00, 0.71009100E-01, 0.19461700E+00, -.13317000E-01, 0.90299200E+00, 0.40424100E+00, 0.50829700E-01, 0.75309400E-01, -.92218700E+00, -.18555500E+00, -.58032400E-01, -.39343700E+01, -.40869300E+00, -.54332400E+01, -.34650700E+00, 0.36169500E+00, 0.33772500E+00, -.66629500E+00, 0.66392400E+00, 0.14514600E+00, -.30200600E+02, 0.10562900E+02, 0.51743200E+03, -.47103700E+03, -.84214400E+03, -.55339900E+03, 0.70970200E+03, 0.17567800E+02, -.51697200E+04, 0.25921000E+04, 0.47511800E+04, 0.25981500E+04, 0.45488700E+03, 0.59093900E+03, 0.94471700E+03, -.25544500E+04, -.17599600E+04, 0.90744400E+03, 0.14902500E+04, 0.11797800E+05, -.59046500E+04, -.93427100E+04, -.59067000E+04, -.10821800E+04, -.22328300E+04, -.26530100E+03, 0.50353400E+04, -.61917900E+03, -.22290900E+04, -.37659400E+04, -.38594100E+04, 0.19353500E+04, 0.15917500E+04, 0.19545600E+04, -.19229000E+03, -.58014900E+03, 0.39725800E+02, -.12076800E+04, 0.25065100E+04, -.39149000E+03, 0.28779900E+04, 0.22310700E+04, -.11012300E+04, -.24024000E+04, -.11588400E+04, -.14820600E+04, -.40318200E+03, 0.61704000E+03, -.15359500E+04, -.27568200E+04, 0.50750900E+02, -.74555400E+03, -.75222500E+02, 0.32465900E+02, 0.84014100E+03, 0.39051000E+02, -.23900700E+03, -.23526700E+03, 0.26924800E+03, -.52438600E+03, -.33277000E+03, 0.24105500E+02, -.83315600E+03, 0.21373100E+04, -.10564300E+04, -.50483100E+04, -.10581800E+04, -.17617300E+04, 0.58701000E+03, -.15062900E+04, -.15748600E+04, -.25712300E+04, 0.39707800E+02, 0.15655300E+04, 0.11239400E+05, -.55989900E+04, 0.35093600E+03, -.56193000E+04, -.53239200E+04, -.30983400E+04, -.14402700E+04, -.21777000E+04, -.79552200E+04, -.23713800E+04, -.58382100E+03, 0.10375500E+03, 0.10201500E+02, 0.51292200E+03, -.50460300E+02, 0.76000300E+03, 0.85783600E+03, -.28804500E+03, -.14479000E+04, -.27786400E+04, 0.11964500E+04, -.22520300E+03, -.80053500E+04, 0.39818200E+04, 0.36435000E+04, 0.40433300E+04, 0.27954300E+04, 0.10267800E+04, 0.24232200E+03, -.10706000E+03, 0.33238300E+04, 0.57887300E+03, 0.39427500E+04, -.25723700E+04, 0.13264400E+04, 0.88762200E+03, 0.12904100E+04, 0.82825700E+03, 0.99474200E+03, 0.19904700E+03, -.17868300E+04, -.17025900E+04, 0.12346900E+04, 0.58674400E+03, -.19894500E+04, 0.99024000E+03, 0.35984400E+03, 0.10019500E+04, -.13515600E+02, -.54259400E+03, 0.11738100E+04, -.18655200E+03, 0.66717900E+03, -.41059600E+03, 0.11113100E+04, -.93620200E+04, 0.46748500E+04, 0.47678300E+04, 0.47150500E+04, -.32763400E+03, 0.71582800E+03, -.13093900E+01, -.37320400E+04, 0.59475500E+03, 0.11846000E+04, 0.47593400E+04, 0.33348800E+04, -.16570200E+04, 0.45739900E+04, -.16670200E+04, -.31257400E+04, -.16027100E+04, -.51104000E+03, -.30590200E+04, -.59467400E+04, -.99771600E+03, 0.97210700E+03, 0.47731300E+04, -.23824700E+04, -.56185500E+04, -.23862000E+04, -.19140800E+04, -.68394700E+03, -.83941200E+03, 0.63643300E+03, -.89843100E+03, -.96326000E+03, -.31751300E+03, 0.10004100E+05, -.50087200E+04, -.39384900E+04, -.50233500E+04, 0.13717600E+04, -.23151500E+04, 0.15472600E+04, 0.62079000E+04, 0.10360700E+04, -.23137900E+04, -.59066400E+04, 0.76654400E+04, -.38143100E+04, -.60048900E+04, -.38610900E+04, -.19663300E+04, -.14852700E+04, 0.51708800E+03, 0.26972300E+04, -.12522200E+04, -.14891600E+04, -.37660300E+04, -.21991500E+04, 0.10996300E+04, 0.30097100E+04, 0.11559700E+04, 0.13373400E+04, -.79477900E+01, 0.92455300E+03, -.58474900E+03, -.25586200E+04, 0.97013800E+03, -.12403100E+04, -.17124200E+03, -.14709700E+03, 0.34952500E+02, 0.76750600E+02, -.72135000E+02, 0.27376400E+03, -.14251000E+03, -.36711500E+03, 0.44033200E+02, 0.33256100E+03, -.65023500E+03, -.67332600E+03, -.99440500E+02, 0.63342300E+02, -.32869500E+03, -.58299900E+02, -.63929700E+02, 0.22638700E+02, 0.59511300E+02, 0.21468900E+03, 0.67857000E+03, 0.32190700E+03, 0.34136600E+01, 0.20963500E+03, 0.33029700E+03, -.80382900E+02 },
        { -.97234500E+01, 0.35346100E+01, 0.18738900E+01, -.20894300E+01, 0.18645200E+01, -.14587800E+01, -.19795200E+01, 0.15267200E+01, -.22706200E+01, 0.30698500E+00, 0.10555300E+01, 0.53643100E+00, 0.27194500E+01, -.35860000E+00, -.55277600E+00, -.44461900E+01, 0.59455300E+01, -.49294200E+00, 0.30842600E+01, 0.57114300E+00, -.13556600E+01, -.14438100E+01, -.40299200E+00, 0.42202800E+01, -.67075400E+00, 0.32178500E+00, 0.25260900E+01, 0.43891000E+01, -.75948900E+01, 0.27834900E+00, 0.18228600E+01, -.15243200E+01, -.12352300E+01, -.32920100E+01, 0.36686200E+00, 0.23010400E+00, 0.77274200E-01, 0.37321300E+01, 0.67024000E+00, -.47162800E+00, 0.76440100E+01, -.55063900E+00, -.24043800E+00, 0.34229700E+00, -.54247000E+00, -.33907400E+00, -.43144100E-01, -.84454300E-01, 0.17671200E+01, 0.39080800E-01, -.67417000E+00, -.23999100E+01, 0.27207600E+01, -.28776400E+01, -.19255600E+00, -.21221000E+01, -.10036900E+01, -.32281900E+00, -.56964400E-01, -.28408700E+01, 0.36021300E+00, -.11935100E+01, 0.53681000E-01, 0.21968900E-01, -.20250500E+01, 0.11499600E+00, 0.85101700E-01, 0.16990800E+00, -.42228200E+01, -.91148900E-01, -.25764600E+00, -.10422000E+02, -.29869700E+01, 0.95612000E+00, 0.17517900E+01, -.37101900E+01, 0.16882100E+00, 0.38113400E+01, -.21725300E+01, -.53204800E+00, -.11104100E+00, 0.53963900E+04, 0.79058000E+04, 0.15792300E+04, 0.24469800E+04, -.21386100E+04, 0.66789200E+04, -.20231400E+04, 0.95697200E+04, -.47684300E+04, -.47687300E+04, -.47850300E+04, -.39953500E+04, -.25638700E+04, -.35501700E+04, -.19783400E+04, -.48555500E+04, -.24168700E+04, -.44430100E+04, 0.88404400E+04, -.44838600E+04, -.11996900E+04, -.44219100E+04, 0.33672100E+04, 0.14974200E+04, 0.89277700E+03, 0.78361100E+04, 0.67370900E+04, 0.42700400E+03, -.42858100E+04, -.87504900E+04, 0.43959300E+04, 0.32165700E+03, 0.43736800E+04, -.52314400E+04, -.41963300E+04, -.38700900E+03, -.55900500E+04, -.21458300E+03, -.15078900E+04, 0.41168200E+04, 0.14631200E+04, -.70293200E+03, -.51646100E+04, -.73351600E+03, 0.61864800E+03, -.33836500E+04, 0.24950400E+04, 0.32483400E+04, 0.59076000E+04, -.38059700E+04, -.25911800E+04, 0.54126700E+04, -.28486000E+04, -.28757300E+04, -.27060900E+04, -.13766900E+04, -.27401900E+04, -.14889600E+04, -.64272700E+01, -.21844900E+04, -.21778600E+04, -.23648400E+04, 0.32633600E+04, -.16010800E+04, -.54837700E+04, -.16332100E+04, -.13205700E+04, 0.26007100E+04, -.10531800E+05, -.21015600E+05, -.99855100E+04, 0.28036700E+04, 0.47672300E+04, 0.10599600E+05, -.52544600E+04, -.36497100E+05, -.52995600E+04, 0.28459700E+04, 0.25652200E+04, -.14404700E+05, -.19396400E+05, -.10551200E+05, 0.40303600E+04, -.35770100E+04, 0.26115100E+03, 0.28396900E+02, 0.33737500E+03, -.13138900E+03, 0.16590700E+04, 0.32979700E+04, -.24529800E+04, -.40428000E+03, -.32879000E+04, 0.27313500E+04, 0.90176000E+03, 0.13556000E+05, -.67950700E+04, 0.12700100E+03, -.67715100E+04, 0.12372500E+04, 0.93376700E+04, -.19009800E+04, 0.13225400E+03, -.92230600E+04, 0.83368700E+04, -.50139400E+04, -.31578300E+04, 0.16537100E+04, 0.22738200E+04, 0.15803800E+04, 0.19544200E+04, 0.31568900E+04, -.15324900E+04, -.21408000E+04, -.24361400E+04, 0.24938000E+04, 0.12334200E+04, 0.27999400E+04, -.13013500E+04, 0.32438000E+04, -.13982800E+04, 0.29521300E+04, 0.38021700E+04, -.28690200E+04, -.14708000E+04, -.10774200E+03, 0.25594500E+04, -.59104000E+03, -.41056500E+05, 0.20519700E+05, 0.60591100E+04, 0.20523200E+05, -.43005800E+04, -.31582400E+04, 0.78795700E+04, -.48742200E+04, 0.14262300E+05, -.86213700E+03, 0.18292100E+05, -.18372900E+04, 0.94604200E+03, -.19307800E+05, 0.91896500E+03, 0.17405500E+04, 0.28966500E+04, -.83164300E+04, -.15169500E+05, -.87149000E+04, 0.28135500E+04, -.72754700E+03, -.15667900E+05, 0.78434500E+04, 0.43438700E+04, 0.78340300E+04, 0.34998000E+04, 0.28518500E+04, 0.37123000E+03, -.50912000E+04, 0.38985800E+04, 0.29430900E+04, 0.46573400E+04, 0.18469000E+05, -.92697200E+04, 0.89161200E+04, -.92371700E+04, 0.11247200E+04, 0.35872700E+03, 0.39388100E+04, 0.19943200E+05, 0.86521700E+04, -.33525500E+04, -.11541700E+05, 0.32561000E+02, -.16322400E+02, -.41256400E+03, -.15442100E+02, 0.31611300E+04, -.14572200E+04, -.11380600E+04, -.52912500E+03, 0.83024300E+03, -.18193500E+04, -.32054400E+04, -.47084800E+04, 0.23098200E+04, 0.15785700E+05, 0.23503000E+04, 0.77880300E+04, 0.10023500E+04, 0.15133500E+04, 0.78696500E+04, 0.67863900E+02, -.37164200E+03, -.68452300E+04, -.19318500E+02, 0.32046100E+03, -.15116300E+03, -.17793000E+03, -.27599900E+03, 0.39594300E+02, -.34743200E+03, 0.20898300E+03, 0.32106800E+03, 0.76334100E+02, 0.17119300E+03, -.20274300E+04, 0.57897600E+03, 0.40958300E+02, -.16054200E+03, -.12098900E+04, -.43940500E+02, -.11503600E+04, -.45250000E+02, 0.34830500E+03, 0.37313900E+04, 0.11612800E+04, 0.62170300E+04, 0.60003700E+03, 0.16542600E+03, -.78095600E+03 },
        { 0.37465200E+01, 0.39530800E+00, 0.15362500E+00, -.48583400E-01, -.17051500E+01, -.82187800E+00, 0.69209800E+00, -.76914200E+01, 0.41587900E+00, -.16955700E+01, -.11686900E+01, -.27965500E+00, -.35663600E+00, 0.23683400E+00, 0.55014900E+00, 0.11467900E+01, 0.32897700E+01, 0.14958900E+01, 0.76099900E+00, 0.52470800E-01, -.18328800E+01, -.53957600E+00, 0.31591300E-01, -.14888500E+01, 0.10532500E+00, -.39937200E-01, -.11398000E+01, -.29729800E+01, 0.22507300E+01, -.29978600E-02, 0.41994800E+00, -.11789700E+01, -.54286000E+00, 0.22677000E+01, -.39521200E-01, 0.14404100E+00, 0.12861800E-01, -.52099000E+00, -.62078400E-01, 0.10138100E+01, -.46898900E+01, -.19127700E+00, 0.23828600E-01, 0.38621200E-02, 0.41910300E+00, 0.12960900E+01, -.14888800E+00, 0.10370100E+00, 0.92764000E+00, -.23996800E+00, 0.21967600E+01, -.21648400E+01, 0.77061600E+00, -.51267700E+01, -.53591700E+00, -.12182500E+01, -.86829200E+00, 0.13445500E-02, 0.10660600E+00, -.10992900E+01, -.20897600E+00, 0.18002700E+01, -.53732800E+00, 0.23948000E-01, -.45415900E+00, -.12205100E+00, -.55453900E+00, -.17726500E+00, -.12840200E+00, 0.20504200E-01, 0.15863200E+00, 0.19271300E+00, 0.91688300E+00, -.68746100E+00, 0.11627800E-01, 0.33498800E+00, 0.14114000E+00, 0.71912700E+00, 0.25087700E+00, 0.85309600E-02, -.79111300E-01, -.82177900E-01, 0.38093000E+04, -.13457200E+04, -.16287900E+04, -.90019600E+03, 0.35850200E+04, 0.18451900E+04, -.94899000E+02, 0.44261600E+02, -.14546900E+03, 0.47312800E+02, 0.19686300E+03, -.63511600E+03, -.41988700E+03, -.58338500E+03, -.40944400E+03, -.53728200E+03, -.14497000E+04, 0.44879800E+04, -.22180300E+04, -.16100400E+04, -.22453200E+04, -.56896300E+03, -.51592300E+03, -.15993000E+03, 0.25421500E+04, 0.20766800E+03, -.64461400E+03, -.76173000E+02, 0.84499400E+03, -.42642400E+03, -.73693800E+03, -.42373700E+03, -.12270100E+04, -.19680000E+04, 0.17291100E+03, -.99549200E+03, -.21225900E+03, -.14132600E+04, -.11144600E+04, -.26211300E+03, 0.13289800E+03, -.48166100E+03, 0.12964800E+03, 0.18944800E+03, -.29272100E+03, -.69615800E+02, 0.21075300E+03, 0.92501100E+03, -.28895000E+03, 0.15751300E+03, -.24647600E+03, 0.19709800E+03, -.75761700E+03, 0.12345400E+03, 0.50095100E+03, -.10049700E+04, 0.67451600E+03, 0.14415600E+04, 0.69557800E+03, -.89952600E+03, -.94316600E+03, 0.95864800E+03, -.50074600E+03, -.93593300E+03, -.48053700E+03, -.72394500E+03, 0.12242100E+03, -.19504700E+04, -.31230700E+04, -.21537100E+04, -.11633900E+03, -.70178300E+03, 0.12279900E+05, -.61606200E+04, -.10427700E+05, -.61397700E+04, -.10473000E+04, -.16333700E+04, -.34494600E+04, -.15701300E+03, -.49662400E+04, -.15634000E+04, -.64552100E+04, -.35042700E+04, 0.16923500E+04, 0.25297200E+04, 0.17517700E+04, 0.91106800E+03, 0.14621500E+04, -.14012200E+03, -.85149600E+03, -.36408400E+03, 0.13704700E+04, 0.14392500E+04, 0.24350000E+04, -.12234100E+04, 0.47891200E+03, -.12157400E+04, -.79661200E+03, 0.13600300E+04, -.69378500E+03, -.10423600E+04, -.17597900E+04, 0.13796100E+04, 0.35942100E+03, -.36941700E+04, 0.18148000E+04, 0.27697000E+04, 0.18514700E+04, 0.86950000E+03, 0.13504200E+04, 0.16146700E+03, -.78454600E+03, -.17798900E+03, 0.13123100E+04, 0.72062900E+03, 0.63074600E+03, -.32471300E+03, 0.15075100E+04, -.31393700E+03, 0.38038000E+03, 0.10558900E+04, -.45492000E+03, -.24436300E+03, 0.26967000E+03, 0.92250700E+03, -.95624800E+03, -.64376000E+04, 0.32038400E+04, 0.10054300E+04, 0.32147500E+04, -.70517100E+03, 0.28860700E+03, 0.19976700E+03, -.22361900E+04, 0.16828200E+04, 0.35733400E+03, 0.33738500E+04, 0.69062700E+04, -.34812500E+04, -.55040400E+04, -.34528900E+04, -.56043800E+03, -.10708000E+04, -.19255900E+04, -.89699700E+03, -.41339500E+04, -.10297900E+04, -.51124500E+04, 0.89816200E+03, -.46627200E+03, 0.79687400E+02, -.44901800E+03, -.34179000E+03, 0.74066700E+02, -.87408200E+03, -.20965800E+03, 0.41045400E+02, -.23763700E+03, -.55830800E+03, 0.43301000E+03, -.16984800E+03, 0.19098200E+04, -.21861300E+03, 0.50599400E+02, -.44665100E+02, 0.13072500E+04, 0.31967300E+04, 0.23124800E+04, -.55585800E+03, 0.10082900E+04, 0.16670800E+03, -.66672700E+02, -.47319300E+03, -.82704000E+02, 0.94137100E+03, 0.87388000E+02, -.43006000E+03, 0.58498900E+03, 0.25003300E+03, -.92808600E+02, -.15462900E+04, -.53880200E+04, 0.27524900E+04, 0.50337900E+04, 0.26907100E+04, 0.51213100E+04, -.11532900E+04, 0.14413700E+04, 0.41814300E+04, 0.27179800E+04, -.12006600E+04, -.20367900E+04, -.35771700E+03, -.10247700E+03, -.70467000E+03, -.70458500E+03, -.58167600E+03, 0.43997100E+03, 0.33099800E+03, 0.50113100E+03, 0.63382400E+02, -.19947700E+03, -.32987700E+03, -.88032000E+03, 0.45259100E+03, 0.50134500E+03, 0.39604900E+03, -.46351900E+02, 0.61470400E+03, 0.32669900E+03, -.67153100E+03, 0.56330300E+03, 0.97778600E+03, 0.16588500E+03, 0.11818300E+04, 0.25236800E+03, 0.47757900E+03, -.44170100E+03 },
        { -.25080700E+01, 0.21160200E+00, 0.43531300E+00, -.20926500E-01, 0.20369100E+00, 0.33859800E-01, 0.90309300E+00, -.33206200E+01, -.28085800E+00, -.12843800E+01, 0.21517800E-01, 0.45730500E+00, 0.51564800E+00, -.17673400E+00, -.28788100E+00, -.10942300E+00, -.12709300E+01, -.61069200E+00, 0.17792200E+01, -.18179200E+00, 0.22068200E+00, -.22712900E+00, 0.23817900E-01, 0.23414700E+00, -.19709300E+00, -.17672000E-02, 0.16792700E+00, 0.75387900E+00, -.48829100E+00, 0.57891100E-01, -.16162700E+00, -.25900100E+00, 0.20614300E+00, 0.84929200E+00, 0.14560900E-01, 0.32082500E-01, 0.37715000E-01, -.11311800E+00, 0.91827600E-02, -.27646700E+00, 0.22582300E+01, 0.57275600E-01, -.15050000E-01, 0.15145600E+00, -.22584700E+00, 0.10414800E+00, -.19322400E-01, 0.82165100E-02, -.47001600E+00, 0.11272200E+00, 0.73842200E-01, 0.57280200E+00, -.34023100E-01, 0.17680300E+01, 0.33771500E+00, -.37531400E+00, -.87357200E-02, 0.36157200E-01, -.27382200E-01, -.36463700E+00, 0.10832500E+00, -.53027500E+00, -.11337700E+00, 0.23366800E+00, -.25089500E-01, 0.60579100E-01, -.41111100E+00, -.12817500E+00, -.63459400E+00, -.20992600E-03, 0.10590100E+00, -.40258000E+01, -.38393500E+00, -.38893300E+01, 0.25774000E+00, -.64311400E+00, 0.30296100E+00, -.25230100E+00, -.28415100E+00, -.12644100E+00, -.11116000E+00, 0.10523100E+00, 0.62104100E+00, 0.58084800E+03, 0.33771900E+03, -.52248300E+03, -.93377900E+02, -.17894900E+03, -.24314500E+04, 0.11931100E+04, 0.32797200E+03, 0.12156500E+04, 0.28753600E+03, 0.62473200E+02, 0.75352000E+03, -.58740600E+03, -.52110400E+03, 0.26710500E+03, 0.15668500E+04, -.53028300E+03, 0.33613900E+03, 0.73057100E+03, 0.26448900E+03, 0.21275100E+03, -.21594200E+03, 0.21295300E+03, 0.74867300E+03, 0.85119400E+03, -.36250000E+03, -.66238600E+03, -.39829300E+04, 0.19572800E+04, 0.14268900E+04, 0.19908000E+04, 0.18675200E+03, 0.59853600E+03, -.39586900E+03, -.55548800E+03, 0.22056400E+04, 0.59138000E+03, 0.23959200E+04, -.18041800E+03, 0.91257800E+02, -.26300200E+03, 0.89479700E+02, 0.13212000E+03, 0.35453000E+03, 0.68119300E+03, -.71492200E+03, -.20782500E+04, 0.61381200E+03, 0.10763100E+04, 0.25437100E+03, -.89523000E+01, 0.18964900E+03, -.12707300E+03, -.25692500E+03, -.37034700E+03, 0.28338400E+03, -.18631900E+03, -.94382200E+03, -.59837100E+02, -.30155900E+03, -.48457300E+03, 0.27499000E+03, 0.20905200E+04, 0.24167500E+03, -.12780000E+04, 0.27459700E+03, -.11975400E+04, -.14454500E+04, 0.63697200E+03, -.86770000E+01, 0.31087400E+04, 0.37245200E+04, -.19787700E+04, 0.36244200E+04, -.18621800E+04, -.41090700E+04, -.22928100E+04, 0.18175700E+03, -.53510300E+03, -.22112400E+04, -.17858800E+04, 0.24215600E+04, -.36943300E+03, 0.13510000E+03, 0.33134700E+02, 0.18490100E+03, 0.30698600E+02, -.21666600E+02, 0.32942900E+03, -.60324900E+03, -.32959300E+03, 0.12975500E+03, -.51216200E+02, -.56086900E+03, 0.28322100E+03, -.17092900E+03, 0.27869100E+03, 0.53340400E+03, 0.15740100E+03, -.54016600E+03, 0.80339400E+03, 0.16658100E+04, -.25553400E+03, -.10535400E+04, -.16892900E+03, 0.63722500E+02, -.13342500E+03, 0.88199000E+02, -.15323500E+03, -.28520700E+03, 0.47771500E+03, -.36412600E+03, -.20865500E+03, -.15548500E+03, -.13687000E+03, 0.20216100E+03, -.14240400E+03, -.65276500E+03, -.10034500E+03, -.14750800E+03, -.22951300E+03, -.24709800E+02, -.17488000E+03, 0.45780900E+03, -.31384800E+03, 0.57940700E+03, -.64674000E+04, 0.32325000E+04, 0.53384500E+04, 0.32316200E+04, -.78627000E+03, 0.37935100E+03, 0.14957000E+04, -.45877700E+03, 0.20016200E+04, 0.90398100E+03, 0.26576300E+04, 0.44083800E+04, -.23079300E+04, 0.12942700E+04, -.22040900E+04, -.27778400E+04, -.20603200E+04, 0.43437200E+03, 0.60800700E+03, -.18899000E+04, -.15249500E+04, 0.67992300E+03, -.28197800E+04, 0.13775100E+04, 0.38089100E+04, 0.14099200E+04, -.94062600E+03, 0.33568900E+03, 0.22556500E+03, -.40466200E+03, 0.13675200E+04, 0.10343000E+03, 0.25983100E+04, -.23615500E+04, 0.12884000E+04, -.20132700E+04, 0.11797300E+04, 0.25371200E+04, 0.77321000E+03, 0.71870700E+03, 0.10503800E+04, 0.11694500E+04, 0.50603200E+03, -.17408300E+04, 0.43697700E+04, -.21670200E+04, -.11464000E+04, -.21845400E+04, -.75827100E+03, -.83103400E+03, 0.24867900E+03, 0.64084700E+03, -.16835300E+04, -.88613200E+03, -.16556300E+04, -.10364600E+04, 0.60741200E+03, 0.13152700E+04, 0.51661900E+03, 0.47750800E+02, -.77987300E+03, 0.15214700E+04, 0.26265900E+03, -.37893400E+03, -.28699400E+03, -.21354700E+04, -.15161100E+03, -.62123700E+02, 0.81422800E+02, 0.12548900E+03, -.25151300E+02, 0.65286200E+02, 0.21281500E+02, 0.24417300E+03, -.31052100E+02, 0.98302900E+02, 0.33249200E+02, -.52485900E+03, -.73023600E+02, 0.77670500E+02, 0.19944300E+03, 0.12129700E+04, -.10835400E+03, -.69137500E+02, 0.66064800E+02, 0.36869900E+02, 0.21900000E+03, -.84469500E+03, -.10473600E+04, 0.27873800E+03, -.76923500E-01, 0.71959000E+02 },
        { 0.67850400E+01, 0.23361600E+01, -.51202800E+00, -.35355000E+01, -.15017900E+01, -.16947600E+01, -.18133100E+01, 0.29196600E+01, 0.10405700E+00, -.44356500E+00, -.46878500E-01, -.80737700E+00, 0.20729100E+00, 0.30571100E+00, 0.89925600E+00, -.17068000E+02, 0.40085900E+01, 0.25437000E+01, -.34026900E+01, -.16061100E+00, 0.20387700E+00, 0.28756600E-01, -.17452800E+00, -.19653800E+01, 0.14447800E+00, 0.10282000E-01, 0.11450800E+00, -.87285800E+00, -.10655100E+01, -.10849800E+00, 0.17232800E+01, 0.34443600E+00, -.74526400E+00, 0.19443600E+01, -.20001200E-01, 0.27384000E+00, 0.16929200E+00, -.49162600E+00, 0.28610800E+00, 0.31599000E-01, -.25677400E+01, 0.29407600E+00, 0.50544300E-01, 0.98880100E-01, 0.48186700E+00, -.28633100E+00, 0.19143400E-01, 0.17238600E+00, 0.15864500E+01, -.34294500E+00, 0.36367900E+00, -.62977900E+00, 0.47616000E+00, -.27575700E+01, -.40076000E+00, -.57694000E+00, -.98657500E+00, 0.22467300E-01, 0.22474700E+00, -.34317300E+00, -.56037600E-01, 0.79085100E+00, 0.13502100E-01, 0.26935400E+00, 0.62537300E+00, -.23256100E+00, -.18493200E+01, -.52388400E+00, 0.93606800E+00, 0.77062800E-03, 0.12660400E+00, -.99809900E-01, 0.13755700E+01, 0.70439300E+01, -.68095000E+00, -.56930200E+00, -.30785600E+00, 0.20918800E+01, -.64010500E-02, -.54188700E-01, 0.28231900E+00, -.11466400E+00, -.47802400E+00, 0.16789500E+00, 0.19448000E+04, 0.12459300E+04, 0.81215800E+02, 0.12394400E+04, 0.20788600E+04, -.10583000E+04, -.51910500E+04, -.10390600E+04, 0.87606600E+03, 0.34761600E+03, -.15412300E+04, 0.15855200E+04, 0.32217600E+04, -.18909800E+03, -.22833500E+04, -.21540300E+04, 0.10542400E+04, 0.69569500E+04, 0.10805100E+04, -.14878300E+04, -.75418700E+02, 0.17282400E+03, -.14129700E+04, -.17013000E+04, 0.17294600E+03, 0.36936700E+04, 0.80401700E+04, -.40181700E+04, -.12874700E+04, -.40167200E+04, -.79052700E+03, -.45418800E+03, -.19252000E+03, -.20997100E+03, -.40981800E+04, -.52914400E+03, -.48861200E+04, -.67772900E+03, 0.30426600E+03, 0.72277200E+03, 0.34260100E+03, 0.12574700E+04, 0.27035400E+03, -.13754700E+04, 0.23161800E+04, 0.33995400E+04, -.17411500E+03, -.41471300E+03, 0.29301600E+03, -.14100800E+03, -.18794900E+04, -.14710500E+03, 0.45447300E+03, -.41111900E+03, 0.36511700E+03, 0.18305000E+04, 0.12252300E+04, -.70067200E+03, -.11355700E+03, -.22076900E+04, 0.10270600E+04, 0.13775300E+05, 0.11070700E+04, 0.22735900E+04, -.89827400E+03, 0.25977000E+04, 0.42525700E+04, 0.15873600E+04, -.56870500E+03, -.63881400E+04, -.89287400E+03, 0.38735100E+03, -.38478400E+04, 0.44601000E+03, 0.59126900E+04, 0.28847200E+04, -.28947000E+03, 0.52106300E+04, 0.41247300E+04, 0.17233100E+04, -.90456500E+04, -.36993400E+04, 0.17893600E+04, 0.18599300E+04, 0.18496700E+04, 0.58214700E+01, 0.32034400E+03, 0.29244800E+03, 0.44904700E+03, 0.25442800E+04, 0.35729000E+02, 0.14480400E+04, 0.31272800E+04, -.15176700E+04, -.19453700E+04, -.15662500E+04, -.29560500E+04, -.13130500E+04, 0.42734200E+03, -.10971800E+04, -.30436700E+04, -.25445500E+03, 0.86298300E+02, -.88878100E+03, 0.41096600E+03, 0.20863400E+04, 0.43570400E+03, -.12756100E+03, 0.13303900E+03, -.10806500E+03, 0.57324000E+03, 0.97221400E+03, 0.10377200E+03, -.68314500E+03, 0.22478600E+04, -.11062500E+04, 0.12783200E+04, -.11278300E+04, 0.16283100E+03, 0.10854800E+04, -.13017700E+04, -.42712900E+03, -.14656000E+04, 0.13090700E+04, -.22776600E+04, 0.11254500E+05, -.56249200E+04, 0.93076400E+02, -.56164200E+04, 0.12412900E+04, 0.87597700E+03, -.33390500E+04, -.35833300E+03, -.31545400E+04, -.48440900E+03, -.52092800E+04, -.16831200E+04, 0.81673500E+03, -.64608600E+04, 0.84097200E+03, 0.41357100E+04, 0.22915200E+04, -.35442800E+03, 0.25984800E+04, 0.35186400E+04, 0.13842100E+04, -.64389200E+04, 0.35297000E+04, -.18035200E+04, 0.90069500E+04, -.17650200E+04, 0.10751800E+04, -.15120300E+03, -.72958800E+03, 0.64642900E+03, -.15798000E+04, -.25459500E+02, -.44326500E+04, -.12383000E+05, 0.62257900E+04, -.28150700E+04, 0.61970400E+04, -.30940500E+04, 0.15044600E+04, -.78163700E+03, -.64335100E+04, 0.14255600E+04, 0.16879000E+04, 0.13076600E+05, -.60118000E+04, 0.29543200E+04, 0.50299700E+04, 0.30041500E+04, 0.19616000E+04, 0.18747800E+04, -.89687400E+03, -.18603600E+04, 0.14817100E+04, 0.17998700E+04, 0.18913400E+04, -.19625900E+04, 0.97834100E+03, -.21051800E+04, 0.98999900E+03, 0.17840900E+04, 0.14769400E+04, -.30620300E+04, -.12188100E+04, 0.33899200E+04, 0.64432500E+03, 0.46306900E+04, -.23511000E+03, 0.37326000E+03, -.68739700E+03, -.72444900E+03, -.30047500E+03, -.66342000E+02, -.64499500E+02, 0.26607700E+03, -.14176900E+03, -.45593200E+03, 0.34752700E+03, 0.44454800E+03, -.36182400E+02, 0.32570900E+03, 0.30619200E+03, -.18129500E+04, 0.65382600E+03, -.14602300E+02, -.72614300E+03, 0.95143300E+02, -.84097800E+03, 0.12439300E+04, 0.34139300E+04, -.57194200E+03, -.22574600E+03, -.52069700E+01 },
        { 0.55113400E+01, 0.16736400E+01, 0.84199700E-01, -.26646400E+01, -.90012200E+00, -.12982100E+01, -.10036500E+01, 0.14813000E+01, 0.30523900E+00, -.60756400E+00, -.49272800E+00, -.86512700E+00, -.32763200E+00, 0.23479000E+00, 0.84431700E+00, -.12465400E+02, 0.29922400E+01, 0.13453400E+01, -.24556700E+01, 0.36901900E+00, -.45822100E+00, -.71893500E+00, -.25183500E+00, -.36520700E+01, 0.69708700E-01, 0.11866800E+00, -.30541300E-01, -.25936500E+01, -.23201400E+00, -.16971000E+00, 0.90461800E+00, 0.65450700E-01, -.57345600E+00, 0.17469200E+01, -.42850600E-01, 0.17907600E+00, 0.18127700E-01, -.65508100E+00, 0.43415000E+00, 0.29463900E+00, -.35887000E+01, -.46242800E+00, 0.46989700E-01, -.50846600E+00, 0.54839400E+00, 0.52661200E+00, -.73075200E-01, 0.76553600E-01, 0.43164900E+00, -.27816000E+00, 0.82796700E+00, -.10028100E+01, -.34679400E+00, -.31643900E+01, -.65161600E+00, -.16416100E+01, -.96905000E+00, -.63632700E-01, 0.73108400E-01, 0.58560400E+00, -.25937200E+00, 0.85632000E+00, -.72377700E-02, 0.32847000E+00, 0.86370200E+00, 0.39443800E-01, -.83831900E+00, -.29692900E+00, 0.17981700E+01, 0.37816000E-01, -.29536300E-01, 0.37664400E+01, 0.16138700E+01, 0.50783200E+01, -.15409400E+01, 0.36923800E+00, 0.22411200E+00, 0.47459200E+00, -.38767100E+00, 0.28533800E+00, 0.25290600E-01, -.36345200E-01, -.35026000E+00, -.14128500E+01, 0.52643600E+00, -.13005200E+04, 0.41294900E+02, -.11110600E+03, -.74046200E+04, 0.36614500E+04, 0.11480900E+04, 0.37020000E+04, 0.95521000E+03, 0.68634800E+03, 0.14883300E+04, -.16908200E+04, -.33181200E+03, 0.93923400E+03, 0.39353900E+04, 0.15670400E+04, -.70188400E+03, 0.13429800E+04, -.78643400E+03, -.15679100E+03, -.86629100E+03, -.53662200E+02, 0.18595500E+04, 0.10107600E+04, -.78446600E+03, -.64138700E+03, -.44375500E+04, 0.21734000E+04, -.12086900E+04, 0.22159300E+04, 0.32998500E+03, 0.86359600E+03, -.93229600E+03, -.12903300E+04, 0.36252000E+04, 0.68944300E+03, 0.16656700E+04, -.35017000E+03, 0.16669900E+03, -.62196100E+03, 0.17180300E+03, 0.24448900E+03, -.76647400E+02, 0.21126900E+04, 0.29857500E+03, -.36052800E+04, 0.49959900E+03, 0.22239100E+04, 0.14989000E+04, -.60127300E+03, 0.95956900E+03, -.74897700E+03, -.88354400E+03, -.70847100E+03, 0.14984500E+03, -.67827000E+02, -.16882500E+04, -.43232500E+03, -.99693900E+03, 0.11917500E+04, -.55660300E+03, 0.74561600E+04, -.59857100E+03, -.18293500E+04, 0.19090700E+01, -.81601300E+03, 0.89987500E+03, 0.17137100E+03, -.36701700E+03, 0.26631700E+04, 0.57298700E+04, -.30596700E+04, 0.14044600E+05, -.28645800E+04, -.57734100E+04, -.21798200E+04, 0.56767600E+03, -.44797900E+03, -.42466200E+04, -.14481200E+04, 0.20339700E+04, -.28981400E+04, 0.13979800E+04, 0.73362300E+03, 0.14489400E+04, 0.35364500E+03, 0.10897700E+03, 0.97409500E+03, -.71669300E+03, -.65482600E+02, 0.41576200E+03, 0.47760900E+03, -.55479700E+04, 0.27879700E+04, 0.16835100E+04, 0.27729300E+04, 0.99790200E+03, -.75249300E+02, -.15847400E+04, 0.58010600E+03, 0.48613900E+04, -.66196000E+03, -.10362900E+04, -.36012000E+04, 0.17803400E+04, 0.81170000E+03, 0.18120300E+04, 0.59446800E+01, -.50749600E+03, 0.15531500E+04, -.47109100E+03, 0.52827700E+03, -.18618700E+03, 0.70394700E+02, 0.94910100E+03, -.53651500E+03, -.19887900E+04, -.47140900E+03, -.58136500E+03, -.10445600E+04, 0.62557700E+03, -.86559700E+02, 0.85330300E+03, -.80116600E+03, 0.79839300E+02, -.65542100E+04, 0.32832400E+04, 0.12008700E+05, 0.32680500E+04, -.22471200E+03, 0.12184100E+04, -.16785700E+03, -.25090800E+04, 0.10456700E+04, 0.17709800E+04, 0.87551500E+03, 0.31799000E+04, -.17475900E+04, 0.67130500E+04, -.15894600E+04, -.35415900E+04, -.14005300E+04, 0.87449900E+03, -.99219200E+02, -.27032800E+04, -.75837600E+03, 0.16457600E+04, 0.16668000E+04, -.88508300E+03, 0.71498800E+04, -.83326000E+03, -.16825700E+04, -.27918000E+03, -.13852300E+03, 0.39714700E+03, -.17444700E+03, -.38371600E+03, 0.55299800E+03, -.56091200E+04, 0.29605800E+04, -.82598100E+04, 0.27999100E+04, 0.33555800E+04, 0.78378900E+03, 0.13919300E+04, 0.94853600E+03, 0.32522900E+04, 0.64541200E+03, 0.73327400E+03, 0.88730500E+04, -.44289300E+04, -.14010100E+04, -.44350300E+04, -.12691200E+04, -.10943500E+04, 0.12496800E+04, 0.15887700E+04, -.41593600E+04, -.10731700E+04, -.24573300E+04, -.13425900E+04, 0.76866400E+03, 0.46003800E+04, 0.66421700E+03, 0.29360700E+02, -.48205400E+03, -.14417900E+02, -.14621700E+04, -.11205000E+04, 0.21497000E+03, -.32345400E+04, -.27547900E+03, -.12618300E+03, 0.25350300E+03, 0.33838400E+03, -.27147000E+01, 0.78300600E+02, -.16758300E+03, 0.38262100E+03, -.20322600E+02, 0.21154200E+03, 0.15140000E+03, -.81785900E+03, -.37435600E+03, 0.61299100E+02, 0.35641700E+03, 0.62492700E+03, -.33809300E+03, 0.34792700E+02, 0.22101500E+03, 0.20847400E+02, 0.13334300E+03, -.31478600E+03, 0.45261000E+02, 0.33412800E+03, -.18700100E+03, 0.26357400E+02 },
        { -.32857400E+01, -.94264700E+00, 0.62293400E+00, 0.17598600E+01, 0.22001000E+01, 0.55835400E+00, 0.17938100E+01, -.15296900E+01, -.10830000E+00, -.14799000E+01, 0.38473000E+00, 0.36365800E+00, 0.67480600E+00, 0.96078300E-01, -.46698300E+00, 0.16883400E+02, 0.29476400E+01, 0.17455000E+01, 0.16491000E+01, -.27118200E+00, -.15208000E+01, 0.12617200E+00, -.42380600E-01, 0.12563700E+01, -.22914600E-01, -.71720400E-01, -.51872600E+00, 0.41239200E+00, 0.93580200E+00, 0.78887300E-01, -.82184800E+00, -.13578800E+01, 0.42307500E+00, 0.20452600E+01, 0.38461500E-02, -.18299500E+00, -.37697300E-01, 0.48321900E+00, -.12174200E+00, -.32615600E-01, 0.81268300E-03, 0.53217400E+00, -.98608100E-01, 0.10076300E+00, -.67640500E+00, 0.73498700E+00, -.92534900E-01, -.48033600E-01, -.60317700E+00, 0.12229400E-01, 0.44263300E+00, -.73001200E+00, 0.43763100E+00, -.88988800E+00, -.10302100E+00, -.20746700E+00, -.24957400E-01, -.24316700E-01, -.56704600E-01, -.11505800E+00, 0.25642100E-01, 0.29221800E+00, 0.80896700E-02, -.78130600E-01, -.12664800E+00, 0.66165600E-01, 0.15190400E+00, 0.20069700E-02, -.52084700E+00, 0.12019200E-01, -.39858100E-01, 0.48339700E+00, -.81331600E+00, -.29366500E+01, -.79317900E-01, 0.27182900E+00, 0.23940800E+00, -.85644300E+00, 0.27702700E-01, 0.31702400E-01, -.10980900E+00, 0.69187300E-01, 0.21445200E+00, -.49066100E+00, -.34824800E+00, 0.36302600E+00, 0.27607900E+03, 0.21682900E+03, 0.71494500E+03, -.34586100E+03, 0.11319400E+04, -.35739600E+03, 0.35532600E+02, -.16914100E+03, 0.11019700E+03, 0.16420400E+03, -.67540400E+02, -.19766000E+03, -.70242100E+03, -.27083200E+03, 0.13709900E+03, -.18095500E+04, 0.13613200E+03, -.34696900E+03, 0.12479400E+03, -.27341300E+03, -.46282200E+03, -.56603000E+03, 0.81925100E+02, 0.49061100E+03, 0.72612400E+03, -.36515000E+03, 0.15218300E+04, -.36237900E+03, 0.35927500E+03, 0.84500400E+01, 0.14284400E+03, 0.47686700E+03, -.34091200E+01, -.19936800E+03, -.68450100E+03, -.13751500E+03, 0.79504700E+02, -.39667100E+03, 0.69506400E+02, -.26163300E+03, -.84205200E+02, -.35413300E+03, -.52546700E+03, 0.10589400E+03, -.33559600E+02, -.22556200E+01, -.30822400E+03, 0.14906300E+03, 0.10623900E+03, 0.15398900E+03, 0.32643000E+03, 0.26562300E+03, 0.92234900E+02, -.80052300E+02, 0.25222300E+03, 0.20057900E+03, -.40035600E+02, -.34940600E+03, 0.18318900E+03, -.26426000E+04, 0.17536200E+03, 0.14986500E+02, 0.84390600E+02, 0.16982600E+03, 0.51821900E+03, 0.61731600E+03, -.64872900E+02, -.53758400E+02, 0.30308700E+04, -.14737600E+04, -.21425100E+04, -.15155200E+04, 0.72708200E+02, -.11884400E+04, 0.23304500E+03, 0.18476600E+04, -.56031400E+02, -.10559500E+04, -.25516600E+04, 0.15874300E+02, -.13046400E+02, -.21216700E+03, -.79132900E+01, -.19475200E+02, 0.44787900E+02, -.51973900E+02, -.15414300E+03, 0.11090700E+03, 0.73914700E+00, 0.98084000E+02, -.10469100E+03, 0.41225500E+02, -.69867200E+02, 0.52168900E+02, 0.44508400E+03, 0.15509900E+03, 0.61369700E+03, 0.47873400E+03, -.17327600E+03, 0.17961800E+03, 0.53214900E+03, 0.59377000E+03, -.30046000E+03, -.53699700E+03, -.29896900E+03, -.58093800E+02, 0.93628800E+02, -.20339700E+03, -.24181200E+02, -.95756700E+02, 0.75461400E+02, 0.17132300E+02, -.91959900E+03, 0.46255500E+03, 0.25202500E+03, 0.45899400E+03, -.16300300E+03, -.77305600E+02, 0.28289500E+03, 0.23762500E+03, 0.36818700E+03, -.21669800E+02, -.81330800E+02, 0.29357300E+03, -.15211000E+03, -.18428100E+04, -.14457100E+03, 0.30106600E+03, 0.25166400E+02, -.77417900E+02, 0.59260000E+02, 0.91279900E+02, -.35417500E+03, -.62444700E+01, 0.41124300E+04, -.20282500E+04, -.74555700E+03, -.20563400E+04, 0.24083000E+02, -.10085900E+04, -.89469000E+02, 0.16170200E+04, -.58365800E+03, -.82679000E+03, -.26754700E+04, 0.34764400E+03, -.16550100E+03, -.28528400E+04, -.17385600E+03, -.26894600E+03, -.12613100E+03, -.94971900E+02, 0.29952900E+03, 0.35469700E+03, -.20316900E+03, -.63461500E+02, 0.10698300E+04, -.55807400E+03, 0.11735500E+04, -.53377700E+03, -.70735400E+03, -.19585600E+03, -.34714000E+03, -.69154000E+03, -.14422400E+04, -.66609800E+02, 0.38499600E+02, -.15191500E+03, 0.88377700E+02, -.12365000E+04, 0.75602200E+02, -.49328200E+03, -.23225000E+03, -.43787000E+03, -.38118100E+03, 0.17426500E+03, -.55075400E+02, -.12652400E+03, 0.93036800E+03, -.46472800E+03, -.15357800E+04, -.46338400E+03, -.17117800E+03, 0.32278700E+03, 0.14014500E+03, -.20912100E+03, -.15624300E+03, 0.23884700E+03, -.19781000E+03, 0.12237800E+03, 0.11739500E+02, -.70689200E+02, -.74957600E+02, -.21645000E+02, 0.44581400E+02, -.21668100E+02, -.12877300E+03, -.52540800E+01, 0.28853600E+02, -.87864500E+02, 0.93046300E+02, 0.22835900E+01, 0.13586100E+02, -.93124700E+02, 0.22117300E+03, 0.74245100E+02, -.16998900E+03, -.55837700E+02, 0.48219900E+02, -.11880900E+03, 0.11659600E+02, -.87375100E+03, -.50878300E+02, 0.31603200E+02, 0.22510400E+02 },
        { 0.73798000E+01, 0.26584000E+01, -.27832600E+01, -.58843900E+01, -.15117000E+01, -.15702900E+01, -.43992900E+01, 0.19070700E+02, 0.52079300E+00, 0.32953100E+01, 0.27860000E+01, -.32043200E+00, 0.39772600E-01, 0.40358300E+00, 0.90210800E+00, -.86459700E+01, 0.35878100E+01, 0.46143200E+00, -.14424000E+01, 0.47859600E+00, -.23281900E+01, -.84563300E+00, 0.86583000E-01, 0.11803500E+01, 0.60486700E-01, 0.82229400E-01, 0.19292800E+01, 0.45856000E+01, -.50061000E+01, -.20889600E+00, 0.19874800E+01, 0.29636500E+01, 0.79668800E-01, -.13326300E+01, 0.66566800E-01, 0.27422700E+00, -.25050100E-02, -.40018500E+01, 0.41247900E-01, -.16760600E+01, 0.87153800E+00, -.75470500E+00, 0.31814500E+00, 0.33490600E+00, 0.12706800E+01, 0.50030000E+00, 0.21888800E-01, 0.22280500E+00, 0.69778000E+01, 0.39174700E+00, 0.11703000E+01, 0.98545800E+00, 0.14681400E+01, 0.14979700E+01, 0.13322300E+01, -.96796100E+00, 0.29147700E+00, 0.16517600E+00, 0.21150800E+00, -.11967300E+01, -.23958300E+00, -.41060600E+00, 0.48354500E+00, 0.32446100E+00, -.55173500E+00, -.21711700E+01, -.12319700E+01, -.12921500E+00, 0.27752200E+01, -.21063000E-02, 0.33017300E+00, 0.55309600E+01, 0.49810900E+00, 0.42719600E+01, -.22051100E+01, -.62424300E-01, -.80338100E+00, 0.21388200E+01, -.19220900E+01, -.14590300E+00, 0.49068000E+00, -.27525400E+00, -.42922400E+00, 0.13129500E+01, 0.10756900E+01, -.57899900E+00, 0.95965300E+00, -.29101200E+04, -.11310700E+04, 0.58439800E+03, -.53343200E+03, 0.56565800E+03, 0.70990500E+03, 0.77939000E+03, -.81886800E+03, -.64125600E+03, 0.86649300E+02, 0.66680100E+03, 0.95745100E+03, 0.65823800E+04, -.33450000E+04, -.18191900E+04, -.32902000E+04, -.60367800E+03, -.16067000E+04, 0.10051200E+04, 0.35220200E+04, 0.15196400E+03, -.13083100E+04, -.46392800E+04, -.26804800E+04, 0.13473500E+04, -.10240500E+04, 0.13412300E+04, -.98042400E+03, -.37139300E+03, -.12643600E+03, -.15674800E+04, 0.14564400E+03, -.26094000E+03, 0.64450000E+04, 0.25833700E+04, -.12787500E+04, -.99066800E+03, -.12908500E+04, -.88717900E+02, -.33134100E+02, 0.57878100E+03, 0.19166800E+04, 0.44173000E+03, 0.13697500E+03, -.30325600E+04, 0.13204500E+04, -.70631300E+03, -.40443400E+03, -.66044600E+03, -.22590100E+02, -.28437900E+03, -.54840400E+03, 0.39688000E+03, -.63164500E+03, 0.15370700E+01, -.18295700E+03, -.35145100E+04, 0.17451700E+04, 0.48330600E+04, 0.17582000E+04, 0.11906100E+03, 0.44488300E+03, -.20029600E+03, -.29282400E+04, -.63191600E+03, 0.43603300E+03, 0.90006000E+02, 0.33194100E+04, -.15891800E+04, -.21260900E+04, -.16598100E+04, -.20400300E+04, -.37604700E+03, -.10339400E+04, -.36024900E+04, -.45471600E+04, -.19865100E+03, 0.37625400E+03, -.27641800E+04, 0.14103100E+04, 0.12100900E+04, 0.13813400E+04, 0.44474800E+03, 0.39283600E+03, 0.55491900E+03, 0.87004300E+02, 0.69156900E+03, 0.30006700E+03, 0.36942100E+03, 0.81990600E+03, -.41466100E+03, 0.32987500E+03, -.40709300E+03, 0.43704300E+03, 0.10517700E+04, -.13253000E+04, -.11452800E+04, -.15555200E+04, 0.50912400E+03, 0.97397900E+03, -.31488700E+04, 0.15765600E+04, 0.16498000E+04, 0.15689600E+04, 0.52587900E+03, 0.34829100E+03, 0.91922600E+03, 0.36200500E+03, 0.11975000E+04, 0.15950500E+03, 0.20584500E+03, -.14254500E+04, 0.73120800E+03, 0.92541500E+03, 0.71138800E+03, 0.72456700E+03, 0.10083600E+04, -.58192000E+02, -.98586400E+02, -.13570300E+03, 0.31865100E+03, 0.31206300E+04, -.45119000E+04, 0.22600400E+04, 0.39593700E+04, 0.22591900E+04, -.96540900E+03, 0.21143900E+03, -.35024100E+02, -.22091100E+04, 0.82725100E+03, 0.44393300E+03, 0.68462200E+04, -.31085500E+04, 0.16317600E+04, -.26329700E+03, 0.15541400E+04, -.11317100E+04, 0.74194400E+02, 0.71330400E+02, -.42111800E+04, -.28629100E+04, 0.11289700E+03, 0.20522400E+04, -.20871900E+04, 0.10332300E+04, 0.32555200E+04, 0.10435500E+04, -.16913600E+03, 0.52719700E+03, -.10252600E+03, -.11333500E+04, 0.19416300E+03, 0.34425800E+03, 0.15307300E+04, 0.34620200E+04, -.17971700E+04, -.29415000E+04, -.17294300E+04, 0.89675700E+03, -.27029700E+03, 0.80548800E+03, 0.44348000E+04, 0.22736700E+04, -.52064500E+03, -.37630500E+04, 0.22790200E+04, -.11582600E+04, -.81429000E+02, -.11400000E+04, -.61873100E+03, -.63467700E+03, 0.44651900E+03, 0.11316600E+04, 0.70012400E+03, -.33411600E+03, -.33877300E+04, -.56660400E+04, 0.27640300E+04, 0.41109200E+04, 0.28358300E+04, 0.22053800E+04, 0.75797100E+03, -.72065600E+03, -.10067400E+04, 0.73447300E+03, 0.80086300E+03, 0.21435300E+04, -.58101900E+03, 0.15875900E+03, -.32545000E+03, -.36659800E+03, -.22452000E+03, 0.18083500E+03, -.22805900E+03, -.19280900E+03, -.11398400E+02, 0.21474200E+02, -.45171600E+02, -.43266400E+03, -.20321700E+03, 0.15215500E+03, -.13570400E+03, -.46998700E+03, 0.33471500E+03, 0.62655100E+00, -.36329300E+03, 0.12677400E+03, 0.35770500E+03, 0.25443200E+03, 0.16780900E+04, 0.22530900E+02, -.18926700E+02, 0.83168300E+02 },
        { 0.18834600E+01, 0.46851500E+00, 0.65550500E+00, -.22325200E+00, -.12202700E+01, -.23493900E+00, -.16004600E+00, -.73481500E+00, 0.14399900E+00, -.76413200E+00, -.37047300E+00, -.24093900E+00, -.26800700E+00, 0.17736700E+00, 0.17379200E+00, -.92897500E+00, 0.67706700E+00, 0.45850000E+00, -.13028200E+00, 0.31534700E+00, -.38314300E+00, -.20334000E+00, -.43433900E-01, -.11326000E+01, 0.19952800E+00, -.63853000E-02, -.52789400E+00, -.19659700E+01, 0.78332700E+00, -.21324900E-01, -.10484500E-01, -.74510900E+00, 0.17591100E-02, 0.80121000E+00, -.34662300E-01, -.79382700E-02, 0.41071500E-01, 0.36530500E+00, 0.39485800E-01, 0.62285100E+00, -.11267600E+01, -.15912100E+00, -.35619400E-01, -.30026000E-01, 0.50975800E+00, 0.74022600E-01, 0.82062000E-02, 0.66096700E-01, 0.47684500E+00, -.14123200E+00, 0.59179300E+00, 0.20828800E+00, 0.28080900E+00, -.15860700E+01, -.16560400E+00, -.37647700E+00, -.43893500E-01, -.29112700E-01, 0.62682600E-01, 0.15349100E+00, -.31661900E+00, 0.11207800E+01, 0.45663800E-01, 0.27997900E-01, 0.18203100E+00, -.11074800E+00, -.12920500E+01, -.25688500E+00, -.37465500E+00, 0.95293500E-02, -.27231000E-01, -.18718500E+01, 0.21205300E+00, 0.12138600E+01, -.94301800E-01, 0.57691900E+00, 0.36503800E-01, 0.70729000E+00, 0.83560700E-01, 0.20846700E+00, -.41379300E-01, 0.25358300E-01, 0.88261300E-01, -.23857400E+00, 0.14705000E+00, -.69508700E-01, -.12432400E-01, 0.75965300E-02, -.27452900E+04, 0.13612300E+04, 0.12914700E+04, 0.13725000E+04, -.10628000E+03, -.22258800E+03, 0.66875600E+03, -.10335600E+04, 0.47328300E+02, -.23942000E+02, 0.43155200E+03, 0.10267900E+04, -.49854100E+03, -.43123600E+03, -.51472600E+03, 0.21655600E+02, -.11229600E+02, -.33951300E+03, 0.20450600E+03, -.51157800E+03, 0.10484500E+03, 0.13490300E+04, -.82636700E+03, 0.40611400E+03, -.31128000E+04, 0.41189900E+03, 0.29212500E+03, -.17989400E+03, 0.56480500E-01, 0.49524200E+03, 0.19499600E+04, -.20990700E+03, 0.25664200E+03, -.11688000E+04, 0.58249300E+03, 0.36094500E+03, 0.58298900E+03, -.58480500E+02, -.48234200E+03, 0.89322100E+03, -.12572200E+04, -.23093200E+04, 0.55139800E+01, -.64910200E+03, 0.99736100E+03, -.48365700E+03, 0.89817900E+03, -.49845200E+03, -.63407400E+03, -.19344200E+03, -.33037600E+03, -.44177000E+03, -.49320600E+03, -.28826200E+03, -.35884400E+03, 0.16247300E+04, -.78805400E+03, -.73425300E+02, -.81359200E+03, -.42485800E+03, -.21104000E+03, -.38189100E+03, 0.28392800E+03, -.59684000E+03, -.10719600E+03, -.12884000E+04, -.41350800E+03, 0.15782200E+03, 0.71242000E+04, 0.20691600E+03, -.87966100E+03, -.10104800E+03, 0.31940200E+03, -.12747700E+04, -.12403100E+04, 0.38918200E+03, -.17426100E+04, 0.62237700E+03, -.29682300E+03, -.55710600E+03, -.31115800E+03, 0.63414800E+02, 0.21205000E+02, 0.44131500E+02, 0.35460500E+02, -.57009700E+03, 0.12837200E+03, 0.31474900E+02, -.28504700E+04, 0.14230700E+04, 0.20650300E+04, 0.14257900E+04, 0.91154800E+03, 0.11516000E+04, -.90387500E+03, 0.72700500E+03, 0.27835000E+04, 0.60961100E+03, 0.21502400E+04, -.12944300E+04, 0.65670200E+03, -.10663000E+03, 0.65140000E+03, 0.18835500E+03, 0.90356500E+02, 0.28326600E+03, -.38040700E+03, -.18849300E+03, 0.15493900E+03, 0.22723700E+03, -.10908600E+04, 0.52737600E+03, -.41953900E+03, 0.54692400E+03, 0.53295000E+02, -.49186000E+03, 0.10021300E+04, 0.33920600E+03, 0.23890300E+03, -.31107200E+03, -.54967900E+02, -.21722100E+04, 0.10902900E+04, 0.28426900E+04, 0.10819600E+04, 0.51300400E+03, 0.46080400E+03, -.60057700E+03, -.12691900E+04, 0.13296000E+03, 0.64718800E+03, 0.13127000E+02, -.15034900E+04, 0.71073900E+03, 0.44793700E+04, 0.75196900E+03, -.39028900E+03, 0.35712200E+03, 0.22339800E+03, -.11376600E+04, -.57913900E+03, 0.64593000E+03, -.79334300E+03, 0.17645700E+04, -.88143300E+03, -.20621300E+03, -.88222100E+03, -.13264600E+03, -.34338400E+03, 0.92772800E+02, 0.49665100E+03, -.41389000E+03, -.15357100E+03, -.15496200E+04, 0.13625700E+03, -.37184100E+02, -.18028400E+04, -.70244700E+02, 0.31805600E+03, -.87506600E+01, 0.43627700E+03, 0.62012900E+03, 0.19925700E+03, -.20296400E+02, 0.24894800E+04, 0.46303700E+04, -.23084600E+04, -.12481100E+04, -.23145200E+04, -.77223100E+03, -.96370100E+03, 0.48791700E+03, 0.62942500E+03, -.22917900E+04, -.73635700E+03, -.24054600E+04, 0.21260000E+04, -.10533300E+04, 0.28913900E+04, -.10663300E+04, -.11670700E+04, -.31636300E+03, -.62177400E+03, -.25019900E+03, -.12005200E+04, -.44877800E+03, 0.63869500E+03, 0.28864100E+03, -.52315600E+02, 0.15480800E+03, 0.19131500E+03, 0.36443200E+02, 0.35558700E+02, 0.61002000E+02, 0.15843100E+03, 0.50886800E+02, 0.82361200E+02, -.17454100E+03, -.16586400E+03, -.20202100E+03, -.61119200E+02, 0.11022800E+03, -.14214700E+03, -.18712100E+03, -.31050000E+03, 0.17112800E+03, -.99696000E+01, 0.17552200E+03, 0.19672600E+03, -.11663200E+03, 0.86635200E+02, -.11397800E+03, -.21732800E+03 },
        { -.13955900E+02, 0.66824800E+01, 0.33870400E+01, -.25122800E+01, 0.23201500E-01, -.33715300E+01, -.22961900E+01, -.95081900E+01, -.35618000E+01, -.32422400E+00, -.35778800E+00, 0.41956100E+00, 0.38708000E+01, -.80943100E+00, -.80010600E+00, 0.33421300E+01, 0.13210200E+02, -.19844200E+00, 0.46625100E+01, 0.83553100E+00, -.78882600E-01, -.25586600E+01, -.99887800E+00, -.68597500E+00, -.16461100E+01, 0.21423900E+00, 0.14769000E+01, -.72405700E+00, -.75853500E+01, 0.52985800E-01, 0.83137700E+00, -.98316800E+00, -.20297300E+01, 0.25893300E+01, 0.40692500E+00, 0.18758800E+00, 0.43548500E-01, 0.47913100E+01, 0.11150900E+01, 0.14850100E+01, 0.80919000E+01, -.16623800E+01, -.38321300E+00, -.44837100E+00, 0.57317700E+00, 0.12150400E+01, -.95439600E-01, -.64458300E-01, 0.12346400E+01, 0.43661200E+00, 0.12305400E+01, -.35666000E+01, 0.21273600E+01, -.67433900E+00, 0.87523500E+00, -.32699400E+01, -.34398500E+00, 0.30301800E-01, -.15667500E+00, -.28725200E+00, -.31156700E-01, 0.14114200E+01, -.68447600E+00, -.11357100E+01, -.29980900E+01, -.71812300E+00, 0.15080900E+01, 0.13863700E+00, -.10541300E+01, 0.33578500E-01, 0.27572900E+00, -.82703500E+01, -.32390000E+00, -.40720500E+01, 0.17232300E+01, -.12462100E+01, 0.22918800E+00, 0.16665400E+01, -.11856600E+01, -.74095500E+00, -.41166500E+00, 0.15155100E+00, 0.13458200E+01, 0.22261500E+01, -.31118800E+00, -.67673700E-01, 0.42292900E+00, 0.16263400E+00, -.42554600E+00, 0.12347500E+03, 0.14416100E+04, -.29875900E+00, -.23778200E+03, 0.12554700E+04, -.11856400E+04, -.11323500E+04, -.12881500E+04, 0.82405800E+03, -.14130000E+03, 0.14595700E+05, -.78612600E+04, -.86500200E+04, -.73006100E+04, -.15092700E+04, -.27622200E+04, -.31090500E+02, 0.55180900E+04, 0.70883800E+03, -.30259800E+04, -.53559200E+04, 0.29433600E+03, 0.68258600E+01, -.14956200E+04, -.14980300E+03, -.99117700E+03, -.64831300E+03, -.22270200E+03, -.14671400E+04, -.14151700E+04, -.14709100E+03, 0.20255800E+03, 0.19285700E+04, -.99815200E+03, -.82101200E+03, -.96711000E+03, -.72749700E+03, 0.16242200E+02, 0.98901000E+02, 0.13394200E+04, 0.21714500E+04, -.72423100E+03, -.12176900E+04, 0.66510900E+03, -.11889900E+04, 0.40836600E+03, -.33206000E+03, -.59144200E+03, -.39378600E+03, -.54726600E+03, -.53047100E+03, 0.32231900E+03, -.45677800E+03, -.33787100E+03, 0.42876900E+04, -.21851200E+04, -.53650900E+04, -.21464000E+04, 0.13757900E+03, 0.52443700E+03, -.26808500E+03, 0.42128500E+03, -.41318100E+04, 0.62997700E+03, -.12064600E+04, 0.26230700E+04, -.82842900E+03, -.59808300E+04, -.13112000E+04, 0.93726600E+03, 0.26335400E+04, -.23034600E+04, -.82885700E+03, -.13860300E+04, 0.18464200E+04, 0.13659900E+04, 0.29033100E+04, -.93244200E+03, -.12668600E+04, -.14516900E+04, 0.16243200E+03, 0.12029500E+03, -.11870400E+04, 0.34104200E+02, -.24227300E+04, 0.18953900E+03, -.71745600E+03, -.22080300E+03, 0.16873800E+03, 0.11084500E+04, 0.11593900E+03, 0.90057100E+03, 0.38019700E+03, -.63034200E+03, -.16589100E+04, -.24455500E+04, 0.11308100E+04, 0.68944500E+03, -.50777300E+03, 0.48867800E+03, 0.12970600E+03, 0.25933700E+03, 0.66195500E+03, 0.72463300E+03, -.92039300E+03, -.92465000E+03, -.16265800E+04, 0.69856400E+03, 0.58101800E+03, -.35540100E+03, 0.34262600E+03, 0.50042600E+03, 0.18089200E+03, 0.38085900E+03, 0.85854800E+02, 0.39309500E+03, -.96229700E+02, -.71407200E+03, 0.94773100E+02, 0.51451200E+02, 0.38809700E+04, -.17987000E+04, -.41380000E+04, -.19491000E+04, 0.25375200E+03, -.45421300E+03, -.26029800E+04, -.18859900E+04, -.28334500E+04, -.22632500E+03, -.11811800E+04, -.37148900E+04, 0.24532000E+04, -.86867900E+03, 0.18579200E+04, 0.79959700E+03, 0.30601600E+04, -.18629700E+04, -.25772900E+04, -.64512900E+03, 0.22258100E+04, 0.37726800E+04, 0.78729300E+04, -.38905800E+04, -.80493700E+04, -.39363300E+04, 0.86769600E+02, -.10357100E+04, -.50304100E+03, 0.15947600E+04, -.28929500E+04, -.68583600E+03, -.31931900E+04, 0.15824200E+05, -.85605200E+04, -.30485600E+04, -.79165100E+04, -.23204400E+04, -.41882300E+04, 0.51728500E+03, 0.62585700E+04, 0.14441700E+04, -.40642200E+04, -.79046600E+04, -.45651900E+04, 0.20109600E+04, 0.12674100E+04, 0.22839600E+04, 0.51480000E+03, 0.58629700E+03, 0.17502500E+04, 0.61612200E+03, 0.23086500E+04, 0.39253700E+03, 0.24286500E+04, -.10600800E+04, -.20211800E+03, 0.10992300E+04, 0.52294400E+03, 0.59288300E+03, -.48915900E+03, -.13603100E+04, -.13909200E+04, -.18209600E+04, -.30522400E+03, 0.27148700E+04, 0.66125700E+02, -.79904100E+01, 0.10286400E+03, 0.74771300E+02, 0.37844500E+02, 0.84832600E+02, 0.15196100E+03, -.11142900E+04, 0.67146300E+02, 0.10738600E+03, -.24421700E+03, -.23708900E+02, 0.35023100E+03, -.16491000E+03, -.10261400E+04, -.21774200E+04, -.90563800E+02, 0.78159000E+03, 0.12922900E+03, 0.55209900E+02, 0.52026300E+03, 0.15484500E+04, 0.24061500E+04, -.32642100E+03, 0.25368100E+03, -.32623300E+03 },
        { 0.25156400E+01, -.31881500E+00, -.69666500E+00, -.14688000E+01, -.82126100E+00, -.20765500E+00, -.11148400E+01, 0.42437200E+01, 0.29434000E+00, 0.24108500E+00, 0.22832400E+00, -.31935300E+00, -.72112800E+00, 0.91196900E-01, -.21311100E+00, -.12761800E+01, -.12904000E+01, -.24199200E+00, 0.65157300E-01, 0.54680800E+00, -.16497700E+00, 0.18336500E+00, -.36426400E-01, -.39365500E+00, -.90460400E-02, 0.11134800E+00, 0.44107700E+00, -.43066000E-01, 0.32258800E+00, 0.86429600E-01, 0.27381200E+00, 0.29010900E+00, 0.33692200E+00, -.39483500E-01, 0.29880700E-01, 0.41705500E-01, -.10525000E+00, -.86164100E+00, -.17679400E-01, -.68624800E+00, -.89236400E+00, -.19239500E-01, 0.16438100E+00, -.89175800E-01, 0.27632800E+00, 0.20043300E+00, 0.17095400E-01, -.36016600E-01, 0.38381500E+00, 0.13536400E+00, -.27834800E-01, -.25039500E+00, -.60612700E+00, 0.20765500E+01, 0.25176600E+00, 0.19011100E+00, 0.47424700E+00, 0.21303800E+00, -.38731700E-01, 0.89356500E+00, -.63859600E-01, -.54531400E+00, 0.23928600E-01, 0.97411300E-01, -.21813100E-01, -.36993000E+00, -.69551800E+00, -.99360000E-01, 0.27526400E+00, 0.77204900E-02, 0.16444200E-01, -.93060600E+00, 0.56989800E+00, 0.74635300E+00, -.27864800E+00, 0.48378000E+00, -.80920200E-02, 0.88039200E-01, 0.16887500E+00, -.29468200E-01, 0.23330000E-01, -.11422300E+00, -.14348300E+00, -.82803900E-01, 0.13603600E+00, 0.18419000E+00, 0.49245100E+00, 0.25989000E-01, 0.31100900E+00, -.61553400E-01, -.16605200E+04, -.18642700E-01, 0.28843800E+03, 0.10784400E+04, -.82417300E+03, 0.54603500E+01, 0.13946000E+02, 0.71548500E+03, 0.58978200E+03, 0.25641100E+04, -.13494800E+04, 0.84813000E+03, -.12822100E+04, -.31759400E+03, -.83508800E+03, 0.59088700E+03, 0.10028500E+04, 0.39449900E+03, -.64288500E+03, -.21385900E+04, -.12884800E+04, 0.66656300E+03, 0.19765000E+04, 0.64409800E+03, 0.19524300E+03, 0.77563000E+03, -.53431200E+02, -.74270300E+03, -.10877300E+04, 0.72225800E+03, 0.46479600E+03, 0.12601200E+04, -.65029100E+03, 0.18775800E+03, -.63014800E+03, 0.13356200E+02, 0.45252000E+03, -.62551900E+03, 0.65210800E+03, 0.14379000E+04, 0.19188200E+03, 0.28060700E+03, 0.25546600E+03, -.20723100E+03, -.86983200E+03, -.12769400E+03, 0.66254100E+02, -.53679200E+02, -.15391500E+03, 0.27504200E+03, -.71520100E+02, -.35148900E+02, -.65998100E+02, 0.18742600E+04, -.98114300E+03, 0.29864200E+04, -.93727400E+03, 0.29653100E+03, 0.40063900E+03, -.76916200E+03, -.11604200E+04, -.19273900E+04, 0.38203300E+03, -.19839100E+03, -.18281100E+04, 0.92850800E+03, -.19930700E+04, 0.91407100E+03, 0.14637200E+04, 0.19682300E+04, -.12255600E+04, -.19957400E+04, -.31170000E+02, 0.16927500E+04, 0.26899700E+04, 0.36414300E+03, -.12569100E+03, 0.32278400E+03, -.18198900E+03, 0.36788800E+02, -.19642800E+02, -.32344500E+03, -.19369600E+03, -.55322600E+03, -.13729300E+02, -.18860900E+03, 0.23906000E+04, -.11714200E+04, -.18284000E+04, -.11937600E+04, -.30968300E+03, -.54202100E+03, 0.21860000E+03, -.28735100E+03, -.18025800E+04, -.38622300E+03, -.19226100E+04, 0.23318400E+03, -.94420300E+02, 0.70924900E+03, -.11671500E+03, 0.97526600E+02, 0.82699800E+02, -.32459900E+03, -.41270300E+03, -.52609300E+03, 0.83741400E+02, -.84763800E+02, 0.63130700E+03, -.28678800E+03, 0.63674300E+03, -.31542600E+03, 0.31199400E+03, 0.29957100E+03, -.94160300E+03, -.10478800E+04, -.30693900E+03, 0.22581300E+03, 0.94009800E+02, -.42176200E+03, 0.22343700E+03, 0.23635700E+04, 0.21038200E+03, -.27676100E+02, -.44727500E+03, 0.15803800E+04, 0.17776400E+04, 0.35672600E+03, -.49522100E+03, 0.32777500E+03, -.54806500E+04, 0.27792600E+04, -.11748800E+04, 0.27403500E+04, 0.12039700E+04, 0.19789300E+04, -.57568100E+03, -.24363200E+04, 0.68993100E+03, 0.15304600E+04, 0.36748200E+04, 0.80970500E+03, -.41515100E+03, 0.29139900E+04, -.40484500E+03, 0.38750300E+03, 0.96070000E+02, -.21957500E+03, -.21140400E+03, -.70839900E+03, 0.15199800E+03, -.28948300E+03, 0.27305200E+03, -.17805200E+03, -.28272900E+04, -.13677100E+03, -.35096100E+03, -.63303300E+03, 0.20329400E+03, 0.57494500E+03, 0.19614200E+04, -.65712300E+03, -.18078800E+04, -.28047000E+04, 0.13549700E+04, 0.20790200E+04, 0.14024200E+04, 0.34847000E+03, 0.52528300E+03, 0.95533000E+01, -.76440000E+03, 0.11749600E+04, 0.53192000E+03, 0.16017000E+04, -.28753700E+04, 0.13658500E+04, -.10807100E+04, 0.14372000E+04, 0.10916700E+04, 0.26203300E+03, 0.65183200E+02, -.37762800E+03, 0.59429500E+03, 0.25919100E+03, -.34632500E+02, -.37105700E+03, 0.57296300E+02, 0.81885400E+02, 0.61968400E+02, -.17325100E+02, -.33382600E+02, -.10162000E+02, -.26425000E+03, -.14016600E+01, -.51711000E+02, 0.28646700E+03, 0.15662600E+03, 0.14728600E+03, 0.19707200E+02, -.26421000E+03, -.11459000E+04, -.59049100E+02, 0.11294400E+03, 0.61704200E+02, 0.26818400E+02, -.22280700E+03, 0.80665800E+03, 0.22770100E+04, -.21210600E+03, -.42488300E+02, 0.20788500E+03 },
        { 0.10054000E+02, 0.22325400E+01, -.23995300E+01, -.14857900E+01, -.60290800E+01, -.36686500E+01, -.21169200E+01, -.11372400E+02, 0.63696200E+00, -.21979900E+01, -.21282500E+01, -.15856300E+00, -.63068500E+00, 0.61299200E+00, 0.27386800E+00, -.26947400E+01, 0.44400700E+01, 0.29057500E+01, -.30005000E+01, -.20392200E+01, -.64722300E+00, -.31473700E-01, -.76942800E-01, -.89379900E+00, 0.17808300E+00, 0.71518500E+00, 0.52424100E+00, 0.65738500E-01, -.46821100E+00, 0.10539200E+00, 0.20199900E+00, 0.22342400E+00, 0.80052400E-01, -.23353500E+01, 0.44058200E-01, -.45932100E-03, 0.13293700E-02, 0.93454800E+00, 0.12879400E-01, -.22680000E+00, -.43937800E+00, -.24658300E+00, 0.14761100E+00, -.54193700E-01, 0.33270700E+00, -.23485700E+00, 0.50428300E-01, -.19465800E-01, -.19218500E+01, -.17831900E+00, 0.94148200E-01, -.71514000E+00, 0.11565800E+00, -.93332000E+00, 0.14431500E+00, 0.30050600E+00, -.54618300E+00, 0.20235000E+00, -.43359100E-02, -.54842600E+00, 0.22189000E+00, 0.57819200E+00, -.14147800E+00, -.63066600E+00, -.10651500E+01, -.87477900E-01, -.11681100E+01, -.20698100E+00, 0.44786200E+00, -.12473400E-02, 0.11514800E+00, -.33545100E+01, 0.35704400E+00, 0.52260600E+01, 0.10906400E+01, -.37354200E-02, -.48621900E+00, 0.21607300E+01, -.25686100E+00, -.19943100E+00, 0.91140600E-01, -.40729300E-01, -.13332800E+00, 0.12408600E+00, 0.32419800E+00, -.65407100E-01, 0.10611500E-02, 0.14100200E-01, 0.33450900E+00, -.35715600E-01, 0.71719800E+00, 0.19476400E+02, -.89716900E+02, 0.39272800E+02, -.82200200E+02, 0.44388500E+03, 0.55910100E+03, -.99644400E+02, 0.19857700E+03, -.57648400E+04, 0.28883400E+04, 0.29539100E+04, 0.28827500E+04, 0.55042300E+03, 0.11493600E+04, -.25576100E+03, -.25607000E+04, 0.34552200E+03, 0.11215200E+04, 0.26128300E+04, 0.96063100E+03, -.48566400E+03, -.76327500E+03, -.48001500E+03, 0.35609700E+03, 0.29543200E+03, -.22526400E+03, 0.73762600E+03, 0.65050500E+01, 0.81580200E+02, -.20019700E+04, -.22612000E+04, 0.11312600E+04, 0.17111300E+04, 0.11309900E+04, 0.95373400E+03, 0.32527500E+03, 0.21703900E+03, 0.56683400E+03, 0.30536400E+03, 0.28466500E+03, 0.10002900E+04, 0.83979100E+03, -.45992400E+03, 0.42773500E+03, -.41993700E+03, -.76124500E+02, 0.25753400E+03, -.50566600E+03, 0.26888800E+02, -.24471500E+03, -.32592900E+02, -.55685300E+02, 0.12808700E+04, -.61987000E+03, -.68455200E+03, -.64014500E+03, 0.40445300E+03, -.36564100E+03, 0.29600100E+03, 0.12849100E+04, 0.42670300E+03, -.20091800E+02, -.62436700E+03, -.44390000E+04, 0.22208800E+04, 0.38017300E+04, 0.22194600E+04, 0.16497100E+04, 0.11367700E+04, 0.12459600E+04, 0.19570300E+04, 0.37765300E+04, 0.99944100E+03, 0.39467900E+03, -.23444700E+03, 0.12481900E+03, -.95993100E+03, 0.11744900E+03, -.11866300E+03, -.85674500E+02, 0.45850400E+02, 0.67079300E+03, 0.97943700E+03, -.27508100E+03, 0.23287100E+03, 0.17060400E+04, -.84993500E+03, -.13924900E+04, -.86603400E+03, -.16014300E+04, -.13834500E+04, 0.11429500E+03, 0.35306900E+03, 0.35941600E+03, -.11673600E+04, -.14766900E+04, 0.15678000E+03, -.75853000E+02, -.95446100E+03, -.79558500E+02, -.21884400E+03, -.33255000E+03, 0.73151300E+02, 0.76632900E+03, 0.79755600E+03, -.46612100E+03, 0.66220900E+01, -.27660000E+03, 0.13943500E+03, -.97251300E+03, 0.13800000E+03, -.26369000E+03, -.38450900E+03, 0.26236800E+03, 0.48428400E+03, 0.54201700E+03, -.25088500E+03, -.51294900E+03, 0.61550800E+04, -.30710400E+04, -.26688600E+04, -.30765800E+04, 0.30212700E+03, -.57811300E+03, -.14467100E+03, 0.20025200E+04, -.49149400E+03, -.92483100E+03, -.42521000E+04, 0.56412800E+03, -.27753600E+03, 0.27177300E+03, -.28212900E+03, 0.79790100E+03, 0.57662500E+03, 0.38084500E+03, 0.24955900E+04, 0.26044200E+04, 0.46384400E+03, -.85199800E+03, -.15432400E+02, 0.19715600E+02, -.42022200E+03, 0.77005600E+01, 0.70146900E+03, -.12180600E+03, 0.47326400E+03, 0.61303300E+03, 0.61713400E+02, 0.15038400E+03, -.75425100E+03, -.36248000E+04, 0.17955000E+04, 0.13222700E+04, 0.18129100E+04, -.64041400E+03, 0.69665900E+03, -.77833400E+03, -.24946100E+04, -.11121700E+04, 0.76718200E+03, 0.24088800E+04, -.26204500E+04, 0.13065900E+04, 0.22005800E+04, 0.13100700E+04, 0.11329400E+04, 0.10964300E+04, 0.41332900E+02, -.12212500E+04, -.60055300E+03, 0.11430800E+04, 0.15996700E+04, 0.19048100E+04, -.97573400E+03, -.17570800E+04, -.95166900E+03, -.98387600E+03, -.68248200E+02, -.54791700E+03, 0.12743800E+03, 0.11370200E+04, -.87776100E+03, -.16231900E+03, 0.23823700E+03, 0.26219500E+02, 0.34314000E+02, 0.33890200E+02, 0.47007600E+02, -.58541200E+02, 0.17161600E+03, 0.16522900E+03, 0.19431900E+02, -.27846500E+02, 0.25095600E+03, 0.11741900E+03, 0.18981900E+02, -.94717300E+02, 0.10316700E+03, 0.13472300E+03, -.69271300E+02, 0.14139300E+03, 0.45683700E+02, -.57887400E+02, -.30821700E+03, -.13362400E+03, -.81507100E+03, -.48486100E+02, -.11968600E+03, -.18276000E+02 },
        { -.28530700E+01, 0.37574700E+00, 0.10477000E+01, 0.13095100E+01, 0.16033800E+01, 0.57066100E+00, 0.11811500E+01, -.95739600E+00, -.20945000E+00, 0.84276500E+00, -.40123700E-01, 0.33775900E-01, 0.47048800E+00, -.14762800E+00, 0.70709000E-01, 0.75206600E+01, -.36208300E+01, 0.54106000E+00, 0.13025400E+01, -.14486400E+00, -.18163300E+01, -.10322500E+00, -.50606300E-01, -.31529100E+00, -.27423400E+00, -.81024600E-01, -.43161900E+00, -.80142800E+00, 0.77749300E-01, -.22059000E-01, -.33966700E+00, -.34612700E-02, -.28031700E+00, 0.68956600E+00, -.35119700E-01, -.52310700E-01, 0.35738500E-01, 0.38287500E+00, 0.89296500E-01, 0.19304300E+00, -.34920400E+00, -.56854200E-01, -.20273700E-01, -.18424500E+00, -.11509600E+00, 0.30419000E+00, -.51187900E-01, 0.52777700E-02, -.11581900E+01, 0.47203200E-01, 0.51640900E+00, -.20177500E+00, -.23239500E+00, 0.69629400E+00, 0.18481500E+00, -.25841400E+00, -.56853300E-01, 0.12603900E+00, -.24533000E-01, 0.55897800E+00, 0.24825500E-01, -.66681000E-01, -.27465600E+00, 0.64937900E-01, 0.25523000E+00, -.22907600E-02, 0.11019100E+00, -.41741100E-02, -.49903000E-01, 0.17400200E-01, -.52391200E-01, 0.24014400E-01, -.85981400E+00, -.13090800E+01, -.21470400E+00, -.30194900E+00, 0.20411300E+00, -.60619600E+00, 0.40281900E+00, 0.17597200E-01, -.54168000E-01, -.95210900E-01, -.17205000E+00, -.59503500E-02, -.32283100E-01, 0.11223500E-02, 0.32913900E+00, -.93227300E-01, 0.27449200E+00, -.12266100E-02, 0.35568400E+00, -.42083200E-02, 0.86608300E+03, 0.58264400E+03, -.41902300E+03, -.38483900E+02, -.38013600E+02, 0.39215000E+03, 0.18631900E+03, 0.46605400E+04, -.23391300E+04, -.25957600E+04, -.23310800E+04, -.88222100E+03, -.98040000E+03, 0.17059300E+03, 0.21705700E+04, 0.15682400E+03, -.11665700E+04, -.27710800E+04, -.17358400E+02, 0.68470600E+01, 0.18238100E+04, 0.79207900E+01, -.71897400E+03, -.40823500E+03, 0.75878000E+02, -.69383500E+03, -.79925200E+03, -.11726900E+03, 0.83949100E+03, 0.15855400E+04, -.79006300E+03, -.14656600E+04, -.79367000E+03, -.34395700E+03, 0.54972100E+02, -.36366900E+03, 0.54921500E+03, 0.79757400E+03, -.95364700E+02, -.14161800E+03, 0.16965000E+03, -.83874000E+02, -.33414500E+03, -.84700300E+02, 0.15465700E+03, -.24033600E+03, 0.18481700E+03, 0.21854600E+03, 0.18256800E+03, -.29153300E+02, -.28781000E+03, -.10782800E+04, 0.52991900E+03, 0.97530400E+03, 0.53840100E+03, 0.12081700E+03, 0.73811700E+03, -.40025400E+03, -.69291700E+03, -.19863400E+03, 0.44034500E+03, 0.11037100E+04, 0.40316500E+04, -.20184900E+04, -.22556400E+04, -.20157200E+04, -.74150400E+03, -.82014000E+03, -.78961200E+03, 0.43606300E+03, -.18315500E+04, -.77492200E+03, 0.73204900E+03, -.61709600E+03, 0.31966900E+03, 0.32308700E+03, 0.30827100E+03, 0.19821500E+03, 0.34753900E+03, -.80120100E+02, -.51807400E+03, -.23528800E+03, 0.33634000E+03, 0.10735500E+03, -.12996600E+04, 0.65233700E+03, 0.23843800E+03, 0.65184200E+03, 0.62617500E+03, 0.17033900E+02, 0.60843500E+03, -.53793700E+03, -.59484300E+03, 0.11814300E+03, 0.26700900E+03, 0.78353900E+02, -.29184400E+02, 0.86290200E+02, -.37456100E+02, 0.84138500E+02, 0.28178900E+03, -.90882700E+02, -.34837000E+03, -.45081100E+03, 0.31269700E+03, -.63192800E+02, 0.13846200E+04, -.68294200E+03, -.74630600E+02, -.69146800E+03, -.17306900E+03, 0.21724500E+03, -.40998900E+03, -.17124200E+03, -.76621600E+03, 0.15605200E+03, -.15921600E+03, -.47131800E+04, 0.23547200E+04, 0.20411200E+04, 0.23541400E+04, 0.17276900E+03, 0.32058400E+03, 0.62802400E+02, -.15302700E+04, 0.87393800E+03, 0.50400400E+03, 0.30986700E+04, 0.23189300E+04, -.11593500E+04, -.79260400E+03, -.11593200E+04, -.36713900E+03, -.63113800E+03, -.33151200E+03, 0.86433900E+02, -.16450500E+04, -.52648300E+03, 0.63624300E+03, -.71173800E+03, 0.34406000E+03, 0.50581200E+03, 0.35590800E+03, -.52555300E+03, 0.21965900E+03, -.26140400E+03, -.37685700E+03, 0.20527700E+03, 0.35514900E+02, 0.14675500E+04, 0.44467600E+04, -.22183900E+04, -.27292100E+04, -.22246600E+04, -.10162600E+03, -.78252700E+03, 0.30990800E+03, 0.21017300E+04, 0.68096800E+03, -.10937900E+04, -.37319600E+04, 0.27254200E+03, -.14085900E+03, -.71425300E+03, -.13587000E+03, -.54093200E+03, -.14427800E+02, -.11787000E+03, 0.57762000E+03, 0.47254400E+03, -.14352600E+03, 0.16206100E+02, -.28818600E+04, 0.14412900E+04, 0.16711500E+03, 0.14389800E+04, 0.20957200E+04, 0.10667800E+04, -.17953600E+03, -.43381200E+03, 0.40438300E+03, 0.12429100E+04, 0.74960200E+03, -.31240000E+03, 0.94155800E+02, -.23644000E+03, -.23753600E+03, -.13010900E+03, 0.11707300E+03, -.30367100E+03, -.51741500E+03, -.13754600E+03, 0.31908200E+02, -.54707900E+02, -.19561900E+03, -.46054100E+02, 0.12617000E+03, -.40463100E+03, -.34928300E+03, 0.23092600E+03, -.75779500E+01, -.23446200E+03, 0.11522000E+03, 0.18718100E+03, 0.46386700E+03, 0.92748600E+03, -.38411400E+02, 0.70065200E+02, 0.85514400E+02 },
        { -.10152700E+02, 0.44589000E+01, 0.23663700E+01, -.18202000E+01, 0.11953000E+01, -.19619700E+01, -.18372000E+01, -.11768900E+01, -.22070900E+01, 0.99316700E+00, 0.25551300E+00, -.32471400E-01, 0.28675700E+01, -.46806500E+00, -.43188000E+00, 0.96858200E+01, 0.94307000E+01, 0.73655500E-01, 0.46576900E+01, 0.14475000E+01, -.29223500E+01, -.22053200E+01, -.79926200E+00, -.11657800E+01, -.15855500E+01, 0.11881000E+00, 0.12721900E+01, -.11784500E+01, -.59764000E+01, 0.44867500E-01, 0.84189900E+00, 0.12655800E+00, -.16770700E+01, 0.48555500E+01, 0.29404700E+00, 0.30418700E+00, 0.43152900E-01, 0.22486500E+01, 0.95359900E+00, 0.38629000E+00, 0.34959200E+01, -.14490100E+01, -.32240500E-01, -.36083600E+00, 0.86571200E+00, 0.13241400E+01, -.66117100E-01, 0.35329200E-01, 0.54652200E+00, 0.25891300E+00, 0.14477100E+01, -.28615000E+01, 0.19630300E+01, -.65649300E+00, 0.51382400E+00, -.82667000E+00, 0.71722000E+00, -.32693100E-01, -.28248200E-01, 0.45260900E+00, -.38141500E+00, 0.12591700E+01, -.11149500E-01, -.10725100E+01, -.16378400E+01, -.10715800E+01, -.41083600E+00, -.89682300E-01, -.45211200E+00, 0.20801400E-01, 0.20883300E+00, -.70413400E+01, 0.16458000E+00, -.46560900E+01, 0.37635900E+00, -.27081200E+00, 0.36698400E+00, 0.12602300E+01, -.21079700E+01, -.28090500E+00, -.36131200E+00, 0.21359900E+00, 0.94043200E+00, 0.81966400E-02, -.61476100E-01, 0.94795800E+00, 0.60060400E+00, 0.18867000E+00, 0.76846000E+00, 0.71613400E-01, -.14985800E+01, -.26133700E-02, 0.99241400E+00, 0.23777500E+04, -.12577500E+04, -.75615800E+03, -.15940000E+04, 0.17122300E+04, -.36612100E+03, 0.12361700E+05, -.63533700E+04, -.56870300E+04, -.61804900E+04, -.12668900E+04, -.28607700E+04, 0.40453900E+03, 0.45241100E+04, 0.86863000E+03, -.27113800E+04, -.46307600E+04, -.43255400E+04, 0.22228700E+04, 0.33054400E+04, 0.21631700E+04, 0.57349400E+03, 0.15512800E+04, -.66081000E+03, -.16105000E+04, -.16744000E+03, 0.14527100E+04, 0.27858200E+04, 0.10281600E+04, -.55690100E+03, 0.24835400E+04, -.51334300E+03, 0.69221200E+03, 0.19791700E+04, -.10603500E+04, -.28929700E+03, 0.83548500E+03, 0.15509400E+04, -.27223100E+03, 0.13083800E+04, -.61371300E+03, -.37380900E+03, -.65419300E+03, 0.97783500E+02, 0.77781800E+03, -.13082500E+04, -.36729600E+03, -.92898000E+03, 0.46923200E+03, -.74626100E+03, 0.48669000E+04, -.25893400E+04, -.24699900E+04, -.24331200E+04, 0.82290000E+03, 0.77493000E+03, -.12086300E+04, -.22511700E+04, -.54103500E+04, 0.81452500E+03, -.30192900E+04, 0.19736900E+04, -.96216200E+03, -.44641100E+04, -.98689900E+03, 0.20529700E+04, 0.33153600E+04, -.20331000E+04, -.25615800E+04, -.24142900E+04, 0.26441500E+04, 0.11560800E+04, 0.28691300E+04, -.14082500E+04, -.15967200E+04, -.14341300E+04, -.11837500E+03, -.35391200E+03, -.66388100E+03, 0.84297500E+03, -.11827400E+04, -.31279800E+03, -.98983600E+03, 0.56093000E+04, -.27870200E+04, -.40990200E+04, -.28002400E+04, -.19423300E+04, -.20910100E+04, -.32002500E+03, -.56402600E+03, -.28335700E+04, -.15800000E+04, -.18310100E+04, -.93608800E+03, 0.45538700E+03, 0.37817400E+03, 0.46278200E+03, 0.53785500E+03, 0.22235900E+03, -.22675300E+03, -.22355200E+03, -.33462700E+03, 0.13916100E+03, 0.38196900E+03, -.50056900E+04, 0.25053600E+04, 0.13166000E+04, 0.25027100E+04, 0.93515000E+03, -.11871400E+03, 0.26282300E+03, -.10480500E+04, 0.16936300E+04, -.46994300E+02, 0.34749600E+04, 0.64820100E+04, -.32144000E+04, -.15727200E+04, -.32399400E+04, -.20006800E+04, -.24548100E+04, 0.25543200E+04, 0.42903000E+04, -.10538200E+04, -.25450500E+04, -.15949500E+04, -.10460600E+05, 0.52522500E+04, 0.10634000E+04, 0.52302300E+04, 0.20285400E+04, 0.42274400E+04, -.10014500E+04, -.52657400E+04, -.20938800E+03, 0.32215600E+04, 0.52961300E+04, 0.70248200E+04, -.34878900E+04, -.43429000E+04, -.35124300E+04, 0.10235600E+04, -.62990000E+03, -.59263500E+03, 0.13252200E+04, -.24951700E+04, -.38490400E+03, -.36508300E+04, 0.10645700E+05, -.53839700E+04, -.55963100E+04, -.53222500E+04, -.19028600E+04, -.34851900E+04, -.27343900E+03, 0.52740300E+04, 0.30882200E+04, -.31590000E+04, -.56355500E+04, -.63403400E+04, 0.31467800E+04, 0.37506000E+04, 0.31699300E+04, 0.20174500E+04, 0.15685800E+04, 0.87132200E+03, -.17627900E+04, 0.19913600E+04, 0.16631500E+04, 0.18355000E+04, -.30778100E+04, 0.15259900E+04, -.39459900E+04, 0.15393800E+04, -.43061100E+03, -.10784100E+04, 0.71866900E+03, -.74491500E+03, -.50799100E+03, -.10446500E+04, 0.23479800E+03, -.31673200E+03, -.95141600E+02, 0.34278000E+03, 0.29234100E+03, 0.23338700E+03, -.94370400E+02, 0.55163700E+03, -.72666600E+03, 0.26364300E+03, -.99147200E+01, 0.15822000E+03, 0.12713300E+03, 0.49878200E+03, -.32549900E+03, -.71548100E+03, -.28085500E+04, -.28056200E+03, 0.67911500E+03, 0.32480700E+03, -.10465400E+03, -.15384100E+03, 0.19855500E+04, 0.35467400E+04, -.38615500E+03, 0.44375700E+02, 0.25555200E+03 },
        { 0.19899400E+01, -.23142200E+00, -.75858700E+00, -.88684100E+00, -.10500600E+01, -.52617600E+00, -.12077900E+01, 0.17893700E+01, 0.64131400E-01, -.40757500E+00, 0.13472600E+00, -.42645400E-01, -.19094900E+00, 0.69528100E-01, -.84817100E-01, -.61996100E+01, 0.26942000E+01, -.74020400E+00, -.71912900E+00, 0.85401100E-01, 0.14766400E+01, 0.20569500E+00, 0.23951000E-01, 0.10364800E+01, 0.28332200E+00, 0.95552300E-01, 0.52422200E+00, 0.16088000E+01, -.25953700E+01, 0.53645200E-01, 0.10677400E+00, -.23243700E+00, 0.21067100E+00, 0.45743100E+00, 0.19680000E-01, 0.84929800E-01, -.10497500E-02, -.48241800E-01, -.15454600E-01, -.16530000E+00, 0.45684700E+00, 0.11368000E+00, 0.12320100E-01, 0.63696100E-01, -.71412000E-01, -.32840000E+00, 0.46936400E-01, -.13745900E-01, -.11865600E+00, -.63941700E-01, -.11604000E+00, 0.67859200E+00, -.26257700E-01, 0.23774700E+00, 0.34418300E-01, 0.33654100E+00, 0.13981500E+00, 0.17577300E-01, -.89282400E-02, -.14656600E+00, 0.39846700E-01, -.84471500E-01, 0.12986600E+00, 0.10374300E+00, 0.15235500E-01, 0.13100800E+00, 0.15158200E+00, 0.38800400E-02, 0.52252700E-02, -.47604600E-02, -.32363600E-01, -.41592400E+00, 0.26516900E+00, 0.33887600E+00, 0.14893600E+00, 0.30116800E+00, -.26035100E-01, 0.17495300E+00, 0.19400500E+00, 0.75820400E-01, -.17363100E-01, -.37423000E-01, -.31614300E-01, 0.35141500E+00, 0.79518300E-01, -.59679700E-01, -.29774700E+00, 0.18953100E-01, -.47762400E+00, 0.62229900E-02, -.39405400E+00, -.58894300E-02, -.42009800E+00, 0.67486200E-01, -.20934200E+03, -.32023400E+03, -.23709800E+03, -.57940900E+02, -.30096900E+03, 0.19962400E+04, -.10260300E+04, -.85065600E+03, -.99955100E+03, 0.76136400E+02, 0.26495600E+02, -.15642400E+03, 0.82441800E+03, 0.17172600E+03, 0.30054700E+02, -.75623400E+03, -.48810300E+02, 0.33739200E+02, -.10231800E+04, 0.23040500E+02, -.15393400E+03, -.27797100E+03, 0.87716900E+02, -.19117400E+03, -.19786100E+02, -.11694700E+03, 0.40159000E+03, 0.30529100E+03, -.15766600E+03, -.66569500E+03, -.15418500E+03, -.45083500E+03, -.59654600E+03, 0.30451400E+03, 0.54749600E+02, -.56414000E+01, -.51928600E+03, -.59181900E+03, 0.91936900E+03, -.52123900E+03, -.36524400E+02, -.45944800E+03, -.28987500E+03, -.24461600E+03, -.21780400E+03, -.55080400E+02, -.14599500E+03, -.24973500E+03, -.49980800E+03, -.17881900E+03, 0.85387100E+02, 0.33496000E+03, 0.88093500E+02, 0.53084500E+03, 0.36700500E+03, -.33380400E+03, -.69405400E+03, -.69692000E+03, 0.42164200E+03, -.57165900E+03, -.16009700E+04, 0.80923900E+03, 0.11082500E+04, 0.80066500E+03, 0.69332300E+03, 0.71793100E+03, -.59640700E+03, -.15562800E+04, -.31210900E+03, 0.87359000E+03, 0.23052600E+03, 0.47655600E+03, -.18639400E+03, -.30721600E+03, -.23846300E+03, 0.17471400E+03, 0.19072000E+03, -.26779500E+03, -.95633000E+02, -.69521800E+03, 0.18538200E+03, -.94617300E+02, -.67824000E+03, 0.34581400E+03, 0.97440300E+03, 0.34185700E+03, 0.10641000E+04, 0.11639000E+04, -.34751300E+03, -.58907800E+02, 0.48570000E+02, 0.94756700E+03, 0.80677100E+03, -.25727600E+03, 0.15899600E+03, -.12715700E+03, 0.13243500E+03, 0.24722300E+03, 0.33020000E+03, -.20839900E+03, -.42270500E+03, -.62927700E+03, 0.29626600E+03, 0.50246100E+02, 0.45786100E+03, -.20883400E+03, 0.35468400E+02, -.22736700E+03, 0.13491800E+03, 0.15288200E+03, 0.41946600E+02, -.63313300E+02, -.45038100E+03, 0.11618100E+03, -.26584500E+03, -.35568300E+04, 0.17824400E+04, 0.14661900E+04, 0.17740000E+04, 0.50456700E+03, 0.26011500E+03, -.25551300E+03, -.13912000E+04, 0.61589700E+03, 0.39263800E+03, 0.19402900E+04, -.27785100E+04, 0.14070800E+04, 0.13348400E+04, 0.13895100E+04, 0.56712500E+03, 0.78157800E+03, -.32015900E+03, -.16143700E+04, -.18536200E+03, 0.80529000E+03, 0.88000100E+03, 0.98956900E+01, -.31087200E+01, 0.11300900E+02, -.48797200E+01, 0.19636700E+03, 0.72822100E+02, -.24595200E+02, -.17665400E+03, -.18139200E+03, 0.17070700E+03, -.20343000E+03, 0.35558600E+04, -.17994800E+04, -.14281700E+04, -.17802100E+04, -.42205800E+03, -.36518100E+03, 0.74936700E+02, 0.15372000E+04, 0.30284500E+03, -.58577000E+03, -.11171200E+04, 0.86599100E+03, -.45077800E+03, -.25382000E+03, -.43228200E+03, -.64990200E+03, -.51906600E+03, 0.22049600E+03, 0.33830500E+03, -.28440700E+03, -.44298500E+03, -.65846800E+03, 0.23868500E+02, -.53698700E+02, 0.20425100E+04, -.15480200E+02, 0.53997600E+03, 0.69564100E+03, -.83249300E+03, -.34780900E+03, -.60417000E+03, 0.51120200E+03, 0.31484400E+02, 0.54637200E+02, 0.77641000E+02, 0.35479700E+02, 0.43650300E+02, -.38059000E+02, 0.34030700E+02, -.16293700E+03, -.31530800E+03, -.64615200E+02, 0.82696100E+02, 0.28345900E+02, -.43051600E+02, -.10544400E+03, 0.17056100E+02, -.27488000E+03, -.57618200E+03, -.50795900E+02, -.21342600E+03, 0.49506400E+02, 0.34315300E+02, 0.18097700E+03, 0.52254100E+03, 0.10645800E+04, -.59049100E+02, -.56049800E+02, -.99773800E+02 },
        { -.19114700E+01, -.75022200E+00, 0.45341300E+00, 0.10078100E+01, 0.14632600E+01, 0.82300900E+00, 0.64277200E+00, 0.13209700E+01, -.27810500E-01, 0.47552800E-01, 0.38267100E+00, 0.18159300E+00, 0.89881100E-01, -.45021200E-01, -.29181000E-01, 0.29445600E+01, -.12806100E+01, -.13886700E+00, 0.11540400E+01, 0.51513600E+00, -.43835500E+00, -.52787300E-01, 0.14101700E+00, 0.10232600E+01, 0.19265100E-01, -.37347200E-01, 0.24499900E+00, 0.13701700E+01, -.38546500E+00, 0.77701300E-03, -.32961900E+00, 0.42705300E+00, 0.91064300E-01, -.90325800E+00, 0.41589200E-03, 0.26643600E-01, 0.16464100E-01, -.20565700E+00, -.92899800E-01, 0.96515000E-01, 0.24780800E+00, 0.18195700E-01, -.20942700E-01, 0.25383000E+00, 0.36623700E-01, -.42952900E+00, 0.69437400E-01, 0.24329900E-01, 0.33051500E+00, -.37232500E-01, -.30601200E+00, 0.81932800E+00, 0.24201800E-01, -.19058300E+00, -.96972600E-01, 0.98033300E+00, 0.38345500E+00, -.10633700E+00, 0.43130200E-01, 0.35286400E-01, -.58125200E-01, -.16528500E-01, 0.30460400E+00, -.12018400E-01, 0.56545200E+00, -.16037600E+00, -.84238600E+00, -.11653100E-01, 0.15867900E+00, -.86155500E-02, -.36064800E-02, 0.14706700E+01, 0.53956300E+00, 0.12723500E+01, -.45887900E+00, 0.19777100E+00, -.23225900E+00, 0.27248700E+00, -.21830200E+00, 0.10895300E-01, 0.94367600E-01, 0.14913700E-02, -.25578200E+00, -.18293400E+00, -.19914500E-01, -.11302500E+00, 0.26644600E+00, 0.19992800E+00, 0.32371500E+00, -.27701400E-01, -.51678900E-01, 0.33824500E-02, 0.10223700E+00, -.97162600E-01, -.60324600E-01, 0.26591600E+03, 0.42087300E+03, -.28298300E+02, -.36231000E+03, -.33509100E+04, 0.16681300E+04, 0.16721800E+04, 0.16761300E+04, 0.16768900E+03, 0.64545400E+03, 0.62592200E+02, -.16204600E+04, -.27309400E+03, 0.80546200E+03, 0.22045800E+04, -.41609400E+03, 0.20735900E+03, 0.83951800E+03, 0.20870100E+03, 0.52584200E+03, 0.41794700E+03, 0.94090700E+02, 0.60796500E+03, 0.48219400E+03, 0.19012000E+03, -.85310500E+03, -.95757800E+03, 0.47664700E+03, 0.10793100E+04, 0.47961900E+03, 0.46906200E+03, 0.25840000E+03, -.14760000E+03, -.42128300E+03, -.19646300E+03, 0.38818600E+03, 0.41632200E+03, 0.12687600E+03, -.48526900E+02, -.87958800E+01, -.63531800E+02, 0.84263900E+02, 0.28845900E+03, -.19975900E+03, 0.11309100E+02, -.21090400E+03, 0.13304600E+03, 0.86603300E+02, 0.40284500E+03, -.20054000E+03, -.54782100E+03, -.20080400E+03, 0.20764300E+03, -.13332200E+03, -.16153000E+03, -.22866900E+03, 0.10346300E+03, -.29291800E+02, -.10348200E+04, 0.37005900E+03, -.19260900E+03, 0.45470600E+03, -.18511900E+03, 0.60090300E+03, -.23077200E+01, 0.26814900E+03, 0.61036800E+03, 0.54085700E+03, 0.13869000E+03, -.22123500E+04, 0.40194300E+03, -.21498900E+03, -.57684300E+03, -.20072400E+03, -.16859900E+03, -.10501900E+03, 0.48939800E+02, 0.35594100E+03, 0.50981800E+03, -.20260600E+03, 0.60561300E+01, 0.12863900E+04, -.64204900E+03, -.11561600E+04, -.64436100E+03, -.84506100E+03, -.61417100E+03, 0.10160400E+03, 0.50603600E+03, 0.24018600E+03, -.72980400E+03, -.68541500E+03, 0.36718500E+03, -.19460700E+03, -.40414000E+03, -.18578400E+03, -.15512900E+03, -.17359300E+03, 0.51253400E+02, 0.32780100E+03, 0.45923000E+03, -.21956200E+03, -.12502000E+03, -.86470900E+03, 0.42761300E+03, -.82312200E+02, 0.43169800E+03, -.50051400E+02, -.22107200E+03, 0.11213000E+03, -.56007600E+02, 0.72808900E+03, -.78310000E+02, 0.82900200E+02, 0.14557900E+04, -.72366900E+03, -.39569900E+03, -.72583800E+03, -.37044200E+02, -.42277100E+03, 0.11943100E+04, 0.20108000E+04, 0.61761800E+03, -.65551100E+03, -.15924000E+04, 0.90967200E+03, -.46342100E+03, -.59581000E+02, -.45496100E+03, 0.44860300E+03, -.15316800E+02, 0.81634600E+02, 0.70656300E+03, 0.41263200E+03, 0.62275700E+02, -.22419200E+04, 0.63130400E+02, -.30950400E+02, 0.32453300E+02, -.31597900E+02, 0.31098600E+03, -.37838500E+02, 0.10178200E+03, 0.21213800E+03, 0.16496600E+03, 0.17913300E+02, -.80000400E+03, -.28871700E+04, 0.14479400E+04, 0.91486100E+03, 0.14446600E+04, -.31253900E+03, 0.48315500E+03, -.31933700E+03, -.14721600E+04, -.53603700E+03, 0.59857000E+03, 0.27534000E+04, -.26699700E+03, 0.13494700E+03, 0.64035200E+03, 0.13314800E+03, 0.34304600E+03, 0.22776800E+03, -.29387800E+03, -.80016900E+03, -.51372700E+03, 0.39372600E+03, 0.33304200E+02, 0.85404700E+03, -.41413700E+03, -.14476400E+04, -.42548100E+03, -.58913900E+03, -.57052400E+01, 0.22940900E+03, 0.35973000E+03, 0.67791500E+03, -.29250300E+03, -.14607700E+03, 0.62481500E+02, -.51068300E+01, 0.44109700E+02, 0.40942600E+02, 0.50176900E+02, -.55559500E+02, 0.98191000E+02, 0.18905700E+03, 0.30927300E+02, -.62711300E+02, 0.11319200E+03, 0.98236200E+02, -.70727500E+01, -.51177600E+02, 0.13697400E+03, 0.40557300E+02, -.45984500E+02, -.11976300E+03, 0.42669000E+02, -.34034800E+02, -.28453400E+03, 0.25938800E+02, -.32251700E+03, -.34137900E+02, -.11926200E+03, 0.92209100E+02 },
        { 0.43889600E+01, 0.67827800E-01, 0.27582800E+00, 0.62191800E+00, -.18849400E+01, -.63006800E+00, 0.11483000E+01, -.10439700E+02, 0.62492900E+00, -.23109300E+01, -.14609600E+01, -.18033000E+00, -.55712100E+00, 0.28024700E+00, 0.25106100E+00, 0.23653600E+01, 0.58932400E+01, 0.20532700E+01, 0.18913300E+01, 0.39231800E+00, -.26987700E+01, -.14142300E+01, 0.32108100E+00, -.16283700E+01, 0.65196900E-01, 0.40523800E-01, -.20471000E+00, -.36804900E+01, 0.38937100E+01, 0.36281900E+00, 0.32696900E+00, -.23188300E+01, 0.83842200E+00, 0.97673100E+00, -.10579400E+00, 0.18616100E+00, 0.31222900E-01, 0.31025100E+00, -.43512000E+00, 0.10879400E+01, 0.27384600E+00, -.45592000E+00, -.40279100E-01, 0.88955800E-01, 0.49079900E+00, 0.11224000E+00, 0.12924000E+00, 0.65033700E-01, -.28573000E+01, -.88700300E-01, 0.11391900E+01, -.15694500E+01, -.19440000E+00, -.20416600E+01, -.72955800E+00, 0.52616600E+00, 0.15969800E+00, -.21099300E-01, 0.56004300E-01, -.32157700E+00, -.51112900E-02, -.19700400E+00, 0.44696400E+00, -.18253800E+00, 0.28776600E-01, -.71288200E+00, -.20439500E+00, 0.13033700E-01, 0.14534800E+01, 0.21840700E-02, 0.85322400E-01, 0.37809900E+01, 0.36789700E+00, 0.18665800E+01, -.11775400E+01, -.21219800E-01, -.59507700E+00, 0.73630100E+00, -.92102100E+00, -.78052700E-02, 0.18848100E+00, -.89769900E-01, -.57336800E+00, 0.21358900E-01, 0.23214900E+00, -.17904400E+00, 0.12965100E+00, 0.20318400E+00, 0.34428200E-01, 0.68469900E-02, -.31893200E+00, 0.14750500E-02, 0.61887100E+00, -.16109700E+00, 0.79993300E+00, 0.61088800E+00, 0.66973200E+03, 0.92412300E+02, -.85829600E+02, -.53300600E+03, 0.27638300E+03, 0.32187400E+03, 0.26808800E+03, -.73900400E+03, -.60619800E+03, 0.46727300E+03, -.37863500E+03, -.84968300E+03, -.51402000E+03, 0.12554100E+04, 0.66665700E+03, -.33520500E+03, -.47410300E+03, -.33177900E+03, 0.17875300E+03, 0.21917500E+03, -.14232000E+02, 0.66951100E+03, 0.47375800E+03, -.75504500E+02, -.12943400E+04, -.15495900E+04, 0.77447100E+03, 0.20479400E+04, 0.77670400E+03, 0.97394200E+03, 0.97761100E+03, -.31902200E+03, -.11451800E+03, 0.16731200E+03, 0.87978900E+03, 0.64421500E+03, -.26034000E+03, 0.20661800E+03, 0.84746100E+02, 0.12994500E+03, 0.32037000E+03, 0.45899100E+03, -.20276700E+03, -.78009300E+02, -.17688800E+03, 0.40379400E+03, 0.67454800E+03, -.21157900E+04, 0.10454800E+04, 0.15471200E+04, 0.10593500E+04, -.25261100E+03, -.32741900E+03, 0.78089600E+03, 0.44237400E+03, 0.17447500E+04, -.38693600E+03, -.18054700E+03, 0.24142100E+04, -.12118800E+04, -.62862900E+03, -.12073100E+04, -.55776100E+03, -.89056700E+03, 0.70702100E+03, 0.15042500E+04, 0.45465900E+02, -.11603400E+04, -.27139700E+04, -.26840000E+03, 0.73581800E+02, -.11020800E+03, 0.13460700E+03, -.36382500E+03, -.56490200E+03, 0.67455100E+03, 0.11913200E+04, 0.17340600E+04, -.62755000E+03, -.15756300E+03, 0.33977300E+04, -.17028300E+04, -.16234100E+04, -.16991800E+04, -.14347900E+04, -.77497400E+03, -.47355600E+03, 0.32003800E+03, -.93380800E+03, -.71316800E+03, -.15308600E+04, -.73519700E+03, 0.32568300E+03, 0.35051000E+03, 0.35776000E+03, -.17258600E+03, -.42854300E+03, 0.65708800E+03, 0.14706600E+04, 0.20074200E+04, -.50743300E+03, -.22878900E+02, -.27573600E+04, 0.13571800E+04, 0.69202800E+03, 0.13771100E+04, 0.24094300E+02, -.22485600E+02, 0.33068600E+03, 0.45692400E+03, 0.13616000E+04, -.41153200E+02, 0.85594300E+03, 0.57398900E+04, -.28697500E+04, -.17280700E+04, -.28650700E+04, -.69746100E+03, -.93339200E+02, -.34635100E+03, 0.15771000E+04, -.10221100E+04, -.46458700E+03, -.26306400E+04, 0.21612000E+04, -.10937900E+04, -.10529900E+04, -.10808800E+04, -.40184300E+03, -.75229700E+03, 0.44192200E+03, 0.10811600E+04, 0.12957400E+03, -.89370400E+03, -.24397800E+04, -.11599500E+04, 0.57618300E+03, 0.80048200E+03, 0.57990000E+03, 0.72916700E+02, 0.13922100E+03, 0.10626200E+03, 0.10191300E+02, 0.77194700E+03, -.24215300E+02, 0.69217600E+02, -.44522400E+04, 0.22428800E+04, 0.10542300E+04, 0.22286500E+04, 0.32704600E+02, 0.36183100E+03, 0.74313400E+02, -.17116700E+04, -.60594400E+03, 0.80350800E+03, 0.32673100E+04, -.17404800E+04, 0.88261300E+03, 0.16525700E+04, 0.86941100E+03, 0.76382200E+03, 0.27396300E+03, -.21007300E+02, -.85715800E+03, 0.50333300E+03, 0.44997400E+03, 0.10388100E+04, 0.85490100E+03, -.38375300E+03, -.20704400E+04, -.42377200E+03, -.17638600E+04, -.13741100E+04, 0.38242900E+03, 0.11369100E+03, 0.83924700E+03, -.11925400E+04, 0.19399500E+04, 0.80305300E+02, -.72325800E+02, 0.30658700E+02, -.37683700E+01, 0.76493600E+02, -.53438700E+02, 0.42774700E+03, 0.35927600E+03, 0.11892200E+03, -.19829700E+03, -.16929100E+03, 0.64405000E+02, 0.20452400E+03, -.80670700E+02, 0.35842200E+03, 0.59506500E+03, 0.23351100E+02, 0.22430600E+03, 0.12720000E+02, -.51284500E+02, -.30926100E+03, -.60709000E+03, -.10702900E+04, 0.31287000E+02, -.67482800E+01, -.90801700E+01 },
        { 0.18793900E+01, 0.60870600E+00, -.90264800E+00, -.11211200E+01, 0.22505200E+00, -.82790200E+00, -.37479400E+01, 0.44970900E+01, 0.13748700E+00, 0.24158700E+01, 0.17107400E+00, -.60224600E+00, -.52139800E+00, -.52616600E-01, 0.44532100E+00, -.53327500E+01, -.24408500E+01, -.56585700E+00, -.20211200E+01, -.20506700E+00, 0.35611000E+00, 0.72537900E+00, -.12620100E+00, -.88090300E-01, -.59189400E-02, 0.68982100E-01, -.19201600E+00, 0.73142800E+00, -.14184500E+01, -.35776300E-01, 0.62284000E+00, 0.37985300E+00, 0.46360300E-02, 0.29464800E+00, 0.11453900E-03, -.52389100E-01, -.48645600E-01, -.54343600E+00, 0.44887100E-01, -.26320200E+00, -.13764800E+00, 0.46556000E+00, -.58331200E-01, 0.25950600E+00, 0.79769000E-01, 0.27396900E-01, -.88688500E-02, 0.11770500E-01, 0.21495800E+01, -.35180600E-01, 0.27014400E+00, 0.19530800E+00, 0.53210400E+00, -.43893600E+00, 0.60809200E+00, 0.59678300E+00, 0.39919700E+00, 0.36991000E+00, 0.58690600E-01, -.49614600E+00, -.66725600E-01, 0.27459500E+00, -.29760200E+00, 0.44116800E+00, 0.77844900E-01, -.12673900E+00, -.72158200E+00, 0.25333400E-01, -.14210800E+01, -.17259000E-01, 0.31590800E-01, -.36747500E+01, -.15028400E+01, -.69175100E+00, 0.14918200E+01, 0.16361800E+00, -.27088700E+00, 0.91156200E+00, 0.27932300E+00, -.66645300E-01, 0.54093800E-04, 0.99357000E-01, 0.74419100E-01, -.26553500E+00, -.68827100E-01, -.86466700E-01, -.35302500E+00, -.60297900E-01, -.41576000E+00, -.69439100E-01, -.62286300E+00, -.26829900E-02, 0.71983100E-01, 0.13374300E+00, -.36375200E+00, -.10230800E+00, 0.50601200E+00, -.20783800E+03, -.69416800E+03, -.53590300E+03, 0.23707100E+03, -.23271000E+01, 0.26626000E+03, 0.66357000E+03, 0.64879400E+03, -.44111000E+03, -.99349400E+02, 0.48281200E+03, 0.64126700E+03, 0.83833100E+03, -.31663800E+03, 0.16263500E+03, 0.13640800E+04, 0.15666400E+03, 0.20002100E+03, 0.15308500E+03, -.37550400E+02, -.72931600E+02, -.10140800E+03, 0.38337300E+03, 0.43342500E+03, 0.23775800E+03, -.12268400E+03, -.12894200E+04, -.12077900E+03, -.45468600E+03, -.56790200E+03, -.21973800E+02, -.75867500E+03, -.70241900E+03, -.42740600E+03, -.84624100E+03, 0.83210600E+03, -.54721200E+03, -.46896400E+02, -.41578400E+03, -.44196300E+03, -.36218000E+03, -.20272900E+02, -.16291800E+03, 0.36811400E+02, -.40411300E+03, -.67411100E+03, 0.34012700E+04, -.16678200E+04, -.55727700E+02, -.17022000E+04, -.16034100E+03, 0.14967000E+03, -.12303000E+04, -.30269900E+03, -.15026600E+04, 0.13709600E+03, -.12169500E+04, -.45326100E+03, 0.22238800E+03, 0.25200000E+04, 0.22684000E+03, 0.15678700E+03, 0.44409600E+03, -.99292600E+03, -.13850400E+04, -.35041500E+03, 0.74454700E+03, -.46328500E+03, 0.15712500E+03, 0.26262200E+02, -.17515200E+03, -.78650200E+02, 0.49109000E+03, 0.70917800E+03, -.60036800E+03, -.11665100E+04, -.17596200E+04, 0.75430900E+03, 0.32236400E+03, -.46333600E+04, 0.23260300E+04, 0.11192500E+04, 0.23169600E+04, 0.89457700E+03, 0.76363500E+02, 0.13274900E+04, 0.62964700E+03, 0.21633700E+04, 0.61184100E+02, 0.29426800E+04, -.10207200E+04, 0.57393300E+03, 0.19088400E+03, 0.51919100E+03, 0.40821100E+03, 0.53644900E+03, -.25313700E+03, -.15576000E+04, -.17050100E+04, 0.58150400E+03, 0.15952200E+03, -.38193100E+03, 0.20879500E+03, 0.21269400E+03, 0.19276900E+03, 0.14766200E+03, -.38739700E+03, 0.74727800E+03, -.20573400E+03, -.56566400E+03, -.20247700E+03, -.48825400E+03, -.32913200E+04, 0.16584800E+04, 0.34526500E+04, 0.16404000E+04, 0.80472800E+03, 0.67346200E+02, 0.68749400E+03, -.23772800E+03, 0.90043400E+03, 0.26471800E+03, 0.82735700E+03, -.86419800E+03, 0.45628700E+03, 0.16824600E+04, 0.43238800E+03, 0.15285500E+03, 0.54814100E+03, -.66191100E+03, -.10006400E+04, -.23114100E+03, 0.66818000E+03, -.17330300E+03, 0.14640000E+04, -.73494400E+03, 0.36382700E+03, -.73191800E+03, -.19467200E+03, -.22731800E+03, -.10104000E+03, 0.16787600E+03, -.62906900E+03, -.67365300E+02, -.93137400E+03, 0.74121800E+03, -.40384100E+03, -.24669100E+04, -.37330700E+03, 0.26364700E+03, 0.10579500E+03, 0.30836600E+03, 0.65265000E+03, 0.78525900E+03, -.26473900E+03, 0.60759600E+03, 0.27752800E+04, -.14202300E+04, -.19906800E+04, -.13867700E+04, -.78055600E+03, -.13367800E+03, -.43946200E+03, 0.86622300E+02, -.13259900E+04, -.29246100E+03, -.18122100E+04, 0.62502600E+02, -.12147300E+03, 0.79695500E+02, -.35363900E+02, 0.92404400E+03, 0.11508000E+04, -.21152700E+01, -.26657900E+03, -.60652800E+03, 0.81262900E+03, -.30165400E+03, 0.25708600E+02, 0.53266900E+02, 0.28311800E+02, 0.84662800E+02, -.42827700E+02, 0.99322300E+02, -.24380200E+03, -.20908300E+02, -.79910800E+02, 0.78521100E+02, 0.12770500E+03, 0.66072800E+01, -.23902800E+03, 0.48494900E+02, -.62116200E+02, -.32762200E+03, -.11080400E+03, -.45561800E+03, 0.53057300E+02, 0.76572300E+02, 0.11620900E+02, 0.39468800E+03, 0.75604300E+03, 0.21359100E+02, -.30700100E+02, 0.65278300E+02 },
        { -.80685500E+01, -.30110500E+01, 0.34044500E+01, 0.61085200E+01, 0.26808400E+01, 0.23245300E+01, 0.38412800E+01, -.14835200E+02, -.28256600E+00, -.17583800E+01, -.29009100E+01, -.34108300E+00, -.11480100E+01, -.59165800E+00, -.38225900E+00, 0.10829600E+02, -.64927400E+01, -.47866800E+01, 0.22735700E+01, 0.14449000E+01, 0.43898500E+01, -.31022600E+01, 0.41068700E+00, -.14236800E+01, -.44818900E+00, -.78345000E-01, 0.97568200E-01, -.18015100E+01, 0.73685500E+00, 0.18543500E-01, -.22489000E+01, -.12643200E+01, 0.26721700E-01, -.48319500E+01, -.16280300E+00, -.54434300E-01, 0.16899500E+00, 0.27564500E+01, -.83634900E-02, 0.27176300E+01, 0.86177300E+01, -.30187800E+01, -.47098700E+00, -.79342600E+00, 0.99848300E+00, -.10199600E+01, 0.22382700E+00, 0.47283100E-01, 0.97092300E+00, 0.13866100E+00, 0.29120000E+00, 0.27773400E+01, -.28699600E-01, 0.68625400E+01, 0.12073200E+01, -.69568100E+00, 0.10816100E+01, 0.12759800E+00, -.67895600E-01, 0.38971100E+00, -.37844900E+00, 0.44898000E+00, -.37747500E+00, 0.26081900E+00, -.12329700E+01, -.68956000E+00, 0.32914700E-01, 0.25222000E+00, -.23419500E+00, 0.33011800E-02, 0.25429300E-01, -.23241900E+01, -.24508500E+00, -.21108000E+01, 0.65758300E+00, -.17340200E+01, -.63495500E+00, 0.20867200E+01, -.49898100E+00, -.45528100E+00, -.23042400E+00, 0.46656200E-01, 0.39655200E+00, 0.96312300E+00, -.30081000E+00, -.70832800E+00, 0.78448700E+00, -.22858200E+00, 0.16357100E+01, -.14277300E-01, 0.64278800E+00, -.69236100E-02, 0.12904000E+01, 0.40009000E+00, 0.16080900E+01, 0.12630000E+01, -.10332100E+01, -.23649500E+01, 0.30360500E+04, -.94748300E+03, 0.50923500E+03, -.57207900E+03, 0.47240800E+03, 0.11880900E+04, -.17206700E+03, 0.41138800E+03, 0.10558800E+04, -.10184900E+03, -.38400000E+03, -.43829800E+04, 0.37579800E+03, -.20574200E+03, 0.56333500E+04, -.18922400E+03, -.11468400E+04, -.24547700E+03, 0.15356700E+03, -.12342700E+04, -.19047100E+04, 0.20165900E+03, 0.12545800E+04, 0.30188100E+04, -.15004200E+04, -.40240600E+04, -.15109600E+04, -.64465600E+03, 0.51471500E+03, -.12862700E+04, 0.89855000E+03, 0.34764400E+03, 0.16130200E+03, 0.77142000E+03, -.22508700E+04, 0.95490500E+03, -.92503400E+03, 0.11256400E+04, 0.14250400E+02, -.86844200E+03, 0.15434600E+04, 0.12157000E+03, 0.12133000E+04, -.21627400E+03, 0.12187900E+04, 0.15292600E+04, -.69459400E+03, 0.30330000E+04, -.76586600E+03, -.37175800E+04, -.41746400E+03, -.15455300E+04, -.53323100E+03, 0.81919500E+03, -.12503700E+04, 0.82046300E+04, 0.41236400E+04, -.20825800E+04, -.55868300E+04, -.20616600E+04, -.74458800E+04, -.31103300E+04, -.21876200E+04, -.19548500E+04, -.27634100E+04, -.37994500E+04, 0.11628200E+05, -.22630600E+04, 0.12832200E+04, 0.17380000E+04, 0.11315400E+04, 0.57940800E+03, 0.53035000E+03, 0.69015700E+02, -.23251900E+04, -.16431400E+04, 0.85930700E+03, 0.13461100E+03, -.86219100E+04, 0.43162700E+04, 0.12718500E+04, 0.43084200E+04, 0.10553800E+04, -.19587000E+04, 0.40368600E+04, 0.35689900E+03, 0.22554700E+04, -.14566600E+04, 0.18620200E+04, -.16630500E+04, 0.91910300E+03, 0.17228900E+04, 0.83745600E+03, 0.12155400E+03, -.27611100E+02, 0.42979000E+03, -.13757900E+04, -.10854200E+04, 0.28245300E+03, 0.20778000E+03, 0.10000600E+04, -.51544400E+03, 0.11725100E+04, -.49861800E+03, -.18934700E+03, -.13165300E+03, 0.17382000E+03, -.78049800E+02, -.14755800E+04, -.27224800E+03, -.95372500E+02, -.46317300E+04, 0.23176300E+04, 0.65929900E+04, 0.23117000E+04, -.28054800E+03, 0.12885600E+04, 0.46576500E+03, -.14420800E+04, 0.35311900E+03, 0.15535500E+04, 0.26629400E+04, 0.77151800E+04, -.38120400E+04, -.51504700E+04, -.38573600E+04, -.60015400E+04, -.36160100E+04, -.11008600E+04, 0.23962600E+03, -.26870800E+04, -.37219800E+04, 0.73521200E+04, -.29066600E+04, 0.14034200E+04, 0.46695700E+04, 0.14533900E+04, -.27877900E+04, 0.29595900E+03, -.54028900E+03, -.13262900E+04, 0.61321400E+03, -.48060600E+03, 0.60770100E+04, -.60222000E+04, 0.29907600E+04, -.16948600E+03, 0.30089700E+04, 0.48670000E+04, 0.15650700E+04, 0.21115700E+04, 0.32797800E+02, 0.38219200E+03, 0.13833400E+04, -.60718000E+04, 0.32569100E+04, -.16783900E+04, -.51065000E+04, -.16277600E+04, -.90166000E+03, 0.67828600E+03, -.16308800E+04, 0.14304100E+04, 0.92689000E+03, -.16680900E+03, 0.24972000E+03, -.44945000E+04, 0.20977800E+04, -.16423100E+04, 0.22440700E+04, 0.23820900E+04, 0.11974300E+03, 0.26997200E+04, 0.11113900E+02, 0.86962400E+03, 0.10524600E+04, 0.54571100E+01, -.58930800E+03, -.52672900E+02, -.21674000E+03, -.17771000E+03, -.19987500E+03, 0.31375700E+03, -.30256300E+03, 0.87912500E+03, -.11344400E+03, 0.15821900E+02, -.53863800E+03, -.14993600E+03, -.12244600E+02, 0.34479800E+03, 0.75655000E+03, 0.31301100E+04, 0.20275600E+03, 0.19285300E+03, -.24626400E+03, 0.23369500E+03, -.40211600E+01, -.29146400E+04, -.19783100E+04, 0.60315500E+03, 0.59834500E+03, 0.36856500E+03 },
        { 0.31426300E+01, 0.12887500E+01, -.14859300E+00, -.13415800E+01, -.15420600E+01, -.11321300E+01, -.11437700E+01, -.23953100E+01, -.19625100E-01, -.13490000E+01, -.46253100E+00, -.41898800E+00, 0.24795900E+00, 0.22602500E+00, 0.21144400E+00, -.12137500E+00, 0.43712100E+01, 0.26858400E+01, -.26745700E+01, -.12157800E+01, -.53979300E+00, 0.52531700E-01, -.17375800E+00, -.81511700E+00, 0.65749300E-01, -.58653400E-02, -.58704300E+00, -.16274000E+01, 0.97512300E-01, -.59269300E-01, 0.52018100E+00, -.64896700E+00, -.44281400E+00, 0.26103800E+01, -.11721600E-01, 0.67765500E-02, 0.29372700E-01, 0.33263300E+00, 0.11700000E+00, 0.28485100E+00, -.15844600E+01, 0.13445700E+00, -.37208000E-01, -.22289900E+00, 0.18231600E+00, 0.49415100E+00, -.63266100E-01, 0.42028100E-01, 0.29783400E+00, -.23967700E+00, 0.83571800E+00, -.18571300E+01, 0.12025400E+01, -.31332100E+01, -.25646500E+00, -.56580000E-01, -.60474000E+00, 0.95563000E-01, 0.88681000E-01, -.41096400E+00, 0.11913100E-01, 0.15814100E+01, -.18304700E+00, -.38820500E+00, -.56643000E+00, -.37321000E+00, -.45166800E+00, -.17295100E+00, 0.64360400E+00, 0.18619300E-01, 0.46216400E-01, 0.19610300E+01, 0.66782000E+00, -.62008300E+00, -.37375700E+00, 0.23159300E-01, 0.14297400E+00, -.20102500E+00, -.37484500E+00, 0.65340800E-01, -.97391700E-01, -.42105900E-01, 0.26077600E+00, -.57631100E+00, -.12148000E+00, 0.50923500E+00, -.29466500E+00, -.74805600E-01, -.48373300E+00, 0.65785400E-01, -.80963500E+00, 0.19648800E-03, 0.50229200E+00, 0.13353500E+00, 0.39240000E+00, 0.10139500E+01, 0.69878200E-01, 0.14303500E+00, -.12062700E-01, 0.47104500E+04, -.23293200E+04, -.22716100E+04, -.23548300E+04, -.77551500E+03, -.99886300E+03, -.17862200E+03, 0.21007600E+04, -.21865800E+03, -.12075500E+04, -.20990000E+04, 0.24155200E+03, -.12169000E+03, -.14328000E+04, -.12038900E+03, -.40701200E+03, -.29100700E+03, 0.20168400E+03, -.76374500E+02, 0.51732400E+02, -.17207700E+03, 0.11281000E+04, 0.45142600E+03, -.22473100E+03, -.13755400E+03, -.22530000E+03, -.14925400E+03, -.57902400E+02, -.27427900E+02, 0.13736600E+03, 0.26943700E+03, -.26495500E+03, -.42294600E+03, -.34439900E+03, 0.14684800E+03, 0.17076000E+03, 0.17212900E+03, 0.83353200E+02, -.19955200E+02, 0.29107900E+02, -.51168600E+02, 0.23866900E+03, 0.36224100E+02, -.68820500E+02, -.16774500E+04, 0.83813000E+03, 0.48048800E+03, 0.83909300E+03, -.73366900E+02, 0.21946900E+03, 0.37305700E+03, 0.57368100E+03, 0.63542600E+03, -.21962400E+01, 0.73792500E+03, 0.14837400E+04, -.72641700E+03, -.11385900E+04, -.74191500E+03, -.87247700E+02, -.31840900E+03, -.25218700E+03, 0.10294700E+04, -.26828500E+03, -.57486900E+03, -.11597200E+03, -.69142500E+02, 0.38723900E+02, 0.54273100E+03, 0.34503000E+02, -.19184500E+03, -.46860000E+03, 0.24073100E+03, 0.13457200E+03, 0.25946100E+03, -.37719400E+03, -.18626500E+03, 0.18336100E+04, -.91330100E+03, 0.30973400E+03, -.91628900E+03, 0.61347100E+03, 0.11374800E+04, -.10282000E+04, -.40266400E+03, -.15068600E+04, 0.11964000E+04, -.24586700E+03, -.33395300E+03, 0.16490700E+03, 0.49675300E+03, 0.16479400E+03, -.87132200E+00, -.16990900E+03, 0.17092200E+03, 0.14382700E+03, 0.20934500E+03, -.12405700E+03, 0.27444600E+02, -.41407300E+03, 0.21972200E+03, 0.41503200E+03, 0.20658100E+03, 0.59414000E+02, 0.57713300E+02, 0.29293100E+03, 0.34697900E+03, -.21736300E+03, -.97203900E+00, 0.53118700E+03, -.88707800E+03, 0.43589100E+03, -.44108400E+03, 0.44478400E+03, -.25463800E+03, 0.33037900E+03, -.90244400E+03, -.13289700E+04, -.25767900E+03, 0.40392400E+03, 0.18284400E+04, 0.64595800E+03, -.30613600E+03, -.47147800E+03, -.32304200E+03, 0.38412500E+02, -.14604800E+03, -.19881000E+03, 0.34076500E+03, -.30264800E+03, -.30513000E+03, 0.22343200E+03, 0.19290700E+03, -.98010900E+02, -.63447600E+03, -.96472300E+02, -.24485600E+03, 0.18903600E+02, -.14919500E+03, 0.18477000E+03, 0.13147800E+03, -.82988500E+02, 0.35934900E+03, 0.35739700E+04, -.17946700E+04, -.86343200E+03, -.17863600E+04, -.35829400E+03, -.67851700E+03, 0.17511000E+02, 0.14876900E+04, -.20147200E+03, -.64299500E+03, -.22779200E+04, -.61904900E+03, 0.30217500E+03, 0.18105800E+03, 0.30932400E+03, -.16645700E+03, -.44845000E+03, 0.35411400E+03, 0.12833600E+02, 0.67820900E+03, -.39074400E+03, -.19851700E+03, 0.89181400E+01, -.23008900E+02, 0.99341300E+03, -.34544900E+01, -.34730200E+03, -.56539300E+03, -.29867900E+03, -.50697500E+03, -.49167400E+03, -.21249000E+03, -.15361800E+03, 0.16507100E+02, -.63710000E+02, -.17528400E+02, -.31941000E+02, 0.27929000E+02, 0.41264500E+01, 0.55119700E+02, -.19093500E+03, 0.37919000E+02, -.83990800E+02, -.31810500E+03, 0.46778400E+01, 0.77381400E+02, -.54978200E+02, -.11826200E+03, -.43331700E+02, 0.57169400E+02, 0.81173900E+02, -.39463300E+02, -.36545600E+02, 0.18803100E+03, 0.90659800E+01, 0.10770900E+03, 0.48305100E+02, 0.18050500E+02, -.11744900E+03 },
        { 0.99808800E+01, -.38471700E+01, -.19594900E+01, 0.21213800E+01, -.15792400E+01, 0.13110100E+01, 0.13672500E+01, 0.80518200E+00, 0.19636000E+01, -.16870800E+00, -.46096400E+00, -.22947100E+00, -.22587800E+01, 0.59048400E+00, -.24878800E+00, 0.82222400E+00, -.43632600E+01, 0.15310600E+01, -.40572300E+01, -.14079700E+01, 0.16650400E+01, 0.11180600E+01, 0.54588100E+00, 0.68911900E+00, 0.90121000E+00, -.54996500E-01, -.91975000E+00, 0.51787800E+00, 0.45023200E+01, 0.90436600E-01, -.99606100E+00, -.65212200E+00, 0.13675400E+01, -.25038900E+01, -.17027900E+00, -.20345000E+00, -.41084300E-01, -.11524800E+01, -.73094900E+00, -.29279800E+00, -.96415000E+00, 0.44270500E+00, 0.10417000E+00, 0.22987400E+00, 0.91612800E-01, -.86133100E+00, 0.66829000E-01, -.72942400E-02, -.89642800E+00, -.29007200E+00, -.59915500E+00, 0.67588200E+00, -.30619500E+00, -.89963100E+00, -.32123300E+00, 0.52921500E+00, -.73813000E+00, 0.63517600E-01, 0.46336100E-01, -.71250200E+00, -.22514400E-02, 0.94517900E-01, -.52833200E-01, 0.15759600E+00, 0.53445900E+00, 0.59127900E+00, -.11967500E+01, -.18298200E+00, 0.39437600E+00, -.66473500E-02, -.32566900E-01, -.11344400E+01, -.60764700E-01, 0.58877800E+01, 0.62603100E+00, 0.58433900E+00, -.61160100E+00, 0.13097400E+01, 0.67689500E+00, 0.12081100E+00, 0.20168200E+00, -.20460500E-01, -.75460500E+00, -.11412300E+01, 0.19897900E+00, -.34934800E-01, 0.19289900E+00, 0.12872300E-02, 0.97598800E+00, 0.32828200E+00, 0.16112400E+01, 0.15157900E-01, -.22692000E+00, -.70465800E+00, -.30615400E+01, -.27903600E+00, -.56271300E+00, 0.38274900E+00, -.21566300E+00, -.92458100E+00, 0.33366800E+03, -.50783800E+02, 0.24771300E+00, 0.20290900E+03, 0.12803500E+03, -.22452300E+03, 0.56906100E+03, -.16717500E+03, 0.98937100E+02, -.60715000E+03, -.72403800E+03, 0.28737500E+03, 0.53045000E+03, 0.36229300E+03, 0.29219800E+02, 0.20836900E+03, -.27822000E+02, -.74503500E+01, 0.66496700E+03, 0.14131600E+03, 0.11996800E+04, -.88356500E+03, 0.44707000E+03, 0.10089400E+04, 0.44219200E+03, 0.47506700E+03, 0.50454400E+03, -.41636300E+03, -.22712700E+03, -.64045300E+03, 0.52515300E+03, 0.27711500E+03, 0.80820800E+03, 0.10752100E+03, -.33086200E+03, -.40412400E+03, 0.26206800E+03, 0.37685800E+03, -.35849300E+03, 0.17968600E+03, -.48313300E+03, 0.30861200E+03, -.29540100E+03, -.38305200E+04, 0.19138200E+04, 0.24979700E+04, 0.19154900E+04, 0.62072300E+03, 0.31441500E+03, 0.14964100E+03, -.90762900E+03, 0.13697700E+04, 0.18629300E+03, 0.73277500E+03, -.15032900E+04, 0.49493600E+03, 0.92158900E+03, 0.75161300E+03, -.43621100E+03, -.46100500E+03, 0.98639400E+02, -.15917700E+03, 0.50677700E+03, -.65532100E+03, 0.11463600E+04, -.12064000E+04, 0.32840000E+03, 0.96864400E+02, 0.60326600E+03, 0.72216500E+02, -.22313300E+03, 0.56833600E+03, 0.76116000E+03, 0.10555500E+04, -.27739900E+03, -.11544600E+03, 0.24528300E+04, -.12597200E+04, -.11870200E+04, -.12232800E+04, -.35527900E+03, 0.35542300E+01, -.26237600E+03, 0.31816800E+03, -.50316700E+03, -.11302900E+03, -.51038800E+03, -.16654100E+04, 0.70739000E+03, 0.38650700E+03, 0.82770300E+03, 0.21309100E+03, -.48615300E+02, 0.64251400E+03, 0.83792200E+03, 0.11621100E+04, -.17737200E+03, 0.68327200E+02, -.27512400E+04, 0.12894600E+04, 0.87490100E+03, 0.13754400E+04, 0.25091800E+03, 0.21950200E+03, 0.31953400E+03, 0.28819800E+03, 0.97717400E+03, 0.83441200E+02, 0.15499800E+04, -.11214700E+04, 0.47916600E+03, 0.15251400E+04, 0.56151200E+03, -.92672200E+03, 0.11481600E+03, 0.74297700E+03, -.12768800E+02, 0.10457400E+04, -.12022600E+03, 0.23643300E+04, -.12109100E+04, 0.26799600E+03, 0.65000300E+03, 0.60541100E+03, -.46113200E+03, -.58799500E+03, 0.29832100E+03, -.45973100E+03, 0.99078200E+02, -.65266700E+03, 0.71702600E+03, -.25193000E+04, 0.12516100E+04, 0.17411700E+04, 0.12596400E+04, 0.12031700E+03, 0.50465900E+03, -.89867500E+01, -.36710800E+03, 0.11412100E+04, 0.28394400E+03, 0.14649400E+04, -.25734700E+03, 0.48570300E+03, -.86224900E+03, 0.12907700E+03, 0.44953400E+03, 0.67312400E+03, -.40478400E+03, 0.59116600E+03, -.78364600E+03, 0.68211500E+03, -.53177600E+03, -.28608500E+03, 0.30416900E+03, 0.40290600E+03, 0.14288900E+03, 0.15761800E+03, -.72236800E+01, -.37439200E+03, -.68072100E+03, -.22734900E+01, 0.75094800E+02, -.78684300E+03, -.57680300E+03, 0.74501600E+03, -.24334500E+03, 0.28885400E+03, -.40021400E+03, -.87508000E+02, 0.19875500E+03, -.10050900E+03, 0.63331000E+03, -.20696100E+03, -.61680000E+03, -.52446300E+02, 0.16937300E+02, 0.52680000E+02, 0.36747500E+02, 0.15378400E+02, -.52872700E+01, 0.12059400E+03, 0.83990400E+02, 0.87030300E+01, -.34378300E+02, -.15850600E+03, -.84004900E+02, -.19924300E+02, -.28088800E+01, 0.12541100E+03, 0.60342500E+03, -.33850700E+02, -.10487300E+03, 0.40409700E+02, -.23091800E+02, -.14826000E+03, -.59009600E+03, -.10570800E+03, 0.12609900E+03, -.43790000E+02, 0.90096200E+02 },
        { 0.62794500E+01, 0.86927200E+00, 0.56952200E+01, 0.48693500E+01, -.36506800E+00, -.10138600E+01, -.21447600E+01, 0.44658100E+01, 0.10228900E+00, 0.32073400E+01, -.45554000E+00, -.94516700E+00, -.59454100E+00, 0.67104400E+00, 0.43783800E+00, -.13676100E+02, 0.28738400E+01, 0.82420400E+00, -.41973000E+01, 0.20198100E+00, 0.14674400E+01, -.28150900E+00, 0.14310500E+00, -.58768800E+00, -.34215200E+00, 0.14805600E-01, 0.11317700E+01, 0.71734300E+00, -.18169200E+01, 0.47521800E-01, -.73011300E-01, 0.75157400E-02, 0.73509400E+00, -.34251400E+01, 0.35218100E-01, 0.30470700E-01, 0.10622700E+00, 0.13312700E+00, 0.43209100E-01, -.43379900E+00, -.10958700E+01, 0.37479300E+00, 0.14296400E+00, 0.32352700E+00, -.98213800E-01, -.18339000E+01, 0.45166000E-03, 0.82501600E-02, -.59030800E+00, -.25843600E+00, 0.27849700E+00, 0.74840000E+00, -.74774400E-01, -.23201300E+01, 0.16669600E+00, 0.72724300E+00, -.22360900E+00, 0.10321900E+00, 0.26055000E-01, -.11220700E+01, 0.21996100E+00, -.73610700E+00, -.70638500E-01, 0.62801700E+00, 0.79936800E+00, 0.20889300E-01, -.21221700E+01, -.28995400E+00, 0.97122600E+00, 0.95119500E-02, 0.12563800E+00, 0.41483200E+00, 0.30041300E+00, 0.52481000E+01, 0.52437700E+00, -.15040100E+00, -.30636500E+00, 0.15032200E+01, 0.21977000E+00, 0.29487200E+00, 0.13152800E+00, -.19465800E-01, -.33551100E+00, -.27590100E+00, 0.45415900E+00, -.75353800E-01, -.59942900E+00, 0.16142200E+00, -.10777100E+01, -.26835200E+00, 0.22928000E+00, -.13301200E-01, -.43478100E+00, -.25706800E+00, -.12101900E+01, -.10552600E+01, 0.32592300E+00, 0.21559600E+01, -.37014500E+00, 0.79770700E+00, -.17957800E+00, 0.15299400E+04, -.12835100E+01, -.19193000E+03, 0.68601800E+03, -.80936500E+03, -.77981500E+03, -.18897200E+03, 0.64933300E+03, 0.52292000E+03, 0.15139900E+03, -.72155200E+02, -.49941900E+04, -.76883600E+02, 0.34330600E+03, -.23849100E+03, -.11783000E+03, 0.75314200E+03, 0.87934000E+03, -.40916000E+03, -.14588200E+04, -.19018000E+04, 0.92622300E+03, 0.24542200E+04, 0.94981800E+03, 0.12246300E+04, 0.23220300E+03, 0.67590100E+03, 0.10064800E+04, 0.27056400E+03, 0.42308300E+03, 0.80229000E+03, 0.11843800E+04, -.39482400E+03, 0.94764500E+03, -.59191400E+03, 0.15539400E+01, 0.54271500E+03, -.88644200E+03, -.24575600E+03, -.84250600E+03, 0.29140800E+03, 0.25585000E+03, -.75265500E+04, 0.37171600E+04, 0.24504900E+04, 0.37620900E+04, 0.13551400E+04, 0.29795100E+03, 0.16617900E+04, -.87571400E+03, 0.16680500E+04, 0.52885800E+03, 0.15581500E+04, -.25413100E+04, 0.12096700E+04, 0.10171400E+04, 0.12708000E+04, 0.15261300E+04, 0.77017300E+03, 0.13947700E+04, 0.11468700E+04, 0.78952500E+03, 0.68758800E+03, 0.14429300E+03, -.18861900E+03, -.53684500E+02, -.13274100E+04, 0.94672400E+02, -.55249500E+03, -.65718400E+03, 0.79940200E+03, 0.21929900E+04, 0.27766600E+04, -.92182500E+03, 0.13484300E+03, 0.68589700E+04, -.34282100E+04, -.12316200E+04, -.34262800E+04, -.16668400E+04, 0.65697000E+03, -.24066500E+04, -.30069600E+03, -.17909000E+04, 0.75048300E+02, -.35253600E+04, -.20549300E+03, 0.69890000E+01, -.11781000E+04, 0.99978100E+02, -.34304700E+03, -.52738900E+03, 0.65734300E+03, 0.22065800E+04, 0.27702100E+04, -.75643700E+03, 0.25888600E+03, 0.24613900E+03, -.17907600E+03, -.10789500E+04, -.12138000E+03, -.15865300E+02, 0.32246400E+03, -.33888100E+03, 0.91979200E+03, 0.90505800E+03, 0.30332600E+03, -.13192000E+01, 0.24583500E+04, -.12173300E+04, -.34510800E+04, -.12331900E+04, -.86103700E+03, -.10449800E+04, 0.10282700E+03, 0.36223700E+03, 0.13706300E+03, -.11953400E+04, -.13498500E+04, -.27669000E+04, 0.13060400E+04, -.27455200E+03, 0.13836500E+04, 0.11664800E+04, 0.71680800E+03, 0.92015900E+03, 0.49262600E+03, 0.80470900E+03, 0.61962800E+03, 0.51258200E+03, -.18078300E+04, 0.90971800E+03, -.59665800E+03, 0.90397200E+03, 0.10597800E+04, 0.38951100E+03, 0.43111500E+03, 0.21230800E+02, 0.49517600E+03, 0.46645100E+03, 0.41727100E+03, 0.40049800E+04, -.19402700E+04, 0.95937100E+03, -.20045200E+04, -.16559900E+04, 0.33558200E+03, -.17958700E+04, 0.26818500E+03, -.11223300E+04, 0.31294500E+03, -.27903400E+03, -.28613600E+04, 0.14594500E+04, 0.43056800E+04, 0.14312700E+04, 0.12469800E+04, 0.87794000E+02, 0.89991200E+03, -.75201800E+03, -.45838100E+03, 0.61053900E+03, 0.15611500E+04, 0.34670300E+04, -.16030900E+04, 0.28046800E+04, -.17370700E+04, -.18021600E+04, -.23507500E+03, -.97051300E+03, 0.77955600E+03, 0.33117400E+03, -.84620700E+03, 0.79360700E+03, 0.44450600E+03, -.22164500E+02, 0.85324300E+02, 0.39349700E+02, 0.14113400E+03, -.19468400E+03, 0.97349900E+02, -.36525800E+03, 0.69822200E+02, -.44583700E+01, 0.33081800E+02, 0.39462800E+02, 0.76400200E+02, -.20938400E+03, -.25469300E+03, -.59620600E+03, -.58907000E+02, 0.14151400E+03, 0.97876400E+02, -.17988900E+03, 0.89963400E+02, 0.40208400E+03, 0.26864400E+03, -.55208800E+02, -.28231400E+03, -.21645100E+03 },
        { -.57504900E+01, -.16317100E+01, 0.15467700E+01, 0.13117600E+01, 0.44995000E+01, 0.23462600E+01, 0.13951200E+01, 0.11233700E+02, -.28465300E+00, 0.39213000E+01, 0.14422200E+01, -.18494200E+00, -.14163800E+00, -.37639500E+00, 0.48766300E+00, -.96902200E+01, -.59625600E+01, -.41692400E+01, 0.16750600E+01, 0.25387000E+01, 0.18768100E+01, -.31625100E+00, 0.34506300E+00, 0.71996300E+00, 0.45682100E-01, -.47450600E+00, 0.38156300E+00, 0.11573100E+01, -.66105500E+00, -.20389100E+00, 0.80574600E-01, 0.43046400E+00, -.13181400E+00, -.60787600E+00, -.31779300E-01, 0.21407200E+00, 0.58670600E-01, -.74778800E+00, 0.12102800E+00, 0.14795000E+00, -.31701400E+00, 0.22115900E+00, -.27982400E-01, 0.32860500E+00, -.76660300E-01, -.62497200E+00, 0.69140500E-01, 0.54792900E-01, 0.11490200E+01, 0.34459100E-01, -.76358500E+00, 0.14173800E+01, -.63421800E+00, 0.76713800E+00, -.19146000E+00, 0.74659500E+00, 0.40560100E+00, -.12048800E+00, 0.79561800E-01, 0.90364700E-01, -.18275300E+00, -.66667200E+00, 0.17011500E+00, 0.56746800E+00, 0.11933500E+01, 0.51095600E+00, -.25897100E+00, -.39047600E-01, -.60517700E+00, -.26641500E-01, -.10821100E-01, 0.62971400E+00, -.14212400E+00, -.87136500E+00, -.21980600E+00, 0.10721100E+00, -.70424700E-01, -.46879900E+00, 0.43939700E+00, 0.44444300E-01, 0.15171100E+00, 0.42767100E-01, -.10280900E+00, -.37705100E+00, -.13394700E+00, -.11429300E+00, 0.21888400E+00, 0.28912800E-01, 0.22288400E+00, -.12044400E+00, 0.33051800E+00, 0.10428500E-01, -.21568700E+00, -.23529000E+00, -.12966600E+01, -.63996900E+00, -.13231400E+00, 0.36631900E-01, -.21885800E+00, -.21203600E+00, -.18935400E+00, -.21490700E+00, 0.19684500E+02, 0.18096400E+03, 0.19073400E+03, -.14379600E+03, 0.34972400E+03, -.19743800E+03, 0.27395000E+03, -.10220900E+03, -.90350400E+03, 0.45176800E+03, 0.14886600E+04, 0.45198000E+03, 0.93828600E+02, 0.15982900E+03, 0.64535100E+02, -.21803600E+03, 0.26988600E+03, 0.15880800E+03, 0.50656300E+03, 0.16232500E+03, -.99355100E+02, 0.73365600E+02, -.80799100E+02, 0.19415200E+03, 0.32276600E+03, -.49250000E+03, -.10488500E+03, -.40750600E+03, 0.40460800E+03, 0.62399800E+02, -.12860800E+03, 0.16151900E+03, -.42632700E+03, 0.64288500E+02, 0.98527200E+02, 0.56814800E+02, 0.11726400E+03, 0.72930700E+02, -.12478200E+03, 0.10724400E+03, 0.27885700E+03, -.22425800E+04, 0.10949500E+04, 0.17522300E+04, 0.11215000E+04, -.67842600E+02, 0.20154200E+03, -.18125300E+03, -.10395100E+04, 0.42963500E+03, -.47768400E+01, 0.10947500E+04, 0.25325200E+04, -.13377100E+04, -.27637700E+04, -.12663000E+04, -.16150800E+04, -.83807800E+03, -.81990000E+03, -.38211200E+03, -.13638900E+04, -.98746200E+03, 0.50214400E+03, -.78673500E+03, 0.35708600E+03, 0.65485700E+02, 0.39367200E+03, 0.12911200E+03, 0.13608500E+03, 0.21054700E+03, 0.46398500E+02, 0.24552300E+03, 0.11474200E+03, 0.13547100E+03, -.64968700E+02, 0.40270400E+02, -.37414600E+03, 0.39843500E+02, -.17218800E+03, -.18629500E+03, 0.47923100E+03, 0.24917900E+03, 0.18085400E+03, -.34640500E+03, 0.11510100E+03, -.11720200E+04, 0.56397500E+03, 0.50852500E+03, 0.58603400E+03, 0.14792400E+03, 0.10547000E+03, 0.33011600E+03, 0.10575300E+03, 0.41034700E+03, 0.85258900E+02, 0.87862500E+02, -.11866000E+04, 0.56592000E+03, 0.89374400E+03, 0.59314700E+03, 0.22609200E+03, 0.25366400E+03, -.70965300E+02, -.16813300E+03, 0.33866300E+03, 0.23019600E+03, 0.58804200E+03, -.24477900E+04, 0.12278800E+04, 0.22702900E+04, 0.12245800E+04, -.49275800E+03, 0.12232700E+03, 0.11691400E+04, 0.12745300E+03, 0.11078500E+04, -.45421700E+01, 0.16531700E+04, 0.13715700E+04, -.74863000E+03, -.15066500E+04, -.68583900E+03, -.12074300E+04, -.83744200E+03, -.31870500E+03, -.54333700E+03, -.12535900E+04, -.86184000E+03, 0.13372600E+03, -.66261000E+03, 0.31230000E+03, 0.12582800E+04, 0.33129300E+03, -.33547000E+03, 0.21543500E+03, -.26049000E+03, -.24014200E+03, 0.36940100E+03, -.37672000E+02, 0.92383600E+03, -.67691100E+03, 0.40006700E+03, -.21450600E+03, 0.33883700E+03, 0.59255500E+03, 0.45647100E+03, 0.65169800E+01, 0.43718000E+03, -.78887800E+02, 0.47659200E+03, -.17576500E+02, 0.94550400E+03, -.47053100E+03, -.59931800E+03, -.47288200E+03, -.14132300E+03, -.82449700E+02, -.50331300E+03, -.96960700E+02, -.11970900E+03, -.89647200E+02, -.64620700E+03, -.84808000E+03, 0.48891500E+03, -.26698300E+02, 0.42448500E+03, 0.28936100E+03, 0.23594800E+03, 0.63900500E+03, 0.20777600E+03, 0.47222900E+03, 0.30931000E+03, 0.54009400E+03, -.11970800E+03, 0.48537500E+01, -.10495700E+02, -.12189900E+02, -.21179100E+02, 0.17737600E+02, -.32319900E+02, 0.89038300E+02, -.16075700E+02, -.93115100E+01, -.82243600E+02, -.67261300E+02, -.61676000E+02, 0.65879800E+02, 0.99909200E+02, 0.49028600E+03, 0.29892800E+01, -.15160900E+03, -.15158500E+02, 0.31427900E+02, -.14750100E+03, -.49065000E+03, 0.16644500E+03, 0.77835200E+02, 0.18351800E+01, 0.13551000E+03 },
        { 0.43333400E+01, 0.92002000E+00, -.35087600E+00, -.11070300E+01, -.32275500E+01, -.92632500E+00, -.59238600E+00, -.28791300E+01, 0.32948900E+00, 0.93755900E+00, -.97733500E+00, -.34433900E+00, -.83142400E+00, 0.18423200E+00, 0.92892600E-01, -.18267100E+01, -.14470000E+01, 0.56849300E+00, -.33951700E+00, 0.50129000E-01, -.12804600E+01, -.45780100E+00, 0.56322800E-01, -.13366900E+01, -.15778400E+00, -.55286500E-01, -.65790900E+00, -.11156500E+01, 0.29390700E+01, -.10112000E+00, 0.78707200E+00, 0.26759000E+00, -.11154500E+01, 0.63722100E+00, -.77386900E-02, 0.23369600E+00, -.10291100E-01, -.78830500E+00, 0.24367600E+00, -.25502400E+00, -.23755400E+01, -.28758700E+00, 0.18691800E+00, -.33911400E+00, 0.18780000E+00, 0.29640900E+00, -.55301100E-01, 0.28997000E-02, -.54455000E-01, -.82117300E-01, -.10822400E+00, 0.20920500E+00, -.62009500E+00, 0.25213500E+01, -.55893800E+00, -.76971600E+00, -.40492700E+00, -.16947800E+00, -.18500200E-01, 0.24663400E+00, 0.74304700E-01, -.69446200E+00, 0.16475900E+00, 0.30540200E+00, 0.39451700E+00, 0.45483100E+00, -.95358200E+00, -.47153100E+00, -.98879900E+00, -.13528700E-02, 0.39888700E-02, -.53493200E+01, -.28284700E+00, -.18684300E+01, 0.34610300E+00, -.10131300E+01, 0.44069500E+00, -.51698500E+00, 0.46357600E+00, 0.33782400E-01, -.85818100E-01, 0.10459900E-01, 0.33457000E+00, -.54414100E+00, 0.93958000E-02, 0.50249900E+00, 0.62377300E+00, -.31854200E+00, 0.70990000E+00, 0.28154900E-01, 0.10166100E+01, 0.74374200E-02, 0.37306200E-01, -.30355000E-01, -.14489100E+01, -.20493500E+01, -.29165400E+00, -.47300300E+00, -.36394500E+00, -.24032700E+00, 0.16957600E-01, -.47040200E-01, -.64379000E-02, 0.65768200E+03, 0.47012500E+03, -.23734200E+03, 0.42747000E+03, -.35296600E+03, 0.64224300E+03, -.65148300E+03, -.15312600E+04, 0.76270000E+03, 0.34262200E+04, 0.76549500E+03, -.30389600E+02, 0.26239200E+03, 0.13804000E+03, -.37786800E+03, 0.14894300E+03, 0.30891900E+03, 0.15264600E+04, 0.12070200E+04, -.60740400E+03, -.14404900E+04, -.60361200E+03, -.17658000E+03, 0.78430400E+02, -.56126300E+03, -.13250800E+03, -.51283800E+03, 0.21153800E+03, -.91630200E+02, -.62278700E+03, 0.25020900E+03, -.56585800E+03, 0.31142400E+03, 0.18352400E+03, 0.20513600E+02, 0.34006200E+03, 0.67746700E+02, 0.11074600E+03, 0.14496900E+03, 0.98501400E+02, -.74866500E+03, 0.38957100E+03, 0.13932400E+04, 0.37420900E+03, -.31335000E+03, 0.17555000E+03, -.10339800E+04, -.19131800E+04, -.54454200E+03, -.11432200E+03, 0.91496400E+03, 0.40044800E+04, -.20122200E+04, -.46609000E+04, -.20022300E+04, -.20889600E+04, -.12467900E+04, -.15178100E+04, -.10070700E+04, -.25893200E+04, -.12347400E+04, 0.74294300E+03, -.60912200E+03, 0.35442800E+03, 0.50744500E+03, 0.30475700E+03, 0.19322900E+03, 0.17486900E+03, 0.11172400E+03, -.69496900E+03, -.47558000E+03, 0.26336200E+03, -.54197600E+02, -.21118300E+04, 0.10642700E+04, -.11266900E+03, 0.10551000E+04, 0.32272000E+03, -.41000800E+03, 0.13509700E+04, 0.34399900E+03, 0.81802900E+03, -.58674100E+03, 0.10310500E+04, -.12681600E+04, 0.65855600E+03, 0.92001500E+03, 0.63543600E+03, 0.18375800E+03, 0.11548100E+03, 0.38144900E+03, -.61125300E+03, -.27364500E+03, 0.21548700E+03, -.54558100E+02, -.16989800E+04, 0.84631500E+03, 0.13049100E+04, 0.84967100E+03, 0.24177900E+03, 0.13501200E+03, 0.29006300E+03, -.25849900E+03, 0.32152700E+03, 0.20053900E+03, 0.10558500E+04, -.53425300E+04, 0.26735700E+04, 0.39036500E+04, 0.26708300E+04, -.71500900E+03, -.11219100E+03, 0.22512600E+04, 0.17590400E+03, 0.18253200E+04, -.52696800E+02, 0.30085800E+04, 0.19359100E+04, -.95108200E+03, -.22612200E+04, -.96794400E+03, -.14132700E+04, -.11008800E+04, -.70708600E+03, -.10810500E+04, -.21028400E+04, -.10090700E+04, 0.41139200E+03, 0.28455200E+03, -.16538500E+03, 0.15780000E+04, -.14227000E+03, -.88579900E+03, 0.49463400E+02, -.48952800E+03, -.21844600E+03, -.41127800E+02, -.25301400E+03, 0.96784200E+03, -.30225700E+02, 0.97476500E+01, -.69693100E+03, 0.14910500E+02, 0.96743700E+03, 0.62458000E+03, 0.17054800E+03, 0.11106500E+04, 0.27662600E+03, 0.46868200E+03, -.72951500E+03, 0.21867400E+04, -.11202300E+04, -.23761600E+04, -.10933000E+04, -.45530600E+03, 0.95338600E+02, -.10392600E+04, 0.11916700E+03, -.29880400E+03, -.65794000E+02, -.14085000E+04, -.14007600E+04, 0.65309700E+03, 0.41359300E+02, 0.70000700E+03, 0.83255200E+03, 0.94830900E+03, 0.10401200E+04, -.42389000E+02, 0.70497200E+02, 0.12264500E+04, -.96742200E+03, -.18795700E+03, 0.39452900E+02, -.55184700E+02, -.43717200E+02, -.36723200E+02, 0.72245700E+02, -.24094900E+03, 0.20484900E+03, -.86751100E+02, 0.29497600E+02, -.12672300E+03, -.95404000E+02, -.13643600E+03, 0.86875100E+02, 0.14328600E+03, 0.47254600E+03, 0.56783300E+02, -.23242600E+03, -.77789000E+02, 0.64916800E+02, -.52747700E+02, -.40678400E+03, 0.33110500E+03, 0.11458900E+03, 0.10403200E+03, 0.24268800E+03 },
        { -.44950300E+01, -.17878500E+01, 0.18446700E+01, 0.32823400E+01, 0.23310900E+01, 0.15573800E+01, 0.23105100E+01, -.42914500E+01, -.77049700E-01, 0.68733500E+00, -.13597900E+01, -.36592600E+00, -.10337500E+01, -.43537800E+00, 0.18426000E+00, -.33635600E+01, -.76967300E+01, -.42391400E+01, 0.20885000E+01, 0.19710700E+01, 0.24873300E+01, -.17536300E+01, 0.35685000E+00, -.12704800E+01, -.13715100E+00, -.26654300E-01, 0.28929500E+00, -.14347600E+01, 0.36561300E+00, 0.67571700E-02, -.10426000E+01, -.86012500E+00, -.36754600E-02, -.36571600E+01, -.98308200E-01, 0.96913800E-01, 0.16538100E+00, 0.19222500E+01, 0.25679500E+00, 0.12647500E+01, 0.25648500E+01, -.89655400E+00, -.20274100E+00, -.34919100E+00, -.12046300E+00, -.72493400E+00, 0.89667200E-01, 0.85263400E-02, -.10246000E+01, -.13698700E+00, 0.18527700E+00, 0.21819800E+01, -.81242300E+00, 0.35675300E+01, 0.26769500E+00, 0.15453700E+00, 0.25554800E+00, -.36735100E-02, -.55092100E-01, -.27017900E+00, -.54693900E-01, -.48695000E+00, -.41495600E+00, 0.38401800E+00, 0.34429000E+00, 0.93520600E+00, -.46069800E+00, 0.84343400E-01, -.11688800E+01, -.19913800E-01, -.69008800E-01, -.37778000E+01, -.53824100E+00, -.95161000E+00, 0.74851500E+00, -.15569000E+01, -.82729900E-01, 0.89448400E+00, 0.70855100E+00, -.10856800E+00, -.73126500E-01, 0.17393400E+00, 0.32548700E+00, 0.25916500E+00, -.12158900E+00, -.83860100E+00, -.75622800E+00, -.30550000E+00, 0.18688000E+01, -.20742200E-01, 0.24948900E+00, 0.61905100E-02, 0.10551600E+01, -.35547800E-01, -.13907700E+01, -.11607800E+01, 0.12508400E+00, -.91350200E+00, -.26284800E+00, -.14354200E+01, 0.26463600E-01, -.48482600E+00, -.71125500E-01, 0.53008600E+00, 0.47441800E+03, -.50703100E+03, 0.41684200E+03, 0.20837800E+03, 0.25634600E+03, 0.16415400E+04, -.93552200E+03, 0.46820400E+03, 0.10436700E+04, 0.46647400E+03, 0.17395500E+03, 0.10273000E+03, 0.44478100E+03, -.13796900E+03, -.25117500E+03, 0.22732200E+03, -.24731900E+03, 0.57403600E+03, -.30627000E+03, -.51028400E+03, -.28844400E+03, -.29806300E+03, -.50398100E+03, 0.25402000E+03, 0.15588700E+04, 0.15402100E+04, -.65479900E+03, 0.36706300E+03, -.48174000E+03, 0.17948300E+03, -.26026000E+03, 0.24109600E+03, 0.95115600E+02, -.75183500E+02, 0.19289700E+03, -.29831900E+03, -.41445700E+02, 0.60467700E+02, -.49620600E+03, -.28790000E+04, 0.14303100E+04, 0.23617300E+04, 0.14382800E+04, -.69794200E+03, 0.48163200E+03, -.44732400E+03, -.83726500E+03, 0.10589900E+04, 0.52067400E+02, 0.57309300E+04, -.10626000E+03, 0.31301200E+02, -.29587700E+04, 0.53288200E+02, -.12381800E+04, -.45674700E+03, -.78787600E+03, 0.35041500E+03, 0.34703100E+03, -.83576800E+03, 0.62462000E+04, -.37136600E+03, 0.21983500E+03, -.19978300E+03, 0.18578900E+03, -.12276500E+03, -.33297800E+03, 0.13747700E+03, -.42722600E+03, -.70663500E+02, -.24527300E+03, -.19995000E+03, 0.12111200E+04, -.58712300E+03, -.33246400E+03, -.60343000E+03, 0.53111400E+03, 0.67583600E+03, -.73946000E+02, -.32531600E+03, -.17500600E+04, 0.62017600E+03, -.15997900E+04, 0.46581300E+03, -.22226500E+03, -.32777200E+03, -.22886900E+03, -.29513400E+03, -.54322300E+03, 0.18692700E+03, -.22671500E+03, -.22211600E+03, -.38907600E+03, -.39437800E+03, 0.94847000E+03, -.48182900E+03, 0.41378000E+03, -.47275800E+03, -.20341400E+03, -.23243200E+03, -.39444100E+02, 0.34296600E+02, -.57892600E+03, -.10662800E+02, -.38741500E+03, -.16919200E+04, 0.85204200E+03, 0.12402200E+04, 0.84184400E+03, -.64951200E+01, 0.26833700E+03, 0.55282000E+03, -.14329600E+03, 0.57480900E+03, 0.19586900E+03, 0.34753000E+03, 0.11392900E+04, -.55538700E+03, -.26531500E+04, -.56942900E+03, -.10556300E+04, -.75381700E+03, -.40693200E+03, 0.64702000E+03, -.43830000E+02, -.97128500E+03, 0.41537200E+04, -.29111800E+04, 0.14317600E+04, 0.15999100E+04, 0.14556500E+04, -.47928400E+03, 0.54302300E+03, -.66030100E+02, -.53208400E+03, 0.97650900E+03, 0.19960700E+03, 0.34189900E+04, -.35723000E+03, 0.17256700E+03, 0.39703700E+03, 0.17651600E+03, 0.59795900E+03, 0.69492100E+03, -.11424500E+03, -.42094100E+02, -.66173400E+03, 0.63681900E+03, -.18565200E+04, -.11766100E+04, 0.55162400E+03, 0.37451400E+03, 0.58897800E+03, -.34149900E+03, -.40592400E+03, 0.99526500E+02, 0.51015400E+02, 0.12217900E+04, -.46036900E+03, 0.10529900E+04, 0.67658700E+03, -.39419400E+03, -.38841900E+03, -.34156900E+03, -.12019900E+03, -.33861000E+02, 0.71515200E+03, -.13107800E+03, -.48292200E+03, 0.21154000E+03, -.22425500E+04, 0.63323100E+02, 0.35031800E+01, 0.55718700E+02, 0.66110900E+02, 0.20585700E+02, -.59468100E+00, -.35244100E+02, -.74363100E+02, -.28665000E+02, -.15476400E+02, -.95475900E+02, 0.10263500E+03, 0.10083900E+03, -.19017800E+02, -.34433300E+02, 0.78533200E+03, -.48071900E+02, 0.64466700E+02, 0.15475300E+02, -.11619900E+02, -.12587800E+03, -.75455200E+03, -.27445800E+02, 0.12013900E+03, 0.64150800E+02, 0.46264100E+02 },
        { 0.31133600E+00, -.10238700E-01, -.17530700E+00, -.10880000E+00, -.14638500E+00, -.24876800E-01, -.12231300E+00, 0.25728800E+00, 0.17935700E-01, 0.46894400E-01, 0.15521000E-01, -.15172100E-02, -.50171200E-01, 0.44859300E-02, 0.19814500E-01, -.87596400E+00, -.29289400E+00, -.19075100E+00, -.74092300E-01, -.74328800E-03, 0.89560600E-01, 0.31874100E-01, 0.13176500E-01, -.17846100E-01, 0.24070500E-01, 0.63784600E-02, 0.48653200E-01, 0.40623800E-01, -.96609800E-01, -.58279500E-02, 0.11925700E-01, 0.30097200E-01, 0.39318800E-01, -.25494300E+00, 0.90106200E-03, -.46540700E-03, -.29906800E-02, -.54277900E-01, 0.54643400E-02, -.37935800E-01, -.14327900E+00, 0.19082000E-01, 0.63848000E-02, 0.50880200E-03, -.21098500E-01, 0.33253500E-01, -.67135600E-02, -.91341600E-03, 0.14990000E-01, -.27221400E-02, 0.20625900E-01, -.54547100E-01, -.24772100E-01, -.21518200E-01, -.88715900E-02, -.78864500E-01, -.66232900E-01, -.17204300E-02, -.18568700E-02, -.45516000E-01, 0.31271000E-02, 0.68125900E-02, -.34569300E-01, -.79568400E-02, -.22421700E-01, 0.30540200E-02, -.43231100E-01, 0.12978900E-01, 0.14984100E+00, 0.89547100E-03, -.83211600E-02, 0.40595500E+00, 0.11929700E+00, 0.11693400E+00, -.86120600E-01, -.35238400E-01, 0.10180000E-01, -.83132300E-01, -.55798600E-01, 0.28331800E-02, -.45784300E-02, 0.51868000E-02, 0.91488900E-02, -.12465900E-01, -.17936300E-02, 0.16488500E-02, -.36343500E-01, -.67482500E-02, 0.12691600E-01, -.46916200E-02, -.72504700E-02, -.42470400E-04, 0.56374000E-01, -.53183800E-02, -.46018100E-01, 0.10037800E-01, 0.53973100E-02, 0.15536600E-01, 0.80877800E-02, -.17887900E-02, -.11502400E-01, 0.33902100E-01, 0.20637400E-02, 0.45715000E-01, 0.57049800E-02, 0.26521800E+02, -.15601800E+02, 0.19168900E+01, -.82710600E+01, -.37735400E+02, 0.56317300E+01, -.18608200E+01, -.15518300E+03, -.27630400E+01, -.10018900E+02, -.17962700E+02, 0.29668400E+02, 0.15663700E+02, 0.14660500E+02, -.12092700E+02, 0.77164800E+01, -.53936300E+02, 0.26378400E+02, 0.61351600E+02, 0.27019300E+02, -.89882400E+01, -.45925100E+02, 0.38800900E+02, -.19520300E+02, 0.16946700E+02, -.38883100E+02, -.92967900E+01, 0.16572300E+02, -.81387000E+01, 0.34151300E+02, -.82969700E+01, -.85457800E+01, 0.26820400E+01, -.29933800E+02, -.78866200E+00, 0.31830200E+01, -.81837600E+01, -.46610600E+01, 0.11862100E+03, -.61998500E+02, -.91878400E+02, -.59260100E+02, 0.89766400E+02, 0.34563400E+02, -.18891500E+00, 0.15370400E+02, -.80997100E+02, 0.68471700E+02, -.22466500E+03, -.77380100E+03, 0.38823000E+03, 0.51410900E+03, 0.38689400E+03, 0.26633800E+03, 0.18748000E+03, 0.99317000E+02, -.13230800E+03, 0.23046400E+03, 0.23162500E+03, 0.21052500E+02, 0.33498200E+02, -.17214400E+02, 0.16179300E+02, -.16775800E+02, -.18513500E+02, -.42228400E+02, 0.18409100E+02, 0.43324500E+02, 0.44272100E+02, -.47771900E+02, -.11275000E+02, 0.18093000E+03, -.90079400E+02, 0.17078000E+02, -.90346000E+02, 0.35334200E+02, 0.11710100E+03, -.12697300E+03, -.59435800E+02, -.83478300E+02, 0.10298300E+03, -.52789300E+02, 0.33471400E+02, -.17271500E+02, -.15053600E+02, -.16949700E+02, -.75579300E+01, -.19713300E+02, 0.19755900E+01, 0.36137500E+02, 0.45434600E+02, -.27964000E+02, 0.64775500E+01, 0.80981200E+02, -.38944400E+02, -.66400300E+02, -.40557800E+02, -.70607700E+01, -.63594400E+01, -.31081800E+01, 0.24684100E+02, 0.10291200E+02, -.16240500E+02, -.30702100E+02, -.95930700E+02, 0.47366800E+02, -.50167400E+02, 0.48136600E+02, 0.21507900E+02, 0.99506000E+01, -.58415300E+02, -.60131400E+02, 0.11201600E+02, 0.27309300E+02, 0.75431300E+02, -.60371800E+03, 0.30219600E+03, 0.38038900E+03, 0.30185100E+03, 0.19370800E+03, 0.15923200E+03, 0.59241600E+02, -.10775200E+03, 0.18954600E+03, 0.17892500E+03, 0.56654300E+02, -.79329900E+02, 0.41188700E+02, -.55879900E+02, 0.39662400E+02, 0.80537600E+02, 0.19682500E+02, 0.31200200E+02, -.19904700E+02, -.43881400E+01, 0.57358800E+02, -.89375700E+02, 0.27264900E+03, -.13709600E+03, -.85244200E+02, -.13624000E+03, -.77994400E+02, -.49039600E+02, -.25637500E+02, 0.45283300E+02, -.45273500E+02, -.68734900E+02, -.68674400E+02, -.42238700E+02, 0.21156400E+02, 0.49949600E+02, 0.21092500E+02, 0.19722100E+01, -.46058300E+02, 0.30017100E+02, 0.14298600E+02, 0.11713600E+02, -.25977600E+02, -.10943700E+02, 0.87964100E+02, -.43885500E+02, 0.35205800E+02, -.43839600E+02, -.46662400E+02, -.12939200E+02, -.10416900E+03, -.31961400E+02, -.18044900E+02, -.36663100E+02, -.87145700E+02, 0.81279600E+01, 0.53760000E+00, 0.11273300E+02, 0.98021900E+01, 0.46340300E+01, -.68776000E+01, 0.53858500E+01, -.34549300E+02, 0.38263400E+01, -.33878500E-01, -.41910000E+01, 0.69302200E+01, 0.13596700E+01, -.10510900E+02, -.28628800E+02, -.73178300E+02, -.83139000E+01, -.55072600E+01, 0.11085900E+02, -.65118400E+01, 0.12756900E+02, 0.67292500E+02, 0.99739100E+02, -.29279900E+01, -.93748800E+01, -.11247700E+02 },
        { 0.35711700E+01, -.31448900E+00, -.23969100E+01, -.13000600E+01, -.16601100E+01, -.18480000E+00, -.67917600E+00, 0.53637800E+01, 0.16863500E+00, 0.97547900E+00, 0.37381500E+00, -.15835800E+00, -.58821500E+00, 0.21423700E-01, 0.48801200E+00, -.16883000E+02, -.43474600E+01, -.17376100E+01, -.58041000E+00, 0.42609000E+00, 0.11416000E+01, 0.55006100E+00, 0.73073000E-01, 0.32695200E+00, 0.32655600E+00, 0.13269400E+00, 0.86794100E+00, 0.16988400E+01, -.27830900E+01, 0.15255400E-02, 0.12062600E+00, -.24964000E+00, 0.84440900E+00, -.23225400E+01, 0.31422200E-01, 0.13087200E-01, 0.24213600E-02, -.76128800E+00, 0.34514900E-01, -.61956500E+00, 0.34798000E+00, 0.45698200E+00, 0.32829200E-01, 0.26330200E+00, -.32014000E+00, -.10972400E+00, -.15619400E-01, 0.57077600E-02, -.39675000E+00, -.50745100E-01, 0.51530200E+00, 0.16851500E+01, -.59063500E+00, 0.77937800E+00, 0.31175700E+00, -.94131500E+00, -.43296800E+00, 0.10857800E+00, -.39203100E-01, -.93305300E+00, 0.11072300E+00, -.84256400E+00, -.41450300E+00, 0.38042200E+00, -.51408200E+00, 0.49291100E+00, 0.12134200E+01, 0.14108900E+00, 0.52341300E+00, -.73832200E-02, -.20808500E-01, 0.93059800E+00, -.78458200E+00, -.83280800E+00, 0.25780600E+00, -.99244900E+00, 0.17770700E+00, -.55339000E+00, -.21264400E+00, -.69049700E-01, -.12026200E-01, 0.10630700E+00, 0.18777000E+00, 0.45771100E+00, 0.27716900E-01, -.27960600E+00, -.28822900E+00, -.11413400E+00, -.13354100E+00, -.86538000E-01, 0.30666600E+00, -.20813200E-02, -.44256400E+00, -.83717600E-01, -.80319900E+00, -.13814300E+01, -.36211800E+00, -.48275200E-01, -.52231600E-01, -.39308400E+00, -.17203100E+00, -.15052700E-01, -.18219300E-01, 0.14564400E+00, -.92942600E-01, 0.23549600E+01, 0.44402500E+03, 0.26260100E+03, -.15981900E+02, 0.91853300E+02, -.81820900E+02, 0.44224900E+02, 0.24186600E+03, 0.40372600E+02, -.18266800E+03, -.23088800E+02, -.12755400E+03, -.40964000E+03, -.64499900E+02, 0.17718700E+02, -.64951200E+02, -.31152800E+03, 0.13875200E+03, 0.55105500E+03, 0.15524900E+03, 0.46659500E+03, 0.31311300E+03, -.15381900E+03, 0.56653600E+03, 0.17017500E+03, 0.31171400E+03, 0.13909700E+03, 0.32985200E+03, -.11466700E+03, -.28193700E+03, -.16480600E+03, -.27200500E+02, 0.16236200E+01, -.84617200E+02, 0.15221000E+02, -.29475500E+03, 0.30425400E+02, 0.17881600E+03, -.27302200E+04, 0.13358700E+04, 0.21195600E+04, 0.13645700E+04, 0.14017400E+03, 0.18185800E+03, 0.47479200E+03, -.16310000E+03, 0.91599200E+03, 0.12914300E+03, 0.98531400E+03, 0.67284400E+03, -.38537600E+03, -.13719700E+04, -.33635300E+03, -.12629100E+04, -.33263700E+03, -.27410200E+03, 0.18726600E+03, 0.14256500E+03, -.56897400E+03, 0.11008300E+04, -.54964200E+03, 0.26319900E+03, -.42034700E+03, 0.27490900E+03, 0.12329700E+01, -.44245600E+02, 0.27575600E+03, 0.55143000E+03, 0.64131200E+03, -.11223100E+03, 0.68323600E+02, 0.87567300E+03, -.42937700E+03, -.46120100E+03, -.43508400E+03, -.54658100E+03, -.19615900E+03, -.40894700E+02, -.14620900E+03, -.38554800E+03, -.24149900E+03, -.47323000E+03, -.70195400E+03, 0.34048300E+03, -.50054700E+02, 0.34902100E+03, 0.31016000E+02, -.83688400E+02, 0.32643900E+03, 0.65201200E+03, 0.81450100E+03, -.16697200E+03, 0.37215700E+02, -.57693400E+03, 0.26813500E+03, 0.29320700E+03, 0.28920700E+03, 0.15780800E+03, 0.26694900E+03, -.17627200E+03, 0.46106900E+02, 0.27397300E+03, 0.14099200E+03, 0.31597500E+03, 0.23845500E+02, -.86844300E+01, 0.93878900E+03, -.13735200E+02, -.40990200E+03, 0.23128800E+03, -.46158900E+02, -.41106800E+03, 0.10273400E+03, 0.13727700E+03, 0.62917500E+03, 0.12924200E+04, -.68439800E+03, -.12611400E+04, -.64611600E+03, -.10993900E+04, -.60167900E+03, -.10452400E+03, 0.17698000E+03, -.30691000E+03, -.65889900E+03, 0.15745200E+03, -.10618500E+04, 0.51919300E+03, 0.10699400E+04, 0.53095100E+03, -.40498100E+02, 0.24348100E+03, -.41828000E+02, -.18347700E+03, 0.49561000E+03, 0.89951100E+02, 0.92549100E+03, -.39728400E+03, 0.23351500E+03, -.32090700E+03, 0.19772000E+03, 0.35485100E+03, 0.20865100E+03, -.24427000E+02, 0.28105400E+03, -.62359200E+02, 0.22816800E+03, -.16528700E+03, -.35789300E+03, 0.17470100E+03, 0.50226400E+03, 0.17921900E+03, 0.28370100E+03, 0.68662100E+02, -.75615500E+02, 0.17524000E+01, 0.26548700E+03, 0.47312600E+02, 0.18716600E+03, -.40543200E+03, 0.23275200E+03, -.15215300E+03, 0.20113300E+03, 0.24935800E+02, -.18354200E+03, 0.12250000E+03, 0.70890800E+02, 0.49682500E+03, -.18429000E+03, 0.82236800E+03, -.66632700E+02, -.22550500E+02, 0.30327900E+02, 0.19716900E+02, -.41765600E+01, -.12356300E+02, 0.73783100E+02, -.36501400E+02, 0.22503000E+02, -.33662600E+02, -.38765300E+02, -.67860800E+02, 0.12558400E+02, 0.25325400E+02, 0.25012800E+02, 0.50215000E+03, -.35357900E+02, 0.42482800E+02, 0.26667400E+02, -.39815100E+01, -.96033200E+02, -.52642300E+03, 0.96457100E+01, 0.81811600E+02, 0.26128300E+01, 0.32530000E+02 },
        { -.39772000E+01, -.37836900E+00, 0.17430000E+00, 0.64647600E+00, 0.40961700E+00, 0.28763500E+00, 0.69788600E+00, -.13721500E+01, -.31311600E-01, 0.20211500E+00, -.20494900E-01, 0.30504300E+00, 0.37895300E-01, -.15138100E+00, -.25059200E+00, 0.49932300E+01, -.72337100E+00, -.96216400E+00, 0.27771400E+01, 0.44512100E+00, -.13138200E+01, -.36336700E+00, -.19338800E+00, -.97353100E+00, -.31274000E+00, 0.21758700E-01, -.42952700E+00, -.77139600E+00, 0.30905700E+00, 0.46071200E-01, -.40350300E+00, -.18935100E+00, 0.74404300E-01, 0.13207200E+01, -.95751200E-02, -.10371600E+00, -.12832300E-01, -.52205100E+00, -.10833700E-01, -.27752700E-01, 0.15628700E+01, -.39168500E+00, -.18042000E-01, -.10030200E+00, 0.22099400E+00, 0.12745400E+00, -.34184000E-01, 0.10145100E-01, -.44808300E+00, 0.12824300E+00, -.11887300E+00, 0.39597300E-01, 0.61142900E-01, -.11832900E+01, -.70804900E-01, -.95785100E+00, 0.11563000E+00, -.21919300E+00, -.32567200E-01, 0.59466800E+00, -.24160500E+00, 0.58948200E+00, -.73368700E-01, -.36608700E+00, -.55576100E+00, -.59523900E+00, 0.29531400E+00, 0.36610200E+00, 0.92067500E+00, 0.65509700E-02, -.95506900E-01, 0.50929400E+01, 0.12760100E+01, -.19519400E+01, -.13276300E+01, 0.44002000E+00, 0.25512100E-01, -.61656800E+00, -.51898800E+00, 0.37455500E-01, -.11217900E+00, 0.36389900E-01, 0.14051400E+00, -.81280100E+00, -.29119100E+00, 0.38562800E+00, -.59615200E+00, 0.17735800E-01, -.31404800E+00, -.54716600E-02, -.12395800E+01, -.47926100E-03, -.64020400E-01, 0.20552500E+00, 0.81280400E+00, 0.74929500E+00, 0.68168900E-01, -.31951300E+00, 0.18020900E+00, 0.55073200E+00, -.10016800E+00, -.34145600E+00, -.27910100E-01, -.42587700E+00, 0.46392200E+00, 0.40943900E+01, -.45409800E+00, -.50875300E+03, 0.26698400E+03, -.93483600E+03, -.89576900E+03, 0.44471300E+03, 0.18583300E+04, 0.44746900E+03, 0.45648500E+03, 0.34239200E+03, 0.12330700E+03, 0.25652000E+03, 0.49392700E+03, 0.13412000E+03, 0.39211000E+03, -.52838500E+03, 0.25509900E+03, 0.60295500E+03, 0.26397500E+03, 0.29834000E+03, 0.72146300E+03, -.77200400E+03, -.11609400E+04, -.80322200E+03, 0.89964500E+03, 0.61405700E+03, -.31813600E+01, 0.12505400E+03, -.55986900E+03, 0.17212000E+01, 0.12149200E+03, 0.11791200E+03, 0.10107900E+03, 0.80775800E+02, -.14242200E+03, 0.15673100E+03, 0.53606800E+03, -.29964000E+04, 0.14892300E+04, 0.24153300E+04, 0.14977600E+04, -.20713400E+03, 0.22679800E+03, 0.18253200E+03, -.85495000E+03, 0.10540400E+04, -.17909800E+02, 0.33832900E+03, 0.67399000E+04, -.34447500E+04, -.38521700E+04, -.33699000E+04, -.24920000E+04, -.18140500E+04, -.14551500E+04, -.88955000E+03, -.30355400E+04, -.18190100E+04, -.26436800E+04, 0.23205400E+03, -.15704400E+03, -.12640400E+03, -.11564300E+03, 0.26031900E+02, 0.20835500E+03, -.98096600E+01, 0.11772300E+03, 0.29821700E+02, 0.14783900E+03, -.77908100E+02, 0.20155000E+04, -.10104900E+04, -.99237400E+03, -.10063200E+04, 0.23676300E+03, 0.18848800E+03, 0.53115100E+03, 0.17342300E+04, 0.32507600E+03, -.32035400E+03, -.11343200E+04, -.27112900E+03, 0.11211400E+03, 0.38218800E+03, 0.13343900E+03, 0.13640300E+03, 0.32714600E+03, -.22824100E+02, 0.90080200E+02, 0.23397200E+03, 0.25563400E+03, -.73638600E+01, -.93736700E+03, 0.43481000E+03, 0.73488600E+03, 0.46943400E+03, 0.23981900E+03, 0.42030000E+03, -.40160000E+03, -.41290200E+03, 0.55663500E+03, 0.29902400E+03, 0.54745600E+03, -.45517000E+04, 0.22790800E+04, 0.33434000E+04, 0.22743400E+04, -.23089600E+03, 0.12255800E+03, 0.19670200E+04, 0.50049100E+03, 0.18944600E+04, -.11207100E+03, 0.25601500E+04, 0.49399000E+04, -.25440000E+04, -.23795200E+04, -.24698900E+04, -.17207300E+04, -.15362600E+04, -.80913700E+03, -.66511100E+03, -.26791900E+04, -.14337800E+04, -.27610400E+04, -.14272000E+04, 0.69226300E+03, 0.21407600E+04, 0.71362200E+03, -.42209000E+03, 0.23209600E+03, -.24098700E+03, -.52269300E+03, 0.81774000E+03, -.10151100E+03, 0.95312500E+03, -.17908500E+04, 0.97032800E+03, -.56678700E+03, 0.89469300E+03, 0.60244600E+03, 0.44468400E+03, 0.13003400E+03, 0.28488100E+02, 0.27636300E+03, 0.51863300E+03, 0.71906600E+03, 0.12929400E+04, -.62971900E+03, -.51875400E+03, -.64627500E+03, -.74328100E+03, -.48132700E+03, -.96640100E+03, -.10109700E+04, -.65215700E+03, -.25801100E+03, -.76210700E+03, -.66646100E+03, 0.42252200E+03, -.17058100E+03, 0.33170800E+03, 0.22589600E+03, 0.19851100E+03, 0.72062100E+03, 0.48894700E+03, 0.68172200E+03, 0.22547900E+03, 0.69993800E+03, -.11040100E+03, -.27140900E+02, 0.16718400E+02, 0.26848000E+01, -.21800800E+02, 0.80153100E+01, 0.22259300E+02, 0.44337800E+02, -.91696700E+01, -.30190700E+02, 0.43311200E+01, -.32507100E+01, -.36243400E+02, 0.86389200E+02, 0.10604400E+03, 0.52471500E+03, -.83023300E+01, -.44618200E+03, 0.20422800E+02, 0.49123500E+02, -.26511700E+03, -.38378600E+03, -.68642900E+02, 0.28696100E+02, -.10112000E+03, 0.14750100E+03 },
        { -.67184000E+01, -.23167000E+01, -.57991200E+01, -.38094200E+01, 0.21507100E+01, 0.20187900E+01, 0.90705000E+00, 0.25306700E+01, -.39029300E+00, -.13504900E+01, 0.17072900E+01, 0.10754700E+01, 0.14746700E+01, -.93401900E+00, -.86472400E+00, 0.10228900E+02, 0.62288800E-01, 0.33287600E+00, 0.20580200E+01, -.43215300E+00, -.99856500E+00, 0.41986700E+00, -.17339200E+00, 0.53135100E+00, -.46203500E+00, 0.40171000E-02, 0.77246600E+00, 0.17707300E+01, -.17195100E+01, -.23965900E-01, -.57104600E+00, 0.22404400E+01, 0.44626200E+00, -.23312300E+01, 0.50889700E-01, -.29418400E+00, -.95950000E-01, -.10361100E+01, -.35898500E-01, -.11989600E+01, 0.21560700E+01, -.59361300E+00, 0.23309000E+00, -.15783900E+00, -.23626600E+00, 0.48460800E-01, 0.14639200E+00, -.81415300E-01, -.47407900E+01, 0.18907600E+00, -.96536200E+00, 0.39010000E+00, -.27524500E+00, 0.43612500E+01, -.24450400E+00, 0.22544600E+01, 0.50446600E+00, -.31905200E+00, -.11504100E+00, -.87304700E+00, 0.64276300E+00, -.11243400E+01, 0.60354300E+00, -.12252400E+01, -.38477100E+00, 0.15744600E+01, 0.28621500E+01, -.26192000E-01, 0.44810000E+00, -.14614400E-01, -.13612900E+00, -.27976900E+01, 0.19557100E+01, 0.41559000E+01, -.90600700E+00, -.27524600E+01, 0.54545700E+00, 0.80297700E+00, -.35837700E+00, 0.10436900E+00, -.48067200E-01, 0.31219900E-01, 0.56428300E+00, 0.12632100E+01, 0.61966600E+00, 0.61351600E-01, -.77097200E+00, 0.70115300E+00, -.10603700E+01, 0.17455600E+00, -.30068400E+00, -.12291700E-01, -.19161200E+01, -.37455500E+00, 0.20443000E+00, -.27330600E+01, -.24202600E+00, 0.39607900E+00, -.38417400E+00, -.54025800E+00, 0.45565600E-01, -.36385300E+00, -.60572500E-01, -.59714900E-01, 0.62083000E+00, 0.16531800E+02, -.13381100E+01, 0.30763900E-01, 0.39067100E+03, 0.72742200E+03, 0.18601600E+03, -.93204700E+02, -.40520400E+03, -.94864200E+02, 0.85153300E+02, 0.14086200E+03, -.98038500E+03, -.64724700E+03, 0.31558700E+03, 0.33028900E+02, -.16355600E+04, -.95685700E+03, 0.46299800E+03, 0.23531100E+04, 0.47703300E+03, 0.13717200E+04, 0.19608200E+04, -.95579000E+03, -.73148600E+03, -.10817400E+04, 0.18791900E+04, -.50508000E+03, 0.18674400E+04, -.68668300E+03, -.56434600E+03, -.93322500E+03, -.23118000E+03, 0.32536900E+03, -.44708600E+03, 0.41063600E+02, -.11759100E+04, 0.18831200E+03, 0.85618200E+03, -.43931200E+04, 0.21424800E+04, 0.37716600E+04, 0.21946800E+04, -.46812700E+02, -.61849900E+03, 0.18465100E+04, 0.47044300E+03, 0.14966000E+04, -.63567900E+03, 0.69111500E+03, 0.93567400E+04, -.47595300E+04, -.30191100E+04, -.46781600E+04, -.22752800E+04, -.69342200E+03, -.11989200E+04, 0.78722700E+03, -.31885000E+04, -.13767600E+04, -.28458100E+04, 0.34089500E+04, -.18319700E+04, -.21826300E+04, -.17032600E+04, -.35687100E+03, 0.66677900E+02, -.56600400E+03, 0.18839500E+04, 0.18806800E+03, -.20992800E+02, -.53336900E+03, 0.13621400E+04, -.69473200E+03, -.92549600E+03, -.67542700E+03, -.17834100E+04, -.19208600E+04, 0.66338200E+02, 0.84262800E+03, 0.77008600E+03, -.19387100E+04, 0.77043400E+03, 0.17026000E+04, -.91892200E+03, -.10172600E+04, -.85593200E+03, -.26116600E+02, 0.31552300E+03, -.63618100E+03, 0.12986900E+04, 0.37981200E+03, 0.16149800E+03, 0.19015100E+03, -.30806600E+04, 0.14553100E+04, 0.83453300E+03, 0.15432400E+04, 0.43566800E+03, 0.56361200E+03, -.60822000E+03, -.11000800E+04, 0.65758900E+03, 0.60340700E+03, 0.92783700E+03, 0.75483100E+04, -.37672300E+04, -.25303700E+03, -.37805900E+04, -.56827800E+03, -.83880300E+01, -.11888200E+04, 0.80828300E+03, -.16776400E+04, -.42180900E+03, -.33319300E+04, 0.39576900E+04, -.20861300E+04, -.19633200E+04, -.19785600E+04, -.17118000E+04, -.37328200E+03, -.70434700E+03, -.35336200E+03, -.22557600E+04, -.82670500E+03, -.11475500E+04, 0.24240700E+04, -.12147100E+04, 0.43283100E+03, -.12119400E+04, 0.22391200E+03, -.32412900E+03, -.34995700E+03, 0.41175400E+03, -.50904400E+03, -.65469600E+03, -.86253100E+03, -.30992700E+04, 0.16421200E+04, -.15881500E+04, 0.15464600E+04, 0.12723700E+03, 0.62709600E+02, 0.11374900E+03, -.33304900E+03, 0.72716700E+03, 0.48223800E+03, 0.34421900E+04, -.13681700E+04, 0.73938000E+03, 0.22951300E+04, 0.68498600E+03, 0.10136100E+04, 0.61411200E+03, 0.72793000E+03, -.65091500E+03, -.63989200E+03, 0.64088200E+03, 0.73516400E+03, -.16079900E+04, 0.99056000E+03, -.48105800E+03, 0.79800300E+03, -.57289100E+03, -.16379800E+04, 0.97711100E+03, 0.17747600E+04, 0.16015600E+04, -.16977200E+04, 0.84819700E+04, -.13473400E+03, -.17288700E+03, -.80617000E+01, -.32953000E+02, -.27052900E+02, 0.20098500E+02, 0.47506600E+03, 0.45801000E+03, 0.14927700E+03, -.13950100E+03, -.26302500E+02, -.27991200E+03, 0.11303100E+03, 0.15408500E+03, 0.48004000E+03, 0.15561800E+03, 0.13319500E+02, 0.30557100E+03, 0.47149100E+02, 0.62895300E+02, -.28563800E+03, -.37570800E+03, -.34144300E+03, 0.14040800E+03, -.41222900E+02, -.20823300E+02 },
        { 0.25276600E+01, 0.49461500E+00, -.47030200E+00, -.84762800E+00, -.18799600E+01, -.54063300E+00, -.89329900E+00, -.61269000E+00, 0.46723000E-01, 0.80663200E+00, -.53809900E+00, -.31980700E+00, -.46331700E+00, -.66376400E-01, 0.14861200E+00, -.81647300E+01, -.13249300E+01, -.10531700E+01, -.17388000E+01, -.24421100E+00, 0.17380200E+01, 0.90745900E-01, -.34895100E-01, -.90572300E+00, 0.76533400E-01, 0.78009000E-01, 0.13790500E+00, -.77023600E+00, -.24899900E+00, 0.56522300E-02, 0.19648600E+00, -.48708400E+00, 0.28974000E+00, -.61695600E+00, 0.61369400E-02, -.26693000E-01, -.33318200E-01, 0.17154200E+00, 0.12521000E+00, -.16221400E+00, 0.21094300E+00, 0.39001100E+00, -.42306300E-02, -.24649800E-01, -.25771200E+00, 0.10032100E+00, -.41176700E-01, -.56144200E-01, -.62532500E+00, 0.20678400E-02, -.35504500E+00, -.51004100E+00, -.40414900E+00, -.14938000E+00, -.22106000E-01, -.33412500E+00, -.39606100E+00, 0.16577900E-01, -.55962800E-01, -.32787000E+00, 0.16766900E+00, -.75842700E+00, -.22265600E+00, 0.19835600E+00, 0.11957600E-01, 0.21395100E+00, 0.19736800E+00, -.74716100E-02, 0.13490200E+00, 0.72966200E-02, 0.18763700E-01, -.82141500E-01, -.56620100E+00, -.52459500E-01, 0.24621600E+00, -.67919700E+00, 0.44408300E-01, -.12950300E+00, -.11320000E-02, -.75163500E-01, -.16806600E-01, 0.37975900E-01, 0.18264200E-01, -.79816100E-01, -.23966400E-01, -.77472800E-02, -.24684200E+00, -.15235600E+00, -.26515900E+00, -.41075200E-01, 0.83934900E-01, -.14152500E-02, 0.99939400E-01, 0.50638800E-02, -.51622900E+00, -.43533800E+00, 0.31975700E-01, -.14970700E+00, -.89832500E-01, -.30842200E+00, -.34416500E-01, -.66443500E-01, -.52007900E-01, 0.38038400E+00, 0.40618700E-01, -.44305100E+01, 0.10638200E+00, -.46710500E+00, 0.59048400E-01, -.61901500E+03, 0.34465600E+03, -.16865500E+03, -.83247000E+03, -.17299300E+03, 0.72391300E+02, -.72941300E+02, 0.22220000E+03, 0.33448300E+03, 0.93543900E+02, -.88907300E+02, 0.36718900E+02, -.68538700E+03, 0.33360200E+03, 0.56704700E+03, 0.34193100E+03, 0.57374600E+02, -.13147000E+03, -.93827800E+02, -.57200500E+03, -.22587600E+03, -.53928200E+02, -.85082400E+02, 0.18631600E+03, -.56283600E+02, 0.16215800E+02, -.93042500E+02, -.76530600E+02, -.49997100E+02, -.10418800E+03, -.54728800E+01, 0.10456100E+03, -.99647800E+02, 0.96233200E+02, -.11616100E+04, 0.57271900E+03, 0.10469900E+04, 0.58015800E+03, 0.33557800E+03, 0.30892700E+03, 0.28877400E+03, 0.18418100E+03, 0.50578600E+03, 0.40687200E+03, -.61806800E+03, -.27889700E+04, 0.13634900E+04, 0.25303600E+04, 0.13945800E+04, 0.55270600E+03, 0.28002300E+03, 0.21074100E+03, -.84821300E+03, 0.87188500E+03, 0.44927000E+03, -.76095800E+03, -.74087400E+03, 0.35955500E+03, 0.38732100E+03, 0.37025300E+03, 0.72699900E+02, 0.64310300E+01, 0.18157200E+03, 0.91445900E+02, 0.30352800E+03, -.49363800E+02, 0.31820600E+03, 0.13982900E+04, -.69543900E+03, 0.66405800E+02, -.69654900E+03, 0.43925500E+03, 0.10033800E+04, -.48070400E+03, 0.31617700E+03, -.24263100E+03, 0.76304200E+03, -.28261300E+03, -.88604200E+03, 0.43500200E+03, 0.40957200E+03, 0.44385400E+03, 0.13863300E+03, 0.13699300E+03, 0.92482100E+02, 0.23766700E+02, 0.34405000E+03, 0.51677100E+02, 0.24770100E+03, 0.21487900E+03, -.11107800E+03, -.17592800E+02, -.10667300E+03, 0.79902600E+02, 0.11856500E+03, -.49526100E+02, 0.98097100E+02, 0.13285100E+02, -.24842000E+02, -.35941000E+03, -.22512000E+04, 0.11276600E+04, 0.10406300E+04, 0.11234300E+04, 0.23299400E+03, 0.34115400E+03, -.40547200E+02, -.62095900E+03, 0.71113200E+03, 0.28890100E+03, 0.16003700E+04, -.12115200E+04, 0.57595700E+03, 0.14590400E+04, 0.60589000E+03, 0.31524100E+03, 0.13532300E+03, 0.88625100E+02, -.46992100E+03, 0.39163400E+03, 0.25315400E+03, -.81926100E+03, -.16045300E+04, 0.80100300E+03, 0.82140800E+03, 0.80229800E+03, 0.23750100E+03, 0.25914800E+03, 0.18580400E+03, -.35906500E+03, 0.53622600E+03, 0.34663400E+03, 0.16227800E+03, 0.83578000E+03, -.39224100E+03, -.86009700E+03, -.41901800E+03, -.14211600E+03, -.42490200E+01, -.12236800E+03, 0.22977500E+02, -.29175400E+03, -.62305900E+02, -.15256100E+03, 0.35826900E+03, -.17823800E+03, 0.11447900E+03, -.17878500E+03, -.38974400E+03, -.53033400E+03, -.22114300E+03, -.27086800E+03, -.26590400E+03, -.34747600E+03, -.52332500E+03, 0.58586400E+03, -.26942500E+03, 0.29277300E+03, -.29468400E+03, -.16931900E+03, 0.62453800E+02, -.52788800E+03, -.11299100E+03, 0.13345700E+03, -.15284800E+03, -.96156900E+02, 0.49744200E+02, -.93672800E+01, 0.73609200E+02, 0.68310600E+02, 0.51352300E+01, -.27063100E+02, 0.14968400E+02, -.23583200E+03, 0.85819100E+01, -.75512100E+01, 0.30291100E+01, 0.77382900E+02, -.45680900E+02, -.19179300E+02, -.14946400E+03, -.29553900E+02, -.79440000E+02, -.28414200E+03, 0.81649500E+02, -.92741300E+01, -.28280600E+02, 0.74238300E+02, 0.31126700E+03, 0.41797000E+00, -.10604000E+03, -.42964500E+02 },
        { 0.30815600E+01, 0.91822400E+00, 0.38618600E+01, 0.33958300E+01, -.69127700E+00, -.81048900E+00, -.65953600E+00, -.10734200E+01, -.85638500E-01, 0.68699900E+00, -.50646000E+00, -.20420800E+00, 0.35678600E-01, 0.79174600E-01, 0.76962500E-01, -.82729900E+01, 0.12111000E+01, -.54067200E-01, -.12792100E+01, -.34450300E+00, 0.12805100E+01, -.29006800E+00, 0.90650300E-01, 0.39387300E+00, 0.36291300E+00, 0.62771900E-01, 0.32680800E+00, -.29576500E+00, -.20619000E+01, 0.86584500E-01, 0.10685800E+00, -.99838300E+00, 0.47269500E-01, 0.23831000E+01, -.12925200E-01, 0.15836200E+00, 0.84465400E-01, 0.85829700E+00, 0.75881400E-01, 0.34254200E+00, 0.20693500E+01, 0.46982600E+00, -.12219800E+00, 0.16505000E-01, 0.84411200E-01, 0.17122500E+00, 0.38637400E-01, 0.35954800E-01, 0.59279900E+00, -.63470800E-01, 0.42266700E+00, 0.17657800E+01, -.76536400E+00, 0.19585800E+01, 0.37732500E+00, -.21859500E+00, 0.68786200E+00, 0.11146800E+00, -.14839600E-01, 0.49024100E+00, -.19080500E+00, -.50999700E+00, 0.23146000E+00, 0.77211900E+00, 0.45406400E+00, -.17549900E-01, -.97197500E+00, -.86723500E-01, -.34816000E+00, -.11553700E-01, -.74188900E-01, -.91614000E+00, 0.61965400E+00, 0.69443100E+00, -.23265700E+00, 0.63474500E+00, -.14259900E+00, 0.27011600E+00, 0.26822900E+00, -.49891500E-01, 0.37459900E-01, -.13467100E+00, -.30828200E+00, 0.35829600E+00, 0.36454700E-01, -.58395700E-02, 0.29272400E+00, 0.19226800E-01, 0.15703200E+00, 0.10490600E+00, 0.11497600E+00, 0.17446200E-02, 0.59107300E+00, 0.14281400E-01, 0.82881000E+00, 0.99274400E+00, 0.48749300E+00, -.78664400E-01, -.28773400E-01, 0.29784300E+00, 0.57759700E-01, -.71631500E-01, 0.64271200E-02, 0.18796900E+00, 0.89204900E-02, -.44347000E+01, -.39508800E+00, -.11563900E-02, -.88969500E-01, -.19468100E+00, 0.14028800E+04, -.70108500E+03, -.43394800E+03, -.70157300E+03, -.30498900E+03, -.31793900E+03, -.31723300E+02, 0.43086700E+02, -.37777800E+03, -.27470700E+03, -.70675600E+03, -.48544100E+03, 0.23952600E+03, 0.30487800E+03, 0.24251500E+03, 0.24469900E+02, -.15541600E+03, 0.13936700E+03, 0.42972900E+02, -.31273600E+02, -.20296800E+03, -.12382400E+03, 0.87693400E+02, -.29154400E+02, -.33981600E+03, -.43833200E+02, -.13821400E+03, -.19995400E+03, 0.95293000E+02, 0.24766000E+03, 0.19823100E+03, -.23876300E+03, -.23808100E+02, -.17301700E+03, 0.56161700E+02, -.30393600E+03, 0.86375300E+02, 0.41057300E+03, -.54670700E+02, 0.62820500E+03, 0.67919500E+03, -.22706700E+03, 0.18615400E+03, -.52092200E+03, -.36343300E+04, 0.18098000E+04, 0.75238400E+03, 0.18171900E+04, 0.76591200E+03, 0.10066700E+04, 0.19352100E+03, -.27276700E+03, 0.14690900E+04, 0.86680400E+03, 0.70279100E+03, 0.61690600E+03, -.29939400E+03, -.54005900E+03, -.30867100E+03, -.30435900E+02, 0.34174800E+02, -.25721400E+03, 0.13360400E+03, -.22496700E+03, 0.28343500E+01, -.12817600E+03, -.48348100E+02, 0.23645300E+02, 0.31434800E+03, 0.24896700E+02, -.72275200E+02, 0.90973700E+02, -.16600000E+03, -.35806900E+03, 0.15477400E+02, 0.27887800E+03, 0.27712600E+03, 0.10699400E+04, -.52786700E+03, -.56051400E+03, -.53436400E+03, -.87151600E+02, 0.20547700E+01, -.36994700E+03, 0.44450600E+02, -.38876200E+03, -.26871400E+02, -.28316500E+03, 0.14122600E+04, -.70141500E+03, -.53700000E+03, -.70601900E+03, -.29027000E+01, 0.12684100E+03, -.40065000E+03, -.16397300E+03, -.52116600E+03, 0.68690200E+02, -.65876100E+03, 0.79186600E+03, -.40460400E+03, -.16491100E+04, -.39636000E+03, 0.34078200E+03, 0.33015700E+03, -.97510200E+03, -.45554300E+03, -.24871000E+03, 0.23554900E+03, -.25394800E+03, -.22924300E+04, 0.11323200E+04, 0.15067100E+04, 0.11462500E+04, 0.36079000E+03, 0.62341100E+03, 0.10818700E+03, -.31792900E+03, 0.94073100E+03, 0.55343200E+03, 0.43123700E+03, 0.50742800E+03, -.24635900E+03, -.40544400E+03, -.25370700E+03, 0.33021400E+03, -.36937900E+02, 0.39596400E+02, 0.84258800E+02, -.39026400E+03, 0.10512400E+03, -.73765100E+03, 0.54487100E+03, -.26393100E+03, 0.60629000E+03, -.27267600E+03, -.29251800E+03, -.23930900E+03, -.13590800E+03, -.24474500E+03, -.18298600E+03, -.14764500E+03, 0.11583800E+03, -.73275800E+03, 0.37604600E+03, 0.19470000E+03, 0.36645400E+03, 0.19509000E+03, 0.11118000E+03, 0.10992900E+03, 0.24061100E+03, 0.13795400E+03, 0.11467400E+02, 0.20667100E+03, 0.12573000E+03, -.49243200E+02, -.22889700E+03, -.63173800E+02, 0.37686500E+03, 0.45620000E+02, -.70507100E+03, 0.54327000E+02, 0.25151400E+03, -.90946000E+02, 0.49174800E+02, 0.28476200E+01, 0.12543700E+02, -.58168100E+01, -.51660400E+01, -.16757200E+02, -.39421700E+02, -.82160300E+01, -.15208100E+03, 0.21591500E+01, 0.11134300E+01, -.32762400E+00, 0.38272200E+02, -.52844300E+02, 0.31666700E+02, -.12244800E+03, -.15759400E+03, -.40698000E+01, 0.16700800E+02, -.46978800E+01, -.19973100E+02, 0.14659000E+02, 0.36639900E+02, 0.38459600E+03, -.60349700E+02, -.28893700E+02, -.80758900E+02 },
        { 0.91143000E+01, -.40394700E+01, -.18817600E+01, 0.11704500E+01, -.20252100E+00, 0.24083500E+01, 0.63863400E+00, 0.75831500E+01, 0.23386500E+01, 0.38766800E+00, 0.23464200E+00, -.58957600E+00, -.31201500E+01, 0.41671500E+00, 0.74502900E+00, 0.10575100E+01, -.12616600E+02, -.13890900E+01, -.23261200E+01, 0.40618800E-01, 0.47262400E+00, 0.14909800E+01, 0.68270500E+00, -.19588400E+01, 0.11060300E+01, -.21314600E+00, -.12521200E+01, -.27624800E+01, 0.49216400E+01, -.99831600E-01, -.10310100E+01, 0.16709100E+01, 0.19198400E+01, 0.12570100E+01, -.39981200E+00, -.12526000E+00, 0.14407100E-01, -.48712700E+01, -.96473800E+00, -.66132700E+00, -.42425200E+01, 0.21171800E+00, 0.30868500E+00, 0.88293700E-01, 0.95246600E+00, -.80471200E+00, 0.18673400E+00, 0.20461400E+00, 0.10715200E+01, -.70905000E-01, 0.48549000E+00, 0.34079900E+01, -.12078300E+01, 0.61053000E+01, 0.39295200E+00, 0.23630300E+01, 0.13295100E+01, 0.16775200E+00, 0.18656300E+00, 0.13465700E+01, -.21276200E+00, -.22504300E+00, 0.91117700E+00, 0.70955700E-01, 0.20043400E+01, 0.83051300E+00, 0.10856700E+01, 0.69831900E-01, 0.21251700E+01, -.33710100E-01, -.66395000E-01, 0.75347900E+01, 0.18699400E+01, -.10888400E+01, -.15619300E+01, 0.24057600E+01, 0.15800800E-01, -.32575500E+01, 0.11266700E+01, 0.57286900E+00, 0.32305700E+00, -.48879800E+00, -.56947000E+00, 0.10607100E-01, 0.21557700E+00, -.36745100E-01, 0.10128500E+00, 0.21290300E+00, 0.85160200E+00, 0.46588700E-01, 0.16878200E-01, 0.18401100E-01, -.32045400E+00, -.14733000E+00, -.52130200E+00, -.53563800E+00, -.49645000E+00, -.95491300E+00, -.20015800E+00, -.82688100E+00, 0.18263700E+00, -.33098900E+00, 0.78923100E-01, -.16076600E+00, 0.23613200E+00, 0.14169500E+01, -.14404000E+00, 0.52154100E+00, 0.67493600E-01, 0.36782400E+00, -.12937500E+01, 0.91490900E+02, -.44944700E+03, 0.20101200E+01, -.41694200E+03, -.26908700E+03, -.18965300E+02, -.47742900E+03, -.19410300E+03, -.18187700E+03, 0.16477900E+03, -.15710000E+02, 0.19909700E+01, 0.37276400E+02, 0.10049000E+02, 0.12091400E+03, -.22176500E+03, 0.37238900E+03, 0.44878800E+03, -.44047100E+02, -.23342400E+03, -.58680700E+03, -.43229800E+03, 0.29122600E+02, -.23754000E+02, 0.21577800E+03, -.21374300E+03, -.23764200E+03, 0.12514700E+03, 0.21726000E+03, 0.29321800E+03, -.27416800E+03, 0.72527000E+02, 0.24193200E+04, -.12292300E+04, -.24319600E+04, -.12077100E+04, 0.33499600E+03, -.41515600E+03, 0.22337300E+03, 0.73745400E+03, -.15891000E+04, -.66112300E+02, -.16952100E+04, -.27692900E+04, 0.14643800E+04, -.51886000E+02, 0.13843900E+04, 0.14104100E+04, 0.13923800E+04, 0.37328800E+03, 0.71800000E+03, 0.11527400E+04, 0.13213900E+04, 0.70015600E+02, 0.18878700E+04, -.82950500E+03, -.12483700E+04, -.94390900E+03, -.17517600E+03, -.63819500E+02, -.41548500E+03, 0.24681400E+03, -.41820200E+03, -.89198200E+02, -.50920300E+03, -.13610600E+04, 0.70338900E+03, 0.62108500E+03, 0.67666700E+03, -.78215600E+03, -.47831100E+03, -.18480900E+03, -.10636700E+04, 0.30803800E+03, -.21120700E+03, 0.15449200E+04, 0.21048000E+04, -.98204300E+03, -.11265300E+04, -.10559300E+04, -.20449600E+03, -.13643000E+03, -.40093300E+03, 0.17624100E+03, -.67237700E+03, -.15051100E+03, -.65715200E+03, 0.54942700E+03, -.18241600E+03, -.32966800E+03, -.27711600E+03, 0.13472500E+03, 0.69611600E+02, 0.45288100E+02, -.41118700E+02, -.38409300E+03, 0.51519300E+02, -.37632100E+03, 0.33620100E+04, -.16721500E+04, -.35194200E+04, -.16744700E+04, 0.11251000E+03, -.24220400E+03, -.12176300E+04, 0.11960600E+02, -.79639000E+03, -.19503400E+03, -.15118700E+04, -.26996600E+04, 0.14359800E+04, 0.15973800E+04, 0.13494700E+04, 0.93061800E+03, 0.11292300E+04, 0.22682500E+03, 0.48825800E+02, 0.10233600E+04, 0.10552600E+04, 0.55505800E+03, 0.29336000E+04, -.14503400E+04, -.23256700E+04, -.14669000E+04, 0.30878800E+03, -.40309400E+03, -.10032300E+03, 0.62657100E+03, -.13722900E+04, -.14697700E+03, -.19411100E+04, 0.94064800E+03, -.56530100E+03, 0.16532600E+04, -.46697200E+03, -.65107700E+03, -.50460500E+03, -.15015200E+03, 0.98628200E+02, 0.32997300E+01, -.46071300E+03, 0.10667300E+03, -.58026600E+03, 0.23703500E+03, -.23056300E+03, 0.28908800E+03, 0.81650600E+03, 0.61600800E+03, 0.31467400E+03, 0.56379900E+03, -.34566600E+02, 0.49670200E+03, -.22990500E+03, 0.11278700E+03, -.17529800E+03, -.23760800E+03, -.51067500E+02, 0.25168600E+03, 0.20477700E+03, -.94946900E+03, -.36394300E+03, 0.62066500E+02, 0.59991100E+02, 0.47576300E+02, 0.21764600E+01, 0.31265100E+02, -.12788900E+03, -.11925100E+03, -.66672700E+01, -.20797600E+02, -.38943400E+02, 0.14428600E+02, 0.38073000E+01, 0.13184700E+02, -.17058800E+02, -.56503100E+02, -.80129200E+02, -.83835400E+01, -.62621800E+02, -.58324600E+03, 0.11854000E+03, 0.18736500E+03, -.13767300E+03, -.18546400E+02, 0.14126200E+03, 0.39664700E+03, 0.48496700E+03, -.84777500E+02, 0.59238900E+01, -.77820100E+02 },
        { -.12399500E+01, -.25515600E+00, 0.39769200E+00, 0.43028900E+00, 0.14746400E+00, 0.55672600E+00, 0.14111900E+01, -.46091900E+00, -.49039200E-01, -.94802500E+00, 0.15076000E+00, 0.16348700E+00, 0.11114500E+00, -.19093400E-01, -.21168700E-01, -.12856100E+01, -.66601300E+00, 0.39225000E+00, 0.49439300E+00, -.34857700E-02, -.54636600E+00, 0.70599200E-01, 0.44107200E-04, 0.12502400E-01, 0.29537200E-01, -.14177700E-01, -.14607800E+00, -.58291900E+00, 0.20484700E+00, -.25817600E-01, -.93755100E-01, 0.41496300E+00, -.36840200E-01, -.52725500E+00, -.13828200E-01, -.50921100E-01, -.92974700E-02, -.26531300E+00, -.79853900E-01, 0.21855500E+00, -.33644300E+00, -.30786900E+00, -.68093500E-02, -.18172700E-01, 0.35970400E+00, 0.12185000E-01, 0.29297600E-02, 0.33184500E-01, 0.51209500E+00, 0.46348200E-01, 0.46114700E+00, 0.32119800E+00, 0.12277800E+00, -.97784200E-01, 0.22405100E+00, -.53404700E+00, 0.19039300E-01, -.14891700E-02, 0.49020000E-02, -.99542100E-03, -.65126600E-01, 0.59849700E-01, -.11868900E+00, 0.60161500E-03, -.49804900E-01, -.22326200E-01, 0.17058500E+00, 0.58042000E-01, 0.32716500E+00, 0.33992200E-02, -.86062700E-02, 0.77993400E+00, -.26991500E+00, -.17921100E+01, -.64529000E-01, 0.39508200E+00, 0.45059900E-01, -.65959800E+00, 0.11059100E+00, 0.80651500E-01, -.32749300E-01, -.23509000E-01, -.25802900E-01, -.25203800E-01, -.14262600E+00, -.80351600E-01, 0.57266200E-01, 0.82699600E-01, 0.33595200E+00, -.40868600E-03, -.16769000E+00, -.15750800E-03, 0.21426400E+00, 0.74016600E-01, -.12385900E+00, 0.21678500E+00, -.27219100E+00, -.19745000E+00, 0.55168500E-01, -.79306800E-01, -.12293400E-01, 0.24459800E-01, 0.20777400E-02, -.17259100E+00, 0.98251700E-01, 0.14886000E+01, 0.26100500E-01, 0.79441500E-01, -.65224900E-01, 0.26345500E+00, -.22445200E+00, -.85335300E-02, 0.72300700E+03, 0.15660600E+00, 0.19097600E+02, 0.49883500E+02, -.38323700E+02, -.10659200E+03, -.12573500E+03, 0.38958300E+02, -.34559800E+03, 0.88684600E+02, -.41635700E+02, -.14096700E+03, -.44087200E+02, 0.58301400E+02, 0.14462900E+03, -.10108600E+03, 0.15243600E+03, 0.17226800E+03, 0.10636000E+03, 0.97207400E+02, 0.64247300E+02, -.64780200E+02, -.24405500E+03, -.32134300E+02, -.63884700E+01, -.67045500E+00, 0.64402700E+02, 0.58980100E+02, -.69904400E+02, 0.18403500E+02, 0.70159500E+02, -.62533600E+03, 0.31758900E+03, 0.58743000E+03, 0.31281200E+03, -.73336500E+02, -.84248500E+02, 0.78078900E+02, -.25927100E+03, 0.17963100E+03, -.12173500E+03, 0.37598900E+03, 0.15658800E+04, -.77410900E+03, -.11548200E+04, -.78296300E+03, -.34612200E+03, -.31592200E+03, -.22291100E+03, 0.23015700E+03, -.48619000E+03, -.36906900E+03, -.40300600E+03, 0.54325800E+03, -.24798800E+03, -.20337300E+03, -.27143900E+03, -.29874700E+02, 0.29492400E+01, -.11509100E+03, 0.42730100E+02, -.20862200E+03, 0.99917500E+01, -.19368600E+03, -.30406600E+03, 0.15361500E+03, -.18119300E+03, 0.15127200E+03, -.17507300E+03, -.49655500E+03, 0.34519100E+03, 0.47112300E+01, 0.13089200E+03, -.43722200E+03, 0.13055400E+02, 0.36125300E+03, -.16581000E+03, -.62557000E+02, -.18147400E+03, -.51963300E+01, 0.12828200E+02, -.10134500E+03, 0.44430000E+01, -.16537600E+03, 0.21323300E+02, -.10930900E+03, -.40972000E+03, 0.21366300E+03, 0.16270500E+03, 0.20475700E+03, 0.34526500E+02, 0.73282000E+01, -.40882100E+02, -.21383300E+03, 0.17397800E+03, 0.34049800E+02, 0.74621600E+02, 0.45428900E+03, -.22790400E+03, 0.17571800E+03, -.22668000E+03, -.53772200E+02, -.14558200E+02, 0.18841300E+03, 0.44035700E+03, -.54219200E+02, -.55635000E+02, -.42551500E+03, 0.93717200E+03, -.45684200E+03, -.58539100E+03, -.46862100E+03, -.25052100E+03, -.27402100E+03, -.92830200E+02, 0.92520500E+02, -.39233800E+03, -.29607100E+03, -.35950900E+03, 0.19611000E+02, -.12898800E+02, 0.53508400E+03, -.98135500E+01, -.55199000E+02, -.64542700E+01, -.50910000E+02, -.19580100E+02, 0.21998600E+01, -.75577500E+02, 0.66468100E+02, -.57440800E+03, 0.27805200E+03, -.14887600E+03, 0.28746200E+03, 0.11542900E+03, 0.14101200E+03, 0.86611100E+01, -.17717000E+03, 0.11866000E+03, 0.13191700E+03, 0.24130100E+03, -.44067300E+03, 0.21390200E+03, -.32639100E+01, 0.22024700E+03, 0.14229600E+03, 0.28241800E+03, -.75202000E+02, -.11094400E+02, 0.14460800E+03, 0.21568600E+03, 0.39642200E+03, -.19674400E+03, 0.82308400E+02, -.27858700E+03, 0.98660400E+02, 0.74549100E+02, 0.52894100E+02, 0.11220200E+03, 0.10934700E+03, 0.29961900E+02, 0.10665400E+03, 0.36624000E+03, -.27311100E+02, -.10587700E+02, 0.98368900E+01, 0.88135300E+01, -.61958400E+00, 0.70672300E+01, -.28756300E+01, 0.10185500E+03, -.22811900E+01, -.41205000E+01, -.10364100E+02, -.11127900E+02, 0.18879900E+02, 0.28456300E+02, 0.86636400E+02, 0.10327300E+03, -.49690400E+01, 0.89855800E+02, 0.73696400E+01, 0.16865400E+02, -.48679100E+02, -.91209800E+02, -.13154800E+03, 0.30448100E+02, 0.47670500E+02, 0.24313700E+02 },
        { 0.91179600E+01, 0.24422400E+01, -.23681800E+01, -.11417900E+01, -.64478500E+01, -.33551500E+01, -.20103300E+01, -.17319200E+02, 0.10012100E+01, -.41693500E+01, -.26964800E+01, 0.31841400E-01, -.98275800E+00, 0.52952600E+00, 0.14493000E+01, 0.32784600E+01, -.67366100E+00, 0.17113900E+01, -.12783800E-01, -.15170900E+01, -.38049500E+01, 0.19083200E-01, 0.86361400E-01, -.72549500E+00, 0.40401200E+00, 0.10906700E+01, 0.91700100E+00, 0.47680800E+00, -.18769100E+01, -.58929800E-01, 0.69326800E+00, 0.19433700E+01, 0.45487700E-02, -.17405300E+01, 0.47909000E-03, 0.14717400E+00, 0.73755600E-01, -.12239600E+01, -.89813500E-01, -.10498600E+01, -.66009400E+00, -.56608600E+00, 0.28887500E+00, 0.35178800E-01, 0.73887200E+00, 0.20990000E+00, 0.13493400E+00, 0.15139100E+00, 0.37490100E+00, 0.58838600E-01, 0.92595200E+00, 0.11047700E+01, 0.35214600E+00, 0.36824700E+01, 0.77675300E+00, 0.19079400E+01, 0.12313800E+01, 0.35822300E+00, 0.14530900E+00, 0.15299700E+00, -.85055800E-01, 0.73794000E+00, 0.70791700E+00, -.88960200E+00, -.10819400E+01, -.52782600E+00, 0.53742400E+00, -.28893300E-01, 0.69422200E+00, -.41460000E-01, 0.12108500E+00, 0.89964100E+00, 0.91733400E+00, 0.71115700E+00, -.38970700E+00, 0.10374700E+00, 0.26746200E-01, 0.28535600E+00, -.95404500E+00, -.18224200E-01, 0.21386600E+00, -.43799400E-01, 0.91218100E-01, 0.12817500E+01, 0.40157800E+00, -.28989400E+00, 0.19752800E+00, 0.22709100E+00, 0.60513000E+00, 0.32350200E+00, 0.44760200E-01, 0.17185300E-01, -.28277900E+00, -.68186700E-01, 0.68083600E+00, 0.44243400E-01, 0.13876600E+00, -.72034700E+00, -.85534900E-02, -.92553400E+00, 0.29665800E+00, 0.14209600E+00, 0.14916600E+00, -.42504500E+00, 0.92395800E-01, -.12770400E+01, -.51748100E+00, 0.46513800E+00, 0.46445900E-01, 0.38013600E+00, -.11698500E+01, 0.67564500E-02, -.14434200E+01, 0.22648600E+02, -.43028800E+03, -.16509600E+03, -.12953600E+02, -.50976500E+03, -.21772100E+03, -.11893200E+03, 0.45441200E+03, -.36484800E+03, 0.21298000E+03, 0.11502200E+03, 0.18593900E+03, 0.12236400E+03, -.85329500E+02, 0.56704900E+03, 0.69398100E+03, -.81002700E+02, -.53305100E+02, -.33287500E+03, -.17516300E+03, -.21392000E+03, -.22854800E+03, 0.86996700E+02, -.27237300E+03, -.27452500E+03, 0.46056800E+02, 0.20312000E+03, 0.18428800E+03, -.31944300E+03, -.27731400E+03, 0.35843800E+04, -.17941800E+04, -.30538400E+04, -.17891000E+04, 0.46137500E+03, -.50792200E+03, 0.29287900E+02, 0.66143500E+03, -.21344900E+04, -.14191700E+03, -.23424000E+04, -.34707200E+04, 0.18818300E+04, 0.32053400E+03, 0.17349500E+04, 0.18486600E+04, 0.17557100E+04, 0.18432300E+03, 0.46400100E+03, 0.13425800E+04, 0.16930700E+04, 0.38951200E+03, 0.34013700E+04, -.15111700E+04, -.19101200E+04, -.17006200E+04, -.46710600E+03, -.38990300E+03, -.68001300E+03, 0.19770500E+03, -.78331600E+03, -.34481100E+03, -.10965200E+04, -.48328300E+03, 0.23921100E+03, 0.14533000E+03, 0.21299500E+03, -.52372700E+03, -.72913100E+03, -.64738300E+01, -.65634000E+03, 0.49756800E+03, -.50458300E+03, 0.61053100E+03, 0.39447300E+04, -.18685400E+04, -.19829000E+04, -.19776400E+04, -.53933800E+03, -.53149200E+03, -.67715600E+03, 0.89469500E+02, -.12341200E+04, -.44836400E+03, -.11915400E+04, 0.10374400E+04, -.43785100E+03, -.97422000E+03, -.52251900E+03, -.10414400E+03, -.20119400E+03, 0.78205700E+02, -.14119900E+03, -.55398500E+03, -.10344800E+03, 0.10820700E+03, 0.31957400E+04, -.16270900E+04, -.37487600E+04, -.15874800E+04, 0.38174500E+03, -.42076700E+03, -.90366200E+03, 0.62202400E+03, -.35184100E+03, -.38414500E+03, -.18201400E+04, -.32655800E+04, 0.17867500E+04, 0.22001000E+04, 0.16322200E+04, 0.12357400E+04, 0.14050200E+04, 0.15109000E+03, -.14900900E+03, 0.12137500E+04, 0.12992800E+04, 0.73649900E+03, 0.29068000E+04, -.14322000E+04, -.20734700E+04, -.14535600E+04, 0.54281600E+03, -.41504100E+03, -.75592500E+02, 0.60440800E+03, -.15264600E+04, -.11468100E+03, -.21806400E+04, 0.97615400E+03, -.62999000E+03, 0.14694200E+04, -.48274400E+03, -.85979200E+03, -.53366400E+03, -.19648900E+03, 0.46295500E+02, 0.65504200E+02, -.53532100E+03, 0.30801200E+03, -.16891500E+04, 0.81205800E+03, -.16405500E+02, 0.84291100E+03, 0.75973000E+03, 0.94140900E+03, 0.18287700E+03, 0.25850700E+03, -.53801700E+02, 0.79813000E+03, 0.49952400E+03, 0.33698300E+02, -.22262800E+03, -.62143000E+03, -.84094800E+01, 0.18167800E+03, 0.26769700E+03, -.12366200E+04, -.63092700E+03, 0.10961800E+03, 0.91044400E+02, -.94700500E+03, -.12820000E+00, 0.28915000E+02, -.11992900E+03, -.10772900E+03, -.34442600E+00, -.69273400E+01, -.33212900E+02, 0.89279300E+02, 0.51437500E+00, 0.88670500E+01, -.13303700E+02, -.59865200E+02, -.83848400E+02, -.23596100E+02, -.24046700E+02, -.74440300E+03, 0.13465400E+03, 0.24295400E+03, -.15353500E+03, -.40133200E+02, 0.12770700E+03, 0.54421000E+03, 0.61904100E+03, -.92671000E+02, 0.40234200E+02, -.77161000E+02 },
        { 0.27765100E+01, -.50756900E+00, -.25805200E+01, -.66907600E+00, -.13006700E+01, -.28202300E+00, -.10602700E+01, 0.32725400E+01, 0.10565000E+00, 0.80796200E+00, 0.21784600E+00, -.36272400E+00, -.25708300E+00, 0.19529700E+00, -.78347800E-01, 0.32984100E+01, 0.50393500E-01, 0.15867700E+00, -.45438900E+00, 0.23021000E-01, 0.59365700E+00, 0.30831600E+00, 0.81218600E-02, 0.71823200E+00, 0.84087700E-01, 0.10836500E+00, 0.58510600E+00, 0.88140200E+00, -.18956400E+01, 0.93948600E-01, -.20117900E+00, -.65525400E+00, 0.85274500E+00, 0.14798600E+01, 0.23651800E-01, -.37175700E-01, -.37367500E-01, -.45607300E+00, -.21969000E-01, -.73981100E+00, -.36442200E-01, 0.89758000E+00, 0.14269100E-01, 0.24798100E+00, -.53605100E+00, 0.63349800E+00, -.55139100E-01, -.21103300E-01, 0.61816300E+00, -.59769800E-01, 0.63665300E+00, -.84276200E+00, 0.11064500E+01, 0.69841300E+00, 0.29629800E+00, 0.11851400E+01, 0.22356000E+00, 0.24631900E+00, 0.20336100E-01, -.66106800E+00, 0.12538700E+00, 0.41863300E+00, 0.16399200E+00, -.49830500E+00, -.92660000E+00, 0.12036900E+00, 0.42199300E+00, -.74470600E-01, 0.53535400E-02, -.15318500E-01, 0.68853700E-01, 0.11975800E+01, -.60578100E-01, -.12090800E+01, 0.16563000E+00, -.41571100E+00, 0.14457100E+00, -.20606400E+00, -.41739900E+00, -.27469200E-01, 0.20303500E-01, 0.53486600E-02, 0.26111200E+00, 0.59490100E+00, -.68698000E-01, -.14405900E-01, 0.41357100E+00, 0.19750200E+00, -.98446500E-01, 0.21813200E+00, 0.19811200E+00, 0.68951600E-02, 0.50830300E-01, -.27024100E+00, -.16257800E+00, -.47300100E+00, 0.70051600E+00, -.54663400E-01, -.29973300E+00, -.44588400E+00, 0.16143100E+00, 0.34438700E-01, 0.29018500E-02, 0.33539100E+00, 0.26451900E+00, 0.39823400E+00, -.88496700E+00, 0.92141800E-01, 0.17012900E+00, 0.37531900E+00, 0.92334200E-01, -.21601900E-01, -.97216900E+00, 0.32753900E-01, -.28564000E+03, -.11083400E+03, -.21393400E+03, -.35137600E+03, 0.89662400E+02, -.50989400E+02, 0.26486100E+03, 0.37426200E+03, -.17181700E+03, -.31197400E+03, -.18645600E+03, 0.57676800E+02, -.11644100E+02, 0.27011300E+03, 0.62170400E+03, 0.14068600E+03, -.23926300E+02, -.86165800E+02, -.43578600E+03, 0.98938500E+02, -.29633300E+02, 0.21777100E+03, -.15225600E+03, -.19009000E+03, 0.15630900E+03, 0.53394600E+01, 0.12613200E+03, -.16344900E+03, 0.65610600E+01, 0.22791500E+04, -.11373500E+04, -.20049600E+04, -.11389600E+04, 0.12678300E+03, -.34596200E+03, -.10548900E+03, 0.33618300E+03, -.11596900E+04, -.22426300E+03, -.11846600E+04, -.44839400E+02, 0.78841700E+02, -.12633700E+04, 0.22339200E+02, 0.40190400E+03, 0.56668100E+03, 0.44352400E+02, 0.57161200E+03, 0.18512500E+03, 0.48269000E+03, 0.12554100E+02, 0.13780000E+04, -.60894300E+03, -.11314600E+04, -.68904700E+03, -.18450500E+03, -.85050100E+02, -.27537500E+03, 0.95952000E+02, -.27449100E+03, -.73460100E+02, -.32256000E+03, -.13879400E+04, 0.69016300E+03, 0.28203900E+03, 0.69233400E+03, -.67828800E+03, -.76503000E+03, 0.21950100E+03, -.80546400E+03, 0.20010500E+03, -.56928200E+03, 0.60891300E+03, 0.13890100E+04, -.65027000E+03, -.92849900E+03, -.69503400E+03, -.18054200E+03, -.13987800E+03, -.23986000E+03, -.35258200E+02, -.50208000E+03, -.10625500E+03, -.34040500E+03, 0.61420400E+03, -.27802100E+03, -.41871600E+03, -.30788200E+03, 0.34562200E+02, -.26459200E+02, 0.30681900E+02, -.28583300E+02, -.27600700E+03, -.19630300E+02, 0.35208600E+02, 0.21432100E+04, -.10827400E+04, -.17367800E+04, -.10695300E+04, -.43318100E+02, -.32635300E+03, -.25798700E+03, 0.27459700E+03, -.72119500E+03, -.22094100E+03, -.13188500E+04, -.35793500E+03, 0.23806600E+03, -.29963600E+03, 0.17885700E+03, 0.26597300E+03, 0.46172300E+03, 0.35356300E+01, 0.25221600E+03, 0.27298600E+03, 0.39555400E+03, 0.98498000E+02, 0.23134300E+04, -.11473600E+04, -.15486000E+04, -.11567500E+04, 0.84789600E+02, -.35522300E+03, -.13847400E+03, 0.47117700E+03, -.94229700E+03, -.26313000E+03, -.12280600E+04, 0.43165200E+03, -.27273500E+03, 0.99417700E+03, -.21476500E+03, -.39934600E+03, -.37885700E+03, -.24360600E+02, 0.12540400E+03, 0.13519100E+03, -.37836300E+03, -.99411300E+02, -.48760600E+03, 0.23432800E+03, -.29817300E+03, 0.24347400E+03, 0.62020700E+03, 0.62354700E+03, 0.21239800E+03, 0.51569100E+03, 0.14234100E+03, 0.45829200E+03, 0.30562300E+03, -.41881200E+03, 0.12756500E+03, -.20562100E+03, 0.21111900E+03, 0.30476400E+03, 0.89085100E+02, -.39566300E+02, -.19207200E+03, -.73600400E+02, 0.94907100E+02, -.26076500E+03, -.53586900E+02, -.33036000E+01, -.86623200E+02, -.73205400E+02, -.11949100E+02, 0.66986000E+01, -.35296300E+02, 0.11980800E+03, 0.58251900E+01, 0.21306600E+01, -.26880900E+02, -.99677700E+02, -.68809500E+01, 0.87984300E+01, 0.38649900E+02, -.30505400E+03, 0.78252500E+02, 0.26390400E+03, -.87763600E+02, -.11807100E+02, 0.81641400E+02, 0.20009500E+03, 0.89240300E+02, -.31007300E+02, 0.80439800E+02, 0.18752000E+02 },
        { 0.78099700E+00, 0.82463900E+00, -.35386000E+00, -.92638100E+00, -.12446300E+00, -.98615100E+00, -.74157600E+00, 0.12360500E+01, 0.45362600E-01, 0.32539000E+00, -.49344200E-01, -.17310900E+00, -.26751500E+00, -.14092200E-01, 0.23619300E+00, -.93380500E+00, -.12904600E+01, -.93591700E+00, -.33647600E+00, 0.15568200E+00, 0.11082400E+01, 0.18217500E+00, 0.19814500E-01, 0.39962600E+00, 0.63308300E-01, 0.81361900E-02, 0.33416300E-01, 0.52358700E+00, -.33756000E+00, -.62329000E-02, -.66579700E-02, -.18462900E+00, 0.15259800E+00, 0.34233300E+00, -.48886100E-02, -.10573800E-01, -.83959800E-02, -.35780300E+00, -.15549700E-01, 0.66711100E-01, 0.70146600E+00, 0.41999100E-01, -.89168300E-01, -.81541000E-03, -.16857200E+00, -.72918300E-02, -.13254400E-02, -.27854200E-02, 0.10092600E+01, -.34317400E-03, -.55467800E-01, -.10461900E+00, 0.13218900E+00, 0.39975300E+00, 0.66246300E-01, -.11507800E+00, 0.17795300E-01, -.53644500E-01, -.46564100E-02, -.16643200E+00, 0.16942200E+00, -.14307100E+00, 0.25186900E+00, -.18503700E+00, -.74998900E-01, 0.50810900E-01, -.28017800E+00, 0.40360200E-01, -.24042700E-01, -.17902300E-01, 0.37666900E-01, -.61290000E+00, 0.66129500E+00, 0.17719800E+00, 0.22928100E+00, 0.12600200E+00, -.86895600E-01, 0.43667400E+00, 0.60826900E-02, -.15332400E+00, 0.39702600E-01, -.52418500E-01, -.24479900E-02, 0.30959300E+00, -.91092600E-02, -.14904900E+00, 0.34417000E+00, 0.69884900E-01, 0.42324600E+00, 0.84575700E-01, 0.24932300E+00, 0.45016300E-02, 0.27323800E+00, 0.16070300E-01, -.34737400E+00, 0.11647400E+00, 0.22190900E+00, -.27714900E-01, -.67002100E-01, -.34966400E+00, 0.12044500E+00, 0.30573900E-01, 0.62659800E-02, 0.14296400E+00, -.71420700E-01, -.24378100E+01, -.16307300E+00, -.19464800E+00, -.99890800E-01, 0.29609700E+00, 0.17276700E+00, -.10083400E-01, 0.18418900E+00, 0.47214900E-03, 0.17244300E-01, 0.92796700E+02, -.12180700E+03, -.24666400E+03, -.11821600E+03, 0.94927100E+02, -.15443500E+03, 0.17611200E+02, -.41487200E+01, 0.46330500E+02, -.87816800E+01, 0.21476900E+02, -.37253400E+00, 0.24540100E+03, 0.36825200E+03, 0.27771400E+03, -.15583300E+02, 0.21352400E+03, 0.81682700E+01, -.48880600E+02, -.68938800E+02, -.40798300E+01, -.51956600E+02, -.10489300E+03, 0.92077000E+02, -.76600400E+02, -.79524900E+02, -.53229600E+02, -.62423100E+02, 0.81451500E+02, -.36455800E+02, 0.71081700E+03, -.40725800E+02, 0.28664800E+02, 0.17852700E+02, 0.74716700E+02, 0.23455000E+03, 0.18498300E+02, -.28482600E+02, 0.81914100E+02, 0.32872200E+03, -.14248900E+03, -.52643300E+03, -.16436300E+03, -.30089700E+02, 0.10723700E+03, -.65860800E+02, 0.48699000E+02, -.17928600E+03, 0.73868300E+02, 0.27400800E+03, 0.17430700E+03, -.66718800E+02, 0.27999200E+02, -.87067700E+02, -.69328400E+02, -.11307700E+03, 0.33238500E+02, -.16549300E+02, -.10772100E+02, -.84482800E+02, -.10995000E+03, 0.15258600E+03, -.76045600E+02, 0.98309500E+02, -.76359500E+02, 0.50993100E+02, 0.87942400E+02, -.29649900E+03, -.28050500E+03, -.22032500E+03, 0.44472400E+02, -.42884200E+03, 0.23248900E+03, -.10475100E+03, 0.27237900E+02, -.11592100E+03, -.63583300E+02, -.93485900E+02, 0.18326600E+02, -.14543900E+02, -.55508400E+02, -.62192100E+02, -.71426700E+02, 0.67268000E+03, -.32727100E+03, -.82674800E+02, -.33632100E+03, -.97462900E+02, -.23405500E+02, -.11104900E+03, -.42823700E+01, -.12668500E+03, -.18146600E+02, -.21319600E+03, 0.38772500E+03, -.19600500E+03, 0.59298700E+03, -.19387200E+03, 0.80830700E+02, 0.13143200E+03, -.33698400E+03, -.37157800E+03, -.48306200E+03, 0.18951100E+03, -.38658000E+03, 0.20220100E+03, -.76678500E+02, -.66087200E+03, -.10110500E+03, -.13506400E+02, 0.76675300E+02, -.51551100E+02, 0.83184400E+02, -.86748200E+02, 0.42867800E+02, 0.20367700E+03, 0.32692200E+02, -.17213400E+02, 0.37371400E+03, -.16346400E+02, -.38251800E+02, 0.57137900E-01, -.28166100E+02, -.57838700E+02, -.73948200E+02, -.32587800E+02, 0.15935700E+03, -.13931700E+03, 0.49804300E+02, -.50042400E+03, 0.69662800E+02, -.15919500E+03, -.15113900E+03, 0.77966200E+02, -.53761800E+02, 0.18793100E+03, -.18380400E+03, -.22433500E+02, -.12066900E+03, 0.53465600E+02, 0.26353000E+02, 0.60333000E+02, -.56602300E+02, -.17548000E+03, 0.32136900E+03, 0.32882600E+03, 0.14597200E+03, -.17271100E+03, 0.25192600E+03, -.14146100E+03, 0.43532000E+02, 0.99120100E+02, 0.70705900E+02, -.64726800E+02, -.23413600E+03, 0.10661300E+03, -.17920500E+03, -.16509600E+03, -.96764600E+02, -.13372600E+03, -.25417300E+02, -.77408800E+01, -.72287200E+01, -.33687900E+01, -.13658300E+02, 0.14084900E+02, 0.32323000E+02, -.33775800E+02, 0.72056200E+00, 0.31345300E+01, 0.11025000E+02, -.20402700E+02, 0.45128300E+02, 0.24909200E+02, -.21239600E+02, -.12924600E+03, 0.13356500E+02, 0.11890300E+03, -.12317400E+02, 0.15205900E+02, -.73690600E+01, 0.95275400E+02, 0.18930900E+03, -.11818600E+02, 0.27609000E+02, -.88553200E+01 },
        { 0.65911200E+01, 0.20763700E+01, -.59843800E+00, -.27573500E+01, -.21950800E+01, -.16335100E+01, -.23240900E+01, 0.54133600E+00, -.52796200E-01, -.11153300E+01, -.30733700E+00, -.89786300E+00, 0.27964000E+00, 0.39462500E+00, 0.88937000E+00, -.13190600E+02, 0.49906100E+01, 0.35195000E+01, -.57733000E+01, -.13231700E+01, 0.81080800E+00, 0.14686700E+00, 0.22143700E-01, -.64226200E+00, 0.52742400E+00, 0.48534000E-01, 0.28182300E+00, -.12589500E+01, -.19635100E+01, -.19435200E+00, 0.13949400E+01, -.59482200E+00, -.31047600E+00, 0.13971900E+01, -.17174200E-01, 0.17539600E+00, 0.81205100E-01, 0.26914900E+00, 0.32727200E+00, -.98948300E-01, -.24216500E+01, 0.11598500E+01, -.22280900E-01, 0.17254800E-01, -.50753900E+00, 0.49339200E+00, -.81378000E-01, 0.39278000E-01, 0.64400500E+00, -.28098200E+00, 0.50534200E+00, -.93254900E+00, 0.11136200E+01, -.26190400E+01, -.10858600E+00, 0.87298200E+00, -.66228800E+00, 0.13180700E+00, 0.11461100E+00, -.16475300E+01, 0.25108000E+00, 0.17536300E+00, -.12946300E+00, 0.17319100E+00, 0.92040900E-01, 0.37284000E+00, -.58125200E-01, -.38798600E+00, 0.12887500E+00, 0.33060400E-02, 0.69885000E-01, 0.17565900E+01, -.14128700E+01, -.22064100E+01, 0.39776200E+00, -.14351100E+01, 0.16086000E+00, -.96758800E+00, 0.14576700E+00, 0.17264500E+00, -.60647200E-02, -.21238700E-01, 0.10643900E+00, -.35610700E+00, -.28953500E+00, 0.17589300E+00, -.88385300E+00, -.83875200E-01, -.16468300E+01, -.48403900E-01, -.11612700E+01, -.26307400E-02, 0.51805700E+00, -.10365500E+00, -.44641100E+00, 0.93823800E+00, -.39197200E+00, 0.29373800E+00, -.20628600E+00, 0.14905600E+01, -.25585500E+00, 0.44062600E-01, -.47366300E-01, 0.85404500E+00, -.20116200E+00, 0.51687800E+00, -.48131100E+00, -.95318200E+00, -.24516600E+00, 0.50459900E+00, -.42752200E+00, 0.62107400E-02, -.87030900E+00, -.78148000E-01, -.68916100E+00, 0.30615600E+00, -.69876700E+03, -.74308800E+03, 0.24003900E+03, 0.81947000E+02, -.14095900E+04, -.13220600E+04, 0.63788900E+03, 0.19551300E+04, 0.66027300E+03, 0.11998500E+04, 0.15317900E+04, -.47850900E+03, 0.21939000E+03, -.16383100E+03, 0.14449200E+04, 0.41546100E+03, 0.11035000E+04, -.34058800E+03, -.79058900E+03, -.55144700E+03, -.28939600E+03, 0.16166000E+02, -.23375500E+03, 0.17736900E+02, -.81412700E+03, 0.86953100E+01, 0.78139300E+03, -.51155200E+04, 0.24807700E+04, 0.33766300E+04, 0.25566600E+04, 0.55961600E+02, -.29617700E+03, 0.17393900E+04, 0.18579300E+03, 0.18432500E+04, -.26883100E+03, 0.12098400E+04, 0.60304500E+04, -.31398600E+04, -.33345900E+04, -.30151000E+04, -.26703600E+04, -.10304700E+04, -.76728800E+03, 0.21364100E+03, -.18531700E+04, -.14133500E+04, -.12858800E+04, 0.32287400E+04, -.16569300E+04, -.34403100E+04, -.16135800E+04, -.34181600E+03, -.12572200E+02, -.44003000E+03, 0.18704800E+04, 0.35083500E+03, -.19525200E+03, -.77112700E+03, 0.18264600E+04, -.91701200E+03, -.11677000E+04, -.91074600E+03, -.17165200E+04, -.16330100E+04, 0.22746300E+03, 0.82951400E+03, 0.29141100E+03, -.17095100E+04, -.61222600E+03, 0.21068400E+04, -.10757300E+04, -.20627900E+04, -.10587600E+04, -.10588500E+03, 0.11776700E+03, -.47473100E+03, 0.14716700E+04, 0.51240900E+03, -.11535800E+03, -.37676900E+03, -.15706500E+04, 0.72377200E+03, 0.22535300E+03, 0.78709200E+03, 0.39181900E+03, 0.54013600E+03, -.67494800E+03, -.68754000E+03, 0.62411500E+03, 0.39387100E+03, 0.41263100E+03, 0.50549000E+04, -.25285300E+04, -.38754200E+03, -.25312400E+04, -.69357100E+03, -.28763800E+02, -.42323400E+03, 0.57653900E+03, -.10735500E+04, -.21089700E+03, -.22294700E+04, 0.37525100E+04, -.20091400E+04, -.19495000E+04, -.18760900E+04, -.20815400E+04, -.10343100E+04, -.34591900E+03, -.71272300E+02, -.16401800E+04, -.11207300E+04, -.15168700E+04, 0.39357500E+03, -.21260600E+03, 0.13024400E+04, -.19673400E+03, 0.81714100E+02, -.28982000E+02, -.16923100E+03, 0.47555000E+02, 0.19753200E+03, -.31111800E+03, 0.20604300E+02, -.11730700E+04, 0.70132300E+03, -.96722700E+03, 0.58466700E+03, 0.46106200E+03, 0.23871000E+03, -.24444300E+03, 0.23487700E+03, 0.24097100E+03, 0.23660300E+03, 0.97618600E+03, -.16307900E+04, 0.85614700E+03, 0.21953100E+04, 0.81591700E+03, 0.97826700E+03, 0.72316900E+03, 0.30158000E+03, -.51807400E+03, -.14778600E+03, 0.67716300E+03, 0.12360800E+04, -.96954900E+03, 0.64309600E+03, -.24066600E+03, 0.48117200E+03, -.33331600E+03, -.10728400E+04, 0.59853900E+03, 0.91990600E+03, 0.10557900E+04, -.12121800E+04, 0.45410400E+04, -.90883700E+02, -.14091200E+03, 0.67493700E+02, 0.47033400E+02, -.56490600E+01, -.19983100E+02, 0.36838300E+03, 0.23529300E+03, 0.11877100E+03, -.11044900E+03, -.19689500E+03, -.27107600E+03, 0.14022200E+03, 0.10161400E+03, 0.30041500E+03, 0.67319800E+03, -.73208900E+02, 0.29234900E+03, 0.99049800E+02, 0.25041000E+02, -.25885100E+03, -.72282600E+03, -.59319500E+03, 0.21023000E+03, 0.48678200E+01, 0.63647100E+01 },
        { -.29319500E+01, -.13508100E+00, 0.25866300E+01, 0.10260600E+01, 0.13254000E+01, 0.14078900E+01, 0.11330600E+01, -.65194900E+00, -.37400800E-01, -.59496800E+00, 0.20698400E+00, 0.46806000E+00, 0.83668800E-01, -.29519900E+00, 0.36322300E+00, -.77940600E+01, -.43028500E+01, -.18138100E+01, 0.12893900E+01, 0.50285000E+00, -.78864800E+00, -.50595600E+00, 0.20589000E+00, -.29544500E+00, 0.19737400E-02, -.28561400E-01, 0.14710200E+00, -.11794900E+00, 0.34456300E+00, -.14302600E+00, 0.28750100E+00, 0.12154800E+01, -.63208600E+00, -.34661000E+01, -.35047400E-01, 0.12304300E+00, 0.65247500E-01, 0.30763400E+00, 0.19668300E+00, 0.61104600E-02, -.95056700E+00, -.14889900E+00, 0.93562100E-01, -.18861100E+00, -.47854900E+00, -.38520600E+00, -.12774300E-01, -.35982300E-01, -.27768300E+01, 0.54529200E-01, -.86211300E+00, 0.22520300E+01, -.17727700E+01, 0.18184100E+01, 0.18815700E-01, 0.46835300E-01, 0.53511400E-01, -.20289200E-01, -.79147500E-01, 0.25781100E+00, 0.88883300E-01, -.15927900E+01, 0.61871500E-01, 0.27653400E+00, 0.44753100E+00, 0.61467400E+00, 0.11089500E+01, 0.15344400E+00, -.84820600E-01, -.13751700E-01, -.76851300E-01, 0.73587700E+00, -.47794000E+00, 0.32436200E-01, -.35348700E-01, -.80656500E-01, 0.84406700E-01, -.44310700E+00, 0.49536800E+00, 0.68275800E-01, 0.74318300E-01, 0.82440900E-02, -.32536400E+00, -.39910900E-01, 0.14120400E+00, 0.65046100E-01, -.50351800E+00, -.37687800E-01, -.41727200E+00, -.72618500E-01, -.17325300E+00, -.10676900E-03, 0.91209600E-01, -.43151200E-01, -.52171700E+00, -.10453200E+01, -.57154100E+00, 0.15111800E+00, -.20307300E+00, 0.16458900E-01, -.13889300E+00, 0.94801700E-02, 0.48760800E-01, -.46923600E+00, 0.10845800E+00, -.73045400E+00, 0.51548000E+00, 0.48379500E+00, 0.23396800E-01, -.45331000E+00, -.72311500E+00, 0.47225300E-01, 0.13114900E+01, 0.37735000E-01, -.10606600E+01, -.68182900E+00, -.10387000E+00, -.39761500E+03, -.14118100E+03, 0.86416100E+02, -.61153100E+01, 0.26234300E+03, -.12657700E+03, -.30865000E+03, -.12983800E+03, -.24589800E+03, -.47896500E+03, 0.24861400E+03, 0.48518200E+03, 0.25399600E+03, -.45584100E+03, -.41055200E+03, -.59952800E+03, 0.19499300E+03, -.23104000E+03, 0.29950800E+03, -.13664000E+03, -.26663400E+03, 0.25926100E+03, 0.90847000E+02, 0.25766300E+03, -.26297100E+03, 0.52139600E+02, 0.35069700E+04, -.17862500E+04, -.26011400E+04, -.17522200E+04, 0.27263700E+03, -.31899100E+03, -.19202600E+03, 0.61959300E+03, -.17931300E+04, -.79832500E+02, -.15840600E+04, -.42835400E+04, 0.21856500E+04, 0.62416900E+02, 0.21416100E+04, 0.11588200E+04, 0.13665400E+04, 0.38344800E+03, -.32202800E+03, 0.11243200E+04, 0.13649200E+04, 0.10383800E+04, 0.84932500E+03, -.34254900E+03, -.88793500E+03, -.42482200E+03, -.10338600E+03, -.93967500E+02, -.21457700E+03, -.12943700E+03, -.30679300E+03, -.95844900E+02, -.19430800E+03, -.19725200E+04, 0.98744400E+03, 0.91210500E+03, 0.98498300E+03, -.91035000E+02, -.20661000E+02, 0.19309400E+03, -.85787200E+03, 0.30278700E+03, 0.13247400E+03, 0.11817900E+04, 0.13560000E+04, -.63406000E+03, -.89663900E+03, -.68044700E+03, -.20138800E+03, -.21708600E+03, -.24443100E+03, -.14144500E+03, -.54150900E+03, -.19447400E+03, -.42291300E+03, 0.96426600E+03, -.45703000E+03, -.24062600E+03, -.48376000E+03, 0.43108000E+01, -.85145600E+02, -.74538000E+02, -.93539100E+02, -.41240600E+03, -.89267200E+02, -.48076700E+03, 0.11789700E+04, -.60781100E+03, -.14742700E+04, -.58523300E+03, 0.20489500E+03, -.15491800E+03, -.29069100E+03, -.80587100E+01, -.50970600E+03, -.48947400E+02, -.78101100E+03, -.36131200E+04, 0.18576600E+04, 0.10661600E+04, 0.18063400E+04, 0.72206000E+03, 0.10136900E+04, 0.32963600E+03, -.44301800E+03, 0.10445100E+04, 0.99862600E+03, 0.11289900E+04, 0.19658100E+04, -.97450100E+03, -.12474300E+04, -.98296900E+03, 0.24702300E+03, -.23382400E+03, -.13152100E+03, 0.19210200E+03, -.11834000E+04, -.17073500E+02, -.14403100E+04, 0.17254300E+03, -.13411500E+03, 0.14823700E+04, -.84107300E+02, -.37690800E+03, -.30295400E+03, -.12362000E+03, -.12308900E+03, 0.13946100E+03, -.27425500E+03, -.57538300E-01, 0.23014600E+03, -.12699000E+03, -.84472400E+03, -.11573900E+03, 0.22178700E+03, 0.27222500E+03, -.36598700E+02, 0.68764800E+03, 0.13373800E+03, 0.11887200E+03, -.17206600E+03, -.26239000E+03, 0.49567800E+02, 0.17587900E+03, 0.13474800E+03, 0.21755200E+03, 0.24165700E+03, -.33271700E+03, -.50424700E+03, -.16525500E+03, 0.15234500E+03, -.62468000E+03, -.50826800E+02, 0.27144400E+02, -.31560800E+02, -.16243600E+02, -.26739700E+02, -.20682600E+01, -.89702000E+02, 0.55523900E+02, -.97216200E+01, 0.30377900E+02, 0.26302200E+02, -.11523800E+02, -.76713600E+02, 0.27338500E+02, -.26749600E+02, -.46919600E+03, 0.19896000E+02, 0.66912400E+02, -.39787100E+02, 0.18519400E+00, 0.41824200E+02, 0.27679700E+03, 0.70079800E+03, -.88206900E+02, 0.53890800E+02, 0.24551800E+02 },
        { 0.91053400E+00, 0.31023400E+00, -.41475500E+00, -.52352100E+00, 0.18274400E+00, -.50896600E+00, -.20420900E+01, 0.17868500E+01, 0.35971400E-01, 0.11072700E+01, 0.57461600E-01, -.36870600E+00, -.20613300E+00, -.24408800E-01, 0.24114000E+00, -.67367600E+01, -.34542300E+01, -.14091700E+00, -.29826100E+00, -.27280700E+00, -.14605100E+01, -.94235500E-01, 0.67418800E-01, -.73749400E+00, 0.15686400E-01, 0.59613000E-01, -.85315900E+00, -.29087400E-01, 0.56966000E+00, 0.11118200E-02, 0.52862000E+00, -.15304100E+00, -.16698800E+00, -.11233700E+01, -.27894000E-01, -.43589200E-01, -.28798700E-01, 0.11552500E-01, 0.91757800E-01, -.13897800E+00, 0.84452200E+00, -.18435100E+00, -.15563200E-01, 0.82445500E-01, 0.30402200E+00, -.49760500E-01, 0.52441200E-02, 0.61701100E-02, 0.10346300E+01, 0.11642900E+00, -.34151700E+00, -.27415300E+00, 0.37292800E+00, -.31198400E+00, 0.21533100E+00, -.33616500E+00, -.23748700E+00, 0.72707900E-01, 0.29836300E-01, -.21896700E+00, -.32080700E-01, 0.23855200E+00, -.21001600E+00, -.57099400E-01, -.92368800E-01, -.49960500E-01, 0.13503900E+00, -.12067300E+00, 0.89313000E-02, 0.13821800E-01, 0.13188300E+00, -.19163700E+01, -.14194600E+00, 0.55940300E-01, 0.31349900E+00, 0.69884700E-02, -.60150100E-01, 0.54300400E+00, 0.35215100E+00, 0.62156500E-02, 0.15781800E-01, -.11146400E-01, 0.13493200E+00, 0.10200900E+00, 0.85491200E-01, -.15061300E+00, -.21600200E+00, -.24675900E-01, -.26279900E-01, -.57935100E-01, -.56679300E-01, -.16904000E-02, 0.14977100E+00, 0.33075800E-02, -.34493800E+00, -.58387200E+00, 0.90066200E-01, 0.29370600E+00, -.12537000E+00, -.19999100E+00, -.34027900E-01, -.35297600E-01, -.24304300E-02, 0.54617800E-01, 0.67341700E-01, 0.37372800E-01, 0.56394900E-01, -.13533100E+00, 0.67076700E-01, 0.26271400E-01, -.24510600E+00, 0.34247100E-01, -.23507700E+00, 0.40354900E-02, 0.18837300E-01, -.74256000E-01, -.14910800E+00, -.25222600E-01, 0.12777300E+03, -.20924300E+02, -.42626100E+03, -.52772900E+03, 0.25482500E+03, 0.59004600E+03, 0.26389900E+03, 0.46944700E+03, 0.28075000E+03, 0.74340800E+02, 0.18148900E+03, 0.12413700E+03, 0.29632200E+03, 0.31512600E+03, 0.46034300E+03, -.18561700E+03, -.16989100E+03, -.23013800E+03, -.12895600E+03, 0.63680700E+01, -.10929000E+03, 0.38327900E+02, -.23025700E+03, -.15010000E+02, 0.20135000E+03, -.13077500E+04, 0.63621900E+03, 0.12166100E+04, 0.65380300E+03, 0.10908100E+03, 0.78896700E+02, 0.30246200E+03, -.34523800E+02, 0.50301700E+03, 0.60219100E+02, 0.85785300E+02, 0.10896800E+04, -.57319100E+03, 0.28129500E+03, -.54483900E+03, -.47287500E+03, -.26896800E+03, -.10296200E+03, -.42428500E+01, -.34828900E+03, -.30274300E+03, -.67489500E+03, -.84695200E+03, 0.40161500E+03, -.10964800E+03, 0.42368900E+03, 0.14309700E+02, -.13300900E+03, 0.41547600E+03, 0.38089700E+03, 0.61394400E+03, -.13961000E+03, 0.18531800E+03, 0.10579800E+04, -.52509900E+03, -.45580800E+03, -.52908900E+03, -.39508600E+03, -.11555800E+03, -.28622800E+03, 0.14436800E+03, -.18082600E+03, -.22597100E+03, -.81245700E+03, -.15427700E+04, 0.75502800E+03, 0.38734300E+03, 0.77088000E+03, 0.99640500E+02, -.10066100E+03, 0.53763800E+03, 0.33994700E+03, 0.81480700E+03, -.11445700E+03, 0.18800700E+03, -.75265000E+03, 0.36536600E+03, 0.50045200E+02, 0.37649900E+03, 0.67943000E+02, -.19591500E+02, 0.10502800E+03, -.80412900E+02, 0.39121200E+03, -.16922100E+02, 0.82553400E+02, 0.15612100E+03, -.76721700E+02, 0.68951900E+03, -.78318500E+02, -.22533400E+03, 0.12091700E+03, -.10235400E+02, 0.17663400E+03, 0.86957700E+02, 0.45328900E+02, -.20940500E+03, 0.72044700E+03, -.38620200E+03, 0.31083600E+03, -.36022100E+03, -.35017800E+03, -.24396100E+03, -.12964500E+02, -.47251300E+02, -.36821700E+03, -.23855600E+03, -.69856500E+03, -.36355800E+03, 0.17624500E+03, 0.78808700E+03, 0.18178200E+03, -.59575900E+00, 0.68668000E+02, 0.75445600E+01, -.70391900E+02, 0.20692400E+03, 0.17573100E+02, 0.77287300E+02, -.17726000E+03, 0.11295100E+03, -.80802800E+03, 0.88520600E+02, 0.12087500E+02, 0.63426500E+02, -.53186900E+02, -.22275900E+02, -.23384500E+02, 0.67574100E+02, 0.39212000E+03, -.36059800E+03, 0.18174200E+03, 0.63587300E+03, 0.18032200E+03, 0.20465900E+03, -.93264300E+01, 0.73608700E+02, -.17929600E+03, -.36834600E+02, 0.59090000E+02, 0.35760500E+03, 0.28500000E+03, -.11558300E+03, -.22708400E+03, -.14282000E+03, -.42698900E+03, -.29649600E+03, -.11320700E+03, 0.28510500E+02, 0.13890600E+03, -.33597500E+03, 0.69741900E+03, 0.21433900E+02, -.39664600E+02, 0.93734600E+02, 0.91266700E+02, 0.20835000E+02, -.17221000E+02, 0.11506500E+03, 0.60116000E+01, 0.43382400E+02, -.32086800E+02, -.38877700E+02, -.13569600E+02, 0.59170000E+02, 0.61892700E+01, 0.41957500E+02, 0.12296300E+03, -.96175300E+02, 0.57137500E+02, 0.86274000E+02, -.70468800E+01, -.66437900E+02, -.10807700E+03, -.26392500E+02, 0.51897000E+02, -.20053800E+02, -.19869900E+02 },
        { 0.10429700E+01, -.27048900E-01, -.59892000E+00, -.37730900E+00, -.35228200E+00, 0.41041500E-02, -.24886700E+00, 0.15258800E+01, 0.97296100E-01, -.11144200E+00, 0.28628300E+00, 0.93805100E-01, -.60041600E-01, 0.64035300E-01, 0.11873500E-02, 0.38537400E+00, -.80114500E+00, 0.15335200E+00, -.25448600E-01, -.21720900E+00, -.88027100E+00, 0.41900400E+00, -.44079000E-01, 0.30219500E-01, 0.10619600E+00, 0.66683700E-02, -.17648700E+00, -.21389100E+00, 0.29211800E+00, 0.28216100E-04, -.24217800E-01, 0.12704700E+00, 0.13589900E+00, -.14071600E+00, 0.13473600E-01, -.67180800E-01, -.51097200E-01, -.37550800E+00, -.11756300E+00, -.89220700E-01, -.74070400E+00, 0.21873900E+00, 0.15145400E-01, 0.15507000E+00, 0.18842200E+00, 0.99292200E-01, -.87383300E-02, 0.54370900E-02, 0.91989300E+00, 0.96189600E-03, 0.11584000E+00, -.43866600E+00, 0.23031500E+00, -.11446800E+01, -.32838000E-01, -.12597900E+00, -.49823200E-01, -.22590900E-02, 0.20542700E-01, 0.24044800E-01, -.87574000E-01, 0.54801500E+00, 0.13526800E-01, -.14128000E+00, -.26467100E+00, -.50872300E-01, -.12072600E+00, 0.54265600E-01, 0.31288800E+00, -.46637300E-02, -.42125300E-01, 0.59035300E+00, 0.62090100E+00, 0.78509200E+00, -.13072000E+00, 0.38416500E+00, 0.75339900E-02, -.23990800E+00, -.14436500E+00, -.43888800E-02, 0.49568600E-02, -.17412600E-01, -.27693800E-01, -.11781500E+00, -.34238600E-01, 0.10913100E+00, 0.20664900E+00, 0.64930300E-01, 0.11497100E+00, 0.91265800E-02, 0.83608600E-01, 0.18236900E-02, -.78204700E-01, 0.13936500E-01, 0.23406000E+00, 0.51000400E+00, -.18917800E-02, -.53044800E-01, 0.87344800E-01, 0.28892100E+00, -.50031300E-03, 0.53398100E-01, 0.12866200E-01, -.50663400E-01, -.13395300E+00, -.14752100E+01, 0.84240200E-01, -.58165500E-01, -.18895600E-01, 0.11722300E+00, 0.16471500E+00, -.13741800E-01, 0.51561600E+00, 0.76621100E-02, 0.23760500E+00, 0.21498100E+00, -.10635700E+00, -.12260300E+00, -.59914300E+00, -.28182100E+02, -.18881900E+03, -.31951500E+03, 0.14884300E+03, 0.37449900E+03, 0.15983700E+03, 0.23464000E+03, 0.19733800E+03, -.20700700E+02, 0.31545300E+02, 0.14259000E+03, 0.20394900E+03, 0.36538100E+03, 0.72003000E+01, 0.81347500E+02, -.62026300E+02, -.35845600E+01, 0.22457300E+02, 0.30632600E+02, -.14956900E+02, 0.21786500E+02, -.61419200E+02, 0.30963800E+02, 0.13258500E+03, -.74410400E+03, 0.34830500E+03, 0.42568700E+03, 0.37204800E+03, -.25708000E+00, 0.71105100E+02, 0.19754200E+03, 0.74010800E+02, 0.27690000E+03, 0.48932000E+02, 0.49475200E+03, 0.47854700E+03, -.28116500E+03, -.62023300E+03, -.23927700E+03, -.50546300E+03, -.16529100E+03, -.97745900E+02, -.32975300E+02, -.22038800E+03, -.22681600E+03, 0.78563400E+03, -.30487300E+03, 0.11054200E+03, -.78836500E+02, 0.15257900E+03, 0.25948900E+01, -.45722200E+02, 0.16992400E+03, 0.23472500E+03, 0.33132200E+03, -.68781500E+02, 0.63208300E+02, 0.11624300E+04, -.58007400E+03, -.40302400E+03, -.58093100E+03, -.23023000E+03, 0.34050900E+02, -.24928100E+03, 0.17875200E+03, -.36210500E+03, -.49946500E+02, -.68652000E+03, -.53451500E+03, 0.24164800E+03, 0.14962700E+03, 0.26639900E+03, 0.40412200E+02, -.20339200E+02, 0.22329000E+03, 0.25650600E+03, 0.42079700E+03, -.50343300E+02, 0.63355600E+02, -.16591900E+03, 0.62649700E+02, 0.85003900E+02, 0.83030200E+02, 0.41871900E+02, 0.10318600E+03, -.90004400E+02, 0.16252000E+02, 0.17630800E+03, 0.44039900E+02, -.25220900E+02, 0.52909300E+02, -.25186900E+02, 0.67451100E+02, -.26484300E+02, -.21928000E+03, 0.72471500E+02, -.21175100E+02, -.19786700E+02, 0.23303200E+02, 0.18032500E+02, 0.27291100E+03, 0.49508200E+03, -.29221900E+03, -.35390400E+03, -.24754700E+03, -.38678000E+03, -.20038000E+03, -.52178100E+02, -.12161700E+02, -.25815800E+03, -.20442300E+03, 0.30862900E+03, -.25705800E+03, 0.12453600E+03, 0.24964600E+03, 0.12852900E+03, -.96080700E+02, 0.57450300E+02, -.22825000E+02, -.56718700E+02, 0.10251700E+03, 0.49417700E+00, 0.61037600E+03, -.16368900E+03, 0.12207500E+03, 0.10097400E+03, 0.81844000E+02, 0.10654700E+03, 0.45853100E+02, -.57234400E+02, -.27865400E+02, -.35151800E+02, 0.63945300E+02, -.38796600E+03, -.30482500E+03, 0.16399700E+03, 0.36406700E+03, 0.15240300E+03, 0.90140900E+02, -.85162100E+02, 0.30133300E+02, -.18554500E+03, 0.59471100E+02, -.19853500E+02, 0.16596900E+03, 0.18655500E+02, 0.45490600E+02, -.28583600E+02, -.94373000E+01, -.17480800E+03, -.26968100E+03, 0.91317200E+02, 0.14444100E+03, 0.20595300E+03, -.26262700E+03, 0.33091900E+03, -.21620200E+01, -.22778800E+02, 0.27588200E+02, 0.23886600E+02, 0.23704600E+01, -.90578100E+01, 0.77390100E+02, -.30096900E+02, 0.22657000E+02, -.26029100E+02, -.21017600E+02, -.93257000E+00, 0.57726200E+02, 0.61774100E+01, -.27846100E+01, 0.13992300E+03, -.27261300E+02, 0.24237700E+02, 0.25907300E+02, 0.35726300E+01, -.35675500E+02, -.13993500E+03, -.33204000E+02, 0.24232700E+02, -.15906200E+02, -.92830600E+01 },
        { 0.15890500E+01, -.59595900E-01, -.18853300E+00, 0.13891100E+00, -.17931800E+00, -.29336400E+00, -.17823000E+01, 0.13713000E+01, 0.21375000E+00, 0.20924900E+01, -.34933700E+00, -.59292900E+00, -.44513500E+00, 0.14222100E+00, -.19898400E-01, 0.81922900E+01, 0.18940800E+01, 0.13069500E+01, -.16273300E+01, 0.45098000E-01, 0.39903800E+00, -.15453500E+00, -.47737800E-01, 0.13795300E+00, -.69235600E-01, 0.20671400E-01, 0.39357300E-02, 0.77853500E+00, -.62982200E+00, 0.29674400E-01, -.10343700E+00, -.36835400E+00, 0.10475400E-01, 0.10896000E+01, 0.13571500E-01, 0.29791700E-01, 0.18447000E-01, -.41688200E-01, 0.58513200E-01, -.66613800E-01, 0.13067400E+01, -.86395100E-01, -.24078600E-01, -.98161900E-01, -.18567700E+00, 0.10277600E-01, -.25098100E-01, -.15609700E-01, -.14014700E+01, -.61049200E-01, -.34937500E+00, -.55688500E-01, -.35192200E-01, -.20493800E+01, -.13189100E+00, 0.55829500E-01, -.17887500E+00, -.90770100E-01, -.13628600E-01, 0.77173700E-02, 0.13829200E+00, -.15022000E+00, 0.45374900E-01, -.97224600E-01, 0.13375700E-01, -.25553800E+00, -.12533000E+01, -.53775800E-01, 0.55708400E+00, 0.28112900E-03, 0.16139600E-01, 0.66455700E+00, 0.70049200E+00, 0.16312700E+01, -.37305300E+00, -.90780600E-01, -.15815400E+00, 0.82547000E+00, -.30548800E+00, -.98500400E-01, 0.32315200E-01, 0.35704100E-02, -.16925900E+00, -.60459300E+00, 0.11492800E+00, 0.33182500E+00, -.31678200E+00, 0.22216800E-03, -.46265300E+00, -.83678100E-01, -.39347300E+00, -.15688500E-02, 0.95205900E-01, 0.56989900E-01, -.42100500E+00, 0.12174500E+00, -.59150600E-01, 0.48825200E+00, -.93297800E-01, 0.58387800E+00, -.12303500E+00, 0.81235400E-01, -.90371200E-02, -.84508300E-01, 0.22258400E+00, 0.11626200E+01, -.53866500E-01, 0.59890800E+00, 0.72861500E-02, 0.23954400E-01, 0.27265300E+00, 0.46586400E-02, -.14083500E+00, 0.15566200E-01, -.14076300E+00, 0.32772200E-01, 0.41085900E-01, -.75831300E-01, 0.70089500E+00, 0.36879000E+00, 0.50188800E+03, 0.62203700E+03, -.29552600E+03, -.83221900E+03, -.31052000E+03, -.43602900E+03, -.34570500E+03, -.43222400E+02, -.10137600E+03, -.19939000E+03, -.36168300E+03, -.56665500E+03, -.21332500E+03, -.19944100E+02, 0.18294700E+03, 0.10652700E+03, 0.10430400E+03, 0.23755000E+02, 0.34923500E+02, 0.13073700E+02, 0.17756600E+03, 0.12930200E+02, -.26642300E+03, 0.10197800E+04, -.48162400E+03, -.15698700E+04, -.50931200E+03, -.73864300E+02, -.10491700E+03, -.27212000E+03, -.14792200E+03, -.42415900E+03, -.70805200E+02, -.13373000E+03, -.12496100E+04, 0.69013200E+03, 0.10569100E+04, 0.62473600E+03, 0.69852800E+03, 0.22760100E+03, 0.30881600E+03, 0.86520800E+02, 0.48791500E+03, 0.28122600E+03, 0.13527300E+03, 0.59796500E+03, -.23947500E+03, 0.15746900E+03, -.29918300E+03, 0.34929100E+02, 0.14088700E+03, -.33805900E+03, -.42566000E+03, -.61571300E+03, 0.16607400E+03, -.11763400E+03, -.16450700E+04, 0.82094000E+03, 0.56676600E+03, 0.82204200E+03, 0.40844200E+03, 0.19217200E+02, 0.37670300E+03, -.15262200E+03, 0.38513300E+03, 0.16990800E+03, 0.12455300E+04, 0.10347900E+04, -.48033900E+03, -.33942100E+03, -.51745900E+03, -.54790500E+02, 0.73530000E+02, -.40074300E+03, -.38966600E+03, -.74988800E+03, 0.10457100E+03, -.95886600E+02, -.76343100E+02, 0.68179600E+02, -.49383100E+02, 0.37344200E+02, -.60834900E+02, -.10563500E+03, 0.14777800E+03, 0.55055600E+02, -.22395000E+03, -.63655400E+02, 0.18134200E+03, -.24942200E+02, 0.83030700E+01, -.85881100E+03, 0.14436900E+02, 0.20878800E+03, -.21000200E+03, 0.67454800E+02, 0.44039800E+02, 0.83148500E+01, -.17025800E+03, 0.54186500E+02, -.97305100E+03, 0.55673100E+03, 0.63579800E+03, 0.48642900E+03, 0.54878900E+03, 0.27772100E+03, 0.14410900E+03, 0.53011100E+02, 0.51857100E+03, 0.27227700E+03, 0.46399800E+03, 0.62229400E+03, -.30395800E+03, -.76567500E+03, -.31117600E+03, 0.37898000E+02, -.11219200E+03, -.79438600E+01, 0.13443900E+03, -.25307800E+03, -.28622200E+02, -.46588500E+03, 0.39411200E+03, -.25995400E+03, 0.50634400E+03, -.19607100E+03, -.17600600E+02, 0.12317200E+02, -.46367600E+02, 0.23237500E+02, -.66160100E+02, 0.34133200E+02, -.19443700E+03, 0.45693300E+03, -.24560900E+03, -.49357100E+03, -.22875400E+03, -.15552600E+03, 0.15712600E+03, -.10472200E+03, 0.18412100E+03, -.48782600E+02, 0.79718100E+02, -.39757000E+03, -.39616900E+02, -.67640300E+02, 0.49472400E+03, 0.21572700E+02, 0.22772100E+03, 0.44225500E+03, -.12675400E+03, -.11724600E+03, -.30997700E+03, 0.43809700E+03, -.52657700E+03, 0.12733600E+02, 0.38824500E+02, -.59980100E+02, -.54389000E+02, -.73702000E+01, 0.13866800E+02, -.14717000E+03, 0.25421600E+02, -.40807600E+02, 0.38566300E+02, 0.36076400E+02, 0.13840500E+02, -.91824400E+02, -.21597800E+02, -.18285400E+02, -.13149500E+03, 0.59029600E+02, -.60774400E+02, -.53206700E+02, -.78097900E+01, 0.85913300E+02, 0.13999000E+03, -.76322100E+02, -.42094500E+02, 0.19971700E+02, 0.96261500E+01 },
        { -.14048700E+02, -.43855700E+01, 0.41975100E+01, 0.33756900E+01, 0.87911100E+01, 0.59136300E+01, 0.35806400E+01, 0.17968600E+02, -.11806100E+01, 0.44207500E+01, 0.31870000E+01, 0.47081900E-01, 0.10404600E+01, -.90828000E+00, -.17526700E+01, 0.54405000E+01, -.26627100E+01, -.33214500E+01, 0.23282400E+01, 0.24120100E+01, 0.45170600E+01, -.55092700E+00, 0.45092800E-01, 0.78639600E+00, -.46496900E+00, -.13744300E+01, -.12350800E+01, -.17215500E+01, 0.14292200E+01, -.12161300E-02, -.12945400E+01, -.22868500E+01, 0.32858800E+00, 0.38588000E+01, -.56385800E-01, -.16983600E+00, -.99512700E-02, 0.67534800E+00, -.12080200E+00, 0.14551700E+01, 0.55912800E+01, -.40104000E+00, -.41311700E+00, -.93306400E-01, 0.33459400E+00, 0.80377800E-01, -.70659900E-01, -.97911700E-02, 0.26200800E+01, 0.20740700E+00, 0.29014500E+00, -.96678000E+00, 0.99821700E+00, 0.41807000E-02, 0.71687000E-01, -.28970500E+01, -.45654700E+00, -.21866600E+00, -.62212300E-01, 0.64228600E-01, -.48526700E+00, 0.51980000E+00, -.52877700E+00, 0.39325600E+00, 0.19373800E+00, 0.80383200E+00, 0.14691200E+01, 0.18846800E+00, -.12056800E+01, 0.17046800E-01, -.71288800E-01, -.38833300E+01, -.80904400E+00, -.42210800E+01, 0.73393700E+00, 0.44960100E-01, 0.15248600E+00, -.55490300E+00, 0.32118000E+00, -.10038300E+00, -.93073700E+00, 0.15825800E+00, 0.41770200E+00, -.66258800E+00, -.70452600E+00, 0.49573200E+00, 0.10770100E+01, 0.15691100E+00, 0.17387800E+01, 0.93590500E-01, -.21922600E+00, 0.44843800E+00, 0.67301800E+00, 0.39000000E+00, -.18756600E+01, -.19461300E+01, -.87943500E+00, -.10560800E+01, -.25569200E+00, 0.10193200E-01, -.11613000E-01, -.10569000E+01, -.33568900E+00, 0.10917700E+01, 0.23309100E+00, 0.75804500E+01, 0.95437800E-01, 0.31236100E+00, 0.21350400E+00, -.68038400E+00, 0.71725100E+00, 0.11107700E+00, 0.26178100E+01, 0.62806400E+00, -.20023500E+01, -.20865200E+01, 0.82613300E+00, 0.71650800E+00, -.47248000E+01, -.96503400E+00, -.35736000E+01, 0.32672700E+04, -.16179000E+04, -.28747500E+04, -.16626500E+04, -.50783900E+03, -.10231300E+04, 0.39399900E+03, 0.12428200E+04, 0.14287100E+04, -.11754100E+04, 0.20730700E+03, -.15128100E+04, 0.56323100E+03, 0.80232900E+03, 0.75739700E+03, 0.14094500E+03, -.24832900E+03, 0.77941100E+03, -.21936600E+03, 0.63265100E+03, -.10584700E+02, 0.41189400E+03, -.17538500E+04, 0.97132100E+03, 0.17002000E+03, 0.88300000E+03, -.83164400E+03, 0.43263700E+03, -.49301300E+03, -.77057700E+03, 0.13329500E+04, -.79902000E+02, 0.24341300E+04, 0.45372600E+04, -.21664400E+04, -.10499000E+04, -.22682800E+04, -.13456500E+04, -.19907400E+04, 0.69688700E+03, 0.94824100E+03, -.13626500E+04, -.19148400E+04, -.89881400E+03, -.94042800E+04, 0.46944200E+04, 0.51479800E+04, 0.47029200E+04, 0.12395500E+04, 0.87275900E+03, 0.19062200E+04, -.19305400E+04, 0.11796300E+04, 0.10285300E+04, 0.29427300E+04, -.44235600E+04, 0.22216900E+04, 0.15307300E+04, 0.22846200E+04, 0.25505000E+03, 0.71526400E+03, -.24105800E+03, -.19600400E+04, -.11548400E+04, 0.80262000E+03, 0.19274900E+03, -.10351200E+05, 0.51675500E+04, 0.51482700E+04, 0.51898700E+04, 0.11086600E+04, 0.68395800E+03, 0.23611100E+04, -.15342000E+04, 0.18362900E+04, 0.86678600E+03, 0.24642300E+04, 0.47208400E+03, -.19508500E+03, 0.91495800E+03, -.23083300E+03, -.59703600E+02, -.18475800E+03, 0.62723800E+03, 0.54990300E+03, 0.16202800E+02, -.22443700E+03, -.13519300E+04, -.35479700E+04, 0.17901200E+04, 0.30844600E+04, 0.17936500E+04, -.56935700E+03, 0.32600800E+03, 0.48954200E+03, -.14896300E+04, -.10587200E+04, 0.55902400E+03, 0.78635400E+03, 0.45895300E+04, -.21642600E+04, -.33740800E+04, -.22943700E+04, -.63201200E+03, -.14126600E+04, 0.20752200E+03, 0.14362500E+04, -.10023900E+04, -.13485400E+04, -.11045500E+04, 0.38143800E+03, -.19528700E+03, -.18636400E+03, -.19044800E+03, -.13518100E+04, -.14028300E+03, -.15550900E+03, -.99114100E+02, 0.34164100E+03, -.36875700E+03, 0.10661000E+04, 0.66650500E+03, -.43426100E+03, -.49059100E+03, -.34813400E+03, 0.43535200E+03, -.92442300E+02, 0.29880900E+03, -.76248900E+02, 0.30995700E+02, 0.21291100E+02, -.17437200E+04, 0.34190900E+04, -.17676300E+04, -.13155500E+04, -.17273800E+04, -.46636300E+03, -.10671100E+04, 0.62548300E+03, 0.20611100E+04, 0.95221200E+03, -.11059400E+04, -.53836900E+03, 0.13802800E+03, -.23344200E+03, 0.17472800E+04, -.34080900E+02, 0.21954200E+03, 0.19352800E+03, 0.15085400E+04, -.14133100E+03, -.16866900E+04, 0.94808100E+03, -.99211700E+03, -.45803500E+02, -.24738800E+02, 0.85025900E+02, 0.13148400E+03, -.24669500E+02, 0.26312800E+02, -.30440600E+03, -.19438600E+03, -.33887300E+02, 0.51366900E+02, 0.73993300E+02, 0.94059000E+02, 0.12346500E+03, 0.49162200E+02, -.13067700E+03, 0.38356700E+03, -.17823500E+03, 0.21499800E+03, 0.11323900E+03, 0.49295200E+02, 0.19177000E+03, -.18424400E+03, -.84332300E+03, -.15110100E+02, 0.13943800E+03, 0.11219500E+03 },
        { 0.64732000E+01, -.11903300E+01, -.27143300E+01, -.43300000E+00, -.21741200E+01, 0.26402000E+00, -.91470000E+00, 0.34179300E+01, 0.66295300E+00, 0.28849300E+00, 0.11368900E+00, -.12799400E+00, -.13032500E+01, 0.17547600E+00, 0.19053100E+00, -.70108800E+01, -.76887300E+01, -.25410700E+00, -.27754300E+01, -.11570000E+01, 0.14062900E+01, 0.12976600E+01, 0.23156000E+00, 0.16615800E+01, 0.66603000E+00, 0.96889500E-01, 0.25799600E+00, 0.27731600E+01, -.92810000E+00, 0.20756200E-01, -.59442600E+00, -.20949100E+00, 0.12159200E+01, -.45991500E+01, 0.38295300E-01, -.17839900E+00, -.10244000E+00, -.14171500E+01, -.51320000E+00, -.37832900E+00, 0.26291400E+01, -.10124400E+00, -.37920800E-01, 0.29914200E+00, 0.14511500E+00, 0.21263100E+00, -.49073300E-01, -.26971000E-02, 0.18841600E+01, 0.98448800E-01, 0.64512200E+00, 0.67587500E+00, 0.11850300E-02, -.17401000E+01, 0.35028200E+00, -.27064900E+01, -.98476100E+00, -.58041500E-01, -.57818200E-01, -.11862200E+01, -.24145300E+00, -.34835400E+00, -.77844400E+00, 0.22839300E+00, -.90437700E+00, 0.28508000E+00, 0.20061800E+01, 0.27671200E+00, 0.13149400E+01, 0.23143100E-01, 0.38735800E-01, 0.15702600E+01, -.15503000E+01, -.16153700E+01, 0.18348800E+00, -.96774600E+00, 0.15162800E+00, -.86871500E+00, -.11013100E+01, -.33790800E-01, -.10742300E+00, 0.34411800E+00, 0.16372200E+00, -.38333500E+00, -.27271000E+00, -.79692400E-01, 0.12213100E+00, 0.73564500E-02, 0.29282500E+00, 0.22156700E+00, 0.35783900E+00, 0.35564000E-02, -.74211100E+00, -.35142300E+00, -.26947600E+01, -.22391600E+01, -.30774300E+00, 0.29270000E+00, -.11530800E+00, -.11493900E+01, 0.27756700E+00, -.60739000E-01, -.54258400E-01, 0.58294300E+00, -.15764700E+00, 0.10489800E+02, 0.68395000E+00, 0.30052100E+00, 0.13849300E-01, -.89995800E+00, 0.52362100E+00, -.15225700E+00, -.16479800E+01, -.46996800E-01, 0.22246600E+00, 0.26341500E+00, 0.95952700E-01, -.54631400E-01, -.96480700E-01, 0.12363100E+01, -.43018800E+00, -.44378500E-01, 0.64016600E+02, -.21894800E+03, -.19919200E+01, -.85692900E+02, -.86080600E+02, -.17105200E+03, -.18219400E+03, -.21250300E+03, -.44474100E+02, -.61345800E+03, -.75902000E+01, -.24737000E+03, 0.72003100E+02, 0.39607600E+01, -.93664600E+02, -.53867600E+02, 0.29159000E+02, -.92549700E+02, 0.44111400E+02, -.42576400E+02, 0.70972800E+02, -.44045200E+03, 0.33936800E+03, 0.45017800E+03, 0.21986100E+03, -.32661000E+03, -.15952300E+03, -.15121500E+03, -.34448700E+03, 0.33137700E+03, -.20349800E+03, 0.19148200E+03, 0.93210800E+03, -.22538800E+03, 0.80865700E+03, -.46595100E+03, 0.20747700E+03, -.29645800E+03, -.59341700E+02, 0.36568100E+03, -.37245100E+03, -.25510100E+03, -.15591600E+04, 0.10462300E+04, -.39919900E+03, -.22902900E+03, -.52318600E+03, -.38650500E+02, 0.13754500E+03, -.37504500E+03, -.21680500E+03, -.55183100E+03, 0.11748300E+03, -.58458100E+02, -.19531200E+04, 0.95120900E+03, 0.47468700E+03, 0.98150000E+03, -.16540700E+03, -.53076900E+03, 0.63096100E+03, -.25860600E+03, 0.87724300E+03, -.46518000E+03, 0.15382100E+04, 0.11476200E+04, -.50783200E+03, -.40138000E+03, -.57278300E+03, -.79535400E+02, 0.64674000E+02, -.44668000E+03, -.27633000E+03, -.62705700E+03, 0.59523000E+02, 0.53669600E+01, -.17481000E+03, 0.14993800E+03, 0.94354300E+02, 0.88423200E+02, 0.78106100E+02, -.48569600E+02, 0.69424300E+02, -.80429000E+02, -.13786500E+03, -.20654500E+02, 0.65597800E-01, 0.83894000E+03, -.41633900E+03, 0.24552600E+03, -.42072000E+03, 0.26416600E+03, -.88668800E+02, 0.86332100E+02, 0.48532500E+03, 0.27543300E+02, -.12337800E+03, -.72174200E+03, 0.76820900E+03, -.21066900E+03, -.45072600E+02, -.38396500E+03, 0.15643800E+03, -.16857800E+03, -.10658400E+03, 0.33688800E+03, -.19839200E+03, -.19999900E+03, -.93179700E+03, -.32759100E+03, 0.18164100E+03, 0.34723400E+03, 0.16384000E+03, 0.89208700E+02, -.56732000E+01, 0.59028500E+02, 0.30664900E+02, 0.16984600E+03, -.37906000E+02, -.42239400E+03, -.71369800E+03, 0.19728500E+03, -.39133000E+03, 0.35508900E+03, 0.17786000E+03, 0.27963300E+03, 0.14744100E+03, -.32660200E+03, -.20694200E+02, 0.24612200E+03, 0.79751700E+03, 0.14326000E+03, -.89115400E+02, -.20975000E+03, -.72085900E+02, 0.20033800E+03, 0.41440700E+03, -.94590100E+02, 0.22210500E+03, -.21531800E+03, 0.38858300E+03, -.25601100E+03, 0.36763200E+03, -.36359900E+03, -.15222000E+03, -.18402600E+03, 0.19646000E+03, 0.42710000E+03, -.92391300E+02, 0.22781800E+03, -.96674500E+02, 0.30881600E+03, 0.54460500E+03, 0.25457100E+02, -.11942200E+02, -.26985500E+02, -.20800000E+02, 0.20384900E+02, -.20114400E+01, -.90216100E+02, 0.18520500E+03, -.43811300E+01, -.15677500E+01, -.22493400E+02, 0.31619300E+02, -.10139200E+03, -.20801000E+02, 0.15106200E+03, 0.55849800E+02, 0.17642900E+02, -.34286100E+02, -.11624700E+02, -.10022900E+02, -.31769400E+02, -.24862800E+02, -.35872100E+03, 0.70486700E+02, 0.13718700E+02, 0.19955400E+02 },
        { -.38330900E+01, -.18410700E+01, -.35238200E+01, -.17301100E+01, 0.13690000E+01, 0.14469600E+01, 0.92779900E+00, 0.19814000E+01, -.27304300E-01, 0.64878000E+00, 0.83002000E+00, 0.48314800E+00, 0.12753100E+00, -.11912100E+00, -.67455900E+00, 0.94067000E+01, -.21220300E+01, 0.49750600E+00, 0.22153300E+01, 0.78165600E+00, -.15051300E+01, 0.10182900E+00, 0.12863600E+00, 0.41785200E+00, -.90691400E+00, -.79847500E-01, 0.62854500E+00, 0.35551400E+01, 0.64930800E+00, -.18654000E+00, -.71470300E+00, 0.23269900E+01, 0.25758600E+00, -.66260300E+01, 0.34686000E-01, -.26497200E+00, -.11791200E+00, -.12390000E+01, -.62454400E-01, -.83640100E+00, -.29439200E+00, -.15861700E+00, 0.19203900E+00, 0.23930100E+00, -.30197800E+00, 0.28582200E-02, 0.42073800E-01, -.66946700E-01, -.37904800E+00, 0.22369000E+00, -.15110500E+01, 0.20373500E+00, -.46774900E+00, 0.45255100E+00, -.25847700E+00, 0.24234200E+01, 0.91596100E+00, -.19673700E+00, -.10482800E-01, -.47254600E-01, 0.26918300E-01, -.17943500E+00, 0.51326400E+00, -.73651700E+00, 0.22216900E+00, -.43074100E+00, -.82296900E+00, 0.29462600E+00, 0.40514400E+00, -.20976400E-01, -.13451700E-01, 0.24108700E+01, 0.16022800E+01, 0.57054000E+01, -.81024000E+00, -.70892800E+00, -.29146700E+00, 0.15894300E+01, -.62714300E+00, -.28547500E+00, 0.20935400E+00, 0.66375000E-01, -.34623300E+00, -.61742300E+00, 0.27293500E+00, 0.93862100E-01, 0.63153300E-01, 0.18761200E+00, 0.35859600E+00, -.11789500E+00, 0.43685700E+00, 0.90365100E-02, -.54163600E+00, -.22449500E+00, -.92047200E+00, -.39424600E+00, 0.11206900E+00, 0.30701700E+00, -.21165300E+00, -.37569400E+00, -.45478100E-01, -.46889800E-01, 0.21495500E-01, 0.29092900E+00, 0.53327500E-01, 0.26449500E+01, 0.20817500E+00, 0.46993200E+00, -.31103500E+00, -.10469900E+01, -.13398300E-01, 0.60351900E-01, -.91881900E+00, -.25086800E-01, -.15800400E+00, -.17175700E+00, 0.97427200E-01, -.13802600E+00, 0.92780900E+00, -.26776100E+01, -.11264800E+01, 0.92137300E-01, -.57837700E-01, 0.71865900E+03, 0.33021800E+01, -.19872900E+03, 0.51019000E+03, -.86020300E+03, -.12681200E+04, -.96468400E+03, 0.48999000E+03, -.66523800E+03, 0.34754500E+03, -.11008900E+03, 0.10391300E+03, -.17394800E+03, 0.14091300E+03, 0.18814400E+03, -.21721800E+03, 0.33744800E+02, -.58673000E+02, 0.93450200E+02, -.45135400E+02, 0.72108800E+03, -.38611200E+03, -.24002300E+04, -.36054500E+03, -.17077200E+02, -.26771400E+03, 0.21933500E+03, 0.18765100E+03, -.48096300E+03, -.14107600E+03, 0.29359800E+02, -.30797700E+04, 0.15358600E+04, 0.18923400E+04, 0.15397800E+04, 0.58823800E+03, 0.78110500E+03, 0.14982100E+03, -.57117000E+03, 0.77860200E+03, 0.59130000E+03, 0.20865100E+04, 0.25264000E+04, -.12841000E+04, -.96027900E+03, -.12631700E+04, -.67240000E+02, 0.26116300E+03, -.79210100E+03, 0.30431000E+03, -.83250600E+03, 0.19805800E+03, -.44898300E+03, 0.42428000E+03, -.22191900E+03, -.22205200E+03, -.21644600E+03, 0.91118100E+02, -.24476400E+03, 0.42681500E+03, 0.73427000E+03, 0.47830700E+03, -.20188800E+03, 0.11550200E+04, 0.25668600E+04, -.12883100E+04, -.11816700E+04, -.12889400E+04, -.43909800E+02, 0.34875100E+03, -.98469100E+03, 0.62296500E+02, -.10104300E+04, 0.25560200E+03, -.12280300E+03, -.12375500E+04, 0.60007600E+03, 0.88597300E+02, 0.61771700E+03, 0.28828400E+02, 0.15965400E+03, -.21815000E+03, -.42401900E+03, -.60572400E+02, 0.10769100E+03, 0.33621800E+03, 0.15277400E+04, -.77118500E+03, -.25495100E+04, -.76381400E+03, 0.12769600E+03, -.21959900E+03, -.14248300E+03, 0.55508500E+03, 0.23998900E+03, -.33064700E+03, 0.19540400E+03, -.26079800E+04, 0.12798800E+04, 0.18126300E+04, 0.13038500E+04, 0.31988300E+03, 0.55303500E+03, 0.11177400E+03, -.53931300E+03, 0.74510300E+03, 0.42059100E+03, 0.18967800E+04, 0.50561600E+03, -.23966500E+03, -.15822100E+04, -.25286000E+03, 0.33115600E+03, -.54830200E+02, -.51313500E+02, -.22666000E+02, -.47453100E+03, -.82957500E+01, 0.18011300E+03, 0.24831500E+03, -.10779700E+03, 0.11300200E+04, -.12188400E+03, 0.26047500E+03, -.40245500E+02, -.17047600E+03, 0.36830400E+02, -.32753800E+03, 0.81973200E+02, -.59499000E+03, -.62322000E+03, 0.33779100E+03, 0.55729400E+03, 0.31289900E+03, 0.98247400E+02, 0.31297300E+03, -.26331900E+03, -.55798000E+03, -.38019700E+03, 0.33915500E+03, -.10667900E+03, -.99196000E+03, 0.54211500E+03, -.74728400E+03, 0.49422900E+03, 0.13555000E+03, -.36077300E+03, 0.79070500E+02, 0.75680400E+03, 0.95495200E+03, -.53516800E+03, 0.28913900E+04, -.86231900E+02, -.44050900E+02, -.57048100E+02, -.62888400E+02, -.28934300E+02, 0.17407000E+02, 0.68606100E+02, 0.10838500E+03, 0.30188800E+02, -.54920100E+02, -.65774000E+02, -.35494600E+02, -.45185100E+02, 0.94543400E+01, 0.68281000E+02, 0.17817600E+00, 0.54422700E+02, -.16036100E+03, -.19403900E+02, 0.26634800E+02, 0.60089000E+01, -.10103000E+03, -.70074800E+02, 0.30880800E+02, -.38392800E+02, -.82735300E+00 },
        { -.10408400E+02, -.32972000E+01, 0.27576800E+01, 0.30448100E+01, 0.51874700E+01, 0.38719800E+01, 0.31180100E+01, 0.36716300E+01, -.72773100E+00, -.12791900E+00, 0.18667600E+01, 0.79657500E+00, 0.13891500E+01, -.29121900E+00, -.35199500E+00, 0.26683100E+01, 0.42051100E+01, -.72308200E-01, 0.79511400E+00, 0.93491600E+00, 0.13408300E+01, 0.22618200E+00, 0.44871200E+00, 0.33314200E+01, 0.81857100E-01, -.71850600E+00, -.26136300E+00, 0.21235300E+01, 0.85086100E+00, -.19488300E+00, -.45446500E+00, -.50569400E+00, -.39911300E-03, -.30099000E+01, -.83750900E-01, -.11067000E+00, -.51093500E+00, 0.15234100E+01, -.52712500E+00, 0.14162600E+01, 0.98143500E+00, 0.57606400E-01, -.23120500E+00, 0.58625500E+00, -.15976600E+00, -.45691800E+00, 0.56798900E-01, -.42014600E+00, -.23728700E+00, -.66661300E-01, -.10159100E+01, -.86371600E+00, 0.12072200E+01, -.31241200E+01, -.10254800E+01, 0.99416500E+00, -.15754300E+00, -.31041300E+00, 0.54832200E+00, -.75335600E+00, -.30339800E+00, 0.16129500E+01, 0.62251800E-02, 0.39177300E+00, 0.10270300E+01, 0.30828200E-01, 0.81556800E+00, -.90879800E-01, -.20912000E+01, -.31518000E-01, 0.22669200E-01, -.16242700E+01, -.21625200E+01, -.17474700E+01, 0.10558000E+01, -.19930100E+01, 0.67770600E-01, 0.17328400E+01, 0.45957300E+00, 0.34145800E+00, 0.20443200E+00, 0.41565600E+00, -.17524000E+00, -.12116600E+01, -.31925400E+00, 0.92249900E-01, -.51794100E+00, 0.29361200E+00, -.14391900E+01, -.23454400E+00, -.27192600E+01, 0.84872700E-01, -.23640900E+00, 0.32367600E-01, 0.60174200E+00, -.31980700E+00, 0.80606000E-01, 0.80768700E+00, -.39685100E+00, 0.17658700E+00, -.92952700E-01, -.37096500E+00, -.12061800E-01, -.14316700E+00, 0.17807800E+00, 0.40066100E+01, -.26944700E+00, 0.33088600E+00, 0.22050400E-01, -.11760700E+01, -.73790800E+00, 0.95209000E-01, 0.22637200E+01, 0.55410500E-01, -.17755000E+01, -.11199000E+01, 0.16915900E+00, 0.58646700E+00, 0.93552000E+00, -.62757200E+01, -.22318000E+01, 0.23056400E+00, -.74812100E+00, 0.55439400E+00, 0.36645900E+02, 0.26038200E+03, 0.32611900E+03, -.46464000E+03, -.61229800E+03, -.10349700E+03, 0.45674500E+03, 0.48799800E+03, 0.85498500E+02, -.19105500E+02, -.35098400E+03, -.51488000E+02, -.24211900E+03, -.19817700E+03, 0.33959700E+02, -.25183500E+03, -.63425400E+02, -.96487200E+02, 0.10545500E+03, -.10002900E+03, 0.50555200E+02, -.15186400E+01, 0.53769400E+02, -.92397300E+03, 0.67255800E+02, -.49388200E+03, -.34312400E+03, 0.14583300E+03, -.94825300E+02, 0.14651300E+04, 0.80360000E+03, -.36322500E+03, -.16339900E+04, -.40040700E+03, -.16708100E+04, -.70051700E+03, -.68015100E+03, -.53419500E+03, -.74932800E+03, -.87658600E+03, 0.28693700E+04, 0.30542500E+03, -.14303500E+03, -.15733500E+04, -.15914200E+03, -.22383600E+03, -.39494200E+03, 0.27268600E+03, 0.23912800E+03, 0.41633000E+03, -.40862400E+03, 0.33238300E+03, 0.35830700E+02, -.26761600E+02, -.18876700E+03, -.10553100E+02, -.57672400E+03, -.16790600E+03, 0.15258500E+03, 0.12413300E+03, 0.29287600E+03, -.46346900E+03, 0.19743800E+03, -.10255500E+03, 0.32717300E+02, -.94385300E+03, 0.71969600E+02, -.16656500E+03, -.29767500E+03, 0.24417700E+03, 0.23326000E+02, 0.40153800E+03, -.29492700E+03, 0.29326500E+03, 0.10147900E+04, -.55592200E+03, -.14349500E+03, -.46780400E+03, 0.32270700E+03, 0.26314200E+03, -.39565500E+03, -.53504400E+02, -.20495500E+03, 0.57126300E+02, -.61053900E+03, -.12177100E+04, 0.61836200E+03, 0.13999300E+04, 0.61228500E+03, -.61306100E+03, -.78559800E+02, 0.66622900E+03, 0.27530000E+03, 0.43219200E+03, -.68890400E+02, 0.14794500E+04, 0.14554100E+04, -.71230200E+03, -.15719500E+04, -.72626500E+03, -.12924300E+04, -.75197500E+03, -.46597300E+03, -.42301400E+02, -.64300200E+03, -.78512500E+03, 0.12164900E+04, -.26049800E+03, 0.11888900E+03, 0.52687100E+03, 0.12994200E+03, -.84686200E+03, 0.74277600E+02, -.27966300E+03, -.21381100E+03, 0.44171200E+02, -.14073200E+03, 0.19099900E+04, -.72767400E+03, 0.34643100E+03, 0.75028300E+03, 0.36838100E+03, 0.72765800E+03, 0.25482600E+03, 0.33564800E+03, -.24555300E+03, 0.17954600E+03, 0.29933800E+03, -.15147800E+04, 0.65619700E+03, -.32886600E+03, -.33607600E+03, -.33038700E+03, 0.20814200E+03, -.51223600E+01, -.18794400E+03, 0.20127400E+03, -.31287400E+03, 0.12379100E+03, -.52352400E+03, -.16082100E+02, -.23864000E+02, 0.51147100E+03, -.27542500E+02, 0.22576400E+03, -.24888000E+03, 0.61404600E+03, 0.52144200E+03, 0.25307500E+03, -.24446100E+03, 0.81293400E+03, -.67350400E+02, -.97578500E+02, 0.86345000E+02, 0.99936200E+02, -.69420500E+01, -.28536800E+01, 0.17139900E+02, 0.97169000E+02, 0.63532600E+02, -.84486000E+02, -.76137300E+02, 0.33247900E+02, 0.43401300E+02, 0.38735400E+02, 0.90318200E+02, 0.63546300E+03, -.95860500E+02, -.57966400E+02, 0.98831000E+02, 0.26496500E+02, 0.14051900E+01, -.60377400E+03, -.17828100E+03, 0.13470800E+03, 0.15994200E+02, 0.45001400E+02 },
        { -.26593600E+01, 0.26650400E+00, 0.75129600E+00, 0.68266900E+00, 0.19816200E+01, 0.60398700E+00, 0.18183400E+00, 0.26936500E+01, -.30022600E+00, 0.10043800E+01, 0.55546900E+00, 0.16798600E+00, 0.48844200E+00, -.18344600E+00, -.68666500E-01, -.24174700E+01, -.44968800E+00, -.33815600E+00, -.10139100E-02, 0.41651000E-01, -.69937500E-01, -.30536600E-01, -.45749800E-01, 0.22160100E+00, -.28840300E-01, 0.46379600E-01, 0.91817300E+00, -.34343200E+00, -.19717700E+01, 0.65978300E-01, 0.10844700E+00, 0.78682200E+00, 0.30821500E+00, -.11640600E+01, -.96283300E-02, -.24572100E-01, 0.12862700E-01, 0.34256500E+00, -.60089400E-01, -.20716100E+00, 0.23380400E+01, 0.38767200E-01, -.17566400E-01, 0.77062100E-01, -.19729600E+00, -.56252200E+00, 0.60519100E-01, -.41406500E-01, -.59769000E+00, -.58049500E-01, -.24548600E+00, 0.77840000E+00, 0.46985100E+00, 0.84060100E+00, -.71029800E-01, 0.51803900E+00, -.26538700E-01, -.25984000E+00, -.57347600E-01, -.49806800E+00, 0.19827400E+00, -.12401200E+01, 0.58245400E+00, -.28898400E+00, 0.47935900E+00, 0.25147100E+00, 0.10140100E+01, 0.10147600E+00, 0.11977100E+01, 0.15126200E-02, -.19828200E-01, 0.38277100E+01, 0.21951900E+00, 0.35854200E+00, -.10440300E+01, -.81952700E+00, 0.28111200E-01, -.81168200E+00, -.77395800E+00, 0.11331200E+00, 0.60890400E-01, -.68294000E-02, -.33105300E+00, 0.51591100E+00, 0.98523400E-01, 0.26049300E-01, -.14868500E+00, 0.26685900E+00, -.66646400E+00, 0.14621000E+00, -.67707000E+00, -.12367900E-02, -.32596600E+00, -.11970100E+00, 0.12617700E+01, -.16356300E+00, 0.49608900E+00, -.23138900E+00, -.11521200E+00, -.32117800E+00, 0.12268300E+00, 0.50586300E-01, 0.15323300E-01, -.28883500E+00, 0.16155500E+00, 0.20009400E+01, -.41991000E+00, 0.27161500E+00, 0.15809500E+00, 0.87858400E-01, -.17814200E+00, 0.53775200E-02, 0.52314500E+00, 0.20902100E-01, 0.34450100E-01, -.39095800E+00, -.17804500E+00, 0.40469800E+00, -.12245700E+01, -.46911000E+00, -.16572500E+00, -.22218100E-01, -.14144100E+00, 0.25955000E+00, -.55417300E-01, 0.48115000E+03, 0.56795500E+02, 0.20397900E+03, 0.23735300E+03, 0.22527600E+03, 0.14091900E+03, 0.24111300E+03, 0.62464100E+02, -.32596100E+02, -.14308200E+03, -.31549400E+02, -.19566200E+03, -.13543500E+03, 0.88953000E+02, -.92575900E+02, -.80766300E+02, -.50813100E+02, 0.19208100E+03, -.19407400E+04, 0.98039300E+03, 0.15094800E+04, 0.97035100E+03, -.52588500E+03, 0.11749300E+03, 0.26567000E+03, -.11008400E+03, 0.99607700E+03, -.77200000E+02, 0.14819000E+04, 0.46928100E+04, -.23404300E+04, -.21406900E+04, -.23462400E+04, -.18381000E+04, -.13071800E+04, -.46447100E+03, 0.24102200E+03, -.16371700E+04, -.12662600E+04, -.72172300E+03, -.22121600E+04, 0.11002100E+04, 0.34469200E+03, 0.11059100E+04, 0.16724900E+03, 0.91252200E+02, 0.60101100E+03, -.16530100E+03, 0.66161400E+03, 0.12715100E+03, 0.75744000E+03, 0.39001000E+03, -.19488300E+03, -.25641000E+03, -.19131700E+03, -.37302600E+03, 0.20187800E+03, -.30017600E+03, 0.16957200E+03, -.18727500E+03, -.24269900E+02, -.53947600E+03, -.29820600E+04, 0.14766700E+04, 0.10051400E+04, 0.14950300E+04, 0.19680100E+03, -.31559300E+02, 0.88754700E+03, -.13322800E+03, 0.90399300E+03, 0.20662900E+02, 0.47391200E+03, -.36743600E+03, 0.17568600E+03, 0.14530000E+03, 0.18690400E+03, 0.19363000E+03, -.17752900E+02, 0.31100400E+03, 0.10141500E+03, 0.19862000E+03, -.28971800E+02, -.68049500E+02, -.13052000E+04, 0.65834000E+03, 0.14452700E+04, 0.65197300E+03, -.19409100E+03, 0.21707700E+03, 0.24863600E+03, -.10789300E+03, 0.24180800E+03, 0.20616300E+03, 0.48090700E+03, 0.41679100E+04, -.20783800E+04, -.17034400E+04, -.20837600E+04, -.12827400E+04, -.10974300E+04, -.31259100E+03, 0.45104900E+03, -.15116100E+04, -.99529800E+03, -.12501600E+04, -.53909200E+03, 0.25930700E+03, 0.98573800E+03, 0.26957000E+03, -.49757100E+03, 0.26333900E+02, -.21651000E+02, -.11236300E+03, 0.42950500E+03, -.14552500E+03, 0.80432000E+03, -.48869400E+03, 0.24271800E+03, -.28157700E+03, 0.24290600E+03, 0.34948700E+03, 0.17342400E+03, 0.14130000E+03, 0.53010300E+01, 0.18441600E+03, 0.11210700E+03, -.20752400E+03, 0.11053000E+04, -.55970600E+03, -.16286300E+02, -.55342000E+03, -.85032000E+02, -.40605500E+03, 0.29524500E+02, 0.40140100E+02, -.22484700E+03, -.28821400E+03, -.54700900E+03, 0.45514600E+03, -.24168800E+03, 0.21895100E+03, -.22930500E+03, -.11157600E+03, -.53490400E+02, 0.21305800E+03, -.42705400E+01, -.12708000E+03, 0.59872900E+02, -.16472700E+03, 0.40857500E+01, -.55828000E+02, 0.15628900E+02, 0.24693700E+02, 0.28160100E+02, -.82835900E+01, -.34181300E+00, -.47137000E+01, 0.30968700E+02, -.35340100E+02, -.49248600E+02, 0.29759200E+02, 0.22308000E+02, 0.77351600E+01, 0.50798100E+02, 0.45151500E+03, -.44081500E+02, -.80813800E+02, 0.49847500E+01, -.73419700E+01, -.45955500E+02, -.31854800E+03, -.52479100E+03, 0.86491800E+02, -.59032700E+02, 0.22576700E+02 },
        { -.23457900E+01, -.46027700E+00, -.14309400E-01, 0.99060500E+00, 0.18282100E+01, 0.28409800E-01, 0.86855800E+00, -.15688900E+00, -.18907100E+00, 0.78583500E+00, 0.42190600E+00, 0.31066200E+00, 0.53130300E+00, -.78227600E-01, -.41464300E+00, 0.41814800E+01, 0.13783900E+01, 0.69293500E+00, 0.23664400E+00, -.45821600E+00, 0.15064300E+00, 0.20629400E+00, 0.69127300E-01, 0.12016800E+01, -.69906600E-01, -.64779300E-01, 0.22613400E+00, 0.14049300E+01, -.67036200E+00, 0.30074000E-01, -.14161900E-01, 0.36011400E+00, -.58503900E-01, 0.90125700E+00, 0.32945300E-01, 0.75391300E-01, 0.10917600E-01, -.36637500E-01, -.77795900E-01, -.47161400E+00, 0.10599700E+01, 0.48188000E+00, 0.29024500E-01, 0.12657300E+00, -.60105500E+00, -.19108200E-01, 0.54308200E-02, -.41918800E-01, -.11992100E+01, 0.59925200E-01, -.57265200E+00, -.11853600E+00, 0.23523800E+00, 0.48851700E+00, 0.26787200E-01, 0.12052800E+01, 0.30153200E+00, 0.58718600E-02, -.16512300E-01, -.20493400E+00, 0.15130300E+00, 0.10923000E+00, 0.47322700E-01, -.38402600E+00, -.64219700E+00, -.10658300E+00, 0.70050600E+00, 0.14806400E+00, -.86555300E-01, -.10443500E-01, 0.11955400E-01, 0.19301200E+01, 0.26195900E+00, -.10077400E+01, -.32231400E+00, -.11584000E+01, 0.73702300E-02, -.97884600E-01, -.70869600E+00, -.24722200E+00, -.16655200E-01, 0.42193500E-01, 0.25328100E+00, 0.63281800E+00, -.17928700E+00, -.10748700E+00, 0.60713700E-01, 0.95244700E-01, -.87039500E+00, 0.88252000E-01, -.56599900E+00, -.14781600E-02, -.63676400E-01, 0.12780000E-01, 0.39742300E+00, 0.82062400E-01, 0.47199700E+00, 0.65029900E-01, -.18742000E-01, 0.39803700E-01, 0.29884300E-01, 0.13300200E+00, -.16205700E-01, -.37993700E-01, -.30218600E-01, -.31663200E+00, -.12719500E+00, 0.33619700E+00, 0.13680200E-01, -.28407300E+00, 0.44178900E+00, 0.12638300E-01, -.97405600E+00, -.10235700E-01, -.15912200E+00, 0.77583700E+00, -.18042000E+00, 0.24692500E+00, 0.61889600E+00, -.82002700E+00, 0.47647300E+00, -.42140000E-01, -.12305500E+00, 0.13720000E+00, -.74779200E-01, 0.37283000E+00, 0.40046900E+03, -.23438100E+03, -.22670100E+03, -.54433500E+02, 0.36123900E+03, 0.38754600E+03, -.37607900E+03, 0.19953500E+03, -.10177800E+03, 0.18776900E+03, -.56928000E+02, -.99806800E+02, 0.12584700E+03, -.10143200E+03, 0.96217800E+02, -.47052100E+02, 0.15319800E+03, 0.77292700E+02, -.34710700E+02, 0.54757700E+02, -.38982000E+02, -.31683600E+03, -.32767800E+02, -.19785200E+03, -.15640800E+03, 0.54242600E+02, -.12085700E+03, 0.63470000E+03, 0.20810900E+04, -.10506200E+04, -.18962800E+04, -.10403500E+04, -.70102200E+03, -.39478300E+03, -.54504600E+03, 0.12726300E+02, -.62989400E+03, -.43250600E+03, 0.54754800E+03, 0.15135500E+04, -.73821700E+03, -.82060600E+03, -.75705500E+03, -.13617400E+03, -.37481500E+02, -.34503000E+03, 0.10064600E+03, -.41599600E+03, -.41681900E+02, -.32962100E+03, 0.17217600E+03, -.88270700E+02, -.14014400E+03, -.81586800E+02, -.74725700E+01, -.31089200E+03, 0.23891600E+03, 0.30315500E+03, 0.10979000E+03, -.34700200E+03, -.33224900E+03, 0.15689200E+04, -.77397500E+03, -.68164100E+03, -.78229600E+03, -.11805900E+03, 0.35172900E+02, -.41382700E+03, -.74750000E+02, -.57572200E+03, 0.27766600E+02, -.23269000E+03, 0.94984500E+03, -.47923100E+03, 0.10152100E+02, -.47154300E+03, -.15480600E+02, 0.11347300E+03, -.31297000E+03, -.18680500E+03, -.36256300E+03, 0.70445600E+02, -.21996500E+03, 0.12721500E+03, -.62980200E+02, 0.25847400E+03, -.65270700E+02, 0.62501000E+02, 0.40296200E+02, 0.19439700E+03, 0.32117000E+03, 0.73533500E+02, 0.46207400E+01, -.77182600E+02, 0.13884700E+04, -.70884800E+03, -.13562200E+04, -.69399900E+03, -.49845900E+03, -.29180000E+03, -.37151500E+03, -.15705500E+02, -.51695100E+03, -.31179400E+03, 0.19792300E+03, 0.49556200E+03, -.25154600E+03, -.31871000E+02, -.24774700E+03, -.24079000E+03, -.78988500E+02, -.11422400E+03, 0.12875300E+03, -.28913900E+02, -.16427800E+03, 0.33512500E+03, -.26598100E+03, 0.14544800E+03, 0.31012100E+03, 0.13128000E+03, 0.16553900E+03, -.24254000E+02, 0.18114300E+03, -.33819900E+02, 0.26273700E+02, -.12234000E+02, -.58174400E+03, -.58834400E+03, 0.29764300E+03, 0.24232700E+02, 0.29373200E+03, -.26747600E+02, 0.14748300E+03, 0.58910100E+02, -.14112800E+03, 0.40053700E+02, 0.15312100E+03, 0.46617800E+03, -.38961800E+03, 0.20330100E+03, 0.30410300E+03, 0.19205000E+03, 0.20393200E+03, -.23679500E+03, 0.33211700E+03, 0.23871900E+03, 0.23411900E+03, -.17321600E+03, 0.17913000E+03, -.38516200E+02, -.31838300E+02, 0.43222600E+01, 0.12066300E+02, -.24304800E+02, 0.24830000E+02, 0.48646500E+02, 0.58616000E+02, 0.65469000E+01, -.24944700E+02, -.32390300E+02, -.21799400E+02, 0.57270300E+02, 0.33269200E+02, 0.39659400E+02, 0.19591300E+03, -.30054600E+01, 0.79060100E+02, 0.15019700E+02, 0.31664600E+02, -.49120500E+02, -.15750300E+03, -.16953700E+03, 0.31504700E+02, 0.39882400E+02, 0.77435900E+00 },
        { 0.80774900E+00, -.59003200E-01, -.19254200E+00, 0.18875400E-01, -.23720100E+00, -.12862800E+00, -.10339300E+01, 0.62004000E-02, 0.83952700E-01, 0.85650400E+00, -.20705500E+00, -.19190700E+00, -.23577400E+00, 0.15941100E-01, -.65801300E-01, 0.57579500E+01, -.65190700E+00, 0.15253600E+00, -.16114600E+00, -.69553000E-01, 0.22193300E+00, 0.15406300E+00, -.48216500E-01, 0.28886700E+00, -.46089100E-01, 0.18500200E-01, -.18499900E-01, 0.65074300E+00, -.91875200E+00, 0.26884000E-01, -.17393900E+00, -.24337600E+00, 0.13735900E+00, 0.23069400E+00, 0.92975400E-02, -.43543700E-01, 0.21835600E-01, -.68629700E-01, -.30041700E-01, -.28090800E-01, 0.95581800E+00, 0.24027900E-01, -.33347100E-01, 0.26408800E-01, -.35293400E-01, 0.94956200E-01, -.21771400E-01, 0.15080400E-01, -.13568400E+00, -.26106300E-01, 0.31015800E+00, 0.65360800E-01, -.80188700E-02, -.92467500E+00, 0.43504100E-01, -.62282500E+00, -.21634400E+00, -.10292700E-02, -.31396800E-02, -.11498500E+00, 0.64372200E-02, -.22427600E-01, -.16383400E+00, 0.10744000E+00, -.16771000E+00, -.89110100E-01, 0.10270200E+00, -.67279100E-02, 0.12387900E+00, 0.62921000E-02, 0.16742200E-01, 0.52651100E+00, -.46251500E+00, -.10554400E+01, 0.68434800E-01, -.21191800E-02, 0.61693600E-01, -.25131200E+00, -.35882700E-01, -.10802200E-02, -.29437400E-01, 0.25990100E-01, 0.42916300E-01, -.12180500E+00, -.51584300E-01, 0.61548200E-01, 0.15287500E+00, -.42769300E-01, -.66318400E-01, -.25406400E-01, -.45629500E-02, -.15805100E-02, -.48135600E-01, 0.16997100E-01, -.24893400E-01, -.29885300E+00, -.65204600E-01, -.56598200E-01, 0.14932300E-01, -.18169800E+00, -.28246900E-01, -.51848700E-01, -.62778000E-02, -.39921300E-01, 0.69899100E-01, 0.14446900E+01, 0.12136900E+00, 0.12839200E+00, -.11298900E-01, 0.43444900E-01, -.10068100E-01, -.52243300E-02, -.15244500E+00, 0.27026500E-02, 0.12348200E+00, 0.15146900E+00, 0.56994400E-01, -.23927900E+00, 0.34106700E+00, -.40259000E+00, 0.26322800E+00, -.44027100E-01, -.41684800E-01, -.10805200E+00, -.19945900E-01, 0.13147000E+00, 0.26367800E-02, -.17369300E+03, -.23432600E+03, -.10518500E+03, 0.38049500E+02, -.11283600E+03, -.15037000E+03, 0.85776800E+02, 0.82787400E+02, 0.75053300E+02, 0.63428000E+02, 0.71271300E+02, -.26676100E+01, 0.13453000E+02, 0.62536700E+02, 0.35482400E+02, 0.62251600E+02, 0.67561000E+03, -.34159200E+03, -.79353100E+03, -.33727100E+03, -.55121200E+02, -.73385100E+02, -.15348100E+03, -.11150800E+02, -.29870100E+03, -.45901700E+02, -.17301500E+03, -.71428500E+03, 0.35886700E+03, 0.32385000E+03, 0.35712800E+03, 0.19919200E+03, 0.14641200E+03, 0.16940800E+03, 0.84798700E+02, 0.10126700E+03, 0.14139200E+03, 0.37640400E+03, 0.17200300E+03, -.90286200E+02, 0.76442800E+02, -.86014200E+02, 0.17302200E+02, 0.34654900E+02, -.31600400E+02, 0.68518100E+01, -.57799400E+02, 0.19196100E+02, 0.30407800E+02, -.36423700E+03, 0.18052200E+03, 0.61893800E+02, 0.18433500E+03, -.17925300E+03, -.15751500E+03, 0.15812900E+03, -.10070900E+03, 0.15575800E+03, -.13391000E+03, 0.54628900E+03, 0.17007700E+02, -.11677400E+02, 0.45962800E+02, -.93798700E+01, 0.35703300E+02, 0.66438500E+02, -.43919300E+02, -.18294600E+02, -.24234900E+02, 0.43800000E+02, 0.11321800E+03, -.29088500E+03, 0.14081300E+03, 0.10282600E+03, 0.14574200E+03, 0.55678400E+02, 0.22714300E+02, 0.11050800E+02, 0.10534700E+01, 0.68404600E+02, -.17078600E+01, -.14570900E+02, 0.49021000E+03, -.24558900E+03, -.49442900E+03, -.24345100E+03, -.14961400E+03, -.15582600E+03, 0.94507500E+02, 0.22089200E+03, -.23859500E+02, -.16146600E+03, 0.42074100E+02, -.53575600E+03, 0.26586500E+03, 0.24783000E+03, 0.26784900E+03, 0.97460700E+02, 0.12623000E+03, 0.65984000E+02, -.13080400E+02, 0.10437000E+03, 0.10668200E+03, 0.38693900E+03, 0.23421200E+03, -.11488500E+03, -.41007400E+03, -.11711800E+03, 0.72787100E+01, -.18356500E+02, -.37426200E+02, 0.29181100E+02, -.16453400E+03, 0.59854800E+01, 0.56307500E+02, -.14626600E+03, 0.73687100E+02, 0.43226700E+03, 0.73289100E+02, 0.82326300E+02, 0.88191000E+02, -.74287600E+02, -.11920600E+03, -.54955600E+02, 0.94610900E+02, -.11357400E+03, 0.66306500E+02, -.30037400E+02, -.13259600E+03, -.33877600E+02, 0.16609300E+03, 0.14986800E+03, -.11652500E+03, 0.27782900E+02, -.59049100E+02, 0.15180400E+03, -.19086800E+03, 0.30529100E+02, -.12265300E+02, -.16098300E+03, -.13891000E+02, -.47860100E+02, 0.23954700E+02, 0.72032700E+02, 0.15760600E+03, 0.12511300E+03, -.61137700E+02, 0.46591100E+03, 0.30594900E+00, -.71425800E+01, -.24151100E+00, -.10064600E+01, 0.32948700E+01, -.42445500E+01, -.64385400E+01, 0.66757800E+02, 0.11390100E+02, -.11872800E+02, -.10191000E+02, 0.10998400E+02, -.13271300E+02, -.87614500E+01, 0.41358500E+02, -.23778400E+02, 0.38113800E+00, -.15012700E+02, 0.75410600E+01, 0.22220200E+00, 0.14696000E+02, -.62162900E+01, 0.35415000E+01, 0.16823000E+02, 0.79562000E+01, 0.17960600E+02 },
        { -.37204900E+01, 0.63558200E+00, 0.29223400E+01, 0.90110600E+00, 0.18169800E+01, 0.55553100E+00, 0.74907000E-01, -.17775500E+01, -.45627600E-01, -.33631400E+00, -.22423800E+00, 0.10216600E-01, -.31586100E-01, -.20858700E+00, 0.50118800E+00, 0.40874500E+01, -.25793300E+01, -.16972000E+01, 0.52241300E+00, 0.71835900E-01, 0.16603100E+00, -.21224600E+00, 0.61735400E-01, 0.18158300E+00, -.14031100E+00, -.11874000E+00, -.46756500E+00, -.18446000E+00, 0.31745200E+00, -.11648400E+00, -.37218300E+00, 0.11555500E+00, -.19432800E+00, -.95196900E+00, -.42495200E-01, -.11320700E+00, 0.64980600E-01, 0.60009000E-01, -.43705700E-02, 0.60955100E+00, -.67280400E-01, -.15312500E+00, -.15448600E+00, -.79226600E-01, -.32626800E+00, 0.34804300E+00, -.57686800E-01, 0.41603600E-01, 0.26951300E+00, -.19634600E-01, 0.39674700E+00, 0.19899700E+00, 0.21195900E+00, -.15353200E+01, 0.29516400E-01, -.40607600E+00, -.14309000E+00, -.64417300E-01, 0.28202500E-01, -.37510100E+00, 0.17299000E-01, 0.68596900E+00, -.15783300E+00, -.22342700E+00, -.72645800E+00, -.15042100E+00, 0.50097300E+00, 0.23071900E+00, 0.43815000E+00, -.11718600E-01, -.17782300E-01, 0.41478300E+01, 0.18007000E+00, -.26089600E+01, -.43846000E+00, -.11039500E+00, 0.55532100E-01, -.63670100E+00, -.40852200E+00, -.67122200E-01, -.31809100E-01, 0.23347000E-01, 0.23924400E+00, -.19406300E+00, -.30308500E+00, -.28935600E-01, 0.67479900E-01, 0.12339100E+00, 0.45936900E-01, -.21643800E-01, -.39085900E+00, 0.25736600E-02, 0.27903500E+00, -.73005400E-01, 0.14380000E+00, 0.39134400E+00, 0.35299000E+00, 0.18830300E+00, 0.89769900E-01, 0.53241200E+00, -.11182500E+00, 0.34284000E-01, 0.21461700E-01, -.67198000E-01, 0.36257700E+00, 0.52500000E+01, -.49659000E+00, 0.70454500E+00, 0.35126000E-01, -.36832000E+00, 0.50442800E+00, -.20837000E-02, 0.56532300E+00, 0.18857200E-01, 0.14750000E+00, 0.12531900E+01, 0.37764600E-01, -.40184400E+00, -.17590900E-01, -.56062100E+00, 0.41968800E+00, -.77333600E-01, -.29430200E+00, 0.23359900E+00, -.81681600E-01, 0.26841400E+00, -.51058600E+00, 0.14209800E+01, 0.32651600E+03, 0.22163800E+03, -.53062600E+02, 0.33616000E+03, -.32655900E+03, 0.21962500E+03, -.71913300E+02, 0.16275200E+03, -.57636800E+02, -.82079300E+02, 0.83648800E+02, -.34172100E+02, 0.54724800E+02, -.25238300E+02, 0.16555000E+03, -.20645600E+03, 0.10621500E+03, -.34596200E+03, 0.10354000E+03, 0.62110000E+02, 0.41393100E+02, -.24495400E+03, -.45093300E+03, 0.62442900E+02, 0.21256800E+02, -.19247900E+02, -.54787500E+03, 0.27009100E+03, -.11110400E+04, 0.27413900E+03, -.12688300E+03, -.82376300E+02, -.14267900E+03, -.17027800E+03, 0.34587400E+03, -.20651600E+03, 0.37718800E+03, -.95573600E+03, 0.45583400E+03, -.34083500E+03, 0.47711400E+03, 0.63501000E+02, -.29378100E+01, 0.22798000E+03, 0.58923800E+02, 0.44039900E+03, -.40183100E+02, 0.26219200E+03, -.22732400E+03, 0.11130600E+03, -.24396900E+03, 0.12130000E+03, -.29830400E+03, -.32431300E+03, 0.30009600E+03, -.18631800E+03, -.78665300E+01, -.26001300E+03, -.46504900E+03, -.41779600E+03, 0.19385300E+03, -.27403500E+03, 0.21179700E+03, -.46457400E+02, -.14633800E+03, 0.24470100E+03, 0.13089000E+03, 0.36727700E+03, -.15855800E+03, 0.27429300E+02, 0.88164900E+03, -.44761100E+03, -.11014200E+03, -.43692600E+03, 0.29899700E+02, 0.86684100E+02, -.24116000E+03, 0.42804100E+02, -.12340300E+03, 0.10454300E+02, -.13860000E+03, -.19667100E+03, 0.10246300E+03, -.92095600E+02, 0.98651600E+02, -.15364000E+03, -.19272200E+02, 0.38604700E+03, 0.29791600E+03, 0.16561300E+03, -.77554000E+02, 0.46334300E+02, -.53253100E+03, 0.24058000E+03, -.70819000E+03, 0.26650300E+03, -.90807500E+02, -.15380400E+03, 0.13661300E+02, -.74720900E+02, 0.28890500E+03, -.20656100E+03, 0.23439400E+02, -.80327800E+02, 0.39451500E+02, -.24991700E+03, 0.40184700E+02, -.11664900E+02, 0.37126600E+02, -.29721000E+02, 0.46032000E+02, 0.13610800E+03, -.16872200E+02, -.15339200E+03, 0.13129900E+03, -.45491200E+02, 0.85421900E+03, -.67217300E+02, 0.55609300E+02, -.28107200E+02, 0.10857100E+03, 0.63224600E+02, -.21795800E+03, 0.94507700E+02, -.43363900E+03, -.44714200E+03, 0.23261400E+03, 0.96070700E+02, 0.22227500E+03, 0.24326200E+03, 0.25988400E+03, -.77984500E+02, 0.10247900E+03, 0.28250200E+03, 0.20817300E+03, 0.35957800E+03, -.22177400E+03, 0.14187400E+03, -.57598000E+01, 0.10971800E+03, 0.35535500E+03, 0.16140400E+03, 0.16001100E+03, -.11313100E+02, 0.13836600E+02, 0.16624400E+03, -.10956100E+04, -.38174200E+02, 0.42433400E+01, 0.65516000E+02, 0.72211000E+02, 0.10857200E+01, -.23644400E+02, -.25224600E+02, 0.30544000E+02, 0.66292900E-01, -.10557100E+01, -.34317500E+01, 0.68684100E+01, 0.10424600E+02, 0.43483300E+01, 0.13485600E+02, 0.21955100E+03, -.82049300E+02, 0.63416200E+02, 0.65628600E+02, -.16001100E+02, -.37242900E+02, -.24244900E+03, -.98347400E+02, -.81495200E+01, 0.31986500E+02, 0.43192400E+02 },
        { -.47762000E+01, -.16077600E+01, 0.14650500E+00, 0.25555400E+01, 0.10941500E+01, 0.10154300E+01, 0.14417900E+01, -.26765500E+01, -.18316700E+00, 0.17151000E+00, 0.77506100E-01, 0.64535600E+00, 0.30369500E+00, -.14728100E+00, -.68052700E+00, 0.99435500E+01, -.32214500E+00, -.88491000E+00, 0.14434600E+01, -.28190200E+00, 0.91172300E+00, 0.29324900E+00, 0.18715700E+00, 0.26589600E+01, -.65455300E-01, 0.10099700E-01, 0.25319400E+00, 0.22397100E+01, -.28857800E+00, 0.58040800E-01, -.98408400E+00, 0.10872400E+00, 0.32063800E+00, -.36568300E+01, 0.21373600E-01, -.22029500E+00, -.70377800E-01, 0.97266100E+00, -.18931300E+00, 0.26098200E+00, -.18967900E+00, 0.12228400E+00, -.11118700E+00, 0.13233400E+00, -.11385200E+01, 0.10919000E+00, -.68198500E-01, -.13969000E+00, -.19295600E+01, 0.12386200E+00, -.25766700E+00, 0.10269000E+00, -.63760000E+00, 0.61791500E+00, 0.27197800E+00, -.70187400E+00, -.39323700E+00, 0.31876600E-01, -.18313100E+00, -.48703400E+00, 0.43179500E+00, -.50587300E+00, -.53663800E+00, 0.77747500E-01, -.10284200E+01, 0.58903700E+00, 0.13181500E+01, 0.23604500E+00, -.12156100E+01, -.72139200E-03, -.68357700E-01, -.13054100E+01, -.25331300E+01, -.40740000E+01, 0.19541900E+01, -.17521500E+00, -.78059000E-01, -.83450300E+00, 0.44721100E+00, -.10269400E+00, -.19749000E+00, 0.66428700E-01, 0.16923400E+00, 0.33957700E+00, -.69445700E+00, -.50695300E+00, 0.11304600E-01, -.83681600E-01, -.49791700E+00, -.87337200E-01, 0.47516400E+00, -.11939700E-01, 0.18025100E+00, -.12873900E+00, 0.39971000E+00, 0.67271000E+00, 0.58000800E+00, 0.55769100E+00, 0.27664800E+00, 0.88177800E-01, 0.64619100E-02, 0.34551000E+00, -.54969900E-01, 0.11128700E+00, -.24178100E+00, -.42245800E-01, -.57253300E+00, -.80630800E+00, 0.23470400E+00, 0.79741500E+00, 0.64657100E+00, -.99253100E-01, 0.11446800E+01, -.39382300E-01, -.40241400E-01, 0.72097400E+00, -.11217700E+00, -.90969900E+00, -.99020000E-02, -.67465200E+00, 0.81112200E+00, -.25531000E-01, -.33588300E+00, 0.80636300E-02, -.44671400E-01, -.75134700E-01, -.94943400E+00, -.18081000E+01, 0.10565900E+01, 0.61743600E+03, 0.11617900E+03, 0.59657600E+03, -.11754000E+04, 0.65608900E+03, -.30948300E+02, 0.58745000E+03, 0.54793100E+02, -.12270400E+03, 0.28990300E+03, -.88618500E+02, 0.36034500E+03, -.99871100E+02, 0.23616000E+03, 0.30929100E+04, -.15768100E+04, -.19763700E+04, -.15460800E+04, -.40081700E+03, -.19759100E+03, -.30461600E+03, 0.85763000E+03, -.11402700E+04, -.18442700E+03, 0.30483800E+03, -.31153400E+03, 0.14740300E+03, -.21137400E+04, 0.15585400E+03, -.66544100E+03, 0.29868200E+03, -.22513000E+03, -.18222500E+03, -.47937200E+03, 0.27158000E+03, 0.32213100E+04, 0.15496600E+04, -.77431100E+03, -.10232900E+04, -.77479000E+03, -.21054600E+03, -.17189200E+03, -.22681400E+03, 0.81821600E+02, -.24079200E+03, -.20875600E+03, -.20636800E+03, 0.26395700E+03, -.14416400E+03, 0.15610600E+03, -.12868400E+03, -.37790000E+03, 0.36727800E+02, -.54747600E+02, -.60269400E+02, -.45709100E+03, -.12054400E+03, -.15582600E+03, 0.12874100E+04, -.65062800E+03, -.68404700E+03, -.64384000E+03, -.12472500E+03, -.29546900E+02, -.26316600E+03, -.83444500E+02, -.34550300E+03, -.68590100E+02, -.11506400E+03, 0.12674400E+04, -.66395700E+03, -.12192700E+03, -.63146000E+03, 0.79410200E+02, 0.16512900E+03, -.31505500E+03, 0.18006600E+02, -.35787100E+03, 0.25108500E+01, -.61984000E+03, 0.67479900E+03, -.34483200E+03, -.58837800E+03, -.33660400E+03, -.24993900E+03, -.16639300E+03, 0.13948200E+03, 0.21022500E+02, -.52654900E+03, -.76098200E+02, 0.17782500E+03, 0.56909900E+03, -.31088500E+03, -.12613600E+04, -.28445600E+03, -.61557400E+03, 0.10797300E+03, -.33087200E+03, -.44990600E+01, -.44625000E+03, 0.11251100E+03, 0.18666500E+04, 0.12254300E+04, -.61101000E+03, -.72431900E+03, -.61270700E+03, -.40118500E+03, -.17454600E+03, -.22187500E+03, 0.39929800E+02, -.76528400E+03, -.17437200E+03, 0.98569800E+03, -.10752100E+04, 0.55732500E+03, 0.16393400E+04, 0.53676600E+03, 0.24038400E+03, -.11607300E+02, -.51181100E+02, -.36886100E+03, 0.24660300E+03, -.81756900E+02, -.14347500E+04, 0.82088300E+02, -.17326000E+02, -.58622300E+03, -.42101500E+02, 0.18392400E+03, -.24918300E+02, -.51863600E+02, 0.81037300E+02, 0.15002700E+03, 0.51195500E+02, -.34151900E+02, -.19660200E+03, 0.12446000E+03, 0.38279500E+02, 0.98157300E+02, -.37231700E+02, -.47637600E+03, 0.62100400E+03, 0.25239800E+03, 0.13803500E+03, -.51183500E+03, -.10087800E+03, -.47819900E+02, -.61820300E+02, -.20336500E+02, -.10864700E+02, -.30396200E+02, 0.11487800E+02, 0.81331100E+02, 0.10417700E+03, 0.42039900E+02, -.60442100E+02, -.42678300E+02, 0.16973400E+02, 0.12278400E+03, 0.19512100E+02, 0.54563300E+02, -.10103500E+02, 0.20191700E+02, 0.79554500E+02, -.98714800E+01, 0.27366800E+02, -.24742900E+01, -.56413000E+02, 0.15880300E+03, 0.37937700E+02, 0.48699600E+02, 0.36667500E+02 },
        { -.23129100E+01, -.55460900E+00, -.11459100E+00, 0.91374800E+00, 0.16848900E+01, 0.29342700E+00, 0.94601200E+00, 0.45862400E+00, -.20681200E+00, -.10074500E+01, 0.73257600E+00, 0.35733000E+00, 0.86858300E+00, 0.69555300E-01, -.32576400E+00, 0.91224000E+01, 0.30854200E+01, 0.13801700E+01, 0.11811500E+01, -.44527600E+00, -.61361200E+00, 0.30064600E+00, -.20773600E-01, 0.15934700E+01, -.76964900E-01, -.88200600E-01, 0.49567400E-01, 0.13449700E+01, -.10758900E+01, 0.10992900E+00, -.24272300E+00, -.15891900E+00, 0.33006000E+00, 0.24829200E+01, 0.24694700E-01, -.23357900E-01, 0.76443700E-01, -.25081500E+00, -.18042300E+00, -.56769300E+00, 0.13269100E+01, 0.73968600E+00, -.34600200E-01, 0.33496600E+00, -.58780700E+00, 0.39358500E+00, -.26981400E-01, 0.46479800E-01, 0.16729000E-01, 0.10278600E+00, 0.20088900E+00, -.28918500E+00, 0.55559900E+00, 0.41997800E+00, 0.22507200E+00, 0.27069100E+00, 0.30088700E+00, -.32229100E-02, 0.36804800E-01, -.16088900E+00, 0.85023500E-01, 0.47469600E+00, 0.13840900E+00, -.43643700E+00, -.73134800E+00, -.46975600E+00, 0.15350500E+00, 0.11205300E+00, 0.52489600E+00, -.11714800E-01, 0.48728300E-01, 0.36839500E+01, 0.77902400E+00, -.64012800E-01, -.61453600E+00, -.43245500E+00, -.18039400E+00, 0.68909700E-01, -.83237900E+00, -.16952200E+00, 0.60629400E-01, -.45598400E-02, 0.10279600E+00, 0.61173900E+00, -.68376600E-01, -.26674900E+00, 0.33974100E+00, 0.21374400E+00, -.47676800E+00, 0.49778500E-01, -.39781300E+00, -.83205700E-03, -.11930300E+00, -.88546800E-01, 0.61567400E+00, 0.66036700E+00, 0.29375300E+00, -.10157900E+00, -.12670700E-01, 0.16096100E+00, -.22586500E-01, 0.13416200E+00, -.15145200E-01, -.16943700E+00, -.34158100E-01, -.64769100E+00, 0.11200800E+00, 0.25430100E+00, -.14760700E+00, -.52190400E+00, 0.25157200E+00, -.10943300E-01, -.10960100E+01, -.23294800E-01, -.87091500E-01, 0.62897700E+00, -.38028500E-01, -.11601100E+00, 0.14012400E+01, -.12131600E+01, 0.65992700E+00, -.12305800E+00, -.10105200E+00, 0.76999000E-01, -.12300200E+00, 0.31749300E+00, 0.71256800E+00, 0.63006700E+00, -.22736200E+00, -.67431900E-02, 0.10665700E+03, 0.11807000E+03, -.23914500E+03, 0.13338800E+03, -.22080300E+02, 0.11904700E+03, -.61180300E+02, -.11056100E+03, 0.97874300E+02, -.68254400E+02, 0.67575100E+02, -.72909900E+02, 0.72429500E+02, 0.63970800E+03, -.32249200E+03, -.16785400E+03, -.31928900E+03, -.62353200E+02, -.21834400E+02, -.20702900E+03, -.53878100E+02, -.34813200E+03, -.40386200E+02, -.24591900E+03, -.61041400E+03, 0.30179700E+03, -.53301100E+03, 0.30538100E+03, 0.27520700E+02, 0.21989600E+03, -.18946800E+03, -.29780600E+03, -.33296200E+02, 0.17137900E+03, 0.48770700E+03, 0.28753200E+03, -.14152400E+03, -.29776900E+03, -.14424400E+03, -.65942300E+02, -.52543500E+02, -.54552800E+02, -.43900900E+02, -.33091500E+02, -.59149700E+02, 0.27308600E+02, -.34968700E+03, 0.17336500E+03, 0.78186700E+02, 0.18260400E+03, -.11644200E+03, -.60559000E+02, 0.84314300E+02, -.18262600E+03, 0.14774100E+03, -.14393100E+03, 0.70356500E+02, 0.27840700E+03, -.13981500E+03, -.19599000E+03, -.13692800E+03, -.69964500E+02, -.73657800E+02, -.29238000E+02, -.80305600E+02, -.74389700E+02, -.64184800E+02, -.19570000E+02, 0.55702400E+03, -.28380900E+03, -.93712100E+02, -.27466600E+03, 0.19558500E+02, 0.16094300E+02, -.68575200E+02, 0.57859800E+02, -.90329100E+02, -.17756100E+02, -.12623300E+03, -.37208200E+03, 0.18614200E+03, 0.42143300E+03, 0.18717400E+03, 0.48124200E+02, -.55326800E+01, 0.17186000E+03, 0.39744500E+02, 0.64842700E+02, 0.15222800E+02, 0.15957300E+03, -.68772900E+03, 0.33523400E+03, -.38007700E+03, 0.34406100E+03, -.11240400E+02, 0.13994400E+03, -.69859200E+02, -.24197300E+03, 0.58047100E+02, 0.92508200E+02, 0.34085500E+03, 0.73006400E+02, -.36334900E+02, -.23023100E+02, -.36489400E+02, 0.21821800E+01, 0.17263100E+02, -.37467700E+02, -.44673700E+02, -.16810800E+03, 0.76172500E+01, 0.32484400E+02, -.13657500E+03, 0.73546400E+02, 0.29362900E+03, 0.66870100E+02, -.54108100E+02, -.59432600E+02, 0.11967500E+03, -.56970200E+02, 0.74934300E+02, -.52157000E+02, -.14554400E+03, 0.19178400E+03, -.92287200E+02, -.35727300E+03, -.97515900E+02, 0.42183600E+02, 0.32979300E+02, -.30818600E+02, 0.15048200E+03, -.63569900E+02, 0.58334800E+02, -.12352200E+03, -.23210000E+03, 0.12045300E+03, 0.74606200E+02, 0.11563400E+03, 0.22372000E+03, 0.37170300E+02, 0.16443700E+03, 0.62480800E+02, 0.15108400E+03, 0.33176900E+02, -.60496200E+02, -.44814600E+02, -.62169000E+01, -.17732500E+02, -.92932800E+01, -.11774800E+02, 0.13082800E+02, -.24983000E+02, 0.31824600E+02, 0.30332700E+01, -.34065500E+01, -.70366000E+00, -.36438400E+01, -.10300000E+02, 0.14296300E+02, 0.15253500E+02, -.37433500E+02, 0.11488900E+02, 0.24556300E+01, -.14969400E+02, 0.12834600E+02, -.31655900E+01, -.21055500E+02, 0.20180700E+03, -.29476600E+00, 0.13592500E+02, 0.30303800E+02 },
        { 0.52407500E+01, 0.24280300E+01, -.24437100E+00, -.34952600E+01, -.25536500E+00, -.15237900E+01, -.25897400E+01, 0.13716800E+02, 0.40995600E+00, 0.27975900E+01, 0.24782100E+01, -.32458400E-01, 0.55298900E+00, 0.42188100E+00, 0.30890400E+00, 0.15748700E+01, 0.59903400E+01, 0.35625200E+01, -.11807400E+01, -.29508300E+00, -.37685400E+01, 0.50386400E+00, -.68113900E-01, 0.19424600E+01, 0.10981200E+00, 0.25585000E-01, 0.48586500E+00, 0.37208500E+01, -.27789900E+01, -.13424600E+00, 0.16101500E+01, 0.23345900E+01, -.55863900E+00, 0.38363400E+01, 0.93172200E-01, 0.28058500E+00, -.75445300E-01, -.34033000E+01, -.47996500E-01, -.13280500E+01, -.26774900E+01, 0.56823100E+00, 0.23705600E+00, 0.53032100E+00, 0.48059000E+00, 0.13511600E+00, -.68332600E-01, 0.10556600E+00, 0.51332700E+01, 0.98550700E-01, 0.10874900E+01, -.16936200E+00, 0.12857900E+01, -.12164700E+01, 0.64333000E+00, -.12459300E+01, -.44751600E+00, 0.69947000E-01, 0.11403100E+00, -.17101700E+01, 0.46509500E-01, -.10328100E+01, -.26665000E+00, 0.12323500E+01, 0.13893400E+01, 0.50834800E+00, 0.69573200E+00, -.25925000E-01, -.52787500E+00, -.72423700E-02, 0.11122000E+00, -.12604700E+01, -.26912500E+01, -.50272900E+01, 0.10100800E+01, 0.10452800E+01, -.32565400E+00, -.46999100E+00, 0.49535100E+00, 0.14419000E+00, 0.50079100E-01, -.59250500E-01, 0.12360600E+00, -.95163900E-01, -.97076300E-01, -.30266400E+00, 0.33869400E+00, 0.36809100E+00, -.20315400E+00, -.18681900E+00, -.10003600E+01, -.73732400E-02, 0.13934400E-01, 0.22951400E+00, -.83408900E+00, -.11791200E+01, -.46067800E+00, 0.70054600E+00, -.25288800E+00, -.40451800E+00, -.96887400E-01, -.31004300E+00, -.23300700E-01, 0.34705500E+00, 0.63253400E-01, 0.46266400E+01, 0.53805900E+00, -.55338100E+00, 0.17666400E+00, 0.13167700E+01, -.70628900E+00, 0.13817800E-01, 0.29988600E+01, 0.56760600E-02, -.11355000E+00, -.21235200E+00, 0.16494300E-01, -.13207300E+00, -.99140500E+00, 0.18041300E+01, 0.49931300E+00, 0.35790100E-01, -.58398800E-01, -.29256800E+00, 0.48249300E-01, 0.38767600E-02, -.12027400E+01, 0.24883300E+01, -.68750900E+00, 0.37525900E+00, -.12714400E+01, -.60746300E+03, -.67415500E+02, 0.10411500E+03, -.33329300E+03, 0.33087700E+02, -.40100300E+03, -.41052700E+03, 0.20538800E+03, -.26904400E+03, -.89520700E+02, -.19182700E+03, 0.16254200E+03, -.22719600E+04, 0.11715700E+04, 0.20829300E+04, 0.11346500E+04, -.73654000E+03, 0.13882900E+02, -.78561200E+02, -.72369600E+03, 0.11248500E+04, -.19990500E+03, 0.17983500E+04, 0.42248000E+04, -.21389900E+04, -.36854900E+04, -.21119100E+04, -.16381600E+04, -.10590200E+04, -.13306000E+04, -.50588600E+03, -.11306200E+04, -.13474000E+04, -.75491200E+03, -.96483000E+02, 0.22924000E+02, -.12333400E+04, 0.46901100E+02, -.11090300E+02, 0.96645800E+02, -.14771000E+03, -.19590300E+02, 0.34415300E+02, 0.74769700E+02, 0.14077000E+03, -.77331800E+03, 0.38516300E+03, -.34116100E+02, 0.39396500E+03, -.10547900E+02, -.43169500E+02, 0.40606800E+03, 0.19243600E+03, 0.41256700E+03, -.16544200E+03, 0.99283900E+03, 0.14756400E+04, -.75398800E+03, -.11729700E+04, -.73010300E+03, -.30718100E+03, -.26675300E+03, -.19450500E+03, 0.76362200E+02, -.27989400E+03, -.26782500E+03, -.29670300E+03, 0.18232900E+04, -.91889700E+03, 0.10866500E+03, -.90411100E+03, 0.15216600E+03, 0.20037300E+03, -.45078300E+03, -.16708900E+03, -.50314400E+03, 0.70083300E+02, -.36716200E+03, -.60735000E+03, 0.31990100E+03, 0.12277800E+04, 0.29813400E+03, 0.21849000E+03, 0.38650000E+03, 0.15547200E+03, 0.64250400E+02, 0.11470900E+02, 0.34719200E+03, 0.38645800E+03, 0.20259600E+04, -.10589000E+04, -.25298200E+04, -.10123600E+04, -.10682900E+04, -.89788500E+03, -.53902400E+03, -.21912700E+03, -.66756700E+03, -.10229700E+04, -.55960200E+03, -.55754400E+03, 0.26930200E+03, 0.63748300E+03, 0.27886400E+03, -.31569700E+03, 0.52500000E+02, -.58583000E+02, -.82189100E+02, 0.56006200E+03, -.23101500E+03, -.11822300E+03, -.71152600E+03, 0.39404000E+03, 0.38586100E+03, 0.35168200E+03, 0.48574000E+03, -.10167200E+03, 0.80342400E+03, 0.23837800E+03, 0.14104900E+03, 0.70516600E+02, -.18854400E+03, 0.20622600E+03, -.96459000E+02, -.95085800E+02, -.10329000E+03, -.59603200E+02, -.55563900E+02, 0.82179600E+02, 0.34986100E+01, -.51061400E+02, -.70577400E+02, -.76282500E+03, -.40882400E+03, 0.25291200E+03, 0.16278300E+03, 0.19662700E+03, 0.90970300E+03, 0.17891000E+03, 0.40454500E+03, 0.12226400E+03, -.89999200E+02, 0.39592300E+03, -.16104100E+04, -.11180100E+03, -.37785500E+02, 0.90824400E+02, 0.11502300E+03, 0.21194200E+02, -.27570600E+02, -.78623700E+02, 0.87825900E+02, -.32227400E+01, -.18672600E+02, -.46847900E+02, 0.22529400E+02, -.80906000E+02, 0.26213600E+02, 0.93778200E+02, 0.68066100E+03, -.12991200E+03, -.16435200E+03, 0.98630200E+02, -.15448200E+02, -.10327000E+03, -.63218300E+03, -.49179900E+03, 0.55135400E+02, -.52230000E+02, 0.65206000E+02 },
        { -.15786800E+01, -.62745100E+00, 0.52514100E+00, 0.77671100E+00, 0.91375500E-01, 0.91005800E+00, 0.22068500E+01, -.21581500E+01, -.11513200E+00, -.14660000E+01, 0.12523500E+00, 0.40069600E+00, 0.40269000E+00, -.12985600E-02, -.26656700E+00, -.51371900E+00, 0.20409900E+01, 0.12189900E+01, -.56852600E-01, -.27819900E+00, 0.79071200E-01, 0.37146300E+00, 0.21818200E-01, 0.85778600E+00, 0.18286900E+00, -.23384400E-01, 0.59638600E-01, 0.17628900E+00, 0.13898800E+01, 0.35984200E-01, 0.19129500E-01, -.69347000E+00, 0.11327900E+00, -.31941500E+01, -.21188200E-01, -.17935800E+00, 0.77926600E-02, 0.12926900E+01, -.80328100E-01, 0.35571200E-01, 0.73951400E-01, 0.12004400E+00, -.52165600E-01, 0.10726100E+00, -.17253300E+00, -.14794200E+00, -.20509600E-02, -.24965500E-01, 0.73120300E+00, -.42761400E-01, -.13597100E+00, -.40052000E+00, 0.27852400E+00, -.61036300E+00, -.11388100E+00, 0.31304900E-01, -.21108700E+00, 0.31291600E-01, 0.79027100E-02, -.17132100E+00, -.19006600E-01, 0.16466000E+00, -.91184200E-02, -.81390700E-01, 0.92669100E-01, -.68376000E-01, 0.22654800E-02, 0.10303700E+00, -.21753400E+00, -.25363500E-02, 0.70676600E-02, 0.28761900E+00, 0.24062500E+00, 0.30920600E+00, -.43576200E-01, 0.97320300E-01, -.58577700E-01, 0.17399400E+00, 0.11900600E+00, -.13165900E-01, 0.22921700E-01, 0.43123100E-01, -.85269100E-01, -.25412900E+00, -.60719900E-01, -.35007100E-01, -.99301400E-01, 0.41913900E-01, 0.85276300E-01, -.51746100E-01, -.17636100E+00, 0.10534800E-02, 0.99207300E-01, 0.17742700E-01, -.15986600E+00, 0.40896600E+00, -.89152000E-02, 0.95036900E-01, -.24392300E-01, 0.19887700E+00, 0.21080900E-01, 0.49448300E-03, -.78776600E-02, -.39539400E-01, 0.20696400E-01, -.10405500E+01, -.23162000E-01, 0.61174500E-01, -.10282300E+00, 0.99213900E-01, -.98382100E-01, 0.15049600E-01, 0.57335500E+00, -.14445400E-01, 0.82894100E-01, -.27186300E+00, 0.38023500E-01, 0.14402100E+00, -.45510400E+00, 0.22800700E+00, -.18177200E+00, 0.17050600E-01, -.65511600E-01, 0.67717700E-01, -.79439200E-02, 0.10762800E+00, 0.18988400E+00, -.28898600E+00, -.37648900E+00, -.14983100E+00, 0.62570600E-01, -.10054100E+00, 0.39593200E+03, -.16626900E+03, -.12360900E+03, -.19817500E+03, -.64615800E+02, -.32557900E+02, -.77144500E+02, -.48445200E+02, -.18042300E+03, 0.37550000E+01, -.10761300E+03, -.18423000E+02, 0.16032500E+02, 0.15497700E+03, 0.89552400E+01, -.26182800E+02, 0.36648000E+02, -.12127300E+03, -.84408800E+02, 0.87193900E+02, -.45525700E+01, 0.14809500E+03, -.57828100E+03, 0.30177700E+03, -.13562200E+03, 0.28927700E+03, -.10147500E+03, 0.97677200E+01, 0.41359300E+01, -.13049500E+03, 0.19721300E+03, -.85252100E+02, 0.63241800E+03, -.73494400E+03, 0.33925100E+03, -.99371800E+02, 0.36716400E+03, 0.82344000E+02, 0.16224400E+02, 0.17054700E+03, -.96128600E+01, 0.20687100E+03, 0.13540000E+02, 0.24713200E+03, -.31742600E+03, 0.15639700E+03, 0.59685200E+02, 0.16114300E+03, -.62633200E+00, -.30322500E+02, 0.76534900E+02, -.13747400E+01, 0.13710900E+03, -.65201300E+02, 0.97348300E+02, -.29226000E+03, 0.12970700E+03, -.15840400E+03, 0.14892000E+03, -.56325300E+01, -.44961000E+02, 0.11379900E+03, 0.57673600E+01, 0.12119300E+03, -.43833200E+02, 0.11545000E+03, 0.45215600E+03, -.23876600E+03, -.46655600E+02, -.22381400E+03, 0.14365100E+02, 0.75830900E+02, -.19980000E+03, -.96697200E+02, -.15827300E+03, 0.28440600E+02, -.15463700E+03, 0.57473900E+02, -.22565200E+02, 0.26281700E+03, -.29957200E+02, -.91272500E+02, 0.51837400E+02, -.57627300E+02, -.96196400E+02, -.12052300E+03, 0.63742700E+02, 0.72805400E+02, -.44802500E+03, 0.22142600E+03, -.26932800E+03, 0.22418100E+03, -.89655100E+02, -.34774600E+02, 0.47694700E+02, -.59014100E+01, 0.20026700E+03, -.88307100E+02, 0.47332200E+03, -.11395200E+03, 0.56390300E+02, 0.64515700E+02, 0.56999800E+02, -.97627400E+02, 0.29422300E+02, -.34424400E+02, -.45786700E+02, 0.61606300E+02, -.16577100E+02, 0.12500800E+03, -.37586000E+02, 0.20747100E+02, 0.98533400E+02, 0.17644900E+02, 0.53370400E+02, -.37593000E+02, 0.99967600E+02, -.10663400E+02, -.43500200E+02, 0.21760600E+02, -.21871900E+03, 0.47191900E+02, -.19275400E+02, 0.30898200E+02, -.23823500E+02, 0.16584100E+02, -.16718800E+02, 0.56262100E+02, 0.11701800E+03, -.28413600E+01, -.50867900E+01, -.31478200E+02, -.12656600E+03, 0.80502200E+02, 0.64722400E+02, 0.61353600E+02, 0.13662900E+03, -.62640900E+02, 0.12722500E+03, 0.69137900E+02, -.12638800E+02, -.34924500E+02, -.15580500E+03, -.23705600E+02, -.82435100E+01, 0.59630800E+02, 0.64713200E+02, -.91995100E+01, -.75726200E+01, 0.48027000E+01, 0.89158200E+01, 0.31599900E+01, -.81891800E+01, -.29716000E+01, 0.67021700E+01, 0.27336400E+01, 0.19637900E+02, 0.78490000E+01, 0.10104400E+03, -.71631000E+02, -.24350000E+01, 0.64521100E+02, 0.26419300E+01, -.30417300E+01, -.12942400E+03, 0.81575200E+01, 0.41951700E+01, 0.61351700E+01, 0.51729700E+01 },
        { -.19360100E+01, -.86589100E-01, -.10327400E+00, -.15688900E+00, 0.16859400E+01, 0.28240100E+00, -.27449300E+00, 0.41068000E+01, -.29514900E+00, -.22861300E+00, 0.88423300E+00, 0.14539100E+00, 0.67358800E+00, -.48695900E-01, -.10042300E+00, -.45099500E+01, -.66499700E+00, -.44027700E+00, 0.54791200E-01, 0.26054000E-01, 0.95806800E-01, 0.66706800E-01, 0.98572800E-01, 0.72742200E+00, 0.84854300E-01, 0.14456100E-01, 0.38813100E+00, 0.90499300E+00, -.56199000E+00, 0.30719100E-01, 0.25573100E+00, 0.20779000E+00, 0.79666800E-01, -.11672200E+01, -.27577200E-01, 0.27974000E-01, 0.39153100E-01, -.58795700E-03, -.12473800E+00, -.71944800E-01, 0.11059100E+01, -.12752700E+00, -.18348500E-01, 0.18837000E+00, 0.28012700E+00, -.42835800E+00, 0.10215000E+00, 0.54146200E-01, 0.11626100E+01, -.19895200E-01, -.10503200E+00, 0.60805700E+00, 0.45189300E+00, 0.10070000E+01, 0.19400300E+00, 0.38502600E+00, 0.44891100E+00, 0.67250700E-01, 0.68901100E-01, -.90350300E-01, -.10504700E+00, 0.27773800E+00, 0.18832500E+00, 0.21572800E-01, -.42141500E+00, -.54190100E+00, -.46739300E-01, -.43483200E-01, -.13545800E+00, -.11382500E-01, 0.19591000E-01, -.68966600E+00, 0.28188500E+00, 0.65598100E+00, 0.15123300E+00, -.38185300E+00, 0.18835900E-01, 0.55014300E+00, 0.17707300E+00, -.39729500E-01, 0.34243700E-01, 0.36919100E-02, -.55292300E-02, 0.20446500E+00, 0.37048700E-01, -.18523000E+00, -.99321300E-01, 0.76409200E-01, 0.20340100E+00, -.39029600E-01, 0.12815700E+00, 0.62551600E-03, -.13302600E+00, -.10404800E-01, 0.40829300E+00, 0.36379300E+00, -.66973600E-01, -.89150100E-01, 0.23922200E-01, 0.33801100E+00, -.19439000E-01, 0.55062400E-01, 0.16274200E-01, -.20821600E+00, 0.12212100E+00, -.44266300E+00, -.25061200E-01, 0.41517100E+00, -.24097900E+00, -.55986000E+00, 0.34798600E+00, -.44112900E-02, 0.49492300E+00, -.10480900E-01, -.23029800E+00, 0.72726700E+00, 0.15348200E+00, -.15361800E+00, 0.21241100E+00, -.15810200E+01, -.12945700E+00, 0.18376400E-01, -.22940300E+00, -.59535200E-01, 0.21451400E-01, -.15821200E+00, -.32106600E+00, 0.91317000E+00, 0.14346200E+00, -.64752500E-01, 0.11074200E+00, -.18000300E+00, -.57190300E+00, 0.10264700E+03, -.12597700E+03, 0.50957100E-02, -.11163900E+03, -.10245600E+03, 0.42192900E+02, -.55482600E+02, -.66931000E+02, -.23521300E+02, 0.28946200E+02, -.24098200E+02, 0.12574700E+02, -.75266000E+02, 0.11092800E+02, -.26824200E+03, -.41050400E+02, -.70342800E+02, -.17173900E+02, 0.11445100E+03, -.11269400E+03, 0.73057500E+03, 0.86673100E+03, -.42501000E+03, -.15997400E+04, -.43321500E+03, -.62129500E+03, -.25471400E+03, -.36050300E+03, -.26421100E+02, -.34922900E+03, -.37770000E+03, 0.84464000E+03, -.19401300E+03, 0.34381000E+02, -.35185400E+03, 0.96911500E+02, -.19529500E+02, -.10001200E+03, 0.93145000E+02, 0.84256200E+02, 0.16397800E+03, -.10962700E+03, 0.10821300E+03, -.78198100E+02, 0.33020000E+02, -.72791300E+02, 0.38779700E+02, -.17039000E+02, 0.16932400E+02, 0.10286300E+03, 0.11231400E+03, 0.48259200E+02, -.43240800E+02, 0.11585800E+03, -.90252500E+01, -.33454000E+02, -.22524000E+03, 0.75094300E+01, -.32528700E+02, -.10559200E+03, 0.63835200E+02, 0.19533800E+02, 0.46647400E+02, -.10928700E+03, 0.57196700E+02, 0.43926000E+03, -.24817600E+03, 0.11802300E+03, -.21770100E+03, 0.75797600E+02, 0.13058400E+03, -.18581800E+03, -.10162700E+03, -.20250700E+03, 0.51089400E+02, -.11355200E+03, -.12023900E+03, 0.68861400E+02, 0.69578600E+01, 0.56722800E+02, 0.32450700E+02, 0.14032700E+03, -.45774600E+02, 0.22883800E+02, 0.11640000E+02, 0.10217200E+03, 0.30232900E+03, 0.69794100E+03, -.37059100E+03, -.11053700E+04, -.34877300E+03, -.45510400E+03, -.29588600E+03, -.15068300E+03, 0.11293500E+03, -.24944500E+03, -.33574200E+03, 0.36829400E+03, -.88025800E+02, 0.42402400E+02, -.35487700E+02, 0.44053100E+02, -.15689300E+03, 0.15609700E+02, -.74842600E+02, -.23162500E+02, 0.46748000E+02, -.86335400E+02, 0.39112300E+03, -.42544400E+03, 0.23096100E+03, 0.81856500E+03, 0.21132200E+03, 0.21235800E+03, 0.20682600E+01, 0.20044600E+03, -.50730800E+02, 0.10001300E+02, 0.70283400E+02, -.55469800E+03, 0.79263900E+02, -.23696100E+02, -.12470600E+03, -.38966600E+02, 0.57186600E-01, -.11182500E+02, -.18582300E+02, 0.18732500E+01, -.34201800E+02, 0.10010500E+02, -.18274300E+03, -.42786100E+03, 0.26203800E+03, 0.17746300E+03, 0.21015700E+03, 0.37678100E+03, 0.24501500E+02, 0.11724500E+03, 0.12269600E+03, 0.12193400E+03, 0.42373400E+02, -.29212900E+03, -.64708600E+02, -.86516600E+01, 0.48742300E+02, 0.54090700E+02, -.77281100E+01, -.16374800E+01, -.22635500E+02, 0.46437000E+02, -.37709500E+01, -.13982600E+02, -.10917400E+02, 0.67101100E+00, -.20926800E+02, 0.25006500E+02, 0.39226300E+02, 0.22642300E+03, -.55273300E+02, -.47905200E+02, 0.50337700E+02, 0.57112000E+01, -.24520100E+02, -.23512300E+03, -.12893900E+03, 0.12174100E+02, -.12255000E+02, 0.21415700E+02 },
        { -.91516200E+01, -.49185300E+01, -.89028600E+01, -.33358700E+01, 0.16069200E+01, 0.39308400E+01, 0.44536900E+01, -.85239600E+01, 0.11114300E-01, -.29963300E+01, 0.71882400E+00, 0.15478100E+01, 0.10850800E+01, -.14025700E+01, -.17169600E+01, 0.30423200E+02, -.37241100E+01, 0.19475100E+01, 0.27803800E+01, -.13275300E+01, -.12769000E+01, 0.53785600E+00, 0.60634200E-01, 0.23094200E+01, -.14831100E+00, -.41421100E-01, -.64362000E+00, 0.26001600E+01, 0.20832600E+01, -.11222700E+00, -.13406100E+01, 0.11741500E+01, -.36036100E+00, -.57236100E+01, 0.36237200E-01, -.40044000E+00, -.25927100E+00, 0.45106400E+00, -.48696500E+00, 0.44068300E+00, 0.29769800E+01, -.14339400E+01, -.98715800E-01, -.48524400E+00, -.37037300E+00, 0.86949600E+00, -.12716800E+00, -.21642900E+00, -.50351500E+00, 0.58472700E+00, -.12626000E+01, -.25717400E+01, -.13770200E+00, 0.61485000E+00, 0.12018900E+00, -.22888600E+01, -.67120100E+00, 0.87859700E-01, -.21888600E+00, 0.19408600E+01, -.10481500E-01, 0.13133600E+01, -.10635500E+01, -.10360800E+01, -.23415500E+01, -.64662200E+00, 0.52011400E+01, 0.12050000E+01, -.66220200E+00, 0.27209800E-01, -.64743300E-01, 0.27946700E+01, -.12363800E+01, -.28506900E+01, 0.55565100E+00, -.18384000E+01, 0.69400100E-01, -.86635900E+00, -.11580100E+01, -.12542300E+01, -.25962300E+00, 0.19311600E+00, 0.50461700E+00, 0.40467900E+00, -.70529600E+00, 0.50425400E+00, 0.11002400E+01, -.12372500E+00, -.10829700E+01, 0.15937200E+00, -.68503000E+00, -.25727800E-02, 0.94427400E-01, 0.50504100E+00, -.58877400E+00, 0.32689100E+00, -.73648400E+00, -.45272000E+00, 0.57817200E+00, 0.68890300E-02, -.17715700E-01, -.42098700E+00, -.49917300E-01, -.25756100E+00, -.34384100E+00, 0.10766400E+02, 0.12998800E+01, 0.38278300E+00, 0.84832600E+00, 0.21849000E+00, -.23506100E+00, -.73221900E-01, 0.41481900E+01, 0.56483200E-02, 0.80509100E+00, -.19996600E+01, -.10561700E+01, 0.13733700E+01, -.44186400E+01, 0.47977700E+01, -.11274800E+01, 0.23710200E-01, 0.33325700E+00, -.57945500E+00, -.61569300E-02, 0.10707500E+00, -.37841300E+00, -.23659600E+01, -.80096100E+00, 0.32039100E+00, -.12507300E+01, 0.28847400E+00, 0.19391300E+01, -.23259400E+00, 0.55945100E+03, -.54918900E+00, -.46104700E+01, -.66481500E+02, -.10505500E+03, -.11001800E+03, 0.16141900E+03, -.88393500E+02, 0.30652800E+02, -.26203900E+04, 0.13176100E+04, 0.19215500E+04, 0.13100200E+04, 0.28376800E+00, 0.24788300E+03, 0.43465400E+03, -.13637900E+03, 0.12760900E+04, 0.26147200E+03, 0.10151800E+03, 0.70461600E+03, -.39724200E+03, 0.33300900E+04, -.35202200E+03, 0.87277100E+02, -.41468200E+03, -.16722600E+03, -.54512000E+03, -.32000000E+02, -.39006000E+03, -.20641100E+04, -.13962800E+04, 0.72342600E+03, 0.91815600E+03, 0.69747800E+03, 0.25750500E+03, 0.21221200E+03, 0.30638400E+03, -.14517600E+02, 0.21189100E+03, 0.18617200E+03, 0.31376600E+03, 0.10588000E+04, -.52478400E+03, -.39957100E+03, -.51987300E+03, 0.39179700E+03, 0.65133000E+03, -.84815300E+02, 0.84497400E+03, -.34358800E+03, 0.49972000E+03, -.93838200E+03, -.19893500E+04, 0.10105200E+04, 0.94083800E+03, 0.99871200E+03, 0.31342800E+03, 0.27839300E+03, 0.35018400E+03, 0.13005600E+02, 0.51664100E+03, 0.23573000E+03, 0.42580000E+03, -.63674400E+03, 0.34406900E+03, 0.21248100E+03, 0.32350800E+03, -.11604700E+02, 0.13786400E+03, 0.98275900E+02, 0.11208600E+03, 0.94891900E+02, 0.61120400E+02, 0.31495600E+02, -.10294800E+04, 0.50810500E+03, 0.81480800E+03, 0.51325200E+03, 0.23924100E+03, 0.27627000E+03, -.29700000E+03, -.66060400E+03, 0.32709200E+03, 0.15897800E+03, 0.53537900E+03, 0.76060800E+03, -.40120100E+03, 0.14245300E+04, -.37995900E+03, 0.15790100E+03, -.20411700E+03, -.20739300E+03, -.25828100E+03, -.47117800E+02, -.22566400E+03, -.15003400E+04, -.12881100E+04, 0.64267700E+03, 0.62938000E+03, 0.64409700E+03, 0.42227200E+02, 0.15866400E+03, 0.14673200E+03, -.29653000E+03, 0.64439300E+03, 0.15719400E+03, 0.42286700E+02, 0.34206000E+03, -.14941000E+03, -.17914900E+04, -.17341400E+03, 0.24784000E+03, 0.14573400E+03, 0.69428700E+02, 0.27894700E+03, -.19000600E+03, 0.16037900E+03, 0.48875000E+03, 0.27502600E+03, -.14260300E+03, 0.79624300E+03, -.13851600E+03, -.39049500E+03, -.39243400E+03, -.20182500E+03, -.62047700E+03, -.72407000E+02, -.25151500E+03, 0.23028500E+03, 0.27217500E+03, -.15030700E+03, -.51721300E+03, -.13930800E+03, -.14388000E+03, 0.10669200E+03, -.43815800E+03, -.25677500E+03, -.23168600E+03, 0.10380600E+02, 0.52043400E+03, 0.41421000E+02, 0.21642600E+02, 0.73521400E+02, 0.66041800E+02, -.75248900E+01, -.92113600E+01, 0.50292200E+02, -.17910100E+03, -.19231300E+01, 0.15970700E+02, 0.21087500E+02, -.32615400E+01, 0.19783600E+02, -.41416900E+02, -.84385800E+02, 0.14440300E+03, -.79932100E+02, -.23977500E+03, 0.81206000E+02, -.28722800E+01, -.35358800E+02, -.23871800E+02, -.14260400E+03, 0.99931000E+01, -.84978300E+02, -.40193100E+02 },
        { -.61280400E+01, -.22213900E+01, 0.21500400E+01, 0.26907800E+01, 0.24651600E+01, 0.20431400E+01, 0.27737000E+01, -.38073200E+01, -.37185600E+00, -.19348100E+01, 0.52725400E+00, 0.65894300E+00, 0.10469000E+01, 0.96842200E-02, -.55408200E+00, 0.80253900E+01, 0.73980800E+01, 0.23786300E+01, 0.43335100E+00, 0.10188800E-01, 0.39675200E+00, -.11606600E+00, 0.24595600E+00, 0.17409900E+01, 0.19886300E+00, -.32163100E+00, -.41938900E+00, 0.54468900E+00, 0.13464700E+01, -.52285100E-01, -.40486600E+00, -.80373000E+00, 0.52469600E-01, -.75683800E+00, -.27349300E-01, -.95223800E-01, 0.13222400E+00, 0.83495500E+00, -.20306000E+00, 0.55662200E+00, 0.54998600E+00, -.15007000E+00, -.11997300E+00, 0.36295900E+00, -.11754200E+00, 0.86473500E-01, 0.32194400E-02, 0.99337400E-01, -.26614700E+00, -.13035200E+00, 0.24865700E+00, -.19825200E-02, 0.91777000E+00, -.23288500E+01, -.24856800E+00, 0.60461800E+00, 0.17646000E+00, -.13883500E+00, 0.11815800E+00, -.50129000E+00, -.14346700E+00, 0.12036600E+01, 0.84769200E-01, -.48516500E-01, -.25436100E+00, -.27115800E+00, -.73492200E+00, -.21151300E+00, -.10157200E+01, -.10536100E-01, 0.14270800E+00, -.18790800E+01, -.67548100E+00, -.58711400E+00, 0.62826400E+00, -.11995600E+01, -.93399900E-01, 0.19259900E+01, -.27838800E+00, -.18150100E+00, -.84940900E-02, 0.13526700E+00, 0.27981400E+00, -.26447600E+00, -.11476600E+00, 0.43143800E-01, 0.26000300E+00, 0.14179400E+00, -.20294700E-01, 0.18453000E-01, -.10228100E+01, 0.15783300E-02, 0.40488300E+00, 0.16757100E+00, 0.33322200E-01, 0.17204100E+00, 0.30331800E+00, 0.47930200E-01, -.10865400E+00, -.94928300E-01, 0.54245300E-01, -.20467300E+00, -.11804600E-01, 0.11702400E+00, 0.18505800E+00, -.29994300E+00, -.26406800E+00, 0.28782000E+00, -.13083200E+00, -.36309700E-01, -.43513300E-01, 0.32023100E-01, 0.58741200E+00, -.17219400E-01, -.21526100E+00, 0.80303800E-01, 0.21991500E+00, 0.27927300E+00, -.10528700E+01, -.73113100E+00, -.10787800E+01, 0.10676700E+00, -.15599600E-01, 0.11957000E-01, 0.91741900E-01, 0.30264200E-01, 0.25162500E+00, 0.41486700E+00, -.21521900E+00, -.22277800E+00, 0.50206500E-01, 0.31243000E-01, -.42591300E+00, -.37154600E+00, -.10103500E+00, 0.19986800E+02, -.16851900E+02, 0.15733500E+01, -.86830600E+02, -.60561100E+02, -.99583200E+01, 0.13980200E+02, -.16677300E+02, -.53987500E+03, 0.26765300E+03, -.23870400E+03, 0.26870500E+03, -.21749400E+03, -.13620500E+02, 0.45196100E+02, -.19514100E+03, 0.26965000E+03, -.20314400E+02, 0.49621900E+03, -.26596800E+03, 0.15498400E+03, 0.40331200E+03, 0.13292100E+03, -.37787800E+03, -.14593200E+03, -.10874800E+03, -.32618200E+03, 0.27110000E+02, -.27251900E+03, 0.48935600E+03, -.20173800E+03, 0.10112500E+03, -.28951400E+03, 0.10131900E+03, -.46918500E+00, -.81415100E+02, 0.11026300E+03, -.20492800E+02, 0.65331000E+02, -.78765800E+02, 0.10193800E+03, 0.40920400E+03, -.20721000E+03, -.21254000E+03, -.21055400E+03, 0.10187100E+03, 0.58150400E+02, 0.12390200E+03, 0.44997700E+03, 0.24030000E+02, -.14962100E+02, -.31476000E+03, 0.90155000E+02, -.50213600E+02, -.36668600E+03, -.43790300E+02, -.90738900E+02, -.15597100E+03, 0.58214200E+02, -.64097900E+02, 0.23262100E+02, -.13263300E+03, 0.61470800E+02, 0.52019600E+03, -.27617800E+03, -.24570200E+03, -.26241500E+03, -.64841700E+02, 0.25720800E+02, -.22412800E+03, -.20078100E+03, -.27747100E+03, 0.42511200E+01, -.10872700E+03, 0.19458400E+02, -.96510800E+01, -.43546000E+03, -.13249900E+02, -.11327600E+03, -.35992800E+01, 0.96406100E+01, 0.10040200E+03, 0.12079100E+03, -.84604500E+02, 0.12218500E+03, 0.51745500E+02, -.10125700E+02, 0.31316300E+03, -.25923500E+02, -.28711500E+03, -.20889900E+03, -.29212300E+02, -.95845900E+02, 0.27408900E+02, -.25599000E+03, 0.16035400E+03, -.40745500E+03, 0.20274000E+03, 0.27654200E+02, 0.20374300E+03, -.99286700E+02, 0.73696700E+02, -.45791500E+02, -.17246600E+03, 0.10767500E+03, 0.19107900E+02, 0.25668800E+03, -.18105100E+03, 0.77091500E+02, 0.44089900E+03, 0.90869800E+02, 0.36940500E+03, 0.14027700E+03, 0.23366300E+01, -.40362700E+02, -.10454700E+03, 0.23060800E+03, -.25647700E+03, -.17156800E+03, 0.84003000E+02, 0.38462700E+03, 0.87799700E+02, -.15785100E+02, 0.22352800E+02, -.97016700E+02, -.14398100E+03, 0.28077200E+01, 0.64516600E+02, 0.15800700E+03, -.25105800E+03, 0.10598600E+03, 0.90080200E+02, 0.12320600E+03, 0.13256400E+03, -.47912300E+02, 0.11544600E+02, 0.15905300E+03, 0.55107600E+02, -.11778800E+03, -.25981600E+03, -.33250000E+02, -.22928000E+02, 0.10883400E+03, 0.11062500E+03, -.36503100E+01, -.22164800E+02, 0.51441100E+01, 0.35325200E+02, 0.14693000E+02, -.25637000E+02, -.19103200E+02, 0.32100400E+01, 0.34697600E+01, -.10654100E+02, 0.38200800E+02, 0.26035400E+03, -.11103800E+03, -.63796800E+02, 0.10662700E+03, -.15924400E+02, -.15816400E+01, -.26014300E+03, -.11465100E+03, 0.31443000E+02, -.11896700E+02, 0.76045200E+01 },
        { 0.26940400E+01, -.41019200E+00, -.97761100E+00, -.92886500E+00, -.18848400E+01, -.66251400E+00, -.84659200E+00, -.82722600E+00, 0.16095000E+00, -.10514900E+01, -.17901000E+00, -.83599100E-02, -.28087500E+00, 0.16165600E+00, -.39219300E+00, -.84243900E+00, 0.44575300E+01, 0.38486600E+00, -.10612800E+01, -.20387700E+00, 0.13537600E+01, 0.19248000E+00, -.33337800E-01, 0.28485500E+00, 0.19834200E+00, 0.76001700E-01, -.41548500E-01, 0.44958200E+00, -.51554200E-01, 0.66425800E-01, 0.13821100E-01, -.70184700E+00, 0.25703500E+00, 0.13233400E+01, 0.30816300E-01, -.69789800E-02, -.57918200E-01, 0.78896000E-02, -.15434100E-01, -.20947200E+00, -.42320900E-01, 0.40445800E+00, 0.14812300E-01, 0.14631200E+00, -.12373100E+00, -.18025400E+00, 0.33408400E-02, -.52822500E-01, -.16780100E+00, -.10013400E+00, -.56271000E+00, -.36924700E+00, 0.12129900E+00, -.10330800E+01, -.26788200E+00, 0.17096900E+00, -.16166300E+00, -.10173700E+00, -.27532700E-01, -.36241200E+00, 0.63692800E-01, -.32057800E-02, 0.20367500E+00, -.62306600E-01, -.88717100E-01, 0.22708200E+00, -.42564900E+00, -.51168900E-01, -.16127100E+00, -.84177000E-02, -.34747900E-03, -.11380700E+01, 0.73712500E+00, 0.17425000E+01, 0.22495200E+00, 0.54371100E+00, -.19725000E+00, 0.90456900E+00, -.17642300E+00, 0.47991500E-01, 0.26789000E-02, 0.41345300E-02, 0.14564500E+00, 0.11328400E+00, 0.12161600E+00, 0.17585000E-01, -.20599800E+00, 0.21199000E+00, -.42821100E+00, -.50314200E-01, -.30942100E+00, -.50037400E-02, -.67060900E+00, 0.11731300E-01, 0.34953100E+00, 0.41000600E+00, 0.13001400E-01, 0.40187800E+00, 0.10610700E-01, 0.19280300E+00, -.50291800E-01, 0.80317600E-01, -.24918400E-01, -.66682700E-01, 0.47685600E-01, -.14521400E+01, -.21130100E+00, -.32511500E+00, 0.14600400E+00, 0.31745600E-01, 0.25410800E+00, 0.41725600E-01, -.95699500E-01, -.14373300E-01, -.62669700E+00, 0.29671300E+00, 0.23208300E-01, -.39776700E-01, 0.10049700E+01, -.10155200E+01, 0.21444100E+00, 0.78706100E-02, -.56909000E-01, 0.11144900E+00, -.39774200E-02, -.30908500E+00, 0.50507400E-01, 0.95967700E-02, 0.51899800E+00, 0.32642200E+00, -.36575300E+00, -.15411400E+00, -.76858200E+00, -.39810000E-01, -.21087200E+00, -.16905100E-01, -.14749800E+03, -.13606500E+03, 0.31080300E+02, -.98336800E+02, 0.32112900E+02, -.83276300E+02, 0.76640100E+02, -.47605400E+03, 0.25258300E+03, 0.48491900E+03, 0.23753800E+03, -.82941200E+02, 0.14441700E+03, -.11714200E+03, -.19079100E+03, 0.23888200E+03, 0.82483600E+02, -.15650400E+03, 0.54701100E+03, -.27339200E+03, -.61930500E+03, -.27328100E+03, -.15511800E+03, -.10367200E+03, -.48437200E+03, -.38183600E+03, 0.59933000E+02, -.19327400E+03, -.63591200E+03, -.81235100E+03, 0.40031800E+03, 0.11161200E+03, 0.40556600E+03, 0.10032700E+03, 0.74901400E+02, 0.10712300E+03, -.82818900E+02, 0.13969700E+03, 0.81139500E+02, 0.27740500E+03, 0.19073600E+03, -.93877500E+02, -.13322600E+03, -.91405200E+02, 0.14364700E+03, 0.20293000E+03, 0.34800400E+02, 0.10264500E+03, -.82383100E+02, 0.14346500E+03, -.21490400E+03, -.67444500E+03, 0.33144600E+03, 0.16354500E+03, 0.34157300E+03, 0.32492500E+02, 0.47964600E+01, 0.15688800E+03, -.53835700E+02, 0.17787800E+03, 0.16551800E+02, 0.17027000E+03, 0.48980400E+03, -.23961500E+03, 0.56530000E+02, -.24132900E+03, 0.75657300E+02, 0.95011500E+02, -.11009800E+03, 0.45639200E+02, -.51462400E+02, 0.54543500E+02, -.14124400E+03, -.10490600E+04, 0.52789700E+03, 0.60358300E+03, 0.52234000E+03, 0.15756500E+03, 0.10603100E+03, 0.14463300E+03, -.19475000E+03, 0.20686600E+03, 0.10461400E+03, 0.46200600E+03, 0.30060600E+03, -.15171800E+03, -.67983500E+03, -.15002300E+03, -.97329800E+02, -.78308000E+02, -.28701800E+03, -.20097000E+03, 0.52193200E+02, -.14254300E+03, -.58965100E+03, -.32262100E+02, 0.15292600E+02, -.64369700E+02, 0.16170600E+02, -.64302500E+02, 0.76872700E+01, -.30800800E+02, 0.15480600E+02, 0.19102000E+03, -.36336100E+02, -.30667800E+03, 0.48197800E+03, -.23919700E+03, -.20439500E+03, -.24284300E+03, -.60922800E+02, -.22508700E+03, 0.27496800E+03, 0.29060200E+03, 0.12122000E+02, -.17622400E+03, -.82194700E+02, 0.32276600E+02, -.20479800E+02, 0.19923700E+02, -.16383400E+02, -.14158200E+03, -.11322200E+03, -.38664500E+02, -.97379400E+02, 0.10020900E+00, -.96672900E+02, -.13010200E+03, -.26789700E+02, 0.77691500E+01, -.90904200E+02, 0.10107800E+02, 0.27528100E+03, 0.16700800E+03, -.23180200E+02, -.16321100E+03, -.93760200E+02, 0.23918500E+03, -.37488500E+03, -.16005400E+02, 0.11291600E+02, 0.32648000E+02, 0.39270200E+02, 0.75025800E+00, -.46558200E+01, -.28877500E+02, -.10479600E+03, -.85596600E+01, 0.12834500E+02, 0.14297300E+02, 0.19997200E+01, -.17141000E+02, 0.66105400E+01, -.78857000E+02, 0.87738000E+02, -.48163500E+02, -.87574300E+02, 0.38221100E+02, 0.44259600E+01, -.12129200E+02, -.79340200E+02, 0.78630600E+02, -.32876000E+02, -.28156200E+02, 0.88351800E+01 },
        { 0.49899900E+01, 0.12639600E+01, -.87362000E-01, -.11232200E+01, -.21024800E+01, -.12244800E+01, -.10770900E-01, -.54624800E+01, 0.29574800E+00, -.13296300E+01, -.10256300E+01, -.41399800E+00, -.28794700E+00, 0.20205900E+00, 0.34745200E+00, 0.55654300E+00, 0.23452800E+01, 0.25778600E+01, -.91454400E+00, -.32975700E+00, -.11981600E+01, -.83688400E-01, -.18967000E+00, -.19811800E+01, -.25853100E-01, -.90337400E-01, -.15103200E+01, -.25301400E+01, 0.23133200E+01, -.15399500E+00, 0.49779200E+00, -.70527200E+00, -.10527000E+01, 0.49991500E+01, -.11611500E-02, 0.16598600E+00, 0.25178600E-01, -.27050800E+00, 0.28210600E+00, 0.60390300E+00, -.28096400E+01, 0.48927900E+00, -.28401800E-01, -.21241300E+00, 0.50776500E+00, 0.81620900E+00, -.11763600E+00, 0.73281800E-01, 0.13478200E+01, -.22362700E+00, 0.98591400E+00, -.12909400E+01, 0.99661500E-01, -.32090100E+01, -.38189900E+00, -.18573000E+01, -.10022000E+01, 0.13516700E+00, 0.90608700E-01, 0.56857100E+00, -.36406400E+00, 0.13044700E+01, -.40619800E+00, 0.38700600E+00, 0.16851200E+00, -.43573900E+00, -.72145100E+00, -.47291000E+00, 0.11135900E+01, 0.57798100E-01, 0.21755800E+00, 0.18561300E+01, 0.10868200E+01, 0.42380600E+01, -.10520200E+01, -.23769600E-01, -.90736900E-01, 0.17078600E+01, -.76998600E+00, -.38503100E-02, 0.20832600E-01, -.54396600E-01, 0.15767000E+00, -.59656500E+00, 0.52103000E+00, 0.67005800E+00, 0.16105900E+00, -.66141500E-01, -.63736000E+00, -.87373600E-01, 0.23059500E+00, -.49879900E-02, 0.84853200E-01, -.94751700E-01, -.16167700E+00, -.89091500E+00, 0.34403300E+00, 0.63916900E+00, -.31532600E+00, 0.42171400E+00, -.13807700E+00, -.38066700E-01, -.27313200E-01, 0.29599300E-01, 0.96586200E-02, -.24949000E+01, 0.46870100E+00, 0.52887800E+00, 0.10788200E+00, -.11927300E+01, 0.30201200E+00, 0.10026500E+00, -.17060900E+01, -.15156800E-01, -.76256700E+00, -.12674800E+01, -.17186900E+00, 0.52562600E+00, 0.23929700E+01, -.29718000E+01, 0.91743100E+00, -.11688800E+00, -.27463300E+00, 0.72551500E+00, -.19955600E+00, 0.88021200E+00, 0.91575100E+00, 0.90160700E+00, 0.57235400E+00, 0.75848600E-01, 0.12110500E+01, -.61757700E-01, 0.37340200E+00, -.48479700E+00, -.19689800E+00, 0.15970400E-01, -.22944000E-03, -.13058100E+03, 0.12901600E+03, -.25055600E+02, -.24888500E+02, -.69569100E+02, 0.12886500E+03, -.14376000E+04, 0.72714400E+03, 0.30157900E+04, 0.71759100E+03, 0.30118300E+02, 0.25508200E+03, 0.30718000E+03, 0.17174500E+03, 0.62716700E+03, 0.16819500E+03, 0.30321600E+01, 0.21985400E+04, -.11001500E+04, -.63575000E+03, -.10992400E+04, -.91622500E+03, -.55116300E+03, -.10840200E+03, 0.86829800E+02, -.10174400E+04, -.39675200E+03, -.10204400E+04, -.11486300E+04, 0.54586900E+03, 0.15179900E+04, 0.57447200E+03, 0.29008400E+02, -.77301800E+02, 0.29492800E+03, -.91268300E+02, 0.35977300E+03, -.64980500E+02, 0.20632600E+03, 0.10751600E+04, -.53318400E+03, 0.83547300E+02, -.54161200E+03, 0.40116500E+03, 0.57960200E+03, -.54987700E+03, -.10865000E+03, -.46455800E+03, 0.45740100E+03, -.51476600E+03, -.10615000E+04, 0.50805800E+03, 0.13973100E+04, 0.53128700E+03, 0.92066700E+02, 0.51126900E+02, 0.20622900E+03, 0.13977300E+03, 0.53352100E+03, 0.49396100E+02, 0.29342500E+03, 0.27109200E+03, -.13008900E+03, 0.46535500E+03, -.13615600E+03, 0.17173300E+02, 0.29969800E+03, -.24808400E+03, 0.23503300E+03, 0.14685000E+03, 0.21906300E+03, -.82353600E+02, -.13865800E+04, 0.69723400E+03, 0.25968500E+04, 0.68953300E+03, -.26470500E+02, 0.45570700E+03, -.32303600E+03, -.94304500E+03, -.10757900E+03, 0.53855500E+03, 0.98446400E+03, 0.22534100E+04, -.11140400E+04, -.14274200E+04, -.11266500E+04, -.62868500E+03, -.48715300E+03, -.85171400E+02, 0.24358800E+03, -.95444300E+03, -.34473900E+03, -.10600500E+04, -.12172500E+04, 0.60100500E+03, 0.17210400E+04, 0.60865500E+03, -.19656800E+03, 0.18233100E+03, 0.63810900E+02, -.30229400E+03, 0.44005400E+03, 0.11297600E+03, 0.86228000E+03, -.32013000E+03, 0.15662300E+03, -.18593500E+04, 0.15968300E+03, 0.89484900E+02, 0.87124500E+02, 0.91564300E+02, 0.15201600E+02, 0.42407700E+03, -.76723400E+02, 0.67172100E+03, 0.42781900E+03, -.22467100E+03, -.23511600E+03, -.21229500E+03, -.45055600E+03, -.53371600E+03, 0.52691600E+02, 0.10507200E+03, 0.35044200E+02, -.51525100E+03, -.11149600E+03, -.16429400E+03, 0.72998000E+02, 0.51787200E+03, 0.79008800E+02, -.33462500E+02, 0.49741100E+02, -.14870700E+03, -.17868900E+03, -.13362000E+03, 0.16697800E+03, 0.90976100E+03, -.21765300E+02, 0.30444400E+02, -.25410900E+02, -.44786600E+02, -.19969100E+02, 0.85346200E+01, 0.10178700E+02, -.18109300E+03, -.38376200E+02, 0.43358600E+02, 0.59301600E+02, -.29628500E+02, -.84202400E+01, 0.32156500E+02, -.93214800E+02, -.20131900E+02, 0.49816500E+02, -.29849300E+02, -.33645600E+02, 0.22726200E+02, -.54001200E+02, 0.74460900E+02, 0.27410000E+03, -.12596200E+02, -.16561900E+02, -.21087500E+02 },
        { 0.10781600E+02, 0.35418100E+01, -.43045500E+01, -.83841900E+01, -.31170500E+01, -.22888000E+01, -.53190700E+01, 0.26516600E+02, 0.59389500E+00, 0.35216200E+01, 0.41068600E+01, -.19100700E+00, 0.57413900E+00, 0.82999200E+00, 0.68336700E+00, -.11478300E+02, 0.12389700E+02, 0.33090900E+01, -.31848700E+01, 0.39228000E+00, -.39391500E+01, -.11209200E+01, 0.14209600E+00, 0.25553800E+01, 0.13154200E+00, 0.91204200E-01, 0.29160300E+01, 0.66720900E+01, -.66361700E+01, -.23547900E+00, 0.24884200E+01, 0.48724100E+01, -.31039800E+00, -.13220100E+01, 0.15620700E+00, 0.56122600E+00, -.81519100E-01, -.50552400E+01, -.11193700E+00, -.20948100E+01, -.18804700E+01, -.42610400E+00, 0.41841900E+00, 0.73827500E-01, 0.16689500E+00, 0.12691600E+01, -.11773800E+00, 0.11811800E+00, 0.68931400E+01, 0.34340500E+00, 0.13865300E+01, 0.21490700E+01, 0.63309100E+00, -.44946500E+00, 0.73305200E+00, -.17209400E+01, 0.47724300E+00, 0.10957500E+00, 0.10349100E+00, -.12369600E+00, -.43351200E+00, -.19654900E+00, 0.64022200E+00, 0.11718700E+01, -.11002300E+00, -.24369200E+01, -.51810100E+00, -.63149900E-01, 0.31168800E+01, 0.40399700E-01, 0.11493600E+00, 0.68601500E+01, 0.43347200E-01, 0.64815200E+01, -.17481600E+01, 0.55819600E+00, -.40316800E+00, 0.15832500E+01, -.10130600E+01, 0.85890500E-01, 0.27269400E+00, -.29415800E+00, -.68305900E+00, 0.94710500E+00, 0.85140600E+00, -.24020300E-01, 0.82469000E+00, 0.40483900E+00, -.33430000E+00, -.16193500E-01, 0.23985600E+00, -.60624900E-02, -.47495600E+00, 0.97390400E-01, 0.32815300E+01, 0.72675000E+00, 0.44340200E+00, -.14381300E+00, 0.42060600E+00, 0.42681200E+00, 0.14313300E-01, 0.50775800E+00, 0.13475400E+00, 0.14251100E+00, -.61178300E+00, -.41981000E+00, 0.80598000E+00, 0.50544600E-02, -.34042200E+00, -.12494100E+00, 0.17320000E+01, -.61013100E-01, 0.32074900E+01, 0.60029500E-01, -.11628200E+01, 0.12843600E+01, -.11565900E+00, -.32938200E+00, -.19891400E+01, -.28807600E+01, 0.16750400E+01, -.20874200E+00, -.80702800E+00, 0.12755500E+01, -.28342300E+00, 0.22551000E+01, -.11920500E+01, -.15424300E+00, 0.31486000E+01, 0.15689300E+01, -.28306100E+00, 0.79203500E+00, 0.20124300E+01, -.11569300E+01, 0.11706200E+01, 0.89082100E-01, -.36462000E+01, -.42480300E+00, 0.27808200E+03, 0.13127400E+03, -.69595500E+02, 0.42248400E+02, 0.73343000E+02, 0.10527100E+04, -.49314100E+03, 0.31164500E+04, -.52648200E+03, 0.23606300E+03, 0.20037200E+03, 0.13597400E+03, 0.76436200E+03, -.54636700E+03, 0.38025800E+02, -.25913900E+04, 0.15835000E+04, -.73510400E+03, -.29263400E+04, -.79205500E+03, 0.92932300E+03, 0.50116700E+03, -.24249400E+03, 0.48819600E+03, -.73512900E+03, 0.73228100E+03, -.27243900E+04, -.92608400E+03, 0.31834000E+03, 0.38850900E+04, 0.46389300E+03, -.24257500E+03, -.60617000E+03, 0.36004400E+03, -.18549800E+03, 0.45932600E+03, -.40606300E+03, -.35657900E+03, 0.23862400E+04, -.11813200E+04, -.27484000E+03, -.12033900E+04, 0.73072900E+03, 0.75063400E+03, -.10704100E+04, -.12159700E+04, -.14573400E+04, 0.73212200E+03, -.80175100E+03, -.15599800E+04, 0.69440500E+03, 0.33790100E+04, 0.77739200E+03, 0.33917700E+02, -.29909800E+03, 0.56612100E+03, 0.26347500E+03, 0.74677800E+03, -.15170400E+03, 0.27839300E+03, -.44935800E+03, 0.22743000E+03, 0.91181500E+03, 0.21893800E+03, -.44978100E+02, -.58862800E+02, 0.40942200E+03, 0.77065900E+03, 0.10233600E+04, -.13914700E+02, 0.51702400E+03, -.28847900E+04, 0.14630200E+04, 0.33814800E+04, 0.14430000E+04, 0.26592400E+03, 0.41436200E+03, -.40466200E+03, -.14165300E+04, -.35478600E+03, 0.65131400E+03, 0.22973000E+04, 0.73616700E+03, -.29943400E+03, -.35326800E+04, -.36844600E+03, 0.72999200E+03, 0.51090200E+03, -.77354100E+02, 0.22931300E+03, -.44335500E+03, 0.57127200E+03, -.16974100E+04, -.58104200E+03, 0.29322600E+03, 0.10523100E+04, 0.29048200E+03, 0.35829900E+03, 0.10436300E+03, 0.10707700E+03, -.73933500E+02, 0.28404900E+02, 0.12182500E+03, -.16884600E+03, 0.26949800E+03, -.18465200E+03, -.22244900E+04, -.13224800E+03, -.99445200E+03, -.57954300E+03, 0.36443700E+03, 0.23231200E+03, 0.96455500E+03, -.89820500E+03, 0.12906300E+04, -.55528200E+03, 0.25256200E+03, -.15098700E+04, 0.27917600E+03, -.38006700E+03, -.50772400E+03, 0.11075300E+03, 0.10898800E+03, 0.45211800E+03, -.58296200E+03, -.38744800E+03, -.28999700E+03, 0.13130500E+03, -.37802600E+03, 0.14768000E+03, -.17061000E+03, 0.11849500E+03, -.65738500E+01, -.52527600E+03, 0.45290100E+02, 0.45176400E+03, 0.60692100E+03, -.23562100E+02, 0.76756800E+02, -.18284700E+03, -.19765800E+03, 0.34188900E+02, 0.63616500E+02, -.70111000E+02, -.26069800E+03, -.51395400E+02, 0.70951400E+02, 0.11615900E+03, -.44897200E+02, -.21457000E+02, 0.33741700E+02, -.17153500E+03, -.88404300E+03, 0.26264500E+03, 0.14765100E+03, -.22188800E+03, 0.40995600E+02, 0.11773200E+03, 0.78592200E+03, 0.10088900E+04, -.12365100E+03, 0.50880600E+02, 0.16007400E+02 },
        { -.14662300E+01, -.44016800E-01, 0.46031700E+00, 0.26979700E+00, 0.26220800E+00, 0.34497600E+00, 0.21348400E+01, -.73637000E+00, -.79708000E-01, -.92888300E+00, 0.17120600E+00, 0.32163000E+00, 0.19410800E+00, -.24433300E-01, -.69507000E-01, -.56980100E+01, -.63278200E+00, 0.29548600E-01, 0.28361000E+00, -.12520900E+00, -.62214900E+00, -.14612600E+00, 0.96599300E-01, -.15620600E-01, -.14561900E-01, -.23878400E-01, 0.45555800E-01, -.45983300E+00, 0.77604700E+00, -.49011300E-01, -.25711400E-01, 0.77003200E+00, -.26040700E+00, -.19015100E+01, -.28590100E-02, 0.66366000E-02, -.29387800E-01, 0.10611900E+00, -.77704800E-01, 0.22159000E+00, -.52258200E+00, -.36143600E+00, 0.49157000E-01, -.21976000E-01, 0.47089700E+00, -.15928100E+00, 0.39163000E-01, 0.63994700E-02, 0.11078700E+01, 0.63219700E-01, 0.12587100E+00, 0.20161400E+00, 0.19935900E+00, 0.97612200E+00, 0.20020600E+00, 0.28034000E+00, 0.28971100E+00, 0.79828700E-01, 0.15000800E-01, 0.10773400E+00, -.15749100E+00, 0.37780700E+00, -.47862300E-01, 0.84085100E-02, 0.79414100E-01, -.15569100E-01, 0.17590100E+00, 0.72709200E-01, -.13938000E+00, 0.20654900E-02, -.12798100E-01, -.11536500E+01, -.19615000E+00, -.64352400E-01, 0.35117400E+00, 0.32942300E+00, -.47644900E-01, -.12365000E+00, 0.30864400E+00, 0.98578700E-01, -.19476000E-01, -.19610000E-01, -.16273300E-01, -.47722800E-02, -.11428200E+00, -.14685600E+00, -.17454100E+00, 0.23366800E-01, 0.42315800E+00, 0.11945300E-01, 0.53949200E-01, 0.18106000E-02, 0.10002100E+00, 0.28249700E-01, -.16076800E+00, 0.35733900E+00, 0.26447500E-01, 0.24290200E-01, 0.10726000E+00, 0.38701900E-02, 0.42692800E-01, 0.11448800E+00, 0.10427200E-01, -.19527400E+00, -.75223500E-01, -.17066300E+01, 0.27669300E-01, -.61060500E-01, -.71618200E-01, 0.12423500E+00, 0.60439500E-01, -.69963300E-02, 0.75002100E+00, -.29447100E-04, -.33242000E-01, 0.30426500E+00, -.39564900E-01, 0.76227700E-01, -.91630200E+00, 0.57387500E+00, -.15297200E+00, 0.48341900E-01, -.34110400E-01, -.35205000E-01, 0.36272700E-01, -.16658700E+00, -.19627900E+00, -.61040800E+00, 0.80841500E-01, 0.13702100E+00, -.46897400E+00, 0.19503200E+00, 0.70653400E+00, -.31191000E+00, 0.63509200E-01, 0.11388700E-01, -.16061800E+00, -.26233100E+00, 0.75113200E-01, 0.71399000E+02, 0.18479600E+02, -.19452400E+02, 0.38748900E+02, 0.22405600E+03, -.11817100E+03, 0.23325300E+03, -.11232900E+03, 0.19714200E+03, -.12713700E+02, 0.60992200E+02, 0.11258000E+03, -.18009700E+03, 0.52875200E+02, -.53450500E+03, -.96751800E+01, 0.81555000E+01, 0.27031300E+03, 0.47964000E+01, 0.19503100E+03, 0.94643300E+02, 0.53258800E+02, 0.15522600E+03, -.30926600E+02, 0.21403700E+03, -.60799800E+03, 0.23037700E+03, -.11371000E+03, 0.20057400E+03, -.11493200E+03, -.54662900E+02, -.82650300E+02, -.74759100E+01, 0.58934500E+02, -.96183500E+01, -.84113900E+02, -.94747800E+02, 0.19371300E+03, -.94544100E+02, -.16012100E+02, -.98499300E+02, 0.38267100E+02, 0.35710300E+02, -.11755300E+03, -.81102300E+02, -.97888100E+02, 0.62395900E+02, -.11960100E+03, -.28481500E+03, 0.14049700E+03, 0.36007500E+03, 0.14116500E+03, 0.71453200E+02, 0.44606400E+02, 0.14762300E+02, -.16972600E+02, 0.40550800E+02, 0.43544600E+02, 0.11030200E+02, -.52776500E+03, 0.27093700E+03, 0.17050900E+03, 0.26290700E+03, 0.48857100E+02, 0.23758100E+02, 0.11467900E+03, 0.13636600E+02, 0.15726900E+03, 0.40498900E+02, 0.17973400E+03, -.16376500E+03, 0.79259700E+02, 0.35962600E+03, 0.81096100E+02, 0.10024000E+03, 0.95732000E+02, -.83006700E+02, 0.32248000E+02, 0.12788200E+03, 0.69171500E+02, 0.42777200E+02, 0.10585600E+03, -.49760400E+02, 0.22786900E+03, -.52972100E+02, 0.13146700E+03, 0.78336300E+02, 0.12831600E+02, 0.36777300E+02, -.12184000E+03, 0.15705400E+03, -.56449900E+03, 0.48218900E+02, -.22996800E+02, 0.24616200E+03, -.24108400E+02, 0.11148200E+03, -.72809200E+01, 0.40053100E+02, 0.50321000E+02, -.63999500E+02, 0.50302100E+02, -.14183400E+03, -.62952200E+02, 0.29059500E+02, -.33334700E+03, 0.31730600E+02, -.14863200E+03, 0.35855100E+01, -.21106400E+02, -.47839100E+02, 0.52366400E+02, -.52996200E+02, 0.33376800E+03, -.71815200E+02, 0.33744400E+02, -.11273600E+03, 0.36476000E+02, -.43349600E+02, 0.15410200E+02, -.34040800E+02, -.69514100E+02, -.19053900E+02, 0.15196900E+02, 0.62235700E+02, -.13107600E+03, 0.61031500E+02, 0.12117500E+03, 0.65179200E+02, -.64094200E+01, 0.12033300E+03, -.27525700E+03, -.11123200E+03, 0.36707100E+02, 0.67763700E+02, 0.52702000E+03, -.44494200E+01, 0.20265300E+02, -.40459500E+02, -.47474400E+02, -.82499700E+01, 0.15244600E+02, -.16991800E+00, -.14671500E+02, -.12835100E+02, 0.17411800E+02, 0.13845300E+02, -.19535800E+02, -.93291000E+01, 0.74485300E+01, -.12956700E+02, -.14709800E+03, 0.52698400E+02, 0.17227600E+02, -.46301400E+02, 0.12587000E+02, -.19522100E+02, 0.16075700E+03, 0.13878000E+03, -.13488000E+02, -.25374300E+01, -.14901800E+02 },
        { -.26966500E+01, -.36637200E+00, 0.61189500E+00, 0.48124600E+00, 0.97723800E+00, 0.34806700E+00, 0.54450700E+00, 0.79356800E+00, 0.55814800E-02, 0.51874700E+00, 0.11420700E+00, 0.13416700E+00, -.11650100E+00, -.12744800E+00, 0.15473200E+00, 0.57915800E+00, -.22683300E+00, -.19198100E+01, 0.22793400E+01, 0.94607100E+00, -.18208700E+00, 0.98982200E-01, -.12300900E+00, -.19071700E+00, -.12947800E+00, -.22415500E-01, -.30685200E+00, -.25788600E+00, -.22680800E-01, 0.17288400E-02, -.48547300E-01, 0.42864600E-01, -.23446900E+00, 0.13799900E+01, -.85758300E-02, -.18985600E-01, 0.19769600E-01, -.10831800E+00, 0.69255700E-01, 0.69111600E-01, -.16790500E+01, 0.10647500E+00, 0.63709000E-02, -.47999200E-01, 0.76073100E-02, 0.13203100E+00, -.25365300E-01, 0.27072800E-01, -.53336500E+00, -.17049700E+00, 0.37452100E+00, -.35408900E+00, 0.47671400E-01, -.17354400E+01, -.22881100E+00, 0.21813900E+00, -.11669400E+00, 0.25311200E-01, 0.40607400E-01, 0.38600500E+00, 0.31309500E-01, 0.80334800E+00, 0.25443000E-01, -.88610600E-01, 0.28920400E-01, -.36873800E+00, -.93300900E+00, -.92608900E-01, 0.50114400E+00, 0.93774000E-02, -.81964100E-02, 0.23903200E+01, 0.99343900E+00, 0.85805900E+00, -.39682000E+00, 0.67116800E+00, -.91644900E-02, 0.11119800E-01, 0.16850000E+00, 0.22637400E-01, -.94977600E-02, -.12522400E+00, -.94919800E-01, -.50060400E+00, -.80355300E-02, 0.31565300E+00, 0.15591400E+00, 0.14807000E-01, -.46615600E-01, -.20060400E-02, -.12577500E+00, -.52597300E-03, 0.33973900E+00, 0.73434500E-01, 0.61735700E+00, 0.70903800E+00, 0.29829200E+00, 0.15372700E+00, -.12811300E-01, 0.37997200E+00, 0.40839600E-01, 0.55117300E-01, 0.13454100E-01, -.17106000E+00, 0.91072200E-01, -.27606600E+00, -.12037800E+00, 0.30636200E+00, 0.10437100E-01, -.15054800E+00, 0.99439000E-01, -.20770000E-01, 0.79751500E+00, 0.11452300E-01, 0.26580900E+00, 0.12607300E+00, -.31530400E+00, -.16938500E+00, 0.59051400E-01, -.97370500E+00, -.10386600E+00, -.82786700E-01, -.21925900E+00, -.85659300E-01, -.68705000E-01, 0.21895300E+00, 0.14368900E+00, 0.17852400E+01, -.25949600E-01, -.48739700E-01, -.90891400E-01, -.98000900E-03, 0.26093600E+00, 0.30253900E+00, -.30811300E-01, -.91953900E-02, -.39066600E-02, 0.42246200E+00, -.12933100E+00, 0.17210700E+00, 0.47832000E+02, -.61126900E+01, -.33745300E+02, -.52217900E+03, 0.26090400E+03, -.14640500E+03, 0.26182700E+03, 0.51933700E+02, 0.24731000E+02, 0.11364800E+03, -.16066000E+03, 0.67040100E+02, 0.41936300E+02, 0.97033700E+01, -.98005300E+03, 0.48598700E+03, 0.39219800E+03, 0.49003300E+03, 0.27590800E+03, 0.23131700E+03, -.55217700E+02, -.35367900E+03, 0.44799100E+03, 0.14902600E+03, 0.77781500E+02, 0.27338400E+03, -.13473700E+03, -.28486600E+03, -.13686500E+03, -.11004700E+02, 0.29214100E+02, -.10561100E+03, -.21955100E+02, -.13122700E+03, 0.56531800E+02, -.13179500E+03, 0.23233100E+03, -.11692100E+03, -.85119300E+02, -.11293500E+03, 0.86399000E+02, 0.13214900E+03, -.26673000E+02, 0.35917400E+02, -.12631100E+03, 0.12461100E+03, -.12726300E+03, 0.19450700E+03, -.93537600E+02, -.24950500E+03, -.96598300E+02, -.35510700E+02, -.34677700E+02, -.13561200E+01, -.10629000E+02, -.12559500E+03, -.12225800E+02, -.17700200E+03, -.16427700E+02, 0.98764400E+01, -.11350200E+03, 0.90428300E+01, -.25290800E+02, -.11211600E+03, 0.14001300E+03, 0.40147400E+02, 0.10298800E+02, -.84176000E+02, -.68942700E+01, -.65840500E+03, 0.32906900E+03, -.15532100E+03, 0.33140800E+03, 0.84900800E+02, -.34004900E+02, 0.16287400E+03, -.84959400E+02, 0.16364700E+03, -.33886600E+02, 0.28713500E+03, -.10850300E+04, 0.53524000E+03, 0.46909300E+03, 0.54251000E+03, 0.20348800E+03, 0.18248900E+03, 0.25087700E+02, -.32081800E+03, 0.42383100E+03, 0.11984600E+03, 0.18382800E+03, -.15616200E+03, 0.79798200E+02, -.12089500E+03, 0.78067100E+02, 0.10854700E+03, 0.17812900E+02, 0.48754900E+02, -.65345900E+02, 0.14056500E+02, 0.23186700E+02, -.17348200E+03, 0.49465500E+03, -.24329100E+03, 0.54705600E+02, -.24728200E+03, -.96085400E+02, -.12832100E+03, 0.11665700E+02, 0.17991400E+03, -.42859400E+02, -.81119600E+02, -.83472200E+02, -.33840400E+02, 0.20329800E+02, 0.74630200E+02, 0.15848800E+02, -.56197400E+02, -.74502300E+02, 0.25000500E+02, -.45022600E+02, 0.25418800E+02, -.86840300E+02, -.51236900E+02, 0.91222800E+02, -.40207700E+02, 0.17534100E+02, -.43923200E+02, -.60778200E+01, -.47123200E+02, 0.11664800E+03, -.73500000E+01, 0.19594900E+02, 0.57565000E+01, -.22460100E+03, 0.12739700E+02, -.29333000E+01, -.19114700E+02, -.97639700E+01, 0.60204300E+01, 0.65246200E+01, -.16142700E+02, -.49668200E+02, 0.59219700E+01, 0.47329900E+00, -.33197000E+01, 0.63813900E+01, 0.53071900E+00, -.72058700E+01, -.41735300E+02, -.99625000E+01, 0.12485400E+02, -.29359200E+02, -.21455000E+02, -.10456300E+01, 0.32598700E+02, -.18236600E+02, 0.94585300E+01, -.18391500E+02, -.87873500E+01, 0.21895100E+01 },
        { -.61034200E+01, -.89015600E+00, 0.16603600E+01, 0.17145700E+01, 0.18825800E+01, 0.10154500E+01, 0.61874500E+00, -.29577100E+01, -.10105900E+01, -.17404000E+01, -.13900400E+01, -.21640000E+00, 0.29528900E-01, -.36047300E+00, -.16375300E-01, -.12704800E+02, -.58095900E+01, -.42672200E+01, -.39547100E+01, 0.34670600E+00, 0.65383700E+01, 0.25994900E+01, -.95961700E+00, -.39121700E+01, -.78681000E-01, -.14567400E+00, -.80089000E+00, -.80566300E+01, 0.14281300E+01, 0.11575400E+00, -.20008200E+01, -.45408700E+01, 0.11091900E+01, 0.63263500E+01, -.79163900E-02, -.53452700E+00, 0.23256200E+00, 0.15664200E+01, 0.62051500E+00, -.14965900E+01, -.41563000E+01, 0.20765100E+01, -.17593900E+00, -.58432300E+00, -.22817800E+01, 0.16940300E+01, -.32080000E+00, 0.23505900E-01, -.88894200E+00, -.82965800E+00, 0.14614900E+00, -.38292800E+00, -.35597600E+00, 0.64315200E+00, 0.17771700E+00, -.88743700E+00, 0.19231000E+00, 0.22144100E+00, -.23323900E-01, 0.44931700E+00, -.26631600E+00, 0.69494900E+00, -.79236200E+00, 0.56757900E+00, -.75183000E+00, -.22272500E+00, 0.61786200E+00, -.28948900E+00, -.18967300E+01, 0.37549700E-01, 0.27927400E+00, -.78834700E+01, -.14477800E+01, -.26337500E+01, 0.26071700E+01, -.96122400E+00, 0.55208100E+00, 0.10909700E+01, 0.19973700E+01, -.18900300E+00, -.23172800E+00, 0.45479400E-01, 0.10406200E+01, 0.75624000E+00, -.33919800E+00, -.22702900E+00, 0.15214600E+00, -.45549100E+00, -.61516000E+00, -.15832900E+00, 0.83152800E+00, -.92058200E-02, -.56849200E+00, 0.14630500E+00, 0.12002500E+01, -.11591800E+00, -.98294700E+00, -.47417200E+00, 0.29435300E+00, 0.38990600E+00, -.10844500E+00, 0.17111600E+00, 0.38572100E-01, 0.23040100E+00, -.40867800E+00, -.17673800E+01, 0.58769400E+00, -.33726500E+00, -.19823700E+00, -.52577600E+00, 0.21990000E+00, -.80719600E-02, -.44655100E+00, -.47372400E-02, -.70194900E+00, 0.34855100E-01, 0.22039600E+00, 0.17902800E+00, -.68966000E+00, 0.77747500E-01, 0.40884300E-01, 0.94966300E-01, -.84500000E-01, 0.13544100E+00, 0.68151400E-01, -.76248000E-01, -.53744100E-01, -.12592400E+01, 0.35178400E+00, 0.12255000E+00, 0.83139300E+00, 0.52650000E+00, 0.56211200E+00, -.20002300E+00, 0.61093000E+00, 0.86180900E-01, -.16289600E+01, -.11514600E+01, 0.34673900E+00, -.14051100E+00, 0.18439600E+00, -.61791400E+02, -.73563400E+02, 0.26345700E+03, -.13888200E+03, 0.12258100E+04, -.13374700E+03, -.16558300E+03, 0.18822700E+02, 0.17221000E+03, 0.47519400E+03, 0.74712900E+02, -.83617700E+01, 0.30862300E+02, 0.24879700E+04, -.12258300E+04, -.92367200E+02, -.12443200E+04, -.62129900E+03, -.46233400E+03, 0.10225700E+03, 0.54610300E+03, -.12162200E+04, -.15998900E+03, -.12410700E+04, 0.51732000E+03, -.30265500E+03, 0.74328400E+03, -.25748800E+03, -.20908900E+03, -.30477300E+03, -.26097400E+01, -.90278700E+02, -.92189900E+02, -.25600700E+03, 0.13309300E+03, 0.88258900E+03, -.43822600E+03, 0.18332300E+03, -.46113300E+03, 0.18583100E+03, 0.11827700E+03, -.29645300E+03, -.63732600E+02, -.21560900E+03, 0.10817400E+03, -.39549500E+03, 0.23220800E+03, -.15942900E+03, 0.60171400E+03, -.12082000E+03, -.78926300E+02, -.72689600E+02, -.19165100E+03, -.79251500E+02, 0.36773800E+02, -.39636100E+02, 0.53895800E+03, -.15050500E+03, 0.71438900E+02, 0.77622700E+02, 0.66964000E+02, -.66237800E+02, -.59629300E+00, -.36827900E+02, 0.30166600E+02, 0.81277700E+02, 0.60354900E+02, 0.13918800E+03, 0.43336700E+03, -.21600100E+03, 0.84222600E+03, -.22166700E+03, 0.13934800E+02, -.15967300E+02, -.97569600E+02, 0.11395600E+03, -.39342300E+02, 0.47068800E+02, -.69470100E+03, 0.29206800E+04, -.14291100E+04, -.51039900E+03, -.14607000E+04, -.51896500E+03, -.34272600E+03, -.11750000E+03, 0.46829800E+03, -.12206400E+04, -.15445800E+03, -.12166900E+04, -.69903700E+03, 0.34326800E+03, 0.12071300E+04, 0.34951100E+03, -.70060200E+02, 0.80011600E+02, 0.32857000E+02, -.14501400E+03, 0.19633200E+03, 0.10486900E+03, 0.62423100E+03, -.76301200E+03, 0.36169600E+03, -.12071400E+04, 0.38409500E+03, 0.12351800E+03, 0.35628000E+03, -.24036900E+03, -.33979400E+03, 0.32513800E+03, 0.92958000E+02, 0.89660300E+03, -.18081000E+03, 0.78724300E+02, -.14491600E+03, 0.94823300E+02, -.18253400E+03, -.51274900E+02, -.90069200E+02, 0.11884100E+01, 0.51615000E+02, -.58143200E+02, 0.43717900E+03, 0.29594100E+03, -.17338800E+03, 0.33646700E+02, -.14939100E+03, -.37078600E+03, 0.49163600E+02, -.36396500E+03, -.13609600E+03, -.98656800E+02, -.71420100E+02, 0.75870400E+03, 0.37932000E+02, -.49124300E+01, -.54901700E+02, -.84178600E+02, 0.18688300E+02, -.39560000E+01, 0.35501900E+02, 0.42666900E+01, -.44185200E+01, 0.23152000E+00, 0.81571300E+01, -.18282100E+01, 0.37105900E+01, -.23669700E+02, 0.37402900E+02, -.11865600E+03, 0.95068600E+02, 0.70996200E+02, -.54206500E+02, -.11542900E+02, -.61303900E+02, 0.19831200E+03, 0.76783700E+02, 0.50216700E+02, 0.21834800E+02, -.23396300E+02 },
        { -.19962600E+01, -.59901500E-01, -.18293700E-01, -.92977500E-01, 0.18373400E+01, 0.19098000E+00, -.35873200E+00, 0.38554500E+01, -.29173800E+00, 0.94445800E+00, 0.71465000E+00, 0.81225200E-01, 0.48527900E+00, -.12656600E+00, -.20330900E+00, -.74470400E+01, -.23620100E+01, -.81974900E+00, -.43760500E+00, 0.24487900E-01, -.42855000E+00, -.33318700E+00, 0.22920500E+00, 0.34396300E+00, 0.60964800E-01, 0.41212100E-01, 0.48155900E+00, 0.45825900E+00, -.10389400E+00, -.25584000E-01, 0.58316500E+00, 0.10957800E+01, -.43984000E+00, -.25951900E+01, -.34578500E-01, 0.17255500E+00, -.18843900E-01, -.26440200E+00, -.15806300E+00, 0.13582800E+00, 0.52470200E+00, -.57976600E+00, 0.78771100E-02, 0.71675200E-01, 0.30440500E+00, -.55858500E+00, 0.10972000E+00, 0.12136000E-01, 0.13585100E+01, 0.93981400E-01, -.31270600E+00, 0.86319500E+00, 0.13516200E+00, 0.14493900E+01, 0.26427400E+00, 0.89444500E-01, 0.36655900E+00, 0.15125200E+00, 0.32370300E-01, 0.28959900E-01, -.86710800E-01, 0.10158500E+00, 0.29549900E-03, 0.34660100E+00, -.23197200E+00, -.14017800E+00, 0.45509300E+00, -.80238100E-02, -.67056400E+00, -.93938200E-02, -.57203300E-01, -.14434600E+01, -.41870700E+00, 0.24434000E+00, 0.44134200E+00, -.61432900E+00, 0.22341600E+00, 0.33185200E+00, 0.34473300E+00, -.28064000E-02, -.33810400E-01, 0.54955300E-01, 0.12329600E+00, 0.19259400E+00, 0.19056600E-01, -.35730400E-01, -.23528000E+00, -.45384600E-01, -.27498200E+00, -.46356300E-01, 0.64973400E-01, -.32957000E-02, -.43884800E+00, 0.29784900E-01, 0.44476600E+00, -.51751700E+00, -.58188400E-01, 0.20092500E+00, -.31330600E-02, 0.16657100E+00, -.63951500E-02, 0.56161500E-01, 0.25443900E-01, -.25713600E+00, 0.23003600E+00, -.61341900E-01, -.17726600E+00, 0.60868600E+00, -.12165500E+00, -.50177900E+00, 0.43521800E+00, 0.54459100E-02, 0.31788800E+00, 0.14946700E-01, -.20490300E+00, 0.48168600E+00, 0.17174900E+00, -.47278100E-02, -.31029000E+00, -.15245700E+01, -.33282600E-01, 0.21882500E-02, -.24278200E+00, 0.54649700E-02, 0.10256200E-01, 0.17859200E+00, -.25215000E+00, 0.86692100E+00, 0.23458400E+00, -.10690500E+00, 0.28126500E+00, -.24575500E+00, -.40057600E+00, 0.98921100E+00, 0.86191600E-01, 0.98287400E-02, -.41614800E+00, -.17761300E+00, 0.91210700E-01, 0.13800500E+00, 0.17131300E+00, 0.71194100E-01, 0.11320200E+03, 0.34411400E+02, -.83238300E+01, 0.15967800E+03, -.17299400E+02, -.26718000E+02, 0.39104600E+02, -.13120000E+03, -.12996400E+03, 0.33904900E+02, 0.43818000E+02, -.18725000E+03, 0.43458300E+03, -.21779000E+03, -.12351900E+03, -.21726300E+03, -.13413900E+03, -.16217100E+03, -.60123400E+01, 0.24730900E+02, -.68329800E+02, -.12848300E+03, -.31216800E+03, -.85600800E+03, 0.41879100E+03, 0.45798600E+03, 0.42791600E+03, 0.12316800E+03, 0.79825200E+02, 0.19854400E+03, 0.21534300E+02, 0.23835600E+03, 0.60250500E+02, 0.14507100E+03, -.25799200E+03, 0.13005600E+03, 0.73296100E+02, 0.12979400E+03, -.27537300E+02, -.52734100E+02, 0.52682600E+02, -.47733600E+02, 0.11770700E+03, -.56270300E+02, 0.25955100E+02, -.64014100E+03, 0.31393500E+03, 0.38724300E+03, 0.31893900E+03, 0.73676600E+02, 0.47421800E+02, 0.18108000E+03, 0.10667300E+03, 0.30505800E+03, 0.29896000E+02, 0.88912100E+02, 0.30594100E+03, -.14725700E+03, 0.62510400E+02, -.15256200E+03, 0.57808300E+01, 0.96589900E+02, -.17168300E+03, 0.66078200E+01, -.45843600E+02, 0.74982000E+02, -.10169400E+03, 0.11217800E+03, -.54095100E+02, 0.22333400E+03, -.56456700E+02, -.10017400E+03, 0.14889300E+02, 0.31385700E+02, -.16929800E+01, -.64068900E+02, 0.33596100E+02, -.76878900E+02, 0.29478800E+03, -.14609100E+03, -.21664700E+03, -.14735800E+03, -.60335700E+02, -.10534000E+03, -.42427800E+01, 0.49271200E+02, -.47543900E+02, -.74916400E+02, -.24491400E+03, 0.12921100E+03, -.64721300E+02, -.21227700E+02, -.64599800E+02, -.10223200E+03, -.22628300E+02, -.94646000E+01, 0.43646300E+02, 0.48808300E+02, -.21731800E+02, -.14906000E+03, 0.22971500E+02, -.11119000E+02, -.16447300E+03, -.11716500E+02, 0.75585500E+02, 0.56392800E+00, 0.55250400E+02, 0.85889200E+02, 0.59352200E+01, 0.31353300E+01, 0.78017000E+02, -.37878100E+02, 0.16285300E+02, 0.67495700E+02, 0.18958900E+02, 0.34289100E+02, 0.17547100E+02, 0.22840400E+02, 0.68385800E+02, 0.37529200E+02, 0.11887100E+02, 0.55313200E+02, 0.84809400E+02, -.43213700E+02, -.45638800E+02, -.42888100E+02, -.12237100E+02, 0.19976500E+02, -.11915900E+02, -.30272000E+02, -.10655800E+03, 0.34115200E+02, -.13771800E+03, 0.29336400E+01, 0.41633100E+01, 0.59411800E+02, 0.57319900E+02, 0.96168200E-01, -.17764600E+02, 0.15111000E+02, -.84213600E+01, -.12969100E+01, 0.54995200E+01, 0.49422200E+01, 0.16632000E+01, 0.62264400E+01, 0.26628300E+01, -.10124300E+02, 0.52926900E+02, -.61697700E+02, 0.87005300E+01, 0.59978400E+02, -.71200500E+01, -.20456000E+02, -.26432700E+02, -.27821200E+02, -.86010900E+00, 0.35967600E+01, 0.13680500E+00 },
        { 0.41584800E+01, -.50277100E+00, -.14671200E+01, -.23632500E+01, -.17597600E+01, -.60961000E+00, -.10205200E+01, 0.49100900E+01, 0.44667000E+00, -.29825300E+00, 0.27524800E+00, -.39028600E+00, -.94984100E+00, 0.22644900E+00, -.76216300E+00, 0.19795100E+01, 0.18734300E+01, 0.50653100E+00, -.85989200E+00, 0.65118400E+00, 0.11477400E+01, 0.48373200E+00, -.63041000E-01, 0.16302500E+00, 0.16118200E-01, 0.19169800E+00, 0.74071900E+00, 0.13724000E+01, -.10274700E+01, 0.15698400E+00, -.34926500E+00, 0.35957200E+00, 0.93828800E+00, -.13637800E+00, 0.59455800E-01, -.48334300E-01, -.21387600E+00, -.10584300E+01, -.14068800E+00, -.61626400E+00, -.57271400E+00, 0.16015200E+00, 0.98731200E-01, 0.85458400E-02, 0.85749700E-01, 0.28400100E+00, -.11254000E-02, -.11352200E+00, 0.10015400E+01, 0.43525300E-01, -.13872200E+00, -.48490500E+00, -.25545800E+00, 0.97866300E+00, -.78104000E-01, -.49678200E+00, 0.20554300E+00, 0.21666200E-01, -.11637600E+00, 0.59939800E+00, -.14043400E+00, -.67080600E+00, 0.20047000E+00, -.24716100E-01, -.49448800E+00, -.21365800E+00, -.82200100E+00, -.24355000E+00, -.12570000E+00, 0.13716500E-01, 0.20265300E-02, -.36025100E+01, 0.47865800E+00, 0.23547800E+01, 0.41254500E+00, 0.35866700E+00, -.74781100E-02, 0.56037700E+00, -.53135000E-01, -.39853800E-01, -.53225500E-01, -.38618000E-01, -.12733000E+00, -.37035200E+00, 0.18449600E+00, 0.52983800E+00, 0.31357100E+00, -.91283700E-01, 0.13526600E+00, -.41646700E-01, 0.11773700E+01, -.13138200E-02, -.43085600E+00, 0.18470200E-01, 0.18963000E+00, 0.13260800E+00, 0.11018600E+00, 0.58913700E-01, 0.28276500E-01, 0.12129100E+00, 0.19119400E-01, -.19804100E+00, -.38935300E-01, 0.13546700E+00, -.86416700E-01, -.12487600E+01, 0.21221300E+00, -.24715000E+00, 0.62794700E-01, -.18481400E-01, 0.41149800E+00, 0.15588400E-01, -.77111000E+00, -.21206100E-01, 0.23824600E-01, -.29177900E+00, 0.85110900E-01, -.37302200E+00, 0.74878000E-01, -.14300600E+01, -.21866500E+00, 0.34865600E-01, -.43180200E-01, 0.30368200E+00, 0.76923700E-02, 0.21381400E+00, 0.20556500E+00, -.77101000E+00, 0.41850700E+00, 0.18607500E+00, 0.46278100E+00, 0.23963400E-01, -.48383700E+00, -.44041200E-01, 0.15428800E+00, 0.29152700E-01, -.85027000E+00, 0.21521600E+00, 0.82374100E-01, 0.89810100E+00, 0.42051300E+00, -.29514500E+00, 0.85751200E+00, 0.13163000E+04, -.66376200E+03, -.11250800E+04, -.65888700E+03, -.17700300E+03, -.14520300E+02, -.22449600E+03, 0.14681200E+03, -.55040400E+03, -.63800700E+02, 0.38083000E+02, -.32369500E+03, 0.18105200E+03, -.60775300E+03, 0.16169500E+03, -.86933200E+02, 0.25880700E+03, 0.79752000E+01, -.81550800E+02, -.10175100E+03, 0.17727500E+03, 0.82339100E+03, -.66702500E+03, 0.31155200E+03, 0.28506100E+03, 0.33382900E+03, 0.94361600E+02, 0.89680500E+02, 0.37852500E+02, -.27528100E+03, -.21445900E+02, 0.10828800E+03, 0.44239800E+03, -.25783900E+03, 0.12620400E+03, 0.14241500E+03, 0.11987100E+03, 0.26867200E+02, -.51140400E+01, 0.10739500E+03, 0.61845700E+02, 0.10768700E+03, 0.20051200E+01, 0.13340100E+03, -.21577900E+03, 0.92803600E+02, -.33940600E+01, 0.10830400E+03, -.38530400E+02, -.30596000E+02, 0.19133000E+02, -.11724600E+03, 0.76634600E+01, -.11388000E+02, 0.37044800E+03, 0.16422800E+03, -.95686300E+02, -.13400800E+03, -.85855400E+02, -.48592100E+02, -.77104800E+02, -.16273400E+02, 0.37880900E+02, -.18506900E+02, -.63204900E+02, -.57268000E+02, 0.77584500E+02, -.37646100E+02, -.43602000E+03, -.40491900E+02, 0.19313000E+03, -.17604500E+03, 0.18841200E+03, 0.15810100E+03, -.24992800E+02, -.11082600E+03, -.44748700E+03, -.16699600E+03, 0.10025200E+03, -.32516900E+03, 0.83332400E+02, -.12819200E+03, 0.20658300E+03, -.33171500E+02, -.21751400E+02, -.68365300E+01, 0.12556100E+03, 0.68083700E+03, 0.72784100E+03, -.36071700E+03, -.65555500E+03, -.36392900E+03, -.84700700E+02, -.81861100E+02, -.11480300E+03, 0.70470800E+02, -.34246700E+03, -.68595400E+02, -.15487400E+03, 0.86356200E+02, -.57836700E+02, 0.62350200E+03, -.41893400E+02, -.72165100E+02, -.14277900E+03, -.48660400E+02, 0.52775400E+02, 0.41880400E+02, -.13620200E+03, -.15717200E+03, 0.22288500E+03, -.11095000E+03, -.20302100E+03, -.10961600E+03, -.57814700E+02, 0.26387800E+02, -.55841400E+02, 0.89028300E+01, -.10158900E+03, 0.12978100E+02, -.41531500E+02, -.33533900E+02, 0.80698500E+01, -.16338400E+03, 0.16640200E+02, -.28726500E+02, -.44407200E+02, 0.18520300E+03, -.66332200E+01, 0.15477700E+03, -.45638600E+02, -.90587300E+02, 0.12024600E+01, 0.59881900E+00, -.35257400E+02, -.34180500E+02, -.10539000E+02, 0.12981900E+02, -.92009400E+01, -.56038500E+01, -.44176600E+01, -.11010400E+01, 0.11136100E+02, -.50036700E+01, -.43389700E+01, 0.11858000E+02, -.22427200E+02, -.10117800E+03, 0.20802400E+02, -.12773500E+02, -.23747100E+02, 0.10669200E+02, 0.11984600E+02, 0.21447300E+02, 0.19877100E+03, -.33723800E+02, 0.74275300E+01, 0.19834100E+02 },
        { 0.92839500E+01, -.15819700E+01, -.20260000E+01, 0.13411800E+00, -.12035200E+01, 0.38105200E+00, -.20366000E+01, 0.98836900E+01, 0.11655200E+01, 0.25882800E+01, 0.14210300E+00, -.94379700E+00, -.20356100E+01, 0.42118500E+00, 0.98960000E+00, -.92801500E+01, -.27057900E+01, -.48233300E+00, -.53744000E+01, 0.26773100E-02, 0.20383900E+01, 0.11130600E+01, 0.27843100E+00, 0.97528100E+00, 0.10324500E+01, 0.10595800E-01, -.78658800E-01, 0.81888600E+00, 0.61079300E+00, -.11487300E+00, 0.84754600E-01, 0.29556300E+00, 0.19068300E+00, -.30300600E+01, -.63675600E-01, -.14064100E-01, -.82983600E-01, -.32190300E+00, -.22762300E+00, 0.37464000E+00, -.41631300E+01, 0.16956400E+00, 0.26936600E-01, -.27171200E+00, -.71480300E-01, -.24548200E+00, 0.15663700E-01, -.52471800E-01, -.10228900E+01, -.46003100E+00, -.73944900E+00, -.68330000E+00, -.33184400E+00, -.66359600E+01, -.89366900E+00, 0.13229200E+01, -.71701700E+00, -.94007800E-01, 0.55109400E-01, 0.17731500E-01, 0.14252700E+00, 0.45482000E+00, 0.17023100E+00, -.24907300E+00, 0.66515300E+00, 0.13290800E-01, -.12647600E+01, -.30051900E+00, 0.21506500E+01, 0.28181400E-01, 0.35592900E-01, 0.63707400E+01, 0.17497500E+01, 0.79755800E+01, -.89407300E+00, 0.71544900E+00, -.51494300E+00, 0.74757000E+00, -.12749500E+00, 0.62482300E-01, 0.21747200E+00, -.15727800E+00, -.10290400E+01, -.19674300E+01, 0.21250500E+00, 0.49209400E+00, -.10185400E+00, 0.15086500E+00, -.64474200E+00, -.88578800E-02, -.17637400E+00, -.10983200E-03, 0.14936900E+00, -.21561200E+00, -.20759700E+01, 0.73937100E-01, -.25905500E+00, 0.11656500E+01, -.35066600E+00, 0.48522700E+00, 0.26810800E+00, 0.34489300E+00, -.35324300E-01, 0.22286000E-01, -.70816200E-01, 0.54646900E+01, 0.56532300E+00, 0.45009300E+00, 0.88208700E-01, -.69615400E+00, 0.50601800E+00, -.15453600E+00, -.11009500E+00, -.19092100E-01, -.30784900E-01, -.55067100E+00, -.24592400E+00, 0.10588400E+00, 0.11769000E+01, 0.71251700E+00, 0.12625100E+01, -.32534000E-01, 0.70058500E+00, -.16954400E+00, -.13108800E-01, 0.23085800E+00, 0.88375800E+00, -.18615200E+00, -.12132800E+01, -.20996400E-01, -.10412000E-01, -.32449200E+00, -.41718000E+00, 0.18108500E+01, 0.64097700E-01, -.29296300E-01, 0.10071700E+00, 0.49428900E+00, -.11229300E+00, -.73914300E+00, 0.59758200E+00, 0.36107800E+00, -.71282300E-01, -.47362800E-01, 0.11242400E+03, -.79584200E+03, 0.17554800E+01, 0.32271900E+03, 0.89876500E+02, -.42345200E+03, -.59528400E+03, -.16910400E+03, 0.13035800E+03, -.58275200E+03, -.13054400E+04, 0.53839000E+03, 0.21983800E+03, 0.65280700E+03, 0.47690200E+03, 0.24337300E+03, -.47258200E+02, -.42623300E+03, 0.89670100E+03, 0.10753100E+03, -.30829900E+02, -.49861000E+03, 0.28714400E+03, -.76866800E+03, 0.24841000E+03, 0.17804200E+03, 0.30015100E+03, -.26592200E+02, -.52767200E+02, 0.20948600E+02, 0.28048400E+03, 0.14135800E+02, -.11176800E+04, 0.56020700E+03, 0.33482200E+02, 0.57091800E+03, -.29181900E+03, -.33879900E+03, 0.22937700E+03, -.21250700E+03, 0.42372300E+03, -.24966100E+03, 0.41282400E+03, -.22451200E+01, 0.35137100E+02, -.67084800E+03, 0.18433900E+01, -.15379900E+02, 0.20549700E+02, 0.12843200E+03, 0.55998400E+02, -.51538300E+01, 0.20152000E+02, -.37663300E+03, 0.19872200E+03, -.81342400E+02, -.15501000E+03, -.96269600E+02, 0.83984800E+01, -.86796100E+02, 0.51863700E+02, 0.27794500E+02, 0.87362700E+02, -.66136900E+02, -.44003100E+02, -.30738000E+03, 0.16919700E+03, -.16330100E+02, 0.15876000E+03, -.18449700E+03, -.68539900E+02, 0.38467500E+03, 0.21164200E+03, 0.13135700E+03, -.87218900E+02, 0.15826700E+03, -.23375400E+04, 0.11018800E+04, 0.70254000E+03, 0.11688400E+04, 0.41094300E+03, 0.28374200E+03, 0.11178100E+03, -.60983800E+03, 0.86368200E+03, 0.19121700E+03, 0.46628700E+03, 0.10968900E+04, -.54449700E+03, -.86181100E+03, -.54847000E+03, 0.34296000E+02, -.10939500E+03, -.51983700E+02, 0.28128900E+03, -.16885700E+03, -.76208200E+02, -.10190800E+04, 0.86184300E+03, -.38731300E+03, 0.32608400E+03, -.43131400E+03, -.23736600E+03, -.30243800E+03, 0.19325700E+03, 0.36041700E+03, -.28669400E+03, -.11012400E+03, -.18254600E+03, 0.17669900E+03, -.83503600E+02, -.69185500E+01, -.91152500E+02, 0.19055700E+03, 0.15790700E+03, 0.11064900E+03, 0.16328400E+03, -.11742700E+02, 0.10849700E+03, -.19462000E+03, 0.84001800E+02, 0.29435400E+01, 0.30949000E+02, -.38585000E+02, 0.63760000E+02, 0.29806800E+01, 0.22380400E+03, -.13171500E+03, -.12881400E+03, 0.11234400E+03, -.91974900E+03, 0.63907500E+01, 0.65824000E+01, 0.19962300E+02, 0.38831300E+02, -.14337700E+01, -.51376400E+01, -.61510800E+01, -.88638700E+01, 0.91808800E+01, 0.14672200E+02, -.71254500E+01, 0.21371200E+01, 0.11813400E+02, 0.77411300E+00, -.44533000E+02, 0.62098300E+02, -.52954400E+02, 0.42713500E+02, 0.20114600E+02, -.48209600E+00, 0.16279200E+02, -.93068400E+02, 0.53068100E+02, -.38896000E+02, 0.16418900E+02, 0.19462100E+02 },
        { -.19323300E+01, 0.32399900E+00, 0.82255700E+00, 0.67640900E+00, 0.13252800E+01, 0.43484800E+00, 0.29983500E+00, 0.14123200E+01, -.15745300E+00, 0.10780400E+01, 0.10782400E+00, -.37831300E-01, 0.18612700E+00, -.17628300E+00, 0.21138800E+00, 0.85441200E+00, -.41979500E+01, -.46785900E+00, 0.11598000E+01, 0.28238400E+00, -.83998400E+00, -.18459400E+00, -.31499400E-01, -.28046200E+00, -.14667300E+00, -.12102300E-01, 0.17735300E+00, -.50142100E-01, -.57627100E+00, 0.18519500E-03, -.10770800E+00, 0.58979000E-01, 0.16266500E-01, -.35460600E+00, -.22039000E-01, -.10243500E-01, 0.23656300E-01, 0.71336400E-01, 0.13219400E+00, 0.41276400E-01, 0.37135600E+00, 0.42745000E-01, -.37727500E-01, -.12420600E-01, 0.26519300E-02, -.16486800E+00, 0.26151800E-01, 0.94969300E-02, -.39607800E-01, 0.14754200E-01, 0.13032800E+00, 0.87264200E+00, -.32981700E+00, 0.92240300E+00, 0.11053100E+00, -.32652100E-01, 0.20340100E+00, 0.76048300E-02, -.12548800E-01, 0.38498300E+00, -.81670800E-01, -.11498400E+00, -.22100800E-01, 0.23269500E+00, 0.44513400E+00, 0.16756700E+00, 0.77540100E+00, 0.11831100E+00, 0.17082000E+00, 0.77317800E-02, -.69206900E-01, 0.20892400E+01, -.51631400E+00, -.11329000E+01, -.19586000E+00, -.24865800E+00, 0.21880600E-01, -.84580400E+00, 0.24442800E+00, 0.54147000E-01, -.33239700E-01, 0.11820200E-01, -.20990700E+00, -.57541900E-01, -.19458600E+00, -.18232800E+00, -.67073200E-01, -.27086300E-01, 0.12297100E+00, -.21065200E-01, -.12721400E+00, -.26203700E-02, 0.24606200E+00, -.64903400E-01, -.38918600E-01, 0.29221400E+00, -.32334900E+00, -.21420200E+00, 0.89719900E-01, 0.19897100E+00, -.92229300E-01, -.49601500E-01, -.18546100E-01, 0.20641600E+00, -.25700400E+00, 0.12432300E+01, 0.32190500E-01, -.10080100E+00, -.15447900E+00, -.31400400E+00, -.10763400E+00, -.47740900E-02, -.29893000E+00, -.51662000E-01, -.33092700E+00, 0.19099400E+00, 0.15355100E+00, 0.18616700E+00, 0.26584200E+00, 0.87986700E+00, -.26350300E+00, 0.26909700E-01, 0.17025400E+00, 0.92993500E-02, 0.93159800E-02, -.31951800E+00, -.49184800E-01, -.19955900E+00, 0.36849500E-01, 0.84452600E-02, -.27389900E+00, 0.17458000E+00, -.65453100E+00, 0.79493200E-01, -.29281500E-01, -.71636000E-02, -.22525500E+00, 0.92408500E-01, -.65260300E-01, -.91926200E+00, 0.27766900E+00, -.14132000E+00, -.42008900E-01, -.24757200E+00, -.20038300E-01, 0.83236500E+03, -.14020700E+01, 0.14504000E+02, -.43004800E+01, 0.10584300E+03, 0.20797800E+03, 0.59728800E+02, -.17421100E+02, -.14041800E+03, 0.66571500E+03, -.32262900E+03, -.24561900E+03, -.33280000E+03, 0.17758200E+03, -.13958600E+02, 0.76289700E+02, 0.46824100E+03, -.32207100E+03, 0.82473800E+02, -.70598600E+03, 0.95061800E+02, -.64953000E+02, 0.59232500E+03, -.47253100E+02, -.71235700E+02, -.11809100E+03, 0.21646400E+01, -.98587800E+02, -.49718100E+02, -.10049900E+03, 0.12951400E+03, 0.35007900E+03, -.17187900E+03, 0.22310900E+02, -.17893900E+03, 0.56172500E+02, 0.22877100E+02, -.11804200E+03, -.17267800E+03, -.17900800E+03, 0.22188700E+02, -.17306700E+03, -.19861900E+03, 0.85461100E+02, 0.52959400E+03, 0.10023500E+03, 0.42843200E+02, 0.62526500E+02, -.10804800E+03, -.18021200E+03, -.37191600E+02, 0.76014100E+02, 0.35569700E+03, -.12793500E+03, 0.61357400E+02, 0.13420400E+03, 0.63795600E+02, 0.45225800E+02, 0.94037500E+02, -.40470900E+02, -.25131100E+02, 0.43305900E+02, 0.95587200E+02, 0.56788500E+02, 0.28708100E+03, -.14162700E+03, 0.43508300E+03, -.14798400E+03, 0.18172700E+03, 0.79004900E+02, -.22219500E+03, 0.13654200E+02, -.57254500E+02, 0.84009400E+02, -.33754600E+03, 0.10773100E+04, -.52196300E+03, -.62313900E+03, -.53855800E+03, 0.63507800E+02, -.14869900E+02, -.63466600E+02, 0.38399700E+03, -.38545500E+03, 0.11513000E+02, -.63141200E+03, -.51855000E+03, 0.25754700E+03, 0.56125800E+03, 0.25931200E+03, 0.95550800E+02, 0.77185000E+02, 0.34801500E+02, -.87352200E+02, 0.11523500E+03, 0.89573900E+02, 0.23709300E+03, -.46033000E+03, 0.21812700E+03, -.45523600E+03, 0.22944400E+03, -.11875600E+03, 0.11515100E+03, -.62047500E+02, -.33191500E+03, 0.94855600E+02, 0.13860600E+01, 0.49487500E+03, -.26260600E+03, 0.12441400E+03, -.13341300E+03, 0.13298500E+03, -.40965000E+02, 0.11850500E+02, -.24771500E+02, 0.11758200E+02, 0.47128500E+02, 0.26998600E+02, 0.20136400E+03, -.70358200E+02, 0.26665900E+02, -.11689700E+03, 0.31225500E+02, 0.24640000E+02, 0.11243200E+03, -.17596000E+03, 0.73583900E+02, 0.80017600E+02, 0.33322500E+02, 0.62347200E+03, -.50052200E+01, 0.83396900E+01, -.46062500E+02, -.60643600E+02, -.72207500E+01, 0.84973900E+01, -.14757700E+01, 0.17343600E+01, -.14330900E+02, 0.54003900E+01, 0.12799200E+02, -.12679500E+02, -.98531500E+01, 0.73351300E+01, 0.17251800E+02, -.16032300E+03, 0.65393000E+02, 0.36160300E+02, -.42076100E+02, 0.11211700E+02, -.25396200E+02, 0.16198100E+03, 0.13151700E+03, 0.91031000E+01, 0.91392800E+01, -.88522700E+01 },
        { 0.92843000E+01, 0.51629800E+00, -.21836600E+01, -.30833100E-01, -.37794000E+01, -.16519900E+01, -.24790000E+01, -.24696000E+01, 0.76459700E+00, 0.25542300E+00, -.12268500E+01, -.53442800E+00, -.10983300E+01, 0.48418300E+00, 0.12215400E+01, -.63419900E+01, 0.24416700E+01, 0.12794100E+01, -.40337700E+01, -.82100400E+00, -.32424200E+00, 0.48819600E+00, 0.78988600E-01, 0.67071200E+00, 0.76668000E+00, 0.59578100E+00, 0.75850100E+00, 0.12241500E+01, -.20895000E+01, -.11961000E+00, 0.52595200E+00, 0.88222200E+00, -.34448900E+00, -.36276400E+01, 0.44378000E-01, 0.90625700E-01, -.26601200E-01, 0.81878100E+00, 0.57384600E-01, 0.51855500E-01, -.30234200E+01, -.12485200E+00, 0.10721900E+00, -.32809100E+00, -.12785400E+00, -.39682200E+00, 0.79348500E-01, -.61479500E-01, -.34337800E+01, -.39305100E+00, -.82954700E+00, -.51767700E+00, -.24218700E+00, -.56277300E+01, -.67465900E+00, 0.24962700E+01, 0.25862900E-01, -.60233400E-01, 0.24807200E-01, -.13739600E-01, 0.31193200E+00, 0.42792900E+00, 0.42569700E+00, -.77009400E+00, -.36825300E+00, -.29282900E+00, -.14927600E+01, -.29338900E+00, 0.66815900E+00, -.30128500E-02, 0.18585800E-01, 0.39042800E+01, 0.17682500E+01, 0.50733500E+01, -.10696400E+01, -.67666200E+00, -.28500700E+00, 0.11680000E+01, -.14303400E+01, -.28726800E+00, 0.12278900E+00, 0.32359000E-01, -.41856100E+00, -.69686800E+00, 0.13984300E+00, 0.33114600E+00, -.29087000E-01, 0.22345300E+00, -.68789100E+00, -.65724200E-01, -.79554100E+00, -.83562400E-03, 0.33587300E+00, 0.68898100E-01, 0.32678800E-01, 0.19786600E+01, 0.39441600E-01, 0.56071500E+00, 0.47493500E-01, 0.85092700E+00, -.60594700E-01, 0.42630700E+00, 0.28294800E-02, -.39383200E+00, -.21770400E+00, 0.18918900E+01, 0.69091000E+00, 0.17953200E+00, -.32240100E-02, -.96173400E-01, 0.51465000E+00, -.65603100E-01, 0.31806400E+00, 0.59008000E-02, 0.27207100E+00, 0.15906900E-01, -.36267200E+00, -.35775500E+00, 0.15167300E+01, 0.56443900E+00, 0.20689800E+01, -.23163400E+00, -.87250500E-01, -.35941700E+00, -.18557500E+00, 0.24073500E+00, 0.11883700E+01, 0.83594300E+00, -.12167300E+01, 0.13044200E+00, -.50796600E-01, -.24645000E+00, -.30267800E+00, 0.73933900E+00, -.80325000E-01, -.80825100E-01, 0.12241600E+01, 0.70348300E+00, -.75268900E-01, -.19180800E+01, -.45064700E+00, -.27302900E+00, -.38584100E+00, -.71278700E+00, -.72590800E-04, -.10881900E+01, 0.19529400E+02, -.27151400E+02, -.40169200E+02, -.56703300E+02, -.76156300E+02, -.14095700E+02, -.52932800E+02, 0.31521900E+03, 0.86243900E+03, -.40905300E+03, -.35625500E+03, -.43124500E+03, -.26022100E+02, -.14748400E+03, 0.69789500E+02, 0.51839500E+03, -.46824400E+03, -.75571700E+02, -.57069000E+03, -.28907300E+03, 0.12087400E+03, -.10207400E+02, 0.14478400E+03, -.28173800E+02, -.47834200E+02, 0.24479200E+02, -.40689900E+03, -.11112500E+03, 0.49240500E+01, 0.51733000E+03, -.63323100E+03, 0.31945400E+03, 0.27393300E+03, 0.30808800E+03, -.14909900E+03, -.29331900E+03, 0.12699700E+03, -.25334300E+03, 0.31191100E+03, -.23927800E+03, 0.30767300E+02, -.48601800E+03, 0.21700000E+03, 0.41506600E+02, 0.24460600E+03, -.18950600E+02, -.41170000E+02, 0.23284100E+01, -.44580100E+03, -.14058300E+03, 0.37124400E+02, 0.55820400E+03, -.32581500E+03, 0.15006800E+03, -.19202800E+02, 0.16265600E+03, -.11024900E+02, -.78410100E+02, 0.11746700E+03, -.12284900E+03, -.28625400E+02, 0.53047800E+01, 0.13623700E+03, 0.10322700E+03, -.45922500E+02, 0.51696500E+03, -.51310200E+02, 0.29024500E+03, 0.17500900E+02, 0.19992500E+03, 0.57499000E+03, 0.33082100E+03, -.29113200E+02, -.93464000E+03, 0.98259300E+03, -.46908300E+03, -.37928900E+03, -.49133200E+03, -.85269800E+02, -.13290100E+03, -.24078900E+02, 0.36320900E+03, -.49452100E+03, -.11016700E+03, -.52652700E+03, -.87707200E+02, 0.41962400E+02, 0.36534300E+03, 0.43849600E+02, 0.57754000E+02, 0.26560400E+02, -.93725200E+01, 0.84436600E+01, -.36420800E+02, 0.36215200E+02, -.19697700E+02, -.58903100E+03, 0.27351300E+03, 0.96291700E+02, 0.29465900E+03, -.98855900E+02, 0.15851400E+03, -.46180700E+02, -.42516300E+03, -.91547100E+02, 0.12202200E+03, 0.57183600E+03, 0.34231200E+02, -.26126400E+02, -.24529300E+03, -.17185900E+02, 0.10901300E+02, 0.19151900E+03, -.23910300E+02, 0.21548800E+03, -.13201500E+03, 0.17329600E+03, 0.29167500E+03, -.93617100E+02, 0.24567000E+02, 0.15679900E+03, 0.47175800E+02, 0.61793900E+02, 0.18202100E+03, -.52663000E+02, 0.17290200E+03, 0.17804500E+03, 0.63184500E+02, 0.59655000E+03, -.79022800E+01, -.90883900E+01, -.96524800E+02, -.10167900E+03, -.12065600E+02, 0.21708300E+02, -.28010100E+02, 0.84364700E+02, -.10689300E+02, -.26688400E+00, -.10785500E+02, -.13221400E+02, -.26215000E+02, 0.91720800E+01, 0.71138700E+02, -.57453000E+02, 0.93917700E+02, 0.79837500E+02, -.88953100E+02, 0.13707000E+02, -.65483000E+02, 0.55822300E+02, 0.11073700E+02, 0.27757100E+02, 0.29928000E+02, 0.13370700E+02 },
        { 0.26967700E+01, 0.82176400E+00, -.39483700E+00, -.13882700E+01, -.15900800E+01, -.65257700E+00, -.97151200E+00, 0.42812000E+00, 0.17548700E+00, 0.90431100E+00, -.40366800E+00, -.30483500E+00, -.58455900E+00, 0.81634100E-02, 0.15169900E+00, -.75042000E+01, -.23125200E+01, -.29800900E+00, -.50773800E+00, 0.30116300E+00, -.64782100E+00, -.26493400E+00, -.31100100E-01, -.18043400E+01, 0.80560000E-03, 0.30014000E-01, -.94991800E-01, -.17831100E+01, 0.12659600E+01, -.30555400E-01, 0.69073600E+00, 0.67686300E+00, -.53919500E+00, -.43906800E+00, -.20491200E-01, 0.15338600E+00, -.12322800E-01, -.43715700E+00, 0.61027700E-01, 0.10163700E+00, -.10062500E+01, -.71766100E+00, 0.14197100E+00, -.18946500E+00, 0.87739200E+00, -.44652700E+00, 0.50048600E-01, 0.34694600E-01, 0.66346700E+00, -.26744600E-02, -.10865000E+00, 0.40513200E+00, -.31619600E+00, 0.16585500E+01, -.13146000E+00, -.52667900E+00, -.12873300E+00, 0.14902500E-01, 0.31872600E-01, 0.52599400E+00, -.18472200E+00, -.64110600E-01, -.14970400E+00, 0.32396900E+00, 0.46758000E+00, 0.10807300E+00, -.27809100E+00, -.14714500E+00, -.62424500E+00, 0.36863100E-02, -.29243000E-01, -.35669000E+01, -.21496700E+00, -.45277400E+00, 0.28540200E+00, -.29490000E-01, 0.18370900E+00, -.18666300E+00, 0.57138300E+00, 0.71652700E-01, -.46427300E-01, -.18843300E-01, 0.10295400E+00, -.22286200E+00, 0.38511000E-01, 0.27108400E+00, -.25623700E+00, -.24505500E+00, 0.57557700E-01, 0.16127100E-01, 0.28534900E+00, 0.29154100E-02, -.36191500E-01, 0.16306600E+00, -.49679000E+00, -.82097300E+00, 0.76220700E-02, 0.11162600E+00, -.21827200E-01, -.21733400E+00, 0.56388500E-01, -.11683200E+00, 0.17668500E-01, 0.34312000E+00, 0.79935300E-01, 0.14318200E+01, -.25279800E+00, -.95998000E-03, 0.33835100E-01, 0.40172600E+00, -.15083800E+00, 0.94356300E-02, -.42148300E+00, 0.27326100E-01, 0.30997800E+00, 0.47382900E+00, 0.55564600E-01, 0.98956800E-02, -.67904400E+00, 0.16016900E+00, -.49281900E+00, -.12610400E-01, 0.49544500E-01, -.48798900E-01, 0.15625600E-01, 0.84080100E-01, 0.12284400E+00, 0.33991700E+00, 0.13290000E+00, -.13078800E+00, -.44371200E+00, 0.22562000E+00, 0.75567000E+00, -.36797000E+00, 0.19586500E+00, 0.16709200E-01, -.77824600E+00, -.23845500E+00, 0.13845500E+00, 0.16372500E+01, 0.18357600E+00, -.29349500E+00, -.52435600E-01, -.28977500E+00, -.15732000E-01, -.86662100E+00, -.68376600E-01, -.37676500E+03, 0.19873400E+02, 0.74996200E+02, 0.23024800E+03, 0.16338900E+03, -.88464100E+02, 0.70583200E+03, 0.21028700E+04, -.10364000E+04, -.10472300E+04, -.10515300E+04, -.72641600E+03, -.40298000E+03, -.31041200E+02, 0.47231500E+03, -.84373500E+03, -.39154900E+03, 0.26292300E+01, -.44201700E+03, 0.18360300E+03, 0.66669100E+03, 0.22147000E+03, 0.49753800E+02, 0.30546200E+02, 0.42998100E+02, -.20107200E+03, -.34203100E+02, 0.26460400E+02, 0.47213900E+03, 0.35527700E+03, -.17821900E+03, 0.76451700E+02, -.18829400E+03, 0.82047000E+02, 0.36408600E+02, -.24949800E+02, 0.13368200E+03, -.69463300E+02, -.12234300E+02, -.67329600E+02, -.93664800E+02, 0.18571800E+02, 0.28999800E+03, 0.46630300E+02, -.13228900E+02, 0.59435000E+02, -.13544500E+03, -.85179700E+02, 0.99724200E+02, 0.45161800E+02, 0.66933600E+03, 0.29110400E+03, -.16018100E+03, -.12179100E+03, -.14865500E+03, -.14913400E+02, 0.10806800E+03, -.23877000E+03, -.31455800E+01, -.30649000E+02, 0.73473200E+02, -.60522300E+02, 0.71467900E+03, -.35403600E+03, -.42481800E+03, -.36104100E+03, 0.60775100E+02, -.13603200E+03, -.54770400E+02, 0.14229500E+03, -.16032100E+03, -.70543500E+02, -.62128300E+03, 0.25367100E+04, -.12409700E+04, -.11099000E+04, -.12684400E+04, -.60464400E+03, -.33498300E+03, -.19886100E+03, 0.52803600E+03, -.81576000E+03, -.33577500E+03, -.25569300E+03, 0.15946800E+02, -.11530500E+02, 0.21055700E+02, -.79610600E+01, -.22332100E+03, 0.14360700E+01, -.11700700E+03, -.37302200E+02, 0.52234100E+02, -.44481100E+02, 0.46715800E+03, -.36214200E+03, 0.16242000E+03, 0.11633300E+03, 0.18173100E+03, 0.23200900E+03, 0.17710600E+03, -.17901700E+03, -.21208200E+03, 0.11076700E+03, 0.73114900E+02, 0.33558100E+01, -.42777700E+02, 0.14742400E+02, 0.90549600E+02, 0.23743200E+02, -.94576600E+02, -.69697400E+01, -.77339100E+02, -.30200000E+01, 0.16974100E+02, 0.25860900E+02, 0.18284600E+03, 0.15095600E+03, -.92482700E+02, -.14080700E+03, -.77652800E+02, -.10450100E+03, 0.68315000E+01, -.21962400E+02, 0.13661000E+03, 0.22423300E+02, -.58235400E+02, 0.27554700E+03, 0.18256800E+02, -.10360200E+02, -.66888400E+01, -.26336300E+02, -.18347500E+00, -.12855500E+02, 0.12513300E+02, -.13345200E+02, -.44894300E+01, -.10108900E+02, 0.13957500E+01, 0.11755600E+01, 0.25577900E+01, 0.25769300E+01, 0.72093400E+01, 0.65329500E+02, 0.14537400E+02, -.28175300E+01, 0.12399500E+02, -.66707400E+01, -.14437100E+02, -.47526800E+02, -.47006500E+02, 0.21242800E+02, 0.36871300E+01, -.38293400E+01 },
        { -.10396600E+02, 0.56460500E+01, 0.14137400E+01, -.27761600E+01, -.89944200E+00, -.27025800E+01, -.26799400E+01, -.42728600E+01, -.32338200E+01, 0.29078700E+00, 0.67727500E+00, 0.60616900E+00, 0.35054800E+01, -.47920000E+00, -.73892000E+00, -.78530900E+00, 0.11284200E+02, 0.12151500E+01, 0.40790800E+01, 0.35941300E+00, -.20872000E+01, -.17407400E+01, -.69235900E+00, 0.14535600E+01, -.12587500E+01, 0.71736000E-01, 0.12652500E+01, 0.20666200E+01, -.64777000E+01, 0.11488700E+00, 0.17124100E+01, -.54452900E+00, -.21526100E+01, 0.40066600E+01, 0.40144700E+00, 0.44656600E+00, 0.11369600E+00, 0.31505500E+01, 0.10284100E+01, -.17583500E+00, 0.44933900E+01, 0.29272700E+00, -.15196500E+00, 0.77848700E-01, -.75598300E+00, 0.12904300E+01, -.18469500E+00, -.54650400E-01, -.72067300E+00, 0.20367700E+00, 0.18896600E+00, -.27407400E+01, 0.16619900E+01, -.23012600E+01, 0.22533500E+00, -.59535300E+00, -.22852300E+00, 0.38942100E-01, -.46060700E-01, -.94580500E+00, 0.20547300E+00, 0.69361800E-01, -.37417600E+00, -.72166200E+00, -.21889200E+01, -.13968300E+01, 0.41807900E-01, -.34927700E-01, -.27793600E+00, 0.17487000E-01, 0.27262600E+00, -.34428900E-01, -.46511600E+00, -.84436100E-01, 0.32370500E+00, -.22259700E+01, 0.18551700E+00, 0.20332100E+01, -.16633400E+01, -.47621100E+00, -.96598500E-01, 0.25756000E+00, 0.86641700E+00, 0.99426200E+00, -.83362000E-01, 0.80268200E-01, -.50314400E+00, 0.55833200E-01, -.20020100E+01, 0.40153000E+00, -.93021000E+00, -.55809100E-03, 0.33068100E+00, -.16537100E+00, -.42331200E-02, -.10430400E+01, 0.91956900E+00, 0.13379800E+01, -.51484400E+00, 0.19158000E+00, -.14010700E+00, 0.38428800E+00, 0.76634100E-01, -.14486400E+00, 0.38155500E+00, -.17415600E+00, -.32590100E+00, 0.84264200E+00, -.31566100E-01, -.73531200E+00, -.26894400E+00, -.22724500E+00, -.20092200E+01, 0.10119400E+00, -.25802100E+00, 0.69155800E-01, -.24475800E+00, 0.76386900E+00, 0.29304200E+01, -.17169400E+01, 0.11769600E+01, -.30868500E+00, 0.15447100E+01, 0.54681800E+00, -.19224900E+00, 0.76480700E+00, 0.46450500E+00, -.34577700E+00, 0.32864600E+00, 0.17421000E+00, 0.11300200E+00, -.10708300E+01, -.65032000E-01, 0.46693700E+01, 0.32992600E+00, -.73180300E-01, -.26203900E+01, 0.50675300E+00, 0.39821700E-01, -.11427800E+01, 0.33914200E+01, 0.12264400E+01, 0.22714600E+01, 0.36161300E+00, -.93155400E+00, -.97264400E+00, 0.32335200E+00, -.38671800E+01, 0.57452000E+03, -.57306500E+03, -.19254700E+03, 0.10236200E+02, 0.27641800E+03, -.55225500E+03, 0.43445500E+04, -.26543700E+04, -.39047100E+04, -.21719400E+04, -.73467700E+03, -.38866000E+03, -.32646200E+03, 0.83423500E+03, -.44546200E+03, -.53886100E+03, -.17123700E+04, -.23027100E+04, 0.11627500E+04, 0.15479200E+04, 0.11493800E+04, 0.43235100E+03, 0.69352100E+03, -.38691900E+02, -.63915100E+03, 0.51825200E+02, 0.58447800E+03, 0.15525900E+04, 0.90837700E+03, -.41052200E+03, -.18428400E+03, -.43872800E+03, -.24944900E+02, -.92071300E+01, -.27671800E+03, -.29190400E+03, -.51830000E+03, 0.45220200E+02, 0.23434600E+02, 0.37145200E+02, -.82634300E+01, 0.21300700E+03, -.13116100E+02, -.65739400E+02, 0.46307500E+03, -.52634000E+03, -.38996100E+02, 0.56447800E+03, 0.34207800E+03, 0.15892300E+04, 0.15504400E+04, -.80331000E+03, -.72440300E+03, -.76846800E+03, 0.13551500E+03, 0.46531400E+03, -.89227800E+03, 0.33700600E+03, 0.67999300E+03, 0.33238100E+03, -.11757000E+03, 0.11326000E+04, -.56387200E+03, -.86318000E+03, -.56378500E+03, -.20479800E+03, -.56819700E+03, 0.30755800E+03, 0.23380700E+03, -.48467000E+03, -.24776800E+03, -.10024800E+04, 0.39426600E+04, -.21576800E+04, -.32160800E+04, -.19709400E+04, -.74313500E+03, -.92452500E+02, -.67704800E+03, 0.43991200E+03, -.80147100E+03, -.28601300E+03, -.11381000E+04, 0.25750500E+04, -.13214000E+04, -.17677100E+04, -.12875100E+04, -.49144300E+03, -.17980300E+03, -.54255300E+03, 0.63494000E+03, 0.13936100E+02, -.17416300E+03, -.10197400E+04, 0.18732100E+04, -.76379300E+03, -.29003600E+03, -.93893200E+03, -.43996800E+03, -.48748000E+03, -.18620100E+03, 0.32976200E+03, 0.12805100E+02, -.59116100E+03, -.29602600E+02, -.32494900E+03, 0.12668900E+03, 0.24998200E+03, 0.15960000E+03, -.13122900E+03, 0.92254300E+01, -.78769600E+02, -.40401200E+02, 0.42487400E+03, 0.19271500E+02, -.61686300E+02, 0.68595700E+03, -.27775100E+03, -.85881800E+03, -.34323400E+03, -.15167400E+03, 0.23947700E+03, 0.44322000E+02, -.17579100E+03, -.24068000E+03, 0.36881100E+03, -.80844800E+03, 0.92363800E+02, 0.52900200E+02, -.71447100E+02, -.12918400E+03, -.78451700E+01, -.56993200E+02, 0.27351400E+02, -.38023700E+03, -.35118800E+02, 0.56817500E+02, 0.67183900E+02, -.34808600E+02, 0.39091600E+02, 0.19935900E+02, -.31824200E+03, -.97599100E+02, 0.60459700E+02, 0.54853000E+02, 0.24400800E+00, -.69661700E+01, 0.42216600E+02, 0.71709700E+02, 0.74201100E+03, -.12863900E+03, 0.97766300E+01, -.61832900E+01 },
        { -.16420000E+01, -.85689100E+00, 0.56972800E+00, 0.10820100E+01, 0.20375000E-02, 0.12008300E+01, 0.25295400E+01, -.29740700E+01, -.97399100E-01, -.14784100E+01, 0.10826400E+00, 0.50717300E+00, 0.42240700E+00, -.60817100E-01, -.42216300E+00, 0.35647900E+01, 0.81297600E+00, 0.77280800E+00, 0.19882100E+01, 0.23673900E+00, -.13248200E+01, -.48330900E+00, 0.62555400E-01, -.62465600E-01, -.58206800E-01, -.39271100E-01, -.15081600E+00, -.18586000E-01, 0.65549000E+00, 0.94501900E-02, -.52927700E+00, -.25459900E-01, 0.35417000E-01, -.74729600E+00, -.27437700E-01, -.41057400E-01, 0.16080500E-01, 0.31944100E+00, 0.76200800E-02, 0.18271300E+00, -.39349500E+00, -.77676300E-01, 0.16170000E-01, 0.73763200E-01, 0.90962500E-01, -.67644200E-01, -.71102400E-02, 0.86207900E-02, -.11041600E+01, 0.27172200E-01, 0.14108100E-01, 0.56957000E+00, -.42882100E+00, -.16410700E+00, -.12079900E+00, -.15724400E+00, -.10916800E+00, -.28023800E-01, -.62943000E-02, 0.20732200E+00, -.13014500E+00, -.49390300E+00, -.18265100E+00, 0.31105300E+00, 0.53687900E+00, -.93321900E-01, 0.20168700E+00, -.48567400E-01, 0.31359500E+00, 0.23266900E-01, -.23455800E-01, 0.24683900E+01, -.70295800E+00, 0.14125200E+01, -.63232500E+00, -.17164600E+00, 0.92302300E-01, -.26656900E+00, -.14022200E-01, 0.23042700E+00, 0.46365500E-01, 0.50331100E-01, -.14739200E+00, -.20063000E+00, 0.12406100E+00, 0.13422700E+00, -.49749400E+00, 0.11954100E+00, -.71588800E+00, -.61500500E-01, -.19474600E+00, -.28675200E-02, -.24477400E+00, -.20684400E+00, -.46030500E+00, -.10105500E+01, 0.26796300E-01, 0.62698800E+00, -.28440700E+00, 0.72597900E-01, -.12009900E+00, 0.32326100E-01, 0.35668700E-02, -.19106200E+00, 0.30725800E+00, 0.17377800E+01, -.24085700E+00, 0.33861100E+00, 0.12319800E+00, -.35999400E+00, -.36068500E+00, 0.27851600E-01, 0.10836100E+00, 0.10834000E-01, -.13703200E+00, -.10962800E+01, -.27449400E-01, 0.34988700E+00, 0.68206800E+00, -.84035600E+00, -.51373300E+00, 0.97919000E-02, 0.13519300E-01, -.91739100E-01, 0.21068300E-01, -.29255900E+00, 0.21016800E-01, 0.25114000E+00, -.10055200E+00, -.21603200E+00, 0.51252500E+00, -.16086300E+00, -.58335800E+00, 0.48199900E+00, -.73455600E-02, 0.45008000E-03, -.21846800E+00, 0.93155900E-01, -.78402500E-01, -.63360800E+00, 0.50133300E-01, -.16489300E+00, 0.60465400E+00, 0.11493700E+00, -.45322300E-01, -.27505500E+00, -.47674800E-01, -.21017100E+00, 0.70130900E-01, 0.23183100E+03, 0.38858800E+03, 0.45616400E+02, -.14834600E+02, 0.18408300E+03, 0.32632400E+03, -.12345300E+03, -.23621100E+03, -.16322200E+03, -.26622300E+03, -.67717700E+02, 0.19042500E+02, 0.22290400E+03, -.18012600E+03, -.27805300E+01, 0.35389800E+03, 0.46500700E+03, -.24659800E+03, 0.31250300E+02, -.23207100E+03, -.11186300E+03, -.95680800E+02, -.96529200E+02, -.11369500E+02, -.90083100E+02, -.84283200E+02, 0.30014600E+02, 0.64475000E+03, -.32440000E+03, -.78765900E+02, -.32897400E+03, 0.11738300E+03, 0.18641200E+03, -.15715600E+03, 0.87252400E+02, -.31222800E+03, 0.15881300E+03, -.25882000E+03, 0.80972200E+02, -.55955200E+02, 0.10313000E+03, -.41844700E+02, -.23188300E+01, 0.25702400E+02, -.13529900E+03, -.77283300E+02, -.60879000E+02, 0.33574600E+02, 0.21899300E+03, -.38315000E+03, 0.18781300E+03, 0.56950800E+02, 0.18923500E+03, 0.44951400E+02, 0.56175300E+02, 0.32928200E+02, 0.10483600E+02, 0.74030800E+02, 0.44860000E+02, 0.14487400E+03, -.35152500E+03, 0.17686800E+03, 0.11140200E+03, 0.17207100E+03, 0.14684400E+03, 0.83013000E+02, -.61249000E+02, -.80410300E+02, 0.13350400E+03, 0.83713600E+02, 0.21053200E+03, 0.11877300E+04, -.56932600E+03, -.51539800E+03, -.59391200E+03, -.26310600E+03, -.14360400E+03, -.10134800E+03, 0.33407000E+03, -.35342200E+03, -.80360500E+02, -.16952000E+03, -.23998800E+03, 0.12201500E+03, 0.22536800E+03, 0.12001100E+03, 0.26355500E+02, 0.13570600E+02, 0.24819800E+02, -.19639400E+02, 0.43626200E+02, 0.13322200E+02, 0.46532000E+03, -.11077200E+03, 0.33461800E+02, -.44957400E+02, 0.55704700E+02, -.10474300E+02, 0.35232900E+02, -.80078300E+02, -.14818000E+03, 0.44338400E+02, -.50026100E+02, -.92107900E+02, -.17400300E+02, 0.72321300E+01, -.64968400E+02, 0.10782600E+02, -.12305500E+03, -.86477800E+02, -.80176200E+02, -.99862800E+02, 0.13697000E+02, -.61088100E+02, 0.51066000E+02, -.72263300E+02, 0.22074000E+02, 0.35718600E+02, 0.33657300E+02, -.14438700E+02, 0.53470200E+01, -.10062700E+03, 0.10652600E+03, 0.12257800E+03, -.30017300E+02, 0.75037600E+03, -.14176900E+01, -.68156100E+01, -.66865100E+02, -.77676700E+02, -.19067300E+01, 0.12233300E+02, -.14029300E+01, -.38946600E+02, -.31882900E+01, -.78196500E+01, -.99199700E+01, -.71235300E+01, -.96879100E+01, 0.28660100E+01, -.14827500E+02, -.21885600E+02, 0.79274200E+02, -.19331400E+02, -.62920400E+02, 0.72107600E+01, -.13232700E+02, 0.43882800E+02, -.51363200E+02, 0.11921500E+02, -.99653800E+01, -.12455400E+02 },
        { 0.39302800E+00, -.10257400E-01, -.23721700E+00, -.15322900E+00, -.17722200E+00, -.21026100E-01, -.10283200E+00, 0.43705900E+00, 0.27562400E-01, -.63783900E-01, 0.52663900E-01, 0.13124100E-01, -.50467400E-01, 0.13807200E-01, 0.36001700E-01, -.94775200E+00, -.39142100E+00, -.18325300E+00, -.62636800E-01, -.22559700E-01, -.65270400E-01, 0.54493500E-01, 0.12927600E-01, 0.21163400E-01, 0.35738900E-01, 0.53023700E-02, 0.29400200E-01, 0.33651800E-01, -.35137200E-01, -.77336900E-02, 0.17433400E-01, 0.74671100E-01, 0.77131000E-02, -.25031800E+00, 0.22983800E-02, 0.19163700E-02, -.89230600E-02, -.65045400E-01, -.10678700E-01, -.12930900E-01, -.17401100E+00, -.14388800E-01, 0.73198600E-02, -.31348300E-02, 0.19569600E-01, 0.23023100E-01, -.56899100E-02, -.17879800E-02, 0.73903100E-01, -.84451800E-02, 0.46538200E-01, -.96390200E-01, 0.28766000E-01, -.22196200E+00, -.11631400E-01, -.89187900E-01, -.78964300E-01, -.43877000E-02, -.13353000E-02, -.58270600E-01, -.19830000E-02, 0.75824400E-01, -.36018700E-01, -.20053900E-01, -.29757800E-01, 0.16153600E-01, -.68128000E-01, 0.12524800E-01, 0.14467600E+00, 0.11283700E-02, -.13129100E-01, 0.31123400E+00, 0.14127300E+00, 0.30373500E+00, -.66117300E-01, -.41286700E-01, 0.13830700E-01, -.45792300E-01, -.76304800E-01, -.27523800E-02, -.79367600E-02, 0.82238200E-02, 0.72413000E-02, -.34287500E-01, -.14147800E-01, 0.20985800E-01, -.11361500E-01, 0.40477600E-03, 0.92107300E-02, 0.10231700E-02, -.89127400E-02, 0.76817700E-04, 0.52853900E-01, -.31513200E-02, -.56173600E-01, 0.53156000E-01, 0.17220100E-01, 0.50227400E-01, 0.28082100E-02, 0.43730800E-01, -.39503600E-02, 0.28179500E-01, 0.11598700E-02, 0.35569400E-01, -.11084800E-01, 0.38671600E+00, -.60669500E-02, -.38433900E-02, 0.12115200E-01, -.94410600E-02, 0.35566500E-01, 0.20174900E-04, -.96616200E-02, 0.44759700E-03, 0.26960600E-01, 0.31775900E-01, -.24919500E-01, 0.10821100E-01, -.10247000E+00, 0.32337800E+00, 0.27194300E-02, 0.41506300E-02, 0.23737500E-01, -.22887900E-01, 0.46302500E-02, -.24363100E-01, -.21679100E-01, -.24905100E-01, -.67786700E-02, -.21356400E-01, 0.62247300E-01, 0.63169700E-01, 0.12608800E+00, -.13688600E+00, 0.26796600E-01, 0.62580100E-02, -.73107700E-01, -.61121100E-01, 0.10450500E-01, 0.10546900E+00, -.45523300E-01, -.21146000E-01, -.20891400E-01, -.21230200E-01, -.91924600E-02, 0.91373500E-02, -.95297500E-02, 0.42234700E-01, 0.23804700E-01, 0.67789000E-01, -.31810100E+02, -.12801700E+02, -.16800300E+01, -.31093200E+02, -.58909800E+02, 0.38687500E+02, 0.92500800E+02, 0.29431800E+02, -.69772800E+01, 0.11454900E+02, -.30360700E+01, -.58243100E+02, -.24349300E+02, 0.25524200E+01, -.59621800E+02, 0.29823900E+02, -.14729200E+02, -.27582900E+02, -.14821300E+02, -.78396600E+01, -.19253100E+02, 0.12402800E+02, 0.22480200E+02, 0.67774700E+01, -.14899700E+02, -.47486100E+02, -.32445300E+02, 0.15126900E+02, 0.98048900E+01, 0.15047500E+02, 0.45231500E+01, -.35000900E+01, 0.10213500E+02, 0.67966900E+01, 0.30140600E+02, -.62677700E+01, 0.24785000E+01, -.32643100E+02, 0.16492900E+02, 0.70354100E+01, 0.16041700E+02, 0.29435800E+01, -.15586100E+02, 0.29086400E+02, 0.12759900E+02, 0.68533700E+01, -.11424600E+02, -.53329000E+02, -.41230100E+02, 0.20583800E+02, 0.17406200E+02, 0.20130900E+02, -.10418500E+02, -.19417200E+02, 0.32371000E+02, -.66712300E+01, -.10197500E+02, -.11333200E+02, 0.26445700E+01, -.70645900E+02, 0.35246300E+02, 0.49469400E+02, 0.35184700E+02, 0.39219500E+01, 0.18538000E+02, 0.79453300E+01, -.83089100E+01, 0.18754300E+02, 0.68637400E+01, 0.31943600E+02, -.11573700E+03, 0.61820000E+02, 0.11342800E+03, 0.57842000E+02, 0.40891400E+01, 0.22801900E+01, 0.20502400E+02, -.51253600E+02, 0.37030500E+01, -.21956500E+01, -.36168100E+02, -.69977100E+02, 0.35670100E+02, 0.53298300E+02, 0.34986700E+02, 0.89669800E+01, 0.10979200E+02, 0.11242900E+02, -.28165500E+02, -.46039000E+01, 0.39932100E+01, -.10414000E+02, 0.12983400E+02, -.10175600E+02, -.26791300E+02, -.63129700E+01, 0.34908100E+01, -.11037800E+02, 0.57849200E+01, 0.25663300E+02, 0.84254300E+01, -.52202900E+01, 0.43681200E+02, 0.17079700E+02, -.76582500E+01, -.46311200E+00, -.83402100E+01, -.70021700E+01, -.46490400E+01, 0.69712700E+01, 0.12889000E+02, -.12727800E+02, -.79017100E+01, 0.10218800E+02, -.20498300E+02, 0.82937700E+01, 0.39351500E+02, 0.10307400E+02, -.62397100E+00, -.94877300E+00, -.23713900E+01, -.11819500E+02, 0.11710800E+01, -.94037500E+00, -.11354600E+02, -.28466700E+01, -.40028200E-01, 0.64600900E+01, 0.78737200E+01, 0.21009100E+00, 0.13453800E+01, -.14657400E+01, 0.13005800E+01, -.40796100E+00, 0.10440600E+01, 0.18072200E+01, 0.30570600E+00, -.13956500E+01, -.70491300E+00, 0.14682400E+01, -.50349900E+01, -.57448300E+01, -.11639700E+01, 0.37001500E+01, -.11037400E+00, -.36822500E+01, -.11075600E+01, 0.13154400E+02, -.20793200E+01, 0.19639700E+00, 0.14472700E+01 },
        { -.41851500E+01, -.11233700E+01, -.57736300E+00, 0.14189400E+01, 0.64609600E+00, 0.82944400E+00, 0.74346600E+00, -.11766900E+01, -.30613500E+00, 0.24589600E+00, 0.37490100E+00, 0.72566700E+00, 0.40047200E+00, -.19398300E+00, -.69877900E+00, 0.70135400E+01, -.28706500E+01, -.15883600E+01, 0.27436600E+01, -.17111500E+00, -.57107800E+00, 0.72215400E-01, 0.14581500E+00, 0.19721300E+01, -.27221800E+00, 0.28621000E-01, 0.49147200E+00, 0.20449300E+01, -.91103200E+00, 0.11396600E+00, -.30032900E+00, 0.10483700E+01, 0.25166900E-01, -.10710200E+01, 0.29796200E-01, 0.24927500E-01, -.43288200E-01, -.10783600E-01, -.20862600E+00, -.43674500E+00, 0.22725200E+01, 0.82536300E-01, 0.45760600E-01, 0.29152700E+00, -.27941800E+00, -.62967400E+00, 0.11400300E+00, -.71442700E-01, -.92404900E+00, 0.18988300E+00, -.93520900E+00, 0.89180000E+00, 0.40632900E+00, 0.22417800E+01, 0.38357300E+00, 0.23238700E+01, 0.12087300E+01, -.46086400E-01, -.56121700E-01, 0.39250900E-01, 0.84721100E-01, -.22787700E+00, 0.43813400E+00, -.82117400E+00, -.89706700E+00, 0.19187900E+00, 0.15053600E+01, 0.43528400E+00, -.80205500E+00, -.47346700E-01, -.97377000E-01, 0.14109600E+01, 0.39650400E+00, -.99912200E+00, 0.18440700E-01, -.10333200E+01, -.10849700E+00, 0.24703300E+00, -.67275800E+00, -.12982100E+00, 0.22534300E-02, 0.10641200E+00, 0.18916000E+00, 0.10998700E+01, -.12072200E+00, -.48711500E+00, -.40089100E+00, 0.31542600E+00, -.71764600E+00, 0.10982200E+00, -.10367000E+01, -.39719100E-02, -.48741500E+00, -.65098700E-01, 0.12829200E+01, 0.50939200E+00, 0.29532500E+00, 0.47175700E-01, 0.27369700E-01, 0.22585300E+00, 0.21047900E-01, 0.36690100E-01, 0.32323000E-02, -.75422500E+00, 0.27293500E+00, 0.17799300E+01, -.64111400E+00, 0.75398800E+00, 0.18607100E+00, -.26167600E+00, -.35665600E+00, -.38269100E-02, 0.37146400E+00, 0.12304900E-01, -.17684200E+00, -.24467900E+00, -.12372100E+00, 0.45188200E+00, -.64409800E+00, -.38016000E+00, -.18769200E-01, -.65961200E-01, -.10284800E+00, 0.54860200E-02, -.68344500E-01, 0.38534400E+00, 0.57909300E+00, -.11064800E+01, 0.36528300E-01, -.33473600E+00, 0.81695700E+00, -.35542400E+00, -.10540200E+01, 0.59958100E+00, 0.69857600E-01, -.16733300E-01, -.23319400E+00, -.20881000E+00, -.28386500E+00, -.60265200E+00, -.64031800E+00, -.11692300E+00, 0.80991100E+00, 0.29982600E+00, -.43216700E-01, 0.49727800E+00, 0.62361800E-01, -.50342400E+00, 0.83321000E-01, 0.11815900E+01, 0.66312100E+01, -.11191900E+03, 0.66665200E+02, -.31656700E+03, -.16822800E+04, 0.80115900E+03, -.32913000E+03, 0.84127800E+03, 0.34139300E+03, 0.33099400E+03, 0.83976100E+02, -.37758400E+03, 0.76416400E+03, 0.24742600E+03, 0.10952800E+04, -.98892500E+03, 0.46939900E+03, 0.38219200E+03, 0.49347700E+03, 0.10095900E+03, 0.15681200E+02, 0.15942400E+03, -.89183900E+02, 0.27741100E+03, 0.34188300E+02, 0.18558400E+03, 0.77996800E+03, -.38511500E+03, -.33758600E+03, -.37673000E+03, 0.89285000E+02, 0.19440800E+03, -.19291800E+03, 0.17783800E+03, -.31520400E+03, 0.15374700E+03, -.12542500E+03, 0.11366900E+03, -.69689400E+02, -.82372100E+02, -.53352600E+02, -.13539900E+03, -.17402900E+03, 0.14773800E+03, 0.24654100E+03, 0.24939600E+03, -.17033700E+03, 0.54693300E+02, 0.89098100E+03, -.44747800E+03, -.18405300E+03, -.44074400E+03, -.13276800E+02, 0.83767400E+02, -.28984400E+03, 0.22196600E+03, 0.48908800E+02, -.36762400E+01, -.21441300E+03, -.34714300E+01, 0.24355300E+01, -.38581400E+03, 0.86507800E+01, -.37028600E+03, -.24317600E+03, -.22377300E+01, -.34568500E+03, -.30697000E+03, -.12062800E+03, 0.66676800E+03, -.16501200E+04, 0.81156300E+03, -.17728900E+03, 0.82517400E+03, 0.22843900E+03, 0.29711500E+03, 0.89782900E+02, -.31271300E+03, 0.72685600E+03, 0.24894800E+03, 0.11503100E+04, 0.43208400E+03, -.21740500E+03, -.56572500E+03, -.21607200E+03, -.83985200E+02, -.37749500E+02, -.81539800E+02, -.56583500E+01, -.13785100E+03, 0.14895700E+02, -.10857000E+03, 0.28794900E+03, -.12875500E+03, 0.37211000E+03, -.14472400E+03, 0.21181300E+02, -.51512000E+02, -.30111200E+01, 0.20895900E+03, 0.82936100E+02, 0.30197600E+01, -.41725100E+03, -.31361000E+02, 0.11514500E+02, 0.80351100E+02, 0.11677000E+02, 0.74019800E+02, -.76488200E+02, -.37484400E+02, -.17645700E+03, 0.78725800E+02, -.66694700E+02, -.36608500E+03, 0.18555300E+03, -.84380700E+02, -.22087500E+03, -.88290100E+02, -.99162500E+02, -.16168700E+03, 0.19702700E+03, -.98336500E+02, -.11398400E+03, -.61101800E+02, -.60366900E+03, 0.24652700E+02, 0.15042200E+01, 0.37942200E+02, 0.45265000E+02, 0.10055100E+02, -.22812500E+02, 0.12734000E+02, -.37838200E+02, 0.17073000E+02, -.68381500E+01, 0.46022500E+01, 0.11086600E+02, 0.32010400E+02, -.38386100E+01, -.40673900E+02, 0.44395700E+02, -.48027200E+02, -.24646200E+02, 0.41723300E+02, -.10559600E+02, 0.10943700E+03, -.84673600E+02, 0.13041000E+03, -.16670400E+02, -.26455300E+01, -.33998800E+01 },
        { -.44947300E+01, -.26530500E+01, 0.16049200E+01, 0.39210800E+01, 0.13745900E+00, 0.32558300E+01, 0.21715500E+01, -.77093700E+01, -.51741600E+00, -.13373400E+01, 0.90099200E-01, 0.70181500E+00, 0.13364900E+01, -.34817800E-01, -.12297400E+01, 0.14471400E+02, 0.52173900E+01, 0.45895300E+01, 0.29296400E+01, -.58940100E+00, -.51389300E+01, -.68441900E+00, -.80342900E-01, -.88143700E+00, -.39567700E+00, -.17597300E-01, -.37479300E+00, -.27653900E+01, 0.17829300E+00, 0.95036100E-01, 0.23994000E-02, -.39802100E+00, -.19874400E+00, 0.29589100E+01, 0.19132900E-01, 0.67702200E-01, 0.13031700E+00, 0.10559400E+01, 0.19257700E+00, -.75998300E+00, -.13886400E+00, 0.51394800E+00, 0.28207000E+00, 0.74832300E-01, 0.29261400E+00, 0.20676800E+00, -.13800300E-01, 0.56356000E-01, -.48114200E+01, -.12028900E+00, 0.20748800E+00, -.43124400E+00, 0.86883400E+00, -.29897000E+01, -.47402400E+00, 0.13055600E+01, 0.41984700E-01, -.56032400E-01, 0.23714200E+00, -.12283200E+00, -.68640700E+00, 0.25804500E+01, -.71097900E-01, -.57551500E+00, -.37931100E+00, -.10628800E-01, 0.26080000E+00, -.15113300E+00, -.23950500E+00, 0.34069700E-01, -.13342100E+00, -.18238800E+01, -.13292600E+01, -.13317500E+01, -.45942400E+00, -.11733900E+00, 0.92145700E-01, -.21037500E+00, -.29450300E+00, 0.43528100E+00, -.19795700E+00, 0.16364300E+00, -.27200000E+00, -.93212200E+00, -.18837200E+00, 0.34261200E+00, 0.39984400E+00, 0.13344400E+00, 0.11577100E+01, 0.11287800E+00, -.11099800E+01, -.39589100E-02, -.15117300E-01, 0.27837900E+00, 0.19728700E+01, 0.81508600E+00, 0.45983300E+00, -.97892100E+00, 0.47469000E+00, -.66200900E+00, 0.25115500E+00, -.10028300E+00, -.13516900E-01, 0.39152100E+00, -.24252900E+00, 0.65129900E+01, -.75461200E+00, -.24220800E+00, -.28977900E+00, 0.12244300E+00, 0.10215200E+01, 0.18837700E-01, 0.16346600E+01, -.87476200E-01, 0.15020000E+00, 0.24632600E+00, 0.46011300E+00, -.77903300E+00, -.40371400E+01, 0.74621900E-01, -.15626600E+01, 0.12463000E+00, -.37934300E-01, -.55900900E-01, 0.11232700E+00, 0.43853500E+00, 0.26685500E+00, -.37282700E+00, -.12623700E+00, 0.51151200E+00, -.15587400E+01, 0.42762400E+00, 0.80249700E+00, -.14625600E+01, 0.35230500E+00, 0.40714900E-01, -.36409600E+00, -.10549800E+01, 0.37195100E+00, 0.97547100E-01, -.65396000E+00, -.44225300E+00, 0.77185000E+00, -.13339300E+01, -.18494100E+00, -.13152300E+01, -.23170100E+00, 0.55415900E+00, -.18816300E+00, 0.50729600E+00, 0.74361300E+01, 0.69361900E+00, -.11870900E+03, 0.61048900E+03, 0.39246800E+03, -.27669900E+03, -.70935800E+03, -.19639100E+03, 0.40475000E+03, 0.13352600E+03, 0.33185200E+03, 0.86548300E+03, -.26998400E+03, 0.11042400E+03, -.56462300E+03, -.15542800E+04, 0.72369400E+03, 0.11065900E+04, 0.77799300E+03, 0.32185100E+02, -.56687000E+02, 0.14059800E+03, -.95473000E+03, -.51339800E+02, 0.18410200E+02, 0.15576000E+04, 0.36179900E+02, 0.78084000E+00, 0.23752600E+03, -.43434900E+02, -.80556200E+02, -.29417800E+03, 0.54227000E+02, -.45841800E+03, 0.48166700E+00, -.19163100E+03, -.30721000E+03, -.11952900E+04, 0.54844400E+03, 0.56616000E+03, 0.60162300E+03, -.46911200E+02, -.19115900E+02, -.12907500E+03, -.97934700E+03, -.81438600E+02, 0.99323600E+02, 0.16676600E+04, -.25249300E+01, -.35571500E+02, -.32644500E+03, -.59008300E+01, -.50659500E+02, -.90577700E+02, -.78418300E+02, -.17844000E+03, 0.13255200E+02, 0.37406000E+02, 0.17660800E+03, 0.12025100E+04, -.58889400E+03, -.25043700E+03, -.61298600E+03, 0.51992400E+03, -.31306000E+03, 0.20488700E+03, 0.10233600E+04, 0.20995900E+03, -.28362700E+03, -.22545900E+04, 0.14022400E+04, -.69333600E+03, -.10838900E+04, -.70122000E+03, 0.36615800E+02, 0.70147000E+02, -.41266200E+01, 0.67983700E+03, -.49031100E+03, -.51641300E+02, -.55878600E+03, -.22208500E+03, 0.99054100E+02, 0.23113100E+03, 0.11109900E+03, 0.20376900E+03, 0.11455700E+03, -.13615000E+03, -.45468600E+02, 0.24638200E+02, 0.13736600E+03, 0.65416900E+02, -.37356200E+03, 0.18136500E+03, 0.15883400E+03, 0.18771600E+03, -.40240000E+03, 0.22424200E+03, -.35705800E+03, -.84257000E+03, -.22005300E+03, 0.14795900E+03, 0.80235000E+03, -.58677600E+03, 0.26188800E+03, -.92302900E+02, 0.29999900E+03, 0.13742500E+02, 0.34473900E+03, -.10545400E+03, 0.21249800E+03, 0.20584700E+02, 0.30695600E+03, 0.59168200E+03, -.37000200E+03, 0.15080400E+03, -.75691000E+02, 0.17706600E+03, 0.25066400E+03, 0.38822800E+03, -.10519400E+03, 0.44237800E+03, 0.38857700E+03, 0.15854300E+03, 0.10860300E+04, -.27046600E+02, -.45769300E+01, -.13994300E+03, -.16366700E+03, -.21969700E+02, 0.15955700E+02, -.70684600E+02, 0.68359700E+02, -.26312500E+02, 0.26918800E+00, 0.80912000E+01, -.27897300E+02, -.46124900E+02, 0.21170000E+02, 0.67846300E+02, -.22002200E+03, 0.13524100E+03, 0.12336800E+03, -.10563400E+03, 0.13293100E+02, -.52300600E+02, 0.13209200E+03, 0.30424500E+03, 0.76449100E+01, 0.40381200E+02, 0.28491000E+02 },
        { 0.20277100E+01, 0.25278600E+00, -.51003900E+00, -.70524700E+00, -.83872600E+00, -.28679600E+00, -.10068600E+01, 0.22291800E+01, 0.51254400E-01, 0.90617900E+00, 0.12838600E-01, -.14730500E+00, -.37889300E+00, -.39696800E-01, 0.33828200E+00, -.11851500E+02, -.21318100E+01, -.17349300E+01, -.14153700E+01, 0.50168400E-01, 0.15088700E+01, 0.70190800E-01, 0.15251000E+00, 0.76822400E-02, 0.20608700E+00, 0.47238800E-01, 0.56463600E+00, 0.21001600E+00, -.13182700E+01, -.46438900E-01, 0.16149400E+00, 0.43313200E+00, 0.21320000E+00, -.25987600E+01, 0.44262400E-02, 0.50278700E-01, 0.18170600E-02, -.27480500E-01, 0.49629400E-01, -.18851700E+00, -.41089600E+00, 0.24426300E+00, 0.38734400E-01, 0.67479500E-01, -.12177100E+00, -.43135400E-01, 0.31816200E-02, -.80905500E-02, -.49851700E+00, -.57300300E-01, -.12638600E+00, 0.10682100E+00, -.79953600E-01, -.27938800E+00, -.41191700E-01, 0.22639900E+00, -.14215400E+00, 0.31744100E-03, -.60570700E-03, -.30646600E+00, 0.22450700E-01, -.20706900E+00, -.59077100E-01, 0.14359500E-01, -.28047100E-02, 0.15246900E+00, -.12912500E+00, -.60308900E-01, 0.13162400E+00, -.13504600E-03, -.62400600E-02, 0.23522700E+00, -.12348400E+00, 0.35156300E+00, -.25737100E-01, -.54546900E+00, 0.21986100E-01, 0.12210300E-01, -.70150000E-01, -.21663400E-01, 0.49948600E-02, 0.24512100E-01, -.45687500E-01, 0.15224000E-02, -.11657200E-02, -.67008600E-01, -.16868300E+00, -.27259000E-01, 0.51054600E-01, -.47447000E-02, -.13094500E+00, 0.29606200E-03, 0.30661000E+00, 0.36935700E-01, -.39316900E+00, 0.54938400E-01, -.66862500E-01, -.57101000E-01, -.15438000E-01, -.16137900E+00, -.72936000E-02, -.23315200E-02, -.13638100E-01, 0.13372500E+00, -.46171100E-01, 0.97248100E+00, 0.25458700E+00, -.43526000E-01, 0.13945400E-01, 0.22829300E+00, 0.83663900E-01, -.75540600E-02, 0.16594900E+00, -.24165900E-02, -.63898100E-01, 0.24918100E-01, -.15198800E-01, 0.42348400E-01, -.87778700E-01, 0.25300400E+00, 0.31704700E+00, 0.14356700E-02, 0.72373500E-02, -.13759300E+00, 0.57861500E-02, -.43166600E-01, 0.10147500E+00, -.15509600E+00, -.22758000E+00, 0.83989800E-01, -.34183500E+00, 0.13767000E-01, 0.34819200E-01, 0.10250900E-01, -.20368300E-01, -.10622200E-01, 0.30310700E+00, 0.14642000E+00, -.85521000E-02, -.23862400E+00, -.30079200E+00, -.18906700E-01, -.45935800E+00, -.30661400E-01, 0.20599400E-01, -.19207100E+00, 0.79765900E-02, -.14578900E-01, 0.17154100E-02, -.28154100E+00, 0.94699800E+00, 0.11746600E+00, -.14167900E+00, 0.21707400E+03, 0.43156300E+02, -.18690500E+02, 0.74434300E+01, -.21601500E+02, 0.10674000E+03, 0.15956000E+02, 0.96160700E+02, 0.29216800E+03, -.54742200E+02, 0.23154300E+02, -.66784900E+02, -.17761800E+03, 0.76759900E+02, 0.16913200E+03, 0.89104900E+02, -.23230500E+01, -.62908700E+00, 0.10942800E+02, -.18995900E+03, -.56904500E+02, 0.17530100E+02, 0.30142500E+03, -.12265500E+03, 0.64487500E+02, 0.74741700E+02, 0.57020300E+02, -.36055100E+02, -.94772400E+02, 0.49281100E+02, -.12517200E+03, 0.15230100E+02, -.57056900E+02, -.87855600E+02, -.35201400E+03, 0.16240000E+03, 0.17484300E+03, 0.17585100E+03, 0.30502000E+02, 0.45960500E+02, -.29815800E+02, -.26277200E+03, -.77773100E+02, 0.79917000E+02, 0.35158200E+03, -.15307400E+03, 0.71019200E+02, -.14108400E+02, 0.75140800E+02, 0.45458800E+01, -.11125600E+01, 0.15085600E+02, -.90839100E+02, -.43370400E+02, 0.36277900E+02, 0.67786400E+02, 0.20467300E+03, -.99344300E+02, 0.57942900E+02, -.10535800E+03, 0.19232500E+03, 0.32058200E+02, 0.88390800E+01, 0.29384700E+03, 0.16183500E+03, -.14969100E+02, -.54408500E+03, 0.40185800E+03, -.19081200E+03, -.18633500E+03, -.20093600E+03, 0.16553200E+02, -.15012700E+02, 0.68688400E+01, 0.24635200E+03, -.13833600E+03, -.27358600E+02, -.16594900E+03, -.14783700E+03, 0.73108700E+02, 0.15299000E+03, 0.73935800E+02, 0.65222900E+02, 0.29050700E+02, 0.49870400E+01, -.35127400E+01, 0.14317100E+02, 0.32640400E+02, 0.13140100E+03, -.26256600E+03, 0.12164500E+03, 0.38871500E+02, 0.13132300E+03, -.68211200E+02, 0.66217100E+02, -.47201600E+02, -.28335000E+03, -.83204900E+02, 0.50311300E+02, 0.20423200E+03, -.18890300E+03, 0.87954500E+02, -.47140800E+02, 0.95990800E+02, 0.48782700E+00, 0.86463000E+02, -.16457800E+02, 0.52060000E+02, 0.63918500E+01, 0.83609300E+02, 0.25334400E+03, -.10133200E+03, 0.38363600E+02, -.69338000E+02, 0.48445100E+02, 0.72695100E+02, 0.67372600E+02, -.24972000E+02, 0.17970000E+03, 0.15500400E+03, -.89765400E+01, 0.48146500E+03, -.61596700E+01, -.40281500E+01, -.45563800E+02, -.50504200E+02, -.11751500E+02, 0.98904900E+01, -.31338800E+01, 0.21354400E+02, -.51128500E+01, -.23473700E+01, -.59854900E+01, -.12513900E+02, -.10124700E+02, 0.11061700E+02, 0.21374600E+02, -.45521300E+02, 0.45151300E+02, 0.34943000E+02, -.38629100E+02, 0.78756500E+01, -.35551800E+02, 0.33317300E+02, 0.11001700E+02, 0.12139100E+02, 0.12267500E+02, 0.10235800E+01 },
        { 0.10100600E+02, 0.39631100E+01, 0.79930200E+01, 0.23695800E+01, -.17149700E+01, -.36978400E+01, -.27665700E+01, 0.11595900E+02, 0.45753800E+00, 0.44851400E+01, -.96862500E+00, -.18990200E+01, -.25695800E+01, 0.17051500E+01, 0.10890400E+01, -.19039400E+02, -.10433300E+01, -.36321200E+01, -.19757500E+01, 0.22044800E+01, 0.35030300E+01, -.12469500E+01, 0.11770700E+00, -.20228700E+01, 0.10885900E+01, 0.33717500E+00, 0.13481400E+01, -.28037300E+01, -.36610600E+01, 0.25607100E+00, 0.79824500E+00, -.21226300E+01, 0.85709600E+00, 0.10384600E+02, 0.13834500E-02, 0.76814800E+00, 0.49628400E-01, -.11936400E+01, 0.78442600E+00, -.11997900E+01, -.24485500E+01, 0.15319000E+01, 0.27969100E+00, 0.41255900E-01, -.62048700E-01, -.14504500E+01, 0.14424200E+00, -.27672400E-01, -.36526200E+01, -.42796600E+00, 0.19685300E+00, 0.36488600E+01, -.20228400E+01, 0.45749500E+01, -.30960400E+00, 0.16056700E+01, 0.65734500E+00, -.10754800E+00, -.10325500E+00, 0.40275000E-01, 0.42848800E+00, -.30715800E+01, 0.11848500E+01, 0.15793500E+01, 0.25308600E+01, 0.19561400E+01, -.23080100E+01, -.10767700E+01, -.55803300E-02, -.58680200E-02, -.15226800E+00, -.11685400E+01, -.15064100E+01, -.25932000E+01, -.55584000E+00, 0.80449700E+00, 0.13567600E+00, -.14506000E+01, 0.30829300E+00, 0.77124900E+00, 0.13974500E-01, 0.16853300E+00, -.79279700E+00, -.12872100E+01, 0.11426700E+00, -.19824100E-01, -.41364000E+00, -.26827000E+00, 0.18254700E+01, -.99693100E-01, -.88010800E-01, 0.48711300E-02, 0.75411500E+00, -.33176500E+00, -.55262200E+00, -.73081800E+00, -.10089800E+01, -.10990800E+01, -.25366900E+00, 0.25169600E+00, -.21875300E+00, 0.81601700E+00, 0.85080600E-01, -.23700900E+00, -.10411600E+01, -.99070200E+01, 0.16517200E+01, 0.84161700E+00, -.91347900E+00, -.29706600E+01, -.34991500E+00, 0.74823800E-01, -.38042400E+01, -.59323000E-01, -.28257100E+01, 0.76602700E+00, -.68197000E-01, 0.14058000E+01, 0.40291500E+01, 0.11005400E+01, 0.29925500E+01, 0.33296300E-01, 0.65183800E-01, -.10618500E+01, 0.54369600E-01, -.60063000E+00, 0.34901300E+01, 0.45473000E+01, -.61047700E+00, -.60006600E+00, -.18047600E+01, 0.14481000E+01, -.14267100E+01, -.10571200E+01, -.11562300E+01, 0.36338600E-01, -.76294900E+00, 0.33182500E-02, -.77926300E+00, 0.10836000E+01, 0.37691800E+01, 0.58840100E+00, 0.45494300E+00, 0.45080900E+00, 0.83439800E-02, 0.43606700E+01, 0.11322400E+00, -.22311900E+01, 0.24791200E+00, 0.30193500E+01, -.23262000E+01, -.27470000E+01, -.60197000E+00, -.38399400E+01, -.79908600E+04, 0.39064600E+04, 0.10561100E+04, 0.39955000E+04, 0.27531500E+04, 0.18641100E+04, 0.75271800E+03, -.12211700E+04, 0.27281000E+04, 0.11705100E+04, 0.37133800E+04, -.58494000E+04, 0.27351400E+04, 0.32221400E+04, 0.29237800E+04, 0.53717900E+03, -.14992500E+03, 0.10487800E+04, -.11809500E+04, 0.96471400E+03, 0.69829400E+02, 0.21563900E+04, 0.16618700E+04, -.80679300E+03, -.22549600E+03, -.82389800E+03, 0.22541100E+02, 0.58363500E+02, -.46806400E+03, -.44815600E+03, -.66733300E+03, 0.46974400E+02, -.71748100E+03, -.30125000E+04, 0.13946100E+04, 0.14857600E+04, 0.15215200E+04, -.18201300E+03, -.63374700E+03, 0.93466400E+03, -.52005900E+03, 0.68595800E+03, -.40086100E+03, 0.17887600E+04, 0.20084000E+04, -.10677300E+04, -.37193400E+03, -.10002500E+04, -.20006000E+03, 0.11214000E+03, -.86365700E+03, -.42442200E+02, -.36655400E+03, 0.50246100E+02, -.62389500E+03, 0.28428800E+04, -.14029200E+04, -.22765600E+04, -.14127500E+04, -.57963700E+03, -.74027400E+03, -.52037000E+03, -.22860200E+03, -.13370700E+04, -.55158400E+03, -.82247500E+03, -.72611000E+04, 0.36729200E+04, 0.44466300E+03, 0.36305700E+04, 0.17667000E+04, 0.15389900E+04, 0.62249700E+03, -.94830100E+03, 0.28254200E+04, 0.90382400E+03, 0.44850700E+04, 0.11525700E+03, -.65870100E+02, -.13486600E+04, -.57680500E+02, 0.19986900E+03, 0.18634100E+03, -.33464200E+03, -.47165100E+03, -.39580800E+03, 0.23071800E+03, 0.68810200E+02, 0.36397700E+03, -.20283200E+03, 0.10363700E+04, -.18203700E+03, -.40321100E+03, 0.71230600E+02, -.47639600E+03, -.50074800E+03, -.36973400E+03, 0.38387000E+03, -.57091200E+03, -.15357600E+04, 0.72513000E+03, 0.54038100E+03, 0.76351900E+03, 0.55906400E+03, 0.21899600E+03, 0.21423300E+03, 0.15960300E+03, 0.44769800E+03, 0.18561900E+03, 0.24267200E+03, -.65040900E+03, 0.27622800E+03, -.21566200E+03, 0.33168600E+03, 0.11120700E+03, -.36835200E+03, 0.57016900E+03, 0.38687700E+03, -.13926800E+03, -.35714300E+03, -.25138400E+03, -.73802800E+02, -.28600100E+02, 0.21177300E+03, 0.24772700E+03, -.60497800E+01, -.75722700E+02, 0.13720100E+02, 0.31934200E+02, 0.54344400E+02, -.49939500E+02, 0.27895200E+02, 0.33130300E+02, 0.71618700E+02, 0.17536400E+02, 0.35680500E+02, -.19270400E+03, -.26491300E+03, 0.21414400E+03, 0.23961700E+03, -.26583500E+02, 0.23121400E+03, -.17356500E+03, 0.82182900E+03, -.39037800E+02, 0.79308300E+02, 0.31493400E+02 },
        { 0.21587000E+01, -.91271100E-01, 0.16020400E+00, 0.36953000E+00, -.18260100E+01, -.19263600E+00, 0.51254600E+00, -.49274400E+01, 0.36456200E+00, 0.12719800E+00, -.97930200E+00, -.15843000E+00, -.72572500E+00, 0.93668600E-01, 0.22348900E+00, 0.59167400E+01, 0.17637300E+01, 0.79934300E+00, 0.17396800E+00, 0.99997500E-01, -.64479100E+00, -.26278100E+00, -.24245000E-01, -.22991500E+00, -.18353200E+00, -.61501000E-04, 0.23406300E+00, -.16906300E+00, -.21238100E+00, 0.10881100E-01, -.15503900E+00, 0.91337400E+00, -.20436400E+00, 0.18398400E+01, 0.18663900E-01, 0.14102900E+00, -.58650400E-01, -.76403200E+00, -.32938300E-01, -.37739500E+00, -.50034700E+00, 0.97580600E-01, 0.85730400E-01, -.71039100E-01, -.29414800E+00, 0.12020600E+00, -.93830200E-02, -.49585400E-01, -.90044000E+00, 0.14901400E+00, -.42437000E+00, 0.30972700E+00, -.79379600E+00, 0.21130400E+01, -.53408300E-01, 0.66868400E+00, 0.60200200E+00, 0.38041700E-01, -.55108700E-01, 0.11136200E+01, 0.61087800E-01, -.27490300E+00, 0.19672900E+00, 0.36536100E-01, 0.12555200E+00, -.26234200E+00, -.80667500E+00, 0.76242400E-01, -.12437600E+00, -.86533100E-02, -.13004800E+00, 0.11706700E+01, 0.46198500E+00, 0.24510700E+00, -.49666200E+00, 0.10954100E+00, -.22484300E-02, -.25774300E+00, -.22461200E+00, -.71754400E-02, -.22955300E-01, -.73876500E-02, -.10501600E+00, -.28315500E+00, -.11311300E-01, 0.17463900E+00, 0.44189400E-01, -.94999200E-01, 0.26134900E+00, 0.83649000E-01, 0.41866100E-01, 0.29085900E-02, 0.41366100E+00, -.16858300E-01, -.21983200E+00, 0.23925200E+00, 0.63116200E-01, -.30811300E+00, -.66824400E-01, -.22907900E-01, 0.47810000E-01, -.94921300E-01, -.23033800E-01, 0.26132500E+00, 0.90335300E-02, -.12821200E+01, -.18057400E+00, -.34669300E-01, -.60189100E-01, 0.14737300E+00, -.51380700E-01, -.36667400E-01, -.50051300E+00, -.13246300E-01, 0.80387900E-01, -.36560800E+00, 0.51380200E-01, 0.21899700E+00, -.44244100E+00, 0.43510000E+00, -.15836100E+00, 0.29058600E-01, 0.11716000E+00, 0.23267900E+00, -.43091000E-02, 0.22820100E+00, 0.26802800E+00, -.55783500E+00, -.10966500E-01, -.61289400E-01, -.15672200E+00, 0.22152000E+00, 0.51421700E+00, -.63468900E+00, 0.62369800E-01, 0.15293000E-01, -.54959500E+00, 0.31511400E-01, 0.22785800E-01, 0.13731500E+00, 0.55068400E+00, 0.20189100E+00, -.15861200E+00, 0.15120500E+00, -.77088100E-02, 0.10688000E+00, -.77772500E-02, -.45949300E+00, 0.80537800E-01, -.80519000E-01, -.11134200E+01, -.11230300E+00, 0.40756600E-02, -.31562200E+00, 0.44777100E-01, 0.52257500E+02, -.12277000E+03, 0.28105200E-01, -.99336300E+02, -.11261100E+02, 0.38636400E+02, 0.23242600E+03, 0.12597900E+02, -.41412100E+02, 0.98716400E+01, 0.35169800E+03, -.17545000E+03, 0.38033200E+01, -.17540800E+03, -.71261400E+01, 0.34729000E+02, -.90418100E+01, 0.10192800E+03, -.12530700E+03, 0.51156700E+02, -.11973600E+03, -.67255900E+02, 0.27061100E+02, -.15364000E+01, 0.29015300E+02, -.16971500E+00, -.40079400E+02, 0.28305400E+02, -.21174900E+02, 0.53043300E+01, -.30957300E+02, 0.93665500E+02, -.39838700E+03, 0.19451800E+03, 0.27535800E+03, 0.19825500E+03, 0.14018300E+03, 0.20518900E+03, -.90290300E+01, -.83357000E+02, -.23788400E+02, 0.22034400E+03, 0.52403300E+02, -.31838100E+03, 0.15469900E+03, 0.20018400E+03, 0.15877300E+03, 0.68763300E+02, 0.99308000E+02, 0.21560900E+02, -.37126200E+02, -.65904200E+01, 0.10645400E+03, 0.43471900E+01, 0.35563400E+03, -.17866700E+03, -.14547800E+03, -.18158400E+03, 0.70205900E+02, 0.65452700E+02, -.13931600E+03, 0.54400900E+02, -.20781400E+02, 0.21507900E+02, -.12627200E+03, 0.48242800E+03, -.21363600E+03, -.24896000E+03, -.24115900E+03, -.13191600E+03, -.76852200E+02, -.35634300E+02, 0.22470200E+03, -.11640000E+03, -.87404100E+02, -.26122900E+03, -.44053700E+02, 0.24498300E+02, 0.52477600E+02, 0.22056000E+02, -.16053900E+02, 0.11749900E+02, -.11579300E+02, 0.24166000E+02, 0.99767000E+01, -.46198400E+01, 0.14670900E+03, -.35695400E+02, -.65391400E+01, 0.38888400E+02, 0.17355100E+02, 0.67967500E+01, 0.40366700E+01, -.24774700E+02, -.10323400E+03, -.33093400E+02, 0.28529600E+00, -.22870500E+02, -.63282700E+02, 0.34920600E+02, 0.47721500E+02, 0.33143800E+02, -.52836800E+02, 0.76597400E+01, 0.88710000E+01, 0.66329000E+02, -.35921600E+01, 0.15436800E+02, 0.66195100E+02, -.92616100E+02, 0.29421300E+02, 0.10811800E+02, 0.43071000E+02, 0.80982500E+02, 0.40723800E+02, -.64508200E+02, 0.71313000E+02, 0.78169000E+02, 0.17606600E+02, 0.54772400E+03, 0.92050000E+00, 0.85241400E+01, 0.62646300E+01, -.11542600E+01, -.18052000E+02, 0.11036400E+02, 0.60875500E+01, -.12955900E+02, -.12582000E+02, 0.77837200E+01, 0.69122700E+01, -.12442000E+02, -.64523200E+01, 0.17871400E+02, -.12540200E+02, -.39255100E+01, 0.50748600E+01, 0.17257700E+01, 0.73014500E+01, 0.16481800E+02, -.25840600E+02, -.11173200E+02, 0.20611700E+02, -.81539700E+01, 0.36206200E+01, -.14976000E+02 },
        { 0.68698500E+01, 0.25853500E+01, 0.59776400E+01, 0.35706400E+01, -.17079400E+01, -.24514000E+01, -.18944500E+01, 0.13359600E+01, 0.23402500E-01, 0.21206200E+01, -.11382000E+01, -.10153900E+01, -.76200100E+00, 0.67080400E+00, 0.62128600E+00, -.17971300E+02, 0.28129600E+01, -.93273300E+00, -.25823500E+01, 0.18870700E+00, 0.25647500E+01, -.87476600E+00, -.27678700E-01, -.15194500E+01, 0.58871700E+00, 0.12708300E+00, 0.18855400E+00, -.32747500E+01, -.15376300E+01, 0.24985400E+00, 0.64840300E+00, -.24874800E+01, 0.22157600E+00, 0.60478100E+01, -.26552900E-01, 0.39649700E+00, 0.19178200E+00, 0.15082700E+01, 0.32249200E+00, 0.56895400E+00, 0.12257000E+01, 0.74334300E+00, -.11411300E+00, 0.16312800E+00, 0.44031800E+00, -.92097900E+00, 0.10257300E+00, 0.87857200E-01, -.10191100E+01, -.44725200E+00, 0.88196600E+00, 0.12800900E+01, 0.12155500E+00, -.26409700E+00, 0.15082900E+00, -.68828700E-01, -.32379400E+00, 0.10842800E+00, 0.59266300E-01, -.10065300E+01, -.60761500E-02, -.51477100E+00, -.60164500E-01, 0.10474200E+01, 0.90665100E+00, 0.97813700E+00, -.15275500E+01, -.70779600E+00, -.19221200E+00, 0.69399400E-02, 0.61420200E-01, -.34522100E+01, -.12291900E+01, -.87238900E+00, 0.10731000E+01, 0.52105600E+00, -.24069500E+00, 0.29378200E+00, 0.45838000E+00, 0.41481300E+00, -.43319700E-01, 0.52445800E-01, -.12248700E+00, -.22766600E+00, -.57745900E-01, -.23728900E+00, -.20342800E-01, 0.50518800E-01, 0.72038500E+00, -.75453900E-01, -.24534100E+00, -.38780600E-02, 0.41362200E+00, 0.10487100E+00, -.12166800E-01, 0.14774400E+01, -.42547700E+00, -.25653900E+00, 0.24921400E+00, 0.16591900E+00, -.15618700E-01, 0.60143800E+00, -.61279400E-02, -.39904300E+00, -.72993800E+00, -.10980300E+02, 0.10903300E+01, -.79405400E+00, -.27574400E+00, 0.10826800E+00, 0.14061500E+00, 0.29495500E-01, 0.17125400E+01, -.46395400E-01, -.14827000E+01, 0.42131200E+00, -.21970600E+00, 0.77949200E+00, 0.75777700E+00, -.67032800E+00, 0.91493900E+00, -.12222200E+00, -.18576800E+00, -.28712700E+00, -.12752800E+00, -.21877100E+00, 0.84934000E+00, -.46652800E+00, -.39608200E+00, 0.11723500E+01, -.23186800E+01, -.33628600E+00, -.59881600E+00, 0.30560800E+00, -.56765500E+00, -.11820100E+00, 0.24816300E+01, 0.62216100E+00, -.93952900E-01, -.19733600E+01, 0.54292000E+00, -.32237700E+00, -.41093400E+00, -.80693500E+00, 0.45013800E-01, 0.20428900E+01, 0.15108300E+00, -.32599800E+00, 0.14485000E+00, -.55104000E+00, -.21962000E+01, -.80239800E+00, -.39443000E+00, 0.22690800E+01, 0.34693800E+00, 0.16239300E+01, 0.18826700E+04, -.13917200E+00, -.26003700E+03, -.22421700E+03, -.25996600E+03, -.10711100E+04, -.31355800E+03, -.37882800E+01, 0.20125800E+03, 0.36841800E+03, -.14922000E+03, -.93892800E+03, -.18544600E+03, -.13049800E+03, -.18284200E+03, -.49235000E+02, 0.16712300E+03, 0.28045100E+03, -.23637600E+03, -.49315600E+03, -.15198900E+03, 0.73933700E+02, -.13289600E+03, 0.95673900E+02, 0.46343600E+02, 0.21563100E+03, 0.13827900E+02, 0.47167100E+03, 0.15882200E+03, 0.16475400E+03, 0.93549900E+02, 0.15328500E+04, -.73500000E+03, -.11079500E+04, -.76682700E+03, -.35517700E+03, -.58492500E+03, 0.12917800E+03, 0.52968600E+03, 0.41673700E+02, -.65198900E+03, -.94905100E+03, 0.12889100E+03, -.33084700E+02, -.33509500E+03, -.62595800E+02, -.19110400E+03, -.44294600E+03, 0.33673500E+03, 0.17121800E+03, 0.70095800E+02, -.45403400E+03, 0.10663000E+03, -.18803600E+04, 0.93635600E+03, 0.10500400E+04, 0.95604700E+03, -.32075000E+03, -.59910400E+01, 0.45794900E+03, -.41553600E+03, 0.21967700E+03, 0.63995500E+02, 0.12820600E+04, -.17237200E+04, 0.81790100E+03, 0.20888000E+04, 0.86159800E+03, 0.13083400E+03, 0.33487500E+01, 0.13395700E+03, -.99194300E+03, 0.15584300E+03, 0.18696200E+03, 0.68471500E+03, -.29138500E+03, 0.14863700E+03, 0.46285700E+03, 0.14557000E+03, -.10716300E+02, -.28520700E+01, 0.13976700E+03, -.84789000E+02, 0.96303400E+02, 0.24892100E+02, -.23044300E+03, 0.41130200E+02, 0.13615100E+02, -.61579800E+03, -.18542600E+02, 0.25296000E+03, 0.38656300E+02, 0.22176500E+03, 0.59498200E+03, 0.18836200E+03, 0.46539600E+02, -.17900800E+03, 0.88167100E+03, -.42754800E+03, -.33574300E+02, -.44725700E+03, 0.42348600E+02, -.17047600E+03, -.55693200E+02, -.30886900E+03, -.12579100E+03, -.19226300E+03, -.68310900E+03, 0.34488100E+03, -.13234000E+03, 0.17733600E+03, -.15882600E+03, -.32175400E+03, -.19354500E+03, 0.12680300E+03, -.44304400E+03, -.27062500E+03, -.64484400E+02, -.18004900E+04, 0.72241900E+01, -.30909800E+02, 0.25387900E+02, 0.55761300E+02, 0.67713000E+02, -.16722700E+02, -.16893600E+02, 0.60863200E+02, 0.42458600E+02, -.33037000E+02, -.39240000E+02, 0.51793900E+02, 0.11869000E+02, -.68988300E+02, 0.60968300E+02, 0.15083800E+03, -.46093900E+02, -.11804100E+03, -.19292200E+01, -.50900800E+02, 0.61880400E+02, -.26254400E+02, -.20720500E+03, 0.57586700E+02, -.46084600E+02, 0.35700400E+02 },
        { 0.65216400E+01, 0.37709400E+00, -.28208900E+01, -.17171400E+01, -.29664300E+01, -.88962500E+00, -.20503600E+01, 0.31211100E+01, 0.30406900E+00, 0.32519200E+00, -.49132200E-01, -.24131500E+00, -.64654200E+00, 0.13878700E+00, 0.20062500E+00, -.95180000E+01, -.47679200E+01, 0.12157700E+00, -.25032600E+01, -.11245700E+01, 0.55767000E+00, 0.82047600E+00, -.46000700E-01, 0.22339100E+00, 0.29095600E+00, 0.21668500E+00, 0.64495000E+00, 0.14082900E+01, -.24370500E+01, 0.41268000E-01, -.17513800E+00, 0.46662600E-01, 0.85419500E+00, -.33785800E+01, 0.52148600E-01, -.12377600E+00, -.70161200E-01, -.81084200E+00, -.15557800E+00, -.32843300E+00, 0.16972800E+01, -.19208800E+00, -.11385800E-01, 0.67561700E-01, 0.22085200E+00, 0.15960900E+00, -.43105800E-01, -.48505900E-02, 0.65346200E+00, 0.50002100E-01, 0.98576200E+00, 0.66190300E+00, -.24122900E+00, -.89883200E+00, 0.44028700E+00, -.27530600E+01, -.81809400E+00, 0.10178200E-01, -.91321800E-01, -.78379700E+00, -.12890900E+00, -.36569000E+00, -.79691600E+00, 0.22815000E+00, -.11090300E+01, 0.33901100E+00, 0.20938000E+01, 0.34075600E+00, 0.95962700E+00, 0.15066200E-01, -.80042200E-01, 0.18362100E+01, -.13970300E+01, -.27624900E+01, 0.17842200E-01, -.13093600E+01, 0.35233400E+00, -.11583900E+01, -.80763000E+00, -.55455700E-01, -.18733300E+00, 0.26122100E+00, 0.25352600E+00, 0.93064600E-01, -.26060100E+00, -.18232100E+00, -.97139300E-01, -.88748800E-01, 0.26640500E+00, -.54624300E-01, -.60440700E-01, -.66134900E-02, -.29851800E+00, 0.14254700E-01, -.35519200E+00, -.49585900E+00, -.46963100E+00, -.40825100E+00, 0.31156400E+00, -.31711600E+00, -.17198000E+00, -.16341000E+00, -.62508500E-01, 0.21697100E+00, -.24865400E+00, 0.49288800E+01, 0.74404000E+00, -.31339300E+00, 0.13762200E-01, 0.18068900E+00, 0.32152700E+00, -.12806200E-01, 0.25482100E+00, -.53543800E-01, 0.21824400E+00, 0.42863200E+00, 0.12713000E+00, -.26179000E+00, -.78821200E+00, 0.15788300E+01, -.57098400E+00, -.47385800E-01, 0.21073500E+00, -.27263000E+00, -.15882100E-01, -.35242000E+00, -.46525400E-01, 0.62568200E+00, 0.12895700E+00, 0.56416300E-01, -.25726600E+00, 0.44744700E-01, 0.14853100E+00, -.72755900E+00, 0.11882800E-01, -.66317700E-02, 0.75203000E+00, -.77270200E-01, 0.96868800E-01, -.83899300E+00, -.64719200E+00, -.42015700E+00, 0.35265500E-01, -.40496500E+00, -.15150500E+00, -.12256500E+00, -.71872100E-01, 0.68101100E+00, -.18925600E+00, 0.16383000E+00, 0.43635600E-01, 0.74730300E+00, 0.39579400E+00, 0.26265100E+00, -.24259100E+00, -.11374700E+01, 0.11391800E+00, 0.19464600E+02, -.12620400E+03, 0.18788100E+02, -.77971500E+01, 0.23924900E+03, -.14877700E+03, -.58275300E+02, -.27748200E+03, 0.49666600E+03, -.24151500E+03, -.69360600E+02, -.24757800E+03, -.29938700E+01, 0.28472700E+02, 0.12186400E+02, 0.87684700E+02, -.23187400E+03, 0.66683600E+02, -.20247600E+03, -.51387200E+03, 0.25377100E+03, 0.27773200E+03, 0.25281800E+03, -.56361300E+02, -.14577200E+03, 0.50616200E+02, -.21396000E+03, 0.17370700E+03, -.10598300E+03, 0.16397200E+03, -.67402800E+03, 0.33715700E+03, 0.38902200E+03, 0.33485200E+03, 0.19482900E+03, 0.24121600E+03, 0.55256400E+02, -.19336000E+03, -.10443800E+03, 0.29211300E+03, -.18579700E+02, -.69600600E+03, 0.32980400E+03, 0.33283200E+03, 0.34762300E+03, 0.68503300E+02, 0.11103200E+03, 0.10379300E+03, -.13867800E+03, -.59238700E+02, 0.17316600E+03, 0.44051500E+02, 0.70716400E+03, -.35466900E+03, -.19657800E+03, -.35743200E+03, 0.12052200E+03, 0.13605700E+03, -.24009300E+03, 0.10250800E+03, -.51411900E+02, 0.40455500E+02, -.49748300E+03, 0.58073600E+03, -.27252600E+03, -.70059100E+02, -.29032700E+03, -.15531400E+03, -.10071700E+03, -.56262600E+02, 0.27705600E+03, -.22896500E+03, -.14071500E+03, -.51109000E+03, -.72527300E+02, 0.35147400E+02, 0.10578800E+03, 0.36293500E+02, -.30631000E+02, 0.24614700E+02, -.28345700E+02, -.19916700E+02, -.63847300E+02, -.15394200E+02, 0.68401500E+02, -.10096900E+03, 0.34299600E+02, 0.18309300E+02, 0.49955600E+02, 0.34750600E+01, 0.75950400E+00, -.49258200E+02, -.15241900E+03, -.77914600E+02, 0.20594600E+02, 0.14435100E+03, -.73711900E+02, 0.36566600E+02, 0.11457800E+02, 0.38344900E+02, -.59981400E+02, 0.45248000E+02, 0.84709900E+02, 0.25319400E+03, -.29334800E+02, 0.35032300E+02, 0.23294800E+03, -.22241700E+03, 0.86399400E+02, 0.29007000E+03, 0.10789500E+03, 0.12518600E+03, 0.10777800E+03, -.16650100E+03, 0.26619200E+02, 0.64612400E+02, 0.67902300E+02, 0.84033900E+03, -.14937300E+02, 0.16930400E+02, 0.15779000E+02, 0.11082800E+02, -.29753500E+02, 0.14595000E+02, 0.42570900E+01, -.16557800E+02, -.23954800E+02, 0.20466800E+02, 0.21808400E+02, -.18182600E+02, -.16690000E+02, 0.25826400E+02, -.15324900E+02, -.40870600E+02, -.29046600E+01, 0.49394800E+02, 0.10259000E+02, 0.22712000E+02, -.69787900E+02, 0.82625900E-01, 0.11889500E+03, -.22758200E+02, 0.14235600E+02, -.18767700E+02 },
        { -.14200300E+01, -.57559100E+00, 0.42092100E+00, 0.72190600E+00, 0.12390700E+01, 0.25941800E+00, 0.84841900E+00, -.56089800E+00, 0.68313700E-01, 0.75784700E-01, 0.11792100E+00, 0.66490500E-01, -.53537700E-01, -.18582000E-01, -.22004000E+00, 0.62602300E+01, 0.10847000E+01, 0.24558600E+00, 0.28804900E+00, 0.16718100E+00, 0.39373200E-01, -.72650300E-01, 0.57841100E-01, 0.31102500E+00, -.56830000E-01, -.31355400E-01, -.82449800E-01, 0.46214400E+00, 0.14876800E-01, -.29138300E-01, -.35388900E+00, 0.80882600E+00, -.96946200E-01, 0.15863900E+01, 0.47861500E-01, 0.98646000E-01, -.49305800E-01, -.67517400E+00, -.96446300E-01, 0.15067200E+00, -.64304900E-01, -.11392900E+00, 0.14793000E-01, -.10764700E-01, 0.18139300E+00, 0.87898500E-01, 0.20722700E-01, -.57186900E-02, -.29813300E+00, 0.13858400E+00, -.30678700E+00, -.50548500E+00, -.22561200E+00, -.10417400E+01, 0.10213100E+00, 0.34668100E+00, 0.24942300E+00, 0.23578800E-01, 0.31029500E-02, 0.17559700E+00, -.66732600E-01, 0.35058200E+00, -.22948400E+00, -.48174600E-01, -.14682000E+00, -.40327200E+00, -.21431500E+00, 0.47452300E-01, 0.35695200E+00, 0.15758000E-01, 0.93397600E-01, 0.90263200E+00, 0.30493800E+00, -.31616700E+00, -.51193700E-01, 0.49323400E+00, -.16040800E+00, 0.19091300E+00, 0.74059600E-01, -.10838400E+00, -.32943300E-02, -.19336600E-01, -.79919600E-01, -.31885500E+00, -.15650900E+00, 0.35508700E-01, 0.15057900E+00, -.39428000E-01, 0.58856900E-01, -.74086500E-01, 0.23293000E-01, 0.29058300E-03, 0.32320700E+00, 0.73054900E-01, -.90231200E-01, 0.64406600E+00, -.83045600E-01, -.12393700E+00, 0.15483600E-01, 0.21823700E+00, -.28214100E-01, -.99142200E-01, -.26941100E-01, 0.15279300E+00, -.32930900E-01, -.22841400E+01, 0.16591400E+00, -.14559600E+00, -.18662400E+00, 0.17737000E+00, -.36421000E-01, 0.23826000E-01, -.11247100E+00, -.28519500E-01, 0.12097600E+00, -.91798100E-01, 0.61096100E-01, -.87863600E-01, 0.76459200E-01, 0.57009100E+00, -.37494900E+00, 0.76895400E-01, 0.90288400E-01, 0.60890200E-01, 0.53130600E-01, -.20171600E+00, 0.16775800E-01, 0.77982800E-01, -.18099000E+00, -.17738600E+00, -.38025200E-01, 0.12585500E+00, -.15280900E+00, -.12877800E+00, -.12919900E+00, 0.95663700E-02, -.24221400E+00, -.97246700E-01, 0.33165500E-02, -.29497000E+00, 0.19871800E+00, 0.39393200E-01, 0.36038000E+00, -.29541700E+00, -.40259600E-01, 0.12519200E+00, -.55582000E-01, 0.26098500E-01, 0.41751200E-01, 0.28102900E+00, 0.14751300E+01, -.78531300E-02, -.38158700E-01, 0.42372000E+00, 0.58055500E-01, -.55455000E-01, 0.66972100E-01, 0.40526900E-02, -.15082500E+03, 0.13313400E+02, -.74274600E+02, -.13750700E+03, -.14405700E+02, -.58553900E+01, 0.35543600E+02, 0.26983400E+03, -.11433900E+03, -.11173600E+03, -.13489100E+03, 0.82572300E+01, 0.75095200E+02, -.10439700E+03, 0.93430600E+01, -.15220300E+03, 0.64573500E+02, -.42331500E+02, -.44820400E+02, 0.19323300E+02, 0.49789700E+02, 0.19697100E+02, 0.11355600E+03, 0.10551700E+03, 0.27685700E+02, 0.18465200E+03, 0.59732200E+02, 0.78042800E+02, -.48176900E+01, 0.15581800E+03, -.64449600E+02, -.73776000E+02, -.75899100E+02, 0.29727000E+02, 0.94668700E+02, -.11971000E+03, -.50767600E+02, -.13086100E+03, 0.83274400E+02, -.47086400E+02, -.43452700E+02, 0.19488600E+02, 0.62163100E+02, 0.22339900E+02, -.17423500E+01, 0.16267000E+02, -.26562600E+02, -.60200700E+02, -.30511800E+02, 0.94332000E+01, -.10675000E+02, -.22572600E+03, 0.11033100E+03, 0.12235400E+03, 0.10985900E+03, 0.88106700E+02, 0.46434800E+02, -.76248900E+01, -.10180800E+03, 0.42261100E+02, 0.48655700E+02, 0.87837900E+02, 0.62150500E+02, -.36228800E+02, 0.24881200E+01, -.30963400E+02, -.13327500E+03, -.19945100E+01, -.61238100E+02, -.81675500E+02, -.40372300E+02, -.94525000E+01, -.23989600E+02, 0.15440000E+03, -.76327700E+02, -.24793700E+02, -.77171200E+02, -.21248700E+02, -.20910800E+02, -.20903700E+02, 0.18150400E+02, -.34287900E+02, -.16106900E+02, -.11765600E+03, 0.47600100E+02, -.20281900E+02, 0.16716100E+02, -.24573000E+02, 0.25408100E+02, -.32381400E+02, 0.28340600E+02, 0.78108200E+02, -.98727500E+01, -.10645100E+02, -.51462400E+02, 0.24283800E+03, -.11682200E+03, -.22395600E+02, -.12048000E+03, -.12638400E+03, -.84129900E+02, -.21069800E+02, -.57391800E+02, -.10157000E+03, -.66905000E+02, -.89344400E+02, -.15454000E+03, 0.81591300E+02, 0.15683200E+03, 0.74346900E+02, 0.84667900E+02, 0.17997700E+02, -.12519700E+02, -.56532000E+02, 0.27966700E+02, 0.16608000E+02, 0.10374000E+03, -.12499000E+02, 0.91763000E+01, -.49715400E+01, -.60190300E+01, -.14447700E+02, 0.10497600E+02, -.48970500E+01, -.12890300E+02, -.89652600E+01, 0.85890200E+01, 0.88481900E+01, -.11323100E+02, -.73768900E+01, 0.14670400E+02, -.13740000E+02, 0.22856200E+02, 0.22297300E+01, -.49782500E+02, -.20509400E+01, 0.13826200E+02, -.92133300E+01, -.31080400E+02, 0.38577900E+02, -.14980400E+02, -.15329200E+02, -.13404400E+01 },
        { -.48093600E+01, -.12176200E+01, 0.23990600E+00, 0.14397600E+01, 0.15652000E+01, 0.11838200E+01, 0.83412900E+00, 0.16482000E+01, -.43206300E-01, 0.71938700E+00, 0.57318800E+00, 0.64585300E+00, -.13598400E+00, -.27542500E+00, -.88868600E-01, 0.33439600E+01, -.38878200E+01, -.35979000E+01, 0.34662400E+01, 0.10034200E+01, -.75471800E+00, -.55827700E+00, 0.19264600E+00, 0.94539600E+00, -.13142300E+00, -.13359200E-01, 0.41590900E+00, 0.14711500E+01, -.17153100E+00, -.22226900E-01, -.54605300E+00, 0.91712900E+00, 0.11917000E+00, -.18835500E+01, -.20072300E-02, 0.10707000E-01, -.69425700E-01, -.69761200E+00, -.12730200E+00, -.20387300E+00, 0.22493300E+01, -.61716100E+00, 0.42368400E-01, -.98295700E-02, 0.29116800E-01, -.35007300E+00, 0.67304300E-01, -.51422400E-01, 0.28604700E+00, 0.30296700E+00, -.85328900E+00, 0.18172400E+01, -.47082600E+00, 0.30376800E+01, 0.28198500E+00, 0.77442900E+00, 0.11523100E+01, -.20747400E+00, -.89087600E-01, 0.48086400E+00, -.17748300E+00, -.92874900E+00, 0.35121000E+00, 0.35786600E-01, 0.19183400E+00, -.49040200E+00, 0.79143500E+00, 0.42225000E+00, 0.28842200E-01, -.45579600E-02, -.76337900E-01, 0.29443700E+01, 0.24101800E+00, -.21146600E+01, -.10104900E+01, -.44570300E+00, -.66045700E-01, -.46112100E+00, -.41295100E+00, 0.20837800E-01, -.38083800E-01, 0.28320300E-01, 0.74264500E-01, 0.49442400E+00, -.22273200E+00, -.34254100E+00, -.33886300E+00, 0.26090000E+00, -.38671000E+00, 0.13521600E-02, -.90366300E+00, -.54975600E-02, -.38783000E-01, 0.64521900E-01, 0.57618700E+00, 0.22144200E+00, -.12114400E+00, -.35109400E+00, 0.35525800E-01, 0.39466400E+00, -.97540300E-01, -.75246100E-01, -.48589800E-01, 0.12147300E+00, 0.91248800E-01, 0.53650900E+01, -.38991300E+00, 0.38726900E+00, 0.28126700E-01, -.10144400E+01, 0.23500900E+00, 0.10402800E-01, -.14687800E+00, -.74738900E-01, -.11218900E+01, -.85341000E-01, -.10619900E-01, 0.38285500E+00, 0.79936700E+00, -.20421000E+01, -.33147200E+00, 0.82983500E-01, -.11840700E+00, 0.85638100E-01, 0.22439600E-01, 0.38787500E-01, 0.63758500E+00, 0.10987600E+00, 0.37262200E+00, -.14343700E+00, 0.67364300E+00, 0.12041800E+00, -.67595900E+00, 0.50956700E-01, 0.15303500E-01, 0.49537200E-01, -.39517100E+00, 0.19691200E+00, -.11752900E+00, -.67731100E+00, 0.44462600E+00, 0.12439200E+00, -.31441200E+00, 0.39254400E+00, -.20685300E-01, -.18818900E-01, -.90369500E-01, -.26254400E+00, -.84298800E-02, 0.53845700E+00, -.63776600E+00, -.26477600E+00, -.18094000E+00, 0.64613300E+00, -.10391400E-02, -.89867100E+00, -.43946300E+00, -.44030900E-02, 0.22276900E+01, -.18148700E+03, 0.14633800E+03, 0.30505100E+02, 0.49513800E+02, -.88735400E+02, 0.53915100E+03, -.40657000E+03, 0.16994500E+03, 0.76884500E+02, 0.20333600E+03, 0.56517300E+01, -.14930000E+03, 0.25334000E+03, 0.21257600E+03, 0.39195500E+03, -.14428700E+03, -.23970800E+03, 0.31938500E+03, -.15606900E+03, -.29527600E+03, -.15781000E+03, -.23764400E+03, -.14494200E+03, -.12449100E+03, -.17673900E+03, -.15402400E+03, -.13078400E+03, 0.21611600E+03, -.28937300E+03, 0.12651200E+03, 0.11706900E+03, 0.13983900E+03, -.25112300E+02, -.19187600E+03, 0.36852200E+03, 0.38822900E+03, 0.41949400E+03, -.21234100E+03, -.23122500E+03, -.16299300E+02, 0.20176800E+02, 0.28331600E+02, 0.53926100E+01, 0.63642300E+02, 0.20437600E+01, 0.10047000E+03, 0.28724800E+03, 0.15210000E+03, -.38389000E+02, -.46901200E+02, 0.34446800E+03, -.17008500E+03, -.36858400E+03, -.16446000E+03, -.45882400E+03, -.15762200E+03, -.22335300E+02, -.93350800E+02, -.28890500E+03, -.10339300E+03, 0.52677700E+03, -.28834300E+03, 0.14680900E+03, 0.21016100E+03, 0.14381500E+03, 0.10835100E+03, -.10279700E+03, 0.15469200E+03, -.49503500E+02, 0.11109100E+03, -.14653900E+02, 0.47225300E+03, -.23685600E+03, 0.11565700E+03, 0.12547900E+02, 0.11834600E+03, -.96770400E+02, 0.17806100E+02, 0.38477000E+02, -.20996400E+02, 0.10447400E+03, 0.54599500E+01, 0.50158700E+03, 0.76957600E+02, -.36674200E+02, -.70171000E+02, -.35965900E+02, 0.88855300E+02, 0.80410000E+02, -.38775400E+02, 0.11112200E+03, 0.15038400E+03, 0.19959400E+02, -.31118100E+03, -.23459000E+03, 0.11254800E+03, 0.18854900E+03, 0.11525500E+03, 0.26450100E+03, 0.10261900E+03, 0.15386700E+02, 0.29065900E+02, 0.15365900E+03, 0.65922800E+02, -.18892100E+03, 0.54988400E+03, -.27689900E+03, -.27926000E+03, -.26691200E+03, -.34188300E+03, -.91992900E+02, -.35240700E+01, -.84280700E+02, -.27469900E+03, -.84155100E+01, -.49126900E+03, 0.55737500E+02, -.14499000E+02, 0.58202400E+02, 0.63780000E+02, 0.42821700E+02, -.25424800E+02, 0.15745600E+02, 0.11437700E+02, 0.22232200E+02, -.16936400E+02, -.14402400E+02, 0.40066300E+02, 0.30462400E+02, -.41974500E+02, 0.12274800E+02, 0.53508100E+02, -.49512300E+02, 0.58089200E+02, 0.44027000E+02, -.30943200E+02, 0.72404500E+02, 0.11457500E+02, -.18337400E+03, 0.31170300E+02, 0.21010200E+02, -.10964200E+02 },
        { 0.74804200E+01, 0.74063500E+00, -.26138700E+01, -.28118700E+01, -.10789500E+01, -.34944900E+00, -.27693500E+01, 0.17236000E+02, 0.53480200E+00, 0.28243100E+01, 0.29537400E+01, 0.52756400E-01, 0.44407500E+00, 0.57023100E+00, 0.63991800E-01, 0.37676000E+01, 0.79162400E+01, 0.48980000E+01, -.14024200E+01, -.37951300E+00, -.61644400E+01, 0.84114800E-01, -.17823600E+00, 0.91760400E+00, 0.44062400E+00, 0.50793500E-01, -.12560900E+00, 0.10631900E+01, -.30190700E+00, 0.40884400E-01, 0.79249200E+00, -.77453800E-01, 0.43618100E+00, 0.35601000E+01, 0.73247100E-01, -.47271100E-02, -.15922800E+00, -.13366600E+01, 0.15575900E-01, -.12601100E+01, -.40382900E+01, 0.18332200E+01, 0.18713100E+00, 0.65273700E+00, -.54330400E+00, -.15048500E-01, -.53147200E-01, -.81982100E-01, -.27453900E+01, -.30058500E+00, -.11670300E+01, -.17630900E+01, 0.38767800E+00, -.55301800E+01, -.85480600E+00, 0.13457100E+01, -.10450800E+01, -.25675300E+00, 0.91208200E-02, -.11619500E+01, 0.50095700E+00, -.50926400E+00, 0.23817400E+00, -.23339000E+00, 0.13585300E+01, 0.84249000E+00, -.18728600E+01, -.35012400E+00, 0.68910700E+00, 0.61639000E-02, 0.25085200E-01, 0.23334600E+01, 0.98862200E+00, 0.35862200E+01, -.64705200E+00, 0.16745200E+00, -.33729500E+00, 0.52622300E+00, -.66772400E+00, -.87755700E-01, 0.11097500E+00, 0.78678200E-01, -.38088200E+00, -.17780900E+01, -.60394000E-01, 0.11137900E+01, -.20149700E-01, 0.25880700E+00, -.10353900E+01, -.22328200E-01, -.11275300E+01, 0.89561100E-02, 0.47038400E+00, 0.73732900E-01, -.19226300E+01, 0.14620400E+01, 0.28421400E+00, 0.12126700E+01, -.27100700E+00, 0.62539100E+00, 0.93765200E-02, 0.31151500E+00, -.14358600E-01, -.13972600E-01, 0.25469100E+00, 0.11338200E+01, -.63857100E+00, -.11503100E+00, 0.21102600E+00, 0.11436100E+01, 0.42720300E+00, 0.36130700E-01, 0.18366700E+01, 0.18717700E-01, -.85714700E+00, -.10538800E+01, 0.14010200E+00, 0.10615400E+01, -.98467700E+00, 0.15511000E+01, 0.98065000E+00, 0.27688900E+00, 0.11489700E+00, -.13454200E+00, 0.20640000E+00, -.40052800E+00, 0.48344400E+00, -.31242600E+01, -.15190600E+01, -.37926300E-01, -.57536400E+00, -.64342300E+00, -.11543600E+01, 0.17468600E+01, 0.68869500E-02, -.27040300E-01, 0.63479800E+00, -.17169700E+00, 0.22920900E-01, -.26473500E+01, -.93574800E+00, -.78838800E-02, 0.13077300E+01, -.90525100E+00, 0.52028200E-01, -.19201600E+00, -.55730400E-01, -.11310200E+01, 0.27045000E+00, 0.16733800E+00, 0.49983300E+00, -.10407100E+01, 0.56065900E+00, 0.34553300E+01, 0.63384800E-01, 0.26836800E+01, -.25564300E+00, -.71447100E-02, 0.34706400E+01, 0.15264800E+01, -.67454900E+03, -.19259800E+04, -.43313300E+02, 0.59240800E+02, -.11188100E+03, -.14813100E+04, 0.73707000E+03, -.67650200E+03, 0.73755700E+03, 0.71617400E+02, -.72421100E+02, 0.76611500E+02, 0.26086100E+02, 0.83441200E+03, -.13368600E+03, -.17668000E+03, 0.35029100E+03, -.17866500E+03, -.12215500E+03, -.13108100E+03, 0.28825800E+03, 0.67915200E+03, -.16239800E+03, 0.62176300E+03, -.48013200E+02, 0.52871300E+03, -.12094100E+03, 0.20140700E+04, -.98187000E+03, -.15722000E+04, -.10038900E+04, -.66456800E+03, -.10145300E+04, 0.36397900E+03, 0.10255700E+04, 0.36347700E+03, -.11081400E+04, -.12104200E+04, 0.14400200E+04, -.66857300E+03, -.63132700E+03, -.71187200E+03, -.29568400E+03, -.49992100E+03, 0.42236100E+02, 0.28846700E+03, 0.11239200E+03, -.60437900E+03, -.14508600E+03, -.38631300E+04, 0.19247000E+04, 0.14353100E+04, 0.19610600E+04, -.53595600E+03, -.78890300E+02, 0.80924400E+03, -.11764900E+04, 0.14926000E+03, 0.15035800E+03, 0.25717400E+04, -.32305400E+04, 0.15510200E+04, 0.13356800E+04, 0.16150700E+04, 0.42086400E+03, 0.30814700E+03, 0.46546100E+02, -.17443500E+04, 0.77340700E+03, 0.36857600E+03, 0.11780700E+04, 0.41659200E+03, -.19798600E+03, -.48673800E+03, -.20849600E+03, -.33564600E+02, -.15261100E+03, 0.11460400E+03, -.15116600E+03, -.10357000E+03, -.12785300E+03, -.11832000E+04, 0.63005700E+03, -.25750700E+03, -.48870200E+02, -.31320500E+03, 0.13314800E+03, -.31797200E+03, 0.42488300E+03, 0.13203500E+04, 0.44347600E+03, -.25156000E+03, -.48550200E+03, 0.13831000E+04, -.66794600E+03, -.50101800E+03, -.70489500E+03, -.49107700E+02, -.50977200E+03, -.52332100E+02, -.53985800E+03, -.13481700E+03, -.52213400E+03, -.11505400E+04, 0.48551500E+03, -.15108100E+03, 0.21053900E+03, -.21917900E+03, -.42849200E+03, -.34216400E+03, 0.48792600E+03, -.99874000E+03, -.57673300E+03, 0.20021600E+02, -.39725800E+04, 0.35338300E+01, -.14738300E+02, 0.45052500E+02, 0.10572700E+03, 0.92378300E+02, -.43776000E+02, -.33963200E+02, -.15293000E+02, 0.54234800E+02, -.11031700E+02, -.95323900E+01, 0.63542200E+02, 0.37185000E+02, -.89720800E+02, -.20510800E+02, 0.13854300E+03, -.11185600E+03, -.20098200E+03, 0.18934100E+02, -.62890900E+02, 0.18218000E+03, -.68045400E+02, -.19142800E+03, -.14409700E+02, -.68923300E+02, 0.77919700E+02 },
        { -.51495600E+01, -.11412700E+01, -.38536100E+01, -.30380100E+01, 0.20666800E+01, 0.16171800E+01, 0.11990900E+00, 0.69960400E+01, -.54201300E+00, 0.16062100E+00, 0.18395600E+01, 0.77825400E+00, 0.14765600E+01, -.13708400E+01, -.55050600E+00, 0.13913400E+01, -.21668300E+01, -.38493200E+00, -.32970800E+00, -.22054400E+00, 0.21259300E+01, 0.16095500E+01, -.52091600E+00, 0.94961300E+00, -.14974000E+00, 0.11410500E-01, 0.77799300E+00, 0.10885600E+01, -.20986800E+01, -.46246800E-01, 0.18130900E+00, 0.28113500E+01, -.43750800E+00, 0.28284300E+00, 0.12499200E-01, 0.27381100E+00, -.10531900E-01, -.51712700E+00, -.28616100E+00, -.40346700E+00, 0.10513000E+01, -.33593200E+00, 0.19253600E+00, 0.88682800E-02, 0.35572400E+00, -.87546000E+00, 0.19443100E+00, -.44924500E-02, -.21993500E+01, 0.33895000E-01, -.24106600E+00, 0.65840700E+00, -.52796400E+00, 0.36506800E+01, -.36901100E-01, 0.99935500E+00, 0.58697700E+00, 0.12572400E+00, -.15914700E-01, 0.14169200E+01, 0.17699100E+00, -.11882700E+00, 0.18166000E+00, -.32172500E+00, -.46151300E+00, -.46589500E+00, 0.12612300E+01, 0.35013600E-02, 0.50704700E+00, 0.88035200E-02, -.54352100E-01, 0.21951800E+01, 0.41695700E+00, 0.91098700E+00, -.43340300E+00, -.14823400E+01, 0.24941100E+00, -.13153400E+00, -.30423500E+00, -.14318100E+00, -.68304500E-01, 0.91734500E-01, 0.30380600E-01, -.26581300E+00, -.15895000E+00, 0.31231500E+00, -.78700700E+00, -.97549400E-01, -.97083800E+00, 0.92847200E-01, -.78259200E+00, -.56859700E-03, -.57164400E-01, -.40474700E-02, -.33780600E+00, -.94104200E+00, 0.65602100E-01, 0.39711500E+00, -.20626400E+00, -.55230100E-02, 0.35724100E-01, -.18564300E+00, 0.71448500E-02, -.23817400E+00, 0.58251000E+00, 0.81618100E+01, -.40783200E+00, 0.10681700E+01, 0.19936700E+00, -.30430100E+00, -.32572200E-01, -.41922900E-01, -.11400400E+01, 0.47605700E-01, 0.71467800E+00, 0.20629100E+00, -.29072100E+00, -.27723000E+00, 0.97545100E+00, -.11953400E+01, 0.26119600E+00, 0.63954200E-02, -.97214800E-01, 0.24652500E+00, -.26514300E-02, 0.73234200E+00, -.23856000E+00, 0.13508400E+01, -.71908000E-01, -.38666400E+00, 0.72969500E+00, 0.33545200E+00, -.68380300E+00, 0.93966700E+00, -.56526600E-02, 0.32888700E-01, -.17810800E+01, 0.29380300E+00, -.13082600E+00, 0.24608300E+01, 0.29028800E+00, 0.29359800E+00, 0.96628600E+00, 0.16547100E+00, 0.11992500E+00, -.69121500E+00, 0.65880500E-02, 0.40158100E+00, 0.42489200E-01, -.59883600E+00, 0.34589500E+00, -.62867500E+00, -.13013700E-01, -.29249500E+01, 0.34020900E+00, 0.79908300E+00, -.27325900E+00, 0.65650500E-02, 0.11668500E-01, 0.11482000E+00, 0.20827600E+00, 0.52719400E+03, 0.18937200E+03, 0.32888200E+02, -.30981900E+02, 0.18595600E+04, -.89099500E+03, 0.25905300E+03, -.92944800E+03, -.28670700E+03, -.11454800E+03, -.49089800E+03, -.11790400E+03, -.60262800E+03, -.93702500E+02, -.13768700E+03, 0.18165900E+02, -.73198000E+01, -.61342800E+02, -.11250800E+02, 0.13587900E+03, 0.87540200E+01, 0.15907200E+03, 0.60347500E+02, -.97518100E+02, 0.19509300E+02, -.32454700E+03, 0.12161900E+04, -.59699600E+03, 0.36249800E+03, -.60771600E+03, -.78861000E+02, 0.86014400E+02, -.59907700E+03, -.38300500E+03, -.64511600E+03, 0.13008100E+03, 0.17300700E+03, 0.59588100E+02, -.32734500E+02, 0.74407200E+02, -.29133300E+02, 0.65829500E+01, -.17318800E+02, -.17137800E+02, -.21895900E+03, -.19155800E+03, 0.44203200E+02, 0.85049000E+02, -.90930600E+03, 0.45774500E+03, 0.64893500E+03, 0.44631900E+03, 0.56326800E+03, 0.20198800E+03, 0.12106800E+03, 0.36830800E+03, 0.60935500E+03, 0.11261500E+03, -.17000700E+03, 0.12982300E+04, -.65405000E+03, -.67635500E+03, -.64887400E+03, -.15210400E+03, -.10627500E+03, -.17627300E+03, 0.58320300E+03, -.18732400E+03, -.96962000E+02, -.61703400E+03, -.33226500E+03, 0.16605700E+03, 0.42709400E+03, 0.16620800E+03, 0.15749200E+03, 0.93167700E+01, 0.89407200E+02, 0.10882900E+03, 0.14896300E+03, 0.14797800E+02, 0.21453900E+03, -.23351500E+03, 0.11321500E+03, -.82358300E+02, 0.11499100E+03, -.13719500E+03, -.38090400E+02, 0.13359600E+03, -.35291100E+03, -.14101200E+03, -.73512900E+02, 0.23228600E+03, -.33409000E+03, 0.16475600E+03, -.19966700E+03, 0.16989900E+03, -.11182000E+03, 0.98424800E+02, -.12500400E+03, -.14538300E+03, -.44922700E+02, 0.13479900E+03, 0.44884900E+03, 0.18109400E+02, -.11777200E+02, -.38738700E+03, -.16847200E+02, 0.14344700E+03, 0.10894400E+03, -.53281700E+02, 0.41580500E+03, 0.35068700E+03, -.23086400E+02, 0.10007300E+04, 0.15228900E+02, -.10276600E+02, -.14051500E+03, -.15399700E+03, -.15746300E+02, 0.38029800E+02, -.98154600E+01, 0.14426100E+02, -.55226700E+01, -.13938400E+02, -.31527600E+02, -.23503000E+02, -.22578900E+02, 0.18632800E+02, 0.17327300E+02, -.11230300E+02, 0.16511500E+03, -.18885500E+02, -.13279400E+03, 0.26361300E+02, -.49137800E+02, 0.23859000E+02, -.16719600E+03, 0.25645800E+02, 0.18403900E+01, -.12977900E+02 },
        { -.10732700E+02, -.13008400E+01, 0.40350700E+01, 0.31948000E+01, 0.51652100E+01, 0.22438700E+01, 0.42570900E+01, -.25203300E+01, -.38937700E+00, 0.23107900E+00, 0.30850100E+00, 0.32732200E+00, 0.58271700E+00, -.27664100E+00, -.22423600E+00, 0.13105800E+02, 0.20524500E+01, -.77273800E+00, 0.50521400E+01, 0.23565700E+01, -.15538400E+01, -.96172100E+00, 0.10992700E+00, -.54746000E+00, 0.44574200E-02, -.14811900E+00, -.65096200E+00, -.29616600E+01, 0.25208800E+01, -.38126300E-01, 0.53304400E+00, -.45830600E+00, -.68631800E+00, 0.37436000E+01, -.72968800E-01, 0.13603400E+00, 0.11138700E+00, 0.14152900E+01, 0.18075000E+00, 0.51425900E+00, -.15460700E+01, 0.59967300E+00, -.77710800E-01, -.53883000E-01, -.75006500E+00, 0.14606100E+00, -.12435200E-01, -.80312100E-02, -.10062500E+01, 0.60292500E-01, -.13850900E+01, -.10905700E+01, 0.45416300E+00, -.35885600E-01, -.35466600E+00, 0.23484400E+01, 0.60128800E+00, -.13076200E+00, 0.68352400E-01, -.15127300E-01, 0.19225000E+00, -.22335500E+00, 0.75646000E+00, -.24779400E+00, 0.94551800E+00, -.37042800E+00, -.14057300E+01, -.16886800E+00, -.35337500E+00, -.15328900E-01, 0.84423400E-01, 0.18739700E+01, 0.90729300E+00, -.91458600E+00, -.50922000E+00, 0.15388400E+01, -.25780400E+00, -.52915100E+00, 0.20584900E+00, 0.95692300E-01, 0.16312900E+00, -.16379100E+00, -.51480800E-01, -.29418600E+00, -.67854000E-01, 0.32578100E+00, 0.44726900E+00, -.10324100E-01, -.54239100E+00, 0.94451700E-01, -.20067100E+00, 0.12463700E-01, 0.54491500E-01, -.13682200E+00, -.25122800E-01, -.21647200E-02, 0.29286900E+00, -.16087600E+00, -.33004300E+00, -.28511300E+00, 0.11215600E+00, 0.11768000E+00, 0.71403500E-01, 0.45900700E-01, 0.18426000E+00, -.36664400E+01, -.14442800E+00, 0.45723900E+00, -.11128400E+00, 0.32335800E+00, -.39424300E+00, 0.23608700E-01, -.18815100E+01, 0.90052500E-01, -.69157400E-01, -.19676200E+00, -.71120100E-01, 0.68006600E-01, 0.14096700E+01, -.13587900E+01, 0.14967000E+01, 0.43220000E-01, -.12441400E+00, 0.57402200E+00, 0.75401600E-02, 0.96032200E+00, 0.13748700E+00, -.11717200E+01, 0.35383800E-01, 0.11919500E+00, 0.16921600E+00, 0.41212800E+00, 0.64901900E+00, -.60609900E-01, 0.15296000E+00, 0.41692100E-01, -.20502400E+01, -.84104000E+00, 0.16435800E+00, 0.23870900E+01, 0.38792000E+00, 0.78396000E+00, 0.18435300E+00, 0.18308600E+00, 0.19308900E+00, -.83178300E-01, 0.74570900E-01, -.82984200E+00, 0.31420500E+00, -.76339600E-01, 0.10731600E+01, -.11992900E+01, -.17854200E+00, -.66249000E+00, 0.48581500E+00, 0.23270300E+01, 0.35781400E-01, 0.64695800E-02, -.14318700E+01, -.21248600E+00, 0.26410800E+00, -.31728700E+00, 0.37414700E+03, 0.58527800E+02, 0.95418200E+03, 0.14624700E+04, -.67039400E+03, -.23872900E+03, -.73169900E+03, -.12679800E+03, 0.43850100E+02, -.46953000E+03, 0.20530900E+03, -.35009100E+03, -.41515800E+02, -.33960700E+03, 0.58038900E+03, -.29308400E+03, -.37890300E+03, -.29225000E+03, 0.17202300E+03, 0.24097500E+03, 0.15317800E+02, 0.47227900E+03, -.24658600E+03, 0.16013000E+03, -.36610800E+02, 0.18059800E+04, -.85989100E+03, -.47233400E+03, -.89932500E+03, -.76360500E+02, 0.12169500E+03, -.63819300E+03, 0.18157300E+03, -.39092000E+03, -.99389100E+00, -.18929300E+03, 0.51880800E+03, -.23399800E+03, -.10307500E+03, -.25662300E+03, 0.42658900E+02, 0.52845900E+02, -.17787300E+03, 0.69485700E+02, -.15736900E+01, -.63693600E+02, -.42882900E+02, -.74567800E+03, 0.36894700E+03, 0.14394200E+03, 0.36746300E+03, 0.13889700E+03, -.11791000E+02, 0.65184700E+02, -.13476500E+03, 0.12529600E+03, 0.56902400E+02, 0.70649700E+03, 0.23097700E+03, -.14595600E+03, -.29527800E+03, -.11202100E+03, -.50081800E+02, 0.68872300E+02, -.10061400E+03, -.42047100E+02, 0.16453700E+03, 0.99380800E+02, 0.67835200E+03, 0.38590600E+03, -.18943000E+03, -.13213500E+03, -.19289100E+03, 0.11733900E+02, -.87533700E+02, 0.18083400E+02, 0.19611300E+03, 0.71650700E+02, -.47361500E+02, 0.11723000E+03, 0.18680300E+03, -.67996600E+02, -.69941900E+02, -.95492300E+02, -.24504200E+02, -.72421500E+02, 0.10408700E+03, 0.10999500E+03, -.31234800E+01, -.10193500E+03, -.49014500E+03, 0.50921600E+02, -.14649800E+02, -.71782200E+01, -.24281300E+02, -.50324200E+02, -.82060700E+02, -.13360100E+03, -.44685800E+03, -.37457600E+02, -.13182600E+02, -.23916700E+03, 0.26241300E+03, -.91758500E+02, -.53246500E+03, -.13708700E+03, -.64839000E+02, -.12745300E+03, 0.93344100E+02, 0.14658300E+03, 0.62494200E+02, -.13130600E+03, -.44452100E+02, 0.39901500E+02, -.98814000E+01, -.51362500E+02, -.61128400E+02, 0.28551300E+01, 0.15208200E+02, 0.22283300E+02, -.42211000E+01, 0.14383200E+02, -.20101700E+02, -.32492800E+02, -.35636000E+01, 0.19805200E+02, 0.40017200E+01, -.70443600E+01, 0.63288500E+02, 0.58973100E+02, -.11251100E+03, -.34962600E+02, 0.94813300E+01, 0.63382500E+02, -.74995700E+01, -.22464800E+03, 0.21468300E+02, -.29689800E+02, -.17447700E+02 },
        { 0.44589000E+01, -.10468500E+01, -.38999900E+01, -.80980900E+00, -.25247600E+01, -.33687300E+00, -.91944300E+00, 0.36087600E+01, 0.65571500E-01, 0.46786600E+00, 0.30377900E+00, -.34226400E+00, -.91702800E-01, 0.44397100E+00, -.15693800E+00, -.36489300E+01, 0.54256200E+01, 0.17383400E+01, -.23060300E+01, -.29916300E+00, 0.65328200E+00, 0.70035900E+00, -.65869600E-01, 0.20318900E+00, 0.36410900E+00, 0.14587000E+00, 0.56519400E+00, -.18660400E+00, -.13490500E+01, 0.72553800E-01, 0.21106600E+00, -.40636200E+00, 0.76257200E+00, 0.11690700E+01, 0.58847300E-01, -.36277500E-02, -.85546100E-01, -.12675600E+00, -.13292200E+00, -.46369500E+00, -.17986500E+01, 0.98347400E+00, 0.38346300E-01, 0.26827700E+00, -.38318400E+00, 0.72772300E-01, 0.19623300E-02, -.57040900E-01, -.30297600E+00, -.22613800E+00, 0.16391700E+00, -.12538200E+01, 0.13935800E+01, -.34284200E+01, -.36180700E+00, 0.18467100E+01, 0.19793700E+00, 0.34731400E-01, 0.31194200E-01, -.18436400E+00, -.11726500E+00, 0.16556900E+01, 0.31756800E+00, -.11283700E+01, -.15227100E+01, -.67279900E+00, -.89489700E+00, -.15121500E+00, 0.44237200E+00, -.13854500E-03, 0.43975800E-01, 0.25519100E+01, 0.18003800E+01, 0.16353100E+01, -.85583900E+00, -.19780500E+00, 0.10643200E+00, 0.48847100E+00, -.76661700E+00, -.62766900E-01, 0.47833900E-02, -.39287900E-01, 0.26438400E+00, 0.67282800E+00, 0.87947300E-01, -.13400100E+00, 0.20121300E+00, 0.11493400E+00, 0.19522600E+00, 0.17984300E+00, -.20112500E+00, 0.30948800E-02, 0.20246100E+00, -.49839200E-01, 0.96665700E+00, 0.12289200E+01, 0.23510300E+00, -.68070800E+00, -.25312100E-02, -.20190300E+00, 0.10461000E+00, 0.10939100E-01, -.82173200E-02, 0.14450900E+00, 0.13526000E+00, -.12778700E+01, -.26552600E+00, -.10578500E+00, 0.12007400E+00, 0.18508500E+00, 0.14507800E+00, -.12584100E-01, -.14195100E+01, 0.22597500E-01, 0.20141200E+00, -.23917600E-01, -.35293800E+00, 0.13780200E+00, 0.84014600E+00, -.79715100E+00, -.36402900E+00, 0.73761700E-01, 0.10080600E+00, 0.13642000E+00, 0.53504300E-01, 0.15855800E+00, 0.71871000E+00, -.53687800E+00, 0.55654100E+00, -.48597200E+00, 0.85910600E+00, 0.34179900E+00, 0.70908600E+00, -.84667800E+00, 0.32658600E+00, 0.87629200E-01, -.12931900E+01, -.39118300E+00, 0.57131200E-01, 0.14325000E+01, 0.54161900E+00, 0.64388600E+00, -.75421900E+00, 0.11137900E+01, -.52251200E-01, -.82523100E+00, -.32684000E-01, -.21372300E+00, -.51090300E-02, 0.50538900E+00, -.30596500E+01, 0.28584300E+00, 0.28342100E-01, -.73632600E+00, -.13746200E+00, -.37643300E+00, -.73449300E-01, 0.77372300E-03, -.95156100E+00, -.58629600E+00, 0.58673200E-01, 0.34066500E+00, -.14553400E-01, -.13228000E+03, 0.40857500E+03, 0.18925200E+03, -.91766800E+02, -.11826700E+03, -.93697400E+02, 0.64707100E+02, -.32768900E+02, 0.21312100E+03, 0.46154500E+03, 0.11322500E+03, -.47225100E+02, -.58998600E+03, 0.18572800E+03, -.96676800E+02, -.96404400E+02, -.10430100E+03, -.12554200E+03, -.94944900E+02, -.13064600E+03, -.14084900E+03, -.35424300E+02, -.11243100E+03, 0.33950800E+03, -.81179600E+03, 0.41746600E+03, 0.27436400E+03, 0.40276800E+03, 0.25871900E+03, 0.20464800E+03, 0.27057300E+03, 0.28852700E+03, 0.30566800E+03, 0.15960000E+03, -.40536900E+03, -.64177300E+03, 0.31317100E+03, 0.25650300E+03, 0.31848700E+03, 0.13090400E+03, 0.20162900E+03, 0.56785600E+02, 0.95427000E+02, 0.76814900E+02, 0.15418800E+03, -.12343200E+02, 0.10568900E+04, -.53018200E+03, -.82749800E+03, -.53033300E+03, -.28256500E+03, 0.38403900E+02, -.49850400E+03, -.11698500E+03, -.23254800E+03, -.66042900E+02, 0.39179700E+03, -.21243800E+03, 0.11978200E+03, 0.22393100E+03, 0.10613700E+03, 0.60015300E+02, -.42670200E+02, 0.59395600E+02, -.60672700E+02, 0.80421600E+02, -.99804000E+02, 0.27873100E+03, 0.10050900E+03, -.52064400E+02, -.21857100E+03, -.50253700E+02, -.11435500E+03, 0.25384400E+02, -.91762900E+02, -.45793300E+02, -.68616800E+02, -.50025300E+02, 0.38451900E+03, 0.15177600E+03, -.84302700E+02, -.32611100E+01, -.75210000E+02, 0.53995000E+02, -.53260400E+02, -.27261400E+02, 0.61338500E+02, 0.61848500E+02, -.12488400E+02, -.44748900E+03, -.36436200E+03, 0.18399600E+03, 0.17501900E+03, 0.18358600E+03, 0.91193200E+02, 0.16670200E+02, 0.11138300E+03, 0.93564300E+02, 0.76822900E+02, 0.24103100E+02, -.52996800E+01, -.94282700E+02, 0.34724600E+02, 0.43353900E+02, 0.46371600E+02, -.93668300E+02, -.60423600E+02, -.18835000E+03, -.96645500E+02, -.12510400E+03, -.46694000E+02, 0.33411500E+03, 0.36270700E+01, 0.15326800E+02, 0.13997300E+03, 0.13520400E+03, -.20333600E+02, 0.24121600E+00, 0.37124900E+02, -.31043700E+02, -.10389300E+02, 0.16913100E+02, 0.27013200E+02, -.11879000E+02, 0.19466500E+02, 0.16833900E+02, -.31004600E+02, -.12552500E+02, -.11801400E+03, 0.52433700E+02, 0.12432200E+03, 0.10858800E+02, 0.24190100E+02, -.31150300E+01, 0.11821800E+03, -.24156900E+02, 0.17785300E+02, -.33254500E+02 },
        { 0.30208200E+01, 0.93238000E+00, -.63996000E+00, -.17148400E+01, -.17795200E+01, -.65272600E+00, -.10163200E+01, 0.12917500E+01, 0.16874400E+00, -.12559000E+00, -.19447900E+00, -.27443200E+00, -.43286900E+00, 0.81271100E-01, 0.29093200E+00, -.65620700E+01, -.18914500E+01, -.14530000E+00, -.32746900E+00, 0.25816200E+00, -.64184400E+00, -.71033200E-01, -.58751100E-01, -.13125000E+01, 0.63239100E-01, 0.18154900E-01, -.10739900E+00, -.14522700E+01, 0.10080600E+01, -.85995800E-02, 0.68134400E+00, 0.45804400E+00, -.42949400E+00, -.28254800E+00, -.11409900E-01, 0.11303100E+00, 0.22065000E-01, -.29350300E+00, 0.12619300E-01, 0.21992700E+00, -.12275400E+01, -.58438700E+00, 0.88790700E-01, -.10452100E+00, 0.85139500E+00, -.30620500E+00, 0.32031900E-01, 0.70878900E-01, 0.12126800E+01, -.24136200E-01, 0.21347600E+00, 0.21873600E+00, -.24044500E+00, -.28791700E+00, -.36357800E-01, -.10283300E+01, -.28136900E+00, 0.62309400E-01, 0.67879700E-01, 0.58213400E+00, -.27271100E+00, 0.41235900E+00, -.22304500E+00, 0.46950500E+00, 0.51864900E+00, -.44916900E-01, -.21944700E+00, -.11493800E+00, 0.69407900E-01, 0.12632600E-01, -.62085400E-02, -.11811800E+01, 0.54779700E-01, 0.13113300E+01, -.78722000E-01, 0.49464600E+00, 0.11796900E+00, 0.15228400E+00, 0.23677300E+00, 0.15114000E+00, 0.37571900E-02, -.22814700E-02, 0.69695500E-02, -.22399700E+00, 0.20901600E+00, 0.26103200E+00, -.31230200E-01, -.98138500E-01, -.50003100E-01, -.74698700E-02, 0.31507700E+00, 0.11641000E-03, -.38929700E+00, 0.73476100E-01, -.82527500E-01, -.56166800E+00, 0.19596300E+00, 0.43128600E+00, 0.75570800E-01, -.24014000E+00, 0.50477000E-01, 0.65582100E-01, 0.32336900E-01, -.15191500E+00, -.31968200E-01, 0.95256800E+00, -.32426400E-02, 0.25055900E+00, 0.10040100E+00, -.63745100E-01, 0.60218100E-01, -.48561600E-02, -.34635000E+00, 0.36428800E-01, 0.18644200E+00, 0.68551200E+00, -.18940600E+00, -.57557000E-01, 0.93230700E-01, 0.30723700E+00, 0.56758000E+00, -.10233800E+00, -.58631500E-01, -.55879000E-02, -.78582200E-01, 0.62666600E-01, -.39290700E-01, 0.69830400E+00, 0.20154000E+00, 0.39962300E-01, -.23487600E+00, 0.11595300E+00, 0.39791900E+00, -.17480800E+00, -.75775200E-01, -.19042200E-01, 0.23478200E+00, -.23089700E-01, 0.23618000E-01, 0.89773000E+00, -.83926400E-02, -.13071300E+00, -.26000700E-01, -.42054100E+00, -.89765800E-02, 0.30837400E-01, 0.29837800E-01, 0.63740300E+00, -.66060100E-01, -.26865400E+00, 0.32770900E+00, 0.72522700E-01, -.14366100E-01, 0.18097100E+00, -.29730400E-02, -.60599000E+00, 0.11059400E-01, 0.23565600E-02, 0.92737800E+00, 0.16523100E+00, -.10795000E+00, -.13535500E+00, 0.16160200E+00, 0.20115600E+00, -.29889200E+03, -.24078100E+03, 0.11535000E+03, -.67814300E+02, 0.11990200E+03, -.62038000E+01, 0.17804600E+02, 0.24180500E+02, -.97597100E+02, 0.77377700E+02, 0.36658100E+02, 0.13933200E+03, -.48906200E+03, 0.24466500E+03, 0.14179800E+03, 0.25766500E+03, -.89740600E+02, -.90533100E+02, 0.11308800E+03, -.12932000E+03, 0.98739100E+02, -.42391500E+02, 0.58175500E+02, -.11551000E+02, -.16047700E+01, -.71438000E+02, 0.44572100E+01, -.73407400E+02, -.91351400E+02, 0.75800200E+02, -.12849700E+02, 0.35691200E+02, -.57173900E+02, 0.35984100E+02, 0.97651500E+02, -.49837800E+02, -.78139400E+02, -.46622800E+02, -.11959600E+02, -.54350000E+02, 0.62684600E+02, 0.60002600E+00, -.12390100E+02, -.29037200E+02, -.12277100E+02, -.25475700E+03, 0.12905000E+03, 0.25175700E+03, 0.13310100E+03, 0.67120200E+02, 0.18132000E+02, 0.15370200E+03, 0.37387000E+02, 0.39653000E+02, 0.20743700E+02, -.16213200E+03, -.11287800E+02, 0.30180700E+01, -.17312500E+02, 0.51123500E+01, 0.63381900E+01, -.40017300E+01, 0.85327500E+01, 0.35064200E+02, 0.20121100E+02, -.72752000E+01, -.21638600E+03, -.54209500E+02, 0.27823500E+02, 0.32317200E+02, 0.27070300E+02, 0.35505000E+02, -.11064400E+02, 0.50099600E+02, -.89190400E+00, 0.85876600E-01, -.74789000E+01, -.15335900E+03, -.41668300E+02, 0.20410400E+02, -.35502100E+02, 0.20900200E+02, -.21168300E+02, -.18436400E+02, 0.18425700E+02, 0.20056700E+02, -.43616300E+01, -.23347100E+02, 0.21364400E+03, 0.17590800E+03, -.87772800E+02, -.16619900E+03, -.90779900E+02, 0.28123000E+02, 0.26442000E+02, -.72936000E+01, 0.87774600E+02, 0.26064000E+02, 0.12521900E+00, 0.51746500E+02, 0.15044300E+03, -.75868900E+02, -.14269500E+03, -.70906900E+02, -.32097200E+01, -.19190300E+02, 0.13430900E+03, 0.40887200E+02, 0.32225800E+02, 0.60299200E+01, -.24550500E+03, 0.11902100E+02, -.58904500E+01, -.43335200E+02, -.37829300E+02, 0.67984600E+01, -.21462400E+01, -.31799200E+00, 0.91283300E+01, 0.53464700E+01, -.26224500E+01, -.91290700E+01, 0.88999100E+01, -.63699700E-01, -.67648300E+01, 0.87429700E+01, 0.27826100E+00, 0.34474200E+02, 0.17527900E+02, -.43635900E+02, -.61125700E+01, -.15132000E+02, -.73830500E+01, -.67418600E+02, 0.52423800E+01, 0.10186600E+02, 0.10696800E+02 },
        { -.28827900E+01, 0.11877700E+00, 0.19380300E+01, 0.11176900E+01, 0.42682200E+00, 0.13628700E+00, 0.71598300E+00, -.70415300E+01, -.23526600E+00, -.20545000E+01, -.36201000E+00, 0.53578600E+00, 0.91556700E+00, 0.17785300E-01, -.68767600E+00, 0.93465800E+01, 0.66951900E+01, 0.29943300E+01, -.44197900E+00, -.10997900E+01, -.42581100E+00, 0.14606500E-01, -.12791300E+00, 0.27080000E+00, -.15234700E+00, -.11293100E+00, -.80601000E+00, -.78274400E+00, 0.20775200E+01, 0.67671800E-01, -.41403400E+00, -.51737900E+00, -.29143500E+00, -.34535200E+00, -.23634900E-01, -.19991300E+00, 0.43675300E-01, 0.98474400E+00, -.88029500E-01, 0.47960900E+00, 0.41930900E+00, -.49014300E+00, -.81552100E-01, -.13688700E-01, 0.20528600E+00, -.10520000E+00, -.18009300E-01, 0.26347000E-01, -.33447300E+00, -.16299300E+00, 0.62389100E+00, 0.12999100E+00, 0.64915800E+00, -.10120200E+01, -.22522500E+00, -.10468500E+01, -.47455900E+00, -.23386400E+00, -.15487400E-01, -.32241000E+00, 0.11282600E+00, 0.91655700E+00, 0.33537900E-01, -.31635100E+00, -.52237000E+00, 0.91664100E-01, -.60932800E+00, 0.76631500E-02, -.11159100E+01, -.13687700E-01, 0.48454400E-02, -.45075400E+01, -.39746100E+00, 0.11499800E+01, 0.14743500E+01, -.21478900E+00, -.23175900E+00, 0.16538200E+01, 0.25736400E-01, -.19297600E+00, -.79975400E-01, 0.71784800E-01, 0.56851400E-01, -.34238400E+00, -.66171600E-01, 0.95505000E-01, 0.25589300E-01, -.40852700E-01, 0.14086200E+00, -.97004100E-02, -.25131300E+00, -.33013600E-02, 0.11752500E+00, 0.28051800E+00, 0.22135600E+00, 0.10949100E+01, 0.15327500E+00, 0.31019500E+00, 0.23919000E+00, 0.49881500E-01, 0.15944000E+00, 0.26031000E-01, -.21251100E-01, -.10015800E+00, -.40083800E-01, -.16347500E+01, -.18995200E+00, -.25674400E+00, -.18475900E+00, 0.64748700E+00, -.84513000E-01, -.19035500E-01, -.53466700E-02, -.21416500E-01, 0.50806900E+00, -.10966100E+00, 0.26643600E+00, -.16320200E+00, -.12098000E+01, 0.19814100E+01, -.91916700E-02, 0.11855000E+00, 0.25144000E+00, -.44888400E-01, 0.10061800E+00, -.38182200E+00, -.38095400E+00, -.17419600E+01, -.86963900E+00, -.20712400E+00, 0.46005700E+00, -.16785200E+00, -.61557000E+00, 0.51397000E+00, -.21974800E+00, -.16130300E-01, 0.53307800E-01, -.24970400E+00, -.11017800E+00, 0.10253800E+00, -.30891400E+00, -.27751800E+00, 0.96697200E+00, -.51651600E+00, 0.31829800E-01, 0.71172700E+00, -.15300000E-01, 0.47569400E+00, 0.69545300E-01, -.70816600E-01, 0.46092000E+01, -.20399700E+00, -.95240800E-01, -.23914700E+00, 0.77717200E-01, -.70886500E-01, -.11050100E+00, 0.19283300E-02, 0.21644300E+01, 0.48405900E+00, 0.57992900E-01, 0.66841500E-01, -.16125000E+00, -.19237900E+00, -.58464700E+00, -.89386600E+03, 0.41370200E+03, 0.37618100E+03, 0.44622400E+03, 0.25924200E+02, -.73096400E-01, 0.11315000E+03, -.33608200E+03, 0.15543300E+03, 0.51769300E+02, 0.42103800E+03, 0.13551100E+03, -.62936700E+02, -.39863600E+02, -.56996800E+02, 0.98393400E+02, 0.36777000E+02, 0.56824900E+02, -.31432200E+02, -.13183400E+03, 0.71186500E+02, -.32921200E+03, -.29741500E+03, 0.12119600E+03, 0.12865900E+03, 0.14912000E+03, -.12781100E+03, -.19215900E+03, 0.15266200E+03, -.13244600E+03, 0.11223700E+03, -.12292200E+03, 0.33871700E+03, 0.35538800E+03, -.17740700E+03, -.28949300E+03, -.17598700E+03, -.83588700E+02, -.11834500E+03, -.11464700E+02, 0.33485500E+01, 0.33855500E+02, -.10246200E+03, 0.88408600E+02, -.94783300E+03, 0.47884500E+03, 0.48368900E+03, 0.47934800E+03, 0.61471300E+02, -.40349000E+02, 0.33650500E+03, 0.16056500E+03, 0.30931100E+03, -.25038800E+02, 0.17653900E+03, 0.76597800E+02, -.35326700E+02, -.14267900E+03, -.38103000E+02, -.35460000E+02, -.16299700E+02, 0.29219500E+02, 0.46656800E+02, -.17129500E+02, -.11839300E+02, -.25440000E+02, -.29234700E+03, 0.14539700E+03, 0.12421200E+03, 0.14613800E+03, 0.11604400E+03, 0.24447600E+02, 0.42574300E+02, -.61993100E+02, 0.76936000E+02, 0.32211900E+02, -.56618600E+01, -.14515000E+03, 0.69968900E+02, -.25920100E+02, 0.72808500E+02, 0.17174500E+02, 0.27796400E+02, 0.44715900E+02, -.63919900E+02, 0.12909200E+02, 0.21390000E+02, 0.15992400E+03, -.20806100E+02, 0.28052400E+01, -.27270800E+03, 0.78748800E+01, -.21526400E+02, 0.26523700E+02, -.13423200E+03, -.62146600E+02, 0.10948800E+03, -.98530200E+00, 0.11724200E+03, -.20339600E+02, 0.41929300E+01, -.33896300E+03, 0.14405400E+02, 0.22539900E+02, -.22845600E+02, 0.15986800E+03, 0.84778100E+02, 0.14210200E+03, -.14909800E+02, -.27096500E+03, -.34895600E+01, -.19948000E+02, -.35477400E+02, -.32221500E+02, 0.11002000E+02, -.16610900E+01, -.12733900E+02, 0.31244500E+02, 0.15494200E+02, -.16702300E+02, -.22012400E+02, -.15756900E+01, -.33150900E+00, -.88881800E+01, 0.31859700E+02, 0.28071700E+02, 0.26151400E+02, 0.10560400E+02, -.33855400E+02, -.11552200E+02, 0.22975700E+02, -.31647200E+02, -.89404300E+02, 0.27810200E+02, 0.17446900E+02, 0.23524600E+02 },
        { -.89289400E+01, 0.25540000E+01, 0.11643700E+01, -.23496100E+01, 0.18205200E+01, -.72412400E+00, -.17467000E+01, 0.57308500E+01, -.21836700E+01, 0.77591900E+00, 0.17243800E+01, 0.72720500E+00, 0.20017000E+01, -.28707800E+00, -.45902300E+00, -.26316100E+01, 0.31263900E+01, -.76893200E-01, -.13088900E+01, 0.16660000E+00, 0.25407600E+01, 0.77039000E+00, -.77003300E+00, 0.88522100E+00, -.57469100E+00, 0.58213900E-01, 0.17185100E+01, 0.13447800E+01, -.63143400E+01, -.82047300E-01, -.32591500E+00, 0.63608700E+00, 0.13465100E+00, 0.21257100E+01, 0.93824400E+00, 0.21853900E+00, -.37369500E-01, 0.10190600E+01, -.59078700E-01, -.11468800E+00, 0.42512900E+01, -.30877000E+00, 0.24872600E-01, 0.22655300E+00, 0.55834500E+00, 0.23210100E+00, 0.52077800E-01, -.16311700E-01, 0.13357700E+01, 0.21168900E+00, 0.46443100E-01, -.17470200E+01, 0.83016000E+00, -.90146700E+00, 0.86789100E-01, -.68371200E+00, -.59222900E+00, 0.13206600E-01, 0.99870600E-02, -.38008300E+00, -.26702000E-01, 0.13202500E+00, -.20959800E+00, -.64853100E+00, -.97805000E+00, -.11603700E+01, 0.34879200E+00, -.45935100E+00, 0.12976600E+01, 0.69737300E-01, 0.53483500E+00, -.43192800E+01, -.50947100E+00, -.12965900E+01, 0.67271700E+00, -.20805100E+00, -.11943700E-01, 0.33852400E+00, -.45949700E+00, -.73130500E-01, -.33591400E-01, 0.14867400E+00, 0.14244800E+00, -.84964200E-02, 0.81640700E-02, 0.21709400E+00, 0.30177600E+00, 0.97953700E-01, -.97415200E-01, 0.47841200E-01, -.16594900E+00, 0.86246800E-03, -.15078600E+00, 0.54188900E-01, -.11998100E+01, -.64068300E+00, -.19563000E+00, 0.19961100E+00, -.18026000E+00, -.48345300E+00, -.98452300E-01, -.19198200E-01, -.31519700E-01, 0.36042400E+00, -.22149700E+00, 0.11366200E+01, 0.40195500E+00, -.69426700E+00, 0.24308000E+00, 0.39078600E+00, -.75117600E+00, -.22225300E-01, -.59656200E+00, -.91027400E-02, 0.90737100E-01, -.45195400E+00, -.34876800E+00, -.13499200E+00, 0.18508900E+01, 0.37758700E+00, 0.48629700E+00, -.10186500E+00, 0.11199800E+00, 0.24858700E+00, -.11268300E+00, -.65155400E-01, -.25958400E-01, -.11126000E+01, 0.26870300E-01, 0.42287500E+00, -.13127200E+00, -.26599000E-01, 0.78511700E-01, -.15218700E+01, -.58610000E+00, -.58173300E-01, 0.20615100E+01, 0.69321500E+00, -.20684500E+00, -.20049800E+00, -.19019300E+01, -.74671400E+00, -.18682700E+01, -.11794300E+01, -.14796800E+00, -.33497600E+00, -.13607600E-01, 0.11007100E+01, -.91574400E-01, -.38515100E+00, 0.54151800E+01, 0.50964100E+00, 0.77175000E-01, 0.22874500E+01, 0.50473800E-01, -.13613500E+01, 0.26005400E-01, 0.19873300E-02, 0.14270500E+01, 0.50407100E+00, 0.36949900E-01, 0.27730100E-01, 0.92545400E-01, 0.95416100E-01, 0.64429400E+00, 0.12592100E+00, 0.17173400E+03, -.44312800E+03, 0.83176300E+00, -.39129900E+02, -.71270200E+02, 0.13243600E+03, 0.39884200E+03, 0.23419700E+03, -.87920500E+02, -.29145100E+03, -.27163000E+02, -.46858400E+00, -.25319400E+02, 0.13070400E+02, -.93911800E+02, 0.97639300E+02, -.66919300E+02, -.56031200E+02, -.74673700E+02, 0.78931700E+02, 0.23496300E+03, -.30501500E+03, 0.16722700E+03, -.87044300E+02, 0.14783400E+03, 0.15688400E+03, 0.17145200E+03, 0.25194100E+02, 0.24414500E+03, 0.15740900E+03, 0.13126000E+03, -.29736500E+03, -.30774400E+03, 0.14688200E+03, 0.19639500E+03, 0.15434900E+03, 0.45838100E+02, 0.32366500E+02, 0.12900600E+03, 0.55337400E+02, 0.52491000E+02, -.79489100E+01, -.35497800E+02, 0.15554000E+03, -.90474500E+02, -.70339500E+02, -.80105500E+02, 0.10291000E+02, 0.96289100E+02, -.57836100E+02, -.81189100E+02, -.69443800E+02, 0.93519100E+02, 0.19061000E+03, -.36941000E+03, 0.16224000E+03, 0.22605200E+03, 0.18475500E+03, 0.25176300E+02, 0.29065300E+02, 0.34501900E+02, -.10578300E+03, 0.65472000E+02, 0.20143700E+02, 0.43918600E+02, 0.31858800E+01, 0.44326400E+00, -.18418700E+01, -.15707300E+01, -.96959500E+01, -.35089100E+01, 0.47510800E+02, 0.49695700E+02, 0.11936900E+02, -.12511400E+02, -.10527700E+02, 0.14191700E+03, -.56621700E+02, 0.55613800E+02, -.71581700E+02, -.56272100E+02, -.69207400E+02, 0.24954300E+02, 0.87180900E+02, -.21923000E+02, -.69501800E+02, -.14620000E+03, 0.18008400E+03, -.68770700E+02, -.14410700E+02, -.89401400E+02, -.75048300E+01, -.14487200E+03, 0.10579200E+03, 0.59314900E+02, 0.63304400E+02, -.14466600E+03, -.17803000E+03, 0.88349500E+02, -.35782700E+02, 0.17104000E+02, -.46436300E+02, 0.60975900E+01, -.13796600E+03, 0.93432100E+02, -.12679700E+02, 0.31575800E+02, -.11141000E+03, -.42420900E+02, 0.19700000E+00, 0.41814900E+01, 0.29378100E+02, 0.27964100E+02, 0.19195300E+01, 0.17004100E+01, 0.24395600E+02, -.15997800E+02, 0.13880000E+01, 0.43803700E+00, -.10020600E+01, 0.68457200E+01, 0.67601200E+01, -.74704500E+00, -.17224200E+02, -.10793900E+02, -.25430900E+02, -.23673600E+02, 0.23853400E+02, 0.12411400E+01, -.25519200E+02, 0.56565100E+01, -.39933800E+02, -.10205000E+02, -.11931700E+02, -.49692800E+01 },
        { 0.17431000E+01, 0.40195900E+00, -.93575300E+00, -.96245000E+00, -.11054800E+01, -.41694500E+00, -.68118500E+00, 0.96949600E+00, -.15144100E-01, -.56332800E+00, 0.15568900E+00, -.12886800E-01, 0.98261700E-01, 0.40574100E-01, 0.92107000E-01, -.42004300E+01, -.22785100E+00, 0.48502500E-01, -.52703100E+00, -.31957600E+00, 0.18160500E-01, 0.19735500E+00, -.27383500E-01, -.20062900E+00, -.18425000E-01, 0.28138600E-01, 0.21436200E+00, 0.11943200E+00, -.43702700E+00, 0.33909500E-01, 0.24111300E-01, 0.13553700E+00, 0.28099200E+00, 0.12999500E+00, 0.13002700E-02, 0.77543900E-02, -.97923600E-02, -.50150200E+00, -.75687900E-03, -.37436100E+00, -.26915600E+00, 0.20075300E+00, 0.51010300E-01, 0.12152400E+00, -.71126100E-01, -.21035400E-01, -.30478700E-02, 0.48835600E-02, -.60558100E+00, -.16413200E-02, 0.28830500E+00, 0.53671600E+00, -.29501000E+00, 0.99913800E+00, 0.14235300E+00, -.21539700E+00, -.23152000E-01, 0.52270500E-01, -.23152800E-01, -.14745000E-01, 0.40071800E-01, -.58300400E+00, -.13940300E+00, 0.19223000E+00, 0.67191100E-01, 0.26692400E-01, 0.13256700E+00, -.60217100E-01, -.15493800E+00, 0.60571000E-02, 0.19729000E-01, -.61273700E+00, -.90643100E+00, -.10349200E+01, 0.94329800E-01, -.68696100E+00, 0.10255200E+00, -.17135300E+00, 0.16161400E+00, -.12132700E-01, -.69835800E-02, 0.11634200E-01, 0.79200000E-02, 0.16130500E+00, -.26945400E-02, -.13273100E+00, -.46478700E-01, -.95651200E-01, -.91162800E-02, -.40717700E-02, 0.14331900E+00, -.10824400E-02, 0.28222100E+00, -.26975900E-01, -.25187800E+00, -.47338900E+00, 0.14425400E-01, 0.25081300E-01, -.72346400E-02, -.20416000E+00, -.94394500E-02, -.32719500E-01, 0.15707700E-02, 0.21909600E-01, 0.17768000E-01, 0.14546900E+01, 0.63627000E-01, -.47803800E-01, 0.44334900E-01, 0.69777600E-01, -.20609000E+00, -.16774900E-01, -.88625100E-01, 0.61723300E-02, 0.21722400E+00, -.15846500E+00, 0.20794000E-01, 0.72536500E-01, -.27576300E+00, 0.69541500E+00, -.15415400E+00, -.11594200E-01, 0.90529400E-01, -.22474200E+00, 0.14167300E-01, -.10447400E+00, -.70799500E-01, 0.16743300E+00, -.27754900E+00, -.79422500E-01, -.47027500E-01, -.34749700E-01, 0.17020800E+00, 0.65168000E-01, -.49252300E-02, -.68322800E-02, 0.11287400E+00, 0.90506700E-01, -.22606600E-01, -.29017100E+00, 0.94735500E-01, -.37628100E-01, -.33361300E+00, -.13211600E+00, -.58562500E-02, 0.48574700E-02, -.33108900E-02, 0.18277400E+00, 0.27098200E-01, -.28079300E+00, 0.24403200E+00, -.12043600E+00, -.10775300E+00, -.19411000E+00, -.47337500E-01, 0.59307300E-02, -.50615500E-01, -.20728700E-02, -.90190600E+00, -.10950800E+00, -.49744500E-01, -.12733500E+00, -.32930500E-01, -.24958600E+00, 0.16570900E+00, -.36877400E-01, 0.36005000E-01, 0.21612600E+03, 0.18943600E+00, 0.52861800E+01, -.47073400E+01, -.14792700E+02, -.70027000E+02, -.79308400E+02, -.47079700E+00, 0.44781400E+02, 0.25193200E+03, -.12540200E+03, -.73058500E+02, -.13235900E+03, 0.12720600E+03, 0.87361900E+02, -.15356000E+02, 0.14814100E+03, -.49160500E+02, 0.61959300E+02, -.14839200E+03, -.12535300E+03, 0.65236200E+02, 0.18466100E+03, 0.64315500E+02, 0.27598400E+02, 0.32917200E+02, -.32890600E+02, -.11385800E+03, -.53301800E+02, 0.37105600E+02, 0.84202500E+02, -.29400600E+02, 0.11793000E+02, 0.36447500E+02, 0.13645500E+02, -.14240100E+01, 0.12976500E+02, -.38298900E+02, -.39697500E+02, -.32634700E+02, 0.14759100E+02, 0.17089700E+02, -.20353800E+03, 0.10174200E+03, 0.34281600E+02, 0.98727100E+02, 0.61716600E+02, 0.69309600E+01, -.36985600E+02, 0.14015700E+02, 0.14572800E+03, -.14415500E+02, 0.11825500E+03, 0.11326800E+03, -.52941000E+02, -.55817700E+02, -.56408000E+02, -.21270600E+02, -.38127300E-01, -.95298000E+01, 0.14647200E+02, -.29699900E+02, -.26752700E+01, -.73674200E+02, -.16747000E+02, 0.70860600E+01, 0.90673900E+01, 0.83925000E+01, -.37491700E+01, 0.50651000E+01, -.26439300E+02, -.64330200E+01, 0.22238700E+02, 0.73044900E+01, 0.54369000E+02, -.18733200E+02, 0.73101300E+01, 0.27804800E+02, 0.92841500E+01, -.35702800E+00, 0.41649200E+01, 0.15693700E+02, -.27953600E+02, -.21820000E+01, 0.13462100E+02, -.68662000E+02, -.75442300E+02, 0.35630300E+02, 0.15777300E+02, 0.39192900E+02, -.80682600E+02, -.14707700E+02, -.51272100E+02, -.11995700E+03, -.63989800E+02, 0.51668000E+01, 0.26713100E+02, -.14607400E+03, 0.69533200E+02, 0.22456600E+02, 0.70700400E+02, 0.39750900E+02, 0.53341000E+02, -.74518800E+02, -.80947300E+01, 0.53846200E+02, 0.16118900E+02, 0.23025800E+03, -.72075300E+01, 0.63324900E+01, 0.10211300E+02, 0.71999600E+01, -.11913700E+02, 0.91275800E+01, -.83782400E+01, -.40069700E+01, -.68447100E+01, 0.42581300E+01, 0.74063000E+01, -.12245600E+02, -.64265800E+01, 0.12189700E+02, -.31544000E+01, -.13248400E+01, -.67663400E+01, -.28140400E+02, 0.10366200E+02, 0.10281900E+02, 0.77084400E+01, -.18676700E+00, 0.26813200E+02, -.56525300E+01, -.80787100E+01, -.24609600E+01 },
        { -.89960800E+01, -.10364200E+01, 0.14186700E+01, 0.33394900E+00, 0.39342700E+01, 0.20804800E+01, 0.70149300E+00, 0.87288000E+01, -.13656800E+01, 0.11645100E+01, 0.22857300E+01, 0.89686000E+00, 0.22032700E+01, -.32104400E+00, 0.12359700E+01, -.22463200E+02, 0.24796900E+01, -.34927800E+01, -.29247200E+01, 0.66961300E+00, 0.38545200E+01, 0.84420800E+00, -.81711800E-01, 0.25578900E+01, 0.12367000E+00, -.25713700E+00, 0.22031200E+01, 0.22107100E+01, -.77931100E+01, -.55463400E+00, 0.16989700E+00, 0.15628200E+01, -.18887600E+00, 0.24829700E+00, 0.73374200E-02, 0.76801600E-01, -.14577900E+00, -.53991700E+00, 0.17289200E+00, -.19919500E+01, 0.38760000E+01, 0.81121300E+00, 0.12724100E+00, 0.20543500E+00, -.95083800E+00, 0.12260500E+01, -.16308600E+00, -.13805900E+00, -.35350500E+00, 0.34776300E+00, -.46743400E+00, -.58476200E+00, -.12909900E+00, 0.17167900E+01, 0.27067300E-01, 0.24765900E+00, -.31232600E-01, 0.67901300E-01, -.11661900E+00, 0.55874500E-01, 0.17020100E+00, -.58783300E+00, -.24384200E+00, -.26460300E+00, -.69281600E+00, -.19071900E+00, 0.92147100E+00, -.27547600E+00, -.88190800E+00, 0.40680400E-01, 0.27894400E+00, -.65915600E+01, -.15395000E+01, -.15416600E+01, 0.15697800E+01, -.15025900E+01, 0.11802100E+00, 0.96543800E+00, 0.81553800E+00, -.12959000E+00, -.13256400E+00, 0.24141000E+00, 0.82443600E-01, 0.40586100E-01, -.14512100E+00, -.15232700E+00, -.44487400E-01, -.15077900E+00, -.23741100E+00, -.14116600E+00, -.18029500E+00, -.10198500E-01, 0.21396100E+00, 0.30457900E-01, -.68932800E+00, -.10114500E+01, -.49860700E+00, -.16108000E+00, -.20626300E+00, -.33999700E+00, -.58536000E-01, -.25138000E+00, -.10119700E+00, 0.45246800E+00, -.96462000E-01, 0.89295200E+00, 0.17889100E+00, -.82371500E+00, 0.37818300E+00, 0.49723600E+00, -.11703400E+01, 0.88978800E-01, 0.40511100E+00, -.73241100E-01, -.26068900E+00, -.10768200E+01, -.42675000E+00, 0.27837300E+00, 0.16709600E+01, -.42671200E+00, -.33882100E+00, -.45023600E-01, -.15191100E+00, 0.44905400E+00, -.14393800E+00, 0.30723200E+00, 0.65267000E-01, -.20526800E+01, 0.22546500E+00, 0.39046300E+00, 0.36947700E+00, -.18712600E+00, 0.23051600E+00, -.39752000E+00, -.27742700E+00, -.39945500E-01, 0.11967300E+01, 0.61321400E+00, -.11245700E+00, -.97244900E+00, 0.23943000E+00, 0.26582500E-01, -.99428500E+00, -.47054400E+00, 0.37869100E-01, -.56701100E-01, -.29195100E-01, 0.65238900E+00, -.12394100E+00, -.84230500E+00, -.19169900E+01, -.18957000E-01, -.10999800E+00, 0.13106800E+01, 0.35093700E-01, 0.15323500E+00, 0.23621800E+00, 0.62248600E-02, 0.22365900E+00, 0.73482500E+00, -.24613400E+00, -.44828500E+00, -.97529200E-01, -.10392700E+00, 0.98269200E+00, 0.27830300E+00, 0.25561800E+00, 0.10330900E+00, 0.19109400E+02, -.95550900E+02, -.10737600E+03, -.15610300E+03, 0.63126800E+01, 0.15353600E+02, -.16835200E+03, 0.19233000E+03, 0.43219100E+03, -.21351800E+03, -.12789600E+03, -.22517700E+03, 0.13248900E+03, 0.23680900E+03, -.84371500E+02, 0.36561500E+03, -.48482500E+02, 0.13895500E+03, -.17818300E+03, 0.54847200E+03, -.23487300E+03, -.14252200E+03, -.25230100E+03, -.67096100E+01, 0.76589200E+02, -.50661300E+03, -.11543600E+03, -.21739300E+03, 0.75464700E+01, 0.50192600E+02, 0.24371100E+03, -.12759500E+03, -.42310800E+02, -.11903200E+03, -.12796800E+02, 0.34836300E+02, -.20519200E+03, -.15329600E+03, -.62523900E+02, -.28093900E+02, -.64632100E+02, -.74196300E+03, 0.37369900E+03, 0.43038200E+03, 0.35926800E+03, 0.11982700E+03, 0.10655800E+03, -.46005000E+01, -.60961400E+02, 0.30837400E+03, 0.98130400E+02, 0.41221600E+03, 0.23499600E+03, -.11731600E+03, -.61077900E+02, -.11627700E+03, -.37452300E+02, -.12552900E+01, -.70575000E+02, 0.24992300E+02, -.48312300E+02, -.19089300E+02, -.70574100E+02, 0.29545500E+03, -.14473200E+03, -.23841000E+02, -.14761300E+03, -.29027300E+02, -.33121300E+02, -.35237000E+02, 0.49791700E+02, -.76308900E+02, -.21660600E+02, -.17229700E+03, -.38992500E+01, 0.57746500E+00, 0.11675500E+03, -.12044700E+01, -.60524500E+02, -.63045200E+02, 0.82920200E+02, -.44373300E+02, -.32614600E+02, -.48712400E+02, -.64417500E+02, 0.24681700E+03, -.12491600E+03, -.36357500E+02, -.11980600E+03, -.10129700E+03, -.13464400E+03, -.61359400E+02, -.21919600E+03, -.16012300E+03, -.61659500E+02, -.78122100E+02, -.14081400E+03, 0.81976600E+02, 0.11302200E+03, 0.58875600E+02, 0.49617400E+02, 0.55624500E+01, -.82343100E+02, 0.42210100E+02, 0.56798500E+02, -.97354300E+02, 0.34233400E+03, -.21305800E+02, 0.27050800E+01, -.18529000E+02, -.30061500E+02, -.15974200E+02, 0.12155800E+02, -.15418200E+01, -.34028800E+01, -.23129300E+01, 0.10575800E+01, 0.38993000E+01, -.25182300E+02, -.34946600E+01, 0.19299200E+02, -.41236200E+01, -.48211200E+01, 0.17701700E+02, -.82131500E+02, -.10772000E+02, 0.19392300E+02, 0.69378500E+01, 0.37788100E+01, 0.42532000E+02, -.75915900E+01, -.30424400E+02, -.18514600E+01 },
        { -.20781400E+01, -.84474600E+00, 0.69023300E+00, 0.11011600E+01, 0.20438200E+00, 0.12598400E+01, 0.29104200E+01, -.32796000E+01, -.14824600E+00, -.18173400E+01, 0.95839400E-01, 0.60270900E+00, 0.42043200E+00, -.20751400E+00, -.26380400E+00, -.46347900E+01, -.77545600E+00, -.17303900E+00, 0.17086100E+01, 0.61646100E-01, 0.25993600E-01, -.24053900E+00, 0.26996100E-01, -.21735100E+00, 0.66109400E-02, -.13812600E-01, 0.15508800E-01, -.37147700E+00, 0.16107900E+00, -.36829300E-01, -.14445800E+00, 0.75644700E+00, -.22935800E+00, -.22930800E+01, -.25546100E-01, -.51487800E-01, 0.29397700E-01, 0.36850500E+00, -.11784000E+00, 0.60347200E+00, 0.13159100E+01, -.82970100E+00, -.24163100E-01, -.73793000E-01, 0.76647600E+00, -.42026900E+00, 0.69828500E-01, 0.48228200E-01, 0.76952500E+00, 0.14014300E+00, 0.29122700E-02, 0.44502900E+00, 0.53661200E-01, 0.62624500E+00, 0.22996300E+00, -.77652000E+00, 0.40588300E-01, -.58093000E-01, 0.17564800E-01, 0.26579200E+00, -.24537600E+00, 0.32541300E+00, -.21844400E+00, -.10257800E+00, -.11508400E+00, -.12646900E+00, 0.74852400E+00, 0.15029600E+00, 0.53448000E+00, 0.10868600E-01, -.22921000E-01, 0.22767500E+01, 0.87092900E+00, 0.18982100E+01, -.75804700E+00, -.29865300E+00, -.71997100E-01, 0.18015900E+00, -.46610200E+00, -.65646900E-01, 0.93180700E-02, 0.37638800E-01, 0.34186700E-01, 0.98294600E+00, 0.17386300E+00, -.45197500E+00, -.12891200E+00, 0.17970700E+00, 0.20440600E+00, 0.60359600E-01, -.18682500E-01, -.37418700E-02, -.29877700E+00, -.50814300E-01, 0.35751300E+00, 0.35874800E+00, -.48108900E+00, -.41372100E+00, 0.17151500E+00, 0.16111600E+00, -.31957500E-01, -.42033000E-01, -.23391000E-01, -.39974800E+00, -.75903900E-01, 0.94931400E+00, 0.24891000E+00, -.16190400E+00, 0.33286700E+00, 0.79002000E-01, -.32455200E+00, 0.31575900E-03, 0.10078300E+01, -.32312200E-02, 0.13627800E+00, -.14216700E+01, -.34444600E+00, 0.75713200E+00, -.10661800E+01, 0.17116300E+01, -.87536400E+00, 0.82929800E-01, 0.24566500E+00, -.21197800E-01, 0.46823300E-01, -.32458900E-01, 0.23338600E+00, -.14044200E+01, -.19119300E+00, -.29343000E+00, 0.53447600E+00, -.11153300E+00, -.13434300E+00, 0.14839700E+00, 0.20766000E+00, 0.22609500E-01, -.39584600E+00, -.30804100E+00, 0.31221200E-01, -.83107500E+00, 0.12397600E+00, 0.50397900E-01, 0.95619100E+00, -.14902900E+00, -.78720200E-01, 0.50014300E+00, -.44918700E-01, -.29207900E+00, 0.16870500E+00, 0.75964000E+00, 0.21326700E+01, -.16215200E+00, -.36957000E-01, -.15197200E+00, -.67854800E-01, 0.67288700E-01, 0.15735500E-01, -.17422300E-02, 0.56477400E+00, -.70457800E-02, 0.19585700E-01, -.38966900E+00, -.93993300E-01, -.97633300E-01, -.83867700E+00, 0.83006800E-01, -.12977800E-01, 0.58603700E+00, -.15779900E-01, -.62985900E+02, -.60013000E+02, -.35650100E+02, -.17247100E+03, -.27013800E+02, -.17498900E+02, 0.12856900E+03, -.63649400E+03, 0.31799600E+03, 0.16268500E+03, 0.32652400E+03, -.74718100E+02, -.17812800E+03, 0.15827600E+03, -.75638400E+02, 0.22121100E+03, -.12725000E+03, 0.61653800E+02, 0.30992300E+03, -.16159800E+03, -.59547100E+02, -.15487500E+03, -.13358000E+03, -.14729600E+03, -.22031200E+02, -.70003100E+02, -.83952000E+02, -.95007600E+02, 0.95671600E+02, 0.26699400E+03, -.13889500E+03, -.10589800E+03, -.13219500E+03, -.23916800E+02, -.62247700E+02, 0.41021000E+02, 0.63265500E+01, -.51195000E+02, -.20738200E+02, -.31799600E+02, -.34115600E+03, 0.17400900E+03, 0.42003300E+03, 0.17372600E+03, 0.81495500E+02, -.57065100E+02, 0.22887400E+03, 0.56733500E+02, 0.41740800E+02, -.17531400E+02, -.24890500E+03, 0.16178300E+03, -.82064400E+02, -.15948100E+03, -.81153800E+02, -.27967700E+02, 0.73544600E+01, -.48729300E+02, 0.57621300E+02, -.12594600E+02, -.10008600E+02, 0.36111200E+02, 0.21378000E+02, -.10685800E+02, 0.15654000E+03, -.10707300E+02, 0.42087700E+01, -.30010100E+02, 0.27628200E+02, -.18348400E+02, -.42360300E+02, -.13934600E+02, -.63753800E+02, -.19253400E+03, 0.93651500E+02, -.99535600E+02, 0.96264300E+02, -.49522300E+02, 0.16335900E+02, 0.10753500E+02, -.33676300E+02, 0.43450100E+02, -.74437100E+01, 0.31423800E+03, 0.26673500E+03, -.13332200E+03, -.15701300E+03, -.13495000E+03, 0.22555200E+02, 0.87658000E+02, -.41965500E+02, 0.73569100E+02, -.66102000E+02, 0.48932300E+02, 0.71121400E+02, 0.28681900E+03, -.14433600E+03, -.10350600E+03, -.14107200E+03, -.52000400E+02, 0.12675400E+02, 0.15536500E+03, 0.90586100E+02, -.99624200E+01, 0.37649600E+02, -.15558900E+03, 0.29881500E+02, -.12682800E+02, -.55223100E+02, -.50625000E+02, 0.93218800E+01, 0.16356400E+01, -.71420000E+01, 0.24535900E+02, 0.64136200E+01, -.66764900E+01, -.11220900E+02, 0.13912800E+02, 0.72991200E+00, -.77037300E+01, 0.24554900E+02, -.14850200E+01, 0.52621800E+02, 0.28662900E+02, -.54212900E+02, -.56271700E+01, 0.87104500E+00, -.13885400E+01, -.84115000E+02, 0.14333000E+02, 0.17342800E+02, 0.80963700E+01 },
        { -.75273900E+01, -.39016100E+01, 0.27929600E+01, 0.74484100E+01, 0.92084700E+00, 0.26934900E+01, 0.44781600E+01, -.21513500E+02, -.65134800E+00, -.37618100E+01, -.36045300E+01, 0.87232300E-02, -.56904800E+00, -.54918000E+00, -.57067200E+00, 0.29681000E+01, -.79381400E+01, -.29431500E+01, 0.18975100E+01, 0.21799900E+00, 0.39531400E+01, 0.25820400E+00, 0.74599400E-01, -.12225000E+01, -.27565700E-01, -.19327100E+00, -.16787000E+01, -.41797800E+01, 0.37602600E+01, 0.21350300E+00, -.18065900E+01, -.31966000E+01, 0.80223100E-01, 0.15554100E+01, -.10690800E+00, -.14634600E+00, 0.14412300E+00, 0.35612000E+01, -.47839000E-02, 0.16058700E+01, 0.23677600E+01, 0.76641400E+00, -.39376100E+00, -.29956500E-01, -.56767000E+00, -.99818200E+00, 0.11867700E+00, -.61954200E-01, -.34182400E+01, -.30786800E+00, -.10908100E+01, 0.72552000E+00, -.86459400E+00, 0.34193500E+01, -.49396300E+00, 0.18905000E+01, 0.76956400E+00, 0.18928700E+00, -.25507900E-01, 0.14964000E+01, -.55630800E-02, 0.68378600E+00, 0.29452600E-01, -.33481700E+00, -.85401200E+00, 0.73935700E+00, 0.12670000E+01, -.60666600E-01, -.20976700E+01, -.31609200E-01, -.97940000E-01, -.17778100E+01, 0.58307500E+00, -.27564900E+01, 0.12554300E+01, -.86110200E+00, 0.23102800E+00, -.61074800E+00, 0.41234600E+00, -.14334500E+00, -.20145900E+00, 0.17390900E+00, 0.38207800E+00, 0.21864800E-01, -.59678200E+00, 0.40091100E+00, -.20122800E+00, -.58441200E+00, -.87169700E+00, 0.11240700E+00, 0.33703600E+00, 0.53053200E-02, -.54470900E-01, -.26888900E+00, 0.69480700E+00, -.65969600E-01, 0.15155300E+00, -.18821600E+00, -.51773200E-01, 0.94320400E+00, -.90511200E-01, 0.19610100E+00, 0.69430300E-01, -.18167400E+00, -.17609300E+00, 0.87946000E+00, 0.50088100E-01, 0.12518000E+01, -.59755500E-01, -.21504100E+01, -.51349200E-01, 0.36557100E-01, -.35307300E+01, 0.22309700E-01, 0.23583200E+00, -.83023800E+00, -.19784600E+00, 0.90199200E+00, 0.66706700E+00, -.33225700E+00, -.54071700E+00, -.10142500E+00, 0.12418900E+00, 0.45673200E-01, -.92483500E-01, 0.38569300E+00, 0.18922800E+01, 0.99666300E+00, 0.23531200E+00, -.74539400E+00, 0.13162400E+01, -.52420900E+00, 0.10361900E+01, -.65151900E+00, -.27175900E+00, 0.30985300E-01, 0.22065000E+00, 0.22030100E+00, -.77015500E-03, 0.66972500E+00, 0.49715000E+00, 0.86341200E-01, 0.80259800E+00, -.19887900E+01, -.22398000E+00, -.19131100E+01, -.23229500E+00, 0.13476600E+01, -.29698700E+00, 0.71083600E+00, 0.61671700E+01, 0.74658900E+00, 0.12350600E+01, -.13206600E+01, -.18351600E+00, -.24018000E+01, -.37601500E-01, 0.13212500E-01, -.23479500E+01, -.18970200E+01, -.90937700E-01, -.25507600E+00, 0.43708500E+00, 0.37711600E+00, -.15216500E+01, -.95491500E+00, -.94217800E-01, -.63108400E-01, -.47342400E-01, -.14702800E+01, 0.20264900E+03, -.87604200E+02, -.23252200E+03, -.14159100E+03, 0.36603500E+03, 0.35937600E+02, -.19782900E+04, 0.98257700E+03, 0.30873700E+03, 0.10439100E+04, -.37810600E+03, -.42830100E+03, 0.38377800E+03, -.38490200E+03, 0.26574300E+03, -.23434600E+03, 0.93514700E+03, -.21137400E+03, 0.82282800E+02, 0.40228100E+03, 0.99032400E+02, -.81230700E+02, -.22845800E+02, 0.25445700E+03, 0.23272600E+02, -.93271100E+02, 0.13265000E+03, 0.62406100E+02, -.75126200E+03, 0.37253300E+03, 0.29155900E+03, 0.38377100E+03, 0.23013100E+03, -.19965200E+02, 0.46080400E+03, 0.13575800E+03, 0.27897600E+03, -.91821700E+01, 0.75627700E+02, -.13450700E+04, 0.67625900E+03, 0.10585100E+04, 0.69642100E+03, 0.26706100E+03, 0.90721000E+02, 0.55237300E+03, -.14528500E+03, -.63566100E+02, 0.20685400E+03, 0.30394100E+03, -.32681200E+02, -.33944800E+00, -.19818800E+02, 0.13876300E+02, -.35196300E+02, 0.18063300E+02, -.54389200E+02, 0.69396300E+02, 0.32294100E+02, -.13349500E+02, 0.50689500E+02, -.19185000E+03, 0.10027900E+03, 0.23926700E+03, 0.95774000E+02, 0.12006300E+03, -.82659500E+02, 0.21758000E+03, -.20588300E+02, -.30206200E+02, -.71494200E+02, -.12184100E+03, -.57669800E+03, 0.29131000E+03, -.19728300E+03, 0.28907700E+03, -.27858600E+02, -.66775700E+02, 0.17313100E+03, 0.12821400E+03, 0.19923900E+03, -.18152400E+03, 0.42441000E+03, 0.11226600E+04, -.54936100E+03, -.62903900E+03, -.57283200E+03, 0.10916600E+03, 0.10119000E+03, -.71200000E+02, 0.24723300E+03, 0.58601800E+02, -.24112000E+02, -.38994600E+03, 0.97997300E+03, -.48311500E+03, -.10034500E+04, -.47154100E+03, -.28430700E+03, -.18945400E+03, 0.65562900E+03, 0.19308900E+03, 0.51211100E+02, 0.35398700E+02, -.26416800E+03, 0.11641500E+03, -.30936700E+02, -.18319900E+03, -.16210000E+03, 0.27964200E+02, 0.19506800E+02, 0.23251500E+02, 0.50836700E+02, 0.28477500E+02, -.20493200E+02, -.53959600E+02, 0.42315300E+02, 0.25766500E+02, -.20162900E+02, 0.50013400E+02, -.22202900E+01, 0.16552100E+03, 0.61928000E+02, -.18086800E+03, 0.76980900E+01, 0.26592400E+02, -.64376800E+01, -.45325100E+03, 0.53305700E+02, 0.55133300E+02, 0.11964900E+02 },
        { -.10247400E+02, 0.48900400E+01, 0.21796400E+01, -.33550400E+01, 0.68687000E+00, -.23709900E+01, -.26511300E+01, -.91752200E+00, -.25950900E+01, -.52275000E+00, 0.77010300E+00, 0.33278300E+00, 0.29600800E+01, -.34013000E+00, -.29731900E+00, -.19253000E+01, 0.12864900E+02, 0.97424500E+00, 0.13664200E+01, 0.85293100E+00, -.10009900E+00, -.10051500E+01, -.55876000E+00, 0.15524800E+01, -.10443500E+01, 0.15766700E+00, 0.20871700E+01, 0.22055400E+01, -.55376900E+01, 0.36747700E-01, 0.11235300E+01, 0.66907800E-01, -.10664400E+01, -.38373900E+01, 0.30389300E+00, 0.41226100E-01, 0.60466900E-01, 0.34220200E+01, 0.61544700E+00, 0.58236100E+00, 0.20089100E+01, -.79729700E+00, -.22755000E+00, 0.15847900E+00, -.30649700E+00, -.64470600E+00, 0.64323300E-01, -.47609300E-01, 0.58059000E+00, -.22654000E+00, 0.13347700E+00, -.11064400E+01, 0.17905400E+01, -.18548800E+01, -.29062900E+00, 0.59660500E+00, -.15255200E+01, -.31954200E-02, 0.47482800E-01, -.23077200E+01, 0.88191700E+00, 0.54419700E+00, 0.25481300E+00, -.11207000E+01, -.80180700E-01, -.72343400E+00, 0.44011700E+00, 0.32041000E-01, 0.16853600E+01, 0.35365700E-01, 0.36853400E+00, 0.10001000E+01, 0.10441200E+01, -.11287800E+01, -.28080700E+00, 0.57557000E+00, -.96750500E-02, -.66477600E+00, -.12508100E+01, 0.66590000E-01, 0.52092200E-02, -.37328100E-01, 0.42540100E+00, 0.24403400E+00, -.38540000E-01, 0.34860600E+00, -.22849900E-01, 0.38215300E+00, -.53354500E+00, 0.25158100E+00, -.11079200E+01, 0.70041100E-02, -.41232900E+00, 0.10532100E+00, -.62360300E+00, -.19101900E+00, 0.75637800E+00, 0.92178800E+00, -.25323500E+00, -.51350100E+00, -.18384800E-01, 0.31867000E+00, 0.42734300E-01, -.19260200E-01, -.17665500E+00, 0.15603100E+01, 0.12075100E+00, 0.88447100E-01, -.17061500E+00, -.41226300E+00, 0.46321300E-01, -.93401100E-01, -.14518400E+01, 0.18533400E-01, 0.38124000E+00, 0.39122300E-01, 0.12551700E+00, -.23419800E+00, 0.47544200E+00, 0.44372700E+00, 0.12027200E+01, -.19349600E+00, 0.38829500E+00, 0.28643100E+00, -.15730600E+00, 0.83472300E+00, -.85695800E-01, 0.28288400E+00, -.65780500E+00, 0.13272700E+00, -.17317400E+00, -.16211400E+00, 0.26839300E+01, -.24854500E+01, -.55661600E+00, -.55238400E-01, 0.18867900E+01, 0.16881700E+00, -.11962900E-01, 0.52861100E+00, -.31524100E+01, -.78308800E+00, -.28544200E+01, -.93491700E+00, -.25920300E+00, -.49887700E+00, 0.31850400E-01, 0.88670000E+00, -.14659800E+00, -.97635600E+00, 0.47440000E+01, 0.83335100E+00, -.31448400E-01, 0.28456700E+01, -.68471500E-01, -.33873500E+01, -.26548500E+00, 0.51518200E-02, 0.23912100E+01, 0.15071000E+00, 0.29419900E+00, 0.92769500E+00, -.33503900E-01, 0.56676300E+00, -.18888400E+00, 0.26536100E-01, -.49706600E+00, -.35833800E+01, 0.86071200E-01, 0.13460900E+00, -.96768700E+00, 0.40566400E+03, 0.49911300E+03, 0.17335000E+03, 0.21173100E+03, -.55145800E+03, -.11435600E+04, 0.54369300E+03, -.25001700E+02, 0.60631000E+03, -.37368300E+03, -.20636100E+03, 0.22366800E+03, -.43143100E+03, -.15341200E+03, -.45378700E+02, 0.10348400E+04, -.25854200E+04, 0.12036200E+04, 0.12938100E+04, 0.12778500E+04, 0.44730100E+03, 0.40443300E+03, 0.80988000E+03, 0.25192500E+03, 0.60451400E+03, 0.55841400E+03, 0.42304500E+02, -.20506800E+04, 0.10335500E+04, 0.10029600E+04, 0.10288100E+04, 0.43266100E+03, 0.21370500E+03, 0.66898900E+03, 0.25802800E+03, 0.49007900E+03, 0.17435900E+03, 0.25420100E+03, -.60471100E+02, 0.12373300E+02, 0.82479500E+02, 0.46166300E+02, 0.24644400E+03, 0.15423500E+03, 0.17447300E+03, -.90326000E+02, -.27108900E+03, 0.22524300E+03, 0.38572500E+03, -.53485200E+03, 0.21760800E+03, 0.12809600E+03, 0.26560900E+03, -.20042400E+02, 0.50776300E+02, 0.56185000E+02, -.14328600E+03, 0.78413200E+02, 0.14172500E+02, -.16250000E+03, -.65922500E+03, 0.33159400E+03, 0.13577500E+03, 0.32950000E+03, 0.12042800E+03, 0.14429100E+02, 0.22382700E+03, -.33188800E+02, 0.16526400E+03, 0.15669900E+01, 0.38694000E+03, -.27791300E+03, 0.16920800E+03, -.67594400E+02, 0.14023200E+03, -.16862600E+02, -.59082300E+02, 0.11518400E+03, 0.19925700E+03, 0.13403000E+03, -.16485500E+03, -.14264100E+03, 0.57613900E+03, -.24649300E+03, -.27008000E+03, -.29525100E+03, 0.11337000E+02, -.13278500E+02, 0.21209800E-01, 0.21246700E+03, 0.29280400E+03, -.14571600E+03, -.49136800E+03, 0.54211600E+03, -.26230700E+03, -.10439300E+04, -.25800700E+03, -.13341000E+03, -.23822200E+03, 0.51610800E+03, 0.11236300E+03, 0.19755000E+03, -.48158900E+01, 0.32323000E+03, 0.79751800E+02, 0.98683400E+00, -.23352600E+01, 0.25293800E+00, 0.10070900E+02, 0.19962000E+02, 0.55974900E+02, 0.30616600E+01, 0.69243400E+01, -.65414900E+01, -.31940300E+02, 0.34954900E+02, 0.19959200E+02, -.22666900E+01, 0.52700800E+01, -.43621400E+01, 0.30268400E+02, 0.14103100E+02, -.15636300E+02, 0.17768900E+02, -.24615600E+02, -.17196100E+02, -.38211200E+03, 0.22644000E+02, 0.36152200E+02, -.30019400E+01 },
        { -.82706800E+01, -.62062800E+00, 0.11389800E+01, -.13865400E+00, 0.38486000E+01, 0.18984700E+01, 0.20413800E+00, 0.10876300E+02, -.13312300E+01, 0.15526200E+01, 0.23144600E+01, 0.88686200E+00, 0.19040500E+01, -.33815100E+00, 0.16858200E+01, -.32343900E+02, 0.13064700E+01, -.56256300E+01, -.49811000E+01, 0.56310000E+00, 0.63622100E+01, 0.12439100E+01, -.18623500E+00, 0.15861000E+01, 0.57967200E+00, -.11188800E-01, 0.28942700E+01, 0.27840200E+01, -.95528400E+01, -.76616700E+00, -.20968400E+00, 0.36661800E+00, 0.94660900E+00, -.10988300E+00, 0.90598100E-01, -.67488400E-01, -.86329200E+00, -.14242400E+01, 0.14213200E+00, -.24790400E+01, 0.22051100E+01, 0.75586500E+00, 0.28395800E+00, 0.12142800E+00, -.10138900E+01, 0.13505200E+01, -.15928400E+00, -.35232800E+00, -.13092300E+01, 0.44324600E+00, -.58746400E+00, -.15721800E+00, -.29621200E+00, 0.29563100E+01, 0.17312900E+00, 0.13517200E+01, 0.74674900E+00, 0.37662400E-01, -.33050100E+00, 0.63053200E+00, 0.22746000E+00, -.82621800E+00, -.16142900E-01, -.40807500E+00, -.48821600E+00, 0.54041400E+00, 0.15485000E+01, -.64340300E-01, -.15953900E+01, 0.46204900E-01, 0.14678000E+00, -.61474500E+01, -.13451700E+01, -.23091000E+01, 0.18872100E+01, -.18863700E+01, 0.16532700E+00, 0.79704900E+00, 0.12163000E+01, -.24918800E+00, -.34863700E+00, 0.18836100E+00, 0.23722700E+00, 0.16396000E+00, -.39394700E+00, -.20451100E+00, -.43890700E+00, -.26193700E+00, -.31514600E+00, 0.19199700E-01, -.62993900E+00, -.91416700E-02, 0.51776000E+00, 0.10350400E+00, -.91845500E-01, -.74403800E+00, -.24468200E+00, -.36921500E+00, -.19943600E+00, -.24991100E+00, 0.30183800E-01, -.34633000E+00, -.20734600E+00, 0.43986900E+00, 0.24498000E+00, 0.23503200E+01, -.17624500E+00, -.37759500E-01, -.34089200E-01, 0.12257400E+00, -.85285300E+00, -.29737200E-01, -.48892300E+00, -.15086500E+00, 0.53490400E+00, -.88499900E+00, -.88623500E-01, 0.38300200E+00, 0.21258500E+00, 0.11263400E+01, -.99558800E+00, 0.53770100E-01, 0.24124000E+00, 0.29671400E+00, -.19306400E+00, 0.54747800E+00, 0.74372000E-01, -.72774300E+00, -.70703300E+00, -.34907200E+00, 0.26367400E+00, 0.15850800E-01, -.22101400E-01, 0.14670700E+00, -.15471800E+00, -.12009800E+00, 0.42862600E-01, 0.99004300E-01, -.26361300E+00, -.10194100E+01, 0.66961000E+00, 0.27232300E+00, -.62943000E+00, 0.11820400E-01, 0.40374900E-01, 0.12013900E+01, -.27280000E-01, 0.19206200E-01, 0.17418100E-01, -.10348400E+01, -.19518400E+01, 0.11972900E+00, -.25529500E+00, -.60911600E-01, 0.79647500E-01, 0.11946700E+01, 0.42467900E+00, 0.42792100E-01, -.10604800E+01, 0.15546000E+00, -.12945900E+00, 0.49327800E-01, -.11590300E+00, -.51631000E-01, 0.62950300E+00, -.11965800E+00, 0.92751200E-01, 0.70348700E+00, -.73919300E+00, 0.23512300E+01, -.38422100E+00, -.38598100E+00, 0.50190500E+03, 0.57174800E+02, -.15926600E+02, -.17139200E+03, 0.10584500E+04, -.53910800E+03, -.38546700E+03, -.53858800E+03, 0.11267200E+03, 0.53213400E+03, -.32617400E+03, 0.19335400E+03, -.61504300E+03, 0.41398800E+03, 0.27954600E+03, -.18728900E+04, 0.93980700E+03, 0.81891200E+03, 0.10014800E+04, 0.53864900E+03, 0.62488100E+03, -.15394300E+03, -.30332800E+02, 0.22117400E+03, 0.55468500E+03, 0.19856900E+03, -.18360300E+04, 0.91807100E+03, 0.81476900E+03, 0.92428200E+03, 0.35603900E+03, 0.31100600E+03, 0.66752700E+02, -.11161000E+03, 0.47363500E+03, 0.11431600E+03, 0.30765700E+03, -.10784700E+04, 0.52845900E+03, 0.26010900E+03, 0.52348700E+03, 0.22481800E+03, 0.48359500E+03, -.29457400E+03, -.33321300E+03, 0.23224800E+03, 0.44157900E+03, 0.16089700E+04, -.22341500E+03, 0.10105900E+03, 0.13331800E+03, 0.11354200E+03, -.20953000E+02, -.23776300E+02, 0.38247300E+02, -.12852800E+03, -.23753800E+02, -.17780100E+02, -.32868700E+03, 0.37621700E+02, -.13765900E+02, -.22115800E+03, -.18630600E+02, 0.79219000E+02, 0.94068900E+01, 0.33975500E+02, 0.85990400E+02, 0.27490000E+02, -.21572800E+02, 0.89756900E+02, 0.13418100E+03, -.59816700E+02, 0.19428900E+03, -.72367300E+02, 0.26978200E+02, -.17364000E+03, 0.21214700E+03, 0.98884100E+02, -.20311100E+02, -.17890800E+03, -.72284500E+03, 0.26697700E+03, -.11871800E+03, -.11683700E+03, -.12835000E+03, -.18564000E+03, -.35515800E+03, -.14623600E+02, -.15699100E+03, 0.14306600E+03, -.26669200E+03, -.50758700E+03, -.60308500E+03, 0.30364600E+03, -.22528400E+03, 0.28447400E+03, 0.35245800E+02, -.17224700E+03, -.98239500E+02, -.52075900E+02, 0.19237100E+03, -.18860100E+03, 0.13184700E+04, -.55701400E+02, 0.23644900E+02, 0.19884100E+02, -.47411000E+01, -.36596000E+02, 0.37956600E+02, 0.41281800E+02, -.48058700E+02, -.78173100E+01, 0.13219800E+02, 0.13258200E+01, -.59055800E+02, 0.70195800E+01, 0.42805700E+02, -.47916400E+02, -.15094400E+02, -.15720700E+01, -.11404800E+03, 0.27146400E+02, 0.61951000E+02, 0.11969300E+02, 0.95937800E+01, -.25389200E+02, -.16666600E+02, -.25758500E+02, -.15965200E+02 },
        { -.61256600E+01, -.86693900E+00, -.43847000E+01, -.41467600E+01, 0.24544000E+01, 0.15761700E+01, -.15607300E+00, 0.10358500E+02, -.74076200E+00, 0.92337500E+00, 0.21462800E+01, 0.69776500E+00, 0.15810000E+01, -.16969700E+01, 0.39794600E-01, -.42710300E+01, -.31879800E+01, -.29486500E+01, -.25061600E+01, -.77841600E-01, 0.56730100E+01, 0.16695600E+01, -.83610100E+00, 0.21170000E+01, 0.12582700E+01, 0.94135900E-01, 0.31791500E+00, -.20602300E+00, -.28432700E+01, -.39209600E-01, 0.10210200E+01, -.72072300E+00, -.11131900E+01, 0.54344400E+01, -.97191000E-02, 0.72225300E+00, 0.16101800E-01, -.99522100E-02, 0.13614000E+00, 0.18503100E+00, -.17242800E+01, 0.26017500E+00, -.55021900E-01, 0.12512300E-01, -.29568000E+00, 0.93803300E+00, -.13950900E+00, 0.21607800E-01, 0.13894100E+01, 0.21954400E-01, 0.18036200E-01, -.27591800E+00, 0.29755700E+00, -.22992300E+01, 0.41824600E-01, 0.38518500E+00, 0.32240800E+00, -.14187100E+00, 0.32353400E-01, -.93619300E+00, -.28484000E+00, 0.20290800E+00, 0.13458600E+00, 0.16482000E+00, 0.54980500E+00, 0.11183200E+01, -.13124100E+01, -.15136800E+00, -.12445000E+01, -.34377900E-01, -.27929400E-01, -.48160000E+01, 0.59171200E-01, -.72724100E+00, 0.87915300E+00, 0.11748900E+01, -.17177100E+00, 0.68943300E+00, 0.70039900E+00, 0.13933800E+00, 0.30127400E-01, -.97128400E-01, -.28638300E-01, -.56932400E-01, 0.16703700E+00, 0.75355600E-01, 0.40505500E+00, 0.98247300E-01, 0.69753600E+00, -.13930200E-01, 0.12149900E+00, 0.22096500E-02, -.50287200E-01, 0.24619600E+00, 0.10575400E+01, 0.13144200E+01, 0.23007900E+00, -.32244200E+00, 0.23405700E+00, 0.21160900E+00, 0.32359000E-01, -.97621400E-02, 0.77887600E-02, 0.16848200E+00, -.20960100E+00, -.61627800E+01, -.34436300E+00, -.57932200E+00, -.29710200E+00, 0.49496100E+00, 0.45952600E-01, -.83209800E-02, 0.10783900E+01, -.26245000E-01, -.23034700E+00, -.23614700E+00, 0.47147500E+00, 0.29210000E+00, -.16077300E+01, 0.79694300E+00, -.66005500E+00, 0.38868600E-01, 0.45787100E-01, -.10965800E+00, 0.38429400E-01, -.75065400E+00, 0.46305200E+00, -.10640600E+01, -.38534600E+00, 0.45802900E-02, -.60517800E+00, -.56396400E+00, -.24715500E+00, -.25579800E-01, -.48292200E-01, -.49548000E-01, 0.15593200E+01, 0.31862900E+00, -.75487500E-01, -.31663300E+01, -.48793100E+00, -.59699100E+00, -.28293400E+00, -.15091000E+00, -.13827300E+00, 0.96019000E+00, 0.38965600E-01, -.71095500E+00, -.49139200E-01, 0.65996600E+00, 0.12621600E+01, 0.10895700E+01, 0.35347300E+00, 0.23573400E+01, -.38781100E+00, -.62945700E-01, 0.15578000E+00, -.14967800E-01, -.82157200E+00, -.31349600E+00, 0.54703100E-01, -.61680100E+00, -.38581300E-01, 0.58654100E-02, -.41433700E+00, -.13792500E+00, 0.12767400E-02, -.39274000E+01, 0.48657500E-01, -.21940000E+01, 0.28097000E+00, -.33770800E+00, -.68912500E+00, -.29737900E+03, 0.14381700E+03, 0.17517900E+03, 0.76444500E+02, -.52709700E+02, -.52891800E+02, -.55970000E+02, 0.45432400E+03, 0.32291400E+03, 0.10736100E+03, 0.38655100E+03, -.15001700E+03, 0.28440900E+03, -.26921800E+02, -.28235500E+04, 0.13683300E+04, 0.15867400E+04, 0.14578400E+04, 0.54216400E+03, 0.61173900E+03, 0.76856600E+02, -.65861500E+03, -.27762000E+02, 0.72112100E+03, 0.77608300E+03, -.17079000E+04, 0.83374600E+03, 0.99530500E+03, 0.85324000E+03, 0.39588900E+03, 0.30873900E+03, 0.19353100E+03, -.22563700E+03, 0.13775900E+03, 0.26031800E+03, 0.27660500E+03, -.20803000E+04, 0.10299300E+04, 0.93864200E+03, 0.10274900E+04, 0.60779300E+03, 0.37993100E+03, 0.33467100E+01, -.15216700E+03, 0.69618700E+03, 0.32855300E+03, 0.11387300E+04, 0.37674500E+03, -.19342600E+03, -.24814900E+03, -.18708900E+03, -.16460300E+03, -.29352000E+01, -.45847700E+02, 0.18538600E+02, -.17551900E+03, -.35086700E+02, -.53467200E+03, -.23505300E+03, 0.11293900E+03, 0.36697200E+03, 0.11763500E+03, 0.64890900E+02, -.57746100E+01, 0.18518500E+01, -.18276100E+02, 0.11439800E+03, -.63642600E+01, 0.33729700E+03, -.35178300E+03, 0.17564700E+03, 0.41050500E+02, 0.17404100E+03, -.35633500E+02, -.86602600E+02, 0.22653700E+03, -.69408200E+02, 0.10107700E+03, -.10785800E+03, -.30456500E+03, 0.43922400E+03, -.20705300E+03, -.33617200E+03, -.21385100E+03, -.50894300E+03, -.18814300E+03, -.22276700E+03, -.23234700E+03, -.19963300E+03, -.16293800E+03, -.95086200E+02, -.63230600E+03, 0.29076300E+03, -.84275800E+02, 0.30465100E+03, 0.19136400E+03, 0.62000600E+02, 0.45327400E+02, 0.14013900E+03, 0.39965000E+03, 0.19727500E+02, 0.19503000E+04, -.17610000E+02, 0.27028000E+02, -.57771100E+02, -.78496900E+02, -.68646100E+02, 0.78892100E+02, -.82185300E+01, -.21215600E+02, -.31244800E+02, 0.22382700E+02, 0.15206400E+02, -.66699100E+02, -.24364400E+02, 0.75243200E+02, -.18771300E+02, -.33767300E+02, 0.79556100E+02, -.12064200E+03, -.47172800E+02, 0.89970200E+02, 0.16274800E+02, 0.14293400E+02, -.10206800E+03, -.18475100E+02, -.24867700E+01, -.12499800E+02 },
        { -.11906800E+01, -.33587400E+00, 0.42006900E+00, 0.48484300E+00, -.56760500E-01, 0.58719600E+00, 0.17990400E+01, -.16805700E+01, -.96978100E-01, -.12063800E+01, 0.11581600E+00, 0.54809800E+00, 0.25780500E+00, -.46120000E-01, -.20720200E+00, 0.69555300E+00, 0.18906000E+01, 0.12604300E-01, 0.69837200E+00, 0.88179400E-01, 0.45338000E+00, 0.27885400E+00, -.13027000E+00, 0.10121600E+01, -.44108000E-01, -.20035600E-01, 0.68878100E+00, 0.34151000E-01, -.24924200E+00, 0.38773300E-02, 0.65016200E-02, 0.86100200E-01, -.76120900E-01, -.95272600E+00, -.67339400E-02, -.84175000E-01, 0.69476600E-02, 0.44014800E+00, -.43802900E-01, -.20796700E-01, 0.54247900E+00, 0.17553400E+00, -.15575000E-02, 0.83525500E-01, 0.94041700E-01, 0.29288600E+00, -.32761200E-01, 0.79894500E-02, 0.10437700E+01, -.27328700E-01, 0.56881800E+00, -.38195700E+00, 0.30069800E+00, -.38024200E+00, 0.11131200E+00, -.69043400E+00, -.27542600E+00, 0.37535800E-01, -.16353600E-02, -.28591700E+00, -.61993000E-01, -.41158600E-01, -.18801100E+00, 0.61868500E-01, -.23267200E+00, -.29155400E+00, 0.96914700E-01, -.12166000E+00, 0.10237500E+00, 0.21113400E-01, 0.13121200E+00, -.15530000E+01, -.72397100E-01, 0.13794900E+00, 0.16523000E+00, -.24181200E+00, 0.17302700E-01, 0.62476800E+00, 0.33322200E+00, -.16120600E-01, -.13764500E-01, 0.13354600E-01, 0.92830800E-01, 0.19654800E+00, 0.10391200E+00, -.16205200E+00, -.57178300E-01, -.38727700E-01, 0.80823100E-01, -.10091100E+00, 0.13051700E+00, -.45151400E-02, 0.97629900E-01, 0.62586900E-02, 0.68909400E-01, -.46742800E+00, -.16505300E+00, -.12695900E+00, -.75475700E-01, -.90122000E-01, -.57836500E-01, -.57649300E-01, -.21634700E-01, 0.10531200E+00, 0.14765300E-01, -.55937500E+00, 0.18647900E+00, -.19225700E+00, 0.10321600E+00, 0.12273900E+00, -.32044200E+00, 0.58076800E-01, 0.43370900E+00, -.12234500E-01, -.21724100E+00, -.17788400E+00, -.20495600E+00, 0.13699300E+00, 0.69361300E+00, -.43896700E+00, -.18402500E+00, 0.30398600E-01, -.14028000E+00, 0.16809000E+00, -.97575100E-02, 0.37692100E-01, -.65766000E-02, -.55504700E+00, 0.20308500E+00, 0.78706000E-01, 0.13942500E+00, -.21554900E-01, 0.29203400E+00, 0.83018600E-01, 0.10589000E+00, 0.11909600E-01, -.17823400E+00, -.13318500E+00, 0.68314200E-01, -.15705700E+00, 0.17830400E+00, 0.19393900E+00, -.78444400E-02, -.15207400E+00, 0.16090200E-02, -.83794900E-01, -.26146300E-01, 0.13297100E+00, 0.45516100E-02, -.10911000E+00, -.27907300E-01, 0.13848300E+00, 0.46822600E-01, 0.29782700E+00, -.42486600E-01, 0.34913100E+00, 0.51854000E-01, 0.15020200E-02, -.16449100E+00, 0.14067700E+00, 0.72786600E-03, -.10466500E+00, -.50456500E-01, 0.58573200E-01, 0.21228200E+00, 0.11876300E+00, 0.92158900E-01, 0.91173300E-02, -.58375100E-02, 0.29171400E+00, 0.90845600E-01, -.24098200E-01, 0.12754900E+00, -.97269700E-03, -.43600400E+02, 0.62640600E+02, 0.22052800E+03, -.10775000E+03, -.27119000E+02, -.11969100E+03, 0.63746100E+02, 0.68165700E+02, -.31193100E+02, 0.12980200E+03, 0.34812700E+01, 0.41146400E+02, -.14730200E+03, 0.35841700E+03, -.16182500E+03, -.16931000E+03, -.18398600E+03, -.47311200E+01, 0.27774400E+02, -.14633400E+03, -.33289100E+02, -.94714600E+02, -.14686500E+02, -.71294000E+02, 0.22599900E+03, -.11150400E+03, -.86769800E+02, -.11427800E+03, -.63970100E+02, -.25121600E+02, -.73473400E+02, -.31562200E+02, -.84077800E+02, -.18250500E+02, -.52593400E+02, 0.30615100E+03, -.15198600E+03, -.20682200E+03, -.15829700E+03, -.23397200E+01, -.49217800E+02, -.67633300E+02, 0.43424800E+02, 0.24072300E+02, -.64580900E+02, -.20741500E+03, 0.45978700E+02, -.22445900E+02, 0.35798800E+02, -.22564900E+02, 0.13567100E+01, 0.69095400E+01, -.73002800E+01, 0.85705900E+01, -.70812500E+01, 0.66878900E+01, 0.16259200E+02, 0.12006000E+03, -.60140200E+02, -.71767600E+02, -.59995300E+02, -.36472200E+02, -.21552700E+01, -.39700800E+02, 0.26004200E+02, -.94917400E+01, 0.35117000E+01, -.56385100E+02, 0.97788600E+02, -.47807100E+02, 0.65037700E+02, -.49269500E+02, -.32585600E+02, 0.44514800E+01, -.31096600E+02, -.54316000E+01, -.58434700E+02, 0.30728300E+02, -.19758000E+02, -.82934900E+02, 0.38832600E+02, 0.93038400E+02, 0.43686600E+02, -.33053500E+02, -.20592400E+02, 0.27614500E+01, -.88961900E+02, -.68161500E+02, 0.25379400E+01, 0.24871400E+02, -.11756600E+03, 0.63502700E+02, 0.15969800E+03, 0.54636400E+02, 0.85626100E+02, 0.64661400E+02, -.10433800E+03, -.36482500E+02, 0.12350200E+02, 0.10091000E+02, -.84854700E+01, -.15450500E+02, 0.85929300E+01, 0.13069600E+02, 0.82246500E+01, -.65736800E+01, -.11649700E+01, -.95133700E+01, -.73569400E+01, -.75310300E+01, 0.43332600E+01, 0.11320200E+02, -.50751200E+01, -.91258700E+01, 0.53617200E+01, -.74777800E+01, -.23488700E+01, -.14321000E+02, -.27606100E+02, 0.11997900E+02, -.62110200E+00, -.14480800E+02, 0.32978400E+01, 0.69381500E+02, -.14102100E+02, -.19769800E+02, -.52331500E-01 },
        { -.67286900E+01, -.13184000E+01, 0.19643800E+01, 0.22312900E+01, 0.19523600E+01, 0.11062400E+01, 0.10170800E+01, -.52385500E+01, -.10597700E+01, -.17721000E+01, -.15790000E+01, -.25494600E+00, 0.22646500E+00, -.37891800E+00, 0.14094000E+00, -.11093000E+02, -.54045800E+01, -.36614500E+01, -.29784200E+01, 0.54321000E+00, 0.56253100E+01, 0.19151500E+01, -.72941300E+00, -.26733200E+01, -.30958500E+00, -.20199100E-01, 0.32744900E+00, -.62370300E+01, -.55572000E+00, 0.16096200E+00, -.12676600E+01, -.21564700E+01, 0.75688100E+00, 0.14387700E+01, -.85259300E-01, -.45297100E+00, 0.17031700E+00, 0.23152100E+01, 0.45202000E+00, -.90159600E+00, 0.84227100E+00, 0.13513800E+01, -.23633200E+00, -.25289000E+00, -.11385600E+01, 0.43967400E+00, -.83717900E-01, 0.96572900E-02, 0.53473600E+00, -.52308800E+00, -.24414100E+00, -.26587200E+00, 0.24197400E+00, 0.18394100E+01, 0.73835400E+00, -.85930400E+00, -.37501600E-01, 0.22833100E+00, -.27129600E-01, -.61321400E+00, -.25402000E-01, -.79909600E-01, -.93726300E+00, 0.23215500E+00, -.16962400E+01, -.13301100E+01, 0.39666200E+00, -.36206200E+00, -.11439000E+01, 0.54487300E-01, 0.49882400E+00, -.74523100E+01, -.16654900E+01, -.30887900E+01, 0.22560900E+01, -.15734200E+01, 0.30313400E+00, 0.14534200E+01, 0.15292300E+01, -.34655600E+00, -.13764700E+00, 0.69090100E-01, 0.10771500E+01, 0.13869200E+01, -.21915700E+00, -.82431300E+00, 0.69861600E+00, -.48805100E+00, -.13746700E+00, -.28080400E+00, 0.15656300E+01, -.10324700E-01, -.98935800E-01, -.45106900E-01, 0.70388600E+00, -.56311400E+00, -.14350000E+01, -.10302700E+01, 0.19934000E+00, 0.15861200E-01, -.15586300E+00, 0.60154200E-01, 0.13866800E-01, 0.72455100E+00, -.10003900E+01, -.14358300E+01, 0.14677700E+01, -.19372600E+01, 0.24423200E+00, -.17667700E-01, -.14037700E+01, 0.40991700E-01, 0.10337900E+00, -.32875600E-01, -.88990300E+00, -.22243600E+01, -.31812800E+00, 0.87013700E+00, 0.87448200E+00, 0.24585900E+01, -.51473300E+00, 0.11537500E+00, 0.30188100E+00, 0.33106500E+00, 0.40439500E-01, -.34508800E+00, -.91585100E-01, -.51242700E+01, -.24629600E+00, 0.64038500E+00, 0.13341400E+01, 0.18103400E+00, 0.52378000E+00, -.36050800E+00, 0.46520100E+00, 0.42733500E-01, 0.54116900E-01, -.58196100E+00, 0.21697300E+00, -.30876400E+01, 0.42668200E+00, 0.10173100E+01, -.16795100E+01, -.56456600E+00, 0.12241400E+00, 0.10481600E+01, 0.46459200E-01, 0.34032000E+00, 0.69486400E-02, -.13120800E+01, -.29974800E+01, -.55978600E+00, -.31172100E+00, 0.12715400E+01, -.85264300E-01, 0.53821500E+00, 0.19625500E+00, -.14665300E-01, -.56868900E+00, 0.79633600E+00, -.84700200E-01, -.44926800E+00, -.29863900E+00, -.61578500E+00, -.24705400E-01, 0.15256500E+00, 0.91331400E-01, 0.24418000E+01, 0.22971500E-01, 0.48325700E+00, 0.69069400E+00, -.39558900E+00, 0.77807700E+00, -.27327900E+00, 0.18980400E+01, 0.37433000E+03, -.13230100E+03, 0.60296500E+02, 0.12480200E+03, 0.58570700E+02, 0.20621500E+02, -.13400800E+03, 0.12942800E+03, -.48214200E+02, 0.15785200E+03, -.11325100E+03, -.12277300E+02, -.74832300E+03, 0.33053900E+03, 0.37490100E+03, 0.34139800E+03, 0.12436000E+03, 0.16226900E+03, 0.15328700E+02, -.22509800E+03, 0.13368900E+03, 0.15232300E+03, 0.43302900E+03, 0.64093000E+02, -.36318700E+02, 0.86859200E+02, -.39015400E+02, 0.17265200E+02, 0.69328100E+02, -.50559700E+02, -.93033700E+02, -.54753400E+02, 0.80004100E+02, -.18974900E+02, 0.39374000E+03, -.20019600E+03, -.17870900E+03, -.19145400E+03, 0.18036400E+02, -.55227400E+02, 0.41846000E+01, 0.17573700E+03, -.17555700E+02, -.38041500E+02, -.46606300E+03, 0.14687100E+02, -.82743900E+01, -.73935600E+02, -.76750400E+01, -.40810400E+02, -.70889500E+01, 0.94264100E+01, -.53884200E+02, -.51871100E+02, -.12256100E+02, -.57635400E+02, -.23694800E+03, 0.11617300E+03, 0.17660000E+03, 0.11838200E+03, 0.36694400E+02, 0.51907500E+02, -.25255200E+02, -.67382200E+02, 0.67471200E+02, 0.53009400E+02, 0.15903700E+03, 0.17794100E+02, -.84750200E+01, -.68840800E+02, -.50858500E+01, -.14587600E+02, 0.46589300E+02, -.57065600E+02, -.10064800E+03, 0.81164400E+00, 0.40702700E+02, 0.14390700E+03, -.23459600E+03, 0.12271100E+03, 0.36419400E+02, 0.11690700E+03, -.37140400E+02, 0.79873100E+02, -.49010800E+01, 0.13367800E+03, 0.62370800E+02, 0.40580200E+02, 0.19746100E+03, -.28626600E+03, 0.13825800E+03, 0.23906800E+03, 0.15083600E+03, 0.19500500E+03, 0.47469600E+02, -.38099100E+01, 0.92620600E+02, 0.53743400E+02, 0.34309800E+02, 0.19728000E+03, -.28407200E+02, -.12754400E+01, 0.37655000E+02, 0.27531200E+02, -.77165300E+01, -.14042900E+01, -.13502600E+02, 0.35132500E+01, -.89107100E+01, 0.17101400E+01, 0.53920800E+01, -.70028400E+01, -.12284900E+02, 0.69000400E+01, 0.40319000E+01, 0.12050400E+01, -.33822500E+02, 0.27227500E+02, 0.51227800E+02, 0.32304200E+01, -.14745600E+02, -.58082300E+01, 0.64947700E+02, -.78501600E+00, 0.17484900E+02, 0.19412900E+01 },
        { 0.48496400E+01, 0.17581600E+01, -.30630000E+00, -.15626700E+01, -.18681000E+01, -.14851600E+01, -.81075500E+00, -.37650500E+01, 0.95011400E-02, -.64256200E+00, -.84327800E+00, -.61617000E+00, 0.27661500E+00, 0.28918600E+00, 0.92533000E-01, -.39030100E+01, 0.59025200E+01, 0.40108700E+01, -.29162100E+01, -.82951900E+00, -.19057400E+00, 0.96814300E-01, -.31444000E+00, -.24069500E+01, 0.10343000E+00, -.45704800E-01, -.93579300E+00, -.31634800E+01, 0.15790600E+01, -.27286900E-02, 0.84916600E+00, -.15096700E+01, -.53405500E+00, 0.41672000E+01, 0.68116700E-03, 0.75915700E-01, 0.73675100E-01, 0.63525500E+00, 0.27917400E+00, 0.11720700E+00, 0.36472400E+00, 0.78335100E+00, -.73973600E-01, -.15812600E-01, 0.39588600E+00, 0.72158000E-01, -.31781800E-01, 0.55951000E-01, 0.16002500E+01, -.12315500E+00, 0.46509100E+00, -.10499800E+01, 0.65126600E+00, -.21914300E+01, -.10453900E+00, -.12527400E+01, -.72136800E+00, 0.55672000E-01, 0.76624700E-01, -.33492400E+00, -.16460400E+00, 0.10940200E+01, -.36256000E+00, 0.11463300E+00, -.10612900E+00, 0.26233600E+00, -.54836400E+00, -.19521900E+00, -.63474100E+00, 0.23596500E-02, 0.62436200E-01, -.35129200E+01, 0.54535400E-01, 0.57072900E+00, 0.88120300E+00, 0.55320100E+00, -.14898600E+00, 0.10440100E+01, 0.23395800E+00, -.40584800E-01, -.51764500E-01, 0.36909600E-01, 0.16955200E+00, -.38161000E+00, 0.68135900E-02, 0.22340300E+00, 0.11689800E-01, -.77220100E-01, -.14144500E-01, -.57726100E-01, -.40140400E-02, -.12822300E-02, -.95404400E-01, 0.18352200E+00, -.40877500E+00, 0.90896900E-01, 0.24007400E-01, 0.47716300E+00, 0.56235800E-01, 0.14238300E+00, -.13188900E-01, 0.33932900E-01, -.87498700E-02, 0.51021400E-01, -.18019000E-01, -.11434800E+01, -.12093300E+00, -.19980000E+00, 0.91342600E-02, 0.48250900E+00, -.23266000E-01, 0.80645700E-02, 0.64212200E-01, 0.19219000E-02, 0.32990200E+00, 0.17280300E+00, 0.52016100E-01, -.76727800E-01, 0.85237500E-02, 0.60771800E+00, 0.13420500E+00, -.19182700E-01, -.11844900E-01, -.14845300E+00, -.63735800E-02, -.36714200E+00, 0.12948500E+00, -.20572300E+00, -.28671200E+00, 0.29186100E-01, -.29235800E-01, -.14730000E+00, -.66376000E-01, 0.23143200E+00, -.28610300E-01, -.22010600E-01, 0.49156000E+00, 0.21561800E+00, -.11951300E-01, -.11837400E+01, -.41973300E+00, -.10271800E+00, 0.10156300E+01, -.48850000E+00, -.10123900E+00, -.20527500E+00, 0.68782500E-02, -.40891100E+00, 0.91820700E-02, 0.78584600E+00, 0.36245500E+01, 0.66880800E+00, 0.48680200E+00, 0.43282600E+00, -.16004800E+00, 0.11318700E+00, 0.25777000E+00, 0.32614400E-03, -.13847700E+01, -.95081200E+00, -.91874600E-01, -.44204200E+00, 0.33112200E+00, 0.11960300E+00, -.42367600E+00, 0.49972800E-01, -.46454800E-01, 0.86358400E+00, -.14601100E-01, -.14102500E+01, 0.31781400E+00, -.10498400E+00, 0.41134800E-02, -.90622900E-01, -.11901100E+01, 0.72873500E-01, -.80054400E+03, 0.39861600E+03, 0.22443100E+03, 0.40447000E+03, -.11044100E+03, -.17857300E+03, 0.12418700E+03, -.74367300E+02, 0.35344000E+03, -.14602100E+03, 0.15886800E+03, 0.30357400E+03, -.14495300E+03, 0.60841500E+02, -.15434200E+03, -.29830700E+02, -.39099700E+02, -.23411500E+02, 0.29534900E+02, -.13281900E+03, -.39745500E+02, -.16070900E+03, 0.25112300E+03, -.12861200E+03, 0.68904100E+02, -.12537000E+03, -.13407800E+02, -.50782900E+02, 0.87781600E+02, 0.29941500E+02, -.14196200E+03, -.66019100E+01, -.18501100E+03, 0.18616200E+03, -.92509900E+02, 0.56262500E+02, -.90690000E+02, 0.45305500E+02, -.34611100E+02, 0.36284800E+01, -.72639700E+02, -.15661400E+03, -.14115400E+02, -.34377800E+03, -.12074100E+03, 0.49803000E+02, 0.23694000E+03, 0.59572100E+02, 0.12945900E+02, 0.38257500E+02, -.20516800E+02, -.10916100E+02, 0.30519500E+02, 0.24450700E+02, 0.15874600E+03, 0.23465400E+03, -.11733300E+03, 0.10060100E+03, -.11734700E+03, -.79684800E+02, -.54962700E+02, 0.34586300E+01, 0.45360200E+02, -.80272100E+02, -.45006400E+02, -.94904700E+02, -.76161300E+02, 0.44776600E+02, -.30661500E+02, 0.38411200E+02, -.50704600E+02, -.41488800E+01, -.11529000E+02, 0.33219100E+02, 0.35869800E+02, 0.45624800E+00, 0.23211800E+03, 0.32873500E+03, -.15930300E+03, 0.25169800E+02, -.16539700E+03, 0.12268200E+02, 0.34571700E+02, 0.68748100E+02, 0.12169500E+03, -.17483700E+03, 0.95358800E+01, 0.57428400E+02, 0.35826200E+03, -.16608600E+03, 0.25915800E+03, -.17701000E+03, -.53269900E+02, 0.47513000E+02, 0.46336300E+02, -.12224000E+02, -.15558700E+03, 0.61536400E+02, -.25206200E+03, 0.31038300E+02, 0.48759600E+01, -.51750900E+02, -.46295700E+02, 0.77766900E+01, 0.24306400E+01, -.92661400E+01, 0.23338700E+00, -.50126200E+01, 0.60712900E+01, 0.10563600E+02, 0.22804200E+02, -.19460200E+01, -.91249600E+01, 0.14561000E-01, -.20346500E+02, 0.45252400E+02, 0.16176800E+02, -.56670200E+02, -.17739200E+01, -.12345600E+02, 0.19367800E+02, -.39519400E+02, -.13364200E+02, -.14007000E+01, -.36297500E+01 },
        { 0.72881400E+01, -.35946800E+01, 0.68348600E+00, 0.30564900E+01, 0.63799500E+00, 0.18203400E+01, 0.18970000E+01, 0.15966800E+01, 0.20448400E+01, 0.19082500E+00, -.55348300E+00, -.51249700E+00, -.22424300E+01, 0.30981300E+00, 0.45022000E+00, 0.23241300E+01, -.67599700E+01, -.57606200E-01, -.23297600E+01, -.17349900E+00, 0.53364900E+00, 0.98771900E+00, 0.43330800E+00, -.23924900E+01, 0.84716500E+00, -.17695100E+00, -.17250000E+01, -.36062000E+01, 0.51133800E+01, -.90955100E-01, -.11755500E+01, -.14140300E-01, 0.13258000E+01, 0.32709700E+01, -.34520300E+00, -.15931800E+00, -.13523600E-01, -.29535800E+01, -.58894200E+00, 0.29913600E+00, -.38404600E+01, 0.54650000E+00, 0.78125500E-01, -.24822200E-01, 0.40368600E+00, -.81727400E+00, 0.37874900E-01, 0.79424500E-01, 0.11995100E+00, -.13276200E+00, -.11658600E+00, 0.16033600E+01, -.12271100E+01, 0.14657000E+01, -.36535900E+00, 0.25256800E+00, 0.25749800E-02, -.15077500E+00, 0.63300200E-01, 0.11350000E+01, -.20130700E+00, -.39506900E+00, 0.89891200E-01, 0.72116400E+00, 0.25012200E+01, 0.12986500E+01, 0.37131100E+00, 0.28491100E-01, 0.10430400E+01, 0.27795700E-02, -.18478000E+00, 0.43025700E+01, 0.68582700E+00, -.21467400E+01, -.89165700E+00, 0.20915000E+01, 0.70050900E-01, -.31070800E+01, 0.16828900E+01, 0.55969800E+00, 0.56046800E-01, -.36332300E+00, -.49339900E+00, -.12328300E+01, -.15348200E+00, 0.39395300E+00, -.63696000E-01, -.28743200E-01, 0.35624800E+00, -.31456000E+00, -.19589900E+00, 0.58633200E-03, -.65590600E-02, 0.11309500E+00, -.62597100E+00, -.12016400E+00, -.50926900E+00, -.26809900E+00, -.19505200E-01, 0.21394200E+00, -.15651800E+00, -.39959600E+00, -.50161400E-01, 0.21755300E+00, 0.18278100E-01, 0.18646900E+01, 0.27766000E+00, -.23601200E+00, 0.30184400E-01, 0.30706500E+00, 0.37861000E-02, 0.28801800E+00, 0.12934200E+01, -.63770100E-01, -.23519900E+00, -.55486200E+00, 0.31146500E+00, -.19475900E+00, -.12302500E+01, 0.49068100E+00, -.58432100E+00, 0.24557100E+00, -.46403800E+00, -.35290300E+00, 0.19067200E+00, -.53763200E+00, -.34707800E+00, 0.71121800E+00, -.39827400E+00, 0.63004900E-02, -.41180100E+00, 0.30876800E+00, -.29483100E+00, -.80697700E+00, -.10877200E+00, 0.46491600E-01, 0.70815500E+00, -.55331300E-01, 0.57631100E-01, -.20205300E+00, -.12593400E+01, -.42856900E+00, -.19546000E+00, -.45963400E+00, 0.11832900E+00, -.13881000E+00, -.18458300E+00, 0.57630000E+00, -.23487300E+00, 0.24699800E+00, 0.60863600E+00, 0.98910800E-01, 0.38741500E+00, 0.26757600E+00, -.82993200E-01, 0.11906200E+00, -.74109300E-01, -.49985700E-02, -.19406100E+00, -.34403800E+00, 0.92809700E-01, -.22644000E+00, 0.11909500E+00, -.82781500E-01, -.47663100E+00, -.23784100E+00, -.11622800E+00, -.53881400E+00, 0.16858900E-01, -.41296400E+00, 0.18117000E+00, -.29567300E-01, -.98450700E-01, 0.90229400E-01, -.19391000E+00, -.69829200E-01, 0.37068700E+00, 0.74834300E+02, 0.29645100E+02, -.10357700E+02, -.36610900E+02, 0.17041000E+02, -.18455500E+02, -.84189300E+02, -.79033500E+02, 0.23882200E+02, 0.14415100E+02, -.64592200E+02, 0.27614200E+02, -.28486900E+02, 0.29256800E+02, 0.98878700E+01, 0.91883100E+00, 0.18837100E+02, 0.54143600E+01, 0.25436100E+02, 0.68221700E+00, 0.76559900E+01, -.90530600E+02, 0.72972800E+02, -.11837800E+02, 0.41433500E+02, -.23596000E+01, -.13346900E+01, 0.19343500E+02, -.45596100E+01, 0.28251000E+01, -.85069700E+01, 0.42523400E+02, -.34577800E+01, 0.10317500E+02, -.68823000E+00, -.16237600E+01, 0.18797700E+02, 0.34967700E+02, -.99093000E+00, 0.61238500E+02, 0.67864900E+02, 0.99508700E+01, 0.21062000E+02, -.90558800E+02, 0.39869600E+02, -.28105700E+02, 0.45318700E+02, 0.13754300E+02, 0.30210100E+00, 0.25634000E+02, -.22913300E+02, 0.24627000E+02, 0.20472600E+01, 0.88838600E+01, -.12429300E+03, 0.60624100E+02, -.11179700E+02, 0.62151800E+02, 0.36246600E+02, 0.16574500E+02, 0.28180900E+02, -.34709400E+01, 0.44194200E+02, 0.78867000E+01, 0.29891600E+02, 0.39672600E+02, -.16722600E+02, 0.89808500E+01, -.18818100E+02, -.10954000E+02, -.20298500E+02, 0.15749000E+02, 0.70528800E+01, -.41678300E+02, -.15478400E+02, -.47854900E+02, -.11686100E+03, 0.39849300E+02, -.97489900E+02, 0.60881900E+02, 0.34037000E+02, 0.29392000E+01, 0.20513600E+02, 0.29648100E+01, 0.83423900E+02, 0.34397000E+01, 0.35608300E+02, 0.96287600E+01, 0.19038900E+01, -.12260200E+03, -.64182100E+01, -.11027800E+02, -.41047300E+02, 0.63160400E+01, 0.19229700E+02, 0.49702900E+02, -.47302900E+02, 0.19507800E+02, 0.11374700E+01, -.27758400E+01, 0.87765900E+01, 0.91851000E+01, 0.34026500E+00, -.82249500E+00, 0.10941500E+02, 0.20647700E+01, 0.41393000E+01, -.34405000E+01, -.87019600E+01, 0.24180300E-02, 0.34919900E+01, -.78659400E+00, 0.21456500E+01, 0.70952100E+01, -.89002700E+01, 0.16300200E+02, 0.87295300E+01, -.27351300E+01, -.92630200E+01, -.81121400E+01, -.31664000E+02, 0.51909500E+01, 0.48697600E+01, -.18226400E+01 },
        { 0.64589400E+01, 0.22383400E+01, 0.26272600E+01, -.29601900E+00, -.15711800E+01, -.20561100E+01, -.28603800E+01, 0.37070400E+01, 0.36548000E+00, 0.11709400E+01, -.84241400E+00, -.11409700E+01, -.14774900E+01, 0.91569700E+00, 0.10140900E+01, -.87129200E+01, -.13815600E+01, -.10323900E+01, -.20703800E+01, 0.44887000E+00, 0.69720700E+00, 0.23727700E-01, -.97660500E-01, -.13893300E+01, 0.39911400E+00, 0.55032500E-01, -.66353900E+00, -.21808400E+01, 0.97643600E+00, -.22028100E-01, 0.63393400E+00, -.13321600E+01, -.29481600E+00, 0.45808300E+01, -.26648400E-01, 0.21888800E+00, -.18926800E-01, -.67985900E+00, 0.19960200E+00, 0.57697600E+00, -.31534600E+01, 0.16644100E-01, -.53852400E-01, -.98610200E-01, 0.66774900E+00, -.20889500E+00, -.60590900E-01, 0.61218500E-01, 0.22428500E+01, -.28360100E+00, 0.65909800E+00, -.13214100E+01, 0.32599100E+00, -.31526500E+01, -.65305100E+00, -.23271000E+01, -.12252400E+01, -.10880500E+00, 0.74088600E-01, 0.54053500E+00, -.28027300E+00, 0.85482100E+00, -.27887000E+00, 0.71580700E+00, 0.10985700E+01, 0.62257900E+00, -.12918200E+01, -.39368700E+00, -.11983400E+00, 0.19624200E-01, -.77846100E-01, -.18350900E+01, -.24632500E+00, 0.34996900E+00, -.10600600E+00, 0.68032200E+00, 0.19050900E+00, -.29853000E-01, 0.51859100E+00, 0.32474400E+00, -.82561700E-01, 0.76607900E-01, -.19447200E+00, -.15391600E+01, 0.57835700E-01, 0.40398600E+00, -.74773100E-01, -.13902700E+00, 0.12257400E+01, -.93671100E-01, 0.11238200E+00, 0.10436200E-02, 0.53438500E+00, -.46257100E-01, -.15470600E+01, -.51944200E+00, -.31341000E+00, 0.61208700E-02, -.11078400E+00, 0.18120700E+00, -.13372800E+00, -.77632400E-01, -.51078600E-01, 0.25525900E+00, -.32657100E-01, -.55530100E+00, 0.39767800E+00, 0.17143500E+00, -.14276700E+00, -.23469800E+00, 0.27625100E+00, 0.71227500E-02, -.10603100E+00, -.45403400E-01, -.12008600E+00, -.15204900E+00, 0.18693500E+00, 0.30026900E+00, -.62360800E+00, 0.22634400E+01, -.21763500E+00, 0.19095000E+00, 0.27387900E+00, -.58482700E+00, 0.18921600E+00, -.89246900E+00, 0.26806200E+00, 0.10981600E+01, -.10900700E+01, 0.26185100E-01, -.17038800E+01, 0.31377400E+00, 0.21014600E+00, -.31313600E-01, -.26097200E+00, 0.12284100E-02, 0.62046100E+00, -.39282900E+00, -.17824200E-01, 0.10777900E+01, 0.73844500E+00, 0.36140300E+00, 0.58466200E+00, -.89438700E+00, 0.33036800E-01, 0.12194100E+00, -.82560600E-01, -.15885200E+00, 0.95938500E-01, -.48900400E+00, 0.15063800E+01, -.89267500E+00, 0.33080800E+00, -.12806900E+01, 0.22473300E+00, 0.11967400E+01, 0.89818300E-01, 0.73599800E-02, -.45453300E+00, -.22547700E+00, 0.13837900E+00, -.15261600E-01, -.22875900E-01, -.37272200E+00, -.10541900E+01, 0.14507100E+00, 0.58537600E-01, -.13273100E+01, -.96548400E-02, 0.87343400E-01, 0.27796700E+00, -.11371400E+00, -.19343300E+00, 0.20917500E+00, 0.11381300E+01, -.31434200E-01, 0.68412700E-01, -.61023200E-01, 0.18761200E+03, -.62413400E-01, -.53130600E+02, 0.18825500E+02, -.59883200E+02, -.17952600E+03, -.16666300E+03, 0.35169900E+02, 0.10961000E+03, -.45428300E+03, 0.22094200E+03, 0.36594800E+02, 0.23773100E+03, 0.45101800E+02, 0.11729700E+02, 0.88530300E+02, -.36426600E+02, 0.11060200E+03, 0.24896100E+02, 0.95300600E+02, -.38766900E+03, 0.19131700E+03, 0.27710200E+02, 0.19500000E+03, 0.52263900E+02, 0.78888300E+02, 0.42708200E+01, -.26991200E+02, 0.44098400E+02, 0.62282600E+02, 0.13801600E+03, -.23189200E+03, 0.11457500E+03, 0.14103500E+03, 0.11260600E+03, 0.12657600E+03, 0.20581000E+03, -.11761500E+03, -.13652900E+02, 0.13858600E+03, 0.12833400E+03, 0.40099000E+03, 0.37176200E+02, -.23017200E+02, -.33507000E+03, -.18491900E+02, 0.22243000E+02, -.15030900E+02, 0.14768700E+02, 0.31982300E+02, 0.24773400E+02, -.78334100E+01, -.12510700E+03, -.20466300E+02, 0.11286400E+02, -.11661400E+03, 0.10270400E+02, 0.48374900E+02, -.24317500E+00, 0.26873700E+02, 0.28887200E+02, 0.12313700E+02, -.15290800E+02, 0.10653800E+03, -.17021600E+02, 0.96672100E+01, -.44991300E+02, 0.74485100E+01, 0.23690300E+01, -.40038800E+02, 0.37404900E+02, -.19587700E+02, -.63227800E+02, -.38146800E+02, -.17224900E+03, -.17284900E+03, 0.91417400E+02, -.34745500E+03, 0.87521700E+02, 0.24912300E+02, -.30530700E+02, 0.63741600E+02, 0.46392300E+02, 0.13594600E+03, -.12249900E+02, 0.46034300E+01, -.28403000E+03, 0.14327500E+03, -.19116700E+03, 0.13845800E+03, 0.67990600E+02, -.57474400E+02, 0.77879300E+01, 0.63616300E+02, 0.15907500E+03, -.57210900E+02, 0.42476100E+03, -.18802700E+02, 0.47934500E+01, 0.21311700E+01, 0.30734500E+01, -.23003400E+02, 0.13653100E+02, 0.19758500E+02, -.79087200E+01, -.37436800E+01, 0.67888600E+01, -.60785800E+01, -.21506600E+02, 0.22495500E+01, 0.22854800E+02, -.76586100E+01, -.23538800E+01, -.20471300E+01, 0.44761100E+02, 0.33990100E+01, 0.15097200E+02, -.17813700E+02, 0.12527200E+01, -.53614700E+02, 0.13560200E+01, 0.14048300E+02, -.55508000E+01 },
        { -.10424600E+02, -.35413000E+01, 0.20979200E+01, 0.12823700E+01, 0.71884600E+01, 0.52795900E+01, 0.16287500E+01, 0.24978200E+02, -.12997200E+01, 0.54877600E+01, 0.42394300E+01, -.16426700E-03, 0.14304200E+01, -.63796100E+00, -.19790100E+01, 0.23286000E+00, -.10105100E+01, -.11435100E+01, 0.21532100E+01, 0.21111000E+01, 0.15173900E+01, -.26713500E+00, -.87018900E-01, 0.93236600E+00, -.63043600E+00, -.10949100E+01, 0.20896300E+00, -.12229900E+00, -.11828900E+01, 0.20927900E+00, 0.61360300E-02, -.90753800E+00, 0.59348600E+00, 0.54801200E+01, 0.24262700E-01, 0.12382300E+00, -.12351900E+00, -.70820000E+00, 0.12938500E+00, -.10572600E+01, 0.28361300E+01, 0.13151500E+01, 0.23674600E-01, 0.23314400E+00, -.69800500E+00, -.10077100E+00, -.66674900E-01, -.14917100E+00, -.14027000E+01, 0.74571300E-01, -.44272500E+00, 0.15260900E+00, 0.60996300E+00, 0.11396300E+01, -.16873100E+00, 0.10446400E+01, 0.36246900E+00, -.24180900E+00, -.15281600E+00, -.30786400E+00, 0.92121100E-01, -.16790400E+01, 0.22054100E+00, 0.17310700E-02, 0.62663400E+00, 0.22773500E+00, 0.67545200E+00, 0.18358400E+00, 0.95782100E-01, 0.14234400E-01, -.98231800E-01, 0.48248300E+01, -.20469800E+00, -.25485200E+01, -.11133300E+01, -.12027700E+01, 0.28711700E+00, -.14376600E+01, 0.42786800E-01, 0.32142300E-01, -.82845800E-01, 0.81860200E-01, -.91140100E-01, -.61738600E+00, -.43856000E+00, 0.31457700E+00, -.47710500E+00, -.14536300E-01, -.64522900E+00, 0.29992900E-01, -.96435000E+00, 0.15793200E-02, 0.87701200E+00, -.10886600E+00, -.72439800E+00, -.97287500E+00, 0.41338600E+00, 0.10332900E+00, -.46959200E+00, 0.11343600E+00, -.62486500E-01, -.30571500E+00, -.45786500E-01, 0.40116500E+00, 0.49771900E+00, 0.50709300E+01, -.35211000E+00, 0.72171800E+00, -.44403300E-01, -.25849000E-01, -.75670200E-01, 0.29163900E-01, 0.14830900E+00, -.24874400E-01, 0.10554900E+00, -.58783300E+00, 0.65899800E-01, 0.74517900E+00, -.97407500E+00, 0.74662200E+00, -.44812400E+00, 0.93808200E-01, -.70818800E-02, -.21374800E+00, 0.58363500E+00, -.13167300E-01, 0.96801200E-01, 0.45265300E+00, -.52417100E+00, -.68761800E+00, 0.53557500E-01, 0.69007000E+00, -.71984800E+00, 0.51772700E+00, 0.58393700E+00, 0.27119900E+00, -.32490200E+01, -.43104400E+00, 0.41895100E+00, -.11972800E+01, 0.32003400E+00, 0.94914200E-01, 0.20168000E+01, 0.20685700E-01, -.11573000E+00, -.17148600E+01, -.33458100E+00, -.14816400E+01, 0.89241300E-01, 0.20878000E+01, -.16880500E+01, -.11302100E+01, 0.69225000E+00, -.12118600E+01, -.79554600E-01, 0.15674100E+00, -.87047800E+00, -.58740200E-02, -.15850600E+00, -.31565000E+00, 0.70150100E-01, -.10163200E+01, 0.41172600E+00, -.50059600E+00, -.77290700E+00, 0.42313300E+00, -.17438800E-01, 0.14667700E+01, 0.80631000E-01, -.17947100E+01, 0.33953000E+00, -.34967300E+00, -.35818000E+00, 0.30614700E+00, -.14980500E+01, -.12270400E+00, 0.17858300E+01, -.43074800E-01, -.48394500E+00, 0.47091800E+02, -.24432300E+03, 0.12248700E+02, -.62151000E+02, -.13940200E+03, -.38335300E+03, 0.48867900E+02, 0.42789800E+03, 0.73059200E+02, -.55676000E+02, -.28928100E+03, -.34070500E+02, -.92416000E+00, 0.30057900E+02, -.32945300E+02, 0.54163300E+02, 0.54606600E+02, 0.15728300E+02, 0.58017000E+02, -.13268200E+03, 0.87055200E+02, -.71314300E+02, 0.61514200E+02, 0.41266500E+02, 0.10325200E+03, -.88970200E+02, -.37541700E+02, 0.98661700E+01, 0.25392000E+02, 0.43371500E+02, 0.65375500E+03, -.33047500E+03, -.25054700E+03, -.32689300E+03, -.12799400E+03, 0.31624100E+02, -.22085100E+02, 0.88207400E+02, -.15293900E+03, 0.16158200E+02, -.59835700E+02, -.21155900E+03, 0.90215500E+02, -.33495000E+03, 0.10549600E+03, 0.40615200E+02, 0.13879900E+02, -.86799500E+01, -.88567300E+02, 0.68840800E+02, 0.92094100E-01, 0.83475000E+02, -.18942100E+03, 0.99065900E+02, -.27219300E+03, 0.94955100E+02, 0.76610600E+02, 0.37011800E+02, 0.74352900E+02, -.22471000E+02, 0.46512600E+02, 0.29507900E+02, -.76216000E+02, -.99904000E+01, 0.15622100E+02, 0.66876300E+02, -.38061100E+01, 0.24859200E+02, -.31127600E+02, 0.10201100E+02, 0.49002600E+02, -.11202900E+03, -.51970500E+02, -.19355200E+03, -.17910500E+03, 0.99317300E+02, -.16867200E+03, 0.85232400E+02, 0.22543200E+03, -.37654000E+01, 0.72965500E+02, -.20611800E+02, 0.39911900E+03, 0.34103200E+00, -.25163600E+03, 0.23143900E+03, -.10319800E+03, -.82289300E+03, -.10119700E+03, -.10727300E+03, -.24753900E+03, 0.18409600E+03, 0.90542700E+02, 0.15787000E+03, -.22285600E+03, -.48215000E+02, 0.30076900E+02, -.17386700E+02, 0.59525000E+02, 0.65143000E+02, 0.56200900E+01, -.23074700E+02, 0.65404200E+02, 0.20995900E+02, 0.25140900E+02, -.22343700E+02, -.41590500E+02, 0.18170900E+02, 0.33344300E+02, -.12957500E+01, 0.20350500E+02, 0.42794100E+02, -.63876900E+02, 0.39176500E+02, 0.67676100E+02, -.17322800E+02, -.20370800E+02, -.47941000E+02, -.72524100E+02, 0.34000500E+02, 0.13090000E+02, -.72460400E+01 },
        { -.22879500E+01, 0.35868000E+00, 0.45847900E+00, 0.21372200E+00, 0.17366700E+01, 0.46982200E+00, 0.65638000E+00, 0.22119800E+01, -.20706200E+00, 0.70761300E+00, 0.51548000E+00, 0.71977200E-01, 0.48423600E+00, -.64198000E-01, -.10258400E+00, 0.14171600E+01, -.36454800E+00, 0.43726400E+00, -.26855800E-01, 0.16024000E+00, -.64434600E+00, 0.30476400E-01, -.68547600E-02, -.35275200E+00, -.31186100E+00, 0.95290700E-02, 0.71032200E+00, 0.41106700E-01, -.18084300E+01, -.55888800E-01, -.39932000E+00, 0.15931400E+01, 0.30289700E+00, -.20251300E+01, -.50878900E-02, -.11159200E+00, -.58569900E-02, -.34501000E-01, -.87221000E-01, -.15793200E+00, 0.48459700E+00, -.12277700E+00, 0.44116000E-01, -.49706500E-02, -.11993900E+00, -.12768700E+00, 0.45639300E-01, -.18843100E-01, -.96596700E+00, 0.79302200E-01, -.33180700E+00, 0.43474800E+00, -.15518000E+00, 0.10122000E+01, 0.10344900E+00, 0.88156900E+00, 0.31343100E+00, -.11332200E-01, -.18944500E-01, -.26772200E+00, 0.12529900E+00, -.32849100E+00, 0.93320000E-01, -.14678100E+00, 0.15359300E+00, 0.15298400E+00, 0.47574500E+00, 0.10719200E+00, 0.98541600E-01, -.33696800E-02, -.64983100E-01, 0.49503600E+00, -.17792600E+00, 0.21059600E-01, -.91256800E-01, -.11837300E+00, 0.41839300E-01, -.64460600E+00, -.21536800E-01, 0.27885100E-01, 0.95704800E-02, -.21596400E-02, -.10648000E+00, 0.84295000E-01, -.26689000E-01, -.16642600E-01, -.14775800E+00, 0.64471300E-01, -.97307000E-01, 0.27922700E-01, -.20333900E+00, 0.28471700E-03, -.17463300E+00, 0.12400600E-01, -.17501400E+00, -.16538100E+00, -.66900400E-01, 0.13854300E+00, 0.58537300E-01, -.10069800E+00, 0.28292900E-01, 0.58227000E-01, 0.15092200E-01, -.14778400E+00, 0.16178800E-01, 0.37787600E+01, -.23016000E+00, 0.71963600E-01, 0.18855100E+00, 0.67730500E-01, -.51997500E-01, 0.58622000E-02, 0.70125400E+00, 0.11809300E-01, 0.14325500E+00, 0.92503500E-01, -.12460600E+00, -.42548100E-01, -.39086600E+00, -.38914100E+00, -.12685300E+00, -.72199400E-01, -.11855500E+00, -.22718900E+00, -.40466100E-01, 0.97391400E-01, 0.18183200E-01, 0.40454300E+00, 0.84392700E-01, 0.15653500E+00, -.41779100E+00, -.42218800E-01, 0.44094600E+00, -.97085700E-01, 0.18679600E+00, -.10259300E-01, 0.48897900E+00, -.11204600E-01, 0.92179200E-01, 0.20637600E+00, -.43963300E+00, -.13239500E+00, -.79043400E-01, -.95968400E-01, -.46640300E-01, -.94119800E+00, -.19282000E-01, 0.77180000E-01, -.10503100E+00, 0.45263400E+00, -.16796500E+00, 0.40807000E+00, 0.25059400E+00, 0.11697500E+01, -.75840100E-01, -.61220800E+00, 0.18296700E-01, 0.20613800E-02, 0.46752600E+00, -.78738700E-01, -.94406400E-01, -.28132900E+00, 0.21947400E+00, 0.20272600E+00, -.47280300E-01, -.51743600E+00, -.72542700E-01, -.36661900E+00, -.31341100E-01, 0.18175600E+00, 0.13900800E+00, 0.10955600E-01, 0.16858000E+00, -.27145600E+00, -.51953300E+00, -.28735800E-01, -.11359300E+00, -.19731200E-01, 0.16651500E+00, -.88155600E-02, 0.16124900E+03, 0.76944900E+02, 0.50795300E+02, 0.14943400E+03, 0.83421600E+02, 0.46505200E+02, -.19653700E+03, 0.13663600E+03, -.69416000E+02, 0.14233700E+03, -.73220000E+02, -.59637000E+01, 0.65513100E+01, -.38608600E+02, -.28500100E+02, -.79205900E+02, 0.20141400E+01, -.61252700E+02, 0.41970100E+03, -.20908100E+03, -.69232800E+01, -.21062800E+03, -.39409300E+02, -.40980200E+02, -.28405400E+02, -.12560300E+02, -.17585400E+03, -.23727300E+02, -.14423200E+03, -.33606300E+03, 0.16732700E+03, 0.76940200E+02, 0.16982100E+03, 0.21940300E+02, -.24116600E+02, 0.22170400E+02, -.29473400E+02, 0.13852000E+03, -.36722100E+02, 0.65046100E+02, -.73930500E+02, 0.30170600E+02, 0.17939000E+03, 0.36965600E+02, 0.12445500E+00, 0.17922200E+02, 0.30118800E+02, 0.13659000E+01, 0.17069600E+02, 0.15682500E+02, 0.21188700E+02, -.19278800E+03, 0.94077300E+02, 0.20349200E+03, 0.96375500E+02, -.19439600E+02, 0.15843700E+02, 0.17669600E+01, -.44704600E+02, 0.71697700E+02, 0.95521200E+01, 0.72025800E+02, -.34458600E+01, 0.85912000E+01, 0.52165800E+02, 0.22656700E+01, 0.31418400E+01, -.71399900E+01, 0.18992500E+02, 0.65605500E+01, 0.37371100E+02, 0.39393500E+01, -.28357300E+01, 0.99226100E+01, -.31685200E+01, 0.28018000E+02, -.55393900E+01, -.10354900E+03, -.43509200E+02, -.19971500E+02, -.82059100E+02, -.10484000E+03, -.30580500E+02, 0.11764000E+03, 0.43970300E+02, -.11922300E+02, 0.19687500E+03, -.19907100E+02, 0.10087800E+02, 0.11255800E+02, 0.59154500E+01, -.14360700E+02, 0.35772700E+01, -.15261800E+02, -.17092400E+03, 0.35951100E+01, 0.10180200E+01, -.13142600E+01, -.22525000E+01, 0.43458800E+00, 0.38655500E+01, -.12777500E+02, -.27263300E+01, -.21440400E+01, -.16663800E+01, 0.66670200E+01, 0.47752500E+01, -.58876400E+01, -.10016800E+01, -.28502500E+01, -.23497800E+01, 0.18054900E+01, -.35364800E+02, -.42715400E+01, 0.24591400E+00, 0.99155300E+01, 0.77655500E+00, -.37156000E+00, -.66041100E+01, -.11491400E+02, 0.11976100E+01 },
        { -.26443900E+01, 0.44393800E+00, 0.39105900E+00, 0.13767300E+01, 0.85077400E+00, 0.20709600E+00, 0.11974100E+01, -.45216400E+01, -.34089600E+00, -.13109100E+00, 0.46293300E-01, 0.42286300E+00, 0.98549700E+00, -.85788100E-01, 0.22556800E-01, 0.34024900E+01, 0.22957000E+01, 0.10490200E+01, 0.62075300E+00, -.74957500E+00, -.11949600E+01, -.12624200E+00, -.38992100E-01, 0.15437500E+00, -.13210700E+00, -.23919400E+00, -.93762800E+00, -.82165500E+00, 0.10650000E+01, -.79719100E-01, 0.30909000E+00, 0.58867700E+00, -.12435300E+01, 0.36756800E+01, -.10974300E-01, 0.20124500E+00, 0.10688200E+00, 0.13911100E+00, 0.94078700E-01, 0.42382700E+00, -.10936400E+01, 0.16481000E+00, -.47402600E-01, -.91657400E-01, -.22278100E+00, 0.39515400E-01, -.60145000E-01, 0.52067000E-01, -.12644400E+01, -.94885600E-01, 0.31495600E+00, -.29350500E-01, -.47420700E-01, -.14641400E+01, -.23239100E+00, -.62546200E+00, -.48028500E+00, -.70638400E-01, 0.33898400E-01, 0.17219900E+00, 0.10265400E-01, 0.75756900E+00, -.28759900E+00, 0.11842900E-01, 0.11934300E+00, -.25995100E-01, 0.78500400E+00, 0.14728500E+00, 0.43882900E+00, 0.14944000E-01, 0.11418700E-01, 0.41799500E+01, -.41822800E-01, -.98791800E+00, -.37977000E+00, -.15741200E+00, 0.52317900E-01, -.45365600E+00, -.24032900E+00, 0.36940500E-01, -.54795400E-01, 0.53118600E-02, 0.19041000E+00, 0.19118900E+00, -.20985200E+00, -.51400500E-01, -.15748600E+00, -.53073100E-01, -.84516100E+00, 0.49232800E-01, -.91748000E+00, -.44416100E-02, 0.14721800E+00, 0.80328200E-02, 0.58153300E+00, 0.10700400E+00, 0.20392700E+00, 0.18312800E+00, -.40142200E-01, -.45074300E-01, -.14067100E-01, 0.20551900E+00, 0.14041600E-01, -.34867000E+00, -.81071100E-01, -.18765300E+01, 0.36914800E+00, 0.32523300E+00, -.13914900E-01, -.22763000E+00, -.14019000E+00, 0.11873500E-02, -.41300500E+00, 0.18090500E-01, -.33000700E+00, 0.18383400E+00, -.35267000E+00, 0.63830400E+00, 0.12242600E+01, -.12849400E+00, 0.10453700E+01, -.11431500E+00, -.57092800E-01, -.18913000E-01, -.12425400E+00, 0.67394800E+00, 0.62958400E+00, 0.85869600E+00, -.17192300E+00, -.98776700E-01, -.85717000E-01, 0.11369600E+00, 0.37185700E+00, 0.29004300E+00, -.87373900E-01, -.14591700E-01, -.14940100E+00, 0.20231300E+00, -.83679500E-01, -.99892800E-01, 0.53338400E+00, 0.34623700E+00, -.44032600E+00, 0.44638000E+00, 0.82569300E-01, 0.90468800E+00, 0.11401600E+00, -.41992500E+00, 0.43375300E-01, -.30341100E+00, -.24086100E+01, -.39484700E+00, -.36991700E+00, -.54847600E+00, 0.14600400E+00, -.20596700E+00, 0.88358000E-01, 0.40279900E-02, 0.20735500E+00, -.20271300E+00, 0.10890300E-01, 0.39563500E+00, 0.46914900E-01, 0.27252400E+00, 0.52721600E-01, 0.16584300E+00, -.57068000E-01, -.34703000E+00, 0.60949000E-03, -.29109800E+00, -.59463200E-01, 0.79673600E-01, -.32699600E-02, -.80317800E-01, 0.15791100E+00, 0.16175200E+00, 0.15477000E+00, 0.14959000E-01, -.72425600E-01, 0.59913700E-01, 0.31277600E+00, -.90752800E+02, 0.35166500E+02, -.73977800E+02, -.23324900E+02, -.64111000E+02, 0.27560700E+02, -.12155400E+03, 0.60004000E+02, -.58478600E+02, 0.71455500E+02, -.58895000E+01, 0.96690000E+00, 0.15144100E+02, 0.13562800E+02, 0.97545600E+02, 0.11090600E+02, 0.11992000E+03, -.19945200E+03, 0.99729700E+02, -.74595900E+02, 0.10135700E+03, 0.19509700E+02, 0.41166000E+02, -.31285700E+02, 0.21353900E+02, 0.15135700E+03, 0.35118800E+02, 0.15156900E+03, 0.16403600E+03, -.81939100E+02, -.37549600E+02, -.83450600E+02, 0.24708300E+01, -.18380000E+02, 0.12355300E+02, 0.76053700E+02, -.40678700E+02, -.79982600E+00, -.72884200E+02, 0.22454300E+03, -.10332600E+03, -.25096200E+03, -.11224300E+03, -.23137600E+02, -.21364900E+02, -.35367700E+02, 0.50167100E+02, -.34797700E+02, -.23645000E+02, -.12825400E+03, 0.44339100E+02, -.21326900E+02, -.11114700E+03, -.22162400E+02, 0.20552100E+02, -.28374300E+01, -.13967200E+02, 0.80875900E+01, -.17954400E+02, 0.20133000E+01, 0.60381300E+02, -.57592400E+02, 0.21436600E+02, -.85613300E+02, 0.28555000E+02, 0.30794500E+02, 0.24338300E+02, -.43795700E+01, -.40019100E+02, 0.17089400E+02, 0.28515400E+01, -.19648100E+02, -.13319100E+03, 0.62913800E+02, -.70918400E+02, 0.67238400E+02, 0.26165500E+02, 0.90359300E+02, -.58430700E+02, 0.35066400E+02, 0.85954400E+02, 0.72808800E+02, 0.54564200E+02, -.11203800E+03, 0.43114200E+02, -.19955000E+03, 0.53191900E+02, 0.17037300E+02, 0.36289100E+02, -.36807800E+02, 0.34011000E+02, 0.15321900E+02, 0.49694000E+02, 0.19449400E+03, -.74108500E+01, -.11820900E+01, 0.16016800E+02, 0.11790100E+02, -.37127600E+01, -.30025600E+01, 0.48840900E+01, 0.35669000E+01, -.14635600E+01, 0.28634100E+01, -.26624900E+01, -.10699400E+02, 0.41627000E+00, 0.47700200E+01, 0.43986100E+01, 0.20929500E+01, -.11141900E+02, 0.30741600E+02, 0.19844900E+02, -.12624700E+01, -.53704800E+00, -.20465700E+01, -.47959000E+01, 0.87038100E+01, 0.18679600E+02, 0.16436200E+01 },
        { -.23491100E+01, -.71196100E+00, 0.26731900E+00, 0.70618200E+00, 0.20159500E+01, 0.52951800E+00, 0.95221600E+00, 0.15290400E+01, -.18953900E-01, -.11243200E+01, 0.68983000E+00, 0.24721600E+00, 0.47740500E+00, 0.73326100E-01, -.14090400E+00, 0.86141400E+01, 0.18658700E+01, 0.56472000E+00, 0.14385100E+01, 0.32252300E+00, -.99299900E+00, -.45173600E-01, 0.32744300E-01, 0.25776100E+00, -.15315800E+00, -.65929700E-01, 0.60422300E-01, 0.29293300E+00, -.66052200E+00, -.13829800E-01, -.72725100E+00, 0.68443000E+00, 0.47195000E+00, 0.15713700E+01, 0.12914300E-01, -.49957500E-01, 0.11214200E-01, -.82259600E+00, -.14406300E+00, -.15597200E+00, -.42394600E+00, 0.79445100E-01, 0.43563900E-01, 0.59812400E-01, 0.37401700E-01, 0.56036700E+00, 0.17629900E-01, 0.57758500E-01, -.37507700E+00, 0.18501200E+00, 0.43714700E+00, 0.26615900E+00, -.33999300E+00, 0.49019500E+00, 0.38645000E+00, 0.51931900E+00, 0.86981700E+00, 0.75679700E-01, 0.21927400E-01, 0.14796300E+00, -.73845300E-01, 0.31468200E+00, 0.40010100E-01, 0.96711300E-01, -.20385800E+00, -.17986900E+00, 0.33803300E+00, 0.13425300E-01, 0.31408600E+00, 0.23814200E-02, 0.24102400E-01, 0.12687400E+01, 0.13423200E+00, 0.17356300E+00, -.18579400E+00, 0.69318600E+00, 0.55220900E-01, -.96999100E-01, -.36055900E-01, 0.83358900E-01, 0.35084800E-01, -.33936900E-02, -.40526500E-01, 0.18319000E+00, 0.14690900E+00, -.78298000E-01, -.24770700E-01, 0.36352000E-01, 0.15705000E+00, 0.37965400E-01, 0.41960000E-01, 0.82788100E-03, -.46076500E-01, -.62126400E-01, 0.14586200E+00, -.43439900E-01, -.42218400E-01, -.99293200E-01, -.32664000E-02, -.85050500E-01, 0.27426300E-01, 0.54608500E-01, 0.18188400E-01, -.12053800E+00, 0.35680000E-01, 0.12341000E+01, -.56826300E-01, 0.52511000E-01, 0.75229600E-01, -.10225600E+00, -.75570200E-01, -.22241600E-01, 0.24698000E+00, 0.15969700E-01, -.18972900E+00, -.18287500E-01, 0.18596900E-01, 0.43659200E-01, 0.29643100E-01, -.80164500E+00, 0.21858700E+00, -.51589000E-01, -.82599600E-01, -.65253200E-01, -.31148800E-01, 0.17132100E+00, -.48955000E-01, -.39062700E-01, 0.11791800E+00, 0.12596500E+00, 0.11041000E+00, -.14193500E+00, 0.12585500E+00, 0.21075800E+00, 0.12161700E+00, -.38486500E-02, 0.12701300E+00, 0.62634000E-01, 0.40800900E-02, 0.35567900E+00, 0.11237500E+00, 0.22930600E+00, -.34866000E+00, 0.41858100E+00, 0.62963100E-01, -.34593200E+00, 0.45721100E-01, -.10007500E+00, -.61626000E-01, -.39543700E+00, -.28984200E+01, -.34086000E-01, 0.11893200E+00, -.75295600E+00, -.42615000E-01, 0.34538600E+00, -.80911400E-01, 0.37739200E-04, -.95472200E+00, -.26441300E-02, 0.80715900E-01, 0.20148500E+00, -.13147700E+00, 0.13505500E+00, -.43468400E+00, 0.89144800E-01, 0.39335700E-01, -.52340800E+00, -.14267100E-01, -.16296800E+00, 0.14877800E+00, -.82907800E-01, 0.47857400E-02, 0.15306700E-01, 0.41472700E+00, -.54084500E-02, 0.57485600E-01, -.22270500E-01, -.27146600E+00, 0.41175500E-01, 0.58020500E-01, -.14219700E+00, 0.33460300E+02, -.12402000E+01, -.61604000E+02, 0.75346200E+01, -.14392600E+01, -.29652100E+03, 0.14214200E+03, 0.32191200E+02, 0.15577200E+03, 0.26324100E+02, 0.99774300E+01, 0.58988200E+02, -.32320100E+02, 0.81587000E+02, 0.20990400E+02, 0.87369500E+02, -.19360000E+03, 0.95583100E+02, 0.20576200E+02, 0.98840200E+02, 0.37816600E+02, 0.53346000E+02, -.10447500E+02, -.10773900E+02, 0.51652100E+02, 0.40901900E+02, 0.94026600E+02, -.10714200E+03, 0.52161800E+02, 0.76177300E+02, 0.51844500E+02, 0.72581700E+02, 0.87767000E+02, -.51519200E+02, -.40831600E+01, 0.50780600E+02, 0.58004000E+02, 0.14929400E+03, 0.64241500E+02, -.33575300E+02, -.22859600E+03, -.31655800E+02, 0.31920500E+00, -.78007700E+01, 0.24703700E+01, 0.27398000E+02, 0.10907800E+01, -.79700800E+01, -.99535300E+02, -.24866800E+02, 0.12943800E+02, -.85226300E+02, 0.12447900E+02, 0.22933200E+02, 0.35886400E+01, 0.79521200E+01, 0.82821200E+01, 0.74838200E+01, 0.90640400E+00, 0.79959100E+02, -.78477400E+02, 0.39357100E+02, 0.21032900E+02, 0.38633700E+02, 0.27334900E+02, -.27754100E+01, 0.32045200E+02, -.32264400E+02, -.23689500E+02, -.22322300E+01, -.83473100E+02, -.75924100E+02, 0.40062500E+02, -.10053900E+03, 0.38408600E+02, -.29011000E+01, 0.11981100E+02, -.25564100E+02, -.34461300E+02, 0.43330300E+02, 0.22169200E+02, 0.13460700E+02, -.19776700E+03, 0.96609700E+02, -.15330500E+03, 0.95843100E+02, 0.80261800E+02, 0.25010100E+01, 0.12838300E+02, 0.72739400E+02, 0.10119600E+03, 0.10744300E+01, 0.21594200E+03, -.16190700E+02, 0.24140300E+01, 0.89997900E+01, 0.86403300E+01, -.11658700E+02, 0.46017100E+01, 0.51542800E+01, -.27157600E-01, -.29430200E+01, 0.21772400E+01, -.30680900E+01, -.11810900E+02, -.23691000E+01, 0.12369400E+02, 0.11978100E+01, 0.82899100E+01, -.74277200E+01, -.15071200E+01, 0.10931800E+02, 0.63211000E+01, -.81943700E+01, -.10700300E+02, -.24485200E+02, 0.34294900E+01, 0.26295000E+01, 0.23964100E+01 },
        { -.27359200E+01, -.18146000E+00, 0.20337200E+01, 0.14079400E+01, 0.42905100E+00, 0.58635900E+00, 0.12396300E+01, -.79898400E+01, 0.54515600E-01, -.25107800E+01, -.38385900E+00, 0.10921900E+01, 0.19383300E+00, -.25945700E-01, -.36676600E+00, 0.62626900E+01, 0.42164100E+00, 0.10712400E+01, 0.46919200E+00, -.49343100E+00, -.53110000E+00, 0.42175200E+00, -.10942800E+00, 0.74082700E+00, -.18164700E+00, -.54981200E-01, -.66993900E+00, 0.85199800E-01, 0.78918600E+00, 0.49464300E-01, -.39823100E+00, 0.28143100E+00, -.37088900E+00, -.17091800E+00, 0.23128700E-01, -.10144100E+00, 0.20392200E-01, 0.47836900E-01, -.10849000E+00, -.30946100E-01, 0.16604500E+00, 0.44824900E+00, -.60454400E-02, 0.19118000E+00, -.29986300E+00, 0.79795300E+00, -.15208600E+00, 0.40662600E-02, 0.15724800E+01, -.35572500E-01, 0.45089500E+00, -.18842500E+00, 0.64135900E+00, -.17116800E+01, -.12033800E+00, -.61692800E+00, -.23946000E+00, -.19460400E+00, -.21251300E-02, -.45765400E+00, -.12857900E+00, 0.20130600E+00, 0.12892300E-03, -.46857100E-01, -.16672100E+00, 0.53051800E+00, -.12079200E+00, -.21321600E+00, -.14117300E+01, -.83271900E-02, 0.13684600E+00, -.61874200E+01, -.54881300E+00, 0.22139700E+00, 0.13776200E+01, -.63467800E+00, 0.37429800E-02, 0.18436500E+01, 0.99490800E+00, -.10594500E+00, -.26149900E-02, 0.84356100E-01, 0.11788400E-01, 0.19656100E+00, 0.10498600E+00, -.12600100E+00, 0.18320000E+00, 0.50007100E-01, 0.10090700E+00, -.34546100E-01, 0.26325400E-01, -.33986300E-02, 0.25669100E+00, -.30824700E-02, 0.36826900E+00, 0.28708800E+00, 0.14774100E+00, -.21470700E+00, -.21869400E-01, -.20633200E-01, 0.27849800E-01, -.78329100E-01, -.41379100E-01, 0.16631200E+00, 0.34046600E-01, -.24583600E+01, -.53037800E-01, -.10555500E+00, -.25650800E-01, 0.29604000E+00, 0.44696100E-01, 0.21003500E-01, 0.34052800E+00, -.26431400E-01, -.28945800E+00, 0.13591500E+00, 0.75006800E-01, 0.21625000E+00, -.21255200E+00, -.57830300E+00, 0.20120900E+00, 0.51603800E-02, -.20449900E+00, 0.32556700E+00, -.55281000E-01, 0.15698500E+00, 0.28546700E+00, -.97392700E+00, 0.13874200E+00, 0.13020000E+00, 0.13704200E+00, -.16372000E+00, 0.39863500E+00, 0.16142300E+00, 0.16981600E-01, -.54051600E-02, 0.90764800E-01, 0.62429000E-01, 0.12059600E+00, -.29153000E+00, 0.82625600E-01, 0.24500700E+00, -.68479400E+00, -.66240800E-02, 0.54561200E-01, -.21651600E+00, -.17767500E-02, 0.63022000E-02, -.55788100E-01, -.78685800E+00, -.16644400E+01, -.15580400E+00, -.80085100E-01, 0.44089400E+00, 0.24888600E-01, 0.45771600E+00, 0.11441900E-01, 0.53025600E-02, -.80876500E-01, 0.46922100E+00, -.70787000E-01, -.90414500E-01, -.38379100E-01, -.63993800E-01, 0.76064100E+00, 0.90282800E+00, 0.23433800E+00, 0.66397100E-01, 0.12992700E-01, -.10692200E+01, 0.25539100E+00, -.27856100E+00, 0.16221200E+00, -.82555200E-01, 0.17487300E+00, 0.39191800E+00, 0.51655800E+00, -.40522700E-01, -.15930900E+00, -.20825600E+00, -.27860800E+00, -.59178600E+00, 0.10477500E+01, 0.13387000E+03, -.66559500E+01, -.15373600E+02, 0.14658600E+03, 0.45702500E+03, -.21431700E+03, -.15295700E+03, -.21705600E+03, -.25566800E+02, 0.71420900E+02, -.17801800E+03, -.12483600E+02, -.18898000E+03, 0.66580200E+02, -.47733800E+02, 0.34578600E+02, -.14474200E+02, 0.13207000E+02, -.17325600E+02, 0.25364200E+02, 0.12118700E+03, -.16995100E+03, -.84001800E+02, -.85259000E+02, 0.10505700E+03, -.40804600E+02, 0.54115400E+03, -.27164700E+03, -.15088200E+03, -.28105400E+03, -.38233900E+02, -.10355900E+03, 0.11316700E+02, 0.43138600E+02, -.95887100E+02, -.52050000E+02, -.41223900E+03, 0.31461200E+03, -.15583600E+03, -.20462500E+03, -.15707400E+03, -.30082800E+02, 0.78820000E+01, -.10893300E+03, 0.44402500E+02, -.49411200E+02, -.21991400E+02, -.51445200E+02, 0.23707000E+03, -.11721100E+03, -.13740900E+03, -.11838500E+03, -.74095900E+02, -.32301300E+02, -.39327000E+02, 0.30350100E+01, -.74693600E+02, -.84995400E+01, -.16887500E+03, -.26018700E+02, 0.10348300E+02, -.75277600E+00, 0.87680800E+01, -.23723600E+02, 0.17145600E+02, -.46647200E+02, 0.46787200E+01, -.10340500E+02, -.13398100E+02, -.29373400E+01, 0.21254900E+02, -.93200300E+01, 0.13417200E+03, -.78843700E+01, 0.46097100E+01, 0.29937400E+02, -.27561700E+02, -.69934200E+02, -.31013500E+02, 0.36432100E+02, -.98359700E+02, 0.15170700E+03, -.78927200E+02, -.16908300E+03, -.82428900E+02, -.23841100E+02, 0.62218500E+02, -.66187400E+02, -.38872900E+02, -.23006600E+02, 0.46519800E+02, 0.22554100E+03, 0.20819900E+02, 0.31962000E+01, 0.20752500E+02, 0.21976200E+02, -.83364400E+01, -.12822000E+02, 0.12194800E+02, -.19591400E+01, -.59099800E+01, 0.27457400E+01, 0.24150700E+01, 0.66236600E+00, 0.28207500E+00, 0.10880500E+02, -.31993200E+01, -.84063600E+01, -.22176900E+02, -.21633400E+02, 0.25890800E+02, -.19287300E+01, -.21852800E+02, 0.69409700E+01, 0.54488000E+02, -.15054500E+01, -.11566800E+02, -.84089300E+01 },
        { -.11059600E+02, -.29806500E+01, 0.48940000E+01, 0.71389800E+01, 0.39015800E+01, 0.21434300E+01, 0.48445500E+01, -.20729600E+02, -.47769700E+00, -.15193300E+01, -.37350500E+01, -.39647300E+00, -.95490300E+00, -.63754000E+00, -.10230200E+01, 0.18044500E+02, -.49249200E+01, -.31441600E+01, 0.36719600E+01, 0.17957800E+01, 0.30886500E+01, -.33148600E+01, 0.28241000E+00, -.29848900E+01, -.11704300E+01, -.17773600E+00, -.73359600E+00, -.38047500E+01, 0.37529900E+01, 0.36516000E-01, -.19790200E+01, -.95309700E+00, -.11991600E+01, -.37172700E+01, -.15753300E+00, 0.40837600E-01, 0.25519200E+00, 0.37482700E+01, 0.32607300E+00, 0.30975300E+01, 0.65215900E+01, -.30597500E+01, -.41084600E+00, -.11328600E+01, 0.10399900E+01, -.11294200E+01, 0.17859000E+00, 0.44159600E-01, -.49245200E+00, -.12472800E+00, 0.31399600E+00, 0.11693800E+01, 0.21822500E+00, 0.29037600E+01, 0.29871100E+00, -.73537500E-01, 0.72131500E+00, -.16921400E+00, -.39467700E-01, 0.58633600E+00, -.51233500E+00, 0.14802100E+01, -.52591400E+00, -.28579600E+00, -.36313800E+00, -.12901100E+01, -.30827600E+01, 0.15217300E+00, -.29242900E+00, 0.29073700E-01, -.84582600E-02, -.20052500E+01, 0.15246800E+01, 0.19961000E+01, -.48180100E+00, -.13872500E+01, -.25307000E+00, 0.28638500E+01, 0.12288600E+00, -.10381200E+00, -.21765900E+00, 0.84242000E-01, 0.62213800E+00, -.31307800E+00, -.67486300E-01, -.82903000E+00, -.87176400E+00, -.72056600E+00, 0.26376100E+01, -.52196600E-01, 0.94306000E-01, 0.50291600E-03, 0.16264700E+01, 0.31054300E+00, 0.11464400E+01, 0.54376400E+00, 0.74999000E-01, -.22000000E+01, 0.34897100E+00, -.14222200E+01, 0.18610300E+00, -.76966400E+00, -.67229700E-01, 0.84232200E-01, 0.12011100E+01, -.65623300E+01, -.38386800E+00, 0.33241900E+00, 0.16011200E+00, 0.32813000E+00, -.89987300E+00, -.49056900E-02, -.25045300E+01, 0.59731900E-01, 0.59163000E+00, -.34390900E+00, -.32989600E+00, -.91315600E+00, 0.24012700E+01, -.31145500E+01, -.33338100E-01, -.13116700E+00, -.18568200E+00, 0.88862700E-02, -.60250900E-01, -.17612800E+00, -.87550400E+00, 0.57274300E+00, 0.96938500E-01, -.77121500E-01, 0.54440700E+00, 0.21040400E+00, -.24705300E+00, -.12094600E+00, -.24966900E+00, -.31608300E-01, -.14971400E+00, 0.54139900E+00, -.53889300E+00, 0.22173100E+01, 0.31905700E+00, 0.34581700E+00, -.19619600E+01, 0.15464300E+01, 0.28054000E+00, 0.13704600E+01, 0.29653800E+00, 0.10079000E+00, 0.26825800E-01, -.12613900E+01, 0.37329700E+01, 0.13102300E+01, -.79317600E+00, 0.71887800E+00, 0.18050000E+00, 0.10046800E+01, 0.33416000E+00, 0.13905700E-02, 0.66017400E+00, 0.79938400E+00, -.25992100E+00, 0.49486700E+00, 0.42099600E+00, 0.18245800E+00, 0.28752800E+01, 0.27375800E+00, 0.16548300E-01, -.26721200E+00, 0.51921000E-01, -.40073300E-01, -.56566900E+00, 0.21055800E+00, 0.28017600E+00, -.51126100E+00, 0.35977100E+00, -.17111600E-02, 0.74795300E+00, 0.44307200E-01, 0.88467200E+00, -.22875300E+00, 0.47671000E+00, 0.92962400E+00, -.34129400E+01, -.18429700E+01, -.30705300E+03, 0.43224900E+02, 0.30815700E+03, -.81226800E+03, 0.40122200E+03, 0.18481600E+03, 0.44227200E+03, 0.14155900E+03, 0.24257300E+03, -.64100700E+02, -.26981300E+03, 0.97454800E+00, 0.29045100E+03, 0.26677800E+03, -.94150100E+03, 0.47018300E+03, 0.30815200E+03, 0.47070000E+03, 0.22667100E+03, 0.44033300E+03, -.26868800E+03, -.22338900E+03, 0.87443300E+02, 0.42835700E+03, 0.35360100E+03, 0.43032000E+03, -.22004900E+03, 0.18924300E+03, -.24305500E+03, 0.20924800E+03, 0.19528100E+03, -.14941900E+03, -.49844500E+02, -.76804900E+02, 0.20627400E+03, -.31627500E+03, 0.80952900E+03, -.39329300E+03, -.13591500E+04, -.40321900E+03, -.48463100E+02, -.12962900E+02, -.19255900E+03, 0.23530900E+03, -.55149800E+02, -.72230300E+02, -.40764500E+03, 0.45636700E+03, -.22382300E+03, -.55224400E+03, -.22780000E+03, -.53265200E+02, -.80586200E+02, -.20391100E+02, 0.86208000E+02, -.16049200E+03, -.41965800E+02, -.62937500E+02, -.24156200E+03, 0.10492800E+03, -.96631500E+02, 0.11024600E+03, -.53360500E+02, -.43214100E+02, 0.63706300E+02, -.18427700E+02, -.94008500E+02, -.10228400E+03, 0.16967500E+03, -.13581600E+03, 0.69614800E+02, -.47514200E+02, 0.75807800E+02, -.50076400E+02, 0.38290800E+02, -.47278400E+02, -.81834400E+02, 0.16717700E+03, 0.31183000E+02, -.19153800E+03, -.57092000E+03, 0.25538800E+03, -.54600300E+03, 0.26678700E+03, 0.33636800E+03, 0.16071600E+03, -.55337500E+02, 0.12719700E+03, 0.28256200E+03, 0.17549400E+03, 0.13547400E+04, -.44223600E+02, 0.18777700E+02, 0.79911700E+02, 0.77056600E+02, -.51459600E+02, -.10405100E+02, 0.16896200E+02, -.16279700E+02, -.24964900E+02, 0.14986400E+02, -.48071000E+01, -.39871000E+02, -.21016300E+02, 0.58898400E+02, -.14076900E+02, -.23667100E+02, -.71441000E+02, -.16920400E+02, 0.92698200E+02, 0.17444700E+02, -.81310300E+02, 0.10275900E+02, -.21456700E+02, -.49521800E+01, -.12954000E+02, 0.10015000E+01 },
        { 0.18602300E+01, 0.46387000E+00, 0.57896200E+00, -.24465600E+00, -.11464700E+01, -.35393400E+00, -.28854400E+00, -.10628700E+01, 0.16970700E+00, 0.63748200E+00, -.59569300E+00, -.29069900E+00, -.54414900E+00, 0.45580000E-01, 0.12160100E+00, -.44512400E+01, -.10012700E+01, -.18766700E+00, -.68766600E+00, 0.33210400E+00, 0.35490700E-01, -.30461900E+00, 0.73738100E-02, -.14935900E+01, 0.16301000E+00, 0.21318100E-01, -.39612200E+00, -.19204000E+01, 0.10754500E+01, -.70536100E-01, 0.14298000E+00, -.40179700E+00, -.23350800E+00, -.33102900E+00, -.31082800E-01, 0.45996000E-01, -.16682700E-01, 0.36390600E+00, 0.13580900E+00, 0.55959700E+00, -.10756700E+01, -.33575700E+00, 0.16837000E-01, -.17993100E+00, 0.51727000E+00, -.16265000E+00, 0.22608100E-01, 0.64892900E-03, -.17217200E+00, -.14472100E+00, 0.65013200E-01, 0.25499500E+00, 0.64549100E-01, -.89063200E+00, -.25741600E+00, 0.66443600E-01, -.82578000E-01, -.54302300E-01, 0.10050700E-01, -.36044400E-01, -.20977400E+00, 0.47822500E+00, -.79041700E-01, 0.14332600E+00, 0.41879700E+00, 0.15611100E+00, -.99818800E+00, -.21699600E+00, -.84134100E+00, 0.12171900E-01, -.48623600E-01, -.30992200E+01, -.31122700E+00, -.18952800E+00, 0.15652800E+00, -.16153400E+00, 0.13880900E+00, 0.42734000E+00, 0.27096600E+00, 0.11017600E+00, -.11261100E+00, 0.71211600E-01, 0.19884400E+00, -.43110900E+00, -.33403100E-01, 0.11824100E+00, -.22340000E+00, -.17959300E+00, 0.59741700E+00, -.30133800E-02, -.21167400E+00, -.46520100E-04, 0.22177800E+00, 0.12981800E+00, -.20900100E+00, -.27529400E+00, 0.17053800E-01, -.13481400E-01, 0.14362500E-01, -.18415500E-01, 0.20581700E-01, -.98696700E-01, -.81557400E-02, 0.16921300E+00, -.13213400E-01, 0.82135500E+00, 0.34672500E-01, 0.84276300E-01, 0.60367200E-01, -.29303300E-01, 0.87952300E-01, 0.23490300E-01, -.18387700E+00, -.27786900E-02, -.17440000E+00, -.12195000E+00, -.10579700E+00, 0.22497900E+00, -.35128800E+00, 0.40116000E+00, -.10050300E+00, 0.90709200E-01, 0.27496600E-01, 0.50640500E-01, 0.58533300E-01, -.50902200E-01, 0.16870200E+00, -.47800000E+00, 0.12727600E+00, -.41935300E-01, -.61933000E+00, 0.15736800E+00, -.84272300E-01, -.15967300E+00, -.44687100E-01, 0.11386900E-01, -.20471900E+00, -.21065000E-01, -.75055200E-03, -.14357900E+00, 0.16245500E+00, 0.11860700E+00, 0.10945400E+00, -.73425500E-02, -.21485800E-01, 0.83048200E-01, -.13537500E-01, -.13436600E+00, 0.88849500E-03, 0.12440600E+00, -.11528700E+00, 0.87100700E-02, -.59614300E-03, 0.46818100E+00, 0.15238800E-01, -.51478800E-01, 0.27425500E-01, 0.15865300E-02, 0.71172500E+00, 0.14182100E+00, -.15379900E-01, -.24594300E-01, 0.28946900E-01, 0.19872400E+00, 0.48167600E+00, -.48427400E-01, 0.10771400E-01, 0.34063900E+00, -.40959100E-02, -.27824000E-01, -.41660700E-01, -.36175700E-01, 0.22360500E-01, 0.15787200E-01, -.24903500E+00, -.28050500E-01, 0.65808900E-01, -.27018400E-02, 0.12526200E+00, 0.43398900E-01, 0.71618200E-01, -.98959000E-01, 0.20190500E-02, -.15598400E+00, 0.56424200E-01, 0.24268300E+02, -.24616700E+02, 0.26367100E+03, -.12616700E+03, -.84088000E+02, -.13624600E+03, -.31300700E+02, -.13578000E+02, -.47763300E+02, 0.33430400E+02, -.53783400E+02, -.20043100E+02, -.52533200E+02, 0.12059400E+03, -.56691600E+02, -.41917300E+02, -.59744400E+02, -.27028400E+02, -.35439200E+02, -.82467400E+01, 0.67738900E+01, -.12406500E+00, -.28901600E+02, -.34683100E+02, 0.15393200E+03, -.76790900E+02, -.10552700E+03, -.76001100E+02, -.66731300E+02, -.92461100E+02, 0.77673100E+02, 0.41501000E+01, -.10942100E+03, -.40125600E+02, -.18562000E+03, 0.13997800E+02, -.82147300E+01, 0.94941500E+02, -.70158400E+01, -.12110100E+02, 0.82909600E+01, -.17721500E+02, -.72072100E+01, -.59562200E+01, 0.50765000E+01, 0.66215100E+02, 0.19638000E+00, 0.47203700E+00, -.92294600E+01, -.11614900E+00, -.17754800E+02, -.45541800E+01, -.24644700E+01, -.13338000E+02, -.52098400E+01, 0.27316500E+01, -.41830600E+02, 0.61742400E+02, -.29051800E+02, -.19840600E+02, -.30451000E+02, -.42229600E+01, 0.15956200E+02, -.34541500E+02, 0.34537300E+02, 0.14455300E+02, 0.10763000E+02, 0.53939400E+02, 0.62493500E+02, -.31157500E+02, 0.71773700E+02, -.31603700E+02, 0.10601600E+02, 0.86768700E+01, -.18197200E+02, 0.10097300E+02, 0.95633800E+01, -.21308000E+02, -.27866000E+02, 0.12218100E+03, -.56614300E+02, -.99173300E+01, -.60942000E+02, -.41907500E+02, 0.45265100E+01, 0.10536500E+02, -.55182300E+02, -.70708800E+02, 0.25285600E+02, -.15582800E+03, 0.91730900E+01, -.89319000E-01, -.24507200E+01, -.17682800E+01, 0.93342100E+01, -.72372700E+01, -.15759900E+01, -.50879600E-01, 0.24009500E+01, -.11106400E+01, 0.37211200E+01, 0.93656700E+01, 0.26764600E+01, -.91554600E+01, -.92705100E+00, -.13009400E+01, 0.10074700E+01, -.12160200E+01, -.26163500E+01, -.74489400E+01, 0.45584300E+01, 0.22999100E+01, 0.34101100E+00, -.25160600E+01, -.49832000E+00, 0.19827000E+01 },
        { -.11326700E+02, -.47240800E+01, 0.48455200E+01, 0.93648800E+01, 0.27774300E+01, 0.33837000E+01, 0.61682300E+01, -.26777500E+02, -.58697100E+00, -.47075800E+01, -.43030300E+01, 0.68663000E-01, -.75563300E+00, -.76096300E+00, -.90905800E+00, 0.15626300E+02, -.85189100E+01, -.35829200E+01, 0.28580300E+01, 0.38006300E+00, 0.54319700E+01, 0.44749300E-01, 0.39936000E-01, -.12848700E+01, -.11787000E+00, -.10153500E+00, -.16096900E+01, -.45348100E+01, 0.35765400E+01, 0.22864400E+00, -.28399800E+01, -.29177000E+01, 0.47314700E+00, 0.53079600E+00, -.13626400E+00, -.34515500E+00, 0.59902400E-01, 0.34211600E+01, -.28399500E+00, 0.23109400E+01, 0.65931200E+01, -.78990200E+00, -.53171800E+00, -.39558500E+00, 0.19941400E+00, -.76323400E+00, 0.16998500E+00, -.69619100E-01, -.12765400E+01, -.92402600E-02, -.23862700E+00, 0.69074800E+00, -.27687500E+00, 0.50353000E+01, 0.11956500E+00, 0.34720600E+00, 0.12995700E+01, -.92435800E-01, -.14433900E+00, 0.15702600E+01, -.13219400E+00, 0.57821600E+00, 0.18576900E+00, -.71345000E+00, -.99735700E+00, 0.32094800E+00, 0.50277600E+00, 0.15792600E+00, -.21565400E+01, -.20898900E-01, -.13620500E+00, -.57088200E+01, 0.11037600E+01, -.44067700E+01, 0.13017400E+01, -.46432600E+00, 0.46063300E+00, -.51917800E+00, 0.81143100E+00, -.19937500E+00, -.36307900E+00, 0.78494400E-01, 0.80272700E+00, 0.10862500E+01, -.62522200E+00, -.66714200E+00, -.28421600E+00, -.11766400E+01, 0.17867600E+01, 0.26966200E+00, 0.97605500E+00, 0.82425000E-02, 0.64756600E+00, 0.12644000E+00, 0.14882500E+01, 0.62436900E-01, -.71896200E+00, -.24802600E+01, 0.23116400E+00, -.72011200E+00, 0.25270400E+00, -.48452700E+00, 0.41605200E-01, 0.55388600E+00, -.29977400E+00, -.21903200E+01, 0.10118900E+01, -.30622600E+00, 0.11824300E+00, 0.13607300E+00, -.17184100E+01, -.10827600E+00, -.42995300E+01, 0.85595200E-01, 0.13098400E+01, -.15078800E+01, -.37860200E+00, 0.41508400E+00, -.97106900E+00, 0.57302300E+01, 0.39747800E+00, 0.86934200E-01, 0.88062900E+00, 0.30463800E+00, 0.78263300E-01, 0.83636200E+00, -.20441700E+00, -.41120900E+01, -.74783300E+00, -.83184800E+00, 0.24447100E+01, 0.15732100E+01, 0.25929300E+01, -.25440200E+01, 0.34947500E+00, 0.13361700E+00, -.32972400E+01, -.17422100E+01, 0.22721700E+00, 0.51255800E+01, 0.20646700E+01, 0.11744900E+01, 0.12971600E+00, 0.40910200E+00, -.51176500E-01, 0.44508900E-01, 0.49530600E-02, 0.13981800E+01, 0.17395600E-01, -.17667000E+01, -.18487300E+01, -.69251600E+00, -.25642900E+00, -.35818900E+01, 0.17277100E+00, -.13433600E+00, 0.59977800E-01, 0.61914000E-02, 0.11910300E+01, 0.36943300E+00, -.58950700E+00, -.31895700E+00, -.46668600E+00, -.68395300E-01, 0.14570500E+00, -.95009800E+00, 0.15651400E+00, 0.28146500E+01, -.11124400E+00, 0.31731900E+01, -.20222000E-01, -.21614900E+00, 0.79730300E+00, -.52942000E+00, -.99842400E-01, -.23023200E-01, -.15853800E+01, -.33571500E-01, -.49560700E+00, 0.47243800E+00, 0.20212300E+01, 0.10586200E+01, 0.13324900E+01, -.31603500E+00, 0.58998200E-01, 0.14479900E+01, -.29700500E+03, 0.81398400E+02, -.30767400E+02, 0.24702200E+03, -.73229900E+02, 0.14313500E+02, -.54952700E+02, 0.62020100E+02, 0.40142700E+02, -.13891400E+03, -.60547200E+02, -.15551200E+03, -.30524900E+02, 0.30234600E+02, 0.95220800E+02, 0.14960700E+02, 0.55960500E+01, -.64589400E+02, 0.13867900E+03, -.40183100E+02, -.66246100E+02, -.61921500E+02, -.56240700E+02, -.12613200E+04, 0.63152000E+03, 0.55625400E+03, 0.63999900E+03, 0.17345100E+03, 0.18557300E+03, 0.17759200E+03, -.13275700E+02, 0.37210500E+03, 0.11011400E+03, 0.74824100E+03, 0.38277600E+02, -.49688000E+02, 0.20756300E+03, -.19668100E+02, -.83714300E+02, -.61088300E+01, -.17618400E+02, -.62883600E+02, -.11107700E+03, -.17696900E+00, 0.35796300E+02, -.54917700E+01, 0.46397400E+01, 0.20786000E+03, 0.25916800E+01, 0.76098900E+02, -.32743300E+02, 0.63243400E+02, 0.17189200E+02, -.19871200E+02, -.33607100E+02, 0.17257000E+03, -.88648500E+02, 0.64159400E+02, -.28040400E+02, 0.48734900E+02, -.22128700E+02, 0.37033300E+01, 0.26214500E+02, -.17521700E+02, -.15732500E+02, 0.22522600E+02, 0.12745100E+03, 0.26446700E+03, -.12501200E+03, -.26796100E+03, -.13482700E+03, -.77122000E+02, -.97670100E+02, -.26984900E+00, -.29995600E+02, -.13254100E+03, -.69978100E+02, 0.14240300E+03, 0.46233100E+02, 0.59625300E+01, -.35952200E+02, -.17512200E+02, 0.29482400E+02, 0.32028100E+01, 0.77419100E+02, 0.91998600E+02, 0.10034100E+03, -.30160400E+02, 0.40384300E+03, 0.13005300E+02, 0.23231000E+01, -.12697900E+03, -.12037500E+03, -.11569800E+02, 0.32912600E+02, -.13636000E+01, 0.71133900E+01, 0.15646700E+01, 0.39141300E+01, -.13181100E+01, -.55149100E+01, -.24642900E+01, 0.12025800E+02, 0.89462900E+01, -.55906200E+01, 0.11599200E+03, 0.19476100E+00, -.13675300E+03, 0.22451200E+02, -.57309300E+01, 0.42802600E+01, -.16518900E+03, -.31427200E+01, -.30396200E+01, -.13731000E+01 },
        { -.34534600E+01, 0.54896800E+00, 0.12444600E+01, 0.19158500E+01, 0.15593400E+01, 0.46371300E+00, 0.17360600E+01, -.43024500E+01, -.32817000E+00, 0.51437900E+00, -.30856300E+00, 0.16576200E+00, 0.67608000E+00, -.17081300E+00, 0.13261700E+00, 0.46597900E+01, -.17095300E+01, 0.28225800E+00, 0.63599400E+00, -.34507700E+00, -.79796300E+00, -.45208800E+00, 0.14634900E-01, -.57265700E+00, -.64105900E-01, -.10474900E+00, -.61722800E+00, -.18216900E+01, 0.92634800E+00, -.66241700E-01, -.21510300E+00, -.42718200E+00, -.47898100E+00, -.10726600E+00, -.56549000E-01, -.29184400E-01, 0.59318900E-01, 0.12148500E+01, 0.67830100E-01, 0.97155000E+00, 0.47392300E+00, -.18068300E+00, -.16378300E+00, -.10176200E+00, -.11335200E+00, -.69457000E-01, -.44804100E-01, -.31544500E-02, -.81331000E+00, 0.20204400E-02, 0.15184900E+00, -.23500000E+00, 0.16557700E+00, -.93875600E+00, 0.52122300E-01, -.99200700E+00, -.62304300E+00, 0.16947600E-02, -.21897000E-01, -.27725700E+00, 0.33559400E-01, 0.36963400E+00, -.55514300E+00, 0.27617600E+00, -.28895700E-01, 0.62660400E+00, 0.14116400E+01, 0.12230400E+00, -.94032300E+00, 0.84005100E-02, -.53601200E-01, -.19827200E+00, -.20402900E+01, -.31614400E+01, 0.70608200E+00, -.85502100E+00, 0.11586200E+00, -.85355300E+00, 0.35057800E+00, -.14813800E+00, -.10843000E+00, 0.14986400E+00, -.87745600E-01, -.20996500E+00, -.36749500E+00, -.31744700E-01, 0.40465000E+00, -.20808900E+00, 0.16877200E+00, 0.47252700E-01, -.25718700E-01, -.71295000E-03, 0.90648600E+00, -.69532100E-01, -.10969600E+01, -.28425500E+00, -.26366200E+00, -.23294400E+00, 0.32710400E-01, 0.11774100E+00, -.28113300E-01, -.86872800E-01, -.43792700E-01, 0.11773400E+00, -.15603600E+00, -.33142200E+01, 0.14795900E+00, -.36630700E-01, 0.13429800E+00, 0.51351400E+00, -.67277400E-01, -.19058100E-01, 0.71484700E+00, -.11034700E-01, -.29484400E-01, 0.27727000E+00, -.14969200E+00, 0.56459700E+00, -.15783200E+01, 0.24986500E+01, -.40838400E+00, 0.10115700E+00, 0.16683500E+00, -.20748900E+00, 0.77096400E-01, -.71050000E-01, 0.53464900E-01, -.82374900E+00, 0.22659000E+00, -.10169100E+00, -.69511500E+00, 0.32387600E+00, 0.64110800E+00, -.43877000E+00, 0.28104300E+00, 0.38408400E-01, -.89371900E+00, -.50083200E+00, -.24454400E-01, 0.16561000E+01, 0.43843100E+00, 0.17146800E-01, -.34937200E+00, 0.28228100E+00, 0.58910100E-01, 0.44687000E+00, -.41200900E-01, 0.15475900E+00, 0.10548000E+00, -.11172900E+00, 0.33473200E+00, 0.15241500E-01, -.12129600E+00, -.14344900E+01, 0.35300100E-02, 0.92053100E+00, -.51501100E-01, -.26021000E-02, -.88939700E+00, 0.26675000E-01, -.31715000E-01, -.95384400E-01, -.11713700E+00, -.21680100E+00, -.13498700E+00, 0.33567100E+00, 0.34045500E-01, 0.84449600E+00, 0.13335700E-01, 0.71167800E+00, -.25829500E+00, -.20178900E-01, 0.97385100E-01, -.60108800E-01, -.18006600E+00, 0.94816000E-01, 0.24264400E+00, -.16410600E-01, 0.28515200E+00, -.48268800E-01, -.61194600E+00, -.33756000E+00, 0.19236500E+00, -.63451200E+00, 0.21076700E+00, -.35380800E+00, -.13999200E+00, 0.83907300E+03, -.40396900E+03, -.11494200E+03, -.43089000E+03, -.83046900E+02, -.27120200E+02, -.17001500E+03, 0.82069900E+02, -.23853800E+03, -.50699600E+02, -.15541300E+03, 0.38398600E+03, -.18963400E+03, -.71478300E+02, -.19311000E+03, -.48388800E+02, -.37694000E+02, -.47525200E+02, -.43275800E+02, -.12017100E+03, -.47448200E+02, -.16304200E+03, 0.24887300E+03, -.12102400E+03, -.19332200E+03, -.12503000E+03, -.14944300E+03, -.16411600E+03, 0.13348000E+03, 0.95062600E+01, -.13855800E+03, -.88734600E+02, -.30980900E+03, -.11881400E+02, 0.18931800E+00, 0.29949500E+03, 0.54164500E+01, -.17351700E+02, 0.21257400E+02, -.33045800E+02, -.25453500E+02, -.21182300E+01, 0.80384100E+01, 0.16205200E+03, 0.10549400E+02, -.43678200E+01, 0.46182300E+02, -.52726900E+01, -.51133700E+02, -.15954900E+02, 0.25554400E+01, -.37804800E+02, -.83284200E+01, -.56419500E+01, -.18170300E+03, 0.76229000E+02, -.34406900E+02, 0.34910000E+02, -.38008200E+02, -.48945600E+01, 0.26431100E+02, -.60803800E+02, 0.30413900E+02, 0.22338600E+02, 0.75311900E+01, 0.21482400E+01, 0.27452700E+02, -.12323500E+02, 0.76496800E+02, -.13541800E+02, 0.45938600E+02, 0.20027300E+02, -.15039600E+02, 0.61822300E+01, 0.48206200E+01, 0.22689200E+01, 0.16543900E+02, 0.36741300E+03, -.16941900E+03, -.11243000E+03, -.18337200E+03, -.12844100E+03, -.48078400E+02, 0.63549200E+02, -.60957200E+02, -.11706100E+03, -.39866300E+02, -.34133100E+03, 0.31130300E+02, -.10308200E+02, -.23832500E+02, -.19978600E+02, 0.15060500E+02, -.10493400E+02, 0.10254200E+02, 0.97463600E+01, 0.11371600E+02, -.11616100E+02, -.56618900E+01, 0.20304200E+02, 0.12488500E+02, -.13816700E+02, 0.75536900E+01, 0.66954500E+01, 0.16853600E+02, 0.59497600E+01, -.24249100E+02, -.10779200E+02, 0.11041600E+02, -.47108900E+01, -.16976400E+02, 0.88546700E+01, 0.54402100E+01, -.64517500E-01 },
        { 0.77214300E+01, -.22174400E+01, -.10174200E+01, 0.16484500E+01, -.20971500E+01, 0.18798500E+00, 0.16654600E+01, -.70579300E+01, 0.18204100E+01, -.11019700E+01, -.14362100E+01, -.74034300E+00, -.95250500E+00, 0.34840900E+00, 0.11336400E+01, 0.46637000E+01, 0.12241200E+01, 0.13069300E+01, 0.17410900E+01, -.35036700E-01, -.39339800E+01, -.12678100E+01, 0.70082300E+00, -.10204000E+01, 0.13469300E-01, -.82320900E-02, -.86382800E+00, -.16476900E+01, 0.42541800E+01, 0.86101800E-01, 0.77357200E+00, 0.28037000E+01, -.11700200E+01, -.23217000E+00, -.85122000E+00, 0.21853300E+00, -.54029600E-01, -.23364100E+01, 0.46243700E-01, -.81219700E+00, -.34170600E+01, -.14560000E+00, 0.30623800E+00, -.49687500E-01, 0.43584400E-01, -.49833700E+00, 0.14733800E-01, -.59766900E-02, -.33335000E+01, 0.23167400E+00, -.63340700E+00, 0.14272600E+01, -.15904200E+01, 0.31579900E+01, -.68095600E-01, 0.16799800E+01, 0.11514000E+01, -.99038600E-01, -.52290400E-01, 0.13558000E+01, 0.18586800E+00, -.63770400E+00, 0.13682200E+00, 0.10938500E+00, 0.60795100E+00, 0.20417500E+01, -.46732000E+00, 0.31204100E+00, -.34207000E+01, -.11086100E+00, -.52096000E+00, -.46537800E+01, -.59090400E+00, -.12803000E+01, 0.11405500E+01, -.37665900E+00, 0.46054400E-01, 0.34134200E+00, 0.26243300E+00, -.54379500E-01, -.64034900E-01, 0.14675900E+00, 0.93492400E-01, -.37691400E+00, -.16592700E+00, 0.25112300E+00, -.28862300E+00, -.14871900E+00, -.36702500E+00, -.21384800E-01, -.36928000E+00, 0.11124100E-02, -.45485400E-01, 0.12693400E+00, -.51339700E+00, -.23444900E+00, -.84749500E-01, 0.27569700E+00, -.96435500E-01, 0.36655200E-01, -.68948200E-01, -.72630200E-01, -.21068100E-02, 0.20372500E+00, 0.15447800E-01, 0.13757400E+01, -.36240500E-01, -.20824200E+00, 0.46124300E-01, 0.87238200E-01, -.54125300E+00, -.47823600E-02, -.86008400E+00, 0.16339600E-02, 0.27888800E+00, -.39801700E+00, -.12603700E+00, -.21813000E+00, 0.15210800E+01, -.99322800E-01, 0.26365400E+00, -.50591300E-01, -.42137300E-02, 0.22762800E+00, -.60889700E-01, 0.96260700E-01, -.17857600E+00, -.26595700E+00, -.56421300E-01, 0.80640500E-01, 0.18780200E+00, -.10570700E+00, -.76154800E+00, -.26759100E+00, -.48995000E+00, -.43654600E-01, 0.87136700E+00, 0.72890300E+00, -.28909300E+00, -.66445400E+00, -.41787900E+00, -.46260600E+00, -.33620900E+00, -.53298300E+00, -.67664700E-02, 0.78784300E+00, 0.43112200E-01, 0.39713200E+00, -.21104200E-02, -.29370300E+00, 0.19448500E+01, -.71258300E-01, -.15299600E+00, 0.68410900E+00, 0.11922400E+00, -.24165100E+00, 0.80296800E-02, -.42768200E-02, 0.86854600E+00, 0.37915900E+00, 0.10218800E+00, 0.19994200E+00, -.35679100E-01, -.11633600E+00, 0.35402000E+00, -.24873300E+00, 0.29813500E-01, -.94178700E+00, 0.29384500E-01, 0.41241600E+00, -.18409700E+00, 0.89316200E-01, 0.10309200E+00, 0.21719800E+00, 0.35631000E+00, -.69602300E-01, -.25341800E+00, 0.42403500E-01, 0.16983200E+00, 0.57293000E-01, 0.39866800E+00, 0.27207900E+00, -.11894600E+01, -.26052800E+00, 0.82168400E-01, 0.31636400E+00, -.20211500E-01, -.37790300E+00, 0.13951400E+03, -.11248600E+03, -.15768900E+02, -.13379000E+02, -.31838800E+02, 0.33152500E+02, 0.24220900E+02, 0.31013200E+01, -.33361700E+02, 0.38043100E+02, -.46808200E+02, 0.21146700E+02, -.59039200E+02, 0.22582700E+02, -.15126300E+02, -.27330900E+02, 0.33451200E+02, -.34077700E+01, 0.13640200E+02, -.31148200E+02, 0.38911300E+02, -.12613300E+03, 0.66054100E+02, 0.46843000E+02, 0.66631900E+02, 0.11087500E+02, 0.67057900E+01, 0.20756900E+02, 0.98052900E+00, 0.41335300E+02, -.18223500E+01, 0.72661400E+02, -.86238900E+01, 0.16389700E+01, 0.45698100E+02, 0.39808000E+01, -.53027500E+01, -.19401100E+01, -.56490600E+00, -.10145000E+02, -.73474800E+01, 0.31551500E+01, 0.10961300E+02, 0.62799000E+02, -.31119100E+02, -.16700000E+02, -.31456000E+02, 0.36388700E+01, -.85884600E+01, -.34310200E+01, 0.15723800E+02, -.13116800E+02, -.68239800E+01, -.48211000E+02, -.20212500E+02, 0.11852300E+02, 0.80046000E+01, 0.11803400E+02, 0.69785600E+01, 0.14497600E+02, -.81111200E+01, -.19580100E+02, -.99170000E+00, 0.16944000E+02, -.46230000E+02, 0.59269400E+02, -.29102400E+02, -.72757300E+02, -.30609000E+02, 0.29339600E+00, -.37623200E+01, -.98060200E+01, -.38598500E+00, -.32148200E+02, 0.43559500E+01, -.28820400E+02, -.50978500E+02, 0.32525800E+02, -.54427800E+02, 0.28244900E+02, 0.19085800E+02, -.13430300E+02, 0.35627100E+02, 0.12982000E+02, 0.37755200E+02, -.11057100E+02, 0.46319900E+01, -.18109400E+01, -.11810200E+01, -.24517700E+02, -.24779200E+02, -.45250300E+01, 0.84410900E+01, -.60278900E+00, 0.47114700E+01, 0.44468600E+00, 0.37133000E+00, -.10525200E+01, -.59397600E+01, 0.11466100E+01, 0.44816800E+01, 0.44897800E+01, 0.35797600E+01, 0.24057000E+02, 0.25713600E+01, -.22934700E+02, 0.47356400E+01, 0.80704400E+01, -.24786900E+01, -.78955000E+01, 0.36901000E+01, 0.43548500E+01, 0.14315400E+01 },
        { 0.46490800E+01, 0.33430000E+00, 0.20192700E+00, 0.39260900E+00, -.19156100E+01, -.74922100E+00, 0.85889000E+00, -.10099600E+02, 0.56179300E+00, -.23473300E+01, -.14169000E+01, -.16688300E+00, -.51270400E+00, 0.28234600E+00, -.69390800E-01, 0.47660000E+01, 0.50177000E+01, 0.28755700E+01, 0.13321200E+01, -.17869300E+00, -.26140700E+01, -.74070600E+00, 0.92799500E-01, -.17948100E+01, 0.11876100E+00, -.32195000E-01, -.13103200E+01, -.36777000E+01, 0.39398100E+01, 0.20527500E+00, 0.32796900E+00, -.25588900E+01, 0.21727900E+00, 0.25252800E+01, -.55176500E-01, 0.69454000E-01, 0.77034200E-01, -.82104600E-01, -.25880500E+00, 0.11946400E+01, -.22374900E+01, 0.67665100E-01, -.55955400E-01, 0.25386700E+00, 0.74669400E+00, 0.66260100E+00, 0.81793200E-02, 0.15294100E+00, 0.10784500E+01, -.30644600E+00, 0.21952400E+01, -.17365800E+01, 0.12188400E+01, -.47944700E+01, -.40706700E+00, -.37240300E+00, -.16112300E+00, -.34933200E-01, 0.15390700E+00, -.91118000E+00, -.35514700E+00, 0.14369900E+01, 0.79382000E-01, -.74277200E-01, -.47821200E+00, -.74665400E+00, -.85422800E+00, -.17206100E+00, 0.75005700E+00, 0.62804800E-02, 0.17714200E+00, 0.30329800E+01, 0.12223000E+01, 0.88092500E+00, -.80590800E+00, 0.33160100E-01, -.36156500E+00, 0.16886600E+01, -.19108000E+00, -.38603400E-01, 0.89570600E-01, -.15348700E+00, 0.27384300E+00, -.11975100E+00, 0.17261600E+00, -.53410600E-01, -.59982100E-01, 0.10359000E+00, -.52828600E-01, 0.23326800E-01, -.54468200E+00, 0.22216000E-02, 0.77595900E+00, -.23075100E-01, 0.16937400E+01, 0.13012500E+01, 0.97295600E+00, -.42664800E+00, 0.58264700E-01, 0.25167700E+00, 0.47425700E-01, -.14270100E+00, 0.72208800E-02, -.12989900E-01, 0.24998100E+00, -.18170100E+01, -.43988600E+00, 0.20220500E+00, -.21000900E+00, 0.52606200E+00, -.93920000E-01, -.42622400E-01, 0.57865100E+00, 0.14146900E-01, 0.26341800E+00, 0.12051200E+00, 0.20097200E+00, 0.18996600E-01, -.89444800E+00, -.64041700E+00, -.45499200E+00, 0.61281400E-01, -.14529200E+00, 0.26216000E+00, 0.33860300E-01, 0.23067200E+00, 0.75968300E-01, 0.75672500E-01, -.17076400E+00, -.26891400E+00, 0.15227300E+00, -.23530600E+00, -.62648900E+00, 0.11966300E+01, -.69998600E-01, -.36947400E-02, -.91680300E+00, 0.17802300E+00, -.12199700E+00, -.50237500E+00, 0.96402800E+00, 0.60697400E-01, 0.12179900E+01, -.47094900E-01, 0.21110000E-01, 0.62940300E+00, 0.30254100E-01, -.19244100E+00, 0.11819700E+00, -.82714000E-01, 0.12902000E+01, -.98821600E-01, -.79195800E-01, -.73626800E+00, 0.74207800E-01, 0.94845800E+00, 0.25673500E-02, -.40779600E-02, -.44082800E+00, -.58263800E-01, 0.19477500E+00, 0.36391900E+00, -.10440300E+00, -.16339300E+00, 0.87326700E-01, 0.34472700E+00, 0.44258200E-01, -.49230600E+00, 0.33987800E-01, -.12510100E+01, 0.84781800E-01, -.63491600E-01, -.17575700E+00, 0.36070100E+00, 0.44523200E+00, 0.27801400E+00, 0.41543400E+00, 0.49763300E-01, -.12808400E+00, -.52474300E-01, -.58604900E+00, 0.27448700E+00, -.48767400E+00, 0.63692900E-01, 0.98649700E-01, 0.22044100E+00, 0.29713600E+00, -.15981900E-01, -.25012000E-01, -.28284100E+03, 0.14582800E+02, -.48695900E+02, -.67088600E+02, 0.39273300E+02, -.21193800E+02, 0.76282600E+02, -.60485500E+02, 0.88823100E+02, 0.64864300E+02, -.39977200E+02, -.17543000E+03, -.32218500E+02, -.37546300E+02, -.49487800E+02, 0.90036300E+01, 0.21064400E+02, 0.30448900E+02, -.38268100E+02, 0.51052400E+02, 0.29028900E+03, -.14368400E+03, -.18321600E+03, -.14649600E+03, -.75187400E+02, -.76088100E+02, -.47091400E+02, 0.13287300E+02, -.53372000E+02, -.75828400E+02, -.17943100E+03, 0.51988700E+02, -.10646600E+02, -.76287900E+02, -.25662600E+02, 0.43221900E+02, -.73258400E+01, 0.69794900E+01, 0.62679600E+02, 0.40876700E+02, -.10300200E+00, -.26395100E+01, 0.24070700E+02, -.12986200E+02, -.96138200E+02, -.12002200E+02, -.24555500E+02, 0.94843000E+01, -.25317400E+02, 0.41014100E+01, 0.70734300E+01, 0.91003200E+01, -.73676000E+02, -.17708000E+02, -.19278900E+01, 0.53474200E+02, 0.78284000E+01, 0.35393500E+02, 0.13106500E+02, -.32772600E+01, -.22609200E+02, 0.11283100E+02, 0.16919500E+02, -.87142000E+02, -.58388000E+02, 0.24108900E+02, 0.36291000E+02, 0.29514900E+02, 0.44355600E+02, 0.35404900E+02, -.14683000E+02, -.18045900E+02, 0.10093200E+02, 0.43108300E+02, -.30280600E+02, -.12874200E+02, -.94123700E+01, -.46707800E+02, 0.58694900E+01, -.29789000E+02, -.26242400E+02, 0.22376700E+02, 0.13418300E+02, -.34759600E+01, -.19736700E+02, -.29079300E+03, -.12432100E+01, -.48222900E+01, 0.23201800E+02, 0.23753200E+02, 0.36009200E+01, -.48830100E+01, -.95525000E-02, 0.54218100E+01, 0.39363700E+01, -.41611600E+01, -.10600600E+01, -.90045900E+00, 0.49352300E+01, -.46094500E+01, 0.47353900E+01, 0.11099700E+02, -.22808900E+02, 0.56245500E+01, 0.26590200E+02, -.76614700E+01, 0.17370200E+02, -.66301800E+01, 0.50542200E+02, 0.66825700E+01, 0.43939400E+01, 0.33200600E+01 },
        { -.27741900E+01, -.97644500E+00, 0.55765300E+00, 0.14721500E+01, 0.19539400E+01, 0.85159300E+00, 0.15551800E+01, -.19241900E+00, -.43380800E-01, -.72988100E+00, 0.41760800E+00, 0.28019900E+00, 0.48911800E+00, 0.42636500E-01, -.38048100E+00, 0.13567500E+02, 0.17972300E+01, 0.14792800E+01, 0.13139900E+01, -.42693400E-02, -.13646900E+01, 0.24373500E-01, 0.40935800E-01, 0.12991200E+01, -.77576800E-01, -.76036900E-01, -.14570300E+00, 0.13164800E+01, 0.42669700E+00, 0.59616900E-01, -.62231600E+00, -.36649600E+00, 0.14145500E+00, 0.29090800E+00, -.29845700E-02, -.91975000E-01, 0.69944500E-02, 0.36655700E+00, -.20646500E+00, 0.12700800E+00, 0.54622000E+00, -.20762400E+00, -.42257300E-01, 0.84160500E-01, -.18159400E+00, -.40021500E-01, 0.14853200E-01, -.35019500E-02, -.35296300E+00, -.19272700E-01, 0.35790300E-02, -.22948600E+00, 0.39131600E+00, 0.14996300E+00, -.97306100E-01, 0.51112900E+00, 0.17092700E+00, -.86049900E-02, 0.99912800E-02, 0.22973000E+00, -.53996000E-02, 0.36389200E+00, 0.18682700E+00, -.18935600E+00, 0.24359300E+00, -.17030500E+00, -.84565200E+00, -.92085900E-01, -.54307100E+00, 0.80208500E-03, -.14293300E-01, -.20667200E+01, 0.25706500E+00, 0.88292800E+00, -.81908000E-01, 0.26981300E+00, -.75092000E-01, 0.58730500E+00, 0.87216900E-01, -.49439100E-02, 0.50389300E-02, -.44868900E-01, -.79032700E-01, -.82619300E-01, 0.60856100E-01, 0.13891600E+00, 0.31020500E+00, 0.37058800E-01, 0.98514600E-01, 0.34640500E-01, 0.78843800E-01, 0.82616700E-04, 0.22531700E+00, 0.63736100E-01, 0.61047400E-01, 0.39143400E+00, 0.25151800E-01, 0.18824600E+00, -.34643800E-01, 0.93274500E-01, 0.99781000E-01, -.30829600E-01, 0.65818800E-02, 0.87723800E-02, 0.84886000E-01, -.19121100E+01, -.44261600E+00, -.13645700E+00, -.46254100E-01, 0.16776800E+00, 0.89999500E-01, 0.19953100E-01, -.77393000E+00, 0.65016500E-02, 0.11156600E+00, -.53715900E-01, 0.27161300E+00, -.82566700E-01, -.12325700E+00, 0.28490700E+00, -.70542000E-01, 0.48760900E-01, 0.14472900E+00, -.12021900E+00, 0.71323700E-01, -.11882000E+00, -.77160900E-01, -.47940600E+00, -.45248600E+00, 0.18171700E-01, -.62486200E-01, -.92880700E-01, 0.26729500E+00, -.28602000E-01, 0.78161200E-01, 0.44288500E-02, 0.47857100E-01, -.21482800E+00, 0.12673700E+00, 0.10817100E+01, -.63878100E+00, -.17441400E+00, -.63371900E-01, -.13354800E-01, 0.38800600E-01, -.65538300E+00, -.24524300E-01, 0.44024900E+00, 0.15587600E-01, -.45270700E+00, 0.20504600E+01, 0.90822200E-01, -.46296200E-02, 0.85136400E-01, -.44660900E-01, 0.10520700E+00, -.13292800E+00, -.14604900E-03, -.18394300E+00, -.10471700E+00, 0.11473100E+00, 0.10462600E+00, 0.23981200E-01, -.31631900E+00, -.80752800E+00, 0.12349700E+00, -.80360700E-01, -.10011900E+01, 0.13330500E-01, 0.32673700E-01, -.12094100E-01, 0.11762400E+00, -.76502400E-01, -.12250500E-01, 0.43478500E+00, 0.54221500E-01, -.26292100E+00, -.17983300E-03, 0.92034100E-03, -.42296800E-01, -.15979700E+00, 0.33018100E+00, -.40257500E+00, 0.57318300E-01, -.12387100E-01, -.49625400E+00, 0.74091000E-01, -.17740100E+00, 0.66789700E-02, -.23880300E+00, 0.89384800E+01, -.39992200E+01, 0.43138100E+01, -.13448400E+02, -.46778800E+02, -.27230800E+02, 0.56019800E+01, 0.41273100E+01, 0.14424300E+03, -.85038700E+02, -.31855700E+02, -.72233400E+02, 0.28700900E+01, 0.59689200E+01, -.14496200E+02, -.13204900E+02, -.10113000E+03, 0.12594900E+02, -.75849300E+02, 0.17624500E+03, -.86088100E+02, -.14864200E+03, -.89397700E+02, -.40230300E+02, -.76182600E+01, -.10624400E+03, -.34426800E+02, -.20164100E+02, -.33257600E+02, -.37547400E+02, 0.25653400E+02, -.46569500E+01, 0.19880600E+02, -.13040300E+02, 0.21936700E+02, 0.17110600E+00, 0.14845600E+01, 0.25716100E+02, 0.17033900E+02, 0.69013500E+00, -.98952700E+01, -.92359200E+02, 0.43767700E+02, 0.36691900E+02, 0.46205800E+02, -.28080500E+02, 0.13847000E+02, -.12806100E+02, -.28877400E+02, 0.39535700E+02, 0.45077200E+01, 0.52940200E+02, -.15363600E+02, 0.14890500E+01, 0.37894100E+02, 0.69271100E+01, 0.17176200E+02, 0.75818800E+01, -.87656200E+01, -.43909500E+02, 0.15100100E+02, 0.49970500E+01, -.94686900E+02, -.89840700E+02, 0.43557000E+02, 0.78167700E+02, 0.45267800E+02, 0.88907200E+01, -.80874500E+00, 0.19172000E+02, -.45021600E+01, -.17919400E+02, 0.75793800E+01, 0.36820500E+02, 0.28327800E+02, -.19899500E+02, 0.47558000E+02, -.14641400E+02, -.13359800E+02, -.39794900E+02, 0.37099500E+02, 0.69329500E+02, -.10186300E+02, -.51718700E+02, -.26430000E+02, 0.29429100E+01, -.43886700E+01, 0.80233800E+01, 0.89954000E+01, -.24794200E+01, 0.24363400E+00, 0.29025600E+01, 0.14261800E+01, 0.31317400E+01, -.53400800E+01, -.19021000E+01, 0.32212400E+01, 0.37746000E+01, 0.18866300E+01, 0.13053700E+01, 0.31098700E+01, -.84565200E+01, 0.25434700E+01, 0.87052500E+01, 0.13486700E+00, 0.11566900E+02, -.97298800E+00, 0.18037300E+02, 0.48310300E+01, 0.14304600E+01, -.33176500E+01 },
        { -.82144000E+01, -.35700500E+01, 0.32835400E+01, 0.54916200E+01, 0.26695700E+01, 0.26033800E+01, 0.35760800E+01, -.14023300E+02, -.43013300E+00, -.32046100E+01, -.23321400E+01, 0.11409000E-01, -.47155900E+00, -.40025700E+00, -.31790700E+00, 0.32488200E+01, -.28400100E+01, -.27023800E+01, 0.10870100E+00, 0.72106900E+00, 0.48352500E+01, -.31141200E+00, 0.18848400E+00, -.22763400E+00, -.44694200E-01, -.18078400E-01, 0.18615900E+00, -.14210800E+01, 0.20309400E+01, 0.12810200E+00, -.16734800E+01, -.27213200E+01, 0.12323600E+01, -.73969100E+01, -.13509000E+00, -.46812100E+00, 0.11188300E+00, 0.30539200E+01, -.12364300E+00, 0.15686800E+01, 0.39353700E+01, -.86393300E+00, -.46896300E+00, -.56858600E+00, -.14128900E+01, 0.77311300E+00, -.11544100E+00, -.89103900E-01, -.20664300E+01, -.26556600E+00, -.13849700E+00, -.36742200E+00, 0.28772200E+00, -.32649000E+01, -.77566500E+00, 0.62748400E+00, 0.19064500E+00, -.53242200E+00, -.11083900E+00, -.78383700E+00, 0.26782500E-01, -.78865300E+00, 0.42150500E+00, -.61275200E+00, -.32920100E+00, -.19180500E+01, -.24985300E+01, 0.10792400E+00, 0.92616700E+00, 0.30386800E-01, 0.23984200E-01, 0.41455900E+01, 0.11463700E+01, 0.42777100E+01, -.18886200E+01, -.26633600E+01, 0.97194900E+00, 0.51759800E+00, 0.47001900E+00, 0.95233900E-02, 0.90660300E-01, -.28495800E-01, -.28605200E-01, 0.54523500E+00, 0.10450600E+00, -.76858800E+00, -.40136200E+00, -.29481300E+00, 0.76080400E+00, -.32286800E-01, 0.71493600E+00, 0.38391000E-02, 0.75349200E+00, -.16705400E+00, 0.75199600E+00, 0.28215900E+00, 0.26518400E+00, -.89341500E+00, 0.45275600E-01, -.53591700E+00, 0.18617000E+00, -.85511800E-01, 0.18900000E-01, 0.37968400E+00, 0.56994000E-01, -.49498900E+01, -.23796300E-01, -.59920700E+00, -.98425900E-01, 0.57842000E+00, -.27156700E+00, -.47827500E-01, 0.25092900E-01, 0.29853200E-01, -.18460800E+00, -.11387200E-01, 0.12762800E+00, -.20832600E-01, -.51181400E+00, 0.46803000E+00, 0.97092900E+00, -.34051000E-01, -.17754600E+00, 0.55266800E+00, -.77478200E-01, 0.96823000E+00, -.61092200E+00, -.23541200E+01, 0.12416900E+00, 0.30834600E+00, 0.88672700E+00, 0.16521600E+00, 0.33579100E+01, -.85518500E+00, 0.50686400E+00, 0.48219100E-01, -.11865800E+01, -.61320500E+00, 0.50485900E+00, 0.13439800E+01, 0.76458800E+00, 0.97617700E+00, -.38156500E+01, 0.84397800E+00, 0.30015900E+00, -.33936000E+00, 0.68378100E-01, 0.25369700E+00, -.54327700E-01, -.32144400E+01, -.11293800E+02, -.13706100E+01, -.10479600E+01, -.14058900E+01, -.55682200E-01, 0.79555100E+00, -.66179000E+00, -.80972300E-02, 0.21742900E-01, 0.16626400E+01, -.33736700E+00, -.22881900E+00, -.47740200E+00, -.85139500E+00, 0.16441100E+01, 0.17938300E+01, 0.38706000E+00, 0.33981800E+01, 0.23636400E-01, 0.49256600E+00, -.44662100E+00, -.18120000E+00, 0.61269600E+00, -.49104400E+00, 0.73381000E+00, 0.81844600E+00, 0.11351300E+01, 0.65385500E-02, -.57639900E+00, 0.83972300E-01, -.11937800E+01, -.64131000E+00, 0.14518100E+01, 0.11415400E+01, 0.11765300E+00, -.30614100E+00, -.25486300E+00, -.20680600E+00, 0.29194800E-01, -.92176400E+00, -.38633500E+00, -.85852000E+02, -.15501400E+03, 0.10467500E+03, 0.15974700E+03, 0.22462100E+03, -.16290800E+03, 0.18958000E+03, 0.77811600E+02, -.44350000E+02, -.13909100E+03, -.35933100E+02, 0.40755300E+02, -.31261400E+02, 0.32777300E+02, 0.13316600E+03, 0.66358400E+02, -.58787800E+02, 0.11100000E+02, -.41769100E+03, 0.21677700E+03, 0.13539500E+03, 0.21943700E+03, 0.37109600E+02, -.43769900E+02, 0.13598500E+03, 0.88872300E+02, 0.18871500E+03, -.50829900E+02, 0.15613600E+03, 0.14789000E+03, -.67329000E+02, 0.14940700E+03, -.74197600E+02, 0.10945400E+02, -.40067900E+02, 0.28806700E+02, 0.98534400E+02, -.66101000E+01, -.13869600E+02, -.83102600E+02, -.10793200E+03, 0.53065600E+02, 0.19478700E+03, 0.53799900E+02, 0.25525000E+02, 0.14604200E+02, -.10549300E+02, -.50332500E+02, 0.41931000E+02, -.59450700E+01, -.11165100E+03, -.90731000E+02, 0.39092900E+02, -.27990900E+02, 0.49749300E+02, 0.33693200E+02, 0.87779100E+01, 0.92405500E+01, -.27323300E+02, 0.63692700E+02, -.69403400E+01, -.67876100E+02, 0.73722300E+02, -.44900600E+02, -.76356600E+02, -.39639400E+02, 0.36474600E+02, 0.42555000E+02, -.67560200E+02, -.39232400E+02, -.48243100E+02, 0.56479800E+02, 0.22788700E+02, 0.14072700E+03, -.67553700E+02, -.16336000E+03, -.66413300E+02, -.14828800E+03, -.61853900E+02, 0.73312300E+02, 0.10177800E+03, 0.52705100E+02, -.94464900E+02, -.15449200E+03, 0.19239600E+02, -.16753700E+02, -.57078400E+02, -.59746900E+02, 0.63041000E+01, 0.79820600E+01, 0.65849800E+01, 0.22045200E+02, 0.13000200E+02, -.14001800E+02, -.16904200E+02, -.54535900E+00, 0.89128500E+01, -.54932500E+01, 0.19863700E+02, 0.11203100E+02, 0.56878000E+02, 0.92931300E+01, -.54398700E+02, 0.37540000E+00, 0.29444100E+02, -.12643800E+01, 0.23339600E+00, 0.23074500E+02, 0.10827300E+02, 0.50734000E+01 },
        { -.75607200E+01, -.38374700E+01, -.57401700E+01, -.87884800E+00, 0.14011800E+01, 0.33328900E+01, 0.37439100E+01, -.53910000E+01, -.34662600E+00, -.18322200E+01, 0.14113900E+01, 0.15845700E+01, 0.20145800E+01, -.14357700E+01, -.14795200E+01, 0.19000000E+02, 0.23884500E+01, 0.25943700E+01, 0.32467600E+01, -.82830500E+00, -.20735400E+01, 0.34750800E+00, 0.14264500E-01, 0.23709100E+01, -.43985900E+00, -.19997700E+00, -.39897600E+00, 0.33672100E+01, 0.30589800E+00, -.22860200E-01, -.56513600E+00, 0.91090100E+00, -.24962600E+00, -.52975600E+00, 0.48207300E-01, -.17664600E+00, -.32957900E-01, -.77288200E-01, -.17622000E+00, -.73514000E+00, 0.27023700E+01, 0.60080900E+00, -.25106900E-01, 0.46929400E-01, -.14838700E+01, 0.74488000E+00, -.88700300E-01, -.12630300E+00, -.34959100E+01, 0.28024600E+00, -.17248300E+01, -.50441700E+00, -.18395700E+00, 0.12957400E+01, -.23350000E+00, 0.11592400E+01, 0.21031200E+00, -.41407600E-01, -.92378300E-01, 0.95928900E-02, 0.40499300E+00, -.36285300E+00, -.64132900E-01, -.93109700E+00, -.15849300E+01, -.83941800E+00, 0.16010300E+01, 0.40148000E+00, -.12466600E+00, -.62039800E-02, -.25897300E-01, 0.59448500E+01, 0.12752000E+01, 0.11369100E+01, -.14503700E+01, -.23065300E+01, 0.24855400E+00, 0.13865100E+00, -.16064000E+01, -.83891800E+00, 0.17815300E-01, 0.33565600E-01, 0.81285400E+00, 0.95664000E+00, -.21039400E+00, 0.25937700E+00, -.23008400E+00, 0.15975200E+00, -.19015700E+01, 0.15533400E+00, -.61044400E+00, 0.71393500E-02, -.33550200E+00, 0.91688800E-02, -.41962300E+00, -.86732500E+00, 0.64798700E+00, 0.78510200E+00, -.32270900E+00, 0.11705900E-01, 0.12843000E-01, -.25670200E+00, 0.28453600E-01, -.59145800E-01, 0.67302500E+00, 0.32626400E+01, -.45583200E+00, 0.73719400E+00, 0.66872800E+00, 0.70509700E+00, -.19560900E+00, 0.40757800E-01, 0.39348500E+00, 0.12641400E+00, 0.31047500E+00, -.14066900E+00, -.69259600E+00, 0.96417300E+00, 0.74113200E+00, -.73540300E+00, 0.28871200E+00, -.13260100E+00, -.10006400E+00, 0.14239700E+01, -.23494400E+00, 0.61686900E+00, -.94541300E+00, -.28928500E+01, 0.82153900E+00, 0.37830400E+00, 0.10668500E+01, -.72906300E+00, -.25121100E+00, 0.55014300E+00, -.25167900E+00, -.83551700E-01, 0.13563800E+01, 0.56143400E+00, 0.25955400E+00, -.11965800E+01, -.13033800E+01, -.41757200E+00, -.25994900E+00, -.16636000E+01, 0.82254000E-02, -.82976800E+00, 0.31336800E-02, 0.23529600E+01, 0.40047900E-01, -.25725100E+01, -.13547000E+00, 0.24848500E+00, -.35839200E+00, 0.33199200E+01, -.26414900E+00, 0.37387900E+00, 0.23732400E+00, 0.80918900E-03, 0.29620700E+01, 0.11833800E+01, 0.12557200E-01, -.13818500E+00, -.14403600E+00, -.39746600E+00, 0.80295500E+00, -.53257200E+00, 0.63068400E-01, -.27478200E+00, -.11450900E-01, 0.17458700E+01, -.42323100E+00, 0.79919300E-01, -.19308500E+00, 0.29267600E+00, 0.15645500E+00, -.36696800E+00, -.98908800E+00, 0.25261400E-01, 0.18953900E+00, 0.26383700E+00, 0.17162600E+01, -.55117500E+00, -.24779100E+01, -.50466900E+00, 0.70953900E+00, 0.12704300E+01, 0.14126400E-01, -.46595200E+00, 0.12038600E+00, 0.11058300E+01, -.17428400E+01, -.19979300E+00, -.75699900E+02, 0.98174500E+02, 0.13175000E+03, 0.38659200E+02, -.97297300E+02, -.81759200E+02, -.31483100E+03, 0.13246200E+03, 0.60649800E+02, 0.16605300E+03, 0.20740800E+02, -.85107900E+02, 0.20560500E+03, 0.82107200E+02, 0.14841900E+03, -.15521700E+03, -.79580000E+01, -.97157400E+03, 0.49441000E+03, 0.38112400E+03, 0.49908000E+03, 0.16097900E+03, 0.24469400E+03, -.83968100E+02, -.11875100E+03, 0.24373400E+03, 0.14704500E+03, 0.95625200E+03, -.82130800E+02, 0.46425000E+02, 0.32175700E+03, 0.40100100E+02, -.16802900E+02, -.32226300E+02, 0.38371300E+02, -.52893900E+02, -.50052500E+02, 0.11246300E+01, -.60976000E+02, 0.10800200E+03, -.53651200E+02, 0.64542600E+02, -.54241800E+02, 0.42943000E+02, -.25057600E+02, 0.15023100E+02, 0.26749000E+02, -.42270700E+02, -.52425900E+02, 0.10673600E+03, -.29049100E+02, 0.58950300E+01, 0.39194400E+02, 0.20437300E+02, 0.27274300E+02, -.22854500E+02, 0.50618700E+02, -.69362000E+02, 0.98185600E+01, -.60609800E+01, -.38460200E+03, 0.16199600E+03, -.82597800E+02, -.29456500E+03, -.84681900E+02, -.40702400E+02, -.65337400E+02, -.52632100E+01, -.78902200E+01, -.98335500E+02, -.23846600E+02, 0.10755200E+02, -.13454500E+03, 0.66717700E+02, 0.12993200E+03, 0.67453600E+02, -.73579800E+02, -.13148100E+03, 0.10318600E+03, 0.13340600E+03, 0.71906100E+02, -.15952300E+03, 0.29634200E+03, -.39845800E+00, -.34581200E+01, -.86542900E+02, -.81147800E+02, -.18661800E+02, 0.47190200E+02, 0.11941800E+02, 0.20301400E+01, 0.73256400E+01, 0.23654600E+01, -.56109500E+01, -.21369700E+02, 0.15168200E+02, 0.17139700E+02, 0.29369500E+01, 0.34193500E+01, 0.77835800E+02, 0.19164500E+02, -.90612800E+02, 0.38384100E+02, 0.43222200E+02, 0.26167000E+01, -.91710000E+02, 0.89718800E+01, 0.24725300E+02, -.79805000E+01 },
        { -.51433200E+01, -.11644200E+01, 0.16187100E+01, 0.22698600E+01, 0.18629200E+01, 0.13015000E+01, 0.97587700E+00, -.34244500E+01, -.74620100E+00, -.10187800E+01, -.13666000E+01, -.19129100E+00, -.18446700E+00, -.38038100E+00, -.29203400E+00, -.10827600E+02, -.70474400E+01, -.33529100E+01, -.17822600E+01, 0.52278400E+00, 0.42702700E+01, 0.17847600E+01, -.44323200E+00, -.38915900E+01, 0.37070700E-01, -.49472000E-01, -.29578100E+00, -.75827700E+01, 0.28585000E+00, 0.64303000E-01, -.15792200E+01, -.25728900E+01, 0.17699500E+01, -.43612700E+00, -.82955200E-01, -.66471700E+00, 0.18484700E+00, 0.34233500E+01, 0.64959900E-01, 0.66418000E+00, 0.21296700E+01, 0.11717400E+01, -.27210300E+00, 0.92397100E-01, 0.24441400E+00, -.15622800E+01, 0.23522100E+00, 0.43048600E-01, -.12393200E+01, -.51962700E+00, -.60273600E+00, 0.95236700E-01, 0.33512100E+00, 0.14422300E+01, 0.70962700E+00, 0.46019600E+00, 0.34282800E+00, 0.30408400E-01, -.29512800E-02, -.17729500E+00, 0.66550000E-01, -.55737500E+00, -.11450000E+00, -.32064400E+00, -.10250400E+01, -.13768700E+01, -.71313600E+00, -.17139000E-01, 0.84215700E+00, 0.11617100E-01, 0.17453800E+00, 0.26162100E+01, 0.25236700E+00, -.16776500E+00, -.64284900E+00, -.70838200E+00, -.34210900E+00, 0.55088700E+00, -.36700900E+00, -.25606900E+00, 0.10300000E+00, -.72498500E-01, 0.55398800E-01, 0.48953900E+00, -.18290400E-02, -.63127900E+00, 0.23351700E+00, -.11815000E+00, 0.21858300E+00, -.10608200E+00, 0.54757200E+00, -.23889000E-04, 0.82851900E+00, -.17390900E+00, 0.12468400E+00, 0.47206800E+00, -.20205900E+00, -.54173800E+00, 0.77126900E-02, 0.20755600E+00, -.10573900E+00, -.90635100E-01, -.73303000E-02, 0.48181200E+00, -.43614900E+00, 0.21612000E+00, 0.53381800E+00, -.11815700E+01, 0.11999900E+00, 0.15088900E+00, -.11198700E+01, -.61610400E-01, 0.21373400E+00, -.28030800E-01, -.11037000E+00, -.10955700E+01, -.36721600E+00, 0.23497500E+00, 0.18654200E+01, 0.10134200E+01, -.93017700E+00, 0.11693600E+00, 0.27574200E+00, 0.18367700E+00, 0.73319700E-01, -.54588200E+00, -.16973300E+00, -.21291100E+01, -.30954700E+00, 0.25964100E+00, 0.33666600E+00, 0.31593800E-01, -.69814600E+00, 0.64760100E+00, 0.37598400E-01, 0.29408300E-02, -.63138800E-01, 0.27504100E+00, -.24904400E+00, -.19144900E+01, 0.12537600E+01, 0.15654900E+00, -.41060000E+00, -.27149700E+00, 0.16894800E-01, 0.15909000E+01, 0.54275800E-01, -.23721500E+00, 0.26804700E+00, -.32901600E+00, -.10206500E+01, -.46874900E+00, -.26603700E+00, -.32746900E+00, 0.89843600E-02, 0.18321900E+01, 0.26040300E+00, -.22325900E-01, -.13683100E+01, 0.28606700E+00, 0.12177700E+00, -.14210200E+00, -.24926900E+00, -.61000500E+00, -.40165000E+00, -.48662000E+00, -.21777200E-01, 0.17755400E+01, 0.39261200E-01, 0.12877100E+01, 0.28251800E+00, -.24305700E+00, 0.30579100E+00, 0.64898500E-01, 0.12348400E+01, 0.15652000E+00, -.61693100E+00, -.56076800E-01, 0.35679300E+00, -.13753900E+00, -.26207100E+00, 0.10193000E+00, -.67746300E+00, -.76998200E+00, 0.26227200E-02, 0.34661300E+00, -.25730600E+00, -.32250600E+00, -.10841900E+00, -.24735200E+00, -.21605600E+01, -.39044000E+00, -.25585700E+00, -.40424800E+02, -.91882800E+02, -.59762800E+02, -.23217100E+02, 0.17558900E+03, 0.21193100E+03, -.13620100E+03, -.10624100E+03, -.11043900E+03, 0.33115800E+02, -.29576700E+02, 0.60339800E+02, -.29162900E+01, -.21153400E+03, -.37684700E+02, -.13153700E+03, 0.97556000E+02, -.41575000E+02, -.35910400E+03, -.43775500E+02, -.45402400E+02, -.39107400E+02, -.15693400E+03, -.61468400E+01, 0.12418500E+03, -.11991300E+03, 0.63753400E+02, 0.75796900E+02, -.22519900E+02, 0.38918000E+03, -.39523800E+02, 0.26270400E+02, -.16273300E+02, 0.11184600E+02, 0.41388200E+02, -.47867300E+01, 0.12891500E+01, -.92255000E+01, -.18982400E+03, 0.88837900E+02, 0.18119000E+03, 0.94860000E+02, -.42714600E+02, 0.25223400E+02, -.34944300E+02, -.69700000E+02, 0.99518400E+02, -.54528600E+01, 0.27950600E+02, -.17343700E+02, -.63767800E+01, 0.10666700E+03, 0.10739500E+02, 0.38742600E+02, 0.33512800E+02, -.42947400E+02, -.11756400E+03, 0.42247700E+02, 0.27448600E+02, -.34101400E+03, -.98090900E+02, 0.49008000E+02, 0.81318600E+02, 0.48204500E+02, 0.99809100E+01, 0.76620600E+01, -.61207100E+01, -.38709900E+02, -.11309400E+03, 0.41457000E+02, 0.98213200E+02, 0.19707500E+03, -.10914300E+03, 0.11780400E+02, -.91532600E+02, -.13772900E+03, -.12224800E+03, 0.12833700E+03, 0.19165000E+03, 0.21659900E+01, -.18828500E+03, -.43109700E+02, 0.27392100E+02, -.15934900E+02, -.69056100E+02, -.70519700E+02, -.68048600E+01, 0.19881700E+02, 0.11732000E+02, 0.15085000E+02, 0.13540400E+02, -.17049900E+02, -.11350100E+02, 0.28362700E+01, 0.15974000E+02, 0.47666800E+01, 0.13309400E+02, 0.11761500E+02, 0.68467200E+02, 0.12080500E+02, -.63233200E+02, 0.93053300E+01, 0.47110100E+02, -.61103500E+00, 0.17236300E+02, 0.20419400E+02, 0.13666800E+02, -.77727500E+01 },
        { 0.14570800E+01, -.27718500E+00, -.96492600E+00, -.48812600E+00, -.12009400E+01, -.41992400E+00, -.49738600E+00, -.15769500E+01, 0.67397800E-01, -.95211200E+00, -.37686900E-01, 0.17807900E+00, 0.25297100E-01, 0.90876300E-01, -.22937300E+00, -.71835900E+00, 0.34241500E+01, 0.53673000E+00, -.34497400E+00, -.29748600E+00, 0.69399400E+00, 0.16090000E+00, -.55951800E-01, 0.41230600E+00, -.46118000E-01, 0.14219200E-01, -.55971300E-01, 0.10847000E+01, -.22301200E-01, 0.40837100E-01, -.42432100E-01, 0.51896300E-01, -.33786100E-01, 0.67588000E+00, 0.27362000E-01, 0.26173900E-01, -.14396100E-01, -.55256800E+00, 0.10171000E-01, -.27999400E+00, -.58498100E-01, 0.22572200E-01, 0.43222800E-01, 0.69359100E-01, 0.11244400E+00, -.25293500E+00, 0.19965600E-01, 0.54972800E-02, -.17667700E-01, -.90938500E-01, 0.14819500E+00, 0.66235500E+00, 0.52430600E-01, -.10818100E-01, -.10343100E+00, 0.39088600E+00, 0.20208500E-01, -.18556000E-01, 0.13387000E-01, 0.63235900E-02, 0.23284800E-01, 0.85194700E-01, 0.10521600E+00, -.12876400E+00, 0.76799900E-01, 0.42051000E-01, -.21114100E+00, -.15044100E-01, 0.38537600E-01, -.52048600E-02, 0.90938600E-02, -.29069200E+00, 0.48506000E+00, 0.11321400E+01, -.52622100E-01, 0.10744800E+00, -.10129400E+00, 0.33567000E+00, -.13458000E+00, -.25052100E-01, 0.36349600E-01, 0.50051300E-02, -.57305600E-01, -.98928400E-01, 0.49106700E-01, 0.41119100E-01, -.46296100E-01, 0.69470100E-01, 0.15271200E+00, 0.18269700E-01, 0.10159700E+00, 0.32134400E-02, 0.47319800E-02, -.35102400E-01, -.40677000E+00, 0.18594600E+00, 0.21451600E-01, 0.17547900E+00, -.52466700E-01, 0.15216700E+00, 0.40779000E-01, 0.58177000E-01, 0.48493400E-02, -.87501000E-02, -.62108700E-01, 0.74983100E+00, -.38173600E-01, 0.60898100E-01, -.27861700E-01, -.30643700E+00, 0.10811100E-01, 0.45406000E-03, -.35934800E-01, -.12177300E-01, -.12664400E-01, -.59620900E-01, -.33815700E-01, 0.54135300E-01, 0.54271100E-01, 0.17544100E+00, 0.12016300E-01, 0.26453700E-01, 0.25680200E-01, 0.90704600E-01, 0.35649900E-02, -.14232500E+00, -.69103100E-01, -.62140700E+00, -.21101600E-02, 0.20306900E-01, -.51095400E-01, -.36797500E-01, -.36550000E+00, 0.96541700E-01, -.11553600E+00, -.12808700E-01, 0.18867800E+00, 0.23296400E+00, -.84583500E-01, -.26643200E+00, -.36331300E+00, -.14564300E+00, -.19786200E+00, -.24648100E+00, 0.15950000E-01, 0.45748000E-01, -.80880000E-02, 0.12571000E+00, -.87658600E-02, 0.28493900E-01, 0.11493300E+01, 0.32060900E-01, -.53928300E-02, 0.27505700E+00, 0.31175400E-01, -.53729000E-01, -.25007900E-01, 0.15231600E-02, 0.28326900E+00, 0.33105900E-01, 0.57570600E-01, 0.18608500E-01, 0.44905500E-01, -.59680700E-01, 0.67382100E-01, -.34282400E-01, -.47825000E-01, -.16483500E+00, 0.72613000E-02, -.13045100E+00, 0.11378000E-01, 0.66254700E-01, -.24371000E-01, 0.16507200E-01, 0.12259100E+00, -.49913500E-02, 0.37577700E-02, 0.16842900E-01, 0.32162900E-01, -.42086600E-01, -.85284000E-01, -.76911000E-01, -.22436700E+00, -.14521800E+00, 0.63819100E-01, -.23402100E+00, 0.38836900E-01, 0.69141200E-01, -.51309700E-02, 0.20283100E+00, 0.92321400E-01, -.85473500E-01, -.12808100E-01, -.37805200E-02, 0.27195400E+02, 0.25993500E+02, -.38248200E+01, 0.20718900E+02, -.14338400E+02, 0.56290400E+01, -.27305000E+02, 0.78706200E+01, -.16720100E+01, -.11091900E+02, 0.12750900E+02, 0.22942500E+02, 0.21550800E+02, -.17695700E+02, -.36850600E+01, -.23605200E+02, 0.13252500E+02, 0.24330700E+02, 0.12096200E+02, 0.97769200E+01, -.17749000E+02, 0.30492900E+02, 0.37773000E+02, 0.33453600E+02, -.13133000E+02, 0.69349100E+01, 0.37319300E+02, -.15203600E+02, -.11707000E+02, -.18653200E+02, 0.77316300E+01, -.42368900E+01, -.11228600E+02, 0.59854900E+00, -.33747700E+01, -.44806300E+01, -.11567300E+02, -.48647500E+02, 0.24128400E+02, 0.52211400E+02, 0.24316400E+02, 0.12646400E+02, 0.98020300E+01, 0.16533900E+01, -.15891000E+02, 0.84684400E+01, 0.93015000E+01, 0.24814100E+02, -.17915500E+02, 0.62674800E+01, 0.68920900E+00, 0.90780500E+01, -.23703400E+01, 0.34923800E+01, 0.47337300E+00, -.12828400E+02, 0.98548000E+01, 0.99920200E-01, -.17754900E+02, 0.14291400E+02, -.90701000E+01, -.23139000E+02, -.72702300E+01, 0.80241200E+01, 0.11089000E+02, -.15762400E+02, -.26696500E+01, -.10360700E+01, 0.85586400E+01, 0.84437400E+01, 0.45240600E+02, -.25270700E+02, -.38996500E+02, -.23049900E+02, -.39403000E+02, -.19605900E+02, 0.56217300E+01, 0.18664800E+02, 0.27046100E+01, -.24110600E+02, 0.23727900E+02, 0.75610100E+01, -.26055500E+01, -.59030500E+01, -.66493700E+01, 0.60972800E-01, 0.22810000E+01, 0.50199400E+01, 0.33027300E+01, 0.20895400E+01, -.14697300E+01, -.18131200E+01, -.88162000E+00, 0.41070000E+01, 0.12100000E+00, 0.30417100E+01, 0.24021900E+01, 0.66275900E+01, 0.47394600E+01, -.47992100E+01, 0.11277100E+01, 0.50830000E+01, -.84217400E+00, 0.55201400E+01, 0.32202100E+01, 0.53387700E+01, -.26074300E+01 },
        { -.76577600E+01, -.22394600E+01, 0.27818700E+01, 0.42296400E+01, 0.26327800E+01, 0.17151100E+01, 0.23372700E+01, -.10469500E+02, -.69166400E+00, -.19414500E+01, -.20501800E+01, -.10284500E+00, -.18465600E+00, -.43397800E+00, -.40174000E+00, -.28183900E+01, -.89357100E+01, -.33953300E+01, 0.12524200E+01, 0.35584800E+00, 0.28914300E+01, 0.65223600E+00, -.82434300E-01, -.29522600E+01, 0.23948800E+00, 0.38944600E-01, -.85820800E+00, -.70954400E+01, 0.17999700E+01, 0.28037600E+00, -.14494400E+01, -.36101600E+01, 0.14016000E+01, -.14677500E+01, -.12308200E+00, -.44853200E+00, 0.13684300E+00, 0.37559600E+01, -.72030100E-01, 0.14946400E+01, 0.20894300E+01, -.80377600E-01, -.28460100E+00, 0.81760000E-01, 0.27177400E+00, -.15524600E+01, 0.18471800E+00, -.45304500E-02, -.41006100E+01, -.30082400E+00, -.58117100E+00, -.65243700E+00, 0.44248600E+00, -.27997000E+00, -.29877800E-01, 0.67567100E+00, -.18096900E+00, -.19714400E+00, -.40245400E-01, -.10154800E+01, 0.26108700E+00, -.15491200E+00, -.30224900E+00, -.56329100E+00, -.42267100E+00, 0.18600800E+01, 0.31129800E+01, 0.25355500E+00, -.25960900E+01, -.43124400E-01, -.10471700E+00, -.58183300E+01, -.25494800E+01, -.67615900E+01, 0.23577300E+01, -.72320200E+00, 0.44799800E+00, -.17079000E+01, 0.15680300E+01, -.31600000E-01, -.14116800E+00, 0.15594400E+00, 0.38495500E+00, 0.79063400E+00, -.66693400E+00, -.74040300E+00, 0.35863200E-02, 0.15356200E+00, -.51527300E-01, -.23460800E-01, -.19922800E+00, -.57738500E-02, -.50670900E+00, -.13876400E+00, -.10802600E+01, -.75386600E+00, -.12211500E+01, -.48804300E-01, 0.48198700E-01, 0.56260900E-01, -.16383000E+00, -.94071000E-01, -.26183900E-01, -.14396100E+00, -.24539500E+00, 0.56816000E+01, 0.11436700E+00, -.62497900E+00, 0.30171200E+00, 0.35088600E+00, -.65232500E+00, -.40269100E-01, 0.15426300E+01, -.34395100E-01, 0.88506200E+00, -.36685500E+00, -.11974500E+00, -.29574000E+00, -.67304200E-01, 0.25614000E+01, -.12660300E+01, -.63023800E-01, 0.32890600E+00, -.82483200E+00, 0.33240700E-01, -.95879800E+00, 0.25112900E-02, 0.16889700E+01, -.91392200E+00, 0.10985700E+00, -.16472400E+01, -.18309400E+00, -.73523100E+00, 0.37970600E+00, 0.10739600E+00, -.71563900E-01, 0.22378800E+01, 0.19465500E+00, -.14532800E+00, -.22803300E+01, -.17870000E+00, -.26897400E+00, -.99808200E+00, -.14517800E+00, -.44742300E-01, -.19558200E+00, 0.55284900E-02, -.29369200E+00, -.81122600E-01, 0.26323700E-02, -.32864700E+01, 0.37055100E+00, 0.82197600E-01, 0.71128900E+00, -.19906300E+00, 0.15531200E-01, 0.34121400E+00, -.71854500E-02, -.27638900E+01, -.37181100E+00, -.32216300E+00, -.67687900E+00, -.90937800E-01, -.52520000E+00, -.67973700E+00, -.13882900E+01, -.26973500E-01, 0.16034100E+01, -.16330200E-01, 0.23702700E-01, 0.57636300E+00, -.44363700E+00, 0.20816900E+00, 0.29793900E-01, -.65313500E+00, 0.41454800E+00, 0.11117000E+00, -.51301700E-01, 0.10841700E+00, 0.80192600E-01, 0.84218100E-01, -.56248700E+00, 0.32293600E+00, -.48295600E+00, -.12365000E+00, -.93587900E+00, -.68089100E-01, 0.82977500E+00, -.35196200E-01, 0.73338400E+00, -.30440800E+00, -.59047100E+00, -.34700900E+00, 0.47410900E+00, 0.65446100E+01, -.76502700E+02, 0.25386900E+02, -.32148100E+02, -.39764200E+03, 0.21435300E+03, 0.24062200E+03, 0.20536600E+03, 0.81585500E+02, 0.15909200E+03, -.15880300E+03, -.10482200E+03, 0.15454800E+03, 0.14764200E+03, 0.30976300E+03, -.88616200E+03, 0.43530300E+03, 0.65776600E+03, 0.44379700E+03, 0.19695700E+03, 0.32595600E+03, -.31934700E+02, -.20375000E+03, 0.52718300E+02, 0.29768600E+03, 0.45959900E+03, -.12624600E+03, 0.26068700E+02, -.21987500E+03, 0.64285400E+02, -.10573800E+03, -.15326500E+02, 0.98804700E+02, 0.24742400E+02, -.44305200E+02, 0.15100600E+00, -.11120800E+03, 0.44425400E+03, -.21661600E+03, -.29283400E+03, -.22217300E+03, 0.35435200E+01, -.78477700E+02, -.66535000E+01, 0.97365500E+02, -.13949800E+03, -.77204700E+02, -.25652000E+03, -.36293800E+02, 0.43910000E+02, -.12992700E+03, 0.18632500E+02, -.45089800E+01, -.52809800E+02, 0.76615800E+02, 0.55963300E+02, -.82541600E+02, -.38156300E+02, 0.27291100E+03, 0.78301500E+02, -.25985600E+02, -.86521900E+02, -.39843100E+02, -.10179700E+03, -.54393000E+02, 0.27813900E+02, 0.18104700E+00, -.23467800E+02, -.27773800E+02, -.84292500E+02, -.64610800E+03, 0.35405900E+03, 0.23787800E+03, 0.31763400E+03, 0.38784700E+03, 0.28111800E+03, -.17034500E+03, -.86307000E+02, 0.11702300E+03, 0.28914700E+03, 0.39485400E+03, -.90444000E+02, 0.19536900E+02, 0.29080200E+02, 0.28704700E+02, -.99796600E+01, -.77855100E+01, -.52456200E+02, -.20524700E+02, -.24644400E+02, 0.21108800E+02, 0.49355100E+01, -.22698600E+02, -.51196100E+02, 0.11157200E+02, -.18485300E+02, -.23492200E+02, -.30530000E+02, -.46013900E+02, 0.25627400E+02, 0.24654000E+01, -.63867900E+02, 0.94146000E+01, -.41084200E+02, -.18060100E+02, -.44522000E+02, 0.30818900E+02 },
        { -.22070600E+01, 0.12303700E+00, -.20670100E+00, -.55193000E+00, 0.17122400E+01, 0.64689200E-01, -.33825800E+00, 0.50177200E+01, -.40611300E+00, -.19309800E+00, 0.10056800E+01, 0.68568200E-01, 0.89935900E+00, -.37285900E-01, -.81813800E-02, -.30350100E+01, -.13938200E+01, -.67894600E+00, -.48605800E+00, -.15750900E+00, 0.76618100E+00, 0.28869600E+00, -.31974200E-01, -.70082500E-01, 0.14858500E+00, -.15020800E-01, -.46161200E+00, -.19715900E+00, 0.53975000E+00, -.50165800E-01, -.56435100E-01, -.10565500E+01, 0.90550100E-01, -.53784500E+00, 0.26779000E-01, -.11689500E+00, 0.14360500E-01, 0.51510000E+00, 0.13074700E+00, 0.14795500E+00, -.61043600E+00, 0.18705700E+00, -.41119900E-01, -.11500900E+00, -.29758000E+00, 0.55106100E+00, -.12103000E+00, -.20342300E-01, -.25916300E+00, -.13332500E+00, 0.36754700E+00, -.90141400E+00, 0.25914200E+00, -.28068900E+01, -.21620200E+00, -.89754700E+00, -.77350500E+00, -.13759200E+00, -.30497100E-01, -.80633400E+00, -.24390000E-01, -.22528800E+00, -.27552300E+00, 0.51113500E-02, 0.15631500E+00, 0.54022400E+00, 0.53015000E+00, -.50478300E-01, 0.11338200E+00, 0.17312900E-01, 0.10505300E+00, -.25075800E+00, -.58551600E+00, -.48999300E+00, 0.23062200E+00, -.42231800E+00, 0.93861900E-02, 0.24576900E+00, 0.11279500E-01, -.32617400E-01, -.21851200E-01, 0.34265100E-01, 0.10344900E+00, 0.15671800E+00, -.30209800E-01, -.65215800E-01, -.26537000E-02, -.36233600E-01, -.44975900E+00, -.56834500E-01, -.16490000E+00, -.45045400E-02, -.12663600E+00, 0.15701100E-01, 0.46911300E+00, -.24196300E+00, -.16460900E-01, 0.32328000E-01, 0.50084300E-01, -.75473900E-01, -.32260100E-01, -.36819500E-03, 0.24466700E-02, -.10340500E-01, -.77947600E-01, 0.10713000E+01, 0.17405200E+00, -.16230000E+00, 0.12970600E+00, 0.23704000E-01, -.27028200E+00, 0.20719600E-01, 0.28173900E-02, 0.43115900E-02, -.12647300E+00, -.35403500E+00, -.10377400E+00, 0.86573700E-01, 0.18241200E+00, 0.15015700E+00, -.54357500E-01, 0.13305100E-01, 0.13866700E-01, 0.31898300E-01, 0.49547200E-02, -.44525500E-02, 0.91125500E-02, -.56249700E+00, -.76564500E-01, 0.86725400E-01, 0.30966100E+00, -.29752500E-01, -.11042900E+00, 0.38394700E-01, 0.46319800E-02, 0.23004400E-02, 0.87686400E-01, -.11779600E+00, -.25293200E-01, -.16077800E+00, -.86553600E-01, 0.23603400E-01, 0.81751700E-01, -.20514400E+00, 0.24442300E-01, 0.24994900E+00, 0.57907300E-02, 0.38286600E+00, -.16605200E-01, -.23541700E+00, 0.97840100E+00, 0.75086300E-01, -.74029200E-01, 0.18128400E+00, -.52030300E-02, -.18158800E+00, 0.28782800E-01, -.32111900E-02, -.97064100E-01, 0.19232600E+00, 0.28697700E-01, 0.55719200E-01, -.58000300E-01, -.94626700E-01, 0.11198800E+00, 0.82065200E-01, 0.56235000E-01, 0.55503300E-01, 0.39908500E-02, 0.67551400E-01, 0.31716900E-01, -.41291400E-01, 0.80842100E-01, 0.23902300E-01, 0.52207900E+00, 0.88470800E-01, 0.32721700E-01, -.29016200E-02, 0.83854200E-01, -.46969200E-01, -.10628000E+00, -.63013100E-01, -.12121500E+00, -.21153000E+00, 0.79517100E-01, -.12205600E+00, -.55942100E-01, 0.67105200E-01, 0.96886800E-02, 0.75600600E-01, -.27818400E+00, -.47923700E-01, -.11630800E+00, -.21863600E+00, 0.17144800E+00, 0.14587000E+00, -.10177800E+02, 0.54031400E+02, 0.71690800E+02, -.50587400E+02, -.54477100E+02, -.37919300E+02, 0.11575600E+02, -.28736800E+02, 0.61770500E+02, 0.33013100E+02, -.68694200E+02, -.36422400E+02, -.83028300E+02, 0.29544600E+02, -.10252500E+02, -.15341600E+03, -.11679300E+02, -.16911900E+02, -.45732500E+02, -.28867300E+02, 0.30633800E+02, 0.70936500E+02, -.74760500E+02, 0.53204300E+02, 0.68503000E+02, -.23522600E+02, 0.19510800E+03, -.35118500E+02, 0.12252100E+02, -.10432800E+02, -.12375300E+02, 0.61173200E+01, -.12690400E+02, -.29952600E+01, -.15592800E+02, -.12127700E+03, 0.57803600E+02, 0.12718400E+03, 0.60600300E+02, -.64521100E+01, 0.15636500E+02, -.10298500E+02, -.39492400E+02, 0.49215300E+02, 0.13516800E+01, 0.65509000E+02, -.12464100E+01, -.90213700E+01, 0.33940600E+02, 0.20317000E+01, 0.14307000E+02, 0.17188500E+02, -.25516900E+02, -.45900600E+02, 0.32698300E+02, 0.92378300E+01, -.18844000E+03, -.16685600E+02, 0.60111800E+01, 0.10805500E+02, 0.78592800E+01, 0.10598600E+02, 0.87045100E+01, -.15443500E+02, -.15785700E+02, -.48349800E+02, 0.19339200E+02, 0.55008400E+02, 0.19053300E+03, -.10343300E+03, -.51180800E+02, -.91701600E+02, -.13283800E+03, -.87906400E+02, 0.65345800E+02, 0.80454400E+02, -.12025400E+02, -.11489200E+03, 0.10693800E+02, 0.28656000E+02, -.86053600E+01, -.42950700E+02, -.43701300E+02, -.22867000E+01, 0.12008800E+02, 0.14401900E+02, 0.80485200E+01, 0.87360200E+01, -.81059700E+01, -.56115200E+01, 0.24404300E+01, 0.14550700E+02, 0.15219600E+01, 0.71190800E+01, 0.44495400E+01, 0.42297000E+02, 0.12080300E+02, -.41115200E+02, 0.63889100E+01, 0.28392000E+02, 0.21326800E+01, -.17805500E+01, 0.10677800E+02, 0.13710700E+02, -.96636400E+01 },
        { -.69367200E+01, -.36720100E+01, -.62715200E+01, -.33960100E+01, 0.26598000E+01, 0.34519100E+01, 0.26345500E+01, 0.20372500E+01, 0.13646200E+00, -.12982700E+01, 0.14681500E+01, 0.81968200E+00, 0.59909900E+00, -.11606600E+01, -.34884600E+00, 0.12369900E+02, -.34600900E+01, -.27986800E-02, 0.37073900E+00, 0.26072700E-01, 0.77223600E+00, 0.97498900E+00, 0.18786200E+00, 0.27421400E+01, 0.73418100E+00, 0.42520100E-01, 0.71094800E+00, 0.23731200E+01, -.11444700E+01, -.66303400E-02, -.38438000E+00, 0.92838300E+00, 0.55746100E+00, -.42359800E+01, -.15384700E-01, -.22877900E+00, -.66025400E-01, -.37817100E+00, -.17264700E+00, -.62050600E+00, 0.51820700E+00, 0.20354300E-01, -.72039600E-02, 0.72506500E-01, -.93302500E+00, 0.36286200E-01, -.30840800E-01, -.87823900E-01, -.94157300E+00, -.10916800E-02, -.80545100E+00, -.19377400E+00, 0.11102400E+00, 0.32863600E+00, -.39869600E+00, 0.72228000E+00, -.27817400E+00, -.39816000E-01, -.37078400E-01, -.31063900E+00, 0.23304500E+00, -.41972700E+00, 0.94475800E-01, -.45849200E+00, -.21669400E+00, -.96454000E-01, 0.16028600E+01, 0.30617400E+00, -.34445900E-01, -.37777900E-02, -.67359300E-01, 0.26885900E+01, 0.11844800E+00, -.16112100E+00, -.80281700E+00, -.14647900E+01, 0.25028400E+00, -.58797600E+00, -.28318700E+00, -.12041200E+00, 0.11536500E-01, 0.52648400E-01, 0.22161400E+00, 0.62541500E+00, -.96449800E-01, -.23075800E+00, -.18478900E+00, 0.11899600E+00, -.60635100E+00, 0.63518400E-01, -.24782400E+00, -.93392000E-04, -.30053200E+00, -.19445600E+00, 0.67822400E-01, -.77262400E+00, 0.17149100E+00, -.69245400E-01, -.13959200E+00, -.38605600E+00, 0.40691400E-01, -.32349200E+00, -.22121000E-01, 0.16053100E-01, 0.24246400E+00, 0.41668900E+01, -.23417900E+00, 0.22019900E+00, 0.37752700E+00, 0.36843400E-01, 0.37382800E+00, 0.12127900E-01, 0.12166500E+00, 0.17782800E-01, -.57280100E-01, -.17998800E-02, -.10848900E+00, 0.16769300E+00, -.25808500E+00, -.11079300E+01, -.20343000E+00, -.36866100E-01, -.15688500E+00, 0.27610900E+00, -.57716400E-01, 0.93063200E+00, -.16775400E-01, 0.17424400E+00, 0.29944100E+00, 0.12647500E+00, -.17875800E-01, -.51881400E-01, 0.17281200E+01, -.54524700E+00, -.27227800E+00, 0.12755600E-01, 0.11535000E+00, -.16080200E+00, 0.15862900E+00, 0.13552300E+01, 0.15275400E+01, 0.33256600E+00, -.27027400E-01, 0.27071500E+00, 0.62609100E-01, 0.10954200E+00, 0.10959500E-01, 0.90124700E+00, -.83440800E-01, -.14389500E+01, -.82241300E+01, -.11249300E+01, -.77672200E+00, -.38770800E+00, 0.16241500E+00, -.99611200E+00, 0.63651500E+00, 0.18156400E-02, -.16421800E+00, -.13625500E+00, -.56517800E+00, -.14731400E+00, 0.15462100E-01, 0.53437400E+00, 0.17291200E+01, 0.62228400E+00, 0.10498700E+00, 0.37797400E+01, -.10063100E-01, 0.15502000E+01, -.15119300E+00, 0.98275200E-01, 0.61220200E+00, -.71234200E+00, -.14758600E+00, 0.29970200E+00, -.70152100E+00, 0.95615200E-02, -.60964400E+00, -.31627200E+00, -.75633300E-01, -.54130900E+00, 0.10319200E+01, 0.16907900E+01, -.11561700E+00, 0.26839500E+00, 0.47516300E+00, -.86015500E+00, -.11652700E+00, -.35063700E+00, -.99199900E-01, 0.65597500E+00, -.67809400E-01, -.82304500E-01, -.19422800E+00, -.40664800E+00, -.14048900E+01, 0.97746600E+02, -.57353600E+02, 0.12114000E+02, 0.71893500E+02, 0.19583700E+02, 0.46331300E+01, -.22761800E+02, 0.80197800E+02, 0.30676100E+02, 0.31731300E+02, -.13335300E+02, 0.27684100E+02, 0.39102300E+03, -.19519000E+03, -.35095800E+03, -.19593300E+03, -.12717100E+03, 0.65900600E+01, -.22116400E+03, -.26699900E+03, -.31945800E+03, -.92064500E+01, 0.55038200E+01, -.16734000E+03, 0.90708200E+02, 0.20195800E+02, 0.81657500E+02, 0.37606800E+02, 0.21822900E+02, 0.18906600E+02, 0.48748500E+01, 0.64526500E+02, 0.30775800E+02, 0.12639100E+03, 0.24103400E+03, -.12067200E+03, -.27997500E+03, -.12049900E+03, -.76699800E+02, -.40988000E+02, -.19123000E+02, 0.36241300E+02, -.71171700E+02, -.49683800E+02, -.54232800E+02, 0.31634200E+02, -.22489900E+02, 0.80668700E+02, -.14796800E+02, 0.55704800E+02, 0.67439300E+01, -.25568800E+02, 0.37829300E+02, 0.18704700E+02, 0.82365900E+01, -.16369800E+03, 0.16598900E+02, -.50529900E+01, 0.75116500E+02, -.67004900E+01, -.16930400E+01, -.30482800E+02, 0.29417300E+02, 0.39695700E+01, -.25626100E+02, -.39419200E+01, 0.38432300E+02, 0.83089600E+02, -.48299800E+02, 0.91148600E+02, -.35342900E+02, -.14901300E+03, -.90127200E+02, 0.96221100E+02, -.62648900E+02, -.14610900E+03, -.49138400E+02, -.29349300E+03, 0.72476400E+01, 0.44736800E+01, -.50111800E+02, -.53442800E+02, 0.81629000E+01, 0.38574200E+01, 0.96483200E+01, -.11416500E+02, 0.47196700E+01, 0.54911100E+00, 0.67243700E+01, 0.10154700E+02, 0.16339500E+02, -.86448300E+01, -.10853200E+02, -.81771600E+01, 0.51838200E+02, 0.74675800E+01, -.48085000E+02, -.15307700E+00, 0.27295600E+02, 0.96286900E+01, -.73688300E+01, -.55043900E+01, 0.86068000E+01, 0.25547000E+01 },
        { -.32898000E+01, 0.37808400E+00, 0.25635400E+01, 0.11108400E+01, 0.10877800E+01, 0.35559700E+00, 0.10111000E+01, -.64265700E+01, -.38312800E-01, -.17442000E+01, -.43648600E+00, 0.64528500E+00, 0.27826700E+00, -.95445800E-01, -.11476200E+00, 0.51471100E+01, -.25571400E+01, 0.12524500E-01, 0.20678300E+01, -.21124900E+00, -.20015900E+01, -.53536400E+00, 0.17910200E+00, -.15258900E+00, 0.10030200E+00, -.14781100E+00, -.12605400E+01, -.19566300E+01, 0.20688000E+01, -.52568200E-01, -.22651200E+00, 0.23624000E+00, -.97545300E+00, 0.69785400E-01, -.35856000E-01, 0.95271400E-01, 0.12056100E+00, 0.46456800E+00, -.19312900E+00, 0.12396800E+01, 0.96279700E-01, -.91734900E+00, -.48462000E-01, -.14826900E-01, 0.71271600E+00, -.44190400E+00, -.55306600E-02, 0.10309300E+00, 0.58468500E+00, 0.56699900E-01, -.13702900E+00, 0.46845000E+00, -.78606800E-01, 0.96291100E-01, -.23207600E+00, -.24057200E+01, -.87706400E+00, -.30304800E+00, 0.46835000E-01, -.38029600E-02, -.86664000E-01, 0.55562400E+00, -.22493900E+00, 0.32110900E+00, 0.25092400E+00, 0.90655700E+00, 0.17444500E+01, 0.77411700E-01, -.12075500E+01, -.12872100E-01, -.28093800E-01, -.41195300E+01, -.13896300E+01, -.17439000E+01, 0.16738000E+01, 0.42722800E+00, -.69809900E-01, 0.54120300E-01, 0.59586500E+00, 0.90008800E-01, -.93259700E-01, 0.10999200E+00, 0.53319600E-01, -.26526300E+00, -.17981700E+00, 0.31840200E+00, 0.43866300E-01, -.55221400E-01, -.64336900E+00, 0.12548000E-01, -.32776500E+00, -.34637900E-02, -.61723900E+00, 0.82517800E-01, 0.39114000E+00, -.25937400E+00, 0.49465200E-01, 0.33371400E+00, 0.31819300E-01, -.73729600E-01, 0.45181400E-01, 0.73330700E-01, 0.12673600E-01, -.52911100E-01, -.19348500E+00, 0.48039900E+00, 0.39045200E-01, 0.33398700E-01, -.89469200E-01, -.10207800E+00, -.26325300E-01, -.40341300E-02, 0.59510200E+00, -.14085600E-01, 0.16345400E+00, -.83750600E+00, 0.48541000E-01, 0.31580000E+00, -.80439500E+00, 0.43436800E+00, -.38373000E+00, -.52906600E-01, 0.96387800E-01, 0.14280100E+00, -.64382100E-01, 0.21134200E+00, 0.23352600E+00, 0.23972000E+00, -.51997400E+00, 0.20332200E-01, -.27712300E+00, -.10471200E+00, 0.10175400E+00, -.21072900E-01, -.89401200E-01, -.36406900E-01, 0.65345900E+00, 0.23040400E+00, 0.76404100E-01, -.11298300E+01, -.13851900E+00, -.27803300E+00, 0.73248700E+00, -.22792500E+00, -.65225600E-01, 0.48746000E+00, 0.31993700E-01, -.31513200E-01, -.66940600E-01, 0.11281000E-01, -.10636700E+01, -.21238300E+00, -.97775200E-01, 0.13381500E+01, 0.10540800E+00, -.72608600E+00, 0.31536200E+00, 0.36867000E-02, 0.99430300E+00, 0.14410900E+00, -.13284600E+00, 0.34830600E-02, 0.11704300E+00, 0.20309900E+00, 0.59542500E+00, -.32310700E+00, -.30391300E-01, -.21851200E+00, -.78027900E-02, 0.41664000E+00, -.13873500E+00, 0.50849200E-01, -.64124400E-01, 0.90141900E-01, -.32421300E+00, -.37897500E-01, -.35463300E+00, 0.25055500E-02, -.41542000E-01, 0.82967500E-01, 0.31364600E+00, -.16870200E+00, -.10679600E+01, 0.15653500E+00, -.78924200E-01, -.15148800E+00, -.28031800E+00, -.25141100E+00, 0.72452900E-01, 0.15789200E+00, -.47690600E+00, -.39545300E-01, 0.22478400E+00, 0.13135500E+00, 0.35500300E+00, 0.20576500E+00, -.30006500E+00, 0.10641000E+00, -.20678100E+03, 0.10379800E+03, -.27325100E+02, 0.10503500E+03, 0.28899800E+02, 0.44743400E+01, 0.14319400E+02, 0.58892300E+01, 0.13848200E+03, -.92150700E+01, 0.48700900E+02, -.15022800E+03, 0.74185000E+02, 0.76497200E+02, 0.73880900E+02, -.18916900E+02, -.32672700E+02, 0.65161400E+02, -.35481300E+02, 0.11785700E+02, -.91703500E+00, 0.92798400E+02, 0.22117800E+03, -.11005200E+03, -.11215900E+03, -.11049200E+03, -.12352700E+02, -.80255600E+01, -.58276000E+02, 0.39695800E+02, -.32512700E+02, -.13700300E+02, -.57337700E+02, -.14784000E+03, 0.73528700E+02, 0.43038600E+02, 0.73933700E+02, 0.13931800E+02, 0.15798000E+02, 0.10833700E+02, -.56994100E+02, 0.26975900E+02, 0.20966100E+02, 0.11191100E+03, -.55559200E+02, 0.27554700E+02, -.17549300E+02, 0.27118400E+02, 0.22250000E+02, 0.23254700E+02, -.54929600E+01, -.86340400E+01, 0.51325400E+02, -.13595200E+01, 0.11622200E+02, 0.15066000E+03, -.74621400E+02, -.62939200E+02, -.75284400E+02, 0.25901000E+00, 0.49887800E+01, -.49072300E+02, 0.16371300E+02, -.26226300E+02, 0.91008000E+01, -.69405100E+02, 0.36326300E+01, -.12545700E+01, -.14296300E+03, -.38097300E+01, -.23405900E+02, 0.26845500E+02, -.18666200E+02, -.28397600E+02, -.23845500E+02, 0.48435200E+02, 0.12673800E+03, 0.37099000E+01, -.19455000E-02, -.19125000E+02, -.20127100E+02, -.38825200E+01, 0.39796600E+01, -.15228800E+00, 0.51477000E+00, -.18677500E+00, 0.24774100E+01, 0.26859600E+01, -.91530000E+01, 0.18787900E+00, 0.49499700E+01, 0.38015800E+00, -.17868700E+01, 0.19922000E+02, -.38458200E+01, -.19541600E+02, 0.76178500E+01, 0.12837300E+02, 0.45031600E+01, -.97333200E+01, 0.32834600E+01, 0.43293700E+01, 0.92279100E-01 },
        { 0.15730000E+02, -.61554100E+01, -.36142400E+01, 0.26520500E+01, -.16368400E+01, 0.31296900E+01, 0.31274100E+01, 0.51461800E+01, 0.38680700E+01, 0.10648000E+01, -.19945100E+00, -.61263100E+00, -.38500000E+01, 0.54845200E+00, 0.10211200E+01, 0.29956400E+01, -.12657000E+02, 0.11218100E+01, -.40349800E+01, -.89020500E+00, -.56367500E+00, 0.28885900E+01, 0.86267100E+00, -.52085200E+01, 0.10273800E+01, -.62037100E+00, -.37520200E+01, -.52713300E+01, 0.10206900E+02, -.61314700E+00, -.15620000E+01, 0.52462700E+01, 0.80680600E+00, 0.50559900E+01, -.63432300E+00, -.41653200E-01, -.23328900E-01, -.71183100E+01, -.11476000E+01, -.33364200E+00, -.12856600E+02, 0.11479500E+01, 0.69650700E+00, -.21393000E+00, 0.13273200E+01, -.11833200E+00, 0.14766300E+00, 0.24794500E+00, -.17373600E+01, 0.22436000E+00, -.10193800E-01, 0.32747900E+01, -.35176500E+01, 0.47436400E+01, 0.74756700E+00, 0.51460900E+01, 0.29939100E+01, 0.51492800E+00, 0.24745900E+00, 0.44259300E+01, -.81806300E+00, 0.16808300E+01, 0.18645200E+00, 0.58829900E-01, 0.33569100E+01, 0.14568400E+01, 0.28213800E-01, 0.17705000E+00, 0.27219900E+01, -.12533400E-01, -.18847500E+00, 0.12155700E+02, 0.34969300E+01, -.21388300E+01, -.17294700E+01, 0.48964100E+01, 0.31395200E-01, -.50602800E+01, 0.29631800E+01, 0.88071500E+00, 0.22769500E+00, -.10528700E+01, -.16159900E+00, -.12536700E+01, -.24514400E+00, 0.54119700E+00, -.54172300E+00, 0.26533500E-02, -.69642200E+00, -.14076500E+00, -.10837000E+01, 0.10110700E-01, -.53970200E+00, 0.17257400E+00, -.12785000E+00, 0.10219000E+00, 0.35069600E+00, 0.80467100E+00, -.23491200E+00, 0.48536000E+00, -.12621100E-01, -.24613100E+00, 0.60789700E-01, 0.19065000E+00, 0.17396700E+00, 0.11633400E+01, -.47366800E+00, -.11676900E+00, 0.69772500E-01, 0.10187800E+01, -.77160900E+00, 0.34661300E+00, 0.13882100E+01, 0.35180100E-01, 0.45298400E+00, -.72908400E+00, 0.10601200E-01, -.36652800E+00, 0.16540600E+00, -.67089700E+00, 0.45524300E+00, -.81686900E-01, -.49609700E+00, 0.44505900E+00, -.10869900E+00, 0.17264600E+00, -.38704400E+00, -.65062300E-01, -.27311100E+00, 0.31346700E-01, 0.43310300E+00, -.61709800E+00, -.12812800E+01, 0.17840800E+01, -.61266700E+00, -.87641200E-01, 0.67707000E+00, 0.16374500E+01, -.38818400E+00, -.25786900E+01, 0.49088000E+00, -.41867800E+00, 0.85715800E+00, -.55406700E+00, 0.30406900E+00, 0.12975000E+01, 0.13490700E+00, 0.34614800E+00, -.73662400E-01, -.48088200E+00, -.20053900E+01, -.79482700E+00, -.25960100E+00, -.71316100E+00, 0.21168200E+00, 0.51020800E+00, 0.10152300E+00, -.86875600E-02, -.19954100E+00, 0.14637200E+00, 0.22648400E+00, 0.42056900E+00, -.17583300E+00, -.28686600E+00, 0.71385600E+00, -.19797300E+00, 0.40407300E-01, -.60710900E+00, 0.46989800E-01, -.11551200E+01, 0.33570400E+00, -.13216900E+00, -.41524300E+00, 0.59939400E+00, 0.11344500E+01, 0.13606100E+00, -.44251000E+00, 0.38765900E+00, -.58642300E+00, 0.68369100E-01, -.63207600E+00, -.80958800E-02, -.18749300E+01, 0.57722500E+00, 0.32989000E-01, 0.56601300E+00, 0.25714500E+00, -.13971700E+01, 0.22251100E-01, 0.83947200E+00, 0.10364600E+00, -.18669100E+00, 0.35709500E+00, 0.31591700E+00, 0.39450200E+01, 0.55290700E+00, -.85671400E+00, 0.76350800E+00, 0.12317900E+01, 0.15873300E+03, -.46809800E+02, -.81492500E+00, -.89752700E+01, 0.11463200E+02, -.18466000E+01, -.63340200E+02, -.16477000E+03, 0.30543500E+02, -.16286600E+02, 0.25098000E+03, -.11621400E+03, -.13137700E+03, -.12421900E+03, 0.82441900E+02, -.10154600E+03, 0.12088600E+03, 0.33932300E+03, 0.25445800E+03, -.10415600E+03, -.41358200E+03, -.41411800E+01, -.17077500E+02, 0.25153800E+03, 0.31468700E+01, -.25314400E+02, 0.64218400E+01, 0.63489500E+00, -.38712100E+02, -.26079100E+02, -.11592600E+02, -.43409000E+02, -.23327800E+02, 0.14090700E+02, 0.17372500E+03, 0.11659200E+02, 0.65300600E+01, 0.57161100E+01, 0.30093700E+01, 0.56663400E+02, 0.61993100E+02, 0.14510400E+02, -.11268800E+03, -.23076600E+02, 0.23891400E+02, 0.13355000E+02, 0.11683900E+02, -.64696000E+02, 0.50170800E+01, 0.21827400E+00, -.30064000E+02, -.32343800E+02, 0.58206700E+01, 0.24378500E+02, -.18953600E+03, 0.68224700E+02, 0.36462300E+02, 0.94343000E+02, 0.30065800E+01, 0.56092400E+02, -.10220400E+02, -.82029700E+02, -.28390600E+02, 0.36998800E+02, 0.65124400E+02, 0.92490700E+02, -.32040300E+02, -.16671600E+03, -.44382500E+02, 0.75543400E+02, 0.32944000E+02, -.31408300E+02, 0.57412200E+02, 0.14200700E+03, -.34012300E+02, -.72192700E+02, 0.14654600E+02, -.34172200E+01, -.77353200E+00, 0.90058600E+00, -.67819300E+01, 0.22107300E-03, 0.43237600E+01, 0.15942700E+02, -.56459100E+01, -.55380700E+01, -.85440600E+01, -.50028400E+01, -.68188500E+01, 0.56576900E+01, 0.14580000E+02, 0.10270400E+02, 0.18144500E+00, -.22916900E+01, 0.30021400E+00, -.23627400E+01, -.28878400E+02, -.13452000E+02, -.36722700E+01, 0.74845700E+01, -.85797200E+01, -.54646700E+01 },
        { 0.10467700E+02, 0.42908800E+01, 0.98611500E+01, 0.55320300E+01, -.25559000E+01, -.31657200E+01, -.24509100E+01, 0.30632000E+01, 0.44782700E+00, 0.37083900E+01, -.13535800E+01, -.15544800E+01, -.20304100E+01, 0.17536300E+01, 0.15110200E+01, -.19131900E+02, -.93443400E+00, -.27036500E+00, -.21989700E+01, 0.85578700E+00, -.48759500E+00, -.51254800E-01, 0.34772100E+00, 0.27489300E+00, 0.40427400E+00, -.14576600E+00, -.97029600E+00, -.38058100E+00, 0.41247900E+00, -.16365100E+00, 0.17896400E+01, -.10582200E+01, -.14364800E+01, 0.51958600E+01, -.28296300E-01, 0.66652300E+00, 0.22594200E+00, 0.17750500E+00, 0.48524800E-01, 0.94005100E+00, -.42329000E+01, 0.11740000E+01, -.11822900E+00, 0.51969600E+00, 0.38820400E+00, -.63995000E+00, -.87628700E-01, 0.21046400E+00, 0.54685300E+01, -.34118900E+00, 0.33683000E+00, -.46118100E+00, 0.11860800E+01, -.65060900E+01, 0.34473300E-01, -.83541600E+00, -.47571700E+00, 0.26616300E+00, 0.32577800E+00, 0.26581700E+00, -.73546200E+00, 0.14199000E+01, -.35807700E+00, 0.14176200E+01, 0.13969200E+01, 0.30757700E-02, -.23028600E+01, -.34942100E+00, -.13549200E+01, -.32524300E-01, 0.32980000E-01, 0.29265300E+01, -.25611600E+01, -.83861900E+01, 0.77534300E+00, 0.28228100E+01, -.76251300E-01, -.20323900E+01, 0.13770200E+00, 0.21187300E+00, 0.48629300E-01, 0.13065800E+00, -.20694200E+00, -.23008000E+01, -.91106100E+00, 0.64247300E+00, 0.52312100E+00, -.44011600E+00, 0.28545700E+00, -.16109400E+00, -.14615800E+01, 0.21537900E-01, 0.12213900E+01, 0.53106600E+00, -.51966300E+00, 0.19906600E+01, 0.40590200E+00, 0.36712900E+00, 0.11221700E+00, 0.77287300E+00, -.13754000E+00, 0.98519300E-01, 0.13570800E+00, -.20336600E+00, -.17467200E+00, -.85653700E+01, 0.89699700E+00, 0.94244000E+00, -.62467500E+00, -.88438500E-01, -.56298000E+00, 0.46856800E-01, 0.17495900E+00, 0.94870300E-01, 0.45138100E+00, -.22125400E+00, -.34383800E+00, 0.21799200E+00, -.24988700E+00, 0.93505000E+00, -.35726800E-01, 0.28279500E-01, -.84519000E-01, -.35733000E+00, 0.77250400E-01, -.66982000E+00, 0.67515900E+00, 0.27897700E+01, -.61657400E+00, -.63340900E+00, -.77465800E+00, 0.31424800E+00, -.21579300E+01, 0.54064500E+00, -.10887500E+00, -.21679800E-01, 0.12534900E+01, 0.77892500E+00, -.43643900E+00, -.55880700E+00, -.18415200E+01, -.33588600E+00, -.74929500E-02, -.25610300E+00, -.81626000E-01, -.36801800E+00, 0.89932000E-01, -.46249400E+00, -.17110700E+00, 0.11706200E+01, 0.76960300E+01, 0.11342400E+01, 0.67691000E+00, -.59613900E+00, -.15450000E-01, -.10526300E+01, -.52768800E+00, -.13197500E-01, 0.12339900E+01, 0.15688000E-01, 0.12645800E+00, 0.21503800E+00, 0.30667400E+00, -.66657100E-01, 0.32420900E+00, -.10096000E+01, -.18639800E+00, -.47693300E+01, 0.59444600E-01, -.23626200E+01, 0.39549900E+00, -.22640400E+00, -.91356000E+00, 0.98295900E+00, -.35777900E+00, -.21373800E+00, -.13858900E+00, -.14480700E-01, 0.26138000E+00, 0.44941800E-01, -.83196500E-02, -.39867000E+00, -.15307800E+01, -.58161100E+00, 0.33427200E-01, -.59217700E+00, -.32275900E+00, 0.49093400E+00, 0.53397600E-01, 0.10982000E+01, -.77630400E+00, -.73374900E+00, 0.30175600E+00, -.17846800E+00, 0.15240700E+01, 0.40598000E+00, 0.13741800E+01, -.92500500E+00, -.41272400E+00, -.59769200E-01, 0.30123200E+03, -.80033900E+01, 0.90185600E+02, 0.86775200E+02, -.15772000E+02, 0.16287900E+02, -.42638800E+02, 0.83558500E+02, -.69915800E+02, -.64651100E+02, 0.34254500E+02, 0.69891200E+02, 0.33131200E+02, 0.21706400E+02, 0.73708900E+02, -.11527000E+03, -.15795800E+03, -.20117700E+02, 0.45735500E+02, 0.15795800E+03, 0.60705900E+02, -.48817900E+02, -.13141500E+03, -.31136500E+02, -.32376100E+01, 0.10152700E+02, -.16731900E+02, 0.43633600E+02, 0.15075900E+02, 0.21803000E+01, -.62252500E+02, -.50467700E+02, 0.25213100E+02, 0.17507900E+02, 0.25227600E+02, -.54330300E+02, -.18822000E+02, 0.10354800E+02, -.28949600E+02, 0.75773800E+01, -.33836300E+02, 0.14872400E+03, -.85207300E+02, 0.53335600E+02, -.58047100E+02, 0.44238300E+02, 0.15348900E+02, -.14099700E+02, 0.23355600E+02, -.36990200E+01, 0.74654500E+02, -.52353300E+02, 0.51183300E+02, 0.20180200E+02, -.17150700E+01, 0.37921200E+02, -.87555400E+01, -.59732800E+02, -.53386700E+02, 0.29909600E+02, -.51283900E+00, -.79823500E+02, -.33772000E+02, 0.28663900E+02, 0.47871000E+02, 0.21244800E+01, -.91981600E+01, -.18182300E+02, -.43146800E+02, -.75235100E+01, 0.61768500E+02, 0.37274400E+02, -.13590600E+02, -.14873400E+02, 0.11865100E+03, 0.47165400E+01, 0.10855800E+01, -.45040700E+02, -.47920400E+02, -.49560200E+01, 0.91201700E+01, 0.22212900E+01, -.10895900E+02, -.21219000E+01, 0.32969100E-01, 0.22645100E+01, -.43370900E+00, -.25448100E+01, 0.71667200E+01, -.99889400E+01, -.23922600E+02, 0.47529300E+02, -.12281800E+02, -.46242700E+02, 0.14522900E+02, -.34920000E+01, 0.21524000E+02, -.48084400E+02, -.11113700E+01, -.69917700E+01, 0.37903600E+01 },
        { 0.15834600E+02, 0.36936600E+01, -.43303500E+01, -.29542200E+01, -.90956100E+01, -.50148000E+01, -.23540300E+01, -.16508800E+02, 0.17256600E+01, -.26410400E+01, -.30777800E+01, -.43701300E+00, -.20587300E+01, 0.64076200E+00, -.22546500E+00, 0.23170500E+02, -.10377800E+01, 0.70599500E+01, -.61163300E+00, -.25308600E+01, -.55211300E+01, 0.13456100E+01, -.51768600E+00, -.96170300E+00, -.50066700E+00, 0.15819400E+01, 0.11772900E+01, 0.40697100E+01, -.17075800E+00, 0.23264900E+00, 0.68912400E+00, 0.30828900E+01, 0.23282300E+00, -.43548900E+01, 0.13816600E+00, -.17978600E+00, -.50708300E+00, -.15585300E+01, 0.12055600E+00, -.24466300E+01, -.19965800E+01, 0.11842300E+01, 0.41826800E+00, -.13309100E+00, -.25958300E+00, 0.85098800E+00, 0.20691900E-01, -.33156600E+00, 0.19861000E+01, 0.20481000E+00, -.17785200E+00, 0.37751700E+00, 0.50104400E-01, 0.25428600E+01, 0.10990600E+01, 0.31820000E+01, 0.16463600E+01, 0.58523500E+00, -.25467200E+00, 0.51856900E+00, 0.38510500E-01, -.39970900E+00, 0.49509500E+00, -.84364900E+00, -.59089400E+00, -.54127200E+00, -.63103800E+00, 0.16578400E+00, 0.74080300E+00, 0.33942900E-01, 0.11375600E-01, 0.28640800E+01, 0.20756300E+01, 0.97276300E+00, -.82301900E+00, 0.85204100E+00, 0.88346300E-01, -.83966900E+00, -.51527900E+00, -.14201000E+00, -.11441400E+00, -.68882700E-01, 0.45950600E-01, -.24458800E+00, -.14000800E+00, 0.30145400E+00, -.14343900E+00, -.77331100E-01, 0.37465500E+00, 0.18662100E+00, 0.25365400E+00, 0.39059400E-02, 0.55724900E-01, 0.63960600E-01, -.54926500E+00, 0.49793900E+00, 0.81659200E+00, 0.24475500E+00, -.17193700E+00, 0.14734300E+00, 0.21571300E+00, -.49913100E-01, -.85711200E-01, 0.36601000E+00, 0.26611300E+00, -.84399600E+00, -.54594800E+00, 0.33444900E+00, -.72470900E-01, 0.11798000E+01, -.29489400E+00, -.72836500E-01, -.82831100E+00, -.22937700E-01, 0.17543300E+01, 0.59806500E-01, -.32165900E+00, -.17154500E+00, -.13602800E+00, 0.22290900E+01, 0.14437800E+01, -.26685600E+00, 0.61525500E-01, 0.64169500E+00, -.34485000E+00, 0.84357200E+00, 0.40509300E-01, -.11141800E+01, -.43686200E+00, -.66460700E+00, 0.12681400E+01, -.43072300E+00, -.81090700E+00, 0.16043600E+01, -.47243400E+00, -.12629500E+00, -.11016000E+01, 0.14191500E+01, -.29682000E+00, -.11798300E+01, 0.11706400E+01, -.32541800E+00, 0.10988200E+01, 0.15671800E+00, 0.10569200E+00, 0.73878700E+00, 0.85605300E-01, -.58722200E-02, 0.19601900E-01, -.70840400E+00, -.48475000E+01, -.17984700E+01, -.51498800E+00, -.20964700E+01, 0.35229700E+00, 0.12691400E-01, -.37268400E+00, 0.35647100E-01, 0.89068300E+00, 0.75499800E+00, 0.71023900E-01, 0.25420100E+00, -.20609900E+00, -.31836800E+00, 0.89153600E+00, 0.96503800E+00, 0.18936000E+00, 0.11525800E+00, -.67968900E-01, -.11462800E+01, 0.20482300E+00, -.34917100E+00, -.23867000E+00, 0.57259900E+00, 0.59097300E+00, 0.35784400E+00, -.17469200E-01, 0.49801800E-01, -.13829900E+01, 0.70230100E-01, -.11229500E+01, -.88408000E+00, 0.79004000E+00, 0.18626900E+01, -.98897900E-01, 0.37094600E+00, 0.23753800E+00, -.10832800E+01, -.49882900E-01, 0.94015300E+00, -.80581400E+00, 0.12916200E+00, 0.56578300E+00, 0.16942100E+00, 0.28036800E+01, 0.13215400E+00, -.70801300E+00, 0.77793700E+00, -.30097300E+00, 0.17308300E+00, -.22308000E+00, 0.33202700E+02, 0.30538600E+02, 0.35211700E+02, -.39543800E+02, -.60513200E+02, -.69822100E+02, 0.46221400E+02, -.20162300E+01, -.26162400E+03, 0.12477600E+03, 0.16482500E+03, 0.12967600E+03, 0.24234600E+02, -.90186600E+01, 0.11027200E+03, 0.80070200E+02, 0.22771500E+03, -.18568500E+02, 0.77078700E+02, 0.78523300E+02, -.68616800E+02, -.22667400E+02, -.38291600E+02, -.32017000E+02, 0.14148000E+02, -.34833100E+02, 0.19032400E+01, -.20014500E+02, -.62658300E+01, -.62753100E+02, -.36324300E+03, 0.18075500E+03, 0.25876700E+03, 0.18171300E+03, 0.29950900E+02, 0.31401500E+02, 0.49908000E+02, -.51407700E+02, 0.12960700E+03, 0.29852600E+02, 0.16211000E+03, -.13643700E+03, 0.92566700E+02, -.94714200E+02, 0.62249300E+02, -.15073900E+02, 0.34096600E+01, 0.32297600E+02, -.46217300E+01, 0.66701800E+02, -.32484900E+02, 0.23912300E+03, 0.44633100E+02, -.10659100E+02, -.85702400E+02, -.26260100E+02, -.29148100E+02, -.23919300E+02, -.76421200E+01, -.97481300E+01, -.44488200E+02, -.24349800E+02, -.33393100E+02, 0.36385100E+02, 0.15212000E+02, -.24845400E+03, -.24077100E+02, 0.85006100E+02, 0.47797100E+02, 0.47413900E+01, 0.57889000E+01, 0.88990500E+02, 0.26679300E+02, -.20088000E+01, 0.27585100E+01, -.57067800E+01, -.12584100E+02, -.13602700E+02, -.42996900E+01, -.63625800E+00, -.56036200E+01, 0.95886600E+01, -.28134000E+01, -.59995200E+01, -.88212000E+01, -.37706700E+01, -.14166400E+02, 0.63239700E+01, 0.96347600E+01, -.49951100E+01, 0.14379900E+02, -.17216000E+02, -.12270700E+02, 0.11456200E+01, -.20154800E+02, 0.16353900E+00, -.65337600E+02, 0.10109600E+02, -.13970100E+02, 0.59264800E+01 },
        { -.20430300E+01, 0.13567000E+00, 0.26227300E+00, 0.17043700E+00, 0.15136100E+01, 0.43550400E+00, -.10088500E+00, 0.31864200E+01, -.26006200E+00, 0.75215700E+00, 0.68093100E+00, 0.22851900E+00, 0.40080100E+00, -.10244800E+00, -.63327300E+00, -.85864900E+00, 0.32366800E+00, -.12001800E+00, 0.10890700E+00, 0.10536500E+00, -.25025700E+00, -.10606000E+00, 0.10086600E+00, 0.62936900E+00, -.42130300E-01, 0.28259100E-01, 0.63092900E+00, 0.49381900E+00, -.81360600E+00, 0.16890700E-01, 0.10835800E+00, 0.83491000E+00, -.49774800E-01, -.10182600E+01, -.16817100E-01, 0.81242700E-01, -.10976000E-01, -.22970900E+00, -.14880700E+00, -.30832900E+00, 0.11985400E+01, -.11955400E+00, 0.46427100E-01, 0.55470100E-01, -.66704300E-01, -.17761300E+00, 0.54224800E-01, -.12786600E-01, 0.12217600E+00, 0.10577500E+00, -.47250700E+00, 0.57163600E+00, -.14721000E+00, 0.16592300E+01, 0.99297100E-01, 0.57256900E+00, 0.63004900E+00, 0.39821000E-01, -.65395900E-02, 0.41862800E+00, -.25994500E-01, -.31408700E+00, 0.27725600E+00, 0.81731400E-01, -.19234900E+00, -.28133600E+00, 0.12404900E+00, 0.51643900E-01, -.36776700E+00, -.15918900E-01, -.83928600E-01, -.48369000E+00, -.20382000E+00, 0.35624700E+00, 0.16677400E+00, -.23760100E+00, 0.38251500E-01, 0.11731200E+00, 0.10069400E-01, -.10548700E-01, 0.39203600E-02, 0.61190500E-01, -.18692200E+00, -.94014400E-01, -.15769400E-01, 0.81618700E-01, -.22888400E+00, -.14868600E-01, -.21360500E+00, -.58753800E-03, -.25186600E+00, -.13067000E-03, -.16067400E+00, 0.74299700E-01, 0.48063500E+00, 0.24016300E+00, 0.78889900E-01, 0.36956200E-01, 0.68904100E-01, 0.15996600E+00, 0.15276800E-01, -.14937800E-01, 0.15936100E-01, -.14939600E+00, 0.15220400E+00, 0.53968500E+00, -.23256100E+00, 0.32690400E+00, -.36885100E-01, -.22420800E-01, 0.15734300E+00, -.19414700E-01, 0.18896800E+00, 0.17574800E-01, 0.33725100E-02, 0.30436000E+00, 0.39562000E-01, -.95473000E-01, -.31292900E+00, -.69880600E+00, 0.23019900E-01, 0.24833200E-01, -.13977400E+00, 0.22051800E-01, 0.25518800E-01, 0.58344600E-01, -.12065700E-01, 0.32839300E+00, 0.67682300E-01, -.96518200E-01, 0.11314600E+00, -.56650000E-01, -.21886900E+00, 0.52412100E+00, 0.38145200E-01, 0.10688700E-01, -.53553300E+00, -.49163500E-01, -.16204100E-01, 0.50035600E+00, 0.38583000E+00, -.86468400E-02, 0.60924700E+00, 0.15703100E+00, 0.25638500E-02, 0.14037300E+00, 0.10952200E-01, -.25306500E-01, 0.21091400E-01, -.15382700E-01, -.18382100E+00, -.26422100E-01, -.31358600E-01, -.59668000E+00, 0.16296100E-01, 0.18932300E+00, -.89957000E-01, -.35263600E-02, 0.10062500E+00, 0.12978400E+00, 0.72408500E-01, 0.17601800E+00, -.77964900E-01, 0.27192200E-01, 0.70514100E-01, 0.13668200E+00, 0.25359800E-01, -.62722200E+00, 0.16107100E-01, 0.60211200E-01, -.61571400E-01, 0.37552000E-02, -.11132900E+00, 0.14547200E+00, 0.41060400E+00, 0.93755900E-02, -.16696000E+00, 0.10672900E-02, 0.88373600E-03, -.30187600E-01, -.15717200E+00, -.27408600E+00, -.27912200E+00, 0.15937100E-01, 0.65694100E-01, -.26598900E-01, -.11043300E-02, -.65105500E-01, 0.11935800E-01, 0.24454900E+00, 0.55648300E-01, -.54355400E-01, 0.13786800E+00, -.16222700E+00, 0.89405000E+00, 0.15918900E+00, 0.39778600E+00, 0.28829700E+00, -.14809300E+00, 0.49726600E-01, -.58902800E-01, -.74189500E-02, 0.22516800E+02, 0.24207100E+02, -.33939200E+02, 0.54141500E+01, -.28564200E+01, 0.24213800E+02, -.79307100E+00, 0.26218800E+02, -.15179400E+02, -.14250800E+02, -.13734700E+02, 0.96121600E+01, -.49899800E+02, 0.70950300E+02, 0.64622800E+02, 0.44691400E+02, -.33287500E+02, -.92830700E+02, 0.10997300E+03, -.59524100E+02, 0.69464600E+01, -.54637700E+02, -.11995500E+02, -.25753900E+01, -.22494600E+02, 0.22168900E+02, -.18111700E+02, -.67665600E+01, -.52889600E+02, -.86484900E+02, 0.42582300E+02, 0.64007000E+02, 0.43256300E+02, 0.72087800E+01, 0.87767800E+01, 0.32656200E+01, -.13440300E+02, 0.33619700E+02, 0.11527600E+02, 0.40317800E+02, -.51363500E+01, 0.68419500E+01, -.33547100E+02, 0.21449600E+01, -.51629500E+01, 0.11277200E+02, -.12154400E+02, 0.11454400E+02, 0.13185100E+02, -.76796600E+00, 0.65908300E+02, 0.29164400E+02, -.12460400E+02, 0.48747200E+01, -.14506700E+02, -.99207400E+00, 0.17127100E+02, -.24736200E+02, -.61039000E+00, -.12399300E+02, 0.12853100E+02, -.21763800E+02, 0.48979200E+02, -.20681300E+02, -.10352500E+03, -.24562000E+02, 0.11084500E+02, 0.50489900E+02, -.48392400E+02, -.23647800E+02, 0.68851500E+01, 0.42934500E+02, 0.82232200E+02, 0.64954000E+01, 0.83242300E+00, -.13283800E+02, -.14342300E+02, -.37319200E+00, -.30254700E+01, -.21591800E+01, 0.16062100E+01, -.19857400E+01, 0.29136100E+00, 0.10405300E+00, -.63420300E+00, -.53377600E+01, 0.83855300E+00, 0.13237700E+01, -.20810900E+01, 0.14583100E+02, -.71665200E+01, -.13665000E+02, -.10481100E+01, -.81760500E+01, 0.29553900E+01, -.43479200E+01, 0.27895800E+00, -.48346900E+01, -.86243700E+00 },
        { 0.22212700E+01, -.15961400E+00, 0.80376700E-01, 0.34456200E+00, -.19979800E+01, -.81078700E-01, 0.63008300E+00, -.47977300E+01, 0.36224000E+00, -.11847700E+01, -.84108800E+00, -.97964700E-01, -.54504200E+00, 0.17026000E+00, 0.37764900E+00, 0.85837900E+01, 0.35957700E+01, 0.11077700E+01, 0.57999100E+00, 0.10567200E+00, 0.42816100E+00, 0.19676100E+00, -.17277000E+00, 0.39906200E+00, -.14479700E+00, -.18191000E-01, 0.26793300E+00, 0.74785000E+00, -.10873700E+01, 0.60681300E-01, -.51325800E+00, -.53101500E+00, 0.53167400E+00, 0.23212900E+01, 0.15699400E-01, -.10662200E+00, 0.22174300E-01, -.12658000E-01, 0.72925800E-01, -.54558900E+00, 0.85147600E+00, 0.63040600E+00, -.53366900E-02, -.63894700E-02, -.49982200E+00, 0.36754300E+00, -.37297500E-01, -.14660500E-01, -.85626200E+00, 0.35782500E-03, -.17351900E+00, 0.13718800E+00, -.28235800E+00, 0.15250600E+01, 0.11806400E-01, 0.76441700E+00, 0.64615400E+00, 0.93223500E-02, -.25246200E-01, 0.56398000E+00, 0.35943000E-01, -.23638500E+00, 0.27424400E+00, -.81111000E-01, -.26922400E+00, -.59777000E+00, -.54837200E+00, 0.63952300E-01, 0.36572100E-01, -.90222700E-02, -.58840400E-01, 0.13095000E+01, 0.33820400E+00, 0.45198500E-01, -.41352400E+00, -.31933300E-03, -.91346800E-01, -.27158300E-01, -.37322900E+00, -.51239600E-01, 0.80447200E-02, -.37962400E-02, -.11048500E+00, -.73855500E-01, -.38983800E-02, 0.47703300E-01, 0.20701400E+00, 0.26922400E-01, 0.19279300E+00, 0.70694600E-01, 0.34556200E-01, 0.20574800E-02, 0.34305700E+00, -.54122800E-01, 0.18686000E-01, 0.49219400E+00, 0.62558800E-01, -.32150600E+00, 0.16283500E-02, 0.50357800E-01, 0.21983900E-01, -.40761300E-01, -.19235900E-01, 0.18108300E+00, -.11908900E+00, -.39009800E+00, 0.57605700E-03, -.19548000E+00, -.11272800E-02, 0.16743200E+00, -.18631400E+00, -.47051800E-01, -.12115500E+00, -.15662500E-01, 0.87232400E-01, -.39436300E+00, -.49873200E-01, 0.22088000E+00, -.21790600E+00, 0.68749800E+00, -.20921700E+00, 0.28075300E-01, 0.15204900E+00, 0.15926800E+00, -.28211500E-02, 0.10374900E-01, 0.25134700E+00, -.61650300E+00, -.15154900E+00, 0.36630600E-01, -.15731300E+00, 0.96168300E-01, 0.16163900E+00, -.34522400E+00, -.44996700E-02, -.98021100E-03, -.40631500E-01, 0.16011700E+00, -.53060300E-01, -.40272000E+00, 0.28764800E+00, -.11834900E-02, -.51734000E+00, -.12651500E+00, -.81207400E-02, 0.33194700E+00, -.67497200E-02, -.19196600E+00, 0.81818100E-01, -.16498800E+00, 0.50118800E-01, -.61420200E-01, -.51106300E-01, -.69367700E-02, -.49300000E-02, 0.65403900E+00, -.17042600E-01, -.39770900E-02, -.21946900E+00, 0.10365200E+00, 0.49626700E-01, -.27207100E-01, -.46468500E-01, -.17277400E+00, -.10406300E+00, 0.26046500E-01, 0.40942000E-01, 0.25463100E+00, 0.75968800E-02, -.28037900E+00, 0.15606900E+00, -.56945100E-01, -.94830700E-02, 0.37953900E-01, 0.45344200E+00, 0.19490200E+00, 0.61089100E-01, -.16165200E-01, 0.75602500E-01, -.64395700E-01, -.15547000E+00, -.12267800E+00, -.39894100E-01, -.12417200E+00, 0.56634700E-01, -.11091100E+00, -.71460800E-01, 0.53322700E-01, 0.15803900E-01, 0.10557000E+00, 0.47674500E+00, -.15182300E+00, -.21593100E-02, -.14268800E+00, 0.17729400E+01, 0.17441100E+00, 0.96374800E+00, 0.59035100E-01, 0.25293600E+00, 0.98794600E-01, 0.17526800E+00, 0.25984000E-01, -.10590100E+01, 0.24582600E+02, -.70313300E+02, -.12293900E+02, 0.34360600E+02, 0.32587400E+02, 0.75295100E+02, -.84629900E+00, -.72965800E+01, 0.52363400E+02, -.14982000E+01, 0.10863300E+02, -.48700700E+02, 0.14994500E+03, 0.82572700E+02, -.13093800E+02, -.31751500E+01, -.20739300E+03, -.80862800E+01, -.70122200E+01, 0.62754400E+01, 0.49605800E+01, -.34360200E+02, 0.28969000E+01, 0.77135500E+01, -.11864000E+01, -.16778400E+02, 0.22855000E+00, 0.54160000E+01, 0.86416900E+02, -.41795600E+02, -.49360200E+02, -.43175500E+02, 0.20609200E+02, -.11376500E+02, 0.31217700E+01, 0.39558900E+02, -.18019500E+02, 0.38257100E+01, -.12158300E+03, 0.59826500E+02, -.19246000E+02, -.63135500E+02, -.30993300E+02, -.24207100E+02, -.19275600E+01, -.11483600E+02, 0.77470100E+02, -.36199100E+02, 0.30407200E+01, 0.21921400E+03, 0.53046700E+02, -.19879100E+02, 0.79296700E+01, -.26274600E+02, -.81918500E-02, 0.19606100E+02, -.19987500E+02, 0.11830300E+02, 0.44094400E+02, 0.20081300E+01, -.60660900E+02, -.32077300E+02, 0.21782200E+02, -.61376400E+02, 0.14905600E+02, 0.86237200E+02, 0.11876300E+03, -.10315900E+03, -.12017300E+03, 0.41135200E+01, 0.12870900E+03, -.20155100E+02, -.95373300E+01, 0.67217800E+01, 0.12873700E+02, 0.11854500E+02, 0.80494200E+01, -.15455000E+02, -.14441000E+02, -.13276500E+01, -.60816700E+01, 0.48629400E+01, 0.25074600E+01, 0.39240900E+01, -.15102800E+02, -.75526900E+01, -.15240000E+01, -.26643200E+01, -.11626600E+02, -.14352900E+02, 0.12239900E+02, -.12833600E+02, -.29729500E+02, -.67689200E+00, 0.17993100E+01, -.85055600E+01, -.14926500E+02, 0.75383000E+01 },
        { -.30984300E+01, -.72869400E+00, 0.45967400E+00, 0.88369700E+00, 0.24716200E+01, 0.75628300E+00, 0.39279400E-01, 0.25499600E+01, -.22921800E+00, 0.10897800E+01, 0.57461700E+00, 0.16218200E+00, 0.33821100E+00, -.20134900E+00, -.58899800E-01, -.43570800E+01, 0.70808200E-01, -.99054300E+00, -.37265700E+00, 0.10485300E+00, 0.72015700E+00, 0.76433500E-01, 0.46949000E-01, 0.52968900E+00, 0.29720200E-01, 0.31173900E-01, 0.83169900E+00, 0.68713500E+00, -.20670300E+01, 0.50292600E-02, 0.36967700E-01, 0.10626900E+01, 0.27021400E+00, -.10860900E+01, -.19276800E-02, -.39661300E-02, -.16530100E-01, -.18601600E+00, -.10507900E+00, -.16527000E+00, 0.18557400E+01, -.45029500E-01, -.21335800E-01, 0.10055600E+00, -.22362500E+00, -.33295600E+00, 0.52496200E-01, -.34379400E-01, -.47027000E+00, 0.10226900E+00, -.57363300E+00, 0.25994000E+00, 0.33947200E-01, 0.85203500E+00, 0.15009800E+00, 0.11076900E+01, 0.49098700E+00, -.81489000E-01, -.29730700E-01, -.17686800E+00, 0.96390800E-01, -.11705800E+01, 0.16399600E+00, -.12673900E+00, 0.15579000E+00, -.34087400E+00, 0.25229700E+00, 0.16555200E+00, 0.67450200E+00, -.32831200E-02, -.12418800E-01, 0.32645400E+01, 0.17909400E+00, 0.20622600E+00, -.79075800E+00, -.86000900E+00, -.16692400E-01, -.42175300E-01, -.41015300E+00, 0.66666300E-03, 0.49741700E-01, -.25955900E-01, -.12872200E+00, 0.55620200E+00, 0.17351400E-01, -.13893300E+00, -.22010700E+00, 0.19389400E+00, -.97459600E+00, -.16508300E-02, -.47278800E+00, -.54421700E-02, -.10379400E+00, -.10719700E+00, 0.14808600E+01, 0.30102800E+00, 0.26016600E+00, -.14853400E+00, -.66260900E-01, -.29152200E-02, -.25419600E-01, -.97762300E-01, 0.65634300E-03, -.91170900E-01, -.13195200E-01, 0.11071000E+01, -.14490300E-01, -.20070400E+00, 0.68440100E-01, -.77257600E-01, -.39012500E+00, 0.66771500E-02, -.41713200E+00, -.39601400E-02, -.11447000E+00, -.65452600E+00, -.13202800E+00, 0.28920900E+00, -.75732400E-02, -.69837600E+00, -.83388600E+00, 0.43396300E-01, -.27982800E-01, 0.39274400E+00, -.10067100E-02, 0.39033400E+00, 0.38819500E+00, -.76122200E-02, 0.59870800E-01, -.53104800E-01, 0.42444900E-01, 0.29911100E+00, 0.19572700E-01, -.46959500E+00, -.66774300E-01, 0.23732100E-01, -.41972700E+00, 0.17946600E+00, -.70271900E-01, -.24848600E+00, 0.56155300E+00, 0.96723200E-01, -.29296000E+00, -.20674000E+00, -.48103600E-01, -.11086900E+00, -.39329800E-01, 0.30561900E+00, -.20034400E-02, 0.24455900E+00, 0.40306000E-01, -.51740700E-02, -.53711500E-01, -.26006200E+00, 0.70294000E-01, -.12104200E+00, 0.14702400E+00, -.30559000E-02, -.11791900E+01, -.36382900E+00, -.93341300E-01, 0.42199600E-01, 0.28908900E-01, -.28959000E-01, 0.41923800E+00, -.45341600E+00, 0.42044000E-01, 0.50340300E+00, 0.16060400E-01, -.44854000E+00, 0.85384800E-01, -.74054200E-02, -.10085400E+00, 0.19484500E+00, 0.26980800E+00, -.20284700E+00, -.64267700E-01, 0.58812000E-03, -.12958700E-01, -.22564500E-01, -.26568700E+00, 0.32215900E+00, 0.34643100E-01, -.11958300E+00, -.12654000E+00, 0.20912500E+00, 0.13288600E-01, -.18058700E+00, 0.24658900E-03, -.12296200E+00, -.70953100E+00, -.14696300E+00, -.24634000E+00, 0.12177800E+00, -.49027900E+00, -.14532100E+00, 0.31175500E+00, -.30088200E+00, 0.29093100E+00, -.74673500E-01, 0.15333000E+00, -.13439900E-01, 0.18520300E+00, 0.90864200E+00, 0.72071800E+02, -.29636700E+02, -.36662100E+02, -.61623000E+01, -.37804600E+02, -.73913400E+02, 0.46927900E+02, 0.15863800E+02, 0.39851600E+02, -.29996800E+02, 0.11085500E+03, -.18434100E+03, -.16221800E+03, -.54274000E+02, 0.63340600E+02, 0.20273100E+03, -.15583900E+03, 0.89762700E+02, -.21152300E+00, 0.76751000E+02, 0.38859100E+02, -.61488000E+01, 0.37037200E+02, -.11587600E+02, 0.34643700E+02, 0.40775000E+01, 0.72682700E+02, 0.11634900E+03, -.57928700E+02, -.50802700E+02, -.58222100E+02, -.37357300E+02, -.11892000E+02, -.16005100E+02, -.11174900E+02, -.49593000E+02, -.28993400E+02, -.89776700E+02, -.66814100E+02, 0.20416900E+02, 0.86363800E+02, 0.34947100E+02, 0.28691900E+02, -.28858700E+02, 0.35667600E+02, -.69403500E+02, 0.14527800E+02, -.18741800E+02, -.17594600E+03, -.63019400E+02, 0.23922600E+02, 0.29810300E+02, 0.31074600E+02, -.75644200E+01, -.45742900E+02, 0.49365400E+02, 0.37220600E+01, -.84519700E+01, -.31377800E+02, 0.76372500E+02, -.78236600E+02, 0.34311900E+02, 0.20564900E+03, 0.40955300E+02, -.39262200E+02, -.16123800E+03, 0.18394600E+03, 0.13605100E+03, 0.31179500E+01, -.15714500E+03, -.17739900E+03, -.10551500E+02, -.10159600E+02, 0.74387200E+01, 0.91598900E+01, -.61577100E+01, 0.10942700E+02, 0.10798600E+02, 0.11947900E+01, 0.71678000E+01, -.75732900E+01, -.66173600E+01, -.26019900E+01, 0.16349300E+02, 0.56476500E+01, 0.64830300E+00, 0.24070400E+01, -.95232500E+01, 0.16798200E+02, 0.81509100E+01, 0.84206500E+01, 0.28001400E+02, -.10744900E+01, 0.21835200E+02, 0.87010500E+01, 0.14925300E+02, 0.15343000E+01 },
        { -.79291400E+01, -.20988500E+01, 0.35669500E+00, 0.25589500E+01, 0.25793400E+01, 0.16739800E+01, 0.45501900E+00, 0.31402500E+01, -.48568400E+00, 0.99561000E+00, 0.68555200E+00, 0.60399900E+00, 0.23455700E+00, -.34384500E+00, -.84167200E+00, 0.63217300E+01, -.51230900E+01, -.37080500E+01, 0.23921500E+01, 0.27183000E+00, 0.15589400E+01, 0.76126300E-01, 0.18225500E+00, 0.27806900E+01, -.10120300E+00, 0.24083100E+00, 0.17128100E+01, 0.33310500E+01, -.35596000E+01, 0.26065200E+00, -.13187400E+01, 0.58680300E+00, 0.14409500E+01, -.72612300E+01, -.27717900E-01, -.41824700E+00, -.97973800E-01, 0.13762100E+01, -.29560900E+00, -.13514800E+00, 0.33683200E+01, -.63080800E+00, -.10663600E+00, 0.38904700E+00, -.42077500E+00, -.15391400E+01, 0.20433700E+00, -.14343500E+00, -.13230100E+01, 0.60539900E-01, -.94004800E+00, 0.20230900E+01, 0.34382200E+00, 0.44252400E+01, 0.91153400E+00, 0.20628400E+01, 0.11081700E+01, -.14706800E-01, -.17540500E+00, -.10429200E+01, 0.48461500E+00, -.10350100E+01, 0.97104400E-01, -.22442200E+00, -.84304500E+00, 0.35700700E+00, 0.14872700E+01, 0.62160400E+00, -.18484300E+01, -.44584500E-01, -.20662400E+00, -.10430900E+01, -.24882300E+01, -.65390100E+01, 0.21078200E+01, -.70228000E+00, -.40026300E+00, -.12449800E+01, 0.43196900E+00, -.17483300E+00, -.20550300E+00, 0.15741000E+00, 0.99828100E-01, 0.79639800E+00, -.91383900E+00, -.10783900E+01, -.39035900E+00, -.40326200E-01, 0.19868600E+00, 0.62671500E-01, -.10770400E+01, -.84782200E-02, 0.58532800E+00, 0.21278600E+00, 0.12702900E+01, 0.21147400E+01, -.10061200E+00, -.74836000E+00, 0.79714400E+00, -.24552400E+00, 0.13532600E+00, 0.28545700E+00, -.16692700E-01, -.18586800E+00, -.34860500E+00, 0.80064800E+01, -.45948200E+00, -.63849400E+00, 0.28434400E-01, 0.88476000E+00, -.53586900E+00, -.16244100E+00, 0.19583100E+01, -.51440200E-01, 0.43965600E+00, 0.16184400E+01, -.18861300E+00, -.58812200E+00, -.25502800E+01, 0.30891400E+01, -.85492500E+00, 0.82353400E-01, 0.19625500E+00, -.10518500E+01, 0.15404000E+00, -.89655000E+00, -.68522000E+00, -.11861300E+01, -.52570300E-01, 0.30715400E+00, -.12538400E+01, 0.75115600E+00, 0.19796800E+00, -.55353900E+00, 0.47368700E+00, 0.30260100E-01, -.43816100E+00, -.15145500E+01, 0.68194200E-02, 0.10185400E+01, 0.65695500E+00, 0.23081900E+00, -.11264700E+00, -.11053000E+00, -.15708400E+00, -.73625300E+00, -.11829600E+00, 0.13326100E+00, -.12818300E+00, 0.11354100E+01, -.82392500E-01, 0.57877900E+00, 0.49586300E+00, -.58703300E+00, -.13535000E+00, -.73358700E+00, -.53113900E-01, 0.62656900E-02, -.45868100E-03, -.24141600E+00, -.24796000E+00, -.42627800E+00, 0.12384100E+00, 0.44593900E+00, -.50391400E+00, -.15226000E+00, -.16151400E-02, 0.12601800E+00, -.46087100E-01, 0.93882600E+00, -.84553200E-01, -.53670300E-01, 0.21137900E+00, -.22910000E+00, -.90139600E+00, -.19931100E+00, 0.13985100E+00, -.48090100E-01, 0.10376600E+00, 0.18665000E+00, 0.94098100E+00, -.64805000E+00, -.64156400E+00, -.58555500E+00, 0.35538600E+00, 0.10267500E-01, -.51161900E-01, 0.11801000E+00, 0.42094800E-01, 0.64882800E-02, -.44303100E+00, 0.13012500E+00, -.30006100E-01, -.29230000E+00, 0.13940100E+00, 0.19340300E-02, 0.10053100E+01, -.41218400E+00, 0.11850500E+00, -.47036100E-01, 0.22526100E+00, 0.11449900E+00, -.56108100E+00, -.35720400E+00, -.27270400E+00, 0.11530300E+03, 0.82681000E+02, -.95810000E+01, 0.61229200E+02, 0.99893500E+02, -.53675900E+02, -.11954500E+03, -.48395200E+02, -.37452200E+02, 0.23539000E+02, -.80368700E+02, -.14032300E+03, -.22467400E+03, 0.39338400E+02, 0.65311000E+02, -.13925100E+03, 0.73890000E+02, 0.14373900E+03, 0.69193600E+02, 0.57720500E+01, 0.33717200E+01, 0.49985800E+02, 0.74265400E+01, 0.35973500E+02, 0.22279600E+02, 0.12533600E+02, 0.25914200E+03, -.12885900E+03, -.20978500E+03, -.12962000E+03, -.40513900E+02, -.37169500E+02, -.24085000E+02, 0.66199700E+02, -.67460900E+02, -.42930900E+02, -.89830800E+02, 0.11900800E+03, -.61608100E+02, 0.53218200E+01, -.58213200E+02, 0.35794700E+02, -.81149400E+01, -.20285900E+02, 0.66807200E+02, -.32197200E+02, 0.94889300E+01, -.17948300E+03, 0.24118100E+02, -.10133200E+02, 0.54629300E+01, -.12288900E+02, 0.12776100E+02, 0.10472800E+02, -.12298200E+02, 0.90206200E+01, 0.35536500E+02, 0.11711000E+02, -.40569700E+02, -.17153300E+02, 0.14036600E+01, 0.52170700E+02, 0.69979500E+01, -.37366900E+02, -.30736700E+01, -.30463700E+02, -.76756700E+02, -.10478500E+03, 0.40912700E+02, -.49517500E+02, -.68730300E+01, 0.71552200E+01, 0.93852100E+01, 0.85935700E+01, 0.66782500E+01, -.39504100E+01, -.11298900E+00, -.91454200E+01, 0.77779900E+00, 0.48498700E+01, 0.38040500E+01, 0.64714200E+01, 0.45692500E+01, -.79919000E+01, -.90320800E+01, 0.15734100E+01, -.89033500E+01, 0.32522500E+01, 0.83314000E+01, -.64059600E+01, 0.94984900E+01, -.19898200E-01, -.84283400E+01, -.67160700E+01, 0.37833200E+01, -.61561000E+00 },
        { 0.90888100E+01, 0.36917800E+01, 0.84063000E+01, 0.34544800E+01, -.16634400E+01, -.26981800E+01, -.28801700E+01, 0.82218300E+01, 0.32883300E+00, 0.28766700E+01, -.97210300E+00, -.18719200E+01, -.13969200E+01, 0.53014100E+00, 0.16723100E+01, -.28520400E+02, 0.10731600E+01, -.31192900E+01, -.40514600E+01, 0.20236300E+01, 0.36662600E+01, -.78473300E+00, 0.10683700E+00, -.22582400E+01, 0.64850900E+00, 0.70132700E-01, 0.10693200E+01, -.41632200E+01, -.13381500E+01, 0.18681800E+00, 0.11854900E+01, -.19867500E+01, 0.70498200E+00, 0.31115900E+01, -.67582300E-01, 0.45836800E+00, 0.18889900E+00, 0.65724500E+00, 0.20227500E+00, 0.10699100E+01, -.26009400E+01, 0.77892800E+00, -.19626000E+00, 0.30866400E+00, 0.62818400E+00, -.15024900E+01, 0.10374800E+00, 0.15660700E+00, 0.61339600E+01, -.48731400E+00, 0.24579200E+01, 0.30611100E+01, 0.18633000E+00, 0.19165200E+01, 0.55017600E+00, -.29351600E+01, -.34903200E+00, 0.42788900E+00, 0.11068600E+00, -.10043700E+00, -.76251000E+00, -.13205400E+00, -.18782700E+00, 0.24217500E+01, 0.11799500E+01, 0.10767600E+01, 0.48146600E+00, -.81436500E+00, -.11976000E+01, 0.25222500E-01, 0.92765300E-01, -.72940600E+01, -.28098700E+01, -.57639000E+01, 0.25175000E+01, 0.23881300E+01, 0.18633900E+00, -.19113800E+01, 0.27179100E+01, 0.87811000E+00, -.14088400E+00, -.19124400E+00, -.11410300E-01, 0.19674900E+00, -.75683400E-01, -.12640200E+00, 0.17405800E+00, -.57573400E+00, 0.13891100E+01, -.32268400E-01, 0.16106200E+01, 0.84986100E-03, -.60184600E-01, 0.85051000E-01, 0.21508700E+00, -.40468000E+00, -.84446500E+00, -.88340400E+00, 0.21544600E+00, 0.49784000E+00, -.59109900E-01, -.54545400E-01, 0.22647100E-01, 0.27328000E+00, -.49931800E+00, -.11291100E+02, 0.73445400E+00, -.58770400E+00, -.32523100E+00, 0.87926500E+00, -.22200100E+00, -.50936300E-02, -.57390100E+00, 0.26563200E-01, -.60999300E+00, 0.98799200E+00, 0.67460700E+00, 0.45523800E-01, -.28436600E+01, 0.19751200E+01, 0.79889700E-01, 0.19831200E+00, 0.72020000E-01, -.36983100E-01, 0.20483300E+00, 0.23590700E+00, -.79037400E+00, -.23528700E+01, 0.20104400E+01, -.97749400E-01, 0.66204400E+00, 0.32459100E+00, -.87650800E+00, -.55608200E+00, 0.23020100E+00, 0.12061700E+00, -.33623500E+01, -.70220100E-01, 0.31145100E+00, 0.23814200E+01, -.64838300E-01, -.45002300E+00, 0.26640200E+00, 0.10001900E+01, 0.42181100E-01, 0.12175600E+01, -.97662300E-02, 0.85195200E-01, -.40833800E-01, -.69348800E+00, 0.82268200E+01, 0.71410200E+00, 0.58973100E-01, 0.26989200E+00, 0.35275600E-01, -.44608200E+00, -.27169800E+00, -.28970400E-02, -.75627200E+00, -.27356400E+00, 0.86344400E-01, -.10768500E+00, 0.22630600E+00, -.29698400E+00, 0.16881800E+00, -.32208200E-01, 0.68730300E-01, 0.57669400E+00, 0.31956200E-01, -.26902900E+01, 0.68058900E+00, -.18666800E+00, -.29505400E-01, -.66067000E-01, -.19546300E+00, 0.38067300E+00, 0.71358400E+00, 0.30196700E-02, -.30308400E+00, -.49986700E+00, -.61888400E+00, -.20200000E+00, 0.34413800E+01, -.35445000E+00, 0.65724400E-01, -.23556600E+00, -.81449500E-02, 0.17015400E+01, -.47363100E-01, 0.57999300E+00, 0.32003200E+00, -.54574000E+00, -.68489500E+00, 0.23202800E-01, 0.52369100E+01, -.13511100E+00, 0.16469800E+01, -.12710500E+01, -.15052600E+01, 0.18771000E+00, 0.72780900E+00, -.16061400E+00, -.11031100E+01, 0.11699900E+01, -.83206800E+00, -.84269600E+00, 0.27574900E+03, -.39120100E+02, 0.12393700E+03, -.72056200E+03, 0.35309600E+03, 0.53648100E+03, 0.36230800E+03, -.28877200E+03, 0.37101000E+03, -.44202600E+03, -.83590400E+03, -.53382400E+03, 0.31555500E+03, 0.92311900E+03, -.24237500E+03, 0.11742700E+03, -.58909800E+02, 0.11773000E+03, -.43187300E+02, 0.10291800E+02, 0.43262400E+02, -.16263900E+02, 0.95761300E+01, 0.37779300E+02, 0.16734100E+03, 0.61132200E+03, -.30130300E+03, -.65301000E+03, -.30569100E+03, -.12253900E+03, -.11722600E+03, -.10155500E+02, 0.58974700E+02, -.23765100E+03, -.12527800E+03, -.19982300E+03, 0.99363600E+02, -.46621200E+02, -.61860200E+02, -.48375200E+02, 0.16333200E+03, -.29852700E+02, 0.32221000E+02, 0.65200600E+02, 0.46220900E+02, -.27050600E+02, -.26182800E+03, 0.23195900E+03, -.10754400E+03, -.10629100E+03, -.11597100E+03, -.38579900E+02, -.19390800E+03, 0.98755600E+02, 0.10208300E+03, 0.53508100E+02, -.11427500E+03, -.85032000E+02, -.40649900E+03, 0.21280700E+03, 0.41095600E+03, 0.20609000E+03, 0.15097700E+02, -.12582600E+03, 0.18444600E+03, -.18000300E+03, -.26717000E+03, 0.37099700E+02, -.51911400E+03, -.63032000E+02, 0.92005400E+01, 0.14945600E+02, 0.14122800E+02, 0.46292000E+01, 0.53972200E+01, -.11039000E+02, -.37733700E+02, 0.58701600E+01, 0.13130100E+02, 0.11638600E+02, -.18541900E+01, 0.16451000E+02, -.53294200E+01, -.35531900E+02, -.21636900E+02, -.16576600E+02, 0.41369700E+01, 0.13127500E+02, 0.11127100E+02, 0.62228700E+02, 0.18025200E+02, -.68858900E+02, -.83437200E+01, 0.10625300E+02, 0.20599900E+02 },
        { 0.48517600E+01, 0.61924500E+00, -.34246400E+01, -.14932200E+01, -.28072800E+01, -.25362400E+01, -.88477100E+00, -.40058000E+00, -.69637900E-01, -.17163700E+00, -.65353900E-01, -.44815300E-01, 0.38793400E+00, 0.42742400E+00, -.46028200E+00, -.62107300E+00, 0.87354100E+01, 0.23923200E+01, -.15413100E+01, -.10696800E+01, -.10325700E+01, 0.80684000E-01, -.22008900E+00, 0.17493200E+00, 0.36599800E-01, 0.76889500E-01, -.34468800E+00, -.14205500E+00, -.61311200E+00, 0.97580200E-01, 0.43103300E+00, -.54227200E+00, -.49652300E+00, 0.67798300E+01, 0.99315200E-01, 0.28805100E+00, -.10619900E+00, -.31805900E+00, 0.90069500E-01, -.53714600E+00, -.36350700E+01, 0.66296900E+00, 0.18100700E+00, 0.54266300E-01, 0.34219600E+00, 0.28604600E+00, -.88412600E-02, -.24963600E-01, -.38316800E+00, -.25197000E+00, 0.61676400E+00, -.19298400E+01, 0.49389000E+00, -.17369200E+01, -.61418600E+00, 0.15563800E+00, -.23478900E+00, 0.98112000E-01, 0.19636800E-01, 0.38228300E+00, -.40363200E-02, 0.14576000E+01, 0.22932700E-01, 0.35722800E+00, 0.55798500E-01, 0.18851000E+00, -.29466900E+00, -.33934800E+00, -.60539100E+00, 0.23835400E-01, -.28086600E-01, -.13132000E+01, -.50521600E+00, 0.83849100E+00, 0.71793100E+00, 0.40049500E+00, -.70687300E-01, 0.29918300E+00, -.32841900E+00, 0.98689800E-01, -.15974300E+00, 0.74224100E-01, 0.14726500E+00, -.94649800E+00, -.12697300E+00, 0.59757700E+00, 0.16330800E+00, -.81351500E-01, -.98243400E+00, -.13917700E+00, -.54792500E+00, -.12883300E-01, -.73994300E+00, 0.17633200E+00, 0.19442200E+01, 0.28237300E+01, -.19325800E+00, 0.68493600E-01, 0.51598100E+00, 0.10834800E+01, -.99251400E-01, 0.29896700E+00, -.51229500E-01, -.26875500E+00, -.39255500E+00, -.69765200E+01, 0.41601100E+00, -.66874200E+00, -.15270800E+00, 0.34842500E+00, 0.37565100E+00, 0.33010500E-02, -.76836000E+00, -.47451200E-01, -.29761600E+00, -.54205800E+00, 0.89692400E-01, -.18899500E+00, 0.72941100E+00, 0.57978800E+00, 0.10428700E+01, -.30105300E-01, 0.79348800E-01, 0.28239200E+00, -.72114000E-01, -.18208600E+00, 0.26815000E+00, -.14767700E+01, -.25458000E+00, 0.33650300E+00, 0.31804200E+00, -.48673000E+00, -.69630500E+00, 0.70079800E+00, -.31672800E+00, -.53352900E-01, 0.11890600E+01, -.65209300E-01, 0.10253600E+00, -.58418400E+00, -.26856500E+00, -.16813100E+00, 0.73973400E+00, -.50782200E+00, -.15924900E-01, 0.85160500E+00, 0.53591300E-01, 0.19226700E+00, 0.11061100E+00, -.76258900E+00, 0.28864900E+01, -.98674000E-01, -.14618200E+00, 0.13854600E+01, -.15191200E-01, 0.26994800E-01, 0.10471600E+00, 0.38712800E-02, 0.16964200E+01, 0.49931400E+00, 0.11781100E+00, 0.11463800E+00, -.13640300E+00, 0.53880400E-01, 0.21112200E+00, 0.85201600E-01, 0.66728900E-01, 0.21954300E-01, -.17627500E-01, 0.77562500E-01, 0.18255900E+00, -.92118500E-01, -.14525400E+00, 0.23285500E+00, 0.67712700E+00, 0.37139900E-01, -.47605700E+00, -.40787500E-01, 0.62126400E+00, 0.81531500E-01, 0.43758300E+00, 0.24076400E+00, 0.61212000E+00, -.12099200E-01, -.41016900E+00, 0.74971700E+00, -.40495500E+00, 0.30161100E+00, 0.53508400E-01, 0.34186500E-01, 0.32888900E+00, -.25239800E+00, 0.66248900E-01, 0.55264600E-02, 0.50896900E+00, 0.60662900E+00, 0.41609300E+00, 0.59455800E-01, 0.13336700E-02, 0.65098800E-01, -.16309200E+00, -.10400000E+00, -.77621100E+00, -.26767900E+00, -.19360800E+00, -.17451800E+00, -.47624500E-01, 0.21113700E+02, -.53296600E+02, 0.18301900E+03, -.94683900E+02, -.66163500E+02, -.96010300E+02, -.98957000E+01, -.19714500E+03, 0.24111600E+03, 0.13692400E+03, 0.16442700E+02, -.12876600E+03, -.38771500E+03, 0.32798700E+03, -.16790300E+03, -.98915100E+02, -.16365900E+03, -.23557800E+02, 0.83176100E+01, -.11390400E+03, 0.38714600E+02, -.53934000E+02, -.14107200E+02, 0.17000400E+02, -.24714000E+02, 0.13118700E+02, 0.10706600E+02, 0.12449200E+02, 0.11654100E+02, -.57131800E+01, 0.13095800E+02, -.33356100E+01, 0.88848200E+01, 0.21661600E+02, -.15812400E+02, 0.67996700E+02, -.31519700E+02, -.74639000E+02, -.36616300E+02, -.87980100E+02, 0.15272800E+02, -.60621700E+02, 0.51701500E+02, 0.22891300E+02, -.10126300E+02, 0.32159200E+03, 0.15792300E+03, -.75828500E+02, 0.36989300E+02, -.78155500E+02, -.54812000E+01, 0.23403100E+02, -.43934800E+02, 0.74926500E+01, -.43490800E+02, -.37513400E+01, -.48106500E+02, 0.19180800E+03, -.93234800E+02, -.17644500E+03, -.96130100E+02, -.48587100E+01, 0.66953300E+02, -.22924500E+02, -.38839000E+02, 0.71865300E+02, 0.45473300E+02, 0.48230900E+02, 0.33109300E+02, 0.34170500E+01, -.34923100E+02, -.34774400E+02, -.88654400E+00, -.42099300E+00, -.92776300E+00, -.28717000E+01, -.53950000E+01, 0.23354300E+01, 0.89608800E+01, 0.15377500E+01, -.22253900E+01, 0.19951300E+01, -.43236500E+01, -.23752800E+02, 0.35253300E+02, -.94595500E+01, -.34460900E+02, 0.25719300E+01, -.86730600E+01, 0.26189300E+02, -.23767300E+01, -.10642500E+02, -.32593600E+01, -.47925400E+01 },
        { -.96835000E+01, -.39675100E+01, -.63246400E+01, -.17888300E+01, 0.25748000E+01, 0.34330900E+01, 0.41406500E+01, -.42750800E+01, -.29562900E+00, -.24999900E+01, 0.13599100E+01, 0.16993300E+01, 0.16353000E+01, -.13331800E+01, -.11277400E+01, 0.16831600E+02, -.83589000E+00, -.16012500E+00, 0.26478300E+01, -.73415600E+00, 0.46177900E+00, 0.60195100E+00, 0.25768600E+00, 0.31796700E+01, -.60686400E+00, -.11967100E+00, 0.82344900E+00, 0.58179700E+01, -.56331200E+00, -.13284300E+00, -.19080700E+01, 0.16181900E+01, 0.95494700E+00, -.91922400E+01, 0.43915700E-01, -.61501000E+00, -.11090900E+00, 0.48533500E+00, -.36899900E+00, -.11675600E+01, 0.42339900E+01, -.24072400E+00, 0.85138200E-01, -.73321400E-01, -.16318900E+01, 0.89543500E+00, 0.81426300E-01, -.19318200E+00, -.53661200E+01, 0.48211000E+00, -.24775700E+01, -.40835200E+00, -.82622900E+00, 0.37263800E+01, 0.62660000E-01, 0.47457300E+01, 0.17124700E+01, -.14361300E+00, -.15498100E+00, -.75227500E+00, 0.81169200E+00, -.12301900E+01, 0.93282500E+00, -.19884900E+01, -.15296700E+01, -.44575900E+00, 0.29200100E+00, 0.46793000E+00, 0.27836000E+00, -.52730700E-01, -.38189000E-01, 0.11969800E+01, 0.30418400E+01, 0.44816600E+01, -.14346000E+01, -.23893100E+01, -.25638800E-01, 0.14934700E+01, -.19149300E+01, -.95652900E+00, 0.17070400E+00, -.12184500E-01, 0.16582000E+00, 0.11863700E+01, 0.31465200E+00, -.32990500E-01, 0.44543000E+00, 0.43232600E+00, -.44777100E-01, 0.15148700E+00, 0.26232800E+00, 0.10750400E-01, -.27678100E+00, 0.98107800E-01, 0.59930000E+00, 0.86587800E+00, 0.22764200E+00, -.35571300E+00, 0.23320200E-01, -.46726100E+00, 0.25049200E+00, -.18119000E+00, 0.48058700E-01, 0.78077700E-02, 0.16164800E+00, 0.29384800E+01, -.67775100E+00, -.29715700E+00, 0.15719600E+00, 0.11916100E-01, -.11810500E+00, 0.53536700E-01, 0.18182000E+00, 0.26049500E-01, 0.13238000E+00, 0.55991600E+00, -.66331200E-01, -.15707200E+00, 0.56925500E+00, -.50857200E+00, 0.13543200E-01, -.39704700E-01, -.12192800E+00, 0.68202300E+00, -.85030200E-01, -.31131400E+00, -.11515200E+00, -.16441500E+01, -.20816100E+00, -.13066200E+00, 0.13592700E+01, -.57367900E+00, 0.59106500E-01, -.21160300E+00, -.17814600E+00, -.45284200E-01, 0.12844700E+01, 0.13846000E+00, 0.54663100E-01, -.31843800E+01, -.85063700E+00, -.75629000E+00, 0.13174300E+01, -.13474000E+01, -.37765200E+00, -.87080600E+00, -.11518200E+00, 0.70133100E+00, 0.16917600E-02, 0.13166100E+01, 0.71022500E+01, 0.58734600E+00, 0.18970200E-01, 0.36076700E+01, -.41513700E+00, -.21286300E+01, -.33722200E+00, -.47356400E-02, 0.24592700E+01, 0.91237100E+00, -.46161500E-02, -.77210100E+00, -.26148300E+00, -.63493300E+00, 0.81727000E+00, -.10974100E+01, 0.25533900E-01, 0.21818000E+01, -.33340500E-01, 0.95932600E+00, 0.24970400E-01, 0.13144700E+00, 0.91320300E-02, 0.18627500E+00, 0.25713400E+00, -.48901800E+00, -.12624400E+01, 0.52707600E-01, -.76724600E+00, 0.23997800E+00, -.15299400E+00, 0.98222100E+00, -.32800400E+00, 0.10661500E+01, -.87124300E+00, 0.22660100E+01, 0.75045400E+00, -.23482900E+01, -.40268200E-01, -.12168300E+01, 0.22993700E+01, 0.53559200E-02, -.56352200E+00, 0.59963900E-01, -.29858400E+01, -.11974000E+00, 0.77656000E-01, 0.43607500E+00, 0.13460200E+01, -.82241500E-01, 0.50776900E-01, 0.25917600E+00, -.18918000E+01, 0.31278800E+01, 0.17025400E+01, -.17400600E+00, -.48335700E+00, -.13559400E+01, -.18449600E+03, 0.40617800E+03, -.19892700E+03, -.17049300E+03, -.20762500E+03, 0.27953600E+01, -.22316500E+03, 0.11436300E+03, 0.15118600E+03, -.26115600E+02, -.16297000E+03, -.51718800E+03, 0.62575600E+03, -.28791100E+03, 0.16781900E+03, -.31241900E+03, -.86330300E+00, -.75756900E+01, -.18319400E+03, 0.84550900E+02, -.10114900E+03, -.35654100E+02, 0.12671300E+01, 0.29069200E+03, -.14528600E+03, -.13341200E+03, -.14528800E+03, -.64514300E+02, -.52712400E+02, -.28794800E+02, 0.43745700E+02, -.10554900E+03, -.10215200E+02, -.10254500E+03, 0.16282300E+03, -.10365600E+03, 0.46417600E+02, -.83224100E+02, -.94321600E+02, 0.33796000E+02, -.10998500E+03, -.57496600E+02, 0.55803700E+01, 0.86667200E+01, 0.10575200E+03, 0.18844100E+02, -.20694300E+02, 0.41781300E+03, -.84344200E+01, 0.14286900E+02, 0.71473600E+02, -.39478400E+02, -.23719900E+02, -.11180200E+03, 0.55432000E+02, 0.56867300E+02, 0.23686300E+03, -.13894800E+03, -.63088700E+02, -.12241300E+03, -.48810400E+02, 0.25666900E+02, -.34242400E+02, 0.10635400E+03, 0.56604500E+02, -.35976100E+02, 0.11325300E+03, 0.50130400E+02, 0.42378100E+01, -.54816200E+02, -.50526200E+02, -.14799000E+02, 0.13377300E+02, 0.12270900E+02, -.13750600E+02, -.64787000E+01, 0.58663800E+01, 0.18136300E+02, -.13614500E+02, 0.16418000E+02, 0.14028500E+02, -.16270600E+02, -.22982200E+02, 0.52040900E+02, -.21404900E+01, -.51634900E+02, 0.23034400E+02, 0.27485500E+02, 0.36265500E+02, 0.29053500E+02, -.15848200E+02, 0.90728000E+01, -.25828500E+02 },
        { -.15600500E+02, -.13605400E+01, 0.24338500E+01, 0.21168800E+01, 0.65490100E+01, 0.38218800E+01, 0.13759100E+01, 0.10651000E+02, -.22700200E+01, 0.11717700E+01, 0.29743300E+01, 0.21648100E+01, 0.31914200E+01, -.72060900E+00, -.33858200E+01, 0.30902600E+01, 0.26937100E+01, 0.14790900E+01, -.83717500E+00, -.45043400E+00, 0.29187700E+01, 0.19519600E+01, -.14248400E+01, -.28510600E+01, -.37206700E+00, -.15648200E+00, 0.10026700E+01, -.47986100E+01, -.78464500E+01, -.14312000E+00, -.23717600E+01, -.43249700E+01, 0.31427300E+01, 0.57184600E+01, 0.14035600E+00, -.11630900E+01, 0.49742900E+00, 0.24222100E+01, 0.64470100E+00, -.19254600E+01, 0.57323100E+01, 0.35044800E+01, -.24124200E+00, -.24839100E+00, -.26752500E+01, 0.14866200E+01, -.33149700E+00, 0.80702500E-01, -.24449000E+01, -.48733700E+00, 0.58899300E-02, 0.23479600E+01, 0.49018600E+00, 0.27683300E+01, 0.19301900E+00, 0.17574900E+01, 0.10877600E+01, -.30024500E+00, 0.83936400E-02, -.10640400E+00, 0.17162600E+00, -.13978000E+01, 0.14447800E+01, -.37038300E+00, 0.71512500E+00, -.16965200E+01, -.54579000E+00, 0.72709800E+00, 0.41893000E+01, -.24977400E-01, -.44618000E+00, 0.19078700E+02, 0.32371700E+01, 0.35815800E+01, -.47379200E+01, 0.11655100E+01, -.40141800E+00, -.28204600E+01, -.28996600E+01, 0.19845500E+00, 0.22628100E+00, -.22341300E+00, -.13111200E+01, -.26340900E+00, 0.13872500E+00, 0.27605500E+00, 0.92041000E-01, 0.58704900E+00, 0.43401200E+00, 0.20307100E+00, -.85351000E+00, 0.10531400E-01, 0.36441200E+00, -.44172900E-01, 0.15382800E+01, 0.24467000E+01, 0.47914000E+00, -.84391300E+00, 0.27938000E+00, 0.28765800E+00, 0.15417400E+00, 0.28782700E+00, 0.49168800E-01, -.65284500E+00, -.58263200E-01, 0.54267600E+01, -.29458900E+00, 0.70651900E+00, -.83671700E-01, 0.19131000E+00, 0.28567100E+00, 0.98700500E-03, 0.19158000E+01, 0.15930000E-01, 0.34242000E+00, 0.15725000E+01, -.55538800E+00, -.20817100E+00, -.84965900E+00, -.12879400E+01, 0.22375300E+00, -.32778200E-01, -.44870300E+00, -.16189000E+00, -.56541200E-01, 0.90922800E-01, 0.72598400E+00, 0.25754300E+01, 0.82370400E-01, -.63475700E-01, -.85049600E+00, 0.46360900E+00, 0.24978100E+00, 0.45452600E+00, 0.40362100E-01, 0.52678300E-02, -.10493500E+01, 0.38777400E+00, -.14580400E+00, 0.15103100E+01, -.12264200E+00, -.56373400E+00, -.13206400E-01, -.10734900E+01, -.73480600E-01, -.18844100E+01, -.18718700E+00, 0.10543500E+01, -.71525000E-01, 0.17740800E+01, 0.62848800E+01, 0.62369400E+00, 0.77609800E+00, -.16768100E+01, -.52381800E-01, -.95304400E+00, -.49080100E+00, 0.11566300E-01, 0.59788500E+00, -.80490200E+00, 0.47429600E+00, 0.69810300E+00, 0.14822100E+00, 0.43881100E+00, -.10044100E+01, -.11310000E+00, -.25609300E+00, -.34084600E+01, -.45957100E-01, -.17657100E+01, 0.15589700E+00, 0.37763900E+00, -.90718800E+00, 0.41318300E+00, 0.12431100E+01, -.41660800E+00, -.77739700E-02, 0.55516400E-01, -.61336300E+00, -.21641800E-01, -.58537900E+00, 0.54295400E-01, -.11756300E+00, -.29353400E+00, 0.30442000E+00, -.17055300E+00, 0.55467600E+00, -.26099700E+00, -.12371400E-01, 0.86202800E+00, 0.43604900E+01, -.65292200E+00, 0.53546800E+00, -.12790200E+01, 0.79635900E+01, -.91006300E+00, 0.56327300E+00, 0.18022800E+01, 0.20613400E+01, 0.49414600E+00, 0.87365700E+00, 0.50320600E+00, -.19956300E+01, 0.52027100E+01, 0.11106300E+01, 0.31588100E+00, -.41919300E+00, -.18614700E+01, -.28335500E+00, -.10301600E+04, 0.51540200E+03, 0.59967400E+03, 0.52010700E+03, 0.25079100E+03, -.42055900E+02, 0.34842500E+03, 0.28912900E+03, 0.52235300E+03, -.52888400E+02, 0.95207900E+01, 0.57907100E+03, -.30259500E+03, 0.35075400E+03, -.28878700E+03, -.17120000E+03, -.43993500E+02, -.61623000E+02, 0.86021300E+02, -.20638000E+03, -.49483300E+02, -.14063700E+03, 0.20192500E+03, -.98576700E+02, 0.22357700E+02, -.10104000E+03, 0.40427200E+02, -.63333300E+02, -.33625400E+01, 0.58544400E+02, -.16788300E+02, -.41262800E+02, -.30798500E+03, 0.27460500E+03, -.13301700E+03, -.21390700E+03, -.13568000E+03, -.21777900E+03, -.47794700E+02, -.37805000E+02, -.71118100E+01, -.54319200E+02, -.59852200E+02, 0.34395800E+03, 0.39659000E+02, -.16554300E+02, 0.58253600E+01, -.21678900E+02, -.66207800E+02, 0.35108600E+02, -.49142200E+02, -.12319000E+03, -.14134100E+03, 0.25334000E+02, 0.35085900E+01, -.66796100E+01, 0.20845400E+02, 0.81369900E+02, 0.39929800E+01, 0.21298500E+03, 0.20783200E+03, -.11927700E+03, 0.14840700E+03, 0.36234400E+03, 0.64502200E+02, 0.34371700E+03, 0.17098500E+02, 0.10847600E+01, 0.17638500E+02, 0.20526700E+02, -.14448900E+02, 0.20724100E+02, -.37932800E+02, -.62405200E+01, -.13668500E+02, 0.56763600E+01, 0.12246100E+01, -.17338800E+02, -.26138800E+02, 0.12475700E+02, -.91039900E+01, -.44254500E+02, -.22675600E+02, -.24527100E+02, 0.17658200E+02, 0.18134700E+02, -.45636400E+01, 0.46492300E+02, -.64984800E+02, -.10149300E+02, -.22191600E+02, -.59726300E+01 },
        { 0.13547800E+02, -.53524400E+01, -.30030600E+01, 0.11749000E+01, -.17309300E+01, 0.27841400E+01, 0.12802600E+01, 0.94152000E+01, 0.29978900E+01, -.10492200E+00, 0.14253600E-01, -.89571300E+00, -.46719400E+01, 0.81522500E+00, 0.72393800E+00, -.15362600E+01, -.13201700E+02, -.11028200E+01, -.58182200E+01, -.19625300E-01, 0.30871500E+01, 0.23022400E+01, 0.10688700E+01, -.10186800E+01, 0.18933900E+01, -.25837800E+00, -.14362800E+01, -.18817100E+01, 0.79090700E+01, -.86272900E-01, -.18822600E+01, 0.99877100E+00, 0.30288700E+01, -.34236900E+01, -.52442300E+00, -.37209300E+00, -.10984500E+00, -.49811500E+01, -.14512400E+01, -.87475000E-02, -.61968200E+01, 0.80188000E+00, 0.10620900E+00, 0.15834900E+00, 0.58540900E-01, -.16053300E+01, 0.20730500E+00, 0.65677400E-01, 0.19756600E+01, -.34097500E+00, -.43805300E+00, 0.49512700E+01, -.20500000E+01, 0.37049400E+01, -.40418000E+00, 0.16611500E+01, 0.67493500E+00, 0.16019400E-01, 0.97385600E-01, 0.14272800E+01, -.35218100E+00, -.19332100E+00, 0.78429200E+00, 0.96475500E+00, 0.27469500E+01, 0.10549200E+01, 0.10225900E+01, 0.37845100E-01, 0.18949300E+01, 0.20598300E-02, -.25774200E+00, 0.83971700E+01, 0.14212600E+01, 0.17349600E+01, -.11150900E+01, 0.28490900E+01, -.28361500E+00, -.33708800E+01, 0.25508200E+01, 0.68436300E+00, 0.23153600E+00, -.52394300E+00, -.11223800E+01, -.65095700E+00, -.92088400E-01, -.24174400E+00, 0.31107900E+00, -.29195500E+00, 0.16353500E+01, -.46225000E-01, 0.12389000E+01, 0.14715000E-01, -.23435000E+00, -.41876600E+00, 0.17855400E+00, 0.17558500E+00, -.86244700E+00, -.16124900E+01, 0.11737100E+00, -.20114800E+00, 0.20371300E+00, -.25283000E+00, 0.60691200E-01, 0.61561300E+00, -.56229700E+00, 0.20871200E+01, 0.81342600E+00, 0.23343000E+00, -.34130500E+00, -.11090700E+01, 0.74970000E+00, 0.34908100E+00, 0.39101900E+00, -.49085600E-01, -.10891600E+01, -.12505000E+00, 0.41706100E-01, 0.86017100E-01, -.44139600E+00, -.28239400E+01, -.95724200E+00, 0.12368100E+00, -.12264400E+00, 0.93306300E+00, 0.18188600E-01, 0.98259800E+00, 0.88103500E-01, -.18351900E+01, 0.20752900E+01, 0.57941100E+00, 0.77625300E-01, 0.54146800E+00, -.13560000E+00, -.13621000E+01, 0.81078700E+00, 0.11760500E+00, -.29436300E+01, 0.11131700E+00, 0.47126500E+00, -.74143800E+00, 0.22509100E+00, -.24760000E+00, 0.91209200E-01, 0.14716200E+01, 0.19342400E+00, 0.11868800E+01, -.30937800E-01, -.41580000E+00, -.10455100E+00, 0.32319600E+00, -.72567300E+00, 0.44743400E+00, 0.18408800E+00, 0.19737200E+01, 0.75502400E-01, 0.38168000E+00, 0.40948000E+00, -.35885000E-02, 0.46036300E+00, 0.35095300E-01, 0.19111900E+00, 0.45039800E+00, 0.17642900E+00, 0.73661600E+00, -.48361400E-02, -.10593000E+01, -.18970000E+00, -.58685500E+00, 0.96384600E-02, -.11668900E+01, 0.21421000E+00, -.14118200E+00, 0.92757200E-01, -.40482400E-01, -.11427700E+01, 0.25308800E+00, 0.38458300E+00, 0.14403000E+00, 0.57901300E-01, -.70021200E-01, 0.44431600E+00, 0.31718000E+00, 0.87048600E+00, -.50527100E+00, 0.83868200E-01, 0.49253600E-01, 0.23256200E+00, 0.96365400E+00, -.21973900E-03, 0.78114900E+00, -.39773600E+00, -.55880500E+00, -.43999900E+00, 0.58247100E-01, 0.30978300E+01, -.25439800E-01, 0.57318000E+00, -.44925900E+00, 0.50520000E-02, 0.43407700E-01, 0.47079100E+00, 0.72435300E-01, -.15523000E+01, 0.77027600E+00, -.41520400E+00, -.18994400E+00, 0.35861800E+00, -.58059200E-01, -.87731200E-01, 0.38004800E-01, 0.10240900E+03, -.15555700E+03, 0.28537600E+01, -.27639900E+02, 0.10548100E+02, -.45294200E+02, -.92837800E+02, -.79297600E+02, 0.20419400E+02, -.11912300E+03, 0.81224400E+01, 0.15725800E+02, 0.29561700E+02, -.39888000E+01, 0.11368900E+02, -.11188200E+02, 0.26358300E+02, 0.53419000E+02, 0.22382400E+02, -.70994000E+01, -.50868600E+02, -.56485900E+02, 0.25793700E+02, 0.23918000E+02, 0.28179200E+02, -.96127200E+01, 0.32062500E+01, -.87493800E+01, -.13331600E+02, 0.24356500E+02, -.60470800E+01, 0.24151800E+02, 0.10260300E+02, -.41921000E+02, 0.84042100E+02, -.33686300E+01, 0.16832600E+02, -.21095800E+01, -.89819300E+00, -.62206600E+01, -.25240000E+01, -.24527400E+00, -.93509200E+02, -.51184200E+02, -.15227100E+01, 0.12054600E+03, 0.25083300E+02, 0.28336800E+02, 0.18764200E+02, 0.88829000E+01, -.43619700E+01, -.59743700E+01, 0.23596700E+02, -.47924000E+01, -.42532200E+02, 0.14823200E+01, 0.18464400E+03, 0.20735400E+02, 0.43902900E+02, -.64050500E+01, 0.16823900E+02, 0.79782000E+02, -.16492800E+02, 0.39455100E+01, 0.50547200E+02, -.10913000E+02, -.48583400E+01, 0.14354000E+02, 0.15414900E+02, 0.50191200E+01, -.68936600E+01, -.93731900E+01, 0.44506100E+01, 0.50896500E+01, -.52547900E+01, -.57713000E+01, 0.68580200E+01, -.28005800E+01, -.47184200E+01, 0.47180500E+01, 0.12197400E+02, -.15209700E+02, -.24287500E+01, 0.14995100E+02, -.66251700E+01, 0.96042100E+01, -.11370300E+02, -.67814100E+01, 0.57257100E+01, -.40572700E+01, 0.56805100E+00 },
        { -.43211800E+01, 0.95691300E-01, 0.27713000E+01, 0.14561300E+01, 0.10741400E+01, 0.66937600E+00, 0.96722800E+00, -.80421900E+01, -.22100000E+00, -.21416700E+01, -.41467500E+00, 0.66419800E+00, 0.76938400E+00, -.12567500E+00, -.51243000E+00, 0.93580800E+01, 0.42071900E+01, 0.20843800E+01, -.23007200E+00, -.96717000E+00, -.27718000E+00, 0.21300100E+00, -.11284400E-01, 0.13570300E+01, -.20678400E+00, -.17164800E+00, -.88088900E+00, 0.29560500E+00, 0.26251700E+01, 0.23271200E-02, -.50691200E+00, -.40978100E+00, -.52166100E+00, -.38412300E+01, -.33928900E-01, -.28019400E+00, 0.53815800E-01, 0.16428400E+01, -.22831500E+00, 0.96533000E+00, 0.47570100E+00, -.74009100E+00, -.19028100E+00, 0.53953200E-01, 0.11897700E+00, 0.16966400E-01, -.39521500E-01, 0.35145100E-01, 0.14607500E+01, -.25980300E+00, 0.60572500E+00, -.61900100E+00, 0.15857700E+01, -.34769000E+01, -.40264800E+00, -.79588100E+00, -.78975000E+00, -.20992800E+00, 0.61967200E-01, -.11851400E+01, -.45412700E-01, 0.18295300E+01, -.37603400E-02, -.55952700E+00, -.54828800E+00, 0.33435800E-01, -.48397200E+00, 0.90679200E-01, -.12990700E+01, -.16144900E-01, 0.70060400E-01, -.44558700E+01, -.12127800E+00, 0.18869200E+01, 0.16337400E+01, -.19837500E+00, -.23492300E+00, 0.21918400E+01, 0.68496700E-01, -.10493900E+00, -.53565500E-01, 0.17498000E+00, 0.82190400E-01, -.49922600E+00, -.11802700E+00, 0.10168900E+00, 0.19638700E-01, 0.92527000E-01, 0.22344400E+00, 0.19472600E-01, -.47618100E+00, 0.51873500E-03, -.18842200E-02, 0.22624200E+00, 0.33770900E+00, 0.15825700E+01, 0.45737500E+00, 0.52363000E+00, 0.23050900E+00, -.37400100E-02, 0.30686500E+00, 0.19339200E-01, -.48504200E-02, -.30563800E+00, 0.41697900E-01, -.16252500E+01, -.49485500E+00, -.72763500E-03, -.15467900E+00, 0.58389000E+00, 0.75382200E-01, -.55192900E-02, 0.78115800E+00, -.12447800E-01, 0.49986900E+00, -.16455600E-01, 0.28978800E+00, 0.37033600E-01, -.21920500E+01, 0.16340900E+01, 0.13927700E+00, 0.65046000E-01, 0.37152600E-01, 0.26180000E+00, 0.13229300E-01, 0.34462100E+00, -.11702600E+00, -.17333200E+01, -.84196100E+00, -.32514800E+00, 0.78322800E+00, -.35212000E+00, 0.18830900E+01, -.15182700E+00, -.15630900E+00, -.25144700E-03, 0.26726400E+00, -.38598800E+00, 0.16203200E+00, 0.10307200E+01, -.54554300E+00, -.20208800E+00, 0.56479200E+00, -.25682500E+00, -.14715800E-02, -.12539300E+00, -.28501500E-01, 0.70592700E+00, -.92956200E-01, -.60964200E+00, 0.22095600E+01, -.25615800E+00, -.27806300E+00, 0.50040900E+00, 0.22862500E-01, -.15907600E+01, -.93254400E-01, 0.56134100E-02, 0.29143900E+01, 0.53150500E+00, -.22994600E+00, -.48300400E-01, -.19592400E-01, 0.20497300E+00, 0.93722900E+00, 0.13349100E+01, 0.36622000E-01, 0.10098300E+01, 0.56536200E-02, -.52294900E-01, -.18210000E+00, 0.53703200E-01, 0.97463700E-01, -.13251300E+00, -.41582700E+00, 0.22368700E+00, 0.59537000E-01, 0.97936100E-02, -.93854200E-01, -.38328800E-01, -.54470500E+00, 0.29254600E-01, 0.67627600E+00, 0.10816500E+01, -.42767000E+00, 0.61075600E-01, -.36044800E-01, -.16938000E+00, 0.38283200E-02, -.53665500E+00, 0.67267200E+00, 0.27054100E+00, -.33765200E+00, -.13955700E+00, -.23290000E+00, -.11862900E+00, 0.24094000E+00, 0.26334600E-01, 0.27540400E+00, -.10194300E-02, 0.22279700E+00, 0.10266500E+00, 0.69110400E-01, 0.59704100E+00, 0.26433500E+00, -.13683100E+00, 0.23889300E+00, -.50312600E-01, 0.16931800E+00, 0.56285600E-01, 0.90464300E-02, -.96439600E+02, 0.60672900E+00, 0.39330700E+02, -.23322400E+02, 0.57078300E+02, 0.30095600E+02, -.15294400E+02, 0.93048400E+01, 0.22468000E+02, 0.33510600E+02, -.94319600E+01, -.17275100E+02, -.16076900E+02, 0.11486600E+02, -.56494100E+01, 0.48826500E+01, 0.20478400E+02, 0.11448100E+02, -.29977300E+01, -.37967800E+02, -.37161800E+02, 0.19149800E+02, 0.30917800E+02, 0.18543500E+02, 0.82035600E+01, 0.74158700E+01, 0.90223300E+01, -.87828300E-01, 0.20011800E+00, 0.10250600E+02, 0.54710000E+02, -.12138500E+02, 0.12035700E+01, 0.50326300E+02, 0.70443000E+01, -.95058500E+01, 0.12934700E+01, 0.58543200E+01, 0.14881700E+02, -.39486200E+01, 0.59048000E+01, 0.20300400E+02, 0.35136600E+02, -.20945200E+02, -.43271100E+02, -.17531100E+02, 0.43683500E+01, 0.15510200E+02, -.23181700E+02, 0.87992300E+01, 0.14540000E+02, -.39557900E+01, -.43248900E+02, 0.14418800E+02, -.16126500E+02, 0.59066200E+02, -.96952100E+01, 0.13094200E+02, 0.42979800E+02, -.41921400E+02, -.26605800E+02, -.28267400E+02, 0.47475600E+02, 0.37564200E+02, -.11453200E+01, 0.46401000E+01, 0.60657700E+01, 0.65048600E+01, 0.36782400E+01, -.47767900E+01, -.71568100E+01, -.91667800E+00, -.20899100E+01, 0.25988000E+01, 0.50516300E+01, 0.45510000E+01, -.47056100E+01, -.37742000E+01, -.63132400E+00, 0.94874700E+00, -.63956600E+01, -.24476100E+01, 0.64103000E+01, -.53642700E+01, -.39670100E+01, 0.62624600E+00, -.25792300E+01, -.55997900E+01, -.18647200E+01, 0.44862200E+00 },
        { 0.13547200E+02, 0.31978700E+01, -.36460000E+01, -.15386100E+01, -.10294300E+02, -.48945800E+01, -.19714500E+01, -.26006800E+02, 0.12510400E+01, -.66534200E+01, -.41062400E+01, 0.49124300E-01, -.11302000E+01, 0.94989800E+00, 0.21331100E+01, -.38652600E+01, 0.56989900E+01, 0.29689800E+01, -.25653300E+01, -.21244300E+01, -.34402000E+01, -.30350700E-01, 0.26767100E+00, -.80151500E+00, 0.88924200E+00, 0.14649700E+01, 0.14128500E+01, 0.42093000E+00, -.20889900E+01, -.20920000E+00, 0.66055800E+00, 0.23179000E+01, -.77884900E-01, -.55895500E+01, 0.51198600E-02, 0.17350800E+00, 0.11169900E+00, -.58355900E-01, -.15198300E+00, -.36908400E+00, -.30430000E+01, -.65078400E+00, 0.23898100E+00, -.23625700E-01, 0.32521400E+00, -.15159900E+00, 0.17603000E+00, 0.13023900E+00, -.98946200E+00, -.10390900E+00, 0.58917100E+00, 0.16231100E+01, -.18005600E+00, 0.31337500E+00, 0.24195700E+00, 0.17386800E+01, 0.10033500E+01, 0.32314500E+00, 0.14976400E+00, 0.52408300E+00, -.36995000E+00, 0.21387200E+01, 0.43386500E+00, -.75995700E+00, -.16708100E+01, -.71926800E+00, 0.36380500E+00, -.18801900E+00, 0.74337900E-01, -.19019600E-01, 0.50332700E-01, -.14959000E+01, 0.32629700E+00, 0.22257400E+01, 0.48118600E+00, 0.17165500E-01, -.14687100E+00, 0.10022500E+01, -.40364300E+00, -.69165000E-01, 0.82038200E-01, -.29229200E-01, 0.13396900E+00, 0.14259000E+01, 0.15569900E+00, -.46085000E+00, 0.40940900E+00, -.22349500E+00, 0.11479200E+01, 0.28585000E+00, 0.62867500E+00, 0.15292700E-01, -.22945200E+00, -.28715600E-01, 0.29403700E+01, 0.17315200E+01, 0.20802100E+00, -.13421500E+01, 0.62146900E+00, -.20906400E+00, 0.23795100E+00, 0.49510400E+00, 0.22860700E+00, 0.67237000E-01, -.93857800E+00, -.21275900E+01, 0.22504800E+00, -.25601100E+00, -.37482100E+00, -.62229500E+00, 0.93722900E+00, -.39379000E-01, -.42427500E+00, 0.10183400E+00, -.26955100E+00, 0.80636700E+00, -.24329500E+00, -.33768900E+00, -.22621800E+00, -.21589900E+01, 0.19740600E+00, -.35128000E+00, -.15280600E+00, 0.95468000E+00, -.29870700E+00, 0.15517000E+01, 0.37179200E+00, -.23633000E+01, 0.24817700E+01, 0.93807100E+00, 0.81076500E-01, 0.28449600E+00, 0.73319800E+00, -.19334900E+01, 0.89919600E+00, 0.14615900E-01, -.25328700E+01, -.31627300E-01, 0.49377700E+00, -.17563500E+01, 0.32167200E+00, -.41938500E+00, 0.47778800E+00, 0.85039600E+00, -.11179300E+00, 0.11265000E+01, 0.20829700E+00, -.17460300E+00, -.38167700E-01, 0.56606900E+00, 0.32345600E+01, 0.85619400E+00, 0.73818000E-01, 0.27905800E+01, 0.59092000E-01, -.96011500E-01, 0.56750900E+00, -.46117100E-02, 0.10952800E+01, 0.40422100E+00, 0.17361200E+00, 0.68741400E+00, -.14582800E+00, 0.66616600E+00, 0.17730200E+00, -.94313800E+00, -.88114400E-01, 0.73999500E-01, -.95347100E-02, -.22667400E+00, -.88079900E-01, 0.52974200E-01, 0.18977300E+00, -.10047300E+00, -.64030800E+00, 0.24779900E+00, -.11906100E+00, 0.50629700E-01, 0.21889900E+00, -.18067300E+00, 0.40821400E+00, 0.75022400E+00, -.50545900E+00, -.52839300E+00, 0.13369500E+00, 0.20034700E+00, 0.26679600E+00, 0.51898100E+00, 0.29751500E-01, 0.55476300E+00, 0.12522700E+00, -.38388300E+00, -.40756900E+00, 0.11633100E+00, 0.16633000E+01, -.62299100E-01, 0.32572500E+00, -.44310800E+00, 0.62446400E-01, -.35960400E-01, 0.30743500E+00, 0.22118500E+00, -.16548300E+01, 0.58278400E+00, -.54649500E+00, -.24781000E+00, 0.50020900E+00, -.24619800E+00, 0.14694000E+00, -.74057300E-01, 0.71313100E-01, 0.16813800E+01, 0.36433200E+02, -.52208500E+02, -.11757000E+02, -.16238300E+02, -.25009600E+02, -.12486000E+02, -.19625000E+02, -.26237100E+03, 0.87392000E+01, -.53031500E+01, 0.66014900E+02, -.44724700E+01, -.17877600E+02, -.11108500E+02, 0.15345400E+02, 0.16055300E+02, -.16935000E+02, -.11441000E+02, -.13037200E+02, 0.77939500E+01, -.52670500E+01, 0.30973100E+02, -.39726900E+01, -.56950100E+01, 0.10216100E+01, -.29594100E+02, -.97118300E+01, 0.22161400E+02, -.44656300E+01, -.11702700E+03, 0.16448300E+02, -.78439100E+01, 0.10383900E+02, -.81101900E+01, 0.10269000E+02, 0.85242000E+01, -.23641700E+02, -.37726900E+02, -.65711200E+01, 0.45513300E+01, -.90356500E+02, -.64739600E+02, 0.30526400E+02, 0.13945900E+03, 0.24363100E+02, 0.27218100E+02, 0.17313600E+02, 0.20469200E+02, -.22903700E+02, -.25121000E+02, 0.35494000E+02, 0.28472700E+02, -.60152300E+02, 0.36354800E+02, 0.24021200E+02, 0.47991900E+02, 0.46046800E+02, -.58644900E+02, 0.84187600E+02, 0.13574400E+03, 0.93476700E+02, -.66671700E+02, 0.41927400E+02, -.58203000E+01, -.13066300E+02, 0.57015500E+01, 0.67509200E+01, -.23880900E+01, 0.17996800E+01, 0.44742300E+00, 0.12652500E+02, 0.67905600E+01, -.99115900E+01, -.13886400E+02, -.28702100E+01, 0.28081300E+01, 0.32553100E+01, 0.11530100E+02, 0.15572700E+02, -.67096600E+01, 0.21966300E+01, 0.59876600E+01, 0.26376400E+01, 0.11643000E+02, -.16429400E+02, 0.22408000E+02, 0.15739400E+02, -.70624300E-01, 0.51908600E+00 },
        { 0.17887500E+01, 0.22413800E+00, -.90898200E+00, -.76448500E+00, -.10004100E+01, -.31632400E+00, -.75325300E+00, 0.11758500E+01, 0.70105500E-02, 0.53187800E+00, 0.60510200E-02, -.91847600E-01, -.15621900E+00, -.23919700E-01, 0.11819800E+00, -.76975500E+01, -.17759300E+01, -.76984400E+00, -.82824900E+00, -.13975500E+00, 0.10712100E+01, 0.12109300E+00, 0.52388400E-01, -.27270300E+00, 0.75456700E-01, 0.60153200E-01, 0.49869500E+00, 0.28600100E+00, -.11964700E+01, 0.10357800E-01, 0.57159200E-01, 0.76178300E-01, 0.47058200E+00, -.12896800E+01, 0.42135900E-02, 0.11338400E-01, 0.75592700E-02, -.41164700E+00, 0.37435100E-01, -.41102100E+00, 0.49366100E+00, 0.26990400E+00, 0.39231100E-01, 0.14923300E+00, -.17724900E+00, -.17016400E-01, -.10648700E-01, 0.14643100E-02, -.41320300E+00, 0.46306400E-01, -.14765400E-01, 0.55699000E+00, -.35812400E+00, 0.10034000E+01, 0.15559400E+00, -.37960000E+00, -.13514200E+00, 0.81893400E-02, -.24918000E-01, -.34018500E+00, 0.23858100E-01, -.78572700E+00, -.19949600E+00, 0.19041500E+00, -.34579900E-01, 0.12510500E+00, 0.56357800E+00, 0.55605800E-01, 0.16663000E+00, 0.96893300E-03, -.73283800E-03, 0.10165100E+01, -.90234100E+00, -.14052800E+01, -.14761100E+00, -.93808600E+00, 0.10916700E+00, -.53853800E+00, -.18518600E+00, -.36387300E-01, 0.23773000E-02, 0.89995300E-01, 0.42977600E-01, 0.12310300E+00, -.77571900E-01, -.18124600E+00, -.72587700E-01, -.88880900E-01, 0.29381900E-01, -.33265300E-01, 0.10488000E+00, 0.10515700E-02, 0.11631600E+00, -.11058100E+00, -.46311800E+00, -.49183500E+00, -.95735900E-01, -.14839200E+00, 0.11192300E-01, -.25374800E+00, -.10095600E+00, -.73044400E-01, -.42306000E-02, 0.16591700E+00, -.41989500E-01, 0.23986800E+01, 0.42774200E+00, -.68173200E-01, -.71418800E-02, -.39781900E-01, -.10061600E+00, -.67021500E-02, -.29164200E+00, -.58590000E-03, 0.83181300E-01, -.10734300E+00, 0.58637700E-01, 0.70898800E-01, -.22831500E+00, 0.26172800E+00, -.40880700E+00, -.29651500E-01, 0.83865500E-01, -.11262200E+00, -.50805000E-02, -.64514400E-01, 0.33453100E-01, 0.45271700E+00, -.24328700E-01, -.31706600E-01, -.16736200E+00, 0.44787100E-01, 0.11161900E+00, -.16087600E+00, 0.19576900E-01, -.35400000E-02, 0.98092300E-02, 0.61578900E-01, 0.55945300E-02, -.34650300E+00, 0.22444800E+00, -.99457500E-01, 0.65846100E-01, -.58537700E-01, -.51062100E-01, 0.16758700E+00, 0.34197500E-02, 0.63689200E-01, -.26481700E-01, 0.25547700E-01, -.94747000E+00, 0.81646500E-01, 0.11973800E+00, -.32098900E+00, -.70580800E-01, -.76576500E-02, 0.11454700E+00, -.22062800E-02, -.93321400E+00, -.35580000E+00, -.52826600E-01, -.10584200E+00, -.10423400E+00, -.18410600E+00, -.52123800E+00, -.26165200E+00, -.18258600E-01, 0.44807700E+00, -.79421200E-02, -.24060800E-01, 0.40616600E-01, 0.11668200E-01, 0.23833500E-01, -.32248900E-01, -.28362700E+00, -.48261300E-01, 0.13838600E+00, 0.16624300E-02, 0.82133000E-01, 0.41818400E-01, 0.16461600E+00, 0.13424100E+00, 0.28202400E+00, -.10066000E+00, -.39739500E-01, -.16627800E-01, 0.85088700E-01, 0.76058600E-01, 0.64738000E-02, -.37100300E-01, -.75026400E-01, -.31361800E-01, -.14052000E+00, -.32551400E-01, -.43034000E+00, -.18173100E-01, 0.13512700E+00, -.18342400E+00, 0.14998800E+00, -.60905900E-01, 0.56678600E-01, -.65959600E-02, 0.43216700E-01, 0.27187500E+00, 0.36777400E+00, 0.10534700E+00, -.10382500E+00, -.21538800E+00, 0.65201300E-01, -.35298000E-01, 0.98122100E-03, 0.28353000E+00, 0.18012100E-01, -.48701500E+02, -.60771100E+01, -.31975400E+02, -.41722400E+02, -.42492500E+01, -.27714600E+02, 0.26894800E+02, 0.91682200E+02, -.42042200E+02, -.29413800E+01, -.46095100E+02, -.10706200E+02, -.53559700E+01, -.21240700E+02, 0.12016000E+02, -.22419700E+02, -.21127800E+01, -.13797200E+02, 0.98548100E+02, -.49601400E+02, -.80809300E+02, -.49263000E+02, -.21201700E+02, -.23038000E+02, -.90208200E+01, 0.19222000E+02, -.23437600E+02, -.26790100E+02, -.13124500E+02, 0.69661800E+02, -.37482700E+02, -.43571600E+02, -.35048500E+02, 0.64595400E+01, -.29864400E+01, -.17132300E+02, 0.24681700E+02, 0.71329500E+01, -.55893900E+01, -.43588300E+02, 0.12159000E+02, -.71526600E+01, -.10634000E+02, -.62176000E+01, -.28885000E+01, -.10486900E+02, -.40841200E+00, -.56280000E+01, -.20108100E+02, 0.40111300E+01, 0.14532800E+02, 0.39239200E+02, -.23413200E+02, -.18137700E+02, -.17641600E+02, -.32732000E+02, -.46059900E+01, -.40292900E+01, -.21984600E+02, -.16268500E+02, -.43545600E+01, -.21627200E+00, 0.92226400E+01, 0.12575700E+01, -.11582600E+02, -.11537100E+02, -.23881500E+01, 0.38212000E+01, 0.41021200E+01, -.52027500E+01, 0.38175600E+00, 0.21756700E+01, 0.13959200E+01, -.24350700E+01, 0.38846800E+01, 0.19951900E+01, -.53207200E+01, -.80286800E+01, 0.11307800E+02, 0.11031800E+01, -.11745700E+02, 0.41650200E+01, 0.85964800E+01, 0.10207700E+02, -.16265500E+02, -.16962500E+01, 0.23064400E+01, -.40610300E+01 },
        { -.28287400E+01, -.63078800E+00, 0.24133500E+00, 0.61365700E+00, 0.22246400E+01, 0.76674400E+00, 0.94029300E-01, 0.32746200E+01, -.24602800E+00, -.27893300E+00, 0.83832600E+00, 0.23479900E+00, 0.57092900E+00, -.98230500E-01, 0.63532200E-01, -.21025700E+01, 0.11104000E+01, -.55158800E+00, 0.90902600E-01, 0.60018900E-01, 0.50604100E+00, 0.32341700E+00, -.70890600E-02, 0.98005100E+00, 0.72961700E-01, 0.34959100E-02, 0.70539100E+00, 0.10567200E+01, -.20943700E+01, 0.46580600E-01, -.11276200E+00, 0.63902700E+00, 0.48345500E+00, -.82441000E-01, 0.10710300E-01, -.48258300E-01, 0.22584800E-01, -.11364800E+00, -.18205200E+00, -.19600700E+00, 0.17676600E+01, 0.17006600E+00, -.44701300E-01, 0.24340500E+00, -.15146700E+00, -.32968800E+00, 0.72665800E-01, 0.13320200E-01, -.77141800E-01, 0.57061500E-01, -.33187600E+00, 0.25626900E+00, 0.34554400E+00, -.79907600E+00, 0.20103200E+00, 0.13543700E+01, 0.64881000E+00, -.58287300E-01, 0.30338800E-01, -.91870700E-01, -.92781200E-02, -.24977800E+00, 0.32045300E+00, -.31064500E+00, 0.18255500E+00, -.62475000E+00, -.21927800E+00, 0.21071500E+00, 0.13491000E+01, -.32400600E-02, 0.29622200E-02, 0.51857000E+01, 0.12103300E+01, 0.21762900E+01, -.13017500E+01, 0.13037700E+00, -.12872600E+00, 0.33863300E+00, -.56390900E+00, 0.76476800E-01, 0.12845700E+00, -.44374500E-01, -.24382400E+00, 0.43866600E+00, 0.15700600E+00, -.28355300E+00, -.47066900E+00, 0.31253600E+00, -.45968800E+00, 0.30186000E-01, -.81289700E+00, -.13133100E-02, -.96843800E-01, -.80507700E-01, 0.14949600E+01, 0.11960000E+01, 0.32605200E+00, -.33688800E-01, 0.50682200E-01, 0.72968000E-01, 0.19769700E-01, -.63749200E-02, 0.26889200E-01, -.55175200E+00, 0.12648200E+00, 0.13506800E+01, -.16098400E+00, 0.20209000E+00, -.82734600E-01, -.45806600E+00, -.12850000E+00, -.42138300E-02, -.20201200E+00, 0.34714900E-02, -.24782100E+00, -.34491400E+00, 0.48078500E-01, 0.15613700E+00, 0.31640900E+00, -.15587900E+01, -.12147000E+00, -.40672200E-01, -.14850600E+00, 0.19119200E+00, -.49240800E-01, 0.28527300E+00, 0.19914900E+00, 0.30505700E+00, -.51737200E-01, -.26508400E-01, 0.14754900E+00, -.11037900E-01, -.20317700E+00, 0.12191100E+00, -.31895700E-01, -.88651900E-02, 0.51585500E-01, 0.40845200E+00, -.96284100E-01, -.58569500E+00, 0.86331400E-01, 0.10693000E+00, -.47432200E+00, 0.60647000E-01, 0.30993300E-01, 0.14157500E+00, 0.53406800E-01, -.28017200E+00, -.58316800E-02, -.47127900E-01, -.12751100E+01, 0.10633000E+00, 0.12993800E+00, -.65467700E-01, 0.84532100E-01, 0.94154700E+00, 0.18060600E+00, -.34917900E-02, -.62287700E+00, -.12141100E+00, 0.34595400E-01, 0.13493900E+00, 0.95823900E-01, 0.13536400E+00, 0.25421100E+00, -.13575000E+00, 0.81243700E-02, -.75529000E+00, 0.16945600E-01, -.69221000E+00, 0.19069100E-01, -.72385200E-01, -.11668400E+00, 0.14208800E+00, -.16650700E+00, -.76984700E-01, 0.37954400E+00, 0.61386300E-02, 0.43814600E-01, 0.76857200E-02, -.13872500E+00, -.83462100E-01, -.10755100E+00, -.39738400E+00, 0.13501700E+00, -.35860700E+00, -.76719300E-01, 0.17812300E+00, 0.20694800E-01, 0.12682000E+00, -.73670000E+00, -.94478300E-01, -.86324100E-01, -.15938300E+00, -.84673900E+00, -.16095700E-01, 0.95176300E+00, -.33595000E+00, 0.24270100E+00, -.26957200E-01, 0.16655200E+00, 0.13852100E-01, 0.22494000E+00, 0.71567400E+00, 0.76531300E+00, 0.16550700E+00, -.87997900E-01, 0.48378800E-01, 0.14311500E-01, 0.63671000E-01, -.74039800E-02, -.36041100E-01, 0.14245700E-01, 0.12351500E+00, 0.56657000E+02, -.90137100E+02, -.69868800E+02, -.33363700E+02, 0.39962200E+02, 0.16160700E+03, -.52535900E+02, 0.27438700E+02, -.66657600E+02, 0.25907400E+02, 0.16460400E+02, 0.26583800E+01, 0.79456200E+01, -.10933600E+02, 0.22017200E+02, 0.32507400E+01, -.38604600E+02, -.11035900E+03, 0.54892700E+02, -.37997500E+01, 0.55167700E+02, 0.39338000E+01, 0.12604800E+02, 0.18455200E+02, -.16758900E+02, 0.23661600E+02, 0.48846900E+01, 0.15529400E+03, -.33410400E+02, 0.17398900E+02, 0.17336200E+02, 0.17136000E+02, 0.31232600E+02, -.27751000E+01, 0.26078600E+02, -.62207300E+01, 0.16748800E+02, -.35938200E+01, -.12515500E+03, -.38837600E+02, 0.18576700E+02, -.33873200E+02, 0.19566400E+02, 0.36116800E+01, -.11880900E+02, 0.16421600E+02, 0.52154700E+01, 0.29368500E+01, -.37703300E+01, 0.64905600E+01, -.26039900E+02, 0.11891600E+02, 0.28795600E+02, 0.12727100E+02, -.16026100E+02, -.16906000E+02, -.82238800E+01, -.19181000E+01, -.46755600E+02, 0.33436400E+01, 0.36061900E+02, -.44519900E+01, 0.25337500E+01, 0.20873800E+01, 0.20585500E+01, 0.29990200E+00, 0.13556200E+00, 0.28760500E+01, -.48652300E+01, 0.10359500E-01, 0.32284300E+01, 0.28748600E+01, 0.77983600E+00, 0.98404400E+00, -.29062000E+00, -.36020500E+01, 0.98866700E+00, -.18313100E+01, 0.18544600E+01, 0.21610200E+01, 0.62388700E-01, 0.16767000E+01, -.19931500E+01, -.22389300E+02, -.31817000E+00, 0.96230700E+00, -.20472900E+01 },
        { 0.50461900E+01, 0.16191100E-02, -.89557100E+00, -.34724200E+00, -.57620500E+00, -.36578300E+00, -.21395600E+01, 0.69854800E+01, 0.46334900E+00, 0.26538000E+01, -.45699300E-01, -.96197800E+00, -.91472900E+00, 0.34296000E+00, 0.65453400E+00, -.13992200E+01, 0.31048400E+01, 0.10704900E+01, -.35949300E+01, 0.43830100E+00, -.45856500E+00, 0.37112900E+00, -.10392500E+00, -.60845100E+00, 0.32813100E+00, 0.17703500E-01, -.24454900E+00, -.16169600E+01, 0.62963800E+00, -.12724300E+00, 0.47619600E+00, 0.55074000E+00, -.57024600E+00, -.16989100E+01, -.21480200E-02, -.39943000E-01, -.76839900E-01, 0.41734600E+00, 0.55311200E-01, 0.61944700E+00, -.48124100E+01, -.19648400E+00, 0.32935100E-01, -.33954300E+00, 0.52876800E+00, -.49829300E+00, 0.63070000E-01, -.24781100E-01, 0.76312400E+00, -.26283000E+00, -.22323600E+00, -.11306100E+01, 0.56428700E-01, -.35056200E+01, -.73958400E+00, 0.75423000E+00, 0.12990400E+00, -.10100700E+00, 0.42699200E-01, 0.78132800E+00, -.18980800E+00, 0.85341100E+00, 0.31569600E+00, -.39196700E+00, -.28541800E-01, 0.32374800E-01, 0.43749400E+00, -.18346400E+00, -.98759800E+00, 0.16271300E+00, -.27225100E-01, 0.18527100E+01, 0.76958000E+00, -.14539600E+01, -.78907800E+00, 0.34402600E+00, 0.60125600E-01, -.75416200E+00, -.65578300E+00, -.25857700E-01, -.43692100E-01, 0.25497600E-01, -.26128000E-02, -.69747500E+00, -.24664300E+00, 0.22098900E+00, 0.39697600E+00, 0.94003700E-01, 0.36544300E+00, 0.14241900E-01, -.44343700E+00, 0.26407700E-02, 0.20366900E+00, 0.14668800E+00, 0.21444400E+00, 0.15011500E+01, -.40710500E-01, -.54755000E+00, 0.19857100E+00, 0.72733100E-01, 0.42032000E-01, -.29072200E+00, -.55688500E-01, -.36233600E+00, -.14660900E+00, 0.10038700E+01, 0.82153300E+00, -.11028400E+00, -.48249300E-01, -.78634900E-01, 0.15448000E+00, -.68931800E-01, 0.24755000E+00, -.41876800E-01, 0.57644300E+00, -.19213400E+00, -.18275200E+00, -.50030200E+00, 0.61817600E+00, -.35350600E+00, 0.41806400E+00, -.12840200E+00, -.43476200E-01, -.45152400E+00, -.89559600E-01, -.11237100E+00, 0.66530400E+00, 0.90661600E+00, -.14169500E+01, 0.16323000E+00, -.31976900E+00, -.48687200E+00, -.85221200E+00, 0.13040900E+01, -.36001200E+00, -.92231600E-01, 0.19540500E+01, 0.87982500E+00, -.10586600E+00, -.14140400E+01, -.56973500E+00, -.17662800E+00, -.59768600E+00, -.63013100E+00, 0.77207900E-01, -.11210100E+01, 0.63495400E-02, 0.13634700E+00, -.11520200E+00, -.12500900E+01, -.32442400E+01, -.20028000E+00, 0.21549500E+00, 0.56471000E+00, -.75152200E-01, 0.57982700E+00, -.10430000E+00, 0.22515700E-02, -.61541200E+00, 0.12064500E+00, 0.10510800E+00, 0.22999700E+00, -.21481300E+00, -.75442900E-01, -.10186300E+01, 0.43504400E+00, 0.77199600E-01, -.20951100E+01, -.15335000E-01, -.63043100E+00, 0.22248700E+00, -.31244700E+00, -.39541000E+00, 0.58598900E+00, 0.60523300E+00, -.14822900E+00, 0.35934600E+00, -.68013700E-01, -.48093400E+00, 0.29506500E+00, -.83133500E+00, -.77898200E+00, 0.65534000E+00, 0.35641200E+00, -.24340000E+00, -.85618700E+00, -.19568200E+00, -.98685700E-01, 0.35227500E-02, 0.43844500E+00, -.94061500E+00, 0.48947200E-01, 0.19784900E-01, 0.13587300E+00, 0.11610600E+01, 0.30205700E+00, -.11538000E+00, -.47529300E+00, 0.25635700E+00, -.60677700E-01, 0.19367900E+00, -.49719000E-02, -.10748000E+01, -.43982400E+00, -.25902600E+00, -.35504000E-01, -.15061400E+00, -.30838200E+00, 0.70260100E-01, -.13164700E+00, -.66008300E-01, 0.63958800E-01, -.37322600E-03, 0.16230600E+01, 0.27529200E+00, 0.10787300E+03, -.17512000E+01, -.64414300E+02, 0.40694800E+02, -.20544200E+02, -.26183800E+03, 0.11191700E+03, 0.13581900E+03, 0.13062400E+03, -.10480400E+02, 0.49323700E+02, 0.11250300E+02, -.52899200E+02, 0.44774800E+02, 0.36094200E+02, 0.14788500E+03, 0.76171900E+02, -.36616900E+02, -.16333100E+03, -.38104200E+02, -.77997200E+01, 0.62492300E+01, 0.13657900E-01, 0.45197200E+02, 0.13101000E+02, 0.28101600E+02, -.73877100E+02, 0.66561400E+02, -.21313700E+02, 0.49519400E+02, -.32760900E+02, -.33785400E+02, 0.59601100E+01, -.21132500E+02, 0.56965800E+02, -.86884200E+02, 0.27338700E+02, 0.13560000E+03, 0.10385700E+03, -.40248100E+02, -.81738800E+02, -.51496600E+02, -.14795400E+02, -.88940300E+01, -.15862000E+02, 0.50917000E+02, 0.39393200E+02, -.39724500E+02, -.74747800E+02, -.10028300E+03, 0.69024400E+02, -.35650700E+01, 0.47355000E+02, 0.52547200E+02, -.34153500E+02, 0.74214100E+02, -.45221000E+02, 0.40761100E+02, -.27140200E+02, -.24571200E+02, -.18819900E+02, -.90875600E+00, -.24410900E+01, -.35742300E+01, 0.13051900E+01, -.43879700E+01, 0.46808900E+00, 0.66793700E+01, 0.36237900E+01, -.78094800E+01, -.52468200E+01, 0.12025800E+02, -.20388700E+01, -.46778300E+00, 0.76995100E+01, 0.17549900E+02, 0.33917500E+01, 0.25355100E+01, -.30713300E+01, -.45026300E+01, -.23160600E+02, -.25489900E+02, 0.58490500E+01, -.16790100E+01, 0.42874300E+01, 0.14066500E+02 },
        { -.16661900E+01, -.54281800E+00, 0.47716800E+00, 0.71209100E+00, -.30632900E-01, 0.85171900E+00, 0.29440200E+01, -.32408100E+01, -.97768600E-01, -.19007800E+01, 0.53242300E-01, 0.56693700E+00, 0.41451400E+00, -.35830800E-01, -.37372600E+00, 0.19695000E+01, 0.53793900E+00, 0.84459600E+00, 0.19072400E+01, 0.95842000E-01, -.11201000E+01, -.14164300E+00, -.15323100E-01, -.41475400E+00, 0.26678900E-01, -.48103100E-01, -.38535200E+00, -.83475200E+00, 0.12240400E+01, 0.40212000E-02, -.59594100E+00, -.36502400E+00, 0.77271300E-01, -.66216900E+00, -.16803100E-01, -.95605800E-01, 0.13813600E-01, 0.52901200E+00, 0.55377100E-02, 0.18599600E+00, -.10117400E+01, -.21115900E+00, 0.41376400E-01, -.11369100E+00, 0.17315200E+00, 0.26298300E-01, -.74923900E-02, 0.65229100E-02, -.18334300E+01, -.24237500E-01, 0.11741000E+00, 0.42285200E-01, -.35658200E+00, -.65040200E+00, -.27460500E+00, -.41557200E+00, -.30072500E+00, -.47535300E-01, -.13177100E-01, 0.21370700E+00, -.63407000E-01, 0.24142500E+00, -.19346200E+00, -.72769700E-01, -.10031000E+00, -.12941800E-01, 0.62083600E+00, -.42791900E-01, 0.33920400E-01, 0.21150400E-01, -.65277800E-02, 0.10105000E+01, -.29669300E+00, -.90171100E-01, -.57200700E+00, -.15829900E+00, 0.17251600E+00, -.41031800E+00, -.22146300E+00, -.69241000E-01, -.18491800E-01, 0.27059100E-01, 0.25694400E-03, -.24325200E-02, -.15877300E-01, 0.11491300E+00, 0.24393000E+00, 0.64566600E-01, 0.28022300E+00, 0.51398800E-01, 0.12322800E+00, 0.25625400E-02, 0.22550700E+00, 0.46077200E-01, -.47630700E+00, -.44223400E+00, -.10079000E+00, -.77107000E-01, -.27650400E-01, -.36245500E+00, 0.78037000E-01, -.78662700E-01, 0.12719000E-01, -.10674500E+00, 0.25942500E-02, 0.14662000E+01, 0.16941900E+00, 0.83156200E-01, 0.63501900E-01, -.94310600E-01, -.87403400E-01, 0.18145600E-01, 0.36156700E+00, 0.10105400E-01, 0.20597700E+00, -.18387000E+00, -.13050800E+00, 0.20577900E+00, -.71319100E+00, 0.10844500E+01, -.58267000E+00, 0.10893800E+00, 0.17266400E+00, -.10351900E+00, 0.10124500E+00, -.26088100E+00, 0.31110800E+00, -.46796600E+00, -.51079100E+00, -.17753200E+00, -.16579400E+00, 0.10728300E+00, 0.27045700E+00, -.32262500E+00, -.18282000E-01, 0.18763400E-01, 0.29113700E-01, -.32519400E+00, 0.41840700E-01, 0.62455100E+00, -.15675100E+00, -.77414100E-01, 0.26895600E+00, -.43307000E+00, -.56172400E-01, -.72512500E+00, -.95472500E-01, 0.45726400E+00, -.90205900E-02, 0.16156500E+00, 0.19356600E+01, -.43719100E-01, 0.23930600E+00, -.87222200E+00, -.34961700E-01, -.11916200E+00, -.70818300E-01, -.21971400E-03, -.55340800E+00, -.24878800E+00, -.48370900E-01, -.16315900E+00, -.70041800E-01, -.15111200E+00, -.20189600E+00, 0.34489900E-01, 0.27646600E-01, 0.17728900E+00, -.55155500E-02, 0.23217900E+00, 0.86273600E-01, -.27770400E-01, -.62368600E-02, 0.38083200E-01, 0.26016500E+00, -.71493400E-01, -.11138800E+00, -.85757300E-02, -.76230300E-02, -.33200100E-01, -.69346600E-01, -.23710800E+00, 0.37004900E+00, 0.76887700E-01, 0.52076800E-02, -.26467600E+00, 0.78391400E-01, 0.11271800E+00, -.28633600E-01, 0.61178300E-01, -.30161300E+00, 0.84978500E-01, -.52761800E-01, -.14464800E+00, -.70272300E+00, -.15378200E+00, 0.16277800E+00, -.46661200E-01, -.28485900E+00, -.15133400E-01, 0.15580600E-01, 0.61973100E-02, -.91810800E-01, -.16946000E+00, -.28769500E+00, -.20295400E+00, 0.84800400E-01, -.10129900E+00, 0.42117300E-01, 0.62130000E-02, 0.22127400E-02, -.29188800E-01, 0.29638500E-01, -.16288000E+00, 0.53670200E+00, 0.19654500E+00, 0.32545200E+02, 0.12178600E+02, -.84450800E+01, -.38045900E+02, 0.12513600E+02, -.14806800E+01, 0.31240600E+02, -.60874900E+01, -.26953900E+01, -.14140200E+02, 0.11206900E+02, -.46107900E+01, -.18948500E+02, -.60952200E+01, 0.17613600E+02, 0.52028700E+02, -.26286500E+02, 0.38161700E+02, -.26021300E+02, 0.39002800E+01, -.24338700E+01, -.18778900E+02, -.12194500E+02, -.24438300E+02, -.76805200E+01, -.79269400E+02, -.17421300E+01, -.32878100E+01, -.10524800E+02, 0.10815300E+01, -.18391400E+01, -.45395800E+01, -.62389900E+01, -.19901900E+02, -.40228700E+01, -.15664000E+01, 0.38470800E+02, -.48950700E+02, 0.22878400E+02, 0.38933600E+02, 0.24310900E+02, 0.53692800E+01, -.44342300E+01, 0.27550900E+02, -.85166100E+00, 0.26502900E+02, 0.13575600E+01, 0.34280100E+02, 0.20309800E+02, -.15274200E+02, 0.10822000E+02, -.95379400E+01, -.15008800E+02, -.10668600E+02, -.98429700E+01, 0.10621500E+02, 0.86055400E+01, -.18900500E+02, -.95023600E+01, 0.48112800E+01, -.17687800E+01, 0.25485300E+01, 0.25954600E+01, -.11359800E+00, -.18094700E+00, 0.44542100E+01, 0.12425800E+01, 0.88159600E+00, -.47241200E+00, -.14094700E+01, -.14972700E+01, 0.37182700E+01, -.38200600E+00, 0.20219600E+00, -.22358800E+01, -.25826700E+01, 0.46202900E+01, 0.23920400E+01, -.14653500E+00, 0.26179600E+01, 0.46202000E+01, 0.28890900E+02, 0.27996700E+00, 0.62245400E+00, -.40878000E+01 },
        { -.34107300E+01, -.10170200E+01, -.12694600E+00, 0.10751900E+01, 0.24148500E+01, 0.95171000E+00, 0.10253700E+01, 0.20856700E+01, -.17642500E+00, -.91115700E+00, 0.83757300E+00, 0.34393600E+00, 0.61290700E+00, -.63437600E-01, 0.63754600E-01, 0.69160900E+01, 0.60818200E+00, -.55164700E+00, 0.59927300E+00, -.22709800E+00, 0.10868100E+01, 0.48371400E+00, 0.14529100E+00, 0.28941800E+01, -.18872200E-01, -.45804000E-01, 0.73920000E+00, 0.36346000E+01, -.20168200E+01, 0.64179800E-01, -.66222800E+00, 0.14268100E+00, 0.73366700E+00, -.99628100E+00, 0.29229200E-01, -.13171900E+00, 0.35179900E-01, -.76817000E-01, -.27234500E+00, -.50672400E+00, 0.19001900E+01, 0.53219700E+00, -.90886300E-01, 0.39069800E+00, -.90422300E+00, 0.24671800E-01, 0.18326500E-01, -.60249200E-02, 0.12540300E+00, 0.13000500E+00, -.26330500E+00, -.22645400E+00, 0.13191400E+00, 0.49555400E-01, 0.34094600E+00, 0.99349800E+00, 0.35140700E+00, 0.50126700E-01, 0.97507000E-02, -.26399800E+00, 0.26229100E+00, -.34847000E+00, 0.24309100E+00, -.30189300E+00, -.30600100E+00, -.30857700E+00, 0.44438400E+00, 0.24893900E+00, 0.13829500E+01, -.15486700E-01, 0.58077100E-01, 0.50926000E+01, 0.77836700E+00, 0.12311800E+01, -.68509300E+00, 0.10567200E+00, -.24003300E+00, 0.70665900E-02, -.67159000E+00, -.65815800E-01, 0.16422200E+00, -.23718900E-01, -.24379800E+00, 0.32051400E+00, 0.10701100E+00, -.23442900E+00, 0.18055300E-01, 0.24604700E+00, -.67464800E+00, -.16221800E-01, -.28130500E+00, -.25514100E-03, -.21090900E+00, -.18511700E+00, 0.78178600E+00, 0.92213200E+00, 0.24147900E+00, 0.91421700E-01, 0.58241800E-01, 0.17687500E+00, -.31594900E-01, 0.27901100E+00, 0.26787900E-01, -.34424000E+00, -.72905700E-02, 0.17237700E+00, -.10518300E+00, 0.13142500E+00, -.16079400E+00, -.51408200E+00, 0.35816000E-01, -.29361600E-01, -.69567800E+00, -.15342100E-02, -.16494800E+00, 0.23234000E+00, 0.11635300E+00, -.23813400E+00, 0.10447900E+01, -.67990000E+00, 0.80187000E+00, -.10601900E+00, -.83726900E-01, -.54389900E-01, -.77474500E-01, -.63376600E-01, -.13692500E+00, 0.85413100E+00, -.28000300E+00, 0.94188300E-01, 0.43415800E+00, 0.70964000E-01, -.23714500E+00, 0.11884200E+00, -.19621400E+00, -.25985100E-01, 0.63494900E+00, 0.11086100E+00, -.14990700E+00, 0.39704700E-03, -.47386500E-01, 0.14546700E+00, -.13828700E+00, 0.15543300E+00, 0.28794800E-01, 0.35842100E+00, 0.86307600E-01, -.30257400E+00, -.30606000E-01, 0.39127800E-01, -.13289500E+01, -.39315300E+00, -.73641900E-01, -.35986400E+00, 0.14000600E+00, -.22410500E+00, -.62345500E-01, 0.14439600E-02, 0.25162900E+00, 0.20606700E+00, 0.47205700E-02, 0.16829300E+00, 0.75251100E-01, 0.75200900E-01, 0.33441300E+00, -.72001400E-01, 0.84148400E-02, -.53916800E+00, -.28747200E-02, -.23224000E+00, 0.31128400E-01, 0.31942100E-03, -.11511300E+00, 0.10867900E+00, 0.16750700E+00, -.13116600E+00, -.17114500E+00, -.12072500E-01, -.15127200E+00, 0.92182600E-01, 0.23030900E+00, -.53193500E-01, -.27107400E+00, -.96287700E-01, 0.61555400E-02, -.71153500E+00, -.29282100E-01, -.10961100E+00, 0.37508800E-01, 0.17049800E+00, -.17843200E+00, -.12558000E+00, -.68679400E-02, -.80347300E-01, 0.30727900E+00, 0.14536400E+00, 0.41785000E+00, -.93606800E-01, 0.39537500E+00, -.17942300E-01, 0.17303200E-01, 0.31857300E-01, -.25067800E+00, -.69994800E-01, 0.13731400E+00, 0.12157500E+00, -.88299400E-01, 0.36971600E+00, -.16625000E+00, -.33299300E-01, 0.65879100E-02, -.14556900E+00, 0.69120200E-01, -.22116900E+00, 0.38955000E+00, -.31287100E+00, -.87827500E+00, -.47034900E+02, -.59248700E+01, -.36085800E+02, 0.14611400E+02, -.60927300E+01, 0.13427300E+03, -.72983000E+01, -.19041000E+02, -.31859800E+01, 0.39599000E+01, -.74610900E+01, -.23184000E+02, 0.20190400E+01, 0.65692700E+02, 0.18678500E+03, -.92839300E+02, -.77457300E+02, -.93446500E+02, -.22086900E+02, -.21254900E+02, -.26330600E+02, 0.24435000E+02, -.53426100E+02, -.15313800E+02, -.15426200E+03, 0.83319200E+02, -.44414000E+02, 0.21529900E+02, -.40051000E+02, -.14970100E+02, 0.11055300E+02, -.44432200E+02, -.12758200E+02, -.50243300E+02, 0.22459000E+02, 0.26469500E+02, -.65800500E+02, 0.34353900E+02, 0.94679400E+02, 0.32862000E+02, 0.14514400E+02, 0.23037400E+02, 0.19673600E+02, -.16667200E+02, 0.18277900E+01, 0.31467400E+02, 0.41505600E+02, -.48738000E+01, 0.25472700E+01, 0.37867000E+02, 0.10774700E+01, 0.25721600E+01, -.53682000E+01, -.85733500E+01, 0.13540600E+02, 0.14939000E+02, -.18678300E+02, 0.27127700E+01, 0.22828200E+01, 0.52649200E+00, -.63934800E+01, -.57278500E+01, -.21850300E+01, 0.16360800E+01, 0.39773700E+01, -.74818500E+00, 0.64567300E+00, -.34360800E+00, 0.11092800E+00, -.79795500E+00, 0.49536800E+01, 0.14703700E+01, -.16111700E+01, 0.22948400E+01, 0.53825800E+01, 0.55065700E+01, -.64919000E+01, 0.18752600E+01, 0.39273500E+01, -.27349800E+00, 0.23830300E+02, -.33211300E+01, 0.21491500E+01, -.41619500E+01 },
        { 0.78793300E+01, 0.25030000E+01, -.29179700E+01, -.47563300E+01, -.25971500E+01, -.21883100E+01, -.33150700E+01, 0.13443200E+02, 0.29333800E+00, 0.21512700E+01, 0.27127700E+01, 0.24638400E+00, 0.10730500E+01, 0.74217000E+00, -.44989400E+00, 0.24642400E+01, 0.92101700E+01, 0.60259600E+01, -.14882200E+01, -.13977400E+01, -.52463400E+01, 0.14306400E+01, -.30285500E+00, 0.97060000E+00, -.21733100E-01, 0.62149800E-01, 0.21899800E+00, 0.16248200E+01, -.60097100E+00, 0.13172400E+00, 0.13469600E+01, 0.13203100E+01, 0.17816500E+00, 0.60772000E+01, 0.14027200E+00, 0.16544800E+00, -.13720500E+00, -.27566800E+01, -.14874900E+00, -.24869000E+01, -.46269000E+01, 0.17586100E+01, 0.48040600E+00, 0.73388200E+00, -.18705500E+00, 0.43390100E+00, -.75396700E-01, -.19449800E-02, -.13225400E+01, -.82303500E-01, -.43936600E+00, -.19145100E+01, 0.59421700E+00, -.26709400E+01, -.50065800E+00, 0.96370200E+00, -.40330200E+00, -.60219800E-02, 0.71530600E-01, -.24574100E+00, 0.16170600E+00, 0.12798100E+00, 0.40773400E+00, -.43137200E+00, 0.52283200E+00, -.48514400E+00, -.15518900E+01, -.31486600E+00, 0.95953800E+00, 0.13889400E-01, 0.13428600E+00, 0.39781700E+00, 0.82722700E+00, 0.42422400E+01, -.29390900E+00, 0.12036500E+01, -.30635900E+00, 0.88483000E+00, -.27845800E+00, 0.11351700E+00, 0.17394200E+00, -.96234400E-01, -.47731700E+00, -.12033700E+01, 0.27186300E+00, 0.98090800E+00, 0.25303800E-01, 0.15581300E+00, -.90906000E+00, 0.19830900E-01, -.41214100E+00, 0.81313200E-02, -.23921800E+00, -.88669200E-02, 0.78571100E-02, 0.17156400E+01, 0.30251200E+00, 0.72442400E+00, -.12207100E+00, 0.38828500E+00, 0.92458300E-01, 0.13272500E+00, 0.39008700E-01, -.36727200E+00, -.18417900E-01, -.60057900E+01, -.37967000E+00, -.13341100E+00, -.89541700E-01, 0.87597400E+00, -.12286700E+00, 0.60530000E-01, 0.13827000E+00, 0.42006200E-01, -.14753400E+00, -.21142400E+00, 0.27136600E+00, 0.10781300E+00, -.43807000E+00, -.11720800E+01, 0.33191100E+00, -.35874100E-01, -.18462500E+00, 0.14393400E+00, -.24938600E-01, 0.15935700E+00, -.38707400E+00, -.69372400E+00, 0.12529500E+00, 0.31080400E+00, -.22965100E+00, -.37184600E+00, 0.83090800E+00, -.73503500E-01, 0.14642300E+00, -.18704700E-01, 0.22231800E+00, -.85898700E-01, 0.17891600E+00, 0.96289900E+00, -.90279500E+00, -.30948000E+00, -.32315700E+00, -.98811300E+00, 0.49693900E-01, -.49269200E+00, -.12407400E-01, 0.20247800E+00, 0.20601300E+00, -.14740900E+00, 0.78283800E+01, 0.49557600E+00, 0.36989800E+00, 0.10286700E+01, -.33612100E-01, 0.22109600E+01, -.69052100E-02, -.31259200E-02, -.10360600E+01, 0.10664000E+00, 0.41499900E+00, -.16582200E+00, 0.17904000E+00, -.53568400E+00, -.44439200E+00, -.37628400E+00, -.48363900E-04, 0.19941200E-02, 0.48997800E-02, -.57981800E+00, 0.16298800E+00, 0.20769900E-01, -.96330200E-01, 0.32805000E-01, 0.62188000E+00, 0.11960900E+00, 0.42429500E+00, 0.90575900E-02, 0.78951400E+00, 0.31696700E-01, 0.15917800E+00, -.42590000E-01, 0.10810500E+01, -.11150900E+01, -.11796400E+00, -.27561900E+00, -.52546100E+00, 0.11051500E+01, 0.88800000E-01, -.52295300E-01, 0.13015000E+01, -.39388800E+00, -.81620200E-01, -.16975300E+00, 0.20376000E+01, 0.64548700E+00, 0.96133500E+00, 0.22047500E+00, -.30320000E-01, 0.11762200E+00, -.11379300E+00, -.34169800E-01, -.12154600E+00, 0.62064100E+00, 0.32418100E+00, 0.37395100E-01, 0.12007200E-01, 0.13734500E+00, 0.28409500E+00, 0.10980200E+00, 0.13506700E-02, 0.19485400E+00, -.53169300E-01, -.12849400E+01, -.12482800E+01, 0.45693300E-02, -.27291500E+00, -.15672100E+01, -.42057800E+02, 0.28704700E+02, 0.32152100E+03, -.14708300E+03, -.83237000E+02, -.16176300E+03, -.47396300E+02, -.35115800E+02, -.77848100E+02, 0.20629600E+02, -.10329200E+03, -.26823400E+02, -.10816000E+03, 0.21539000E+03, -.10844900E+03, -.12002700E+03, -.10774000E+03, -.14926900E+00, -.34439100E+02, -.35850100E+02, 0.27953700E+02, -.64276600E+02, -.38267200E+02, 0.66977300E+02, 0.14619800E+03, -.83188700E+02, -.10110100E+03, -.71441900E+02, 0.14382300E+01, -.70034900E+01, -.54104700E+02, 0.42368900E+02, -.25165700E+02, -.11599500E+02, -.63486600E+02, -.19187300E+01, -.56508200E+01, -.12026700E+01, 0.84780100E+00, 0.72756700E+01, -.12647800E+02, 0.20258800E+02, 0.16832700E+02, 0.10330600E+02, 0.14208800E+02, 0.56118800E+02, 0.15666400E+03, -.98552700E+02, -.12978000E+03, -.76464300E+02, -.14255100E+03, -.61252800E+02, -.57012700E+01, -.40071600E+02, -.67509600E+02, -.46051300E+02, 0.17879700E+03, 0.29947000E+02, -.11658800E+01, -.28929500E+02, -.28115300E+02, -.40320700E+01, 0.59917700E+01, 0.27028300E+02, -.66641500E+01, 0.70400300E+01, 0.11385900E+01, -.90526300E+00, -.11676600E+01, 0.18287100E+02, 0.40548900E+01, -.69378700E+01, -.17354000E+02, 0.28058200E+02, 0.14547800E+02, -.29019000E+02, 0.61128100E+01, 0.87885100E+01, 0.23380600E+02, -.93986400E+01, -.37144600E+01, 0.13977700E+02, -.15676100E+02 },
        { -.70332800E+01, -.23978800E+01, 0.31952600E+00, 0.37466700E+01, 0.21019200E+01, 0.17274600E+01, 0.18659200E+01, -.32315700E+01, -.15525800E+00, 0.49562600E+00, 0.30879500E+00, 0.10428500E+01, 0.39016900E+00, -.23161000E+00, -.71825800E+00, 0.97443400E+01, -.10934500E+01, -.17413000E+01, 0.20487500E+01, -.46103700E+00, 0.98780100E+00, 0.62483500E+00, 0.21468500E+00, 0.27177900E+01, 0.41004000E-01, -.11162000E-01, 0.23122800E+00, 0.21715800E+01, 0.10484200E+01, 0.11292800E+00, -.11456900E+01, 0.26846000E+00, 0.70261000E+00, -.54455200E+01, 0.27503000E-01, -.33937400E+00, -.69277700E-01, 0.97619200E+00, -.54549000E+00, 0.12036500E+00, 0.24278200E+01, -.43057900E+00, -.66142300E-01, 0.27797800E+00, -.75082800E+00, -.25054600E+00, 0.12571900E-01, -.12016900E+00, -.16859600E+01, 0.37641900E+00, -.73856500E+00, -.49415600E-01, -.49476000E+00, 0.22266600E+01, 0.40431100E+00, 0.22857900E-01, 0.32448100E-01, -.86893900E-01, -.16445500E+00, -.39159800E+00, 0.42355800E+00, -.61720400E+00, -.26811500E+00, -.70961600E+00, -.11631900E+01, 0.44584800E+00, 0.14082200E+01, 0.48763100E+00, -.11605300E+01, -.27413300E-01, -.10293400E-01, -.29452900E+01, -.14306600E+01, -.41738100E+01, 0.15162300E+01, 0.27877100E+00, -.25381000E-01, -.92051300E+00, 0.28224600E+00, -.19713500E+00, -.61194200E-01, 0.40707000E-01, 0.21810000E+00, 0.10254600E+01, -.62493200E+00, -.88688500E+00, 0.23717100E+00, 0.20945000E+00, 0.22491900E-01, 0.42442200E-01, 0.69821900E+00, -.23417500E-02, -.24400200E+00, -.51686000E-01, -.58790100E+00, 0.27614000E+00, 0.69971000E+00, 0.56783700E+00, 0.15348100E+00, -.10148700E+01, 0.24678600E+00, 0.13912700E+00, -.52338000E-01, -.38628400E+00, 0.87051300E-01, -.18055600E+01, -.67230200E+00, -.79825400E+00, 0.26925800E+00, 0.12484600E+01, 0.98072900E-01, -.11906200E+00, 0.10381900E+01, -.51726100E-02, 0.91992400E+00, 0.14678100E+01, -.27501900E+00, -.68544200E+00, 0.12619600E+00, 0.15106300E+01, 0.63696800E+00, -.93632800E-02, 0.20038000E-01, -.53106600E+00, 0.22922600E-01, -.66921900E+00, -.55594000E+00, -.74188500E+00, -.85517800E+00, 0.12732600E+00, -.35017400E+00, -.38400800E+00, -.27203600E+00, 0.12896700E+01, -.36361900E+00, -.70430800E-01, 0.16229000E+01, -.79006200E-01, -.21673000E+00, 0.81974700E+00, 0.61171700E-01, 0.17334300E+00, -.70653000E+00, -.10088800E-01, 0.13403500E+00, -.45570600E+00, 0.48383200E-01, 0.36865900E+00, 0.34639600E-01, -.14127300E+01, -.61291600E+01, -.80790000E+00, -.48783500E+00, -.11856700E+01, 0.21352100E-02, 0.51147700E+00, -.20269200E+00, -.13993800E-03, 0.10883400E+00, 0.50255700E+00, -.82389900E-01, 0.95120300E-01, -.33640700E+00, -.12563900E+00, 0.75531900E+00, 0.84578400E+00, 0.14323600E+00, -.13632000E+00, 0.21275700E-02, 0.10266700E+01, -.82264400E-01, -.13816800E+00, -.97574400E-02, 0.13880300E+00, 0.14909200E+01, -.22719600E-02, -.72069100E+00, -.57771400E-01, -.57416500E+00, -.33372700E-01, -.74562500E+00, -.18350900E+00, 0.99927800E+00, 0.75294000E+00, -.29892200E+00, -.11752400E+00, -.18481000E-01, -.55471900E+00, -.88200100E-01, -.36885800E+00, -.15494400E-01, 0.28958800E+00, 0.18276400E+00, 0.10704600E+00, -.10675100E+01, -.13160400E-01, -.47920500E+00, 0.37239100E+00, -.81608900E+00, 0.48919600E-01, -.33674000E+00, -.70639800E-01, 0.19492600E+01, -.98916700E+00, -.90429900E-01, -.17933600E+00, 0.31498800E-01, -.75186800E-01, 0.32496900E-01, 0.11251800E+00, -.60079700E-01, -.13093400E+01, -.15184000E+00, -.19710800E+01, -.53349800E+00, 0.32326600E+00, 0.24748600E+01, -.93768700E+00, 0.50711600E-01, 0.24949100E+03, 0.74374400E+02, -.42914000E+02, -.17149500E+03, -.36914800E+02, 0.94317500E+01, 0.29119600E+02, -.52963900E+02, -.54803800E+01, 0.28243400E+02, 0.16936000E+02, -.37196400E+02, -.11964100E+01, 0.28146700E+01, -.18753300E+03, 0.62686500E+00, -.26281900E+02, -.17136900E+02, 0.48838100E+02, 0.57332200E+02, 0.40371000E+01, -.56437100E+01, 0.21711000E+03, 0.81392700E+02, -.35519300E+02, 0.23129300E+02, -.41659100E+02, 0.19368600E+01, 0.13208900E+02, -.30016900E+01, 0.59709600E+02, -.61890600E+01, 0.14947800E+02, -.96485400E+02, 0.49767300E+02, -.19054900E+02, -.19923000E+03, -.24548300E+02, -.16747500E+02, 0.15141500E+02, -.56676900E+02, -.33568100E+02, -.52781700E+02, 0.11518100E+02, -.37921600E+02, 0.24744700E+02, -.69918700E+01, -.47012700E+02, -.14135400E+02, -.13699500E+02, 0.38544300E+02, -.31560000E+02, -.63849900E+02, -.39970600E+02, 0.55813900E+02, 0.55488200E+02, 0.46271000E+01, 0.12541700E+02, -.20889100E+02, -.19983800E+02, -.48455100E+01, 0.65790600E+01, 0.10286600E+01, -.13687600E+02, -.58751800E+01, 0.10772400E+02, 0.12380100E+02, -.27992400E+01, -.21585300E+01, 0.49973200E+01, -.11318300E+02, -.55954300E+01, 0.20136300E+02, -.15614000E+01, -.20208200E+02, 0.67353600E+01, -.39532100E+01, 0.37118100E+01, -.92225700E+02, -.11523600E+02, 0.41124500E+01, -.14393800E+01 },
        { 0.11698500E+01, -.42829000E-01, -.56971300E+00, -.26854500E+00, -.46714900E+00, -.50420100E-01, -.30092100E+00, 0.72512600E+00, 0.98987000E-01, -.16159300E+00, 0.62969000E-01, 0.24492900E-01, -.16921500E+00, 0.44988600E-01, 0.49733800E-01, -.53921000E+00, -.96053700E+00, -.22752100E+00, -.22788300E+00, -.14987800E+00, -.37413100E+00, 0.15067600E+00, 0.88104900E-02, -.22791800E-01, 0.94663300E-01, 0.20919900E-01, -.35921700E-01, -.14968100E+00, 0.10234000E+00, -.27140900E-01, 0.11722700E-01, 0.21067700E+00, -.41183000E-01, -.92112900E+00, 0.65176200E-02, -.25846400E-01, -.29733200E-01, -.71446000E-01, -.45264600E-01, 0.95887900E-01, -.46727600E+00, -.15697400E+00, 0.34873500E-02, -.62946200E-01, 0.16690500E+00, 0.10817700E+00, -.16330700E-01, -.20218600E-02, 0.55143900E+00, -.70557900E-02, 0.19816500E+00, -.40321500E+00, 0.20963800E+00, -.96418000E+00, -.12764100E-02, -.32275400E+00, -.16114800E+00, -.17690200E-01, -.45030800E-03, -.10849800E+00, -.60788100E-01, 0.41870000E+00, -.10530900E+00, -.12750800E+00, -.17296200E+00, -.91191600E-02, -.11210700E+00, 0.74801000E-01, 0.39450300E+00, 0.32760300E-02, -.45413300E-01, 0.73700400E+00, 0.45006800E+00, 0.49986400E+00, -.20846000E+00, 0.71893200E-01, 0.35843000E-01, -.20551400E+00, -.20847600E+00, 0.10293400E-01, -.37355700E-01, 0.18878500E-01, 0.41931200E-01, -.16827400E+00, -.77114500E-01, 0.80890400E-01, 0.21805300E-01, 0.19052000E-01, 0.68656600E-01, 0.42251200E-02, -.10342500E+00, -.17006600E-03, 0.47666500E-01, 0.22492000E-01, 0.17119600E+00, 0.40191200E+00, 0.58981600E-01, -.33119000E-01, 0.77882600E-01, 0.14368600E+00, -.17722600E-02, 0.82471100E-02, -.57179100E-02, 0.17437000E-01, -.56486100E-01, 0.22698300E+00, -.76865000E-01, -.69012400E-01, 0.67822200E-02, -.21702700E-03, 0.93510100E-01, -.64471800E-03, 0.12806200E+00, -.10961600E-01, 0.93388700E-01, 0.17891500E+00, -.66964600E-01, -.93480500E-01, -.13014200E+00, 0.37660300E+00, -.13016000E+00, -.14542900E-01, -.41773500E-03, -.45913400E-01, -.12453400E-01, -.10664500E+00, -.20823500E-01, 0.25308600E+00, 0.21646100E-01, 0.21588400E-02, 0.53825000E-02, 0.36366500E-01, 0.85191700E-01, -.16716100E+00, -.61342500E-01, -.29386400E-02, 0.26102600E+00, 0.64211900E-01, -.18261000E-01, -.27943000E-01, 0.75038700E-02, -.10745400E+00, -.77175000E-01, -.13821800E+00, -.42316600E-01, -.88808500E-01, -.23841700E-01, 0.24121100E+00, -.58174200E-01, 0.74666300E-03, -.16898000E-01, 0.14644300E+00, 0.11857900E+00, -.20893200E+00, -.68028900E-01, -.35443700E+00, 0.11578400E-01, 0.53154200E-03, 0.43624600E-01, -.93335500E-01, -.45064100E-01, 0.14441700E-01, -.10323900E+00, 0.66860900E-01, -.73526800E-01, -.72412800E-01, -.11957700E-01, 0.58352800E-01, -.62542100E-02, 0.16779100E+00, 0.16169800E-01, 0.10639100E-01, 0.34022100E-01, -.31969700E-01, -.59153000E-01, 0.37669700E-02, -.97885400E-01, 0.49752400E-02, 0.33151600E-01, 0.18432600E-01, 0.16672300E+00, 0.26242100E-01, 0.93093900E-01, -.93113000E-02, -.18957300E-01, 0.22416700E+00, 0.46899500E-01, -.31389800E-01, 0.15875600E-02, 0.23314900E-01, 0.83384200E-01, -.37153400E-01, 0.51912600E-02, 0.43829900E-01, 0.23898000E+00, 0.39005400E-01, -.13951900E+00, 0.54358300E-01, -.10144500E-01, 0.12732200E-02, 0.79327700E-03, 0.60712900E-03, -.22644800E-01, -.27027300E-01, 0.57564600E-01, 0.30596400E-01, -.37147800E-01, 0.93486600E-01, -.18050600E-01, 0.11481400E-01, -.29301300E-02, -.12215700E+00, -.60443600E-02, -.12937500E+00, -.12289500E-01, -.51695300E-01, 0.54527100E-01, 0.23638500E+00, -.97384000E-01, -.57861900E-02, 0.76260700E+02, -.34025200E+02, -.23200500E+02, -.37901600E+02, -.30952300E+01, -.54767500E+01, -.16785400E+02, 0.94927400E+01, -.11908600E+02, -.57431100E+01, -.40410900E+02, 0.10545400E+02, -.55905600E+01, -.13550700E+02, 0.14180100E+02, -.24240400E+01, -.69464200E+01, 0.20217100E+01, 0.16838500E+02, -.21700100E+01, -.74373700E+01, 0.29901400E+02, 0.20250100E+02, -.11917900E+02, -.25709600E+02, -.10316400E+02, 0.95327900E+00, -.39822500E+01, 0.93292100E+00, 0.16429900E+02, 0.27495200E+01, -.75323300E+01, -.20600300E+02, 0.14310700E+02, -.96441400E+01, -.26319400E+02, -.70924800E+01, -.10358000E+01, -.26381800E+01, -.11093100E+02, 0.59104600E+01, 0.33448700E+01, -.28273300E+01, -.24862700E+01, 0.44568500E+02, -.28196900E+02, -.28719900E+02, -.22202200E+02, -.28170400E+02, 0.10013600E+01, -.15947700E+02, -.31377000E+02, -.35774000E+02, 0.82971300E+01, 0.11160600E+02, 0.49680100E+01, 0.23722700E+00, -.36581700E+01, -.35977100E+01, 0.11644100E+01, -.54130500E+00, 0.29187400E+01, -.14165800E+01, 0.11794500E+01, 0.27594000E+00, -.55515200E+00, 0.14592400E+01, 0.14951300E+01, -.11665800E+01, -.10270800E+01, -.30125300E+01, 0.36090300E+01, 0.60853600E+00, -.36549400E+01, -.38370000E+00, -.56630200E+00, 0.43232200E+01, -.16514600E+02, 0.84739700E-01, 0.19614000E+01, -.20728500E+01 },
        { 0.53034000E+01, -.14313700E+01, -.18756800E+01, 0.34465400E+00, -.17566400E+01, 0.34179200E+00, -.45020500E+00, -.75985900E-01, 0.68359500E+00, -.51105100E+00, -.10698300E+00, 0.69633200E-01, -.11215200E+01, 0.19990700E+00, -.20266800E+00, 0.98250600E+00, -.45331700E+01, 0.74519700E+00, -.23857900E+01, -.14154800E+01, 0.12569700E+01, 0.10685400E+01, 0.24590300E+00, 0.20023000E+01, 0.40212500E+00, 0.22347300E-01, -.10882500E+00, 0.32524500E+01, 0.71111800E+00, 0.68793200E-01, -.94002600E+00, -.22203000E+00, 0.10148800E+01, -.34934000E+01, 0.37992100E-01, -.18494800E+00, -.10017000E+00, -.13739300E+01, -.55503100E+00, -.47079300E+00, 0.24804800E+01, -.60691500E-01, 0.95887300E-02, 0.32963300E+00, 0.15403100E+00, -.14361300E+00, 0.15991300E-01, -.14964000E-01, 0.15208600E+01, 0.20501900E-01, 0.11403400E+00, 0.90648400E+00, 0.54719800E-01, -.48281600E+00, 0.78251500E-01, -.71605100E+00, -.24181600E+00, -.53502400E-01, -.20050500E-01, -.50817700E+00, -.19543000E+00, -.16032800E+00, -.19082100E+00, 0.10989700E+00, -.24356900E+00, 0.93799500E-01, 0.46971700E+00, 0.55898800E-01, 0.23747600E+00, 0.72797100E-02, 0.44932100E-01, -.99103400E+00, -.57476000E+00, 0.12280500E+01, 0.17704500E+00, -.69643100E+00, -.80977100E-01, 0.53320000E+00, -.88829100E+00, -.91901400E-01, -.80213100E-02, 0.25608400E+00, -.50972400E-01, -.31030600E+00, -.29682000E-01, -.38372100E-01, 0.89583700E-01, 0.15799500E+00, 0.41184500E+00, 0.15015900E+00, 0.37479300E+00, 0.45442800E-02, -.48124500E+00, -.23656400E+00, -.21924000E+01, -.13905800E+01, 0.60258300E-01, 0.65048700E+00, -.21273200E+00, -.61987600E+00, 0.29048300E+00, 0.31953900E-01, -.37855200E-01, 0.31040900E+00, -.18878500E-01, 0.68480100E+01, 0.11152200E+00, 0.41752900E+00, 0.34813000E-01, -.11870100E+01, 0.46202100E+00, -.78143400E-01, -.94810200E+00, -.50200400E-01, 0.59353900E-01, 0.22300800E-01, -.70466600E-02, 0.12205700E+00, -.14592700E-01, 0.34584100E+00, -.42449000E+00, -.34848600E-01, 0.59124400E+00, -.67751700E-01, -.18766700E-01, -.17120700E+00, 0.71843500E-01, 0.40471800E+00, -.14072500E+00, -.15291900E+00, 0.26521100E+00, -.13228500E+00, -.55036500E+00, 0.11039900E+00, -.18713700E+00, -.16566500E-01, 0.63934200E+00, 0.58491200E+00, -.18848400E+00, -.49736100E+00, -.14396800E+00, -.30972600E+00, -.22910300E+00, 0.66191800E-01, -.53595800E-02, 0.10157500E+00, -.21201100E-01, 0.11803800E+00, -.50750200E-01, 0.10284100E+00, 0.17401300E+00, -.11904400E+00, -.19391900E+00, 0.28420900E+00, -.16764600E-01, -.13118800E+01, -.23183700E+00, -.37137100E-03, 0.10517400E+01, 0.36033600E+00, -.76447500E-01, 0.62830000E-01, -.15286400E+00, -.10825600E+00, 0.17693400E+00, 0.24259900E+00, -.42837600E-01, -.27681600E+00, 0.14107700E-01, -.70862600E-01, -.88265800E-01, 0.11044100E+00, 0.93455400E-02, -.65435500E-02, 0.11927600E-01, 0.85856000E-01, -.17471500E+00, -.18590900E-01, -.24086800E+00, -.70512100E-01, 0.60319700E-02, -.20017900E+00, -.51653100E+00, 0.30012000E+00, 0.11532900E+00, -.21799500E+00, 0.96108400E-01, -.26109400E+00, -.18904200E-01, 0.22147400E+00, -.73293400E-02, 0.10647200E+00, 0.23137900E+00, -.55489500E-01, -.51973300E+00, -.62273700E-01, -.63925800E-01, 0.12701000E+00, -.65318100E+00, -.77131700E-02, -.23672000E+00, -.67319800E-02, 0.62778400E+00, -.50606600E+00, -.29598000E+00, -.12221100E+00, 0.13643400E+00, 0.94121600E-01, 0.13712100E-01, 0.54969300E-01, 0.36953600E-01, -.30739800E+00, -.54221400E-01, -.24093200E+00, 0.15755500E+00, 0.22753700E+00, -.12252600E+00, -.17204800E+00, -.53763600E-01, 0.13031100E+00, -.75930000E+00, 0.90085800E+02, -.80127100E+02, 0.12071300E+01, 0.18560500E+02, -.12639500E+02, 0.38450800E+01, -.20563400E+00, 0.60207800E+01, -.70593400E+01, -.31131800E+02, -.10932200E+03, 0.54861500E+02, 0.14871800E+03, 0.69434000E+02, 0.16293000E+02, 0.15027900E+02, 0.41404500E+00, -.33740600E+02, 0.17212100E+02, 0.34930500E+01, 0.65803900E+02, -.78426800E+02, 0.15715600E+02, -.22582700E+02, 0.38882000E+02, 0.19306600E+02, -.47264000E+01, 0.15722800E+02, -.21367100E+02, 0.35800000E+02, -.11908100E+02, 0.91372300E+01, -.18031900E+01, -.49328700E+01, -.45049200E+01, 0.83817200E+00, 0.13174500E+02, -.21312300E+01, 0.10768300E+02, 0.16653800E+02, 0.16776000E+02, -.31259900E+00, 0.66044500E+01, 0.50170700E+02, -.44120500E+02, -.81251000E+02, -.25373900E+02, -.31964400E+02, -.23467700E+02, 0.40368000E+01, 0.11066000E+02, -.30724700E+02, -.11341100E+02, 0.36598000E+02, 0.58827600E+01, -.48848100E+01, 0.38283700E+01, 0.39052600E+01, 0.94979300E+00, -.11652000E+01, 0.66118400E+01, 0.49363900E+01, 0.31507400E+01, -.27148000E+01, -.42243900E+01, -.59199200E+00, 0.35061300E+01, -.25521400E+00, 0.45250800E+01, 0.63583300E+00, -.34241000E+01, 0.38208300E+01, 0.40482700E+01, -.12324500E+01, 0.33287500E+01, 0.67637500E+00, 0.36191100E+01, 0.56085400E+01, 0.27503000E+01, -.35333000E+01 },
        { 0.14242900E+02, 0.18368200E+01, -.22881500E+01, -.24240600E+01, -.61858000E+01, -.39198300E+01, -.19234100E+01, -.88263000E+01, 0.19563500E+01, -.97997300E+00, -.30120100E+01, -.19382000E+01, -.31915400E+01, 0.55508400E+00, 0.25409900E+01, -.50571900E+01, -.17873100E+01, -.25255400E+01, -.13621200E+01, 0.14445400E+00, 0.74513200E+00, -.15228700E+01, 0.54221500E+00, 0.30982800E-01, 0.58766500E+00, 0.47916500E-01, -.24669700E+01, 0.23480600E+01, 0.10063400E+02, 0.10216800E+00, 0.13170700E+01, -.24282100E+01, -.14923700E+01, -.34204900E+01, -.10746800E+00, 0.30299900E+00, -.27226900E+00, -.19539300E+01, 0.20044900E+00, 0.20116200E+01, -.98392800E+01, -.23292800E+01, -.19010700E+00, -.67801700E-01, 0.83593400E+00, 0.70867900E+00, -.18144100E+00, -.84525800E-01, 0.46884500E+01, 0.63378700E-01, 0.82802000E+00, -.27630800E+01, 0.34841600E+00, -.89115800E+01, -.38635800E+00, -.43415300E+01, -.27888600E+01, 0.15162700E+00, -.10337100E-01, -.21964200E+01, -.19624900E+00, 0.23725000E+01, -.18868800E+01, 0.99523000E+00, -.17621400E+00, 0.22978200E+01, -.77081400E+00, -.61685300E+00, -.41024000E+01, 0.36171800E-01, 0.39606100E+00, -.17598300E+02, -.27250100E+01, -.24417700E+01, 0.39553600E+01, 0.66232300E+00, 0.36159500E+00, 0.27970700E+01, 0.23278100E+01, -.13009100E+00, -.20784500E+00, -.34908100E-01, 0.19770300E+01, 0.11938600E+01, 0.31680600E+00, -.58014900E+00, 0.10459600E+01, -.26981100E+00, 0.58176100E+00, -.13557300E+00, 0.23172600E+01, -.12268900E-01, -.10102700E+01, -.13261500E+00, -.22077200E+01, -.32052000E+01, -.29039300E+00, 0.11032500E+01, -.18639000E+00, -.85953700E+00, -.10710000E+00, -.56158700E-02, -.80316000E-01, 0.56989200E+00, -.14856000E+00, -.11242000E+02, 0.93266700E+00, -.63982600E+00, -.47116600E-01, -.58295900E+00, 0.13848300E+01, 0.45527000E-01, -.21621500E+01, -.36048900E-01, -.77035300E+00, -.10786400E+01, 0.12845500E+01, 0.40687000E+00, -.24046500E+01, 0.41867600E+01, 0.10131900E+00, 0.11552800E+00, 0.10080400E+01, -.62461800E+00, 0.20853100E+00, -.86830900E+00, -.89304400E+00, -.26661900E+01, -.29585600E+00, -.48548200E-01, 0.47106700E+00, -.24527000E+00, 0.15019700E+01, -.24564300E+01, 0.69237800E+00, 0.52925400E-01, 0.13289500E+01, -.23377500E+01, 0.85138100E+00, -.30642700E+00, -.21888500E+01, 0.81661200E+00, -.78639900E+00, 0.21573300E+01, 0.55735000E-01, 0.94310900E+00, 0.10402800E+00, -.16299000E+01, 0.13121200E-01, -.14813600E+01, -.64800200E+01, -.34499600E+00, -.75968100E+00, 0.28959100E+01, -.22199300E+00, -.28221100E+00, 0.44670100E+00, 0.41301600E-02, -.12857700E+01, 0.32375900E+00, -.67763300E+00, -.11049100E+01, 0.31951700E-01, -.27247300E+00, 0.27859000E+00, 0.43892200E+00, 0.14794000E+00, 0.58754200E+01, -.60484000E-01, 0.12669200E+01, -.46522500E-01, -.16043300E+00, 0.78838900E+00, -.10112600E+01, -.20690600E+01, 0.44002500E+00, 0.36801700E+00, -.11094600E+00, 0.11328700E+01, -.82293400E-01, 0.36673000E+00, -.10228500E+00, 0.19729700E+01, 0.71246300E+00, -.88842600E+00, -.48325400E+00, -.11343500E+01, 0.11924700E+01, 0.67050100E-01, -.26644000E+01, 0.15218400E+01, 0.74748200E+00, -.55408800E-01, 0.89804400E+00, -.91247200E+01, 0.54945500E+00, -.43750600E+01, 0.33057800E+00, -.17066100E+01, -.10917900E+00, -.13032100E+01, -.24124500E+00, 0.50102000E+01, -.39429600E+01, -.11893700E+01, -.73491000E+00, 0.55680300E+00, -.11971800E+00, 0.12981100E+01, 0.24986100E-01, 0.32977100E-01, -.18011800E+01, -.54236400E-01, -.10610100E+01, -.11449300E+01, 0.27186400E+01, 0.17315500E+01, -.13355000E+01, 0.36274400E+00, 0.19397000E+01, 0.23052800E+01, 0.65261800E+00, -.67119400E+03, 0.19854700E+00, 0.12757300E+03, -.16416300E+03, 0.11701500E+03, -.13682900E+02, -.32376700E+02, -.93490400E+02, -.18414200E+03, -.70502500E+03, 0.34809100E+03, 0.10768800E+04, 0.29796400E+03, 0.21297100E+03, 0.14902100E+03, -.16272900E+02, -.40277400E+03, -.11649000E+02, 0.71950400E+02, 0.16587300E+03, -.58691200E+03, 0.26833800E+03, -.15487400E+02, 0.29632600E+03, 0.15810900E+03, 0.13125900E+02, 0.90323600E+02, -.18953300E+03, 0.24004300E+03, -.12487000E+02, -.13439900E+03, -.15169400E+02, -.24503600E+02, 0.12316400E+03, 0.64304100E+01, 0.10924600E+03, -.76053000E+01, 0.87178500E+02, 0.10949000E+03, 0.13459400E+03, 0.62092300E+01, 0.88330500E+02, 0.14881300E+03, -.12600100E+03, 0.16179500E+03, -.68293500E+02, -.22197200E+03, -.46509300E+02, -.43839500E+02, 0.14789900E+03, -.12076800E+03, -.29366500E+01, 0.30793300E+03, 0.24263000E+02, -.17527000E+02, 0.18074100E+02, 0.15636600E+02, 0.16565200E+02, -.17578000E+02, 0.71397200E+01, 0.25697800E+02, 0.60863500E+01, 0.44613500E+01, -.18837200E+01, -.90333400E+01, 0.85943400E+01, -.14427200E+02, 0.20807100E+02, 0.36622100E+01, -.17358300E+02, 0.16545100E+02, 0.15923600E+02, -.21179300E+02, 0.28961200E+02, 0.15899800E+02, 0.23684300E+03, 0.22479700E+02, 0.27892100E+01, -.15606800E+02 },
        { 0.53570400E+01, 0.65157800E+00, -.20197900E+01, -.14058900E+01, -.27701000E+01, -.11818100E+01, -.19955600E+01, -.21943900E+00, 0.20405100E+00, -.40786800E+00, -.29797300E+00, -.94533500E-01, -.25272500E+00, 0.15002000E+00, -.18685200E+00, -.24224400E+01, -.68698600E+00, 0.12105800E+01, -.20666600E+01, -.13568100E+01, 0.17771100E+00, 0.43938700E+00, -.12463300E+00, 0.76904600E-01, -.92862800E-01, 0.16434600E+00, 0.36649500E+00, 0.13622300E+01, -.12408200E+01, 0.96858100E-01, -.37759100E+00, 0.12053200E+00, 0.51324500E+00, -.17714900E+01, 0.43457900E-01, -.11456000E+00, -.50782400E-01, -.60991400E+00, -.75565100E-01, -.40281200E+00, 0.12075900E+01, -.16508300E+00, 0.41739000E-01, 0.25760800E-01, 0.25595600E+00, -.32432000E-01, 0.24925300E-02, -.72919700E-02, 0.17255300E+00, -.32430700E-01, 0.65548200E+00, 0.72323500E+00, -.21313000E+00, 0.36409500E+00, 0.21301700E+00, -.91897900E+00, -.16506500E+00, 0.50666100E-01, -.50304500E-01, 0.10277200E-03, -.66667800E-01, -.30361300E-02, -.28257500E+00, 0.53347400E-01, -.48650900E+00, 0.98075700E-01, 0.75298600E+00, 0.13420800E+00, 0.34016500E+00, 0.79040100E-02, -.59494700E-01, -.40257400E-01, -.31876600E+00, 0.56870300E+00, 0.46984500E-01, -.82838300E+00, 0.10863200E+00, 0.16230500E+00, -.24976600E+00, -.60245500E-01, -.79888600E-01, 0.77108300E-01, -.22114800E-01, 0.20409700E+00, 0.24793800E-01, -.18743300E+00, -.22953400E+00, 0.35409300E-01, 0.28407700E+00, -.26677500E-01, 0.19597000E-01, -.62864800E-02, 0.12512900E-01, 0.64609000E-01, 0.14630400E+00, 0.12217400E+00, -.10437300E+00, 0.12908200E-02, 0.17904800E+00, 0.12404300E+00, -.38113800E-01, -.42790900E-01, -.37258800E-01, -.49706100E-01, -.89710000E-01, 0.22518300E+01, 0.32838800E-01, -.18603200E+00, 0.47560200E-01, -.14354500E+00, 0.18675400E+00, -.14637600E-01, 0.10264700E+01, -.47922400E-01, 0.92797900E-01, 0.17053500E+00, -.54991200E-02, -.23068800E-01, -.79917300E+00, 0.70372000E+00, -.77310700E+00, -.28369000E-01, 0.52086100E-01, -.28499000E+00, -.14115900E-01, -.43172500E+00, -.19773500E-01, 0.65250700E+00, -.41373700E-01, -.77891900E-01, -.12027400E+00, -.16839200E+00, -.28368000E+00, 0.26561900E-01, -.55598900E-01, -.21387700E-01, 0.92377400E+00, 0.41031500E+00, -.89462200E-01, -.12032000E+01, -.18889400E+00, -.40435900E+00, -.11482100E+00, -.13764800E+00, -.10200400E+00, -.29978700E-01, -.47998100E-01, 0.44768100E+00, -.15775000E+00, 0.13030400E+00, -.27143000E+00, 0.63282100E+00, 0.11909400E+00, 0.25238300E+00, -.24545400E+00, -.11727900E+01, -.33788400E-01, -.17018200E-02, 0.69687600E+00, 0.72650500E-01, -.11316600E+00, 0.19092600E+00, -.49897300E+00, 0.13333600E-01, -.49372900E-01, -.98550900E-02, -.10682900E-01, -.87779500E-01, -.31575300E-02, -.39629200E-01, -.12288300E-01, 0.15074400E-01, -.32827800E-01, 0.23884500E-01, 0.27686300E-01, -.25214900E-01, 0.99539200E-02, 0.32723700E-02, -.29457500E-01, 0.54035700E-02, -.50252700E-01, 0.13986800E-01, -.19647300E-01, -.30077900E-01, 0.12420000E-01, -.15071100E-01, 0.18903900E-01, -.31860300E-02, -.14563400E-02, 0.23985100E-01, -.22201300E-01, -.21387500E-01, -.97248200E-02, -.26073400E-01, 0.13400400E+00, -.32253500E-01, 0.88472800E-01, -.42579000E-02, 0.58106800E-01, -.20015900E-02, 0.35286900E-01, 0.32523000E-01, -.11046400E+00, 0.93069300E-01, 0.20286000E-01, 0.29236000E-01, -.66957000E-02, -.43608700E-01, -.15950900E-01, 0.34386800E-02, 0.35741200E-02, 0.19779800E-01, -.83477800E-03, -.69778000E-01, -.51595700E-01, -.72089900E-01, -.97966200E-01, 0.51638600E-01, 0.13670000E-01, -.37946400E-01, -.16604200E-01, 0.13542400E-01, -.99583100E-02, 0.21024000E+02, -.54766400E-01, 0.96407900E+00, 0.48120000E+00, 0.54355300E+00, 0.10663800E+01, 0.77831200E+00, 0.26208100E+01, 0.84259100E+01, -.41711700E+01, -.15017000E+02, -.46279900E+01, -.12050000E+01, -.86757400E+00, -.40080000E+00, 0.30943000E+01, -.89884800E+00, -.51600200E+00, -.45862900E+01, 0.66228300E+01, -.30789200E+01, 0.14874400E+01, -.35219300E+01, -.25672300E+01, -.16422100E+01, 0.57044900E+00, 0.25752300E+01, -.28057000E+01, -.58460800E+00, 0.16216800E+01, 0.35813200E+00, -.68159700E-01, -.23383500E+01, -.25841800E+00, -.14262800E+01, -.40521500E+00, -.59201000E+00, -.60205500E+00, -.37942900E+00, -.10740200E+01, -.31393500E-02, -.36376200E+01, 0.20090800E+01, 0.11085800E+02, 0.16672900E+01, 0.12757400E+01, 0.13474500E+00, 0.93891300E+00, 0.11175600E+01, 0.40050100E+01, -.15456100E+01, -.11459600E+01, -.34367500E+00, 0.16755700E+00, 0.59149700E+00, 0.58864200E+00, 0.84670900E-04, 0.58841100E-01, -.42520500E+00, -.43239600E+00, -.85441300E-01, 0.34377500E-01, 0.13782600E+00, 0.28154800E+00, -.17063700E+00, -.59065100E-01, -.38723200E+00, -.33669000E+00, -.58548000E+00, 0.57405700E-02, 0.57261200E+00, 0.52580600E-01, -.12998600E+00, 0.17154800E+00, 0.30348800E+00, -.41621000E+00, -.11502900E-01, 0.25483900E+00 },
        { -.39839000E+01, -.12092300E+01, 0.11193300E+01, 0.20529100E+01, 0.24354800E+01, 0.11853000E+01, 0.17392500E+01, -.14574500E+01, -.93736200E-01, -.10609700E+01, 0.34533300E+00, 0.32067700E+00, 0.54770200E+00, 0.35638300E-01, -.54518800E+00, 0.19169300E+02, 0.25796200E+01, 0.22280900E+01, 0.23846400E+01, 0.26402700E+00, -.24038000E+01, -.18608500E+00, -.29964700E-01, 0.12302900E+01, -.29047700E+00, -.11682900E+00, -.54174800E+00, 0.13044000E+01, 0.10149300E+01, 0.64935200E-01, -.69224800E+00, -.21193200E+00, -.15371800E+00, 0.19923900E+01, 0.12302200E-02, -.71194700E-01, 0.22034300E-01, 0.11171600E+00, -.16052700E+00, 0.32851700E+00, 0.76867800E+00, -.14826200E+00, -.86549500E-01, 0.16759600E+00, 0.17717000E+00, -.23302900E+00, 0.68235000E-01, 0.38887300E-01, 0.66380700E+00, -.65531900E-01, -.72209100E-01, -.18945800E+00, 0.48988700E+00, -.57079500E+00, -.24470700E+00, 0.11916100E+01, 0.55740900E+00, -.96917100E-01, 0.73195600E-01, 0.55137500E+00, -.69018400E-01, 0.10000400E+01, 0.53174400E+00, -.35720800E+00, 0.41697400E+00, -.77433500E+00, -.17761600E+01, -.41112100E-01, 0.29829700E+00, -.30304300E-02, 0.45985200E-01, 0.13616800E+01, 0.20127600E+01, 0.28175200E+01, -.82819600E+00, 0.13818200E+01, -.40446200E+00, 0.11722500E+01, -.34254400E+00, 0.68034600E-02, 0.10427200E+00, -.10085100E+00, -.23713800E+00, -.38673700E+00, 0.17692200E+00, 0.13637500E+00, 0.45685400E+00, 0.31865500E+00, 0.52126500E+00, 0.18751200E-01, -.22666200E+00, 0.33098800E-02, 0.18760400E+00, 0.49135800E-01, 0.66368300E+00, 0.17524500E+01, 0.26259900E+00, 0.99535400E-01, 0.41317500E-01, 0.31737500E+00, 0.13143800E+00, 0.88652600E-01, 0.16476500E-01, -.33222400E+00, 0.23648800E+00, -.13198900E+01, -.65321800E+00, 0.19630800E+00, -.25187500E-02, -.13305200E+00, 0.37857000E-01, 0.17579600E-01, 0.44645600E+00, 0.68257400E-02, -.84448800E-01, -.11341700E+00, -.12389900E-01, -.69749500E-01, 0.12127400E+00, -.10519500E+01, -.82246500E-01, 0.17921100E-01, -.89555300E-01, -.19030700E-01, 0.19926100E-01, -.98600200E-01, -.16486500E+00, 0.76679600E-01, -.20208300E-01, -.35795800E-01, 0.12946100E+00, -.36256400E+00, -.43789200E+00, 0.42968200E+00, -.15297200E+00, -.15890800E-01, 0.75520800E+00, 0.11040300E+00, -.91179100E-01, 0.14354500E+00, -.70333500E-01, 0.10785200E+00, 0.11178700E+00, 0.21876800E+00, 0.41555100E-01, -.17744300E+00, 0.19051500E-01, -.53169900E-01, -.12293600E+00, -.76321100E-01, -.28498000E+01, 0.11243400E+00, -.16845100E-01, 0.21256600E+00, -.12416000E-01, -.53945300E+00, -.12572100E+00, 0.71078300E-03, 0.14652100E+01, 0.28273900E+00, 0.31874400E-01, 0.17724400E+00, -.13727100E-01, 0.10824100E+00, -.15124800E+00, 0.27975300E+00, -.45677300E-01, -.10145500E+01, 0.87745600E-02, -.54374600E-01, -.15050300E+00, 0.12479600E+00, -.53306100E-01, -.55168500E-01, 0.25033300E-02, -.12783000E-01, -.27050400E-02, 0.85938500E-02, -.91526800E-01, -.82382100E-02, 0.66171500E-01, 0.49648700E-02, -.72128800E+00, -.45933800E-01, 0.20685200E+00, -.29404600E+00, -.67057300E-01, -.12282100E+00, 0.33013900E-01, -.92148200E-01, 0.23263500E+00, 0.17764400E+00, 0.23755800E+00, 0.21369600E-02, -.11204200E+01, -.69199200E-02, -.84570200E-01, -.33655800E-01, -.19455700E+00, 0.26444900E-02, -.25299000E+00, -.68538800E-01, 0.43853700E+00, -.10402500E+01, -.60834600E+00, -.14454200E+00, 0.11549300E+00, 0.41093100E+00, -.26981000E+00, -.35928400E-01, 0.15616500E-01, 0.39083400E-01, 0.79138300E-02, -.35657800E-01, 0.26194100E-01, -.36549700E-01, 0.18666000E+00, 0.48373500E+00, -.45639700E-01, 0.19857900E+00, -.20754700E+00, 0.17873400E-01, -.94628000E-01, 0.20410900E-01, 0.30917000E+02, -.32811500E+02, 0.28902100E+02, 0.11992400E+02, -.20989900E+01, -.16216600E+02, -.62500800E+02, -.94859400E+02, 0.46946900E+02, 0.12853700E+03, 0.46058400E+02, 0.27199900E+02, 0.24490900E+02, -.83770000E+01, -.49535700E+02, 0.27416000E+00, 0.81827200E+01, -.75066100E+01, -.97799700E+02, 0.46458500E+02, -.49992600E+01, 0.48927800E+02, 0.43939800E+02, 0.15389800E+01, 0.20969500E+02, -.20153500E+02, 0.34010800E+02, 0.33575800E+01, -.61390500E+02, 0.15960900E+02, -.13192400E+02, 0.64008900E+02, -.80013400E+01, 0.13884200E+02, -.39420800E+01, 0.24498300E+01, 0.27675100E+02, 0.23346300E+02, -.83559700E+01, -.61986000E+01, 0.13064800E+01, -.51090800E+01, -.19098100E+02, 0.26689500E+00, -.19952800E+02, -.13436500E+02, 0.10142200E+02, 0.21128500E+02, -.17093900E+02, -.96785500E+01, -.53966400E+02, -.23374600E+01, -.58585500E+01, 0.91315900E+01, 0.92966000E+01, 0.37383800E+01, -.36493200E+01, -.11316000E+01, 0.78797900E+01, 0.21748800E+01, -.26028100E+01, -.35364000E+01, -.66115400E+00, 0.69043000E+00, -.34320700E+01, 0.71897800E+01, 0.60703500E+01, -.90205500E+01, -.47950400E+00, 0.91732500E+01, -.36756200E+01, 0.48406500E+01, -.52849000E+00, 0.43173700E+02, 0.77429400E+01, 0.28721800E+00, 0.22274700E+01 },
        { -.38309600E+01, 0.44620900E+00, 0.24040100E+01, 0.18427000E+00, 0.17127100E+01, 0.98946100E+00, 0.12494100E+01, -.23596700E+01, -.13266400E-01, -.10286700E+01, -.13757200E+00, 0.44811200E+00, -.11226500E-01, -.28333000E+00, 0.43680000E+00, -.43533100E+01, -.58926900E+01, -.16428000E+01, 0.13894000E+01, 0.95397900E-01, -.12501100E+01, -.36823100E+00, 0.85154000E-01, -.98858800E+00, -.66519400E-01, -.14741600E+00, -.66416200E+00, -.15807400E+01, 0.19882600E+01, -.18381000E+00, -.79307800E-01, 0.47545400E+00, -.68479000E+00, -.48650100E+01, -.46373300E-01, -.14149200E+00, 0.93140800E-01, 0.70117700E+00, 0.13454200E+00, 0.59377400E+00, -.90816700E+00, -.10152400E+01, 0.37878100E-01, -.45264100E+00, 0.26649000E+00, 0.23338100E+00, -.66362500E-01, 0.48832100E-01, -.12858000E+01, 0.81364100E-01, -.26014300E+00, 0.49177500E-03, -.87888600E+00, -.72716900E+00, -.23474800E+00, -.15681500E+01, -.81546500E+00, -.16163700E+00, 0.55551400E-02, 0.88821200E-01, -.21274500E-01, 0.35848900E+00, -.28152600E+00, -.22011800E+00, -.18207500E-01, 0.34339900E+00, 0.72205400E+00, 0.18521500E+00, 0.25417100E+00, -.73787900E-03, -.71828300E-01, -.67695400E+00, 0.13612400E+00, -.62057400E+00, 0.23962000E-01, 0.43329500E+00, 0.30270600E-01, -.62793300E+00, 0.15810700E+00, -.47201600E-01, -.39811300E-01, -.26080900E-01, -.16968400E+00, -.50480000E+00, -.12626800E+00, 0.76941100E-01, 0.32339000E+00, 0.12197800E-01, 0.10771800E+01, -.12269900E-01, 0.37273200E+00, 0.38717100E-02, 0.37722900E+00, 0.18199000E+00, -.86498600E+00, 0.29029400E+00, -.49516300E+00, -.38855900E+00, 0.19464700E+00, -.28919400E+00, 0.79527200E-01, -.17549300E+00, -.12931300E-01, 0.11127900E+00, -.25490600E+00, 0.81299300E+00, 0.44646600E+00, -.39207500E+00, -.10300500E+00, 0.22308800E+00, 0.18805400E+00, -.46315400E-02, 0.16287600E+01, -.34172900E-01, 0.27821900E-02, 0.17526200E+00, 0.46288000E-01, -.25913100E+00, -.13659300E+01, 0.11339100E+01, -.86249600E+00, 0.59193200E-01, 0.17938700E+00, -.29962700E+00, 0.84260700E-01, -.44905800E+00, -.13846000E+00, -.38620300E+00, -.39281900E+00, 0.13499100E+00, -.76941600E+00, -.66741800E-01, 0.50796300E+00, -.32494500E+00, 0.23113800E-01, -.93142600E-02, 0.48256100E+00, -.21131400E+00, 0.11375900E+00, -.29506800E-01, -.13664100E+00, -.26764100E+00, 0.23588900E+00, -.44184600E+00, -.42140000E-01, -.44230100E+00, -.71074700E-01, 0.43566000E+00, -.11150600E+00, 0.12659100E-01, 0.56299200E+00, 0.16423900E+00, 0.26733500E+00, 0.52797500E+00, -.20539600E-01, -.45095800E+00, 0.25478700E+00, 0.35288500E-02, 0.15929800E+00, -.23003700E+00, -.10069200E+00, -.64291600E-01, 0.74498200E-01, 0.28695400E+00, 0.27630600E+00, 0.30888600E+00, -.81681600E-02, -.19053700E+00, 0.36469400E-02, -.25604400E+00, 0.63883100E-01, 0.67338100E-02, 0.49502200E-01, -.35837300E-01, 0.58342500E-01, 0.32488000E-01, 0.32962500E+00, 0.72978900E-02, 0.66888100E-01, -.92658100E-01, -.37342100E+00, -.18859900E+00, 0.28574900E+00, 0.26378400E+00, -.58149600E-01, -.40433200E+00, 0.74324500E-01, 0.68442200E-01, -.43447200E-01, -.42800400E-01, -.18940100E+00, 0.15640700E+00, -.35133900E+00, -.16580500E+00, -.46890500E+00, -.34101600E+00, 0.74273600E-01, -.31087700E-01, 0.14495900E+00, -.28149200E-01, 0.20221900E+00, 0.12238400E+00, -.36511300E+00, 0.60853500E+00, 0.44334300E-02, -.84992000E-01, 0.12974700E+00, -.70192900E+00, 0.20493400E+00, -.44617300E-01, 0.78539900E-02, 0.59123700E+00, 0.37943200E-01, 0.58222600E+00, -.18314000E+00, 0.29125200E+00, 0.16900100E+01, -.55254900E+00, -.24005700E+00, 0.21894400E+00, 0.14663600E+01, -.66264400E-01, -.63049700E-01, -.43498900E-01, -.53731700E+00, -.29921400E+02, 0.24629800E+02, -.23246300E+01, -.27187900E+02, -.18551300E+02, -.53480900E+02, -.13088000E+03, 0.65173500E+02, 0.13971700E+03, 0.33649100E+02, 0.33497500E+02, 0.33767300E+02, -.15011700E+02, -.94773300E+02, 0.10110900E+02, 0.23139400E+02, 0.12852800E+02, -.85846300E+02, 0.40794200E+02, 0.25130800E+02, 0.44988400E+02, 0.31347200E+02, 0.16752600E+02, 0.53940400E+00, -.59046800E+02, 0.17728800E+02, 0.16778400E+02, -.82924200E+02, -.46283700E+02, 0.20167000E+02, 0.10939900E+03, 0.23012700E+02, 0.20480100E+02, 0.76891100E+01, 0.22765300E+02, 0.14521500E+02, 0.26899500E+02, 0.97781700E+01, -.81878700E+00, -.62176800E+02, 0.33043100E+02, 0.74933100E+02, 0.30968700E+02, 0.24680100E+02, -.82164500E+01, 0.16637200E+02, 0.10131800E+03, 0.43710200E+02, -.13119800E+02, 0.10720300E+03, -.58549500E+01, -.47676000E+01, 0.66942300E+01, 0.74014800E+01, 0.70447700E+00, -.24576900E+01, -.20967800E+01, 0.73758400E+01, 0.10266700E+01, -.12696500E+01, -.87434500E+00, -.21118900E+01, -.13836000E+01, -.42101600E+00, 0.65108400E+01, 0.71612000E+01, -.74933700E+01, 0.14263900E+00, 0.67714600E+01, -.27724400E+01, 0.49504400E+01, -.48112700E+01, 0.61370600E+02, 0.66847900E+01, -.23403800E+01, -.28458500E+00 },
        { 0.33009600E+01, 0.11512400E+00, 0.22431500E+00, -.61205100E+00, -.24264300E+01, -.17871000E-01, 0.18774000E-01, 0.25214600E+00, 0.33075900E+00, 0.19315700E+01, -.78960500E+00, -.66733000E+00, -.11780900E+01, 0.44417600E-01, -.97275800E-01, 0.69334600E+00, -.18499700E+01, -.80249100E+00, -.17003300E+01, 0.70384900E+00, 0.27372100E+01, -.85113400E-01, 0.94246900E-01, -.63491500E+00, 0.14303300E+00, 0.13075500E+00, 0.46606700E+00, 0.70827500E+00, -.31682700E+00, -.18084600E-01, -.21952000E+00, -.46398700E+00, 0.42718900E+00, -.78317000E+00, -.57190200E-02, 0.31221300E-01, -.89332000E-01, -.14787700E+00, 0.39197900E-01, 0.20052800E+00, 0.22732100E+01, -.12303500E+00, -.12964300E+00, -.30096400E+00, -.63232200E+00, -.14072500E+00, -.21852300E-01, -.13770700E+00, 0.55686400E+00, 0.84286300E-01, -.10805800E+01, 0.86523700E-01, -.78787300E+00, 0.15539200E+01, -.17854800E-01, -.11516600E+00, 0.83771300E-01, -.68308000E-01, -.13416800E+00, 0.20005900E+00, 0.96423400E-01, -.16819900E+01, 0.77522800E-01, 0.37763900E+00, 0.64002900E+00, 0.27537100E+00, 0.24641500E+00, 0.10854200E+00, -.87577400E-01, 0.65149400E-02, -.10086500E-01, -.17603300E+01, 0.18094100E+00, -.49759200E+00, 0.17210000E+00, -.24009400E+00, 0.11853000E+00, -.46240500E-01, 0.32864700E+00, -.66465100E-01, -.74679800E-01, -.33609200E-01, 0.58242400E-01, 0.86948400E-01, -.47585500E-01, 0.28174200E+00, -.89123800E-01, -.26159000E+00, -.53018600E+00, 0.38612600E-01, 0.27771800E+00, -.11769200E-02, 0.81998000E-01, 0.43361400E-01, -.48598400E+00, -.19254800E+01, 0.32982800E+00, 0.22864700E+00, -.31143800E+00, -.45552800E+00, 0.27155800E-01, -.67987000E-01, -.42616800E-02, 0.85009400E+00, -.14935600E+00, -.76642400E-01, -.39430900E-01, -.33909800E+00, 0.18584400E+00, 0.16132200E+00, 0.22093500E-02, 0.25357600E-01, -.24331700E+00, 0.51651700E-02, -.18385800E+00, -.36666600E+00, -.21031100E+00, 0.47924600E+00, -.80305800E+00, 0.41327100E+00, -.64901400E+00, 0.63186800E-01, 0.56114200E-01, 0.26682900E+00, 0.19729900E-01, 0.38449800E+00, 0.23335100E+00, -.66287800E+00, 0.53083700E+00, -.25017400E-02, 0.19058300E+00, 0.51672200E+00, 0.42912600E+00, -.10474600E+01, 0.22503700E+00, 0.61052600E-01, -.11624300E+01, 0.81441000E-02, 0.12925700E+00, 0.77638600E-01, 0.88503300E+00, 0.17980200E+00, 0.75626600E+00, 0.92774200E-01, -.90910500E-01, -.55020700E+00, -.99392100E-01, -.35727700E-01, -.20637000E-01, 0.77866000E+00, -.21500000E+01, -.57465100E+00, 0.17712500E+00, -.77702400E+00, 0.99973000E-01, -.16572200E+00, -.98726600E-01, 0.98922200E-05, -.81887200E+00, 0.28546300E-01, -.10469400E+00, -.13727900E+00, 0.82230800E-01, -.14806200E+00, -.11583300E+00, -.42723000E+00, 0.10589900E+00, 0.31272300E+00, -.22313500E-01, -.13186600E+00, -.32762100E-01, -.53416200E-01, 0.18306500E-01, 0.28927400E-01, -.61209300E+00, -.11032000E+00, 0.16757800E+00, 0.53167300E-02, -.30083100E+00, 0.13945600E+00, 0.50069000E+00, -.23448200E+00, -.73070700E+00, 0.10612300E+00, 0.22466500E+00, 0.46884200E+00, -.12393700E-01, -.44633500E+00, 0.91329000E-01, 0.20239900E+00, -.96862400E+00, 0.11726900E+00, 0.32667100E+00, 0.23689600E+00, -.12645500E+01, -.19488700E+00, -.46980300E+00, -.12148800E+00, -.10133700E+00, -.13006100E-01, -.21586100E+00, 0.14547200E-01, 0.71429900E+00, -.26899600E+00, -.19742300E-01, -.75878500E-01, 0.18205800E+00, 0.66988300E-01, -.15450000E+00, 0.10977200E+00, 0.18770800E-01, 0.26246500E+00, -.13983300E-01, 0.29147800E+00, 0.36303600E+00, -.24891000E-01, -.41832100E+00, 0.85362800E-01, -.14654200E+00, 0.70079100E-01, -.10041100E+01, 0.29908500E-01, 0.51127500E-02, 0.10853500E-01, 0.36595800E+00, -.18073900E+00, -.17692800E+02, -.19370400E+02, -.11616300E+02, -.16553500E+01, 0.19094100E+02, 0.28219400E+02, -.14824800E+02, 0.15171700E+02, 0.14963800E-01, 0.10371700E+02, -.10547200E+00, -.20814800E+02, -.97007700E+01, -.75263600E+01, 0.76671100E+00, -.17531100E+02, -.50852400E+02, 0.25026300E+02, -.14691700E+02, 0.25718500E+02, 0.30717700E+02, 0.75752800E+01, -.30861200E+01, -.12117700E+02, 0.35107000E+01, 0.54342100E+01, -.45372600E+01, 0.27434600E+02, -.14348300E+02, -.19879200E+02, -.13696000E+02, 0.10838600E+02, -.28961000E+01, -.44669200E+01, 0.24636000E+02, 0.20804700E+02, -.92933100E+00, -.11450300E+02, 0.97964300E+01, -.45013200E+01, -.17990200E+03, -.55373000E+01, -.38922400E+02, -.36984900E+02, 0.29889200E+02, -.21200000E+02, -.35811400E+02, -.83039000E+01, 0.63590300E+02, 0.27405600E+01, -.51197700E+01, -.95989600E+01, -.98894000E+01, -.34360800E+01, 0.21598300E+01, 0.10196500E+02, 0.71678100E+01, 0.34922300E+01, -.33073400E+01, -.54387400E+01, -.32265200E+01, 0.68216900E+01, 0.44492500E+01, 0.70889300E+01, 0.84383500E+01, 0.10108900E+02, 0.70926500E+01, -.94588400E+01, 0.21870700E+01, 0.48725000E+01, -.79342400E+01, 0.11231500E+02, 0.66216800E+01, 0.88392700E+01, -.11313600E+01 },
        { -.14870500E+02, -.43102300E+01, -.57090500E+00, 0.46371400E+01, 0.33475400E+01, 0.45946200E+01, 0.55406300E+01, -.10138700E+02, -.13754800E+01, -.24649100E+01, 0.13426300E+01, 0.23176900E+01, 0.29812000E+01, -.46190600E+00, -.28025600E+01, 0.28685900E+02, 0.55024600E+01, 0.46272700E+01, 0.73624800E+01, -.97060400E+00, -.40871600E+01, -.77137400E+00, 0.97939100E-01, 0.22242300E+01, -.77084500E+00, -.74377900E-01, 0.84929400E+00, 0.23139200E+01, -.24678700E+01, 0.25074900E+00, -.11713500E+01, 0.11350400E+01, 0.61942000E+00, -.21686600E+01, 0.36497800E-01, -.11830800E+00, 0.19913600E+00, 0.16407200E+01, -.23089100E+00, -.18629600E+01, 0.73740800E+01, 0.50307900E+00, 0.25167200E+00, 0.36058700E+00, -.13943700E+01, 0.80847400E-01, 0.18349100E+00, -.48228500E-01, -.10080300E+02, 0.41767400E+00, -.14746700E+01, 0.34456500E+01, -.47143900E+00, 0.61951500E+01, 0.82422700E+00, 0.68938100E+01, 0.32066600E+01, 0.32173900E-01, -.90260700E-01, -.23786300E+00, 0.52444700E+00, -.43589100E-01, 0.12036600E+01, -.19713500E+01, -.18777400E+01, -.17509300E+01, 0.14468200E+01, 0.71441600E+00, 0.44246400E+00, -.34551600E-01, 0.36439200E-02, 0.91544400E+01, 0.74336900E+00, 0.10484600E+01, -.17542700E+01, -.30642000E+01, -.41714700E+00, 0.10661000E+01, -.26768300E+01, -.61695500E+00, 0.13460500E+00, 0.14067100E+00, 0.31621000E+00, 0.28693500E+01, -.24459900E+00, -.14126800E+01, -.11567200E+00, 0.54813200E+00, -.85718900E+00, 0.39238800E+00, -.19354600E+01, 0.21704800E-02, -.85978700E-01, -.19558100E+00, 0.37891100E+01, 0.16018300E+01, 0.12861600E+01, -.81113200E+00, 0.31206800E+00, -.83384000E+00, 0.35825900E+00, 0.78436400E+00, 0.15417400E+00, -.73358700E+00, -.19059200E+00, 0.50976100E+01, -.10591700E+01, 0.56289300E+00, -.16009500E-01, -.46242500E+00, -.37492900E+00, -.47914500E-01, 0.47384900E+00, 0.67760300E-01, 0.45102000E+00, 0.10066200E+01, -.96750200E+00, 0.50009500E+00, 0.58374000E-01, -.16144500E+01, -.20312300E+00, -.47053800E+00, -.29299400E+00, 0.49974200E+00, -.44149200E+00, 0.16085000E+01, 0.12433700E+01, -.50974900E-01, 0.53304400E+00, 0.17777700E+00, 0.14145600E+00, 0.28719500E+00, 0.12234400E+01, -.12645000E+01, 0.46625400E+00, -.57715500E-01, -.66660500E+00, -.24102300E+00, -.85512900E-01, -.26350500E+01, 0.31357900E+00, -.81975600E-01, -.58900900E+00, -.69454100E+00, -.19374000E+00, -.35026100E+00, 0.49891800E-01, 0.50572300E+00, 0.40832600E-01, 0.16665500E+01, 0.30442700E+01, 0.69119900E+00, -.56050100E-01, 0.87119100E+00, -.27145800E-01, -.22023800E+00, 0.26266100E+00, 0.65450900E-02, -.70000800E-01, 0.18742500E+00, 0.12883300E+00, 0.62348700E+00, -.38774400E+00, 0.14813200E+00, -.64310300E+00, -.69373100E+00, -.60013800E-01, 0.19944000E-01, -.28560400E-01, 0.17896300E+01, -.71748900E+00, 0.43759100E+00, 0.67700400E-02, 0.70502900E-01, 0.43934500E+00, -.29852100E+00, -.97740600E+00, 0.13177200E+00, -.22628200E-01, 0.85018400E+00, 0.13652800E+01, 0.20258600E+01, -.43875400E+01, -.33828800E+00, -.29185400E+00, 0.68712700E+00, 0.30618700E+00, -.22041000E+01, 0.25377400E+00, -.83039000E+00, 0.29245500E+01, -.55620100E-01, 0.23753900E+00, 0.76075500E-01, -.18326200E+01, 0.59980200E+00, -.45737200E+00, 0.84140800E+00, 0.24330300E+01, -.80341400E-01, -.66964800E-01, 0.47070900E+00, -.25933000E+01, 0.15501000E+01, 0.12498700E+01, 0.63173000E+00, -.49907600E+00, -.10939900E+00, 0.64157700E+00, -.12103800E-01, 0.63598200E-01, -.22254700E+01, 0.81398600E-01, -.36350500E+01, -.28614600E+01, -.44453500E+00, -.30137200E+01, 0.22683400E+01, -.96182500E+00, 0.10545700E+01, 0.87036500E+01, 0.41561700E+00, 0.20690100E+00, -.95422500E-01, -.27930600E+00, 0.14419700E+01, -.15353800E+00, 0.48673100E+02, 0.13461700E+02, 0.50635300E+01, -.25949700E+02, 0.35952000E+03, -.17956100E+03, -.14540100E+03, -.29646000E+03, -.37574900E+02, -.36370600E+02, -.57618300E+02, 0.46484200E+02, -.83624900E+02, -.37453700E+02, -.23814000E+02, 0.31982100E+01, -.16019100E+02, 0.26592500E+01, 0.74508100E+00, 0.32640700E+01, -.41326900E+02, 0.42537400E+02, 0.56225200E+02, 0.71851100E+00, -.23527500E+02, -.42231000E+02, 0.50227000E+02, -.31501400E+02, -.28804300E+03, -.25610200E+02, 0.18760800E+02, -.46121200E+02, 0.52919400E+02, 0.14746700E+02, 0.30934800E+02, -.39078900E+02, -.35705100E+02, -.33433300E+02, -.90931600E+01, -.93742800E+02, 0.17066000E+02, -.41477000E+02, -.60005900E+02, 0.18313900E+02, -.87257400E+02, -.27332300E+02, -.29329800E+02, 0.11035900E+03, 0.99933000E+01, 0.45862200E+01, 0.10774700E+02, 0.11644900E+02, -.80971100E+01, 0.82191500E+01, 0.15421100E+02, -.15551000E+01, 0.20033000E+01, 0.35017800E+01, 0.51723400E+01, -.86539800E+00, 0.14303600E+02, 0.76780900E+01, -.25558800E+01, -.19175900E+01, -.10099600E+02, 0.22746300E+02, 0.11614600E+02, 0.74572900E+01, 0.14020400E+02, 0.14221500E+01, 0.24004100E+02, -.67789900E+01, 0.13025600E+02, -.87655700E+01 },
        { 0.26515800E+01, -.36296700E+00, -.17559400E+01, -.81368100E+00, -.13504600E+01, -.20611600E+00, -.54477700E+00, 0.28001200E+01, 0.11454400E+00, 0.56990300E+00, 0.23262600E+00, -.37352300E-01, -.33255000E+00, 0.37076300E-01, 0.10772800E+00, -.93213700E+01, -.17286100E+01, -.64438900E+00, -.31735700E+00, 0.16543200E+00, 0.65647400E+00, 0.28071300E+00, 0.35484500E-01, 0.32202400E+00, 0.58959700E-01, 0.87690200E-01, 0.65173700E+00, 0.17591500E+01, -.16453700E+01, 0.33225500E-01, 0.22318400E-01, 0.32689400E-01, 0.55353300E+00, -.11763800E+01, 0.36079300E-01, 0.39551900E-01, -.10999500E-01, -.83424700E+00, 0.18778100E-01, -.66409300E+00, 0.87781600E+00, 0.29344300E+00, 0.62061900E-01, 0.25375100E+00, -.12255200E+00, -.29338400E+00, 0.29611200E-01, 0.71307100E-03, -.24217000E+00, -.28884500E-01, 0.24638100E+00, 0.15280200E+01, -.41624100E+00, 0.15947300E+01, 0.18172300E+00, -.19047300E+00, -.66999200E-01, 0.55806700E-01, -.26629200E-01, -.57302600E+00, 0.81179700E-01, -.67244800E+00, -.15729300E+00, 0.18451500E+00, -.33819500E+00, 0.42554300E+00, 0.91184400E+00, 0.59277300E-01, -.11063800E+00, -.12329800E-01, 0.11150000E-01, -.77301700E+00, -.52237600E+00, -.16665400E-01, 0.34913300E+00, -.10009600E+01, 0.68066600E-01, 0.13483200E+00, -.21374400E+00, -.90192800E-01, 0.16498500E-01, 0.10334900E+00, 0.20464300E+00, 0.49991000E+00, 0.70362700E-01, -.32155600E+00, -.40796500E+00, 0.41226800E-02, -.62089200E-01, -.41204200E-01, 0.21888000E+00, -.14903200E-03, -.44338100E+00, -.79308300E-01, -.84566300E+00, -.11092000E+01, -.14255000E+00, 0.25338300E+00, -.52418200E-01, -.18454200E+00, -.84233200E-01, 0.44063500E-01, -.49221100E-02, -.48715600E-01, -.17141800E-01, 0.34509900E+01, 0.40914600E+00, 0.16162100E+00, 0.31480700E-01, -.41369900E+00, -.28771200E-01, -.25100700E-02, 0.17712900E-02, -.96335600E-02, 0.82795700E-02, 0.10133600E+00, 0.18519900E-01, 0.68267300E-01, -.16760300E+00, 0.36230800E+00, -.91577100E-01, 0.33688100E-01, 0.32159100E-01, -.76440900E-01, 0.26833600E-01, -.28716900E+00, -.20596000E+00, -.32589600E+00, -.29480900E-01, -.87035200E-01, 0.31003300E-01, -.85859800E-01, -.61243400E+00, 0.25358100E+00, -.14228000E+00, -.13234700E-01, 0.44191600E+00, 0.19576900E+00, -.14056600E+00, -.48934400E+00, -.28526800E+00, -.11182600E+00, -.28221600E+00, -.64711800E-01, 0.10937500E-01, 0.17866900E+00, -.66309200E-03, 0.94364800E-01, -.94404000E-02, -.28444400E-01, 0.25360400E+00, -.52109900E-01, -.12265000E+00, -.14496900E+00, -.16079200E-01, -.24688500E+00, -.10505000E+00, -.18299700E-02, 0.14068700E+00, 0.89513200E-01, -.35292600E-01, -.66163700E-01, -.72140300E-01, -.79856300E-01, 0.16539200E+00, 0.15029000E+00, 0.21966200E-02, 0.64051000E+00, 0.30261800E-02, 0.25005000E+00, -.32036800E-01, 0.31129600E-01, 0.84894400E-01, -.96680900E-01, -.10262400E+00, 0.86073500E-01, -.12378200E+00, 0.17782800E-01, 0.24352800E-01, -.50257200E-01, 0.14841300E+00, -.26200700E+00, -.40558100E+00, -.17504500E+00, 0.17278700E+00, -.83270600E-01, 0.40994400E-01, 0.10347700E+00, 0.11000600E-01, 0.25592400E+00, 0.15981800E+00, 0.30282900E-02, 0.13941000E+00, -.11137400E+00, 0.52297200E+00, 0.56420100E-01, 0.32142100E-01, 0.21094600E+00, -.12227500E+00, 0.46651600E-01, -.65937500E-01, -.64437700E-03, -.14371200E+00, -.32109200E+00, -.22936300E+00, 0.83103900E-01, -.30081000E-01, 0.29761100E+00, -.79632600E-01, 0.44473800E-01, -.72318000E-02, -.43226500E+00, -.54685400E-02, -.71377800E+00, 0.25020100E+00, -.57346500E-01, -.43549700E-01, 0.20230100E+00, -.79939100E-01, 0.27184500E-01, 0.55252500E+00, 0.13868100E-01, -.42225500E-02, 0.10775000E-01, 0.94972400E-01, -.10064100E+00, 0.14914900E+00, 0.38558600E-02, 0.81143600E+01, -.83817400E-01, -.11134800E+02, -.21277000E+02, 0.10521300E+02, 0.33611400E+02, -.52649500E+01, -.14243700E+01, 0.39835200E+01, 0.31129400E+01, -.51072900E+01, 0.47203300E+01, 0.34173200E+01, 0.30144400E+02, 0.84343800E+01, -.42959500E+01, -.28631100E+01, -.39514400E+01, -.59818800E+01, 0.81532300E+00, -.78400300E+00, -.32062500E+01, 0.60473500E+01, -.16273400E+01, -.34463600E+01, -.12709300E+02, 0.58005200E+01, 0.24324300E+01, 0.63266600E+01, 0.26613200E+01, 0.25557400E+01, 0.48477200E+01, -.19607800E+01, -.33551300E+00, 0.33221400E+01, 0.31229900E+01, 0.11811500E+02, -.67219200E+01, 0.31118500E+02, -.57457100E+01, 0.25660600E+01, 0.50307100E+01, -.98048700E+01, 0.12566800E+02, -.14084100E+01, 0.39447100E+01, 0.31525800E+02, 0.19521400E+01, 0.98031400E+00, 0.14359700E+01, 0.16728000E+01, 0.28645900E+00, -.43980200E+00, -.82372800E+00, -.17085100E+01, -.38562400E+00, 0.10606400E+01, 0.15779100E+01, 0.71991800E+00, -.51294500E+00, -.42049000E+00, -.17841100E+01, -.16444000E+01, -.15498000E+01, -.10490300E+00, 0.16285400E+01, -.64253700E+00, -.90632500E-01, 0.17023900E+01, 0.18911400E+01, -.13621300E+01, -.94819900E+00, -.20844300E+01 },
        { 0.14758900E+01, 0.33228800E+00, -.68615700E+00, -.70978700E+00, -.93449700E+00, -.40891300E+00, -.76958200E+00, 0.37428200E+00, -.15000800E-01, 0.21870300E+00, -.47915300E-01, -.67052900E-01, -.29809000E-01, -.11496300E-01, 0.49296400E-01, -.49833200E+01, -.45127800E+00, -.37476200E+00, -.66883500E+00, -.20754700E+00, 0.76956500E+00, 0.78532700E-01, -.19680900E-02, -.32913300E+00, -.36377100E-01, 0.38019700E-01, 0.31690800E+00, 0.14634300E+00, -.70834300E+00, 0.21135100E-01, 0.15087300E-01, 0.11134800E+00, 0.30787300E+00, -.54581100E+00, 0.39978500E-03, 0.40523500E-02, 0.36825600E-02, -.36442500E+00, 0.48331700E-01, -.35920200E+00, 0.13332200E+00, 0.21248500E+00, 0.43824800E-01, 0.10127100E+00, -.84555400E-01, -.21510300E-01, 0.98284500E-03, 0.43876300E-02, -.42579000E+00, 0.17437400E-01, 0.71137800E-01, 0.46086800E+00, -.32207400E+00, 0.10365000E+01, 0.10065700E+00, -.10479800E+00, 0.67266000E-02, 0.29881700E-01, -.15198300E-01, -.14706200E-01, 0.15246800E-01, -.49765100E+00, -.99287800E-01, 0.11003300E+00, 0.87923500E-02, 0.86816800E-02, 0.27326200E+00, 0.74573700E-02, 0.93264400E-01, 0.23555300E-02, 0.77893900E-02, 0.55407900E+00, -.50038200E+00, -.51564700E+00, -.11470500E+00, -.60039800E+00, 0.59060100E-01, -.19484600E+00, 0.60085100E-01, -.23259200E-01, 0.17661200E-01, 0.17963800E-01, -.24540100E-01, 0.13971200E+00, 0.18941900E-01, -.17171300E+00, -.10254700E+00, -.64222800E-01, 0.10732200E+00, -.15826700E-01, 0.10770200E+00, 0.29999100E-03, 0.22094200E+00, -.53195900E-01, -.22039100E+00, -.27637300E+00, -.40653400E-01, -.11515500E+00, 0.12356200E-01, -.15312100E+00, -.43377200E-01, -.47913200E-01, 0.14294000E-03, 0.16589900E-01, 0.16290100E-01, 0.18334600E+01, 0.16724200E+00, 0.75562000E-02, -.68714700E-02, -.63674400E-01, -.15553700E+00, -.13521100E-01, 0.63162700E-01, -.14788300E-02, 0.41316500E-01, -.13455000E+00, 0.42347700E-01, 0.87256900E-01, -.15725800E+00, -.21023900E-01, -.27958100E+00, -.13419700E-01, 0.27399200E-01, -.13187000E+00, 0.31108100E-02, -.84454600E-01, 0.70963800E-02, 0.26119600E+00, -.11450100E+00, -.47776300E-01, -.16027900E+00, -.78916800E-01, -.13751200E+00, 0.22676100E+00, -.10894700E-01, -.11485200E-01, 0.16414300E+00, 0.18881800E+00, -.50172700E-01, -.44400900E+00, 0.18439000E+00, -.26218900E-01, -.14228100E+00, 0.78162000E-01, -.64122200E-02, 0.14211500E+00, 0.21218800E-01, -.40079600E-01, -.36172400E-01, -.16736600E+00, -.17411400E+01, 0.69788400E-01, -.27654400E-01, -.15161800E+00, -.67843500E-01, -.65151200E-01, 0.37937100E-02, -.27413600E-02, -.52750500E+00, -.15110900E+00, -.52054800E-01, -.55864700E-01, -.94166600E-01, -.15818000E+00, -.19076800E+00, -.78100000E-01, -.93824800E-02, 0.44413500E+00, -.11762900E-02, 0.19803400E-01, -.38557200E-01, 0.14858500E-01, -.12677900E-01, -.10389800E-01, -.19568500E+00, -.41965100E-01, 0.85743400E-01, -.26928800E-02, 0.39270600E-01, 0.26545600E-01, 0.14575400E-01, 0.13180100E-01, 0.21751600E-01, -.12321400E+00, 0.27090300E-01, -.47519400E-01, -.11738600E-01, 0.10298700E+00, 0.21890600E-02, -.46141400E-01, -.81394700E-01, 0.22771100E-01, -.10208300E-01, -.10949700E-01, -.45925100E+00, -.30417100E-01, 0.42028400E-01, -.11801800E+00, 0.96435500E-02, -.26755900E-01, -.23489300E-01, -.23068000E-01, 0.25192400E+00, -.21430500E+00, -.33151400E-01, 0.32101800E-01, 0.51162200E-02, 0.32348500E-02, -.49098700E-01, -.16151400E-01, 0.52300700E-02, 0.20815100E+00, 0.12616700E-01, 0.43687700E+00, 0.60576500E-01, 0.24389100E-01, 0.11640800E+00, 0.20276200E-01, 0.68540800E-01, 0.11129900E-01, -.70743000E+00, 0.96236700E-02, -.83866600E-02, 0.18810200E-01, 0.31402000E+00, -.27935100E+00, -.11022100E-01, -.38956100E-01, -.10799000E+00, 0.24430500E+01, -.42798700E+01, 0.93021600E+01, -.45753800E+01, -.62101200E+01, -.60345400E+01, -.97694100E+00, 0.75637600E+00, -.38344200E+01, -.13671000E+01, -.40463100E+01, 0.25461300E+00, 0.81665900E+01, 0.18511400E+02, -.96078700E+01, 0.44575200E+01, -.88256800E+01, -.48618700E+01, -.49874100E+01, 0.13693200E+01, 0.75320200E+00, -.67138000E+01, -.72285200E+00, -.15471000E+02, -.43080300E+01, 0.14654700E+01, 0.51278900E+01, 0.21377500E+01, 0.10355600E+01, 0.15196400E+01, -.24692800E+00, 0.22151700E+01, 0.47366600E+01, 0.96480700E+00, -.16141700E+01, -.45941900E+01, 0.17584500E+01, 0.21852700E+02, 0.22028800E+01, 0.25644800E+01, 0.15126200E+00, -.23737500E+01, 0.10883400E+02, 0.19027300E+01, -.63203300E+00, 0.29828600E+02, 0.22940900E+00, 0.41710400E+00, 0.28903600E+00, 0.45838700E+00, -.24706200E+00, -.74051400E-02, -.57472600E-01, -.10738200E+01, 0.11417000E+00, 0.57308900E+00, 0.65991000E+00, 0.28831400E+00, 0.12179300E+00, 0.17586400E+00, -.10980500E+01, 0.28837500E+00, -.43861800E+00, 0.56281200E+00, 0.35329900E+00, -.64567800E-01, 0.47042800E+00, 0.45303400E-01, 0.53743300E+01, -.13266800E+01, 0.40059700E+00, -.98895000E+00 },
        { 0.56019100E+01, 0.49147500E+00, -.30362900E+01, -.23815100E+01, -.22895300E+01, -.46721000E+00, -.15879500E+01, 0.74811900E+01, 0.26006900E+00, 0.15036900E+00, 0.14934400E+01, 0.28718600E+00, 0.25896900E+00, 0.28238400E+00, -.16366600E+00, -.16771800E+01, -.15813900E+01, 0.27506500E+01, -.64137900E+00, -.13598400E+01, -.37010800E+01, 0.14144100E+01, -.18198100E+00, 0.57950400E+00, 0.26138100E+00, 0.90335500E-01, -.72965500E-01, 0.10570100E+01, -.81433500E+00, 0.18102800E+00, -.23821600E+00, -.10093200E+00, 0.13947500E+01, 0.21934100E+01, 0.67647000E-01, -.14939900E+00, -.14549600E+00, -.24648700E+01, -.41056200E+00, -.16017600E+01, -.28309500E+00, 0.15362100E+01, 0.13374800E+00, 0.10805000E+01, 0.71099500E-01, -.19318600E-02, 0.28098400E-02, 0.28162600E-01, 0.70345700E+00, 0.75704800E-01, 0.25574300E+00, 0.35296800E+00, -.20906300E+00, 0.55178100E+00, 0.24338500E+00, -.14222200E+01, -.38296100E+00, 0.39228700E-01, -.84478400E-02, -.27882400E+00, -.83132000E-01, -.48718700E-01, -.32989700E+00, 0.74303100E-01, -.98246900E+00, 0.40378100E+00, 0.15483200E+01, 0.20091300E+00, 0.53161100E+00, -.16495700E-01, -.18671800E-01, 0.38731100E+00, -.44170700E+00, -.16613500E+01, 0.32460000E+00, -.62777500E+00, 0.15108500E-01, -.52690600E+00, -.66601200E+00, -.14485100E+00, -.40033200E-01, 0.16377400E+00, 0.14660500E+00, 0.23037800E+00, -.15462500E+00, -.10090900E+00, 0.15479900E+00, 0.53923700E-01, 0.50403300E+00, 0.37812700E-01, 0.31795000E+00, 0.50831400E-02, -.94482900E-01, -.76515400E-01, -.94407200E+00, -.77854900E-01, -.22000700E+00, -.13016900E+00, 0.19719100E+00, 0.76430700E-01, -.99098200E-01, 0.12443100E+00, 0.61781100E-02, 0.14468900E-01, -.25394900E+00, 0.47810600E+01, 0.80983300E+00, 0.29621700E+00, -.12325400E+00, -.63043900E+00, 0.89930400E+00, -.23613500E-01, 0.27997600E+00, -.17512500E-01, -.11689100E+00, 0.10447000E+01, 0.28632000E-01, -.37221300E-01, -.11956600E+01, 0.19648700E+01, 0.33967000E+00, 0.60397300E-01, 0.15063600E+00, -.46347900E-01, 0.46626600E-01, -.10933600E+00, 0.25782300E+00, -.94334400E+00, 0.41512000E+00, 0.16561200E+00, -.31358200E+00, 0.44999800E-01, 0.28566100E+00, -.55936300E+00, 0.14113700E-01, 0.25206300E-01, -.45554200E-01, -.60534900E+00, 0.17970300E+00, 0.38745400E+00, -.53513900E+00, -.27849400E+00, 0.61036300E+00, -.61719000E+00, -.10827100E+00, -.36957800E+00, -.11452200E+00, 0.42936800E+00, -.83942400E-01, 0.51898600E+00, 0.88904600E+00, -.40354900E-02, 0.55593000E+00, -.70569200E+00, -.99576300E-01, -.77009200E+00, -.59489000E-01, 0.11657800E-02, 0.10566800E+00, -.31387300E+00, 0.16540100E+00, 0.28818200E+00, -.26901600E+00, 0.55315100E+00, -.17145000E+01, 0.66064300E+00, 0.66990100E-01, -.93630500E+00, -.16956400E-01, -.88315900E+00, 0.46857300E+00, -.12836800E+00, -.16080200E+00, 0.28925700E+00, 0.42739400E+00, 0.13970100E+00, 0.33418100E+00, -.14131600E-01, -.18977400E+00, 0.10310200E+00, -.20868200E+00, -.80861500E+00, 0.19671200E+01, 0.57628600E+00, -.34821000E+00, 0.27494400E+00, -.31489000E+00, 0.87751200E-01, 0.57771700E-01, 0.13418700E+00, -.21081500E+00, 0.34053700E-01, -.62298100E-01, -.45678700E-01, 0.92149900E+00, 0.40269800E+00, -.31937600E-01, 0.83952300E-01, 0.23318100E+00, 0.43527400E-02, 0.10186400E+00, -.45688000E-01, -.77379100E+00, -.13031100E+00, 0.85662600E-02, 0.72455800E-01, -.19044700E+00, 0.39734800E+00, -.19912200E+00, -.22196900E+00, -.16478300E-02, -.41133700E+00, 0.70916100E-01, 0.40473400E+00, -.99469400E+00, 0.75235400E-01, -.44414700E+00, 0.60401100E+00, -.76057700E-01, 0.23065300E+00, 0.41465500E+01, 0.58524900E-01, -.21260100E+00, -.62619800E-01, 0.44288000E+00, 0.10634900E+01, -.13981700E+00, -.26394400E+00, 0.35444300E+00, -.11071900E+01, -.49749200E+02, 0.10320800E+03, -.51391800E+02, 0.54913700E+02, -.13509900E+03, -.50713800E+01, -.86614100E+01, -.95813600E+01, -.27185300E+02, -.47748700E+02, -.13068300E+01, -.38754200E+02, -.39274200E+02, 0.75976100E+01, 0.52535600E+02, 0.21177400E+02, -.11197400E+02, 0.99735200E+01, -.55774100E+01, -.23492200E+02, 0.20066500E+02, 0.28146800E+01, 0.54563700E+02, 0.67625000E+01, -.81803000E+01, -.57104200E+02, -.38328000E+01, 0.21215100E+01, -.17728400E+02, 0.44413900E+02, 0.13742000E+01, 0.47500900E+00, -.90483500E+01, 0.19963400E+02, -.20448700E+02, -.54945000E+01, 0.96907700E+02, 0.10462400E+02, -.68373800E+01, 0.14013800E+02, -.19746000E+02, -.11945100E+02, -.27814000E+01, 0.14190400E+02, 0.10625300E+03, 0.82598700E+01, 0.66791100E+01, -.39036100E+01, -.39020200E+01, -.49696300E+01, 0.52928200E+01, 0.20361500E+01, -.35743000E+01, -.41484000E+01, 0.75068100E+01, 0.85068400E+01, -.55154700E+01, 0.37406700E+01, 0.42893800E+01, -.49791400E+01, -.26866800E+01, 0.38574900E+01, 0.74824100E+01, -.37518900E+01, 0.40874300E+01, 0.67698100E+01, 0.16429600E+01, 0.23655400E+02, -.73879000E+01, 0.11706300E+01, -.67306800E+01 },
        { 0.46848000E+01, -.23526900E+00, -.22896400E+01, -.69306200E+00, -.16900900E+01, -.51269300E+00, -.12194600E+01, 0.64321700E+01, 0.27882500E+00, 0.21045900E+01, 0.16249400E+00, -.56697000E+00, -.64403800E+00, 0.21261000E+00, 0.45179900E+00, -.85551100E+01, 0.18852900E+01, 0.20027300E+00, -.53855400E+00, 0.12427200E+01, -.62525100E+00, -.14105200E-01, -.17088700E+00, -.94050700E+00, 0.30981100E+00, 0.12559000E+00, 0.10011900E+00, -.94111700E+00, -.88273500E+00, -.28269000E-01, 0.95438600E+00, -.62180500E-01, -.58454200E+00, 0.15219800E+01, 0.11270400E-01, 0.19182300E+00, 0.40686200E-02, 0.46024700E+00, 0.38138800E+00, 0.24414800E+00, -.36682000E+01, 0.52379700E+00, 0.38932300E-01, -.23852300E+00, -.69846200E-02, -.59348700E+00, 0.42837200E-01, -.38112000E-01, -.17002900E+01, -.40638500E+00, -.71129600E+00, 0.74218300E+00, -.65046200E+00, -.35953100E+01, -.81672700E+00, 0.10409900E+01, -.16314200E-01, -.11907700E+00, 0.15765800E-01, 0.45474000E+00, 0.59932500E-01, -.17132700E+00, 0.43571600E+00, 0.29561800E+00, 0.75034800E+00, 0.27666000E+00, -.96319300E+00, -.44536200E+00, -.54785800E+00, 0.43556100E-02, -.34505600E-01, 0.15139500E+01, 0.10618800E+01, 0.37882600E+01, -.32749500E+00, 0.36449400E+00, -.16075200E+00, 0.68858400E+00, 0.91460300E-01, 0.48477800E-01, 0.66333600E-01, -.54129200E-01, -.38366900E+00, -.68892200E+00, 0.23209700E+00, 0.41765500E+00, -.52749000E+00, 0.48912700E-01, -.83596700E+00, -.11662700E+00, -.44597500E+00, -.47911600E-02, -.20560800E+00, 0.26337400E-01, -.16301200E+00, -.25674000E-01, -.25088400E-01, 0.83503600E+00, -.16224000E+00, 0.77887800E+00, -.13896500E+00, 0.20891900E+00, 0.54870100E-03, -.21995600E+00, 0.10733700E+00, 0.17847600E+01, -.43466000E-01, 0.55374600E+00, -.97889600E-02, -.39216600E+00, 0.16144200E+00, 0.83811000E-02, 0.33416800E+00, -.36975500E-02, -.53654300E+00, -.14251100E+00, 0.12023400E-01, 0.13614600E+00, 0.94798900E+00, -.45029100E+00, 0.10868200E+01, -.50041900E-02, -.12718800E+00, 0.14557000E+00, -.36327200E-01, 0.13738500E+00, 0.39445500E+00, 0.54984400E-01, 0.72534200E-01, 0.57622800E-01, 0.36836900E-01, -.19073400E+00, -.47106600E+00, 0.50581800E+00, -.73116500E-01, -.99618800E-02, 0.14469000E+00, 0.25646300E+00, -.50977600E-02, -.67271800E+00, 0.92995500E-01, 0.33853400E-01, 0.42511300E-01, -.33820700E+00, 0.48288900E-01, -.76662600E-01, -.24009400E-01, -.15868200E+00, 0.10901800E-01, -.17125100E+00, -.11653000E+01, -.34597300E+00, 0.14328200E+00, -.53132500E+00, 0.53547800E-01, 0.59024500E+00, -.69712500E-01, -.11556200E-02, -.28678000E-01, 0.15701600E-01, 0.45835200E-01, -.21120000E+00, -.66673300E-01, -.29933900E+00, -.68396500E+00, -.31718500E-03, 0.26819000E-01, -.34601800E+00, -.89124400E-02, 0.47349600E+00, 0.10214500E+00, -.44024500E-01, 0.67055800E-01, -.77195200E-01, 0.11880300E+00, 0.36201900E-01, -.17555400E+00, 0.17427500E-02, -.16450500E+00, -.65938100E-01, -.98981400E-01, -.43789800E+00, 0.15340500E+00, -.11906200E+00, 0.16414600E+00, -.31737600E+00, 0.71839500E-01, 0.11428900E+00, -.60068300E-02, 0.10009400E+00, 0.14524500E+00, 0.23076700E-02, 0.17689600E+00, -.14605400E+00, 0.87164800E+00, -.16644400E-01, 0.12359800E+00, 0.17599400E+00, -.18197400E+00, 0.86734900E-01, -.50028700E-01, -.32148300E-01, 0.11709800E+01, 0.83037900E-01, 0.14784700E+00, 0.21540000E-01, -.88349500E-02, -.47423300E-01, -.89140100E-01, 0.14231500E+00, -.22976200E-01, -.63789000E+00, -.42310400E-01, -.81535800E+00, 0.36189700E+00, -.73872100E-01, 0.96255300E+00, -.47204000E+00, -.31378300E-01, 0.20916000E+00, -.75256600E+00, 0.30912200E-01, -.10995100E+00, 0.17598900E-02, 0.54780000E+00, -.91703300E-01, 0.42300600E+00, -.15220000E+00, 0.37594100E+00, 0.18059700E+01, 0.16239600E-01, 0.21634300E+03, -.10724200E+03, -.89904400E+02, -.11605900E+03, -.28739100E+02, -.38638100E+02, -.23135600E+01, 0.53586000E+02, -.75322800E+02, -.34227500E+02, -.29506700E+02, 0.19307900E+02, -.13559600E+02, -.26296500E+02, -.97879400E+01, -.13385300E+02, -.19000900E+02, 0.12803300E+02, 0.33645200E+02, 0.18640200E+02, -.20507200E+02, 0.23409100E+02, 0.15728600E+02, -.89749300E+01, -.10341800E+03, -.79061800E+01, -.10888500E+02, -.51238700E+01, -.50487300E+01, -.88077700E+01, -.10192300E+02, -.35881000E+01, 0.29938800E+02, 0.58433000E+02, -.41214900E+02, 0.13347200E+02, -.28881700E+02, -.61772300E+02, 0.75585500E+01, -.33898100E+02, -.83365600E+02, -.31059500E+02, 0.12627500E+02, -.22918100E+02, 0.11394200E+02, 0.79146200E+01, -.11989200E+02, -.12802700E+02, -.79975900E+00, 0.32321100E+01, 0.44239800E+01, -.10275900E+02, -.33778500E+01, 0.73887600E+01, 0.85175300E+01, -.10882900E+01, 0.40164900E+01, -.19913700E-02, -.10165200E+02, -.18143600E+02, 0.12175200E+02, 0.56647400E+01, -.12583800E+02, 0.28517100E+01, 0.26852700E+00, 0.18251600E+02, -.15570800E+02, -.97062600E+01, 0.40470300E+01, -.43541000E+01 },
        { 0.11668600E+01, -.84556100E-01, -.56727300E+00, -.27245100E+00, -.41001100E+00, -.88311500E-02, -.29808900E+00, 0.10008300E+01, 0.10636900E+00, -.10836800E+00, 0.93550900E-01, 0.14231700E-01, -.19002700E+00, 0.43876600E-01, 0.64935700E-01, -.79554400E+00, -.10793600E+01, -.30411400E+00, -.28461700E+00, -.12863200E+00, -.29077300E+00, 0.16641900E+00, 0.18499800E-01, 0.17296000E-01, 0.10847500E+00, 0.85725300E-02, -.41849000E-01, -.12008200E+00, 0.12910500E+00, -.30620600E-01, 0.10062100E-01, 0.21001600E+00, -.35234100E-01, -.93658100E+00, 0.36285400E-02, -.24706000E-01, -.31158600E-01, -.10683000E+00, -.53308300E-01, 0.95294300E-01, -.46819900E+00, -.15840200E+00, 0.25626000E-02, -.57911800E-01, 0.17053300E+00, 0.16444900E+00, -.21875900E-01, 0.35371600E-03, 0.67832900E+00, -.12508000E-02, 0.22608000E+00, -.45935400E+00, 0.22914100E+00, -.10535100E+01, 0.52453000E-02, -.37414000E+00, -.20612300E+00, -.11416300E-01, 0.36053000E-02, -.12121900E+00, -.71929300E-01, 0.46895400E+00, -.13154100E+00, -.13762800E+00, -.16558500E+00, -.30163200E-01, -.54935800E-01, 0.70959200E-01, 0.57143000E+00, 0.71433700E-02, -.26609500E-01, 0.88459800E+00, 0.44378500E+00, 0.81027900E+00, -.16500300E+00, 0.15474200E+00, 0.10647200E-01, -.17594100E+00, -.10448100E+00, 0.28330700E-01, -.24901800E-01, -.14680800E-02, 0.73883200E-02, -.21465700E+00, -.64611000E-01, 0.68169900E-01, 0.11622100E-01, 0.15411900E-01, 0.51248700E-01, 0.52353100E-01, -.30978300E-01, 0.55016600E-03, 0.26560900E-01, -.31063000E-01, -.56445000E-01, 0.14859700E+00, 0.68253300E-01, 0.44938600E-01, 0.26156500E-01, 0.40616000E-01, 0.75936400E-01, 0.22009700E-01, -.25228200E-02, 0.60589600E-01, -.39336300E-01, 0.95711900E+00, -.12957300E+00, -.14447200E-01, 0.13712500E-01, -.99987500E-01, 0.92382000E-01, -.31201100E-01, -.56473500E-02, -.78388600E-02, 0.10066200E+00, 0.14880100E+00, -.73876500E-01, -.47465900E-01, -.14100300E+00, 0.38720200E+00, -.20180200E+00, -.72672400E-02, 0.15118100E+00, -.19938100E-02, -.15671200E-02, -.43065100E-01, -.43431800E-01, 0.40421700E-01, 0.17158600E-01, -.93240400E-03, 0.47379500E-02, 0.11920300E-01, 0.10698500E+00, 0.66800400E-01, -.15423800E-01, 0.89276000E-04, 0.19956600E-01, 0.19479000E-01, -.21863500E-01, 0.66352700E-01, 0.22995300E+00, 0.30781500E-01, -.30692900E-01, -.33301800E-01, 0.20756100E-02, -.42836400E-01, -.55200100E-02, 0.72962500E-01, -.12273800E-01, -.12562100E-01, 0.26445400E-01, 0.93593400E-01, 0.48228800E-01, -.26941400E+00, -.41897200E-01, -.34023700E+00, 0.32091400E-03, 0.11532500E-03, 0.26603700E-01, -.59373100E-01, -.54178600E-01, 0.26815100E-01, -.62470100E-01, 0.59281100E-01, 0.91033000E-01, -.49116800E-01, -.79739400E-02, 0.19451500E+00, -.24814600E-02, 0.70876500E-01, -.27623100E-02, 0.12079000E-01, 0.29608200E-01, -.34175800E-01, -.67472000E-01, -.51421400E-02, -.63507800E-01, -.18380400E-01, 0.20274300E-02, -.49722000E-02, 0.10387700E+00, 0.51755400E-01, 0.81902200E-01, -.18167700E-01, 0.84617000E-02, 0.23570300E+00, -.26886000E-02, -.47031700E-02, -.37938600E-02, -.11325400E-01, -.12353600E+00, -.19746600E-01, 0.14829400E-01, 0.61434600E-01, -.77638600E-02, -.27269100E-01, -.12458800E+00, 0.13848400E-01, -.89451300E-01, 0.91212000E-02, -.14277900E-01, -.10289700E-01, 0.19475500E+00, -.18199400E+00, -.32840400E-01, 0.88347000E-02, 0.24508800E-01, 0.14035300E+00, -.75766000E-01, 0.24229900E-01, -.32535400E-03, -.24108700E-01, -.75056500E-02, -.18905500E+00, 0.59890500E-01, -.10608900E+00, 0.89029600E-01, 0.17570900E+00, -.44972600E-01, -.31072400E-01, 0.37362600E+00, 0.10212700E-01, 0.11356700E-01, 0.56974300E-02, 0.11871300E-01, -.15099900E+00, -.32672400E-02, -.27697700E-01, -.11344400E+00, -.74893400E-01, 0.83924600E-02, 0.75062100E-01, 0.61509600E+02, -.83858000E+01, -.15372500E+02, 0.77131000E-01, 0.28223200E+01, -.50772100E+01, -.14543500E+01, 0.12721300E+01, 0.33483400E+01, -.51859400E+01, 0.44386300E+01, -.29989100E+01, 0.72344200E+01, -.20339200E+01, 0.91973000E+00, 0.29151500E+01, -.33827800E+01, -.46338500E+01, -.81667400E+01, 0.53619600E+01, -.12180200E+02, -.35653000E+01, 0.37965900E+01, 0.21170400E+02, 0.18090500E+01, 0.45474300E+00, 0.11466200E+01, -.66080200E+00, 0.13590800E+01, 0.34098900E+01, 0.30645700E+00, -.63160600E+01, -.15213100E+02, 0.11565100E+02, 0.10283000E+02, 0.74296200E+01, 0.94036700E+01, -.33510700E+01, 0.83155200E+01, 0.17356700E+02, 0.10416200E+02, -.51270200E+01, 0.43714100E+01, -.19513400E+01, -.91802000E+00, 0.14737300E+01, 0.17988500E+01, -.29177300E+00, -.16900000E+00, -.43905600E+00, 0.11361900E+01, 0.43557300E+00, -.89701100E+00, -.88758000E+00, 0.75521700E-01, -.22086200E+00, 0.37427700E+00, 0.11865200E+01, 0.32534100E+01, -.16669900E+01, -.56635400E+00, 0.16446900E+01, -.61042900E-01, 0.25370000E+00, -.33319300E+01, 0.79682800E+01, 0.88665100E+00, -.82629900E-01, 0.64623300E+00 },
        { -.28729400E+02, -.69967100E+01, 0.56939700E+01, 0.13794400E+02, 0.79547300E+01, 0.94457900E+01, 0.73259100E+01, -.31225100E+02, -.27892000E+01, -.58759600E+01, 0.32807800E+00, 0.32118300E+01, 0.52855300E+01, -.12413900E+01, -.31019600E+01, 0.52995900E+02, 0.40260100E+01, 0.76863200E+01, 0.13684100E+02, -.21712100E+01, -.85325700E+01, -.12958000E+01, -.19460100E+00, 0.10839500E+01, -.13345300E+01, -.51316200E+00, -.25887800E+01, -.24483000E+01, -.29618200E+00, 0.31592100E+00, -.18113900E+01, -.27455400E+01, 0.25335600E+00, 0.10055600E+02, -.11972400E+00, -.36447500E+00, 0.64219400E+00, 0.30067300E+01, -.30732500E+00, -.31242300E+00, 0.19401700E+02, 0.13459400E+01, -.47559200E+00, 0.89130500E+00, -.13929800E+01, -.19251800E+00, 0.16529200E+00, 0.22720800E+00, -.10676700E+02, 0.46702100E+00, -.17832600E+01, 0.30256400E+01, 0.22040400E+01, 0.39426700E+01, 0.50185300E+00, 0.90809600E+01, 0.45496900E+01, -.56338600E+00, 0.20029300E+00, -.21596400E+00, -.17995800E+00, 0.98807800E+00, 0.15154900E+01, -.18678300E+01, 0.10946300E+01, -.29463200E+01, 0.12167700E+01, 0.11927500E+01, 0.18471800E+01, -.14072000E-01, -.12199600E+00, 0.20923500E+02, 0.22538600E+01, -.14832000E-01, -.51860300E+01, -.48561300E+01, -.31614600E+00, 0.12555700E+01, -.42318900E+01, -.29059500E+00, 0.29718500E-01, 0.41497600E+00, -.40145000E-01, 0.17913500E+01, -.63340500E+00, -.13691100E+01, -.49425800E+00, 0.14886200E+01, -.30275200E+00, 0.46068700E+00, -.62795000E+01, -.50161900E-02, 0.14105800E+01, -.38824100E-01, 0.45934500E+01, 0.15139100E+01, 0.16220200E+01, -.14682100E+01, -.10788200E+00, -.14397500E+01, 0.37379300E+00, 0.23160000E+00, 0.74533600E-01, -.68290700E+00, 0.25579300E+00, 0.33255100E+02, -.14084200E+01, 0.17984700E+01, 0.78081100E-01, -.32919200E+01, -.50964000E+00, 0.85750300E-01, 0.56804100E+01, -.14619800E+00, -.13218500E+01, -.19201500E+01, -.11212000E+01, 0.17021900E+01, -.22818100E+01, -.77033500E+01, -.38878800E+01, -.14410300E+00, -.10083400E+01, 0.21103500E+00, -.27539800E+00, 0.25204100E+01, 0.33218900E+01, 0.42500600E+01, -.80267100E+00, -.21797100E+00, 0.36463700E-01, 0.88326000E+00, 0.31235700E+01, -.29307200E+01, 0.84556000E+00, 0.10458700E+00, -.13075400E+00, 0.18849300E+00, -.13459200E+00, -.67287200E+01, 0.54498400E+00, 0.70804000E+00, -.15147800E+01, -.16155100E+01, -.54443200E+00, -.34956800E+01, -.46720400E+00, -.80430600E+00, -.54582600E+00, 0.48508800E+01, -.41088200E+01, 0.20526300E+01, 0.19123100E+01, 0.11830100E-01, -.38248400E+00, -.12034000E+01, 0.16074500E+00, -.66259300E-02, -.57765000E+00, -.92212100E+00, 0.21030400E-02, 0.49142900E+00, -.12812900E+00, 0.19382800E+01, -.27056500E-01, -.99536300E+00, -.11177100E+00, -.13352500E+01, 0.17333700E-01, 0.16152100E+01, -.10076200E+01, 0.46966600E+00, -.63665100E-01, 0.85881300E-01, -.90598700E+00, -.77085700E+00, 0.57025200E+00, 0.18600200E+00, -.10952800E+01, 0.43374400E+00, -.55007100E+00, -.68994500E+00, -.37025800E+01, -.11205300E+01, 0.11385800E+01, -.16822600E+01, 0.10947900E+01, -.55895100E+00, -.57517400E-02, 0.81388400E+00, -.66336000E+00, 0.44288500E+00, -.31027700E-01, -.19887800E+01, -.34759900E+01, -.10532300E+01, 0.38297300E+01, 0.47886200E+00, 0.72050300E+00, -.48078300E-01, 0.27579100E+00, 0.71851000E+00, 0.97975100E+00, 0.60897100E+00, -.67659000E+00, 0.78479600E+00, 0.28898200E+00, -.25677300E+01, 0.48553100E+00, 0.19304100E+00, 0.72476500E-01, 0.10098300E+01, 0.21870600E+00, -.43444900E+01, -.12703800E+01, -.16961200E+01, -.11473200E+01, 0.22841700E+01, 0.21346000E-01, 0.78190400E-03, -.48159500E+01, 0.21913800E+00, 0.87149600E-01, 0.26042400E-01, -.42209800E-02, -.13819300E+00, 0.25665700E+00, -.14676600E+00, 0.92413200E+00, 0.12540800E+01, 0.47629500E+01, -.29235500E+01, -.18022400E-01, -.92121300E+03, 0.46085300E+03, -.43260500E+02, -.57869800E+02, 0.50914900E+02, 0.41996200E+03, 0.16930400E+03, -.11366700E+03, 0.34885900E+03, 0.42239500E+03, -.16338100E+03, -.49437500E+03, -.22049000E+03, -.13500300E+02, -.23562600E+03, 0.18347200E+03, 0.40822700E+03, -.52677600E+02, -.19762100E+03, -.31860400E+03, 0.10007200E+03, -.37693700E+02, -.42301000E+03, -.48236100E+02, -.87852700E+02, 0.27536900E+02, -.30665800E+03, -.86622600E+00, 0.12038400E+02, -.47634700E+02, -.39418000E+02, 0.53931900E+03, -.25274800E+03, -.50636400E+03, -.26118400E+03, -.23446500E+03, -.11503400E+03, 0.13523400E+01, -.23900800E+03, -.82645900E+02, -.12935400E+03, -.66181500E+03, 0.19582900E+02, -.20464900E+02, 0.26440000E+02, 0.23105200E+02, 0.35782800E+02, -.23937800E+02, 0.14055000E+02, -.15802700E+02, 0.22008400E+02, -.28168300E+02, -.37232500E+02, 0.52790000E+02, -.30047900E+01, -.34644000E+02, -.47667100E+01, -.54942000E+02, -.22519800E+02, -.10438500E+02, 0.23086500E+02, -.18333900E+02, -.42179300E+02, 0.56755100E+02, -.25029800E+03, 0.18884300E+02, 0.19185200E+02, 0.14515400E+02 },
        { -.23435200E+01, 0.86132400E-01, 0.11385000E+01, 0.61925200E+00, 0.85389800E+00, 0.75195200E-01, 0.65893200E+00, -.20850100E+01, -.19388300E+00, 0.19766100E+00, -.18755100E+00, -.19325000E-01, 0.35498800E+00, -.84901200E-01, -.14774100E+00, 0.20013600E+01, 0.20445000E+01, 0.64979900E+00, 0.57333700E+00, 0.23988900E+00, 0.58695600E+00, -.31423400E+00, -.26467000E-01, 0.23534600E-01, -.20198000E+00, -.18929000E-01, 0.64674300E-01, 0.28776500E+00, -.18850800E+00, 0.65930900E-01, -.47260200E-01, -.43793400E+00, 0.98517800E-01, 0.18624100E+01, -.12108600E-01, 0.44550700E-01, 0.62314400E-01, 0.17873800E+00, 0.91154700E-01, -.20924300E+00, 0.10270000E+01, 0.33811800E+00, -.69358100E-02, 0.12829000E+00, -.35901500E+00, -.20869300E+00, 0.32396000E-01, 0.23323100E-02, -.12117900E+01, 0.15171800E-01, -.41450500E+00, 0.84485400E+00, -.42116000E+00, 0.19843900E+01, 0.69644400E-02, 0.71011800E+00, 0.35211100E+00, 0.33509700E-01, -.13760500E-02, 0.21634800E+00, 0.12693200E+00, -.83899500E+00, 0.22658600E+00, 0.23900100E+00, 0.33526200E+00, -.68526100E-02, 0.23816800E+00, -.13975500E+00, -.76809300E+00, -.63409800E-02, 0.88478800E-01, -.12890700E+01, -.88154300E+00, -.97159700E+00, 0.38069900E+00, -.16553700E+00, -.78118500E-01, 0.41053000E+00, 0.37654200E+00, -.24188000E-01, 0.73924900E-01, -.36716000E-01, -.86700600E-01, 0.35746500E+00, 0.15156200E+00, -.17118900E+00, -.43859900E-01, -.29057000E-01, -.14855800E+00, -.48428500E-02, 0.17603100E+00, 0.13317900E-03, -.96752800E-01, -.45951300E-01, -.30028400E+00, -.78100400E+00, -.10761700E+00, 0.58242800E-01, -.15323500E+00, -.29207800E+00, 0.63249900E-02, -.87873700E-02, 0.10978200E-01, -.45547700E-01, 0.11154400E+00, -.37888600E+00, 0.14603000E+00, 0.14899400E+00, -.13748100E-01, -.12207100E-01, -.19178100E+00, 0.16898800E-02, -.24147200E+00, 0.20799800E-01, -.18948400E+00, -.34696500E+00, 0.12123900E+00, 0.19571700E+00, 0.27449300E+00, -.79914400E+00, 0.25218600E+00, 0.25111500E-01, -.48131700E-02, 0.97562000E-01, 0.19942200E-01, 0.22601900E+00, 0.62132400E-01, -.48061300E+00, -.37565100E-01, -.37050900E-02, -.13062900E-01, -.69480600E-01, -.15989100E+00, 0.32201500E+00, 0.12272500E+00, 0.54142100E-02, -.51602400E+00, -.12368400E+00, 0.32698000E-01, 0.46265200E-01, -.11716700E-01, 0.21028200E+00, 0.13898200E+00, 0.26377200E+00, 0.82532500E-01, 0.16792100E+00, 0.45669600E-01, -.46398100E+00, 0.11515700E+00, 0.16397800E-01, 0.72829900E-01, -.27855700E+00, -.23367700E+00, 0.42165100E+00, 0.13574900E+00, 0.70170500E+00, -.18422600E-01, -.77957000E-03, -.87156000E-01, 0.18332300E+00, 0.93085500E-01, -.16211600E-01, 0.20276200E+00, -.12497200E+00, 0.13707100E+00, 0.13154800E+00, 0.21922200E-01, -.15017600E+00, 0.12082500E-01, -.31576700E+00, -.39110400E-01, -.14220500E-01, -.71267100E-01, 0.65848200E-01, 0.13366900E+00, -.12175300E-01, 0.17688200E+00, -.85753600E-02, -.66832000E-01, -.39683700E-01, -.33017700E+00, -.49447900E-01, -.21873200E+00, 0.93560400E-02, 0.43279700E-01, -.45008100E+00, -.86056400E-01, 0.54461100E-01, -.23158000E-02, -.37243200E-01, -.15496800E+00, 0.71362400E-01, -.85274800E-02, -.97162900E-01, -.45690400E+00, -.80632200E-01, 0.29758200E+00, -.10242500E+00, 0.38086100E-01, -.21513300E-02, 0.22008100E-02, 0.46613500E-02, 0.23908600E-01, 0.75827400E-01, -.11116300E+00, -.56072500E-01, 0.72378400E-01, -.20185200E+00, 0.38483000E-01, -.21158200E-01, 0.62557900E-02, 0.24197900E+00, 0.10946200E-01, 0.23571400E+00, 0.77053300E-02, 0.93984700E-01, -.12685000E+00, -.45952500E+00, 0.19315500E+00, 0.94930200E-02, -.19912000E+01, 0.67916500E-03, -.56382400E-03, 0.13352300E-04, -.10253700E-02, 0.40217700E-02, 0.13502400E-02, 0.30696700E-02, 0.62651900E-02, 0.10027200E-01, 0.19116000E-01, 0.15405600E-01, 0.50782100E-01, 0.71154200E-03, 0.44581600E+02, 0.65388500E+00, 0.69603700E+00, 0.64009500E+00, -.91472000E-01, 0.26425300E+01, 0.36083900E+00, 0.21707900E+01, 0.52596700E+00, 0.61000700E-01, -.12465800E+01, -.40414700E+00, 0.31972900E+00, -.33120800E+00, 0.36642800E+00, 0.59474800E+00, -.13622700E+00, -.33029900E+00, -.12194100E+01, 0.26001000E+00, -.13478500E+00, 0.30826000E+00, -.15892800E+00, -.32736800E-02, 0.25249300E+00, -.87207500E+00, 0.84078200E-01, -.17129700E+00, 0.40553400E-01, -.68247400E+00, -.85734900E-01, 0.29480100E+00, -.26321800E+01, 0.99678400E-01, 0.75531900E+00, -.38683500E+00, 0.58269200E+00, 0.57098900E+00, 0.32869200E+00, -.44183600E+00, -.15915800E+01, -.25228900E+00, -.24015700E+00, 0.25794100E+00, 0.25210700E+00, 0.11341900E+00, -.11282000E+00, -.85292300E-01, 0.17694500E+00, 0.12454900E+00, -.23907200E+00, -.30862100E+00, 0.13209400E+00, -.13182900E+00, -.93022600E-01, 0.20510700E+00, 0.12138300E+00, -.24074200E+00, -.17672600E+00, 0.25473100E+00, -.86025400E-01, -.14275400E+00, -.11327800E+00, -.10163300E+01, 0.29730800E+00, -.53745100E-01, 0.17187600E+00 },
        { 0.40022900E+01, -.43849400E+00, -.12651300E+01, -.15776200E+01, -.26226500E+01, -.70833800E+00, -.88062600E+00, -.35202300E+00, 0.43530200E+00, -.83380300E+00, -.27136600E+00, -.25268600E+00, -.64738700E+00, 0.29970900E+00, 0.14245400E+00, 0.12725300E+01, 0.10534900E+01, 0.42034000E+00, 0.73028600E-01, 0.11182800E+00, -.41194600E+00, 0.17244800E+00, 0.11204500E+00, -.99196900E-01, -.61537200E-01, -.14389600E+00, -.97106300E+00, 0.64022600E+00, 0.30529900E+01, -.11299800E+00, 0.31175700E+00, -.46812200E+00, -.56863300E+00, 0.11428600E+01, 0.31143300E-01, 0.86365400E-01, 0.30133500E-01, -.92092900E+00, 0.23503100E-01, -.66153300E-01, -.30859500E+01, -.16576700E+00, 0.10675400E+00, -.15970200E+00, 0.28284300E+00, 0.77212000E+00, -.49025900E-01, 0.99736800E-01, 0.10935900E+01, 0.72739700E-01, 0.28740200E+00, -.91616000E+00, -.53741600E+00, -.37962000E+00, 0.17699400E+00, -.34478000E+00, 0.33603500E+00, 0.28431500E+00, 0.11182000E+00, 0.46871400E+00, -.22562100E+00, 0.11522600E+01, -.53016500E+00, 0.37272700E+00, -.44440200E+00, -.40753500E+00, -.97639000E+00, -.15789700E+00, -.11806500E+01, -.84253500E-02, 0.79876300E-01, -.44553800E+01, -.18259400E+00, -.11192300E+01, 0.10963600E+01, 0.72203200E+00, 0.10593000E+00, 0.77794200E+00, 0.97165600E+00, -.13204900E+00, -.22754600E-01, -.85632100E-02, 0.51653200E+00, -.47918800E+00, -.12782200E+00, 0.65759500E-02, 0.40141800E+00, -.21012700E+00, 0.60309700E+00, -.18679800E+00, 0.80416400E+00, 0.44129300E-02, -.68474000E-01, 0.12636200E+00, -.13538600E+01, -.35914900E+00, -.68868100E+00, 0.25645600E+00, 0.73047400E-01, 0.46896900E+00, -.18260700E+00, -.56542400E-01, 0.22287800E-01, 0.37248800E+00, -.12973300E+00, 0.28315000E+00, 0.31189100E+00, -.28403000E+00, -.89692700E-01, 0.47642000E-01, 0.15201200E+00, -.26869000E-01, 0.53809500E+00, 0.80416900E-02, 0.19062200E+00, 0.24674200E+00, 0.21621400E+00, -.54693800E+00, 0.82162800E+00, 0.33273100E+00, 0.89012600E-01, -.53459200E-01, -.10669400E-01, -.57302800E+00, 0.35249300E-01, -.10448100E+01, -.20682900E+00, 0.11306300E+01, -.23953500E+00, 0.40876200E-01, -.18477600E+00, -.22198500E+00, -.50586500E-01, 0.69586500E+00, 0.98001600E-01, -.24354500E-01, 0.53859100E+00, 0.33666000E+00, -.69459500E-01, -.12151600E+01, -.24341600E+00, -.44571300E-01, 0.14265000E+00, -.18672300E+00, -.15737500E-01, -.48486800E-01, 0.60777700E-01, -.30599300E+00, -.51698900E-01, 0.31256300E+00, 0.20484900E+00, 0.30291000E+00, 0.25649200E+00, 0.10818200E+00, -.10667700E+00, -.17597300E+00, 0.74270400E-01, -.69958500E-02, -.10466100E+01, -.42117800E+00, 0.16329500E-01, -.15001400E+00, 0.15689700E+00, 0.46646300E-01, -.28436000E+00, -.27255700E+00, -.79838500E-01, -.17995800E+00, 0.96493300E-02, -.89160500E+00, 0.34813200E+00, -.89582800E-01, -.96947500E-01, 0.82061300E-01, -.17262300E+00, 0.67782100E-01, 0.28766400E+00, 0.24186100E-03, -.84536600E-01, -.54248800E-01, -.78912100E-01, -.47297500E-01, -.47885800E-01, -.77923200E-01, -.23248200E-01, -.39444800E+00, -.47048000E-01, -.50883600E-01, -.40701500E-01, 0.21620700E+00, -.40604800E+00, -.16044500E+00, -.12119700E+00, 0.13707700E+00, 0.15378600E+01, 0.18590500E+00, 0.19266000E+00, -.27601700E+00, 0.22815900E+00, -.35266700E-01, 0.22121900E+00, -.73122700E-01, 0.62356500E+00, -.17690500E+00, 0.26277200E+00, 0.45662100E-01, -.40505800E-01, 0.15749500E+00, -.20613400E+00, -.21220200E+00, -.19689000E-01, -.14672100E+00, 0.14734700E-01, -.76382700E+00, -.24236700E+00, -.38321000E+00, -.49054500E+00, 0.53668800E+00, 0.20826200E+00, -.27735000E+00, -.87194800E-01, -.43777200E-01, -.61478000E-01, 0.51105300E-02, -.24009300E+00, -.12154800E+00, -.33117600E+00, -.46146500E-01, -.26238000E+00, 0.76696700E+00, -.10914100E+00, 0.61324900E+00, 0.79228400E-02, 0.47572200E-01, -.78658900E+00, 0.11518200E+02, 0.46313300E+01, 0.11318000E+00, -.19503500E+02, -.20339400E+01, 0.85963900E+01, -.46747500E+02, 0.17479300E+02, -.10437000E+02, 0.29937800E+02, -.87608000E+01, -.34102700E+01, 0.16809700E+02, -.16763400E+02, -.10088300E+02, -.16390400E+02, 0.22201500E+02, -.76547900E+01, 0.40103000E+01, -.31428100E+01, 0.61641700E+02, -.20952700E+01, 0.12841600E+00, -.95552400E+01, 0.20767100E+02, 0.43444600E+01, 0.26021800E+01, -.10802500E+02, -.23782000E+02, -.85800900E+02, 0.45511200E+02, 0.80891900E+02, 0.43099500E+02, 0.65257600E+02, 0.25159800E+02, 0.25450700E+01, 0.37570500E+02, 0.34920700E+02, 0.22252100E+02, 0.31424200E+02, -.80402900E+01, 0.16275900E+01, 0.11207800E+02, 0.12401200E+02, -.21405400E+01, 0.19011100E+00, -.77436800E+01, 0.77483700E+00, -.30788000E+01, 0.28772000E+01, 0.25342700E+01, -.23970300E+01, -.43611600E+01, 0.20353900E+01, 0.43053000E+00, 0.78043600E+01, -.12323900E+02, -.48361100E+01, 0.11772800E+02, 0.20103400E+00, 0.32044900E+00, -.82091800E+01, 0.11641000E+02, -.16907900E+01, -.52663700E+01, 0.15444200E+01 },
        { 0.18063800E+02, 0.20639300E+01, -.28200100E+01, -.19959200E+01, -.65677200E+01, -.37449400E+01, -.23238900E+01, -.72009400E+01, 0.26692300E+01, -.30875500E+00, -.35726800E+01, -.22718400E+01, -.46743100E+01, 0.56306700E+00, 0.22188600E+01, -.11504100E+02, -.80322700E+01, -.39238000E+01, 0.55471500E-01, 0.44172700E+00, -.41771600E+00, -.12359200E+01, 0.13361000E+01, -.16969200E+01, 0.12415700E+01, -.50196800E-01, -.31952400E+01, -.62427000E+00, 0.11748500E+02, -.38286200E-01, 0.11333900E+01, -.66166300E-01, -.12754000E+01, -.48155500E+01, -.94714800E-01, 0.57845600E+00, -.26996400E+00, -.52192000E+00, -.83694300E+00, 0.49533000E+01, -.10428600E+02, -.38905100E+01, -.34379600E-01, -.21984200E+00, 0.37078800E+01, -.36183600E+01, 0.59866600E+00, 0.67176700E-01, 0.14684700E+01, -.29509600E+00, 0.71247300E+00, -.86170000E-01, -.39828100E-01, -.39518200E+01, -.10015800E+00, -.96496400E+00, -.27691000E+00, 0.90395200E-02, 0.63833100E-01, 0.54565200E-01, -.31915900E+00, 0.15474500E+01, -.25260700E+00, 0.58792900E+00, 0.88319700E+00, 0.14902500E+01, -.96177700E+00, 0.18102900E+00, -.97219800E+00, -.40088700E-01, -.28199400E+00, 0.13902300E+01, 0.94523800E+00, 0.40177800E+00, -.58678000E-01, 0.17401800E+01, 0.27222900E-01, -.21829200E+00, 0.26920200E+00, 0.59885000E-01, -.17068100E-01, -.30825700E+00, 0.62298200E+00, 0.16819000E+00, 0.73936800E-01, 0.69048400E-01, -.64670300E-01, -.71027300E-01, 0.18570000E+00, 0.19540700E+00, 0.56284100E+00, 0.50877300E-02, -.41882300E+00, -.26417300E-04, 0.53447500E+00, 0.44611800E+00, 0.65035700E+00, 0.58815700E+00, 0.18818000E+00, 0.39178000E+00, 0.55676700E-01, 0.22135100E+00, 0.81346400E-01, -.40136800E+00, 0.31850700E+00, -.38137500E+01, -.23248500E+00, 0.12950100E+01, -.73838900E+00, -.10788300E+01, 0.19307100E+01, -.18564000E+00, -.19479800E+01, 0.57269200E-01, 0.54305000E+00, 0.10033200E+01, 0.11304200E+01, -.24283600E+00, -.30409000E+01, 0.21603500E+01, 0.11591100E+00, 0.13844700E+00, 0.67545500E+00, -.74608800E+00, 0.28345900E+00, -.50807700E+00, -.47080100E+00, 0.24569800E+01, -.83773400E+00, -.93155300E+00, -.24007900E+00, 0.18859000E+00, -.55189900E+00, 0.49734400E+00, 0.53548800E+00, 0.65724400E-01, -.18915800E+01, -.15260700E+01, 0.24681000E+00, 0.87349700E+00, -.27957800E+00, 0.37100600E+00, 0.16991900E+01, 0.16140500E+01, -.22801100E-01, 0.14471700E+01, 0.11512200E+00, -.19202000E+01, 0.28399700E+00, 0.40729600E+00, -.57487200E+00, -.27261300E+00, -.26119800E+00, -.18097800E+01, -.26968300E-01, 0.58872400E+00, -.85412500E-01, -.73859600E-02, -.12284300E+01, -.10282100E+01, 0.17723600E+00, 0.50639200E+00, 0.93105900E-01, -.26833800E-01, -.12713800E+01, -.54714200E+00, -.33272400E+00, 0.20120300E+01, 0.20510800E+00, -.19948300E+01, -.11410700E-01, 0.30840400E+00, -.10695300E+01, 0.15774500E+00, -.19313800E+01, 0.34219600E+00, 0.12443900E+00, 0.13006000E-01, 0.87723600E+00, 0.26295400E-01, -.59036600E+00, -.23490100E+00, -.14535800E+01, -.15076500E+01, 0.13881600E+00, -.65547000E+00, -.51905600E+00, 0.10778200E+01, 0.13814300E-01, 0.23063400E+00, 0.66421900E+01, -.45567000E+00, 0.10584600E+01, 0.84825200E+00, 0.10772900E+02, 0.14727500E+01, -.55033900E+01, 0.13481600E+01, -.71988800E+00, 0.57304800E+00, -.44174300E+00, -.35447500E+00, 0.29025400E+01, -.33146400E+01, -.23162000E+01, -.65820900E+00, 0.73519600E+00, 0.24498300E+01, -.58550200E+00, -.29367200E+00, -.17550700E-01, 0.48428900E+00, 0.18176000E+00, -.16418400E+01, -.39367900E+01, 0.13521900E+01, 0.47198800E+01, 0.38187900E+00, -.34042100E+00, 0.14396700E+01, 0.62752800E+00, 0.33868900E+00, -.42207900E+00, -.70955500E-01, 0.10972400E+01, 0.43391300E+01, 0.34815000E+01, -.49265400E+00, 0.63200700E+01, -.34332400E+00, 0.19836400E+01, 0.84279000E+00, -.83495800E-02, 0.41650100E+00, 0.16298700E+01, 0.21600400E+01, -.78706600E+02, 0.13235100E+03, 0.20970600E+03, -.22121600E+02, -.86251900E+02, 0.21696200E+03, 0.24367200E+03, -.12146000E+03, -.11333600E+03, -.12623600E+03, 0.12452800E+02, -.10050700E+03, 0.78881700E+02, 0.25685200E+03, 0.42683600E+02, -.10520100E+03, -.30076100E+03, 0.74890300E+02, -.44129600E+02, -.10323800E+02, -.37598800E+02, -.20997500E+01, 0.17865500E+02, -.86824700E+02, -.53325000E+02, -.81987500E+02, 0.21927400E+02, 0.14963500E+03, 0.60146200E+03, -.34076300E+03, -.14805200E+03, -.29562200E+03, -.42977600E+03, -.13005600E+02, -.16974300E+03, -.43341800E+03, -.43977600E+03, 0.35470000E+02, -.49521800E+03, 0.52340700E+02, 0.14359000E+02, -.47952600E+02, -.55187400E+02, 0.31758700E+02, -.13388200E+02, 0.21088300E+02, -.27039500E+02, 0.68149300E+01, 0.11339700E+02, 0.28196200E+01, 0.13446300E+02, 0.15095300E+02, -.32540900E+02, -.24709800E+02, -.25599400E+02, 0.48904000E+02, -.45905100E+01, -.54002900E+02, -.14016600E+02, -.56030500E+01, 0.26316800E+02, -.26936800E+03, -.16518500E+02, 0.26898500E+01, -.88102600E+01 },
        { 0.13227600E+02, 0.40178800E+01, -.49507500E+01, -.80060900E+01, -.37282700E+01, -.29815500E+01, -.45534800E+01, 0.21898200E+02, 0.11631900E+01, 0.43720900E+01, 0.36120000E+01, -.14622200E+00, -.14253900E+00, 0.60988900E+00, 0.13997400E+01, -.86050900E+01, 0.75979100E+01, 0.26650900E+01, -.24711400E+01, -.92429200E-01, -.43030000E+01, -.92420600E+00, 0.37718800E+00, 0.48871900E+01, -.31051200E+00, -.14216300E+00, 0.15682100E+01, 0.11921600E+02, -.36936800E+01, -.61021800E+00, 0.30872300E+01, 0.70425500E+01, -.28318100E+01, -.97475700E+00, 0.17374000E+00, 0.87309300E+00, -.14014700E+00, -.62423700E+01, 0.22670100E-01, -.22189000E+01, -.30595400E+01, -.35265800E+00, 0.51255100E+00, 0.75838900E-01, 0.37861900E+00, 0.18928900E+01, -.19716700E+00, 0.12720800E+00, 0.10060300E+02, 0.76025400E+00, 0.25853000E-01, 0.17575500E+00, 0.11106600E+00, 0.33176200E-01, 0.99138600E+00, -.12110100E+01, 0.33592600E+00, 0.53830500E+00, 0.23627100E+00, 0.89461800E+00, -.60725500E+00, 0.72075400E+00, -.31355700E-01, 0.93925800E+00, -.60185500E-01, -.36664500E+01, -.51423100E+01, -.33136900E+00, 0.39883800E+01, 0.44792200E-01, 0.31388100E+00, 0.83341700E+01, 0.37941400E+01, 0.10954200E+02, -.34293100E+01, 0.10134000E+01, -.84182900E+00, 0.37744000E+01, -.19880100E+01, -.19149900E-01, 0.41549400E+00, -.32590000E+00, -.32403900E+00, -.10017900E+01, 0.11437100E+01, 0.77361300E+00, -.44874500E+00, -.10578100E+00, -.94988900E+00, -.11435400E+00, 0.28309000E+00, 0.97159000E-02, 0.54121500E+00, 0.19532500E+00, 0.13148500E+01, 0.13028200E+01, 0.19843400E+01, 0.78407300E+00, -.87710000E-01, 0.53996600E+00, 0.93902500E-01, 0.26691300E+00, 0.61716300E-01, 0.66129400E+00, 0.38943900E+00, -.66196200E+01, -.26533900E+00, 0.76097100E+00, -.58162600E+00, -.10214600E+01, 0.14655000E+01, -.44473400E-01, -.32235900E+01, 0.56122800E-01, -.17617300E+01, 0.90941200E+00, 0.38902300E+00, -.52851100E+00, 0.26516200E+01, -.72184600E+01, 0.36453400E+01, -.10077500E+00, -.97568800E+00, 0.15331500E+01, -.21860600E+00, 0.14791400E+01, -.42565000E+00, -.24781900E+01, 0.19054300E+01, 0.54254800E+00, 0.33269900E+01, 0.31048100E+00, 0.13293900E+01, 0.39959900E-01, -.15345500E+00, 0.88258400E-01, -.37608800E+01, 0.50338600E+00, 0.24393700E+00, 0.32166100E+01, 0.10538200E+01, 0.44864400E+00, 0.11152400E+01, 0.60184800E+00, 0.14970700E+00, 0.24929900E+00, 0.11618400E+00, 0.83626600E-01, 0.21295800E+00, -.64749600E+00, -.36220000E+01, -.16832600E+01, -.59840400E+00, -.37745300E-01, 0.56920800E+00, 0.13730400E+01, -.38952300E+00, -.16619300E-02, 0.44259800E+01, 0.17582400E+01, 0.53038100E+00, 0.11201600E+01, -.37694700E-01, 0.40465600E+00, 0.17592900E+01, 0.11046800E+01, 0.24618700E+00, -.26537000E+01, 0.34372900E-01, -.57628300E-01, -.72752000E+00, 0.32192400E+00, -.39652200E+00, 0.24753400E+00, 0.10854500E+01, -.54280600E+00, -.76403200E+00, 0.37334600E-01, -.96865500E-01, 0.62723300E-01, 0.60168800E+00, 0.38368600E-01, -.11238100E+01, 0.61754400E+00, 0.24214300E+00, 0.19440300E+01, 0.87841700E-01, -.16740900E+01, 0.15914000E+00, -.21091300E+00, -.24864300E+00, 0.34818200E+00, 0.79802300E+00, -.35254600E+00, -.48581900E+01, -.40068200E+00, -.17607600E+00, 0.71550400E+00, 0.57354100E+00, 0.10897400E+00, -.46400800E+00, -.11289400E+00, 0.13087900E+01, -.12334400E-01, 0.42576100E+00, -.37429900E-01, -.41445900E+00, 0.10184300E+01, -.11392800E+01, -.96680400E-01, 0.47841700E-01, -.83386200E+00, 0.39599700E-01, -.44254900E+00, -.85965300E+00, -.11474900E+01, -.35322200E+01, 0.17618700E+01, -.32389400E+00, 0.16422300E+00, 0.42339800E+01, 0.77278200E-01, -.64088500E+00, -.90297500E-01, 0.25450800E+01, 0.67037100E+00, 0.28507900E+01, -.14136100E+00, -.53517100E+00, 0.31321100E+00, -.27097800E+01, 0.16439900E+01, 0.10315900E-01, -.41819800E+00, -.40145900E+01, -.14501300E+01, -.16434300E+00, 0.56940400E+02, -.65477800E+02, -.36308100E+02, 0.78428500E+00, 0.13689900E+03, 0.27057100E+03, -.16298400E+03, 0.11251400E+03, -.13406400E+03, -.15760500E+03, -.66827200E+02, -.78068700E+01, 0.22116800E+02, 0.84467900E+01, -.74130400E+02, 0.90437400E+02, -.86598800E+02, 0.31662400E+02, 0.65392200E+02, 0.42013800E+02, -.36207600E+02, -.85982100E+02, 0.17978400E+03, -.22039200E+02, -.10984300E+02, -.87539700E+02, 0.10927900E+03, 0.63317800E+02, -.71413800E+02, 0.80180000E+03, -.24319400E+02, 0.25601700E+02, 0.30308300E+01, -.50047500E+02, 0.15835200E+03, 0.12461400E+03, -.79262100E+02, 0.16370300E+03, 0.34375400E+02, 0.23005400E+02, 0.28885000E+02, 0.29879700E+02, -.27846700E+01, 0.81772000E+01, -.23116600E+01, -.42769600E+02, -.12347100E+02, 0.24638100E+02, 0.30830100E+02, 0.25532800E+01, 0.62775900E+01, -.15487200E+01, -.46178800E+02, -.43376200E+02, -.30842800E+02, 0.70279900E+01, 0.28565100E+02, 0.51278400E+01, 0.14579200E+02, 0.41789300E+02, -.70523200E+01, -.40647000E+02, -.13297300E+02, -.29747800E+02 },
        { -.88556900E+00, 0.63084200E-01, -.13072400E+00, -.15678400E-01, 0.61951300E+00, 0.14647900E+00, -.11156200E+00, 0.38577400E+00, -.53209400E-01, -.27396500E+00, 0.28845700E+00, 0.11039300E+00, 0.32039900E+00, -.22188500E-01, 0.87960200E-01, 0.24965500E+01, 0.51943800E+00, 0.35014300E+00, 0.31912600E+00, -.14893400E+00, -.62490200E+00, 0.42943200E-02, -.18095500E-01, 0.27869700E+00, -.34974400E-01, -.41674800E-01, -.10951700E+00, 0.73784600E-01, -.85609500E-01, -.88627000E-02, -.65598200E-02, -.49193200E-01, 0.70783500E-02, 0.25271200E+00, -.23541700E-02, -.41230400E-01, 0.34106100E-01, 0.91345500E-02, -.19406500E-01, -.59682700E-02, 0.18751200E+00, 0.71735900E-01, -.27932600E-01, 0.46873500E-01, -.98291300E-01, 0.19891400E+00, -.25396300E-01, 0.28509400E-01, 0.72802400E-01, 0.17367000E-01, 0.23997400E+00, -.88351800E-01, 0.20226700E+00, -.52906100E+00, 0.71508400E-01, -.26129700E+00, -.98324600E-01, 0.98369700E-03, 0.21193100E-01, -.16831200E+00, 0.79567100E-02, 0.26929400E+00, -.31234600E-01, -.56988900E-01, -.10127700E+00, -.64571200E-01, 0.18053300E+00, 0.47548100E-01, 0.17218400E+00, -.22393000E-03, 0.18141100E-01, 0.80275800E+00, -.11110400E+00, -.13102200E+00, -.33600600E-01, 0.74535600E-01, -.58858700E-01, -.70160100E-02, -.10848800E+00, -.30086000E-01, 0.20622000E-01, 0.30786700E-02, -.44375000E-01, -.90789800E-02, -.21741500E-01, -.94333100E-02, 0.20763400E+00, 0.88082600E-01, 0.23779300E-01, 0.62634800E-02, -.78992400E-01, 0.47992300E-03, 0.19867500E-01, -.12860000E-01, 0.43696800E-02, 0.19001000E+00, 0.27017700E-01, 0.32761500E-01, 0.31164500E-01, 0.36838800E-01, 0.63541800E-02, 0.19516900E-01, 0.28773300E-02, -.91261200E-01, -.15799300E-01, 0.35197300E+00, -.42829900E-01, 0.39379700E-01, -.41278500E-01, -.75313500E-01, 0.12052500E+00, -.13125100E-03, 0.36665300E+00, -.74601300E-02, -.40970100E-01, 0.18075800E+00, 0.61566600E-01, -.33682600E-01, -.24397000E+00, -.17317900E+00, -.92120200E-01, -.12508400E-01, -.36963000E-01, -.35301400E-01, -.78618700E-02, 0.47961700E-01, -.10101800E+00, 0.25130700E+00, 0.55600600E-02, 0.49564000E-01, -.14819900E+00, -.88198100E-01, -.57121700E-01, 0.10023900E+00, -.19997900E-02, -.86318100E-02, 0.22351900E+00, 0.75851000E-01, -.17605400E-01, -.17105000E+00, -.16046000E+00, -.61824700E-01, -.92673800E-01, -.30599700E-01, 0.19994100E-01, 0.41283800E-01, 0.53082500E-02, -.19387000E-02, -.22878600E-01, -.64681100E-01, 0.20831300E+00, 0.42331600E-01, -.10117800E-01, 0.18753100E+00, 0.72465400E-02, -.75634200E-01, 0.33858700E-02, 0.16312500E-04, 0.36150300E-01, -.17085300E-01, 0.24877100E-01, 0.65933600E-01, 0.58356100E-03, -.15659200E-01, -.11435200E+00, 0.92736700E-01, -.21028500E-01, -.21607500E+00, 0.61772800E-02, -.12673700E+00, -.11651200E-02, 0.37816400E-01, -.25770500E-01, -.51551500E-02, 0.80960800E-01, 0.13585500E-01, 0.40826100E-01, 0.50682000E-02, -.23257600E-01, -.33621100E-01, -.10535500E+00, 0.34752700E-01, 0.45508300E-02, -.29249300E-01, 0.12410900E-01, -.24554600E+00, -.34665300E-01, 0.58322900E-01, 0.24904100E-02, -.18553200E-01, 0.83350000E-01, -.15199300E-01, -.29556200E-01, 0.31614100E-02, 0.18090000E+00, -.40335300E-01, 0.33749400E-01, -.42129700E-01, 0.32591500E-01, 0.13480300E-02, 0.42747400E-01, 0.70043300E-02, -.61366600E-01, 0.10358800E-01, -.20031000E-01, -.57734600E-03, 0.43541900E-01, 0.84009500E-02, -.28302900E-01, 0.13281100E-02, 0.20126400E-02, 0.68423700E-01, 0.52309200E-02, -.72929000E-01, -.89516200E-01, -.24018800E-01, 0.97843500E-01, -.26477200E-01, 0.25511700E-01, 0.71872700E-02, 0.14398000E+00, -.16276900E-01, 0.52077900E-02, 0.29159500E-02, -.35026400E-01, -.23107500E-01, -.13991600E+00, 0.24115500E-02, -.68028800E-01, -.19699300E+00, 0.21955500E-01, -.16659300E-01, 0.15404900E-02, -.53295700E-03, -.41537800E-02, -.53866300E-02, -.23080000E-01, 0.26263300E-01, 0.66230500E+01, 0.81041600E+00, 0.69129700E+00, 0.72047700E+00, -.94399500E+00, 0.19438900E+01, 0.96656400E+00, 0.53095100E+00, 0.53755800E+01, 0.19648600E+01, 0.34307300E+00, -.92060500E+00, -.38064800E+01, 0.34576300E+01, -.21104300E+02, -.31907200E+00, 0.53626600E+00, 0.13253600E+02, 0.17101000E+00, 0.36661800E+01, 0.65312800E+01, -.82342700E+01, 0.81677400E+00, -.26791200E+00, 0.67994500E+01, -.34908800E+01, 0.13469100E+01, 0.14095500E+01, -.27793300E+02, -.93550200E+00, -.53800700E+01, -.59925200E+01, 0.38299500E+01, -.96386000E-02, -.67140100E+01, -.19673800E+01, -.56936900E+01, -.10799500E+01, -.11836000E+01, -.22319400E+01, -.21436600E+01, 0.29707700E+00, -.31143000E+00, 0.90193400E+00, 0.17827100E+01, 0.12746700E+01, -.11593700E+01, -.15657100E+01, -.13913900E+00, 0.48900900E+00, -.64399200E-01, 0.19922400E+01, 0.30841300E+01, 0.21231900E+01, 0.58381400E-01, -.21855800E+01, -.17782100E+00, 0.41070300E+00, -.30237300E+01, -.25668600E+01, 0.17606300E+01, 0.11599500E+01, 0.67281000E+00 },
        { 0.27697300E+01, 0.50402700E+00, -.72778600E+00, -.10886400E+01, -.21222600E+01, -.42335000E+00, -.77282900E+00, 0.21470400E+00, 0.26948800E-01, -.76620700E+00, -.22455900E+00, -.25681000E+00, -.20851500E+00, 0.32340000E-01, 0.27125700E+00, -.60039800E+01, -.26358600E+00, -.61571000E+00, -.12175100E+01, -.21613900E+00, 0.10779800E+01, 0.17714300E+00, -.64307700E-01, -.43606900E+00, 0.11328500E+00, 0.59452900E-01, 0.91974100E-01, -.47969000E+00, -.51261300E+00, 0.45258600E-01, 0.10844100E+00, -.72553700E+00, 0.46856100E+00, 0.50949200E+00, 0.35578900E-02, -.51280400E-01, -.30164700E-02, 0.26121700E-01, 0.51050600E-01, -.23714200E+00, 0.48792400E-01, 0.54424700E+00, -.26605600E-01, 0.10925900E+00, -.24514100E+00, 0.21543500E+00, -.41052400E-01, -.97829200E-02, 0.95888800E-01, 0.12824000E-01, 0.10603100E+00, -.32876600E+00, -.31319800E+00, 0.38532800E+00, 0.10359400E+00, -.62225400E+00, -.29613500E+00, 0.66503600E-01, -.23503700E-01, -.27353000E+00, 0.14838300E+00, -.68488000E+00, -.12553600E+00, 0.35164600E+00, 0.12048600E+00, 0.29616800E+00, 0.39600400E+00, -.57304700E-01, 0.23192700E+00, 0.32136300E-02, 0.33939200E-01, 0.13632100E+00, -.59422500E+00, -.82367900E+00, 0.32193700E+00, 0.15576900E-02, 0.12339700E-02, -.49201100E+00, 0.10101000E+00, -.10559100E-02, 0.78317700E-02, -.12564000E-02, -.57890900E-01, -.35188800E-01, -.16879400E-01, 0.16131900E-01, 0.60172200E-01, -.19151700E-01, -.18461200E+00, -.43753400E-01, 0.17020500E+00, -.12914900E-02, 0.22042600E-01, 0.22159100E-02, -.37628100E+00, -.24291800E-01, -.73920500E-01, 0.29757000E-01, 0.95753300E-02, -.21897100E-01, -.37857300E-01, 0.84988800E-01, -.22385800E-01, 0.17101700E+00, -.91817400E-01, -.21788900E+01, 0.13599400E+00, -.40406100E+00, -.22026000E-01, 0.55344300E+00, 0.67306100E-01, -.21174000E-03, 0.32887100E+00, -.92353100E-02, -.15072100E+00, 0.92826500E-02, 0.11429100E+00, 0.50376000E-01, -.24388600E+00, 0.99309800E-02, -.44410600E-01, 0.57687700E-02, 0.16695900E-01, -.61018300E-01, 0.10439700E-01, -.91809500E-01, -.26151300E-01, -.76673900E-01, -.10668400E-01, 0.82180400E-01, -.19699400E+00, -.13255400E+00, -.31735900E+00, 0.22274500E+00, -.55973300E-01, -.12129300E-01, 0.20414900E+00, 0.12129100E+00, 0.10185800E-01, -.40852600E+00, -.16415800E-02, -.13638100E+00, 0.87882700E-01, -.24145300E+00, 0.39137400E-02, 0.27128900E-01, -.16485700E-01, 0.55682600E-01, -.15548900E-01, -.58062600E-01, -.86781200E+00, -.24525700E+00, 0.70420800E-01, -.23651500E+00, 0.19391800E-01, 0.11310300E+00, -.36034000E-01, -.10074000E-02, -.31193700E+00, -.50915000E-01, 0.84817000E-01, 0.45722700E-01, -.14099800E+00, -.64035200E-01, -.56879500E+00, 0.14456800E+00, 0.27205900E-01, -.70705200E-01, -.48884100E-02, -.15335900E+00, 0.14719700E+00, -.47055300E-01, -.31647000E-01, 0.65237300E-01, 0.18674900E+00, 0.83235700E-01, -.10908200E+00, 0.28129800E-02, -.16979700E+00, 0.25740400E-02, -.91994800E-01, -.26552000E+00, 0.35575000E+00, 0.20105200E+00, -.50524900E-01, -.26226900E-01, 0.78000400E-01, -.57978600E-01, 0.54925900E-02, 0.19367000E+00, 0.36381300E+00, -.13461400E-01, 0.97098500E-02, -.10474100E+00, 0.10965200E+01, 0.92217500E-01, -.27944000E-01, 0.16595700E+00, -.12238500E-01, 0.44454500E-01, 0.17373600E-01, 0.12648800E-01, 0.17916000E+00, -.76266100E-01, 0.36374200E-01, 0.28331800E-01, 0.66159700E-02, 0.12480700E+00, -.56838800E-01, 0.13270800E-01, -.15630900E-01, -.21304200E+00, 0.56060500E-02, -.55630600E+00, -.92467300E-01, 0.18179800E-01, 0.27100000E+00, -.87950600E-01, 0.58733800E-01, -.11707900E-02, 0.60075000E+00, -.21752800E-01, -.76363100E-01, 0.43951800E-02, 0.56299300E-01, 0.25404300E+00, 0.13236100E-01, -.16380600E+00, 0.57990400E+00, 0.51746500E+00, -.90608800E-01, 0.43237500E+00, -.19510600E-02, -.39022100E-01, -.66150100E-01, -.18750300E+00, 0.19725100E-01, -.21884700E-01, 0.61480200E+00, 0.77740700E+01, -.26512500E+01, 0.10304900E+02, -.58658700E+01, 0.11695300E+01, 0.24975900E+01, 0.28309100E+01, 0.33508100E+01, 0.39411600E+01, -.92243700E+00, 0.53597200E+01, 0.12097000E+00, 0.34318800E+01, 0.15275200E+02, 0.22432300E+02, -.11650000E+02, -.49682100E+02, -.11374900E+02, -.91130900E+00, -.11815500E+02, 0.95625000E+01, 0.24034800E+01, -.20908300E+00, -.13127000E+02, -.16544400E+02, -.21953500E+02, 0.92371900E+01, 0.40884800E+01, 0.11431000E+02, 0.23710000E+02, 0.23230700E+01, 0.40496200E+01, 0.19174600E+01, 0.13412200E+02, 0.26699100E+01, 0.17196800E+02, -.45384800E-01, 0.50935200E+00, 0.61523700E+01, 0.67083900E+01, -.22337100E+01, 0.17431600E+01, -.72712100E-01, 0.17757100E+01, -.10298200E+01, 0.92006700E+00, -.85141400E+00, -.15394900E+01, -.13194200E+00, 0.22444800E+01, 0.17501600E+01, 0.41087500E+01, -.63230200E+01, 0.12622200E+01, 0.65234700E+01, 0.17266000E+01, 0.12605900E+01, -.43288200E+01, -.89888800E+01, 0.10293100E+01, 0.25234200E+00, -.11827900E+01 },
        { 0.21585300E+01, 0.27987700E+00, -.12433000E+01, -.10663900E+01, -.11866700E+01, -.30008800E+00, -.61589300E+00, 0.21633600E+01, 0.21378800E-01, -.26656600E+00, 0.25736200E+00, -.28885700E-01, -.57278600E-01, 0.31312800E-01, 0.20543100E+00, -.77612200E+01, -.20124000E+01, -.43674600E+00, -.70565600E+00, -.25173200E+00, 0.25193100E+00, 0.28362900E+00, 0.37093300E-01, -.64502100E-01, 0.13094800E+00, 0.54215600E-01, 0.41231800E+00, 0.32667300E+00, -.96748100E+00, 0.21637300E-01, 0.77876300E-01, 0.10122400E+00, 0.44329500E+00, -.63087100E+00, 0.88990600E-02, 0.25664500E-01, -.10811500E-01, -.55296700E+00, -.28061700E-01, -.42988300E+00, 0.18242600E+00, 0.24199800E+00, 0.45889100E-01, 0.16203400E+00, -.15509500E+00, -.27573300E-01, -.13283900E-01, -.12816300E-02, -.60244600E+00, 0.24051000E-01, 0.22377800E+00, 0.63616600E+00, -.30996100E+00, 0.77457100E+00, 0.23032900E+00, -.54874100E+00, -.18617000E+00, 0.41900200E-01, -.36867800E-01, -.38434500E+00, 0.46963900E-01, -.82783200E+00, -.27175300E+00, 0.26851900E+00, -.70284000E-01, 0.15758400E+00, 0.50126000E+00, 0.70508900E-02, -.37214200E-01, 0.45811400E-02, 0.11523700E-01, -.30114500E+00, -.12890100E+01, -.17299200E+01, 0.83298500E-01, -.10987800E+01, 0.17177400E+00, -.37787900E+00, -.13778200E+00, -.34093900E-01, -.28693600E-01, 0.96088800E-01, 0.10593000E+00, 0.20594900E+00, -.62241000E-01, -.16953900E+00, -.14730100E+00, -.12495900E+00, -.10916400E+00, -.91203400E-02, 0.41155000E-01, -.96741600E-03, 0.17401700E+00, -.62045000E-01, -.51553400E+00, -.78429800E+00, -.39955000E-01, 0.13190900E-01, -.11596500E-01, -.35349600E+00, -.53627700E-01, -.50695700E-01, -.46438500E-02, 0.15643200E+00, -.32556200E-01, 0.21857800E+01, 0.31240600E+00, -.67320700E-01, 0.83728800E-01, 0.10116800E+00, -.14829600E+00, -.12424100E-01, -.40003500E+00, 0.96640500E-02, 0.23173500E+00, -.55805700E-01, -.35865800E-02, 0.85051800E-01, -.36945400E+00, 0.11718000E+01, -.12658100E+00, -.27031400E-01, 0.14848300E+00, -.22123300E+00, 0.45625600E-02, -.11378300E+00, -.11611800E+00, 0.18849300E+00, -.17747300E+00, -.44836900E-01, -.74912100E-01, 0.12045800E+00, 0.43590600E+00, -.40469000E+00, -.55859100E-02, -.11742400E-02, 0.13797900E+00, -.21854000E-01, 0.60768100E-03, -.27071700E-01, -.46080900E-01, -.97621500E-01, -.38034100E+00, -.23823800E+00, -.34350200E-01, 0.21448100E-02, -.12417700E-01, 0.37384000E+00, 0.21437800E-01, -.20323300E+00, 0.14919400E+01, -.10843400E-01, -.30502400E-01, -.14055300E+00, -.48213100E-01, -.91535400E-01, 0.32140000E-01, -.12280100E-02, -.10635900E+01, -.26402800E+00, -.68997200E-01, -.10388300E+00, -.10721700E-01, -.15504300E+00, 0.12823600E+00, -.15498100E+00, 0.17151100E-01, 0.81782700E+00, -.18563300E-02, -.34590500E-01, -.16892400E-02, 0.26232100E-01, 0.21082800E-02, 0.26644200E-02, -.63900700E-01, -.53901400E-01, -.27533800E-02, 0.67586100E-02, 0.62923200E-01, 0.29030400E-01, 0.14360100E+00, 0.10839500E+00, 0.98833900E-01, -.70807400E-01, -.44388700E-01, 0.68529800E-01, 0.13180500E-01, 0.50793700E-02, 0.10778800E-01, -.37231500E-01, -.55496500E-01, -.41984100E-01, -.61388900E-01, 0.23505600E-01, -.31774500E+00, 0.23278800E-01, 0.85392300E-01, -.93426700E-01, 0.64710000E-01, -.27483800E-01, 0.20591000E-01, -.40772300E-02, -.78674600E-01, 0.11674200E+00, 0.17598700E+00, 0.16978500E-01, -.24562300E-01, 0.46334700E-01, 0.12859900E-01, -.24022900E-01, 0.62108100E-02, 0.74943300E-01, 0.58365000E-02, 0.20241500E+00, -.99276600E-01, -.37057700E-01, -.44563600E-01, 0.11946700E+00, -.66617000E-01, 0.44732400E-01, 0.79431600E+00, 0.14022900E-01, -.15190700E-01, -.16958300E-01, -.31685500E-01, 0.28419400E+00, 0.64160600E-01, 0.53297200E-01, 0.66186100E-01, -.14886600E+00, -.87973900E-01, 0.33500400E-01, -.13644700E-02, -.33419000E-02, -.15495700E+00, -.95119000E-01, 0.91741500E-02, 0.63628000E-01, 0.78448800E+00, 0.65526200E+00, 0.39447700E+01, -.29537900E+02, -.13938300E+02, 0.75887500E+01, -.29064400E-01, 0.66814400E+01, 0.25543600E+00, 0.20993800E+01, -.39856200E+00, -.75817100E+01, 0.24748400E+01, 0.11743900E+01, 0.15702000E+02, -.81497700E+01, 0.44081500E+01, 0.28330500E+02, 0.42287900E+01, -.23442800E+01, 0.60624800E+01, -.83162300E+01, -.81930400E+00, -.24568900E+01, 0.60905800E+01, 0.42079900E+01, 0.12546700E+01, 0.56284500E+00, -.10182000E+02, -.10138000E+01, -.40449700E+01, 0.81271200E+01, -.19083100E+01, -.63961000E+01, -.58189800E+01, 0.63117800E+01, -.34108600E+02, -.21646000E+01, -.47320200E+00, -.22031900E+01, -.25890800E+01, 0.13113300E+01, -.12872100E+01, -.20973800E+01, -.72870100E-01, -.33355400E+00, -.95996700E+00, 0.37470000E+00, 0.60145700E+00, -.14336700E+01, -.13329900E+01, -.96423500E-01, -.22420500E+01, 0.25043600E+01, -.24393300E+01, -.23640200E+01, -.12027100E+01, -.20395600E+01, 0.23355900E+01, 0.75946200E+01, -.12091200E+00, -.12407500E+01, 0.26511800E+01 },
        { 0.41513900E+01, -.18006900E+00, -.24616500E+01, -.94239700E+00, -.19172500E+01, -.93233400E+00, -.73321800E+00, 0.30973900E+01, 0.11697300E+00, 0.83927600E+00, 0.31035400E+00, -.11586600E+00, -.13129600E+00, 0.33460200E+00, -.32205300E+00, -.41114100E+01, 0.31980600E+01, 0.12955800E+01, -.45752100E+00, 0.18781400E+00, -.51778800E+00, -.23121400E+00, -.22794600E-01, -.47788500E+00, 0.16559100E-01, 0.11275400E+00, 0.41591100E+00, 0.55434400E+00, -.85440400E+00, 0.37750000E-01, 0.67710600E+00, 0.47301500E+00, -.21760700E+00, 0.19866300E+01, 0.32466100E-01, 0.25977300E+00, -.21147800E-01, -.64501800E+00, 0.17887300E+00, -.63513700E+00, -.68961400E+00, 0.40117800E+00, 0.16582100E+00, 0.81454100E-01, -.14480700E+00, -.41961900E+00, 0.10860200E-01, -.44496500E-01, -.12252500E+01, -.38037400E-01, -.71201000E+00, 0.72819100E+00, -.65233300E+00, 0.11221200E+01, -.19566300E+00, 0.34432600E+00, -.29197700E-01, -.10138500E+00, -.48868300E-01, -.14772400E+00, 0.10830000E+00, -.11773600E+01, 0.19383300E+00, 0.26375000E+00, 0.56473900E+00, 0.44030900E+00, -.47315500E+00, -.15339300E+00, -.22729700E+00, -.60551700E-02, -.28049900E-01, -.10390100E+01, 0.17746100E+00, 0.14676400E+01, 0.10939400E-01, -.95767600E-01, -.82920900E-01, 0.46602900E+00, 0.15279200E+00, 0.56768500E-01, 0.39423500E-01, -.17051800E-01, -.95840300E-01, -.13555500E+00, 0.13864700E+00, 0.10481000E+00, -.36219700E+00, 0.12023300E+00, -.27965000E+00, -.58917700E-01, -.13678500E+00, -.14479100E-02, -.10316800E+00, -.31223600E-01, -.49775500E+00, -.53132900E-01, -.40172200E-01, 0.63753800E+00, -.13149000E+00, 0.44435800E+00, -.99972400E-01, 0.99511400E-01, -.28694500E-02, -.60144100E-01, -.36353100E-01, -.15741900E+01, 0.45920600E-01, -.12226000E+00, 0.82806200E-01, 0.72034900E-01, -.10809200E+00, 0.32167800E-01, 0.97593200E+00, -.35976300E-02, -.56922600E+00, -.30787800E-01, -.36480300E-01, 0.44874700E+00, 0.16434700E+00, -.76004300E-01, 0.24676800E+00, -.16439500E-02, -.12166200E+00, 0.15484700E+00, -.36803700E-01, -.25565200E+00, 0.74467200E-01, -.75171600E+00, 0.32122700E+00, 0.15110100E+00, -.19507300E+00, -.51567900E+00, -.11990600E+01, 0.95417400E+00, -.20062900E+00, -.46869700E-01, 0.64562500E+00, 0.49853800E+00, -.44590900E-01, -.16873400E+01, -.16782600E+00, -.26663400E+00, 0.22504100E+00, -.62612100E+00, -.16076400E-01, 0.16792900E+00, -.16423900E-01, -.14505200E+00, 0.11704100E+00, 0.10622800E-01, 0.13531100E+01, 0.39618800E-01, 0.13538500E+00, 0.37723100E+00, -.55915200E-01, 0.11945200E+01, -.19581200E-01, -.14695300E-02, -.95558900E+00, 0.25313100E-01, 0.17524300E+00, -.28048700E+00, -.75489200E-01, -.42647100E+00, -.37891900E+00, -.26209000E+00, 0.73524200E-01, 0.25248800E+00, -.10525800E-01, -.63328700E-01, 0.20243300E+00, -.14491600E+00, -.75905000E-01, 0.17711500E+00, 0.31439000E+00, -.16024600E-01, -.15470700E-01, -.95150400E-02, 0.20620000E+00, 0.82108200E-02, -.19772700E+00, -.33442300E+00, 0.85317600E+00, -.27390100E+00, -.12315100E+00, 0.29657300E+00, -.25854200E-01, 0.40824700E+00, -.14549800E-01, 0.23494800E+00, 0.33314200E+00, -.21159300E+00, -.68567100E-01, -.58345000E-01, 0.10943400E+01, 0.20100200E+00, 0.34393400E+00, 0.19584200E+00, -.31017300E+00, 0.86874400E-01, -.60539500E-01, 0.34879900E-01, 0.54313900E+00, 0.73168800E+00, 0.35436600E+00, -.11808500E+00, 0.74384400E-02, -.49214300E+00, 0.36151400E+00, 0.11751400E+00, -.28480700E-01, -.10579200E+00, -.69644900E-01, -.80262100E+00, -.27295000E+00, -.35895800E-01, -.10062100E+00, -.92548500E+00, 0.34219400E+00, -.40209200E-01, -.62222100E+00, -.26657900E-01, 0.29582600E-01, 0.15480600E-02, -.50418200E+00, 0.96775500E-01, 0.68175100E+00, -.16385900E+00, 0.49568800E+00, 0.12897000E+01, -.10390400E+00, 0.16125100E+00, 0.34056000E-02, 0.48015800E-01, -.71912500E+00, 0.28939200E-01, -.58118800E-02, 0.13748200E+00, 0.47112000E+00, 0.11660700E+01, 0.49752000E-01, -.64385300E+02, -.62970600E+02, 0.33466600E+02, -.14226300E+02, 0.30766200E+02, 0.18822300E+02, 0.40665700E+01, 0.14707100E+02, 0.98683300E+01, 0.16697100E+02, 0.33240400E+01, 0.34874700E+02, -.41696100E+01, 0.49511400E+01, -.47170500E+02, 0.22955200E+01, 0.16022200E+01, 0.59668400E+01, -.12185800E+02, -.10317100E+02, -.38042600E+01, 0.92307900E+01, 0.85445200E+01, 0.24601800E+02, -.11557500E+02, -.98601300E+02, -.13454600E+02, -.28519700E+02, 0.22561200E+02, -.24102200E+02, -.75714800E+02, -.39037700E+02, 0.24483400E+02, -.81107400E+02, -.28617000E+00, 0.15762000E+01, -.86061600E+01, -.98407200E+01, 0.22388200E+01, -.14013800E+01, -.10962800E+01, 0.85312000E+00, -.89758900E+00, 0.49709900E+00, 0.18687700E+01, 0.86302100E+00, -.12877600E+01, -.23817000E+01, 0.88911600E+00, -.39505100E+01, 0.97487900E+01, -.89933800E+00, -.91139800E+01, -.11088300E+01, -.45267800E+01, 0.42390400E+01, 0.76110400E+01, -.11068000E+00, -.12527600E+01, 0.43848600E+01 },
        { 0.43508100E+01, 0.13566900E+01, -.91196100E+00, -.23570200E+01, -.26121300E+01, -.13391900E+01, -.89437100E+00, 0.66365000E+00, 0.30954500E+00, 0.96702800E+00, -.61094500E+00, -.50006100E+00, -.80662200E+00, 0.41053700E-01, 0.93438700E-01, -.61982100E+01, -.18808100E+01, -.51242400E+00, -.97102800E+00, 0.54364000E+00, 0.44892900E+00, -.43203000E+00, -.41268700E-02, -.17151300E+01, -.44422200E-01, 0.53685200E-01, 0.65281800E-01, -.14286500E+01, 0.35471900E+00, -.44506100E-01, 0.17782600E+00, 0.14099900E+00, -.18122900E+00, -.75577300E+00, -.13622000E-01, 0.91343000E-01, -.29468900E-01, -.30721600E+00, 0.23715600E+00, 0.17305800E-01, -.17233400E+01, -.40072400E+00, 0.97264500E-01, -.35198500E+00, 0.45955500E+00, 0.23557500E+00, -.53466200E-01, 0.33843900E-02, 0.12185400E+01, 0.11707500E-02, 0.53710700E+00, 0.92239600E-01, -.52828500E+00, 0.23735600E+01, -.69801700E-02, -.22124100E+01, -.63736400E+00, 0.13622100E+00, -.36201900E-01, 0.30160900E+00, -.13038100E+00, -.21328000E+00, -.33573400E+00, 0.60718500E+00, 0.26273000E-01, 0.73705500E+00, 0.80828900E+00, -.22498000E+00, -.10475000E+01, 0.95127300E-02, -.41481000E-01, -.66156600E+01, -.15755000E+01, -.17991600E+01, 0.17942600E+01, 0.43473000E+00, 0.18737900E+00, -.81518200E+00, 0.12618400E+01, 0.62348700E-01, -.13733100E+00, -.54603000E-01, 0.65303100E-01, -.32158600E+00, -.17071200E+00, 0.33700200E+00, -.47115300E-01, -.50408800E+00, 0.50115300E+00, -.18909100E-01, 0.13235400E+01, 0.41542400E-02, -.11720100E+00, 0.61466100E-01, -.79669700E+00, -.76718400E+00, -.50767000E+00, -.20268800E+00, 0.78535400E-01, 0.31776100E+00, -.47340200E-01, -.19697100E+00, 0.73428200E-02, 0.79700400E+00, -.43715300E+00, -.20330100E+01, 0.39321800E+00, -.67569600E+00, -.36201200E-01, 0.36958300E+00, 0.38835000E+00, 0.71970800E-02, 0.24170600E+00, -.43155100E-02, -.75190100E-02, -.15126400E+00, 0.23280400E+00, -.11445600E+00, -.11955700E+01, 0.34885100E+00, -.72377900E+00, 0.30531400E-01, 0.95056700E-01, 0.33909700E+00, 0.17485400E-01, 0.19459800E+00, -.40136100E+00, -.14380100E+01, 0.11247200E+01, 0.44252200E+00, -.59099800E+00, 0.12421600E+00, 0.50114200E+00, -.43515900E+00, 0.45935400E+00, 0.31484700E-01, -.17575700E+01, -.74332700E-02, 0.38078400E+00, 0.46661900E+00, 0.73661200E+00, -.59038900E+00, 0.10099200E+01, 0.22720000E+00, -.59172600E-02, 0.39747600E+00, -.35838300E-01, 0.49735100E+00, 0.88720100E-01, -.76839000E-01, -.43206700E+00, -.32422400E+00, -.14885400E+00, 0.12588500E+01, 0.82167200E-01, 0.38882800E+00, 0.30140300E+00, -.19655700E-02, 0.69028500E+00, 0.29772500E+00, 0.58211400E-01, -.50619200E-01, -.13214500E+00, -.23003500E+00, -.29981500E+00, -.36690800E+00, -.15305900E-01, 0.62597900E+00, -.86610800E-02, -.13128700E+00, 0.17952800E+00, -.11418700E+00, 0.16552300E+00, -.70999500E-01, -.35071100E+00, 0.23128000E+00, -.11743300E-01, 0.24075400E-02, 0.79437000E-01, -.55258900E-01, 0.14522800E+00, 0.35622900E+00, 0.66174900E+00, 0.27162300E+00, -.18594700E+00, 0.65760400E+00, 0.20227000E+00, 0.82701300E-01, -.30504700E-01, 0.11814900E+00, 0.35339300E-01, -.14020800E+00, -.27671500E+00, 0.18787100E+00, 0.89801800E+00, -.66385300E-01, -.34065200E+00, 0.17734200E-01, 0.27619300E+00, -.11256500E-01, 0.16091700E+00, 0.40735500E-01, -.10571600E+01, 0.11090700E+01, 0.33157000E+00, -.11434500E+00, -.34749100E-01, -.47259100E+00, 0.20477800E+00, 0.32067600E-01, 0.93017200E-02, 0.26856000E+00, 0.22987600E-02, 0.10374400E+01, 0.32044100E+00, 0.49939300E+00, 0.11378700E+01, -.78724900E+00, -.37248500E+00, -.35297300E+00, 0.30676200E+01, -.12391200E+00, 0.83533700E-01, -.35923600E-01, -.69252300E+00, -.39467500E-01, -.43845400E+00, 0.15686700E+00, -.22488600E+00, -.82978100E+00, -.18862100E+00, -.34082800E+00, 0.23936800E-01, -.38793900E-01, -.80627000E+00, -.59869600E+00, -.89405500E-01, 0.14490500E+00, -.34067500E+01, -.13047800E+01, 0.59133800E+00, -.42777300E+00, -.69491900E+02, 0.43261200E+02, 0.47903400E+02, 0.35132700E+02, 0.72443400E+02, 0.56258500E+02, -.27624000E+02, -.18231100E+02, -.47071400E+01, 0.59210400E+02, -.13068200E+03, 0.96007200E+01, 0.10612700E+01, 0.25399500E+02, -.49859200E+01, 0.29884900E+02, 0.44017000E+02, -.33994500E+02, -.30655600E+02, -.50670700E+02, 0.55537800E+02, -.38999000E+02, -.10718100E+03, 0.75102700E+02, -.21259900E+03, 0.51960700E+02, 0.52476400E+02, 0.16755700E+02, 0.29807500E+02, 0.64883100E+01, 0.83612100E+01, 0.47284600E+02, -.36660500E+01, -.14985800E+02, -.22022000E+01, -.17361100E+02, -.15720500E+02, -.63699900E+01, 0.44338200E+01, -.23107700E+01, 0.12812900E+02, -.80123700E+00, 0.69862200E+00, -.36034700E+01, -.12220500E+02, -.26836200E+01, 0.79620600E+01, 0.13286500E+02, 0.26473300E+02, 0.15735200E+02, -.28490600E+01, -.16372800E+02, 0.54708800E+01, 0.26232500E+01, -.26255400E+02, -.19915900E+02, 0.10723600E+02, 0.14863700E+01, 0.76050700E+01 },
        { -.13504200E+02, 0.47457100E+01, 0.37557000E+01, -.11804600E+01, 0.26065100E+01, -.21752800E+01, -.63251100E+00, -.58028100E+01, -.24486900E+01, 0.13211400E+01, -.79356800E-01, 0.22451800E+00, 0.38735600E+01, -.54242300E+00, -.12630300E+01, 0.15887400E+02, 0.14751000E+02, 0.27249300E+01, 0.66727100E+01, 0.17300700E+01, -.56892100E+01, -.33007000E+01, -.98567500E+00, -.24928700E+01, -.25599600E+01, 0.48535800E-01, 0.10427800E+01, -.19474900E+01, -.46398900E+01, 0.53679800E-01, 0.13311700E+01, 0.98426200E+00, -.29929900E+01, 0.55496800E+01, 0.27428600E+00, 0.42036400E+00, 0.14538400E+00, 0.32499700E+01, 0.14043600E+01, 0.59513000E+00, 0.20924200E+01, -.11325400E+01, 0.31533300E-02, -.26028600E+00, 0.12107900E+01, 0.11451700E+00, 0.50419400E-01, 0.62924700E-01, 0.40102600E+00, 0.24330500E-01, 0.87677800E+00, -.23475000E+01, 0.17056500E+01, -.23559800E+00, 0.43815200E-01, 0.46332100E+00, 0.75639800E+00, 0.95684400E-01, 0.74297600E-01, 0.10345800E+01, -.34895300E+00, 0.27786300E+01, 0.15893100E+00, -.89298800E+00, -.11696800E+01, -.13264700E+01, -.16182500E+01, -.15793600E-01, -.10711500E+01, 0.11225600E-02, 0.67577700E-01, -.53780700E+01, 0.16621800E+01, -.20576200E+00, 0.58339200E-01, 0.93488700E+00, -.23829800E-01, 0.22818600E+01, -.78753700E+00, -.14583000E+00, -.19041000E+00, 0.15566500E-01, 0.64933800E+00, -.12287800E+00, 0.10286900E+00, 0.53094000E+00, 0.13263100E+00, 0.16376500E+00, 0.12268900E+01, -.50645500E-02, -.83039700E+00, 0.16436800E-02, 0.66077800E+00, 0.72426000E+00, 0.25993800E+01, 0.30974600E+01, 0.78287500E+00, -.13471700E+00, 0.59287400E+00, 0.10673100E+01, -.24142700E+00, -.28760900E-01, 0.61179700E-01, -.13332800E+01, 0.41724800E+00, -.95620500E+01, -.50852300E+00, 0.79172000E+00, -.78685700E-01, 0.26358600E+00, 0.63068700E+00, -.35716200E-01, 0.17968300E+01, 0.85856500E-01, 0.26130100E+00, 0.97440600E+00, -.16234300E+00, -.32600800E+00, -.18982700E+01, -.10438800E+00, -.56598500E-01, 0.49133800E-01, -.71674100E+00, -.19696100E+00, 0.64721900E-01, -.68933400E+00, -.10766100E+01, 0.46257900E+00, 0.61570000E+00, 0.14859300E+00, -.12305900E+01, -.14984900E+00, 0.21262300E-01, -.12593500E+00, -.14969200E+00, -.31631600E-01, 0.99442700E+00, -.66280500E+00, 0.29386200E-01, 0.10064800E+01, -.68178900E+00, -.28365000E+00, 0.59033100E+00, -.28959300E+00, -.12345900E+00, 0.11428200E+01, 0.94730100E-01, -.72538200E-01, -.52799500E-01, 0.82967400E-01, 0.38810500E+01, 0.11988900E+01, 0.18921300E+00, 0.18345400E+01, -.10523000E+00, 0.31085300E+00, 0.35412800E+00, -.11866100E-02, 0.22180800E+01, 0.21696900E+00, 0.16800700E-01, -.10882200E+00, 0.37399400E-01, 0.28195200E+00, -.11985300E+00, 0.59516700E+00, -.29166800E-01, -.12263000E+00, 0.25818000E-02, -.70772500E+00, -.57478600E-01, 0.40835700E-01, 0.50882500E-01, -.25027300E+00, -.94807900E+00, 0.17545800E+00, 0.12707500E+01, 0.23686200E-01, 0.73228500E+00, -.68074400E-01, 0.37314400E+00, -.30271800E+00, -.32171400E+00, -.59244500E+00, 0.36319700E+00, -.31150000E+00, -.29113400E+00, 0.81958000E+00, 0.80775800E-01, 0.24164100E+00, -.19597600E+00, 0.16527200E+00, -.15478400E+00, -.42146300E+00, -.81930400E-01, 0.24259000E+00, 0.84802900E+00, -.26305500E+00, 0.59843300E+00, -.98640900E-02, 0.13562500E+00, -.61807800E-01, -.12374800E+01, 0.22926000E+00, 0.33325800E-01, 0.22756700E+00, -.30641600E+00, -.34390900E-02, -.43569800E-01, -.20961200E+00, -.26351000E+00, 0.10910300E+01, 0.12283600E+00, 0.25876200E+01, 0.98511300E+00, 0.14811600E-01, -.94811900E-01, 0.34723600E+00, 0.14622700E+00, -.41980100E+00, 0.52227500E+00, -.39811700E+00, -.10545900E+00, 0.24498500E-01, 0.76121900E-01, 0.37672400E-01, -.22864000E+00, -.14704700E+00, -.37283200E+00, -.12676200E+01, 0.34942400E+00, 0.28673800E-01, -.10099800E-01, -.44077500E-01, 0.43142500E+00, -.15679800E+00, -.52375600E-01, -.11029200E+00, 0.71089700E+00, 0.11326400E+00, -.86306000E+00, 0.21679500E+00, 0.12614400E+00, 0.85795600E+02, -.13473300E+02, -.62264000E-01, -.12920400E+02, 0.10844300E+01, -.14220000E+02, -.72337200E+01, 0.29172000E+02, -.13445400E+02, -.51982400E+02, 0.39375900E+01, 0.17413000E+01, 0.91523700E+02, -.18633500E+01, -.12826400E+02, -.14677800E+02, 0.11999800E+02, -.45061100E+01, -.26452700E+02, -.13940600E+02, 0.53857000E+01, 0.36724600E+01, 0.11289500E+02, 0.13819900E+03, -.15967000E+00, 0.29427000E+02, 0.18806900E+02, 0.86548800E+01, 0.65389100E+02, 0.39477700E+02, 0.57443900E+01, 0.35108100E+02, -.37631300E+00, -.60113000E+00, 0.10580400E+02, 0.10945800E+02, 0.16389800E+01, -.14282000E+01, -.96871500E+01, -.53274800E+01, -.27869600E+01, 0.11808700E+01, 0.30020400E+01, 0.12216800E+01, -.62655800E+01, -.17813600E+01, -.61132500E+01, -.12027600E+02, -.11235800E+02, -.11108000E+02, 0.10504500E+02, -.19314500E+01, -.14991400E+01, 0.12315800E+02, 0.14194800E+02, -.13191400E+01, -.99307700E+01, 0.13416300E+00 },
        { -.20294500E+02, -.44419100E+01, 0.47539500E+01, 0.70932100E+01, 0.80246700E+01, 0.60509200E+01, 0.70985500E+01, -.91036400E+01, -.10668500E+01, -.19073100E+01, 0.11672800E+01, 0.18067000E+01, 0.20925000E+01, -.97004600E+00, -.14650100E+01, 0.35717300E+02, -.31071600E+01, 0.97713200E+00, 0.10394200E+02, 0.13824300E+01, -.49930600E+01, -.48434300E+00, 0.10652400E+00, 0.18692400E+01, -.49458300E+00, -.19940800E+00, -.36668500E+00, 0.11372600E+01, -.69106400E+00, 0.32026600E-01, -.12030800E+01, 0.14643200E+00, 0.48869800E+00, 0.33830800E+01, -.56660400E-01, -.12313000E+00, 0.10024200E+00, -.89337700E+00, -.14445100E+00, -.89622600E+00, 0.57657200E+01, 0.92516400E+00, -.13146800E+00, 0.31344100E+00, -.16030400E+01, 0.54430700E+00, 0.87810100E-02, -.11607800E-01, -.23742700E+01, 0.60623800E+00, -.10646200E+01, 0.36823900E+01, -.47825100E+00, 0.60952500E+01, 0.26798900E+00, 0.37818800E+01, 0.31702400E+01, -.40605700E+00, -.74547900E-01, 0.94247100E+00, -.87698500E-01, -.14398800E+01, 0.11279800E+01, -.26626700E-02, 0.10145100E+01, -.91767700E+00, 0.32668600E+01, 0.89804600E+00, -.42221100E+00, -.18207800E-01, -.24932000E+00, 0.13023800E+02, -.99874900E-01, -.97790600E+01, -.34545000E+01, -.18843300E+01, 0.71601600E+00, -.38810300E+01, -.11725800E+01, 0.13210600E-01, -.98218200E-01, 0.15263300E+00, 0.37767600E+00, 0.15039700E+01, -.80690600E+00, -.73122300E+00, -.88081900E-01, 0.31324700E+00, -.10975900E+01, 0.35974600E+00, -.25884300E+01, 0.16109000E+00, 0.27555300E+00, -.23347900E+00, 0.14953500E+01, -.37258300E+01, 0.15237700E+01, -.79314600E+00, -.64481700E+00, -.10718200E+01, 0.11724100E+00, -.10824300E+00, 0.19082800E-01, 0.98621300E+00, 0.39411100E+00, 0.28043000E+02, -.11172000E+01, 0.24805000E+01, -.54458200E-03, -.37824400E+01, 0.38148300E+00, -.38880500E-01, -.16519000E+01, -.96496000E-01, -.91572500E+00, 0.15430700E+00, -.69896400E+00, 0.85220000E+00, 0.46615900E+00, -.57783200E+01, -.20208600E+01, 0.15362800E+00, -.40763100E+00, 0.70876500E+00, -.14464600E-01, 0.19563600E+01, 0.17887100E+01, 0.21147700E+01, 0.53432700E+00, -.60404100E+00, 0.12624400E+01, 0.17137700E+01, 0.13481800E+01, -.19385200E+01, 0.33894500E+00, 0.20202800E+00, -.32147000E+01, -.21424600E+00, -.18629000E+00, 0.15298700E+01, 0.27036200E+01, 0.10943800E+01, -.22008300E+01, 0.74304600E+00, 0.40575200E-01, -.20916600E+01, -.35004600E+00, 0.10866600E+01, -.39715100E+00, 0.29726500E+00, -.15908000E+02, -.22042600E+01, -.42106400E+00, -.39631200E+01, 0.40816500E+00, -.26652200E+01, -.75140900E+00, -.34234100E-02, 0.11303700E+01, 0.11205400E+01, -.44141100E+00, 0.93472400E+00, -.26738200E+00, 0.62626400E+00, 0.65202000E+00, 0.47296800E+00, 0.17964500E+00, -.71989500E+00, 0.16412900E-01, 0.61125900E-01, -.28936200E+00, -.49915400E-01, -.26982500E-01, 0.18845400E+00, 0.34952000E+00, -.24167600E+00, -.72384600E+00, 0.20187600E-01, -.23342300E+01, 0.55426700E-01, -.40326200E+00, -.79220000E+00, -.15253000E+01, 0.15250600E+01, 0.79642000E+00, -.60205900E+00, 0.86746100E+00, -.17719100E+01, -.78608800E-01, 0.10970600E+01, -.31725600E+01, 0.69897900E+00, 0.85903500E+00, -.39625800E+00, -.16621400E+01, -.12005900E+01, -.19485300E+00, 0.53326200E-01, -.13482600E+01, -.62946900E-01, -.18879000E+00, 0.80739800E-01, 0.34250700E+01, -.25951300E+01, -.12659800E+01, -.20059700E-01, 0.69580700E+00, 0.52137600E+00, -.11176200E+01, 0.30263800E+00, 0.41270300E-01, -.58639300E+00, -.68645000E-01, -.26319800E+01, 0.18261700E+01, -.10969200E+00, -.89768200E+00, 0.12681200E+01, 0.32037400E+00, -.64207900E+00, -.46390000E+01, 0.11557900E+00, 0.16572600E+00, 0.15191500E+00, 0.22786200E+01, -.34888800E+01, -.14647700E+01, -.21697800E+00, -.72589800E+00, 0.13185200E+00, 0.13768900E+01, 0.24398400E+00, -.52554500E-02, 0.15224700E+00, 0.46194400E+00, -.23425500E+01, -.20960900E+00, -.55092600E+00, -.14029900E+02, -.96239200E+00, 0.21515100E+01, -.12593800E+01, -.21037700E+01, 0.31311600E+00, 0.27398900E+03, 0.37686400E+01, 0.21461200E+03, 0.16740000E+03, -.11108100E+03, -.88630200E+02, -.13613400E+03, 0.21849200E+03, -.77539500E+03, -.67371400E+02, 0.49566200E+02, 0.46678600E+03, 0.32615400E+02, 0.13553800E+03, 0.16018700E+03, -.69688300E+02, -.80144500E+02, -.85332100E+02, 0.18756800E+03, -.18735300E+03, -.53340700E+03, 0.34637900E+03, -.49158400E+03, 0.25672900E+03, 0.25272200E+03, -.91922600E+02, 0.21091600E+03, 0.30102100E+03, 0.12826700E+03, 0.18310000E+02, 0.14632200E+03, -.63042200E+02, -.19301200E+02, -.33918100E+02, -.21781300E+02, -.27745000E+02, 0.17538800E+02, 0.10981500E+02, 0.53632600E+02, 0.12089000E+02, -.41210400E+01, -.26617700E+02, -.46502600E+02, 0.53153200E+01, 0.34018000E+02, 0.55188500E+02, 0.13522000E+03, 0.21887000E+02, -.31780200E-01, -.28059400E+02, 0.22386000E+02, 0.32369000E+02, -.13562900E+03, -.10050400E+03, 0.44189700E+02, 0.15399200E+02, 0.13862600E+02 },
        { -.13570100E+02, -.26684300E+01, 0.42977500E+01, 0.26257200E+01, 0.86058000E+01, 0.40241000E+01, 0.31937200E+01, 0.13627900E+02, -.85995800E+00, 0.47442800E+01, 0.24107700E+01, -.69954900E-01, 0.81698900E+00, -.55061300E+00, -.99624400E+00, 0.10388900E+02, -.97086100E+00, -.21847500E+01, 0.34465300E+01, 0.29971100E+01, 0.47397300E+00, -.11567500E+01, 0.21765100E+00, 0.45231700E+00, -.10247300E+01, -.11953600E+01, -.11048000E+01, -.18916800E+00, 0.28464600E+01, -.18855400E+00, -.53970600E+00, 0.47366600E+00, -.10944300E+01, 0.40514600E+01, -.48785600E-01, 0.20644700E+00, 0.73036500E-01, -.82485300E+00, 0.14461700E-01, 0.89683000E+00, 0.90707000E+00, -.68318200E+00, -.77379700E-01, 0.22993800E+00, 0.11429100E+01, -.77726400E+00, 0.11609400E+00, 0.14464600E+00, 0.36798000E+01, 0.22303000E-01, -.13398200E+00, -.39407300E+00, 0.76545900E+00, 0.38238200E+00, -.36055300E+00, 0.76080600E+00, 0.75368200E+00, -.88380100E-01, 0.20763000E+00, 0.10609200E+01, -.65150800E+00, 0.17259700E+01, 0.25201600E+00, 0.20080700E+00, 0.11966600E+01, -.32590500E+00, -.18096800E+01, -.88362500E-01, -.98647100E+00, -.19758100E-01, 0.71109700E-01, -.33625200E+01, 0.14839100E+01, 0.83761000E-01, -.15376200E+00, 0.20439200E+01, -.23864300E+00, 0.11491200E+01, 0.73006100E+00, 0.14055700E+00, 0.10113500E+00, -.53938700E-01, 0.12632600E+00, -.14076000E+01, -.39103300E-01, 0.46771700E+00, 0.40809000E+00, 0.14004800E+00, 0.16548500E+01, -.46686100E-01, 0.24095200E+00, 0.20679700E-01, 0.22347200E+00, 0.12283800E+00, -.90920400E+00, 0.77479800E+00, 0.43813200E+00, 0.30085300E+00, -.10127300E-01, 0.36207800E+00, 0.65032300E-01, -.37798200E+00, 0.66694700E-01, -.69307100E+00, 0.69563900E+00, -.50760600E+01, -.25150300E+00, 0.15287700E+01, -.64278000E-01, -.86322200E+00, 0.87140800E+00, 0.90136000E-01, 0.48657000E+00, 0.86029900E-01, -.36569500E+00, 0.39172900E+00, 0.77919600E-01, 0.72380700E-01, -.15900300E+01, -.92352200E+00, -.44727200E+00, 0.29396300E+00, -.20590100E+00, 0.48672900E-01, 0.27475200E+00, -.65976500E+00, -.12195100E+01, -.19655700E+00, 0.59615800E+00, -.70933100E-01, -.62334700E+00, -.88343900E-01, -.69626800E+00, 0.47003800E+00, -.11844800E+00, 0.43702300E-01, -.64069200E-02, -.64097300E+00, 0.22691600E-01, 0.17607200E+01, -.25766700E+00, 0.11781000E+00, 0.75473900E+00, 0.60421600E+00, 0.11178900E+00, 0.15247700E+01, 0.93967700E-01, -.95986300E+00, 0.10345000E+00, -.73704500E-01, 0.15329000E+01, 0.16237600E+00, -.22788300E+00, 0.14055400E+01, 0.93721200E-01, 0.74537700E+00, 0.11651500E+00, -.15447200E-01, 0.20596600E+01, 0.45346300E+00, -.30797500E-01, -.47991900E+00, 0.41904700E+00, 0.47744400E-01, 0.13974800E+00, 0.10204100E+01, 0.15425200E-01, 0.74356000E+00, 0.45331500E-01, -.12843500E+01, 0.55770400E-01, -.91797100E-01, 0.92614500E-01, -.31748300E+00, -.14727500E+01, 0.34862200E+00, 0.15335000E+01, 0.11497000E-02, 0.50386000E+00, -.11246400E+00, 0.21235700E+00, -.64691500E+00, 0.24914200E+00, -.12147500E+00, 0.35137400E+00, -.49261900E+00, -.37342500E+00, 0.94379600E+00, 0.30105500E-01, 0.21428000E+00, -.64573600E+00, 0.33657200E+00, 0.17133800E-02, -.31898400E+00, -.13959800E+01, 0.17968800E+00, 0.44690400E+00, -.29666000E+00, -.50256200E+00, -.20565700E-01, -.14482600E+00, -.31414600E+00, 0.18423400E+00, -.92116300E+00, -.47099100E+00, -.75262300E-01, -.84056500E-01, 0.43337500E+00, -.15492300E+00, -.16739200E+00, -.19228500E-01, 0.62656800E+00, 0.13129500E-01, 0.26055900E+01, 0.13993900E+01, 0.39838200E+00, 0.69258200E-02, -.14224000E-01, 0.18016900E+00, -.13875800E+00, -.10281600E+01, -.85358000E-01, -.31542500E-01, -.40999900E-02, 0.44742100E+00, -.25689800E+00, 0.13996300E+00, -.13994500E+00, -.36448100E+00, -.15720200E+01, 0.21223800E+00, -.33244500E-01, 0.16508000E-02, -.10759700E+00, 0.11831500E+01, -.91009200E+00, -.26823200E-03, -.12297200E+00, -.16642400E-01, -.99670300E-01, -.81035000E+00, 0.42275500E+00, -.45580800E+00, 0.76319400E-01, 0.64532600E-01, 0.21652300E+02, -.48216100E+01, 0.21519300E+02, -.30970100E+02, -.21441000E+02, 0.17721400E+02, 0.96744600E+01, -.47550900E+02, 0.21373500E+01, -.14498000E+01, 0.14449700E+03, 0.73974600E+00, -.96940600E+01, -.87870600E+01, 0.14222800E+02, -.73900100E+01, -.32740200E+02, -.84185900E+01, -.21541000E+02, -.56684900E+02, 0.39587000E+02, 0.13510500E+03, 0.28371400E+02, 0.96918200E+02, 0.37176900E+02, 0.20223600E+02, 0.11475700E+03, 0.77879100E+02, 0.25624700E+02, 0.44252700E+02, -.75993900E+01, -.14853200E+01, 0.18779800E+02, 0.21142800E+02, -.10771900E+01, -.97820800E+00, -.14451000E+02, -.14738400E+01, -.43563100E+01, 0.16329400E+01, 0.15914800E+01, -.21504100E+01, -.10236900E+02, 0.12674000E+01, -.20339600E+01, -.24569000E+01, -.20888900E+02, -.15706700E+02, 0.19850600E+02, -.10007200E+01, -.17942800E+01, 0.22556100E+01, 0.82098200E+01, 0.13743900E+01, -.13037500E+02, 0.15841700E+01 },
        { -.85404100E+01, -.32399200E+01, -.90024700E+01, -.55710300E+01, 0.20452400E+01, 0.26498100E+01, 0.24334500E+01, -.21813300E+01, 0.79582900E-01, -.10161600E+01, 0.92842900E+00, 0.93777400E+00, 0.32687900E+00, -.35760800E+00, -.17346400E+01, 0.38444400E+02, -.29920600E+01, 0.33215900E+01, 0.44632900E+01, -.16512300E+00, -.55085800E+01, -.67909900E-01, -.63663100E-01, 0.62449800E+00, -.82431100E+00, -.13671600E+00, -.10330100E+01, 0.16269100E+01, 0.33178400E+01, -.11570100E+00, -.92026900E+00, 0.26580400E+01, -.10906800E+01, -.21588000E+01, 0.50706100E-01, -.18548300E+00, -.18721200E+00, -.12620600E+01, -.17114700E+00, -.25640000E+00, -.11987500E+00, -.13129500E+01, 0.20982500E+00, -.26598300E+00, 0.98999800E+00, 0.26163600E+00, 0.53138000E-01, -.40694200E-01, 0.48564300E+00, 0.21749300E+00, -.12317200E+01, -.24992600E+01, 0.85313100E+00, -.15678200E+01, -.63982700E+00, 0.22117900E+01, 0.76587300E+00, -.20820300E+00, 0.62019400E-01, 0.20023100E+01, -.32854200E+00, 0.30368600E+01, 0.55337300E+00, -.20864900E+01, -.50555100E+00, -.16109100E+01, -.69342300E+00, 0.78093500E+00, 0.74292400E+00, -.11440300E-01, -.69554800E-01, 0.41843200E+01, 0.30051400E+01, 0.51808800E+01, -.16248800E+01, 0.99407900E+00, -.54125900E+00, 0.15977800E+01, -.14605000E+01, -.38500700E+00, 0.11622100E+00, 0.97742600E-01, -.43779100E+00, -.15782900E+01, -.11323700E+00, 0.34382900E+00, 0.30479700E+00, 0.18879700E+00, 0.19478200E+01, 0.68374200E-01, -.43012400E+00, 0.21391900E-01, 0.60334900E+00, 0.40216400E-01, 0.28542600E+00, 0.29716800E+01, 0.51729500E+00, -.57735800E+00, 0.33610900E+00, 0.77062700E-01, 0.14985000E+00, -.14649200E+00, 0.63124000E-01, -.87919700E+00, 0.28044800E-01, -.46329600E+01, 0.37090100E+00, 0.14530700E+01, -.46447200E+00, -.14353700E+01, 0.11178000E+01, 0.48118300E-01, 0.11035400E-01, 0.16725600E-01, 0.66479000E-01, 0.76079100E+00, -.36646600E+00, -.15722200E+00, -.13735100E+00, -.95708800E+00, -.14472800E+00, -.73977400E-02, -.17732700E+00, -.66101100E-01, -.15559100E-02, -.28728100E+00, 0.18907800E+00, 0.20962400E+01, -.11354400E+00, 0.10538100E-01, -.15513200E+01, 0.32808000E+00, 0.43080300E+00, -.39168400E+00, -.35737200E-01, -.17948400E-01, 0.61841200E+00, -.55215300E+00, -.12535000E+00, 0.12048900E+01, -.46997200E+00, -.12712100E+00, 0.51303500E-01, 0.48114800E-01, 0.28417300E-01, 0.11943400E+01, 0.95272400E-01, -.65415600E+00, -.43014000E-02, 0.92244200E+00, 0.20314000E+01, 0.89250500E+00, 0.28996500E+00, 0.12796500E+01, 0.85659200E-01, 0.74619000E+00, 0.52390200E+00, 0.76189500E-04, 0.20659700E+01, -.58229300E-01, 0.76901500E-01, 0.55628900E-01, 0.17992200E+00, 0.52390800E+00, -.96467400E+00, 0.27851000E+00, -.22176700E+00, -.11462500E+01, 0.54813100E-02, 0.31720700E+00, -.36912200E+00, 0.22775200E+00, 0.15243900E+00, -.37887800E+00, -.15876600E+01, 0.14509700E+00, 0.11034000E+01, 0.54356200E-01, 0.12207700E+01, 0.40630800E-01, 0.89776600E+00, -.51430400E+00, -.17252200E+01, -.12404900E+01, 0.50651000E+00, -.18688700E+01, -.18109300E+00, 0.14478000E+01, 0.10861900E+00, 0.72683000E+00, -.36726900E-01, -.70925600E-01, -.25118100E+00, -.69773900E+00, 0.16094400E+01, 0.48006600E+00, 0.13215600E+01, -.46465900E+00, 0.16405000E+01, -.12579800E+00, 0.49794600E+00, 0.20932500E-01, -.30460700E+01, 0.10947500E+01, 0.53137500E+00, 0.81106700E+00, -.73253000E+00, -.70674700E+00, 0.30188900E+00, -.39630900E+00, -.32758200E-01, 0.10030700E+01, 0.18118800E+00, 0.35216700E+01, 0.18771800E+00, 0.21185900E+00, -.10410300E+01, 0.74713500E+00, 0.93993600E-01, -.23464800E+00, 0.29197900E+01, -.17283800E+00, 0.39642600E-02, -.66710200E-01, -.10135200E+01, 0.86488900E+00, -.13286600E+01, 0.11416800E+00, -.10931200E+01, -.26030200E+00, -.20907700E-01, -.94070900E+00, 0.19779900E-02, -.12342100E+00, 0.76569800E+00, -.32353400E-01, 0.14018000E+00, -.18535500E+00, -.26029900E+01, 0.49332900E+00, -.76197300E+00, 0.19547900E+00, 0.56920600E+00, 0.23682600E-01, 0.74598500E-01, -.45589800E-01, -.77528300E+02, -.50799000E+02, 0.18961100E+02, -.19698100E+01, 0.66816100E+02, -.79325300E+02, 0.15055100E+03, 0.15490200E+02, -.10938500E+02, -.94416400E+01, -.73727000E+01, -.38848400E+02, -.45468300E+02, 0.36744100E+02, 0.40758800E+02, -.27468200E+01, -.45171200E+02, 0.55609600E+02, 0.11579600E+03, -.67564900E+02, 0.14378000E+03, -.52599800E+02, -.33050800E+02, -.11566700E+01, -.12814700E+02, 0.17454000E+02, 0.48128200E+02, -.25616100E+02, 0.29910400E+02, 0.15963500E+02, 0.59393900E+00, 0.41158100E+01, 0.16427200E+01, 0.37309700E+01, -.82197800E+00, -.52765900E+01, -.17558000E+02, -.30233500E+01, -.15887600E+00, 0.67396800E+01, 0.89060300E+01, -.32772300E+01, -.52927000E+01, -.18468700E+02, -.50614700E+02, -.17780400E+01, -.45117000E+01, 0.29105900E+01, -.24623500E+01, -.41399200E+01, 0.51160600E+02, 0.36919000E+02, -.99237500E+01, -.64788000E+01, -.62186900E+01 },
        { 0.11619000E+02, 0.32487500E+01, -.30649700E+01, -.51650100E+01, -.65115800E+01, -.38989200E+01, -.45561300E+01, -.28305600E+01, 0.44284100E+00, -.39588100E+01, -.97862500E+00, -.54805000E+00, -.22920300E+00, 0.59585700E+00, 0.75284900E+00, -.11662100E+02, 0.80422100E+01, 0.18458300E+01, -.72180500E+01, -.31745100E+01, 0.15164200E+01, 0.10436500E+01, -.35493600E+00, -.57893100E+00, 0.37625200E+00, 0.42501500E-01, -.12159800E+01, -.22827700E+01, 0.18769800E+01, -.43190600E-01, 0.66603300E+00, -.60461900E+00, -.76479600E+00, 0.12737200E+01, 0.19399500E-01, -.16680200E+00, -.11267800E+00, 0.59892800E+00, -.24126800E+00, 0.82958500E+00, -.33552300E+01, -.12287600E+01, -.21975200E-01, -.74102700E+00, 0.10171800E+01, 0.10895400E+01, -.17309500E+00, 0.14812200E-01, 0.17917400E+01, -.17018500E+00, 0.21292900E+01, -.44947600E+01, 0.12957100E+01, -.48113500E+01, 0.38344000E-01, -.43771900E+01, -.22358300E+01, 0.32566800E+00, -.76678200E-03, -.12757200E+00, 0.70689200E-01, 0.20066600E+01, -.11070300E+01, -.33882300E+00, -.19205100E+01, -.21411400E+00, -.21949100E+00, -.34827700E+00, 0.35781900E+00, 0.46899500E-01, 0.10998000E+00, -.78459200E+01, -.49138900E+00, 0.10667100E+01, 0.18058300E+01, 0.88437900E+00, 0.33513200E+00, 0.12024200E+01, 0.43074300E+00, 0.11933500E+00, -.27667500E+00, -.10778300E+00, 0.37689600E+00, -.14971300E+00, 0.40997000E+00, 0.65989000E+00, -.36366000E+00, -.33758300E+00, -.27759500E+00, 0.49308700E-01, 0.32310400E+00, -.16281600E-01, 0.20779600E+00, 0.51513600E+00, 0.10706500E+01, 0.37241100E+00, -.18223700E+00, 0.54173000E+00, 0.32684500E+00, 0.71923100E+00, 0.22055700E+00, 0.21531200E+00, 0.15255200E+00, -.31428800E+00, -.27838500E+00, -.24297300E+01, -.41509700E+00, -.13428100E+01, 0.34929400E+00, 0.12053700E+01, -.21838000E+00, -.48992300E-01, 0.24092100E+01, -.44410600E-02, 0.36002000E+00, -.66167800E+00, -.22591100E-01, -.41620100E+00, -.96193000E+00, 0.98413200E+00, 0.19440500E+00, -.13415100E+00, 0.39625000E-01, -.45729000E+00, -.66852200E-01, -.20202000E+00, -.48860300E+00, -.10251800E+01, 0.65682200E-01, 0.48889400E+00, -.11536000E+00, -.80657600E+00, 0.47922100E+00, -.10398000E+00, -.12511400E+00, -.64182000E-01, 0.19774100E+01, 0.58263000E+00, 0.39991800E-01, -.10462600E+01, -.82560800E+00, -.41480300E+00, -.16551400E+00, -.50546300E+00, -.50274900E-01, -.98413000E+00, -.16636100E-01, 0.11516900E+01, -.20269400E+00, -.40144300E+00, -.34491000E+00, 0.55064900E+00, -.17767900E+00, 0.17693600E+01, -.17481700E+00, -.17126800E+01, -.79539200E-01, 0.20317700E-02, 0.19878700E+01, 0.64362200E+00, -.42893100E-01, 0.44852500E+00, -.43862400E+00, 0.93706300E-01, 0.20529800E+01, -.31996400E+00, 0.13675900E-01, -.39577900E+00, 0.19693600E-01, 0.17635000E+00, -.30006000E+00, 0.18371200E+00, -.21259300E+00, 0.26700700E+00, 0.11118000E+01, -.31213700E+00, -.68237000E+00, 0.49285500E-02, -.83268200E-01, 0.73176300E-01, -.13798600E+00, 0.48819500E+00, -.17565100E+01, -.27640900E+00, 0.11482900E+00, 0.30499600E+00, -.24209000E+00, -.51904100E+00, 0.10228600E-01, -.30012400E+00, -.19073100E+00, -.43988200E-01, 0.28976800E+00, 0.20426000E+00, -.11547800E+01, -.21317300E+00, 0.19475800E+00, 0.20002500E+00, 0.44555000E+00, 0.71472800E-01, -.18042300E+00, 0.11224700E+00, -.46382000E+00, -.53212800E-01, -.66566100E+00, -.39047500E+00, 0.30699100E+00, 0.33106100E+00, -.34533700E+00, 0.30728000E-01, 0.61733500E-01, -.32357000E+00, 0.16702200E-01, -.25565500E+01, -.91898600E+00, -.48959800E+00, 0.10145900E+01, -.77834700E-01, -.13723400E+00, 0.29370400E+00, 0.15324100E+01, -.14953100E-01, -.28978700E+00, 0.70413300E-01, 0.97021800E+00, 0.11907100E+01, -.45707700E+00, -.47649000E+00, -.75512900E-01, -.15163100E+00, -.11987400E+01, 0.17364800E+01, -.42139000E-02, -.50729300E-01, -.26889300E+01, 0.13635100E+01, -.40725400E+00, 0.14868900E+00, 0.79112400E+01, 0.18877100E+01, -.56785800E+00, -.12043500E+01, 0.10584200E+01, -.26551700E+00, -.25017000E-01, -.35424500E-01, 0.80426300E+00, -.72312000E+02, 0.77390600E+02, 0.10009800E+03, -.16145200E+02, -.57408400E+02, 0.82672600E+02, -.16104800E+02, 0.29787800E+01, -.26146000E+03, 0.78992700E+01, 0.52488600E+01, -.13734400E+02, 0.11894700E+01, -.41016200E+02, 0.35540400E+02, -.14647500E+02, 0.78260100E+02, 0.25244500E+03, -.17261000E+03, -.50856000E+02, -.12892900E+03, -.25393900E+03, -.50693700E+01, -.10993800E+03, -.31675500E+03, -.25703100E+03, -.12101900E+02, -.25164100E+03, 0.29776900E+02, 0.12523100E+02, -.16722400E+02, -.23162200E+02, 0.14153200E+02, -.59918700E+01, 0.19281400E+02, -.12739600E+02, 0.14766100E+01, 0.36500700E+01, 0.67454800E+01, 0.11866700E+02, 0.16640700E+02, -.16302800E+02, -.14005600E+02, -.30263200E+01, 0.21592200E+02, 0.17578900E+02, -.20536900E+02, -.68947600E+01, -.32300300E+01, 0.23889900E+01, -.35979800E+01, -.18119600E+02, 0.75542000E+01, -.33783100E+01 },
        { 0.23061800E+01, 0.33169600E+00, -.82053300E+00, -.10463200E+01, -.10025200E+01, -.20773500E+00, -.75942100E+00, 0.35228400E+01, 0.44150200E-01, -.70350500E+00, 0.41356300E+00, -.61951100E-01, -.15485800E+00, 0.52332000E-01, 0.49952800E+00, -.97412700E+01, -.13270600E+01, -.11547200E+01, -.87802300E+00, 0.51171200E-01, 0.51634800E+00, 0.35463700E+00, 0.65449100E-01, 0.23644800E+00, 0.33103300E+00, 0.24311900E-01, 0.30939100E+00, -.16264900E+00, -.93728600E+00, -.24541800E-01, 0.17834900E+00, -.49298800E-01, 0.31427700E+00, -.15453900E+01, 0.12824300E-03, -.24401300E-01, 0.92612200E-02, 0.14593300E+00, -.17269300E-01, -.11625700E+00, -.10799600E+01, 0.40411400E+00, -.69461400E-03, 0.62232300E-01, -.27040000E+00, 0.12110300E+00, -.31170500E-01, -.18567100E-02, -.63158800E+00, -.93619800E-01, 0.12432600E+00, 0.97717600E-02, 0.17863300E-01, -.18857200E+01, -.59308300E-01, -.80736700E-01, -.24623500E+00, 0.18719400E-02, 0.25111200E-02, -.36230000E+00, 0.84180100E-02, -.16710400E+00, -.75900100E-01, 0.11164200E+00, 0.10372100E+00, 0.26359300E+00, 0.11283700E-01, -.97241400E-01, 0.13479100E+00, 0.39897800E-02, -.18046400E-01, 0.18846900E+00, -.32958800E+00, -.40080500E+00, -.47776700E-02, -.17432100E+00, 0.73402100E-01, -.40866000E+00, 0.66167700E-01, 0.66326400E-01, -.14918300E-01, 0.15262700E-01, -.51846400E-01, -.92043200E-01, -.74404600E-01, 0.50007600E-01, 0.30271300E-01, -.34770100E-01, -.70391200E-01, 0.45628900E-02, -.41035300E-01, 0.10612700E-03, 0.16650800E+00, -.92045900E-02, -.32699900E+00, -.13057600E+00, -.44739800E-01, 0.84472200E-01, -.38962500E-01, -.38038400E-01, -.10787700E-01, 0.22417400E-01, -.14822300E-02, 0.17749600E+00, -.11955600E+00, 0.21058100E+01, 0.21201300E+00, -.11641100E+00, -.30743000E-01, -.62684400E-01, 0.73217200E-01, -.89744900E-02, -.15430300E+00, -.10953600E-01, -.74261800E-01, -.22837300E+00, 0.79726000E-01, 0.98441100E-01, -.92332400E-01, 0.50818800E+00, 0.18298800E+00, 0.27591900E-02, 0.10126200E+00, -.50765300E-01, 0.29614800E-02, 0.21473400E-01, 0.10175600E+00, -.56909100E+00, -.26636900E+00, 0.12707900E+00, -.89666900E-01, 0.13122000E-01, 0.17731900E+00, -.10535700E+00, 0.26961100E-01, -.39739900E-02, 0.23261000E-01, 0.92978500E-01, 0.10269700E+00, -.40955900E+00, -.25034800E+00, -.10538500E+00, -.34111800E+00, -.44233400E+00, 0.18512100E-01, -.32109400E+00, -.39232300E-01, 0.19673500E+00, 0.88020000E-01, -.33705100E+00, 0.19523900E+01, -.40671100E+00, -.58618600E-01, 0.68855300E+00, 0.80639300E-01, 0.51921300E+00, 0.73428700E-02, 0.49253300E-03, -.46637800E+00, 0.10110300E+00, 0.67392000E-01, -.58668600E-01, -.10252700E-01, -.33968800E+00, -.47744400E+00, -.80002300E-01, 0.54610000E-01, -.12613000E+00, -.85980800E-02, -.20356500E+00, 0.17428600E+00, -.72040200E-01, -.33048600E-01, 0.75187100E-01, 0.30394900E+00, 0.85488700E-02, 0.87703300E-03, -.12567300E-01, -.22357500E+00, 0.12012100E-01, -.24015000E-01, -.93722100E-01, 0.26143000E+00, 0.17178200E+00, -.79857000E-02, -.16371900E+00, 0.27160900E-01, -.17516800E+00, 0.72895400E-02, 0.12535800E+00, -.25168000E+00, -.22108000E-01, 0.25611800E-01, 0.21873000E-01, 0.40009500E+00, -.40939300E-01, 0.20832600E-01, -.61196100E-01, -.98452400E-01, 0.43487400E-02, 0.56747900E-03, 0.10183000E-01, 0.45390300E+00, 0.26500300E+00, 0.24793400E+00, -.23348700E-01, 0.37495800E-01, -.28842700E+00, 0.90639400E-01, 0.81356800E-01, -.11158500E-01, -.13211300E-01, -.32552800E-01, 0.16026000E+00, 0.80263800E-01, 0.11144900E+00, 0.16925600E+00, -.50310900E+00, 0.70422200E-01, 0.67033400E-01, -.76613600E+00, -.16446700E-01, 0.55790500E-01, 0.91190000E-03, -.31916200E+00, -.67267400E-01, 0.13663900E+00, -.64969100E-01, 0.27053700E+00, 0.24158400E+00, 0.32673400E-01, 0.14746900E+00, 0.34964700E-02, 0.95515500E-02, 0.23054400E+00, 0.35192200E-01, 0.26603200E-01, -.10125100E+00, -.23329800E+01, -.60479700E+00, 0.49843600E+00, -.32073800E+00, 0.45257200E+00, -.39996900E-01, -.20137800E-01, 0.20331100E-02, 0.12232300E+00, -.12002200E-01, 0.67375200E+01, 0.25599300E+01, -.15214100E+02, 0.55738800E+01, 0.12459300E+01, 0.35033200E+01, -.18681600E+01, -.38740400E+02, -.19069200E+01, 0.37808100E+01, -.14982000E+02, 0.17470100E+02, 0.76429800E+01, 0.23894600E+02, -.17254900E+02, -.10702500E+02, -.58882200E+01, -.10854800E+01, 0.37492400E+01, 0.25006200E+01, -.66290100E+01, -.31843300E+02, 0.96119300E+01, -.20498600E+01, 0.33901000E+01, -.33722300E+02, -.18325200E+01, 0.21126200E+01, -.94881300E+00, 0.51992600E+01, 0.58685100E+01, -.11302900E+01, 0.11170000E+01, 0.67362100E+01, 0.40324900E+01, 0.29418800E+01, -.13041500E+01, -.29218600E+01, 0.74848800E+00, 0.47949800E+01, 0.11790500E+01, 0.43050300E+01, 0.88855200E+01, -.54385500E+01, 0.62246300E+01, 0.55403700E+01, 0.13421300E+01, 0.39231600E+01, -.91237900E+01, -.10591000E+02, 0.23571700E+01, 0.38713300E+01, -.30201900E+01 },
        { -.18727500E+02, -.10128300E+01, 0.43288700E+01, 0.36142100E+01, 0.40822400E+01, 0.21953100E+01, 0.74274700E+01, -.22513400E+02, -.13500500E+01, -.59457900E+01, -.20843500E+00, 0.23532300E+01, 0.29131400E+01, -.74730000E+00, -.26579700E+01, 0.32712200E+02, -.67783500E-01, 0.21508900E+01, 0.11279100E+02, -.56351500E+00, -.40806600E+01, -.14108800E+01, -.47193200E-01, -.81809500E+00, -.14630200E+01, -.15963400E+00, -.77070700E+00, -.82270300E+00, 0.22544500E+01, 0.30708900E+00, -.15811300E+01, -.84523300E+00, 0.10421600E+01, 0.55643900E+01, -.71148000E-01, -.19743700E+00, 0.16815400E+00, -.10237900E+01, -.25819000E+00, -.12737300E+01, 0.10010400E+02, 0.34736400E+00, -.40525400E-01, 0.85763300E+00, -.42853600E+00, 0.78567600E+00, -.36473200E-01, 0.12186900E+00, 0.14741300E+01, 0.10458300E+01, 0.94202600E+00, 0.29614700E+01, 0.20929800E+00, 0.14934800E+02, 0.18903300E+01, -.10751300E+01, 0.17970800E+01, 0.16155000E+00, -.75765800E-01, -.14536900E+00, -.32788800E+00, -.98151500E+00, -.18510700E+00, 0.37509500E+00, -.39121300E+00, -.29671900E+00, 0.37522900E+01, 0.96473900E+00, -.11666100E+01, -.24926800E-01, -.15270600E-01, -.36077700E+01, -.31564500E+01, -.97404100E+01, 0.12790600E+01, -.41258800E+00, 0.36969100E+00, -.17310400E+01, 0.15317800E+01, 0.20003400E+00, -.11778800E+00, 0.30612400E-02, 0.10423400E+01, 0.30795300E+01, -.40059700E+00, -.15021400E+01, -.19204700E-01, -.19127100E+00, 0.10130700E+01, 0.36432100E+00, 0.74006900E+00, 0.81425800E-02, -.66684000E+00, -.26555700E+00, 0.19721900E+01, -.30821900E+01, 0.69338400E+00, -.16308800E+01, 0.10196700E+00, -.22120700E+01, 0.34279100E+00, -.41648600E+00, 0.11911700E+00, 0.42892200E+00, 0.32379500E+00, -.11514200E+01, -.20321300E+01, -.12135800E+00, -.98770700E-02, 0.13965400E+00, -.11939400E+01, 0.85970900E-01, -.46155700E+00, 0.61526700E-01, -.10768000E+00, 0.59290400E+00, 0.23548200E+00, 0.89291500E+00, -.33872600E+01, -.13861600E+01, -.41158400E+01, 0.19644100E+00, 0.52470000E-01, 0.95705100E+00, 0.14454100E+00, 0.46046900E+00, -.18375800E+01, -.20960100E+01, 0.26954400E+01, -.15576500E+00, 0.19432800E+00, 0.67792200E+00, 0.13164600E+01, -.21287900E+01, 0.51740500E+00, 0.12957400E+00, -.31736600E+01, -.16745300E+01, 0.15931700E+00, 0.21693900E+01, 0.10563500E+01, 0.55093000E+00, 0.65368700E+00, 0.11142500E+01, -.75961200E-01, 0.20276600E+01, 0.21746000E+00, -.86522700E-01, 0.20278800E+00, 0.19652800E+01, 0.65538400E+01, -.38494400E+00, -.10945200E+01, 0.40243200E-01, 0.34649700E+00, -.25018400E+01, -.26021700E+00, 0.37512900E-02, 0.19759500E+01, 0.82500900E+00, -.10101400E+00, 0.70839600E+00, 0.50664600E+00, 0.30341700E+00, 0.29772200E+01, 0.38756500E+00, 0.84839400E-01, 0.12128100E+01, 0.61332600E-01, -.22657600E+01, -.56665900E+00, 0.43965300E+00, -.16444200E+00, -.38879700E-01, 0.83840300E-01, -.10700200E+00, 0.41114900E+00, 0.28745000E-01, -.47798100E+00, -.11146700E+00, 0.39773400E-01, 0.11885900E+01, -.33845900E+01, 0.31380700E+00, 0.70256900E+00, 0.16368000E+01, -.53061600E+00, -.11478100E+01, 0.62018700E-01, -.54841200E+00, -.13543400E+01, 0.75189100E+00, 0.34816200E+00, -.42743400E+00, -.71665500E+01, -.13873200E+01, 0.12638600E+01, 0.74101300E-01, -.66701300E+00, -.35441000E-01, -.46361200E+00, 0.31352000E+00, 0.29325200E+01, -.47551300E+00, -.75096600E+00, -.25813600E+00, 0.10908300E+01, -.42653200E+00, -.17201100E+00, 0.33874200E+00, 0.15330400E+00, 0.27393900E+01, 0.19874900E-01, -.78711700E+00, -.17575400E+00, -.14396200E+01, -.41096200E+00, -.71246500E+00, 0.53800400E+00, 0.45151600E+00, -.12889600E+02, -.62686600E-01, 0.37023900E+00, 0.16787500E+00, -.10576000E+01, -.18252900E+01, 0.11614700E+01, -.11941500E+01, -.15733300E+01, 0.12260800E+01, 0.33805800E+01, 0.35209700E+00, -.56021600E-01, 0.42705800E+00, 0.27074400E+01, -.18599100E+00, -.58462400E+00, -.10977600E+01, 0.99523900E+01, 0.78201900E+00, -.26527900E+01, -.19909900E+01, -.36047100E+01, 0.96482500E-01, 0.73844100E+00, -.14775900E+00, -.13703000E-01, -.22317000E+00, 0.23542400E-01, 0.12359200E+03, 0.86181200E+02, -.12178900E+02, -.10286700E+02, -.45823900E+01, -.21475300E-01, -.10695500E+03, 0.25440500E+01, -.29272800E+02, -.10394300E+03, 0.13649100E+03, -.96507700E+02, -.11047700E+03, -.76714100E+02, 0.80957300E+02, 0.16838800E+03, -.12431900E+03, 0.20850200E+03, -.79616700E+02, -.87882300E+02, 0.13178000E+03, -.14145400E+03, -.31414900E+03, -.13822000E+03, 0.72995700E+02, -.46525000E+03, 0.23904800E+02, 0.29619800E+02, 0.43822300E+01, -.79813700E-01, 0.13039200E+02, -.31934400E+01, -.16320600E+02, -.36781300E+02, -.20066800E+02, 0.23455000E+02, 0.36910800E+02, 0.78396400E+01, -.64845500E+01, -.16933500E+02, -.40622700E+02, -.40712100E+02, -.10060600E+01, -.22024400E+02, 0.12168100E+01, -.38038700E+01, -.13257800E+02, 0.40213100E+02, 0.37986000E+02, -.37571900E+02, -.38702500E+02, 0.32389300E+01 },
        { -.13059900E+02, -.75212100E+00, 0.56377600E+01, 0.37806200E+01, 0.55937700E+01, 0.16709900E+01, 0.43412700E+01, -.89183100E+01, -.59112300E+00, -.11792900E+01, -.16160500E+00, 0.60769400E+00, 0.13629600E+01, -.25635300E+00, -.86683500E+00, 0.25708700E+02, 0.10128600E+02, 0.10984600E+01, 0.57624800E+01, 0.19418000E+01, -.21090200E+01, -.17111900E+01, -.14215600E-01, -.74377500E+00, -.72112100E+00, -.27159400E+00, -.11859000E+01, -.29551700E+01, 0.48258100E+01, 0.40122000E-01, 0.16997700E+00, -.23118200E+00, -.14222200E+01, 0.68510900E+01, -.92792700E-01, 0.17517900E+00, 0.14205000E+00, 0.17723300E+01, 0.32934100E+00, 0.39559100E+00, -.26217400E+01, 0.59100600E+00, 0.33319200E-01, -.13294100E+00, -.63359600E+00, -.26412400E+00, 0.84849400E-01, -.13057800E-01, -.19285700E+01, -.95704200E-01, -.20445400E+01, -.10057000E+01, 0.50090500E+00, 0.24490300E+01, -.81063800E+00, 0.59921000E+01, 0.18918100E+01, -.43934200E-01, 0.15152000E+00, 0.15542600E+01, 0.31364500E+00, 0.52620800E+00, 0.17608600E+01, -.59341300E+00, 0.21753100E+01, -.82387600E+00, -.40795800E+01, -.59459400E+00, -.16640700E+01, -.29641500E-01, 0.13351600E+00, -.22133700E+01, 0.30089300E+01, 0.56862800E+01, -.36987800E+00, 0.24790800E+01, -.73821700E+00, 0.21617100E+01, 0.13713500E+01, 0.82033300E-01, 0.37594700E+00, -.52831200E+00, -.57983600E+00, -.64587900E-01, 0.50106100E+00, 0.30921700E+00, 0.18047600E+00, 0.22745800E+00, -.51368000E+00, 0.14722600E+00, -.22852800E-01, 0.13090600E-01, 0.67027900E+00, -.35943000E-01, 0.95350500E+00, 0.11939700E+01, 0.10175200E+01, 0.67214000E+00, -.59894200E+00, 0.59165600E+00, 0.37774600E+00, 0.35507600E+00, 0.12240700E+00, -.47652100E+00, 0.50248200E+00, -.91162000E+01, -.15638600E+01, 0.69851800E+00, -.42154800E-01, -.32516000E+00, -.66785300E+00, 0.19579600E-01, -.37214800E+00, 0.10202500E+00, -.32313600E+00, -.73716100E+00, -.32696000E+00, 0.54665100E+00, 0.13982800E+01, -.30811400E+01, 0.10927700E+01, 0.81090500E-01, -.43434200E+00, 0.55194800E+00, 0.11735900E-01, 0.80220300E+00, 0.17690700E+00, -.11677600E+01, -.30503200E+00, -.14703700E+00, 0.45839800E+00, -.22143900E-01, -.21848100E+00, 0.14404900E+01, 0.18750100E-01, 0.11815900E-01, -.16940700E+01, 0.12654900E+00, -.20513600E+00, 0.16274200E+01, 0.13071700E+01, 0.82532600E+00, -.11124300E+00, 0.73563900E+00, 0.29320400E+00, 0.13407600E+00, 0.12665200E+00, -.13171700E+01, 0.37897800E+00, -.17085700E+00, 0.34628200E+00, -.14405800E+01, -.74591600E+00, -.65378300E+00, 0.48023100E+00, 0.23310400E+01, -.24836700E+00, 0.16261500E+00, -.19136100E+01, 0.17607700E-01, 0.22653000E+00, -.72030400E+00, 0.11979700E+01, -.49753200E+00, 0.94167900E+00, 0.26354200E+00, -.20648900E-01, 0.20317400E+01, 0.24902600E-01, 0.53171300E+00, -.15561800E+00, 0.10053300E+00, 0.10589100E+00, -.18742600E+00, 0.16955200E+00, 0.18362400E+00, -.38012700E+00, 0.32096500E-01, -.14839100E+00, -.20973000E+00, -.65773500E+00, 0.31784600E-01, -.90018100E+00, -.32702800E-01, 0.88134800E-01, -.58805600E+00, 0.16331300E+00, -.65328100E-01, -.56411800E-01, -.23188200E+00, 0.15317200E+01, 0.59740500E-01, 0.17485400E+00, 0.45648300E-01, 0.72593000E+00, 0.34268800E-01, -.82843800E+00, 0.61268900E+00, -.40958300E+00, 0.10124200E+00, -.32414200E+00, -.43645900E-01, 0.82347800E+00, -.88882400E+00, -.73348100E+00, -.23113000E+00, 0.15240100E+00, 0.81966400E-01, 0.10520000E-01, 0.17127200E-01, -.32326000E-02, -.76498500E+00, -.43084500E-01, -.19344400E+01, -.70549300E+00, 0.27878000E+00, 0.64983700E+00, -.76739600E+00, 0.14763000E+00, 0.10423800E+00, -.96775500E+00, 0.14639800E-01, -.43271800E-01, -.13795500E+00, 0.57758800E+00, 0.34374100E+00, 0.10571300E+01, 0.72018400E+00, 0.16489000E+01, -.17307400E+01, -.75150300E-02, -.11519300E+01, 0.28603700E-01, 0.89174500E-01, 0.15806200E+01, -.20582700E+01, 0.21903000E+00, 0.69848700E+00, 0.46549600E+00, -.39373100E+01, 0.18821200E+01, 0.17591200E+01, -.32427300E+00, 0.85349100E-01, 0.33253600E+00, -.32059100E-01, 0.44128600E+00, -.10831400E+01, 0.34312600E+01, 0.52731500E+00, -.71922500E+02, 0.15767700E+02, 0.27718100E+03, 0.10443900E+03, -.57610600E+02, -.23365500E+03, -.52189900E+02, -.13507000E+02, 0.81287100E+02, -.15231100E+03, -.88950600E+00, 0.40896300E+01, 0.54235200E+02, -.51990600E+02, -.86483900E+02, 0.38557800E+02, 0.31059300E+02, 0.38322900E+02, 0.74703100E+02, 0.18755300E+03, -.11461700E+03, -.90750200E+02, -.73584100E+02, 0.20129800E+03, 0.17182800E+03, -.14930900E+02, 0.10141700E+02, -.29428700E+01, -.53981900E+01, -.10818100E+01, -.40020300E+01, -.23278000E+02, 0.16152700E+01, -.14302500E+02, 0.60959400E+01, -.11836300E+01, -.51119000E+01, -.17949100E+02, 0.85523800E+00, 0.31082500E+01, 0.22104400E+02, 0.44251800E+01, -.35126000E+01, -.37030400E+01, -.51342700E+01, -.22128100E+02, -.23018600E+02, -.67628700E+01, -.72273400E+01, 0.64391600E+01, 0.10359500E+02 },
        { -.22007300E+01, -.89079600E+00, 0.64927500E+00, 0.12831200E+01, 0.16688500E+01, 0.93260000E+00, 0.72149200E+00, 0.10523100E+01, -.20765300E-01, 0.69031000E+00, 0.26662100E+00, 0.13972800E+00, -.22684100E-01, -.98126700E-01, -.57510000E-01, 0.21620500E+01, -.19003200E+01, -.43005000E+00, 0.12107900E+01, 0.62852900E+00, -.90853000E-01, -.10494100E+00, 0.13417900E+00, 0.62758500E+00, 0.18310300E-01, -.26775100E-01, 0.25031600E+00, 0.10012600E+01, -.38270300E+00, -.16670100E-01, -.32247100E+00, 0.21930300E+00, 0.19053600E+00, -.12855300E+01, -.66862100E-02, -.29371400E-02, 0.15614400E-01, -.14847500E+00, -.38299300E-01, 0.35385500E-01, 0.43555800E+00, 0.52850600E-01, -.27127800E-01, 0.16247800E+00, -.13611100E+00, -.24448000E+00, 0.40411800E-01, 0.78644600E-02, 0.18435400E+00, 0.92203100E-02, -.32168000E+00, 0.86197400E+00, -.11599900E+00, 0.43799500E+00, -.29166500E-01, 0.76177800E+00, 0.36819900E+00, -.94141900E-01, 0.14588700E-01, -.86762900E-01, -.35854100E-01, -.27630500E+00, 0.20708100E+00, 0.21347300E-01, 0.39748900E+00, 0.30637000E-01, -.17124000E+00, 0.68846700E-01, 0.33086100E-01, -.10721900E-01, -.26366400E-01, 0.15813200E+01, 0.19879400E+00, 0.27812400E-01, -.37428700E+00, -.18498800E+00, -.10332900E+00, -.12975900E+00, -.17759200E+00, -.44569200E-02, 0.53240300E-01, 0.36994000E-01, -.12945300E+00, -.75576400E-01, -.77881200E-01, -.12524400E+00, 0.87012100E-01, 0.11701900E+00, 0.10717000E+00, -.26838400E-01, -.17855800E+00, 0.21258400E-02, 0.17538900E-01, -.87953800E-01, -.14866000E+00, 0.26900600E+00, -.55168600E-01, -.10955300E+00, -.51849200E-01, -.10268000E+00, -.42188400E-01, -.63593800E-01, -.74359900E-02, 0.16180200E+00, 0.75216800E-01, 0.20881500E+01, -.42413600E-01, 0.93734700E-01, -.63922800E-01, -.21299300E+00, -.92449800E-02, 0.84619900E-02, -.33571000E+00, -.14734500E-01, -.83476400E-01, 0.11154700E+00, 0.96595400E-01, -.76101700E-01, 0.40917200E+00, -.50528500E+00, -.42602700E-01, 0.44196500E-02, -.18999900E-01, 0.13243300E+00, -.79826300E-02, 0.92722000E-01, 0.14570400E+00, 0.39377900E+00, 0.22749900E-01, -.44755300E-01, 0.87655500E-01, 0.74609800E-01, -.22257000E+00, -.17216900E-02, -.38949400E-01, 0.51318600E-02, -.96173200E-01, 0.64490500E-01, -.18759500E-01, 0.87730900E-01, -.20681200E-01, 0.34937300E-02, -.35932100E-01, 0.13166300E+00, 0.93253700E-02, -.10087400E+00, -.70247000E-02, -.65973900E-03, -.32419800E-01, -.21677700E-01, -.47616300E+00, -.74506100E-01, 0.25643000E-01, -.56515200E+00, 0.11345200E-01, -.16472000E+00, -.63280000E-01, 0.73859200E-03, -.40312400E+00, -.12787600E+00, -.29244100E-01, 0.31062700E-01, 0.50553100E-01, 0.80011600E-01, 0.19313600E+00, 0.63234700E-01, -.30776100E-02, -.14516000E+00, 0.55688800E-02, -.84928600E-01, 0.19217500E-02, -.29312200E-01, -.32753700E-01, 0.61567900E-01, 0.66028000E-02, 0.23608000E-01, -.60947700E-01, 0.67025100E-03, -.11906600E+00, -.68914000E-02, -.18116500E+00, -.14099100E+00, 0.52387600E-02, 0.14507200E+00, -.12897500E-01, -.51651800E-01, 0.79564100E-01, -.33229700E-01, -.20389200E-01, 0.14675600E+00, 0.12926900E-01, 0.29758500E-02, -.18161700E-01, -.68189700E-01, 0.39679400E+00, -.40331900E-01, -.14873100E-01, 0.63620500E-01, -.17226100E+00, 0.13225100E-02, 0.36472500E-01, 0.34724700E-01, 0.24981300E+00, -.44312600E-01, -.23737600E-01, -.17857500E-01, 0.46818700E-01, -.13070900E+00, 0.53511800E-01, 0.34963300E-01, -.70256100E-02, 0.10126000E-01, -.78104600E-02, -.15874300E+00, 0.12115400E+00, 0.87668300E-01, -.44801800E-01, -.31534300E-01, 0.32255300E-01, -.45933000E-01, -.60747200E+00, 0.19032100E-01, 0.51397800E-01, 0.42198500E-02, -.18242300E+00, -.21015600E+00, 0.41364600E-01, -.36004100E-01, -.11176900E+00, 0.73611800E+00, 0.32526700E+00, -.68725000E-01, -.46230900E-02, 0.25759000E-01, 0.37104400E+00, -.38315400E+00, 0.44869900E-01, -.74311800E-01, -.11952700E+01, 0.53131700E+00, 0.21965700E+00, 0.21821700E+00, -.23299800E+00, 0.42993400E-01, 0.66942500E-01, 0.44967800E-02, 0.39883000E-01, -.95166300E-01, 0.34737800E+00, -.65724700E-01, -.83272300E-01, 0.39198000E+01, 0.10728600E+02, -.59529500E+01, 0.20671400E+01, 0.15614200E+02, 0.30871400E+01, -.37626900E+01, 0.82551700E+01, -.93377700E+01, -.14024700E+02, -.14959300E+02, 0.74303000E+01, 0.24528900E+01, -.80190000E+01, 0.26821800E+01, 0.31542900E+02, 0.35316900E+01, 0.90371100E+01, 0.37005900E+02, -.21660200E+02, -.15064800E+02, -.14794900E+02, 0.32086400E+02, -.87064000E+01, -.30013200E+01, 0.36315800E+01, -.10278000E+01, -.15954100E+01, 0.13671800E+01, -.14595200E+01, -.59240800E+01, -.38840000E+01, -.34127600E+01, 0.23874400E+01, 0.47469500E+01, 0.10596200E+00, -.40899000E+01, -.15722600E+01, -.41224100E+01, -.27978700E+01, 0.13355800E+01, -.52215500E+01, -.13371400E+01, -.15558900E+01, -.47010100E+01, 0.26812600E+01, 0.63718800E+01, -.52981800E+01, -.44761100E+01, 0.31035600E+01 },
        { -.38459100E+01, 0.56546400E+00, 0.15808500E+01, 0.15981000E+01, 0.21956600E+01, 0.77062700E+00, 0.13487300E+01, -.11762800E+01, -.26567400E+00, 0.11500400E+01, -.15563100E+00, -.59580600E-02, 0.47518900E+00, -.19177500E+00, 0.83098600E-01, 0.98483900E+01, -.54712600E+01, 0.79297500E+00, 0.18353400E+01, 0.87689000E-02, -.25750500E+01, -.42506400E+00, -.55358000E-01, -.78930100E+00, -.51218800E+00, -.12180700E+00, -.51072700E+00, -.10055500E+01, 0.71567500E+00, -.40567800E-01, -.53671100E+00, -.28163800E+00, -.17079900E+00, -.83274200E+00, -.46645400E-01, -.19058100E+00, 0.74722300E-01, 0.87146700E+00, 0.12388700E+00, 0.39273300E+00, 0.51781300E+00, -.31707500E-01, -.81872500E-01, -.11940300E+00, -.49239200E-01, 0.37578400E+00, -.37770200E-01, 0.30309400E-01, -.29165100E-01, 0.56979200E-01, 0.27740100E-01, -.41630400E+00, -.46733200E-01, -.59917800E-02, 0.21631600E-01, 0.21826300E+00, 0.21419200E+00, 0.66191100E-01, 0.37768600E-01, 0.57191500E+00, -.13083500E+00, 0.70612000E+00, -.19359000E-01, 0.56271600E-01, 0.46861900E+00, -.88530700E-01, 0.52011200E-01, 0.11133000E+00, 0.14426600E+00, 0.66478200E-02, -.75710100E-01, 0.13783900E+01, -.12860900E-01, 0.79375800E+00, -.40437300E+00, 0.16825300E+00, -.64654400E-01, 0.45291100E-01, 0.18510600E+00, 0.23229000E-01, 0.97345200E-02, -.35437200E-01, -.31168700E+00, -.40546100E+00, -.11937800E-01, -.38569200E-01, -.48155200E-01, 0.84532900E-01, 0.55919200E+00, -.22872500E-01, -.10843300E+00, -.29060500E-03, 0.74400400E+00, -.24152600E-01, -.12654400E+00, 0.93533600E+00, 0.59513400E-01, 0.30139500E+00, 0.15559500E+00, 0.54531300E+00, -.38459000E-01, 0.14746000E-01, 0.88618800E-02, -.15019900E+00, -.55799300E-02, 0.19565900E+01, -.35871600E+00, 0.28910200E+00, -.15402100E+00, -.78571700E+00, 0.39689200E+00, 0.20258200E-01, 0.55965000E+00, -.39531100E-01, -.51916600E+00, 0.35015000E+00, 0.26151100E+00, 0.79753200E-01, -.97774000E-01, -.92452600E+00, -.48248800E+00, -.76615800E-02, -.53983000E-01, 0.60471800E-01, -.15032200E-01, -.49314600E+00, -.21890700E+00, 0.66406000E+00, 0.49613200E+00, 0.13556800E+00, -.84383300E+00, -.28149500E+00, -.89563300E+00, 0.44967500E+00, -.10118300E+00, -.40425300E-01, 0.77977100E+00, 0.35652500E+00, -.67707800E-01, -.95067800E+00, 0.18518100E+00, -.27957000E+00, 0.21263100E+00, -.26085000E+00, 0.72639000E-02, 0.77415700E+00, 0.20631400E-01, -.65236600E-02, -.10581400E+00, 0.40300400E-02, -.25295800E+01, 0.24342800E+00, 0.12349600E+00, 0.32024800E+00, -.79462900E-02, 0.11362200E+00, 0.12499700E+00, -.95320100E-03, 0.54694100E+00, 0.10717900E+00, 0.20399100E-02, 0.40150300E-01, -.78103900E-01, -.65759200E-02, -.19571600E+00, 0.13791500E+00, -.14364500E-01, -.87360600E+00, 0.58115800E-02, -.54754300E+00, 0.30898600E-01, -.44851100E-01, -.69501300E-01, 0.49915200E-01, -.29476900E+00, 0.16569400E-01, 0.37650000E+00, -.55494500E-02, 0.24584500E-01, -.55469400E-01, -.21267100E+00, -.25853600E+00, 0.24210400E-02, -.83250300E-01, 0.92228800E-01, -.67044800E+00, 0.53382700E-01, 0.21340300E+00, -.11238600E-02, 0.22871200E+00, -.19476500E+00, 0.61243000E-01, -.18317700E+00, -.30669500E+00, -.81327400E+00, 0.26274300E-01, 0.76943000E+00, -.12462900E+00, 0.99270800E-02, -.51788500E-01, -.26501100E-01, 0.29668100E-01, 0.85913700E+00, 0.23015400E+00, 0.32973100E+00, -.53510400E-02, -.17005100E-01, -.41501700E+00, 0.11315300E+00, 0.44591100E-02, 0.68044500E-02, 0.14591400E+00, -.15097400E-01, 0.46351500E+00, 0.44127200E+00, 0.15243100E+00, 0.54626600E+00, -.48422300E+00, 0.17246000E+00, 0.10308000E+00, 0.28856100E+00, -.45265900E-01, -.53235500E-01, 0.19269100E-01, 0.46998300E+00, 0.54078200E-01, -.53308000E-01, -.98008900E-01, 0.31375600E+00, -.25186300E+00, -.24320900E+00, 0.38950200E+00, 0.10352600E-01, -.34185900E-01, -.28819000E+00, -.60761300E+00, -.68564300E-01, 0.34280100E-01, -.19185000E+01, 0.37447300E+00, 0.70868100E+00, 0.26387900E+00, 0.76137600E-01, 0.12411300E-01, 0.14010000E+00, 0.90366100E-02, -.24338100E-01, 0.70695900E-01, -.52689100E+00, -.76579400E-01, -.19352200E+00, -.94396700E+00, 0.63032200E+02, 0.18578300E+02, -.12011800E+02, -.54699700E+02, -.92119900E+01, -.12437200E+02, -.26592100E+01, -.60422700E+01, -.12010100E+02, -.15867700E+02, -.83395700E+01, 0.58521500E+00, -.53292600E+01, -.56105600E+01, 0.13605600E+03, 0.21250600E+01, 0.21371000E+02, 0.65927800E+02, -.43739200E+02, -.11410200E+02, -.88952900E+01, 0.52439600E+02, 0.71216500E+02, -.88697300E-01, 0.71379500E+01, 0.93789200E+01, 0.85351300E+01, 0.75313000E+00, -.86429200E+00, -.98911100E+01, -.69998100E+01, -.70039900E+01, 0.52985600E+01, 0.68227900E+01, 0.38097100E+00, -.68845800E+01, -.14160800E+01, -.74161600E+01, -.18558000E+01, -.87589900E+01, -.52298600E+01, 0.88368600E+01, -.16454000E+01, -.71349700E+01, 0.13943600E+01, 0.69886500E+01, -.84184800E+01, -.59720100E+01, 0.80592100E+00 },
        { 0.49318200E+01, 0.16283600E+01, -.14004900E+01, -.30315300E+01, -.29526700E+01, -.14691600E+01, -.87702900E+00, 0.21399400E+01, 0.30465700E+00, -.56218200E+00, -.25031900E+00, -.41580400E+00, -.59395400E+00, 0.14042000E+00, 0.29086100E+00, -.58863400E+01, -.10249300E+01, -.23669100E+00, -.91574200E+00, 0.44781300E+00, 0.26469500E+00, -.57930800E-01, -.37355400E-01, -.84030400E+00, 0.50057400E-01, 0.32373100E-01, 0.29905000E-01, -.71654500E+00, 0.21484500E+00, -.47568100E-02, 0.15714900E+00, 0.70636200E-01, -.15010500E+00, -.28754700E+00, 0.72897500E-02, 0.67761700E-01, -.49412100E-02, -.14889400E+00, 0.15278200E+00, 0.14147900E+00, -.25496400E+01, -.19583400E+00, 0.59507700E-01, -.20049700E+00, 0.50404900E+00, 0.10744800E+00, -.41082800E-01, 0.36233200E-01, 0.15260900E+01, -.12663900E+00, 0.72594700E+00, -.19834600E+00, -.26093900E+00, -.83296700E+00, -.76321900E-01, -.21605000E+01, -.79226000E+00, 0.15052500E+00, 0.21440200E-01, 0.37785300E+00, -.20523400E+00, 0.52764600E+00, -.27015000E+00, 0.50553100E+00, -.79903900E-01, 0.34116900E+00, 0.50117300E-01, -.26260700E+00, -.17475600E+00, 0.13703700E-01, 0.10696500E-01, -.45715100E+01, -.52381300E+00, 0.87153800E+00, 0.12859300E+01, 0.12820100E+01, 0.68202800E-02, -.72304900E-01, 0.93558800E+00, 0.10071200E+00, -.44359000E-01, -.10012600E+00, -.87648000E-01, -.32810600E+00, 0.11428600E+00, 0.27918400E+00, 0.20018500E+00, -.32688300E+00, 0.81768000E+00, -.31462400E-01, 0.13311100E+01, 0.38184900E-02, -.19302900E+00, 0.78518700E-01, -.29373000E+00, 0.30672200E+00, -.46577500E+00, -.16496300E+00, 0.23115600E+00, 0.29010500E+00, -.51076700E-02, -.80181700E-01, 0.19950700E-01, 0.22106000E+00, -.35737700E+00, -.42316200E+01, 0.48902800E+00, -.45298400E+00, -.94153700E-01, 0.22638300E+00, 0.58709400E+00, -.18989400E-05, 0.23973400E+00, 0.11738300E-01, -.16447100E+00, 0.19067500E+00, 0.22089100E+00, -.37118900E+00, -.44515100E+00, -.39200800E-01, 0.24962900E+00, 0.12835100E-02, 0.12938000E-01, 0.26583000E+00, 0.37147400E-02, 0.39683000E-01, -.73023100E+00, -.13246600E+01, 0.10823000E+01, 0.47996500E+00, -.27493700E+00, -.41994600E-01, -.98261700E-01, -.86944500E-01, 0.29096800E+00, 0.10700200E-01, -.97100200E+00, 0.47282200E-02, 0.27618100E+00, 0.56007900E+00, -.10587200E-01, -.37378000E+00, 0.74078200E+00, 0.62384500E+00, 0.52573000E-01, 0.10468800E+01, 0.88396400E-01, -.75351000E-01, 0.77698700E-01, -.41977400E+00, 0.15588100E+01, 0.11589700E+00, -.17072200E+00, 0.19094400E+01, 0.75015300E-01, 0.43739700E+00, 0.29920900E+00, -.39313600E-03, 0.15424100E+01, 0.40946300E+00, 0.10540800E+00, 0.49150700E-01, 0.58370000E-01, 0.11112500E+00, 0.18570900E+00, -.20551800E+00, -.58426400E-01, -.28204300E+00, -.19308000E-02, -.38298200E+00, 0.15891400E+00, -.90693200E-01, 0.10646800E+00, -.11361100E+00, -.36643300E+00, 0.21428500E+00, 0.11103800E+00, -.76462600E-02, 0.28880800E+00, -.11630800E+00, 0.33760700E+00, 0.23029000E+00, 0.65694500E+00, -.11879400E+00, -.59595300E-01, 0.16763600E+00, 0.28905900E-01, 0.49920800E+00, -.17875100E-01, 0.21020500E+00, 0.91954900E-01, -.21430500E+00, -.29352900E+00, 0.10681600E+00, 0.12532000E+01, 0.56898500E-01, 0.50698500E-01, -.22780200E+00, 0.14781200E+00, 0.73799600E-03, 0.21099600E+00, -.18665100E-01, -.11400700E+01, 0.72836500E+00, 0.76523000E-02, -.12890900E+00, 0.26632900E-01, -.17838300E+00, 0.10149400E+00, -.44744100E-01, 0.92847000E-02, 0.61225200E+00, 0.32864600E-01, 0.14789900E+01, 0.71981700E+00, 0.47377800E+00, 0.10406000E+01, -.70751500E+00, 0.20065100E-01, -.48828300E+00, 0.13811900E+01, -.14522100E+00, 0.46024500E-01, -.63707300E-02, -.37655900E+00, -.46150700E+00, -.56577100E+00, 0.62889000E-01, -.18055900E+00, -.10930300E+01, -.21265700E-01, -.42169500E+00, 0.23819300E-01, -.35405300E-01, -.33372600E+00, -.68602600E+00, -.77802000E-01, 0.11883600E+00, -.32829300E+01, -.15470100E+01, 0.10105700E+01, -.44319600E+00, 0.80174800E+00, 0.10804700E-01, 0.48711300E-01, 0.91412800E-02, -.12864000E-01, 0.14211000E-01, 0.86203700E+00, 0.64825300E-02, -.18774800E+00, 0.16099400E+00, 0.31739500E+00, 0.27248800E+02, -.14357200E+02, -.15629200E+02, -.13564400E+02, -.20371500E+01, 0.22840800E+02, -.43420300E+02, 0.39826000E+01, -.10870100E+02, 0.18511700E+02, -.20160700E+02, -.24785700E+02, 0.17851400E+02, -.11120000E+02, 0.12127900E+02, 0.32851600E+02, 0.47024300E+02, -.16609400E+02, 0.64527400E+01, -.20251000E+01, 0.57980900E+02, 0.72654100E+02, -.53560500E+01, 0.81371700E+00, -.27532900E+01, -.31090600E+01, -.35932700E+00, -.10814800E+01, -.90778700E+01, -.23905600E+00, -.34042100E+01, 0.16512300E+01, 0.28456200E+00, -.17457500E+01, -.70837800E+01, 0.49860700E+00, 0.23952900E+00, -.12098700E+01, 0.26474500E+01, -.50982100E+01, -.28045000E+01, -.13937400E+01, -.47943100E+01, 0.13736700E+01, 0.40642900E+01, 0.94195900E-01, -.57379800E+00, 0.29090200E+01 },
        { -.12596200E+02, 0.59259500E+01, 0.98008500E+00, -.39141200E+01, 0.53711600E+00, -.27482200E+01, -.22019100E+01, -.21037600E+01, -.31851700E+01, 0.80415700E-01, 0.58325300E+00, 0.61362900E+00, 0.35438600E+01, -.61420400E+00, -.10533700E+00, -.80405300E+01, 0.77773800E+01, -.19747000E+01, 0.36292500E+01, 0.55859900E+00, -.82926700E-01, -.17020400E+01, -.65780400E+00, 0.35966200E+01, -.13572400E+01, 0.29603600E+00, 0.29226600E+01, 0.53264500E+01, -.87659900E+01, 0.11238100E+00, 0.14421800E+01, -.11941900E+01, -.17595500E+01, -.57096000E+01, 0.51804700E+00, 0.14076500E+00, 0.38693600E-01, 0.52129400E+01, 0.11598800E+01, -.45668400E+00, 0.55934800E+01, -.77836900E+00, -.18066500E+00, -.10134100E+00, -.11143800E+01, 0.11985400E+01, -.16369600E+00, -.16582900E+00, -.89490700E+00, 0.21643500E+00, -.13793600E+00, -.45551600E+01, 0.20031200E+01, -.36676700E+01, 0.10938400E+00, -.16132200E+01, -.12810400E+01, 0.83575000E-01, -.13034900E+00, -.20078900E+01, 0.52901500E+00, 0.43702500E+00, -.48642000E+00, -.13264500E+01, -.36327900E+01, -.88954200E+00, 0.10089000E+00, 0.83809400E-01, -.15586600E+01, -.15635100E-01, 0.14621800E+00, -.87527700E+01, -.12508100E+01, 0.79561600E-01, 0.15132900E+01, -.28133600E+01, 0.18653000E+00, 0.30296900E+01, -.19530600E+01, -.81799000E+00, -.17344100E+00, 0.51832800E+00, 0.46778100E+00, 0.78649300E+00, -.52388700E-01, -.15080400E+00, 0.46727800E+00, -.59251100E-01, 0.26878600E+00, 0.34463800E+00, 0.62244600E+00, 0.17274400E-02, 0.80774800E+00, 0.11659600E+00, -.32471100E+00, 0.36881200E+00, 0.42451900E+00, 0.93372400E-01, 0.14716000E+00, -.50976600E+00, 0.17750600E+00, 0.36897700E+00, 0.25202100E-01, 0.24424600E+00, -.28144000E+00, -.21854100E+01, -.39130700E-02, -.40124900E+00, -.31886800E+00, -.21736500E+00, 0.66629700E+00, -.42945200E+00, -.94201600E+00, 0.18426800E-01, 0.29543200E+00, 0.14844700E+01, -.45776300E-01, -.42968800E+00, 0.99898300E+00, 0.63911100E+00, 0.61387900E+00, -.14635000E+00, 0.63924000E+00, -.84029600E-01, -.61855100E-01, -.33162400E+00, 0.18568200E+00, -.35102500E+00, -.44216600E+00, 0.38778100E+00, -.11068500E+01, -.71818500E-01, 0.97260600E+00, 0.60498000E+00, -.61045500E-01, -.64096700E-01, 0.15186100E-01, -.13560900E+00, 0.80264900E-01, 0.94764200E+00, 0.18440000E+01, 0.39881200E+00, 0.56726400E+00, 0.33318700E-01, -.22857600E+00, -.64508800E+00, 0.12207000E+00, -.54700500E+00, 0.15306300E+00, -.81962000E+00, -.39287200E+01, -.72682400E+00, -.87344200E-01, -.27583700E+00, 0.19789900E+00, -.40307400E-01, 0.13605200E+00, 0.91167700E-02, 0.46907600E+00, 0.46340100E+00, -.14209500E+00, 0.28293700E+00, -.14829500E+00, 0.19499600E+00, 0.13868600E+01, 0.65572000E-01, 0.17145600E+00, 0.23695400E+00, -.29284000E-01, 0.20195800E+00, 0.52645800E-01, -.16387300E+00, 0.97056100E-01, 0.11530900E-01, 0.71364100E+00, -.53457800E-01, -.62906700E+00, -.31795900E+00, -.14707200E+00, 0.11472300E+00, 0.13203300E+00, 0.21397200E+00, 0.90103200E+00, 0.56932000E+00, -.39763500E+00, 0.11427300E+00, 0.10022800E+00, -.53190300E+00, -.37270200E-01, -.45715700E+00, 0.28855000E+00, 0.21993600E-01, -.24207100E+00, -.28547200E-01, -.14547900E+01, -.19110200E-01, 0.31469400E+00, 0.33799400E+00, 0.24493800E+00, -.14024300E+00, -.32902500E-01, 0.18490500E+00, -.77598800E+00, 0.94211200E+00, 0.41117100E+00, -.92178400E-01, -.20752300E+00, -.18212200E+00, 0.25613500E+00, 0.16068000E+00, -.16328400E+00, -.34584300E+00, 0.39228800E-01, 0.24236300E+00, 0.10422200E+01, 0.41806200E+00, 0.11841900E+01, 0.36760700E+00, -.59911000E+00, 0.23523100E+00, 0.37259900E+01, -.46264600E-01, 0.16860800E+00, -.42044200E-01, -.74505700E+00, 0.21994200E+00, -.10040000E+00, 0.38279800E+00, -.16928300E+00, -.22806700E+01, 0.18258100E+00, -.66005000E+00, 0.56918300E-01, 0.18856800E-02, -.14359100E+00, -.87455200E+00, -.13616600E+00, 0.26680400E+00, 0.90127000E+00, -.16891600E+01, 0.40895000E+00, 0.16968000E+00, 0.73195200E+00, 0.46994000E-01, 0.24506700E-01, -.23208900E-01, 0.64023900E-01, -.51991600E-01, 0.93225500E+00, 0.67322800E-02, 0.73368800E-01, 0.56127600E+00, -.93539800E-01, -.13803900E+01, 0.74402400E+02, 0.17660700E+02, 0.32197200E+00, -.13204000E+02, 0.30186000E+02, -.66119600E+02, -.12237800E+02, -.17891400E+02, 0.14555100E+02, -.36902100E+02, -.28013400E+02, 0.22114100E+02, 0.53235300E+02, 0.13706700E+02, 0.85154600E+02, 0.96859700E+02, -.20363000E+02, 0.39768000E+02, 0.57822000E+01, 0.10140300E+03, 0.51532000E+02, -.91720000E+01, 0.19877900E+01, 0.68661100E+01, 0.66686500E+01, 0.12222800E+01, -.43373100E+01, -.20552500E+02, -.25180300E+01, -.83569200E+01, 0.30942800E+01, 0.17537600E+01, -.34171100E+00, -.14697900E+02, -.11866400E+01, -.19045500E+01, -.31863000E+01, -.72899400E+01, -.14142400E+02, 0.69140600E+01, -.44075400E+01, -.11812100E+02, 0.33374800E+01, 0.11081000E+02, -.11534000E+01, -.68184600E+01, 0.60438700E+01 },
        { 0.20689000E+02, 0.54565200E+01, -.57241800E+01, -.97908800E+01, -.81706400E+01, -.63046100E+01, -.79715400E+01, 0.11024400E+02, 0.10210100E+01, 0.55996200E+00, -.82157000E+00, -.15293000E+01, -.18700600E+01, 0.63491700E+00, 0.30826300E+01, -.64925600E+02, -.13676200E+00, -.38786000E+01, -.11334200E+02, -.11171600E+01, 0.62752800E+01, 0.17541700E+01, -.10564500E+00, -.13835100E+01, 0.12224800E+01, 0.22518300E+00, 0.50960500E+00, -.51005500E+00, 0.27816200E+00, -.32142100E+00, 0.29369500E+01, 0.82005800E+00, -.13805900E+01, -.73945500E+01, 0.69086800E-01, 0.16758000E+00, -.68565000E-01, 0.71706400E+00, 0.39603000E+00, 0.90917400E+00, -.11273400E+02, 0.51093000E+00, 0.40702400E-01, -.17851800E+00, 0.40541400E+00, 0.56554200E-01, -.17566400E+00, -.32913400E-01, 0.50884000E+01, -.52135400E+00, 0.61768300E+00, -.30865500E+01, -.10450100E+01, -.88928700E+01, -.68639200E+00, -.55748500E+01, -.40131500E+01, 0.38132400E+00, 0.13783100E+00, -.69133000E+00, 0.23284300E+00, 0.87843600E+00, -.16307400E+01, 0.13647900E+01, -.54834100E+00, 0.13911000E+01, -.79666700E+00, -.79800900E+00, 0.23905300E+00, 0.18665100E-02, 0.13642400E+00, -.51483800E+01, -.12423900E+01, 0.85152500E+01, 0.30824100E+01, 0.12636300E+01, -.17162500E+00, 0.10187800E+01, 0.15498700E+01, 0.26581100E+00, 0.30381500E+00, -.52069200E-01, -.23678400E+00, -.73669300E+00, 0.76295900E+00, 0.16745100E+00, -.13261200E+01, -.60085300E+00, -.23874500E+01, -.50995800E+00, 0.26395500E+01, -.19606300E-01, -.20807500E+01, -.61765800E+00, -.12599800E+01, 0.17663700E+00, 0.74821300E-01, 0.26775500E+01, 0.25416600E+00, 0.14133900E+01, -.47477200E+00, 0.60636200E+00, -.94115100E-01, -.36102000E+00, -.63698200E+00, -.10154300E+02, 0.59594300E+00, -.17783000E+01, 0.44368300E+00, 0.14186400E+01, -.29302100E-01, -.16485400E+00, -.18207900E+01, -.25982400E-02, 0.80622400E+00, -.14311100E+00, 0.31965700E+00, -.98725900E+00, 0.14279100E+01, 0.41472200E+01, 0.30943900E+01, -.31745400E+00, 0.44102900E-01, -.76366900E+00, -.20212800E+00, -.11214800E+01, -.15431100E+01, -.73548700E-01, -.46992700E-02, 0.63399000E+00, 0.31887100E-01, -.80704100E+00, 0.12165700E+00, 0.20432600E+01, -.52907800E+00, -.14334500E+00, 0.16700300E+01, 0.41726200E+00, -.20033600E+00, -.92832300E-01, 0.93587400E+00, 0.35345900E+00, 0.24354600E+01, -.82333500E+00, 0.19958200E-01, 0.20085200E+01, 0.28820700E+00, -.98798400E+00, 0.27305400E+00, -.34762400E+00, 0.42354800E+01, -.52014300E+00, -.30784900E+00, 0.57788700E+00, -.19929200E-01, -.39549900E+00, 0.61775600E-01, 0.17901300E-01, 0.92746000E+00, -.18989700E+00, 0.22200500E-01, -.79770700E+00, 0.74027800E-01, -.76248100E+00, -.70553600E+00, 0.72546500E-01, 0.73843300E-01, 0.82076100E+00, -.75095800E-01, 0.12199000E+01, 0.39517200E+00, 0.89994900E-01, 0.23250600E+00, -.31867500E+00, 0.10045600E+01, 0.60128700E-01, -.18039500E+00, -.60168700E-01, 0.54115600E+00, 0.75625400E-01, 0.70663900E+00, 0.93542000E+00, -.19620300E+01, -.34865800E+00, 0.64068100E-02, 0.95967900E-01, -.28691900E-01, -.78317600E+00, 0.97500500E-01, -.48780600E+00, 0.19619600E+01, 0.87398700E-01, -.91699900E-01, 0.96071000E-01, 0.61502800E+00, 0.39878500E+00, -.43189100E+00, 0.24232400E+00, 0.12278500E+01, 0.49167300E-01, -.14499500E+00, 0.74336900E-01, -.79237200E+00, 0.15783600E+01, 0.11688500E+01, 0.39106400E+00, -.49934400E+00, -.80932000E+00, 0.68707500E+00, 0.75696900E-01, -.52021300E-01, -.15214600E+00, -.23702800E-01, 0.15317200E+01, 0.42820600E+00, 0.51475300E+00, 0.14379400E+01, -.12609900E+01, -.14431100E-01, 0.62920000E+00, 0.11520700E+01, -.26456100E+00, 0.12561500E+00, -.49938400E-02, -.11598400E+01, 0.61554300E-01, -.76143400E+00, -.23805100E+00, -.30826000E+00, 0.17721900E+01, -.95184300E+00, 0.99734400E+00, 0.14833700E-01, -.28560000E+00, 0.66057800E+00, 0.47323000E+00, -.95737700E-01, -.17931300E+00, 0.68417500E+01, 0.26399600E+01, -.30524600E+00, 0.47073600E+00, -.13468700E+00, -.18377400E-02, -.28745400E+00, 0.29148800E-01, -.65001600E+00, -.21813600E+00, -.44274800E+01, -.60557900E-01, 0.21559600E+00, -.11465200E+00, -.33919200E+01, 0.14682000E+01, -.11583600E-01, -.36185300E+03, -.93533700E+00, -.25768400E+02, -.16115400E+03, 0.20951300E+03, -.29858100E+02, 0.28608100E+02, -.15543700E+03, 0.59029500E+02, 0.10489400E+03, -.10171200E+03, 0.36354100E+03, -.49075600E+02, -.10178800E+03, -.75380200E+02, -.29635400E+02, -.94321000E+02, 0.22615800E+02, -.14693200E+03, -.25295100E+02, 0.37597700E+02, 0.23411400E+02, 0.35975900E+02, 0.34221500E+02, -.48692300E+01, 0.12407100E+02, 0.26666000E+02, -.21117300E+02, -.69917100E+01, 0.14609600E+02, 0.23852300E+02, 0.50941900E+01, 0.20676300E+02, 0.26115400E+01, -.24581200E+02, 0.14549600E+01, -.33620800E+02, 0.22903000E+02, 0.33682600E+02, 0.11098700E+02, 0.80388600E+01, -.34731600E+01, -.54085700E+01, -.26081100E+02, -.48630200E+01, -.21925700E+02 },
        { -.12646600E+02, -.36639500E+01, 0.16893000E+01, 0.59657100E+00, 0.87140000E+01, 0.54608500E+01, 0.24776200E+01, 0.26328200E+02, -.11509500E+01, 0.51320900E+01, 0.41039000E+01, 0.87302000E-01, 0.92062500E+00, -.73099400E+00, -.86689100E+00, -.97260500E+01, -.70192500E+01, -.55501600E+01, 0.10420100E+01, 0.22999900E+01, 0.47524200E+01, 0.17923300E+00, 0.26448000E+00, 0.22142300E+01, -.30516600E+00, -.13875100E+01, -.13475600E+00, 0.10057600E+01, 0.32448900E+00, -.29965300E-01, -.89169100E+00, -.13177100E+01, 0.56879000E+00, -.16070300E+01, -.14628400E-01, -.15553900E+00, 0.42016200E-01, 0.45228400E+00, -.63814000E-01, 0.13646700E-01, 0.90066400E+00, 0.16202900E+00, -.91058000E-01, 0.45475400E-01, -.73898900E+00, 0.32827600E-03, -.86159400E-01, -.30644200E-01, -.98009200E+00, 0.92934100E-01, -.73267900E+00, -.15985500E+01, 0.29072100E-01, -.11103300E+01, -.39851500E+00, -.46964700E+00, -.83691100E+00, -.16929700E+00, -.10096700E-01, -.36396700E+00, 0.17086100E+00, -.20535300E+00, -.23443800E+00, -.24646800E+00, 0.12330500E+00, 0.79985900E+00, 0.66377900E+00, 0.17363000E+00, -.39990300E-01, -.17321300E-01, -.83706900E-01, -.97663000E+00, -.27151300E+00, -.23979600E+01, 0.81896200E-01, -.65968000E-01, 0.14625400E+00, -.11300000E+01, 0.34379700E+00, -.66839800E-01, -.15129200E-01, 0.21566200E-01, -.26533600E+00, -.86837200E+00, -.31506800E+00, 0.20037300E+00, 0.44179800E+00, -.13613000E-01, 0.60861300E+00, -.58880800E-01, 0.27320800E+00, 0.53710300E-02, 0.64438300E+00, 0.10437500E+00, -.15591300E+01, -.19368000E+00, -.22061300E+00, -.15134500E+00, -.21571900E-01, -.42970900E+00, 0.40081300E-01, -.15885100E+00, -.32290700E-01, 0.56121300E+00, -.19000600E+00, 0.14656900E+01, 0.35794600E+00, -.41430300E+00, -.27641400E+00, -.25619400E+00, 0.63373300E+00, 0.67264900E-02, 0.54691300E+00, -.67867900E-01, -.31121500E+00, 0.70710100E+00, 0.31244700E+00, -.45988300E+00, -.19026100E+00, 0.34881000E+00, -.33105100E+00, 0.19057700E+00, 0.96657500E-01, -.39532300E+00, 0.18936400E+00, -.91328800E+00, -.10848600E+00, 0.64748900E+00, -.83419300E+00, 0.37452100E+00, -.14587200E+01, 0.32436200E+00, 0.45346100E+00, -.35951900E+00, -.19794000E+00, 0.10113900E-01, 0.81526200E+00, -.14330100E+00, 0.10105600E+00, 0.64319300E+00, 0.37666100E+00, -.74089800E-01, 0.22020800E+00, -.41626900E+00, -.29804700E-01, -.64500200E+00, -.11437500E+00, 0.10382300E+00, -.99685800E-01, -.37122200E+00, -.31312400E+01, -.63771500E+00, 0.29995000E+00, 0.12784900E+00, 0.12928300E+00, 0.20969800E+00, 0.90112200E-01, -.10381900E-02, 0.12025700E+00, 0.36052600E-01, -.81967900E-02, 0.43835000E-01, 0.40084800E-01, 0.11759600E+00, 0.73551900E+00, -.29420100E+00, 0.26965600E-01, -.46423300E+00, 0.63182100E-02, -.23150000E+00, 0.23451100E+00, -.15353200E+00, -.42712700E-01, 0.11406200E+00, 0.46791600E+00, -.13900400E+00, -.30911600E+00, -.48186100E-01, 0.43750900E-01, 0.35405100E+00, 0.40955000E+00, 0.32008200E+00, 0.31046300E+00, 0.15237500E+00, -.41739300E+00, -.16093600E-01, 0.17203900E+00, -.54586500E+00, -.62821900E-02, -.32606600E+00, 0.81446300E+00, -.17024700E+00, -.30715300E+00, -.69679900E-01, -.34421900E+00, 0.28238400E+00, 0.38269400E+00, 0.39420500E+00, 0.77047500E+00, 0.12826400E-01, 0.49318900E-01, 0.53423600E-01, -.13550000E+01, 0.12737400E+01, 0.66279600E+00, 0.58761100E-01, -.42002800E+00, -.27050700E+00, 0.36584300E+00, 0.13734800E+00, -.16096900E-01, -.10489900E+01, -.15397800E+00, 0.26614800E+00, 0.80628000E+00, 0.48706900E+00, 0.82523500E+00, 0.58545900E+00, -.73186700E+00, 0.26195400E+00, 0.54256400E+01, 0.15769300E-01, 0.19344200E+00, -.77485100E-01, -.99351600E+00, 0.52785200E+00, -.17995800E+00, 0.52869200E+00, -.31490900E-01, -.19172100E+01, 0.96390400E-01, -.85775400E+00, 0.27505300E-01, -.45904600E-03, -.37918200E+00, -.96113600E+00, -.75906500E-01, 0.32386500E+00, -.10414400E+01, -.16817200E+01, 0.94058700E+00, 0.24257400E+00, 0.11154700E+01, -.12993900E-01, -.59259800E-01, 0.71741300E-01, 0.43867200E-02, -.62058300E-01, 0.10524600E+01, -.70984300E-01, 0.18284800E-01, 0.61940100E+00, -.79589900E-01, -.11777200E+01, -.29029900E-01, -.30087500E-01, 0.22694800E+02, -.14426000E+02, 0.22404800E+02, -.55140000E+02, -.96981700E+01, -.15009900E+02, 0.75105000E+01, -.34146100E+02, -.25579900E+02, 0.17050600E+02, 0.52189400E+02, 0.81059000E+01, 0.74295200E+02, 0.90807900E+02, -.23041900E+02, 0.21151100E+02, -.37667000E+01, 0.95840500E+02, 0.51691200E+02, -.79625800E+01, 0.30638300E+01, 0.62013600E+01, 0.58169700E+01, 0.75958100E+00, -.33972300E+01, -.18438000E+02, -.34129200E+01, -.80725300E+01, 0.35799900E+01, 0.29360200E+01, -.20827600E+00, -.13118500E+02, -.88108000E+00, -.28914300E+01, -.37044200E+01, -.64192800E+01, -.12087200E+02, 0.61272400E+01, -.34951400E+01, -.11088600E+02, 0.38025400E+01, 0.10342400E+02, -.23593500E+01, -.61099000E+01, 0.53440600E+01 },
        { 0.47550800E+01, 0.98953800E+00, -.66620500E+00, -.14460000E+01, -.36052400E+01, -.81293900E+00, -.50181400E+00, -.16460400E+01, 0.29847000E+00, -.12365500E+01, -.58161500E+00, -.24956900E+00, -.46479400E+00, 0.35745100E+00, 0.33030700E+00, 0.82586600E+00, 0.21358600E+00, 0.11456600E+01, 0.29318000E+00, 0.22477100E-01, -.11548500E+01, -.10189600E+00, -.35802300E-01, -.66592200E+00, -.78864000E-01, -.94120100E-01, -.76900500E+00, -.46597400E+00, 0.23971200E+01, -.79059400E-01, 0.54017400E+00, -.61196500E+00, -.63852800E+00, 0.11304300E+01, 0.29300600E-02, 0.68507400E-01, 0.68151000E-01, -.42176400E+00, 0.17478800E+00, -.18841500E+00, -.19762600E+01, 0.13331500E-01, 0.10248700E+00, -.17756000E+00, 0.22817100E+00, 0.62971700E+00, -.64534000E-01, 0.84779700E-01, 0.11777000E+01, -.12294000E+00, 0.53731600E+00, 0.18554600E+00, -.47277300E-01, 0.17018100E+00, -.35229000E+00, -.92734700E+00, -.25301200E+00, -.11781500E+00, 0.67691000E-01, 0.14693500E+00, -.11419000E+00, 0.54806400E+00, 0.40120000E+00, 0.13003400E+00, 0.23450900E+00, 0.27360400E+00, -.89129200E+00, -.43083700E+00, 0.18613400E-01, -.24719900E-02, 0.39406700E-01, -.25299900E+01, 0.82692100E+00, 0.44549100E+00, -.22517100E+00, 0.45853600E+00, 0.36676600E+00, -.25375700E+00, 0.11598900E+00, 0.19809300E+00, 0.24488600E-01, -.10178600E-01, 0.24975600E+00, -.38251300E+00, 0.26355100E+00, 0.28750000E+00, 0.61403500E+00, 0.31918000E-01, 0.12264600E+01, 0.65619600E-01, 0.81611700E+00, 0.99761100E-02, -.49024300E+00, -.10845100E+00, -.14110000E+01, -.13418100E+01, -.26348200E+00, -.82820200E-01, -.18129100E+00, -.47325500E-01, 0.17779900E-01, 0.20336100E+00, 0.33411000E-01, 0.26004700E+00, -.23205800E-01, 0.13752700E+01, -.11910000E+00, 0.36480500E+00, 0.15041100E-01, -.43275800E+00, 0.43057400E+00, -.18778000E-01, 0.88374100E+00, 0.15018900E-01, -.83875100E-01, 0.56891200E+00, 0.64608900E-01, -.23385400E+00, 0.42539200E+00, -.80629200E+00, 0.11853000E+01, -.19311000E+00, -.25097400E+00, -.32641700E+00, -.13501800E+00, -.12440500E+00, -.15149900E+00, 0.10872600E+01, 0.99174900E-01, 0.25905600E+00, -.77783500E-01, -.58704100E+00, -.41651600E+00, 0.91185900E+00, -.48804800E-01, -.67894600E-01, 0.13092100E+01, 0.64479900E+00, -.68342900E-01, -.10144400E+01, -.57683200E+00, -.31445700E+00, -.28438300E+00, 0.28853800E-01, 0.77166900E-01, 0.50237800E+00, 0.11674700E+00, -.48074100E+00, -.70953300E-01, -.33025500E+00, -.19194000E+01, 0.68978500E-01, 0.17175100E+00, 0.20745800E+00, -.80534600E-01, 0.40750900E+00, -.41129300E-01, -.39922100E-02, 0.15552600E+00, 0.20186100E+00, 0.84520200E-01, -.15223100E+00, 0.46381600E-01, 0.51185300E-01, -.28042800E+00, 0.46589000E+00, -.34096100E-01, -.12747200E+01, 0.90716800E-02, -.34198100E+00, 0.60350900E-01, -.10964400E+00, -.73340200E-01, 0.66516200E-01, -.26145400E+00, 0.31641100E+00, 0.45996400E+00, 0.22088000E-01, -.10450800E+00, 0.92321500E-02, -.23888500E+00, -.72886100E+00, -.16762300E+00, 0.98041500E-01, 0.19256000E+00, -.91236500E+00, -.80555900E-01, 0.32501600E+00, 0.11054400E-01, 0.49445900E+00, 0.21397900E+00, 0.69497500E-01, 0.24248300E+00, -.34037300E+00, 0.95226500E+00, 0.22055700E+00, 0.63833000E+00, 0.14690400E+00, -.80200600E-01, 0.96065800E-01, 0.62340200E-01, 0.58020900E-01, 0.24718500E+00, 0.27718000E+00, 0.55167500E-01, 0.27266800E+00, -.10876900E+00, -.65120300E+00, 0.31528300E+00, 0.71238500E-01, -.55350900E-01, -.67176100E-01, -.48491900E-01, 0.21710200E+00, -.14008600E+00, 0.25749200E+00, -.62510200E-01, -.81531100E+00, 0.24959900E+00, 0.15260200E+00, -.23055200E+00, -.48886900E-01, 0.11219100E+00, 0.10898100E-01, -.48087600E+00, -.56202900E-01, -.64170400E+00, -.14564900E+00, 0.19986000E+00, -.91886300E-01, 0.37630400E+00, -.70680500E+00, -.34661500E-02, 0.15863600E-01, 0.50428800E+00, -.19102300E-01, 0.61527800E-01, -.19902400E+00, -.18967200E+01, -.25932100E+00, -.60986900E+00, -.58031000E+00, 0.83585500E+00, -.57157000E-01, -.23119700E+00, 0.18505800E-01, 0.72175200E-01, 0.90509900E-01, 0.10234100E+01, -.97672200E-01, -.26358800E+00, 0.11218100E+01, 0.43364900E+00, -.67433700E+00, 0.29363800E-01, 0.41378400E-01, 0.51455100E-03, 0.17437700E+02, 0.40255000E+02, -.39049100E+02, 0.14431800E+02, 0.18223500E+01, 0.43090700E+02, -.33046000E+02, -.64134100E+02, 0.47547900E+02, -.14719800E+03, 0.30614500E+02, 0.54183300E+02, 0.35499600E+02, -.19195700E+02, 0.55772100E+01, 0.24111300E+02, 0.65369700E+02, 0.85531200E+02, -.79044400E+01, -.19749300E+01, -.10853500E+02, -.10103400E+02, -.34710300E+01, 0.67118100E+00, -.51982800E+01, 0.36197500E+01, -.17192600E+01, 0.14880600E+01, -.27931100E+01, -.49831300E+01, -.57858300E+01, 0.41438200E+01, 0.44016000E+01, 0.13655600E+00, 0.10020300E+02, -.10870600E+01, -.10073100E+02, 0.96773800E+00, -.29695200E+01, 0.34411700E+00, 0.12930700E+00, 0.41095500E+01, 0.30468300E+01, 0.11936500E+01 },
        { -.34901700E+01, 0.50329900E+00, 0.45460800E+00, 0.11838400E+01, 0.16380100E+01, 0.52850200E+00, 0.10955300E+01, -.21665100E+01, -.35211200E+00, 0.39214900E+00, 0.86149500E-01, 0.28563200E+00, 0.79109000E+00, -.21731700E+00, 0.40718800E+00, 0.20310900E+01, -.80500000E+00, -.37054100E+00, 0.19437000E+00, -.54333200E+00, -.96362300E-02, -.34593600E-01, 0.38256500E-01, 0.91433900E+00, -.35677400E+00, -.13911600E+00, 0.16198300E+00, 0.14476500E+01, -.30909000E+00, -.97838600E-01, -.20244000E+00, 0.73516400E+00, -.35915100E+00, -.18524900E+01, -.26246800E-01, -.89494100E-01, 0.75807100E-01, 0.48743000E+00, 0.78561500E-01, -.61733100E-01, 0.89891700E+00, 0.77997500E-01, -.67007000E-01, 0.51274300E-01, -.42946400E+00, -.14922900E+00, 0.22348700E-01, 0.14453300E-01, -.55758500E+00, -.67255100E-01, 0.28975400E+00, 0.40903200E+00, 0.19640600E+00, 0.33703500E+00, 0.94373800E-01, 0.72349900E+00, -.96904200E-01, 0.14629300E-01, 0.17144700E-01, -.54732400E+00, 0.18737200E+00, -.38606700E-01, 0.44986800E-01, -.20312000E+00, 0.10752300E+00, 0.26889900E+00, 0.59897400E+00, 0.10163700E+00, 0.66189100E+00, -.41804100E-02, 0.21063300E-01, 0.20795900E+01, -.10135500E+00, -.77195400E+00, -.36843400E+00, -.79701800E+00, -.22970400E-01, -.48152000E+00, -.16473500E+00, -.40882300E-01, 0.47701600E-01, 0.34872100E-02, -.57743000E-01, 0.13594900E+00, -.65625600E-01, -.26918100E+00, 0.79612100E-02, 0.46319900E-01, 0.49189700E+00, 0.65761800E-01, -.13251400E+00, 0.51966600E-02, 0.48729400E+00, -.98221100E-01, -.45557700E+00, -.36722000E-01, -.50212800E-02, -.35502700E+00, 0.12843800E-01, -.79323000E-01, 0.39517400E-01, 0.90122400E-01, 0.15100700E-01, 0.12071700E+00, -.47031500E-01, 0.72818200E+00, -.15676300E+00, 0.56022900E-01, -.14447800E+00, -.69008700E-01, 0.93594800E-01, -.51493900E-02, 0.52940500E+00, -.10801700E-01, 0.58397000E-02, 0.74714200E+00, 0.10497000E+00, -.21400800E-01, -.82590400E+00, 0.79283000E+00, -.23109400E+00, 0.61506600E-02, 0.26648100E-01, -.13263900E+00, 0.17648700E-01, -.92388100E-01, -.42826100E+00, 0.29337900E+00, -.11068000E-01, 0.36374200E-01, -.73529000E+00, 0.10296200E+00, -.16132900E+00, -.43190600E-02, -.15294200E+00, -.21675200E-01, 0.15655200E+00, -.95397400E-01, -.95617800E-01, -.26178800E+00, -.49662600E-01, -.91713900E-01, -.66239100E-01, -.44906400E+00, 0.35603400E-02, 0.31006000E+00, -.65232600E-02, 0.86732700E-01, 0.17608000E-01, 0.30385200E+00, 0.19603800E+01, -.20537700E+00, -.82373700E-01, 0.26565200E+00, 0.14290400E+00, -.23869900E+00, 0.24350900E-01, 0.51099400E-02, 0.25203800E+00, 0.27158700E-01, 0.19026300E-01, 0.85136400E-01, 0.46801100E-01, -.14309400E+00, 0.19653900E+00, 0.54870400E-01, -.24936500E-02, 0.35440800E-01, 0.11759300E-02, -.60795100E+00, 0.24694300E-01, 0.45688300E-01, -.83035600E-01, 0.69117800E-01, 0.11946700E+00, -.13687400E+00, 0.19623300E+00, 0.10956500E-04, -.60083200E-01, 0.28421600E-01, -.47707600E-02, 0.29667300E+00, 0.78199600E-01, -.10412300E+00, 0.54847600E-01, -.20410700E+00, 0.61750700E-02, 0.10033800E+00, -.75803000E-02, 0.82095700E-01, -.52526200E+00, -.75386500E-02, -.15487700E+00, -.32930100E-01, -.88867100E+00, -.30509000E+00, 0.30926200E+00, -.30791900E+00, -.17431900E+00, -.45462000E-01, 0.47337200E-01, 0.85805300E-01, -.80691400E+00, 0.17665200E+00, -.52877800E-01, -.21289100E-01, 0.81331200E-01, -.11007500E+00, 0.30122900E-01, 0.22382200E-01, 0.11192400E-01, 0.21809200E+00, 0.47082400E-01, 0.18442300E+00, 0.44425500E+00, -.10302100E+00, -.41123000E+00, 0.25082400E+00, 0.45224800E-01, -.32303600E-01, 0.28401200E-01, -.67807800E-01, 0.11564100E+00, 0.13601200E-01, -.50788400E+00, -.79610100E-01, -.27325800E+00, -.16238300E-01, -.56444500E+00, -.21492000E+00, -.40615400E+00, 0.14807700E+00, 0.44413700E-02, -.56731400E-01, -.23138000E+00, 0.74890400E-01, -.13622100E+00, -.34065000E-02, 0.23426500E+01, 0.45626900E+00, -.10914100E+00, 0.97630700E-01, 0.58671000E-01, -.24031100E-01, -.23182200E-01, -.43426800E-02, 0.49560500E-01, 0.57202400E-01, -.37756300E+00, 0.38237400E-01, 0.60956800E-01, -.21398000E+00, -.25031500E+00, -.31435900E-01, 0.70241000E-02, 0.17763600E-02, -.67036300E-02, 0.58162600E+00, -.33878700E+02, 0.37013500E+02, -.60891700E+01, 0.32473000E+01, -.39641800E+02, 0.14601300E+02, 0.49994800E+02, -.35831300E+02, 0.10567700E+03, -.23962500E+02, -.42358300E+02, -.34416100E+02, 0.19416600E+02, 0.12422400E+02, -.74724400E+01, -.58899500E+02, -.59493400E+02, 0.73983500E+01, 0.84638600E+00, 0.10581300E+02, 0.10343000E+02, 0.27656200E+01, -.10568200E+01, 0.53512700E+01, -.15262900E+01, 0.17507800E+01, -.15083400E+01, 0.15709700E+01, 0.40126200E+01, 0.53360500E+01, -.32107800E+01, -.21692600E+01, 0.23737400E+01, -.10128600E+02, 0.14156300E+01, 0.10136500E+02, -.12887800E+01, 0.36867800E+01, -.28327300E+01, -.35523700E+01, -.24079900E+01, -.24813200E+01, -.18375400E+01 },
        { 0.12290600E+02, 0.44384900E+01, -.42917300E+01, -.60985800E+01, -.42280700E+01, -.38619400E+01, -.60453300E+01, 0.13156000E+02, 0.70857500E+00, 0.49651000E+01, -.51652400E+00, -.15770600E+01, -.22386500E+01, -.63217900E-01, 0.22473300E+01, -.31725300E+02, -.16071400E+02, -.78838600E+01, -.26045000E+01, 0.65375900E+00, 0.14729900E+01, 0.38720600E+00, -.22602300E+00, -.27328800E+01, -.52554200E-01, 0.19991600E+00, 0.27600100E+00, -.93231000E+00, -.20731600E+01, -.21002600E+00, 0.12453700E+01, 0.17910700E+01, -.99829800E+00, 0.16329500E+01, 0.21740500E-01, 0.36973300E+00, -.23958300E+00, -.18698500E+01, 0.36888400E+00, -.23436000E+00, -.33093800E+01, -.17291000E+00, 0.17972800E+00, -.73137800E+00, 0.70716200E+00, -.27096900E+00, -.21579700E-01, -.13136900E+00, 0.21702500E+01, 0.22371300E+00, -.35116000E+00, -.92750300E+00, -.18902500E+01, 0.24898800E+01, 0.23206600E+00, -.26904500E+01, -.11558400E+01, 0.33726500E+00, -.14250800E+00, 0.10555600E+01, 0.10973700E+00, -.16590900E+01, -.66879000E+00, 0.54655600E+00, 0.67287500E+00, 0.88074700E+00, 0.11336600E+01, 0.17767600E+00, 0.13395300E+01, 0.24555100E-01, -.21945000E+00, 0.14853300E+00, 0.75358500E+00, 0.88526000E+00, -.37750800E+00, 0.28752500E+01, 0.25649700E+00, -.33705000E+01, 0.11203500E+01, 0.47101200E+00, -.64786200E-02, -.24707800E+00, -.35263800E+00, 0.13677500E+00, 0.29028800E+00, 0.10312600E+00, -.45957400E+00, -.38844400E+00, -.11141000E+00, -.15981800E+00, 0.23217200E+01, -.55054900E-02, -.10975000E+01, -.30625900E+00, -.69830700E+00, -.90950200E+00, -.85630100E+00, 0.39754800E+00, 0.13863300E+00, 0.34989300E+00, -.22436300E+00, 0.34934100E+00, 0.16262800E-01, -.16492700E+00, -.39514200E+00, -.15588600E+01, 0.78975700E+00, -.73790700E+00, 0.31474900E+00, -.19598400E+00, 0.15092700E+00, -.32452400E-01, -.15232300E+01, 0.34512100E-01, -.64862400E-01, -.53262000E+00, -.26355200E+00, -.56824300E+00, 0.29474400E+01, 0.68453700E+00, 0.22536200E+01, -.17961100E+00, 0.25013700E-01, -.13185100E-01, -.13901200E+00, -.38050700E+00, -.63872100E+00, -.79324900E+00, 0.64484500E+00, 0.56911300E+00, 0.64273400E-01, -.29044100E+00, 0.62132100E+00, 0.75500100E+00, 0.20814500E-01, 0.10900800E+00, 0.56635700E+00, 0.45693300E+00, 0.56413600E+00, 0.79046400E+00, 0.14083800E+01, 0.58177500E+00, 0.44552900E+00, 0.11521000E+01, -.62268600E-02, -.15935600E+01, 0.10055400E+00, -.11467400E+01, -.26424200E+00, -.11605700E+01, -.19302400E+02, -.19045100E+01, 0.76390100E-01, 0.47172900E-01, 0.11098900E-01, -.10611000E+01, -.33906600E+00, 0.21285500E-01, 0.90776000E+00, 0.65579700E+00, -.47963400E+00, -.10701200E+01, 0.27882900E+00, 0.12245300E+00, 0.76644700E+00, -.13350300E+01, 0.13505700E+00, 0.36157800E-03, -.16947800E+00, 0.20967800E+01, 0.71221300E+00, -.54545300E+00, 0.95756800E+00, -.82425500E+00, -.40257300E+00, 0.54393900E+00, -.14061900E+01, -.11610700E+00, -.70817500E+00, 0.28115200E+00, 0.26954200E+01, -.50619300E+00, 0.26533800E+01, 0.24286200E+01, -.59076100E+00, 0.16409200E+01, 0.24271100E+00, -.15068500E+01, -.50117100E-01, -.52961300E+00, 0.93244900E-02, 0.62883300E+00, 0.54951600E+00, 0.36748400E+00, -.25220200E+01, 0.11392000E+00, -.12075400E+01, 0.10180300E+01, 0.29874700E+00, 0.19644900E+00, -.42616200E+00, 0.11516700E+00, -.75173400E+00, 0.10628700E+01, 0.98531100E+00, 0.24858800E+00, -.51908100E+00, 0.60264900E+00, 0.91119800E-01, 0.43890900E+00, -.88262700E-01, -.67172000E+00, -.19152100E+00, 0.13689100E+01, 0.25177000E+01, 0.25037800E+00, 0.15627200E+01, -.90926300E+00, -.42734600E+00, 0.57402400E-01, -.14855200E+01, 0.12383700E-01, -.20172800E-02, 0.16350100E-01, 0.81880100E+00, -.20349100E+01, 0.54514200E+00, -.47100100E+00, 0.53867700E+00, -.11508400E+01, 0.92069700E+00, -.15202400E+01, -.33482200E-01, -.35586200E-01, -.22140800E+00, 0.28819600E+00, -.39547900E-01, -.19543800E+00, -.80674500E+00, -.12737800E+01, -.12496500E+01, -.30784600E+01, 0.23013200E+01, -.21436700E+00, -.58656800E+00, 0.54628200E-01, -.22601700E+00, 0.60206700E+00, 0.30971300E+01, 0.11400900E+00, -.39197000E+00, 0.15444100E+01, -.51661800E+00, -.17173200E+01, -.49774500E-02, 0.26059000E+00, 0.65017400E-01, 0.22464400E+01, -.32176600E+01, -.56317200E+02, -.32305400E+02, -.27442500E+00, -.36349900E+02, 0.33758600E+02, 0.13877800E+03, -.10604900E+03, 0.48852600E+03, -.71671800E+02, -.56941200E+02, 0.65869600E+02, -.64488300E+02, 0.37443900E+02, -.97527900E+02, -.16733600E+02, -.18408100E+02, 0.23747700E+01, 0.60719000E+01, 0.24598500E+02, 0.20743300E+02, 0.18844400E+02, -.18988000E+02, -.16842300E+02, -.10160500E+02, 0.46602900E+00, -.56145100E+01, 0.93433800E+01, 0.21727700E+02, -.87252700E+01, -.22006800E+02, -.97977000E+01, -.12501100E+02, -.22372200E+02, -.15267700E+02, 0.21160900E+02, -.19797100E+02, -.10854700E+02, 0.12335700E+02, 0.22795800E+02, -.10636200E+02, -.14542400E+02, 0.51109900E+01 },
        { -.53977400E+01, 0.14782000E+00, 0.41768100E+01, 0.18473400E+01, 0.22579400E+01, 0.13055400E+01, 0.13293200E+01, -.55952100E+01, -.17749500E+00, -.12583900E+01, -.29358400E+00, 0.55805500E+00, 0.42882800E+00, -.45471200E+00, 0.12143400E+00, 0.33808900E+00, -.17317800E+01, -.17497400E+01, 0.10533800E+01, -.15617300E+00, 0.11466300E+01, -.39901900E+00, 0.10355700E+00, 0.22877500E+00, -.11235300E+00, -.14058300E+00, -.43497000E+00, -.64639700E-01, 0.37692900E+00, -.13154100E+00, -.22238000E+00, 0.72906200E+00, -.61785200E+00, -.29375000E+01, -.48375200E-01, -.80048700E-01, 0.12404100E+00, 0.79858300E+00, -.23882500E-01, 0.10497900E+01, 0.27933200E+01, -.82136100E+00, -.18001700E+00, -.14553200E+00, 0.12090700E+00, -.34946400E+00, 0.11548600E-01, 0.49820800E-01, -.12747300E+00, 0.13897300E+00, -.25903700E+00, 0.84428000E+00, -.25011700E+00, -.76568600E+00, 0.18801800E+00, -.15575800E+01, -.41346900E+00, -.24737200E+00, -.13265400E-01, -.29471600E+00, -.25314800E-01, 0.35406200E+00, -.22181400E+00, -.40098700E+00, -.80364400E+00, 0.29592300E-01, 0.64735700E+00, 0.36240700E+00, 0.17456200E+00, -.20016500E-01, -.30814500E-01, 0.12190500E+01, 0.60623200E+00, 0.13482100E+01, -.37107200E-01, -.41491500E+00, -.30840000E+00, 0.73127500E+00, -.33274000E+00, -.32826400E+00, 0.58668100E-01, 0.12202500E-01, -.14488900E-02, 0.75710300E+00, -.32436100E-02, -.81877700E+00, -.23127100E+00, 0.19156200E+00, 0.92582500E+00, -.21931200E-01, -.54663900E-01, 0.75195700E-03, 0.18704000E+00, 0.43125100E-01, -.43502300E+00, 0.10793100E+01, -.59912300E+00, -.20843700E+00, 0.32544300E+00, 0.52746700E+00, -.87649700E-01, -.14386500E+00, -.20758100E-01, -.51770400E+00, -.83042200E-01, -.19258600E+01, 0.45547900E+00, -.74162800E-01, 0.11521800E+00, 0.19963700E+00, 0.66088600E-01, -.24603400E-01, 0.19678200E+01, -.57873200E-02, -.22218200E+00, 0.48652900E+00, -.73722900E-01, 0.16423600E+00, -.79802600E+00, 0.23774400E+01, 0.37389500E+00, 0.42559100E-01, 0.83302400E-01, -.77236900E-01, 0.24250800E-01, -.38494800E+00, -.78343500E+00, -.14375900E+01, 0.61313100E-01, 0.18780000E-01, -.19198100E-01, -.46880200E+00, -.13611600E+01, 0.12326800E+01, -.74706600E-01, -.45850500E-01, 0.62606000E+00, 0.11641600E+00, -.15908000E+00, -.14123100E+01, -.46770100E+00, -.79145200E-01, 0.10328200E+00, 0.74710600E-01, 0.77500600E-01, 0.14509500E+01, 0.99890700E-01, -.63229900E+00, 0.14166700E+00, -.55124900E+00, 0.27837100E+01, 0.20642200E+00, -.23477500E+00, -.49666400E+00, -.63902900E-01, 0.86679400E+00, -.90713500E-01, -.49337000E-02, -.22807800E+00, 0.15007900E+00, -.73819300E-02, -.40032100E+00, -.15562300E+00, -.70747900E+00, -.35792500E+00, 0.19484400E+00, 0.23532300E-01, 0.86839600E+00, 0.26613600E-02, 0.37860400E+00, 0.16887900E+00, -.10317900E+00, 0.10745800E+00, -.14145600E+00, 0.41978900E+00, 0.22046500E+00, 0.76994900E-01, -.12185900E-01, -.22432700E-01, -.18612700E+00, -.33168700E+00, 0.90009900E-01, 0.14464000E+01, -.21625400E+00, 0.55435200E-02, -.29872200E+00, 0.65346700E-01, 0.61909400E+00, -.80984500E-01, -.40773000E-01, 0.50829300E+00, -.15907900E+00, -.10222400E+00, 0.11679800E+00, 0.15866800E+01, 0.55825600E-01, -.18961000E+00, 0.11969100E+00, -.53887600E+00, 0.86643700E-01, 0.28958100E-01, -.76739300E-01, 0.27897100E+00, 0.56098600E+00, 0.16792800E+00, -.15056000E+00, -.73924600E-01, -.67298400E+00, 0.27479300E+00, 0.73350200E-01, -.45068500E-01, -.88683800E-01, -.72519400E-01, 0.58222200E+00, -.40034900E+00, 0.15964200E+00, 0.85735100E+00, -.13286400E+01, 0.21670700E+00, 0.64996800E-01, -.26964100E+00, -.11634300E+00, 0.35967600E-01, -.31395200E-02, -.77541400E+00, 0.14338100E+00, 0.41832000E+00, -.25816900E+00, 0.52129900E+00, -.42263200E+00, -.14451700E+00, 0.12758400E-01, 0.15357600E-01, -.12953100E-01, -.48611800E+00, 0.13473100E-02, -.43842800E-01, 0.32156300E+00, 0.47018600E+01, 0.38391500E+00, -.38825000E+00, 0.12322500E+01, 0.41002100E+00, -.45753400E-01, -.84179000E-01, 0.94399900E-02, 0.20324500E+00, -.35250900E-01, 0.74810400E+00, -.17351700E-02, 0.22226900E+00, -.20570700E+00, -.10862100E+01, -.27073700E+00, -.37373300E-01, -.79084900E-03, 0.11784800E-01, -.44168900E+00, -.49162600E+00, 0.50970600E-03, -.26895200E+02, -.31588700E+02, -.22856500E+01, -.12460900E+02, -.55817300E+01, -.92365400E+00, 0.11971200E+03, 0.30010300E+01, 0.40427200E+02, 0.72799900E+02, -.38037700E+02, 0.17624700E+02, 0.11244200E+02, 0.58810400E+02, 0.62312100E+02, -.27031400E+01, 0.42236500E+01, 0.15790500E+02, 0.15480900E+02, 0.28569900E+01, -.36671700E+01, -.14592600E+02, -.52912900E+01, -.72102300E+01, 0.16836000E+01, 0.44298700E+01, 0.85964800E+00, -.11099900E+02, -.30599000E+01, -.59696300E+01, -.11022500E+01, -.15551500E+02, -.13061500E+02, 0.15378800E+02, -.42338800E+01, -.86111100E+01, 0.78471800E+00, 0.86147300E+01, -.54451400E+01, -.13464300E+02, 0.25975900E+01 },
        { 0.66831000E+01, 0.21771100E+01, 0.27926900E+00, -.26485000E+01, -.18767500E+01, -.17376500E+01, -.14415400E+01, -.37791000E+00, 0.25065100E+00, -.66489400E+00, -.62907800E+00, -.83924600E+00, -.21029000E+00, 0.24541600E+00, 0.58956300E+00, -.93050700E+01, 0.44921400E+01, 0.30445500E+01, -.23794100E+01, 0.45761800E-01, -.11032400E+01, -.35251900E+00, -.41285500E+00, -.39015900E+01, 0.70512900E-01, -.30749300E-01, -.11225100E+01, -.41298500E+01, 0.17900600E+01, -.10779500E+00, 0.10966900E+01, -.96247300E+00, -.77881100E+00, 0.56109000E+01, -.29054900E-01, 0.17243700E+00, 0.56980600E-01, -.43948100E+00, 0.45949800E+00, 0.47065000E+00, -.30408600E+01, -.39809500E-01, 0.99479700E-02, -.45666000E+00, 0.93185500E+00, 0.66114300E+00, -.11129300E+00, 0.11974500E+00, 0.86175200E+00, -.29155900E+00, 0.12221100E+01, -.81452800E+00, -.17629100E+00, -.27829000E+01, -.60311600E+00, -.23219600E+01, -.11114500E+01, 0.15083500E-01, 0.10655600E+00, 0.31686300E+00, -.26280700E+00, 0.41013300E+00, -.31348200E+00, 0.89540400E+00, 0.13698500E+01, -.13761400E+00, -.15070500E+01, -.53929400E+00, 0.86998200E+00, 0.51324400E-01, 0.92041700E-01, -.19114300E+00, 0.65684000E+00, 0.46321900E+01, -.85352100E+00, 0.56090200E+00, 0.12600500E+00, 0.85281200E+00, 0.14273400E+00, 0.13538900E+00, 0.59352100E-01, -.82855300E-01, -.14686000E+00, -.77177100E+00, 0.60516300E+00, 0.57625500E+00, 0.21031500E+00, -.12551000E+00, 0.65759100E+00, -.86700700E-01, 0.90853800E+00, 0.23373900E-02, 0.20228500E+00, -.66708300E-01, -.15365400E+01, -.17138000E+01, -.47015300E+00, 0.30738100E+00, -.32133800E+00, -.10262000E+00, -.98554700E-01, -.84566400E-01, 0.15230000E-01, 0.36851100E+00, -.38593600E-01, -.13828700E+01, 0.64182400E+00, -.64258200E-01, -.60422900E-02, -.32176500E+00, 0.20732200E-01, 0.87052000E-01, -.29946100E+00, 0.15045000E-01, -.87625400E-01, -.79884600E+00, -.14001800E-01, 0.34511500E+00, 0.90042500E+00, -.10825200E+00, -.45559500E+00, 0.10366700E+00, 0.12146600E+00, 0.33812500E+00, 0.62845100E-01, -.11758400E+00, 0.29785600E-01, 0.69227700E+00, 0.97762900E-01, -.25010800E+00, 0.21744900E+00, -.13870200E+00, 0.43568300E+00, -.27004900E+00, -.13658900E+00, 0.26946500E-01, 0.20526000E+00, 0.27218600E+00, 0.19372300E+00, -.29990100E+00, -.24636300E+00, -.71269800E-02, -.49580500E+00, -.58392500E+00, -.13019700E-01, -.76610800E+00, -.12112200E+00, 0.56072000E+00, -.93009100E-01, -.31478400E+00, -.19293000E+01, -.21054200E+00, 0.22751900E+00, -.10986600E+01, -.18693200E+00, -.70199000E+00, -.14220800E+00, -.70487400E-03, -.10300200E+01, -.59356800E+00, -.88679800E-01, -.18719400E+00, -.44350700E-01, -.20003900E+00, -.69579900E+00, 0.25616500E+00, -.16388000E-01, 0.43271000E+00, 0.40911500E-02, -.28743900E+00, 0.77006000E-01, 0.52882800E-01, 0.72210100E-02, -.62250900E-01, -.27702000E+00, 0.73969700E-01, 0.35015900E+00, 0.31159600E-01, -.22382100E+00, -.95151700E-01, -.46185100E+00, -.47610000E-01, 0.60189600E+00, 0.34519200E+00, -.16914700E-01, -.39159800E-01, -.10981800E+00, 0.11297000E+00, -.14999800E-01, -.21728300E+00, -.47770700E+00, 0.19421300E+00, 0.12629500E+00, 0.21093700E+00, -.77545200E+00, -.27455500E+00, -.64999100E+00, -.26076200E+00, -.47280300E+00, -.19027100E-01, 0.29621200E-01, -.10525000E+00, 0.57430900E+00, -.37481500E+00, -.10784700E+00, -.15478000E+00, 0.16536900E+00, 0.19752600E+00, -.14158200E+00, -.13475600E-01, 0.47547000E-02, 0.29082600E+00, -.48139000E-01, 0.86843100E-01, 0.21533000E+00, 0.14185900E-01, 0.18422200E+00, -.45821500E+00, 0.17715500E+00, -.24279200E+00, -.14553700E+01, 0.22245400E-01, -.56988000E-01, 0.37541500E-01, 0.48794600E+00, -.37880100E+00, -.35078700E-01, -.11671600E+00, -.22743400E+00, 0.82437600E+00, -.53298900E+00, 0.69765800E+00, -.97085800E-02, -.75953500E-01, -.13910300E+00, 0.59252400E+00, 0.14292200E-01, -.59013700E-01, 0.15841300E+01, 0.64209700E+00, 0.90969800E-01, -.15799500E+00, -.19920300E+00, -.27911500E-01, 0.17834800E-01, -.45828000E-02, 0.14818100E+00, 0.32459400E-01, 0.36661800E+00, 0.53308800E-01, 0.45233900E-01, -.32713600E+00, 0.44490800E+00, 0.29488200E+00, 0.14248100E-01, -.10988200E+00, -.66854500E-02, 0.53321700E+00, 0.93693400E+00, -.11670300E+00, -.85611600E+00, -.12992100E+02, 0.53537200E+01, 0.19701800E+02, 0.45881900E+02, -.31992100E+02, 0.10394700E+03, -.22743500E+02, -.13169000E+02, 0.38553800E+02, -.38734100E+02, -.76394800E+01, -.16527100E+02, 0.17167400E+02, -.38395600E+01, 0.13154700E+01, 0.29704200E+01, 0.37050500E+01, 0.26701400E+01, 0.55824100E+01, -.54907600E+01, -.79733800E+01, -.43816200E+01, -.24353300E+01, -.11589100E+01, 0.35680100E+01, 0.48880800E+01, -.63078400E+01, -.60194400E+01, -.47099400E+01, -.43550300E+01, -.28990300E+01, -.75370900E+01, 0.27689000E+01, -.56610000E+01, -.70446500E+01, 0.42498600E+01, 0.92351400E+01, -.45612500E+01, -.86514500E+01, 0.18102300E+01 },
        { 0.33607600E+01, -.11551600E+00, 0.10783600E+00, -.60673500E+00, -.26508600E+01, 0.39734500E+00, 0.24509000E+00, 0.13402700E+01, 0.30312000E+00, -.40462600E+00, -.32779500E+00, -.58934500E+00, -.76609600E+00, 0.24511000E+00, 0.25201700E-01, 0.58858300E+01, 0.61472100E+00, -.11813300E+00, -.53245800E+00, 0.84967900E+00, 0.21121300E+01, 0.59305700E-01, 0.19143000E-01, 0.14235600E+00, 0.17279000E+00, 0.10539700E+00, 0.38460900E+00, 0.11894000E+01, -.11514300E+01, 0.80247200E-01, -.52793600E+00, -.95102300E+00, 0.96768100E+00, 0.16184600E+01, -.13524200E-01, -.48492200E-01, -.19243500E-01, -.70090300E+00, -.67952000E-01, -.75791400E-01, 0.23245000E+01, 0.33758200E+00, -.18222900E+00, 0.41795200E-01, -.60091000E+00, 0.22392500E+00, -.31248300E-01, -.27075300E-01, 0.20494800E+01, 0.10465400E+00, -.10924800E+00, 0.12206400E+00, -.39896000E+00, 0.25079800E+01, 0.18036500E+00, -.65705500E+00, 0.27711700E+00, -.11040100E+00, -.64124800E-01, 0.14351600E+00, 0.10964900E+00, -.15455300E+01, 0.41793900E+00, 0.23418000E+00, 0.61187400E+00, -.11264600E+00, -.71191800E+00, -.71844900E-02, 0.62432500E+00, -.53565100E-02, 0.58975100E-01, 0.32493700E+00, 0.99805400E+00, -.32482900E+00, -.20349900E+00, 0.77789600E+00, -.15188300E+00, -.13210000E+00, 0.22344600E+00, 0.16023900E-01, 0.52236900E-01, -.13705600E+00, -.20240500E+00, 0.10030800E+00, 0.43085000E-01, -.11149300E-02, 0.44992000E+00, 0.30340300E-01, 0.30711200E+00, -.15998500E-01, 0.54352100E+00, 0.17594700E-02, 0.32050700E+00, -.33816900E-01, -.24121300E+00, -.39454700E+00, -.46544100E-01, -.14248400E+00, -.19642800E+00, -.18318500E+00, -.28195900E-02, -.12083900E-01, 0.57967900E-02, 0.57035600E+00, -.14727500E+00, -.16063000E+01, -.13048700E-01, -.59120100E+00, -.11848200E+00, 0.17656700E+00, -.28554400E+00, 0.23226000E-01, 0.11418600E+00, -.17298500E-01, -.17735900E+00, -.18324300E+00, 0.13681400E+00, 0.97212200E-02, 0.22640800E+00, -.77629000E+00, -.75693700E+00, 0.30710300E-03, 0.16176400E-01, 0.95055100E-01, 0.36011500E-02, 0.60562300E-01, -.33853000E-02, 0.58866600E+00, 0.40442000E+00, 0.43979900E-01, 0.13134700E+00, 0.62260200E-01, -.47895000E+00, -.33566300E+00, -.65571000E-01, 0.13757900E-01, -.27481300E+00, 0.54758100E+00, -.21806600E-02, -.45436100E+00, 0.70284800E+00, -.78878600E-01, -.69575400E-01, -.29023400E-01, -.19701800E-01, -.56810300E+00, -.83100400E-01, 0.15756600E+00, -.79469800E-01, 0.27915500E+00, -.28288200E+01, -.42588700E+00, 0.19832800E+00, -.10796400E+01, 0.79368200E-01, 0.13506800E+00, -.89223700E-01, 0.60089100E-03, -.18939300E+01, -.35470300E+00, 0.66157600E-01, 0.16478300E+00, -.12721800E+00, -.19654800E+00, -.88734400E+00, -.11815000E+00, 0.81626000E-01, -.45400100E+00, -.55043100E-02, -.54113800E+00, 0.16042100E+00, -.42553200E-01, -.51169200E-01, 0.10368000E+00, 0.31694100E+00, 0.40424200E-01, 0.87900700E-01, 0.17375000E-01, -.48084900E+00, 0.55158500E-01, -.35890100E-01, -.34856500E+00, -.50690100E+00, 0.14388900E+00, 0.21167000E+00, -.21284100E+00, 0.92268200E-01, -.40683600E+00, 0.34201100E-01, 0.40287300E+00, -.14626200E+00, 0.83565600E-01, 0.18238700E+00, -.41804000E-01, 0.73529700E+00, -.34738900E-01, 0.51015500E-01, 0.16568700E+00, -.16464500E+00, 0.62075600E-01, -.87557300E-01, 0.89397600E-01, 0.72277300E+00, 0.16316500E+00, 0.10363300E+00, -.38401300E-01, 0.15983500E+00, -.55919400E+00, 0.15197500E+00, 0.12783900E+00, -.33500600E-01, -.47388900E-01, -.47080700E-01, -.31020900E+00, -.72509800E+00, 0.11582500E+00, -.22005900E+00, -.52589300E+00, 0.87027100E-01, 0.34313700E+00, -.88790500E+00, 0.16943400E-01, 0.28772000E-01, 0.19688800E-01, -.74569200E-01, 0.34554700E+00, 0.44146800E+00, -.24665200E+00, 0.44328200E+00, 0.10622800E+01, 0.59219000E+00, -.98661600E-01, -.97954200E-02, 0.38398400E-01, 0.75769900E+00, -.48667500E+00, 0.52307600E-01, -.15234100E+00, 0.91725600E+00, 0.15762000E+01, -.21487300E+00, 0.34483300E+00, -.22036900E+00, 0.21879400E-01, -.53615100E-02, -.53842100E-02, 0.93049200E-01, -.64935000E-01, 0.34145000E+00, -.11950100E-01, -.51059700E-01, 0.11958800E+01, -.27214800E+00, -.40878400E+00, 0.11481000E-01, 0.10177400E+00, 0.18202600E-02, 0.34674900E+00, -.31033600E+00, 0.16731500E-01, 0.10910300E+00, 0.57800600E+00, -.63606500E+01, -.15955000E+02, -.28734600E+02, 0.19843200E+02, -.52765500E+02, 0.14243600E+02, 0.19900700E+02, -.14035200E+02, 0.30618700E+02, 0.20533800E+02, 0.20422800E+02, -.14044800E+02, -.13908700E+02, -.43610600E+00, -.24773300E+01, -.15382400E+00, 0.78529000E+00, -.42624500E+01, 0.37992700E+01, 0.29970700E+01, 0.37860300E+01, 0.87208500E+00, 0.17443000E+00, -.31246900E+01, -.36109900E+01, 0.32379100E+01, 0.45576800E+01, 0.39281500E+01, 0.48373100E+01, -.22890700E+00, 0.42853200E+01, 0.76031000E+00, 0.40286400E+01, 0.47175200E+01, -.48819300E+01, -.74928700E+01, 0.37889100E+01, 0.50983400E+01, 0.13533700E+00 },
        { -.96999300E+01, -.40304100E+01, 0.23958600E+01, 0.67077800E+01, 0.23453300E+01, 0.29570400E+01, 0.51581200E+01, -.20027700E+02, -.53045500E+00, -.36415800E+01, -.37312000E+01, 0.59982300E-02, -.11217700E+01, -.69877800E+00, -.93372900E-01, -.16102200E+01, -.15009600E+02, -.62245000E+01, 0.14820600E+01, 0.21698300E+00, 0.62751100E+01, 0.77270300E+00, 0.12888100E+00, -.19608500E+01, 0.13887400E+00, -.40825400E-01, -.11376200E+01, -.51249000E+01, 0.44590800E+01, 0.13594800E+00, -.27450100E+01, -.38647400E+01, 0.11449300E+01, -.64603700E+01, -.13122000E+00, -.63504100E+00, 0.16431000E-01, 0.48281800E+01, -.30907200E-01, 0.18077400E+01, 0.16198300E+01, -.22876500E+00, -.34530300E+00, -.48406900E+00, -.87567800E+00, -.61624900E+00, 0.48976200E-01, -.20616200E+00, -.70116900E+01, -.18626000E+00, -.15882700E+01, -.16933200E+01, -.10842500E+01, -.25338500E+00, -.95365500E+00, 0.15794500E+01, -.26675900E+00, -.18294600E+00, -.19117500E+00, 0.10420900E+01, 0.26297800E+00, 0.89700500E+00, -.21369500E+00, -.18500700E+01, -.14662300E+01, 0.15753600E+01, 0.88900500E+00, 0.23519600E+00, -.15452800E+01, -.31828200E-01, -.27244800E+00, -.35121900E+01, 0.14935200E+01, -.31053500E+01, 0.70551900E+00, -.88643900E+00, 0.88386400E+00, -.23122700E+01, 0.85673200E+00, -.20558100E+00, -.27642400E+00, 0.15133200E+00, 0.24405800E+00, -.28846200E+00, -.77174700E+00, -.15897700E+00, -.10322300E+00, -.68785600E+00, 0.18396500E+01, 0.16581300E+00, 0.16898100E+01, 0.13527200E-01, 0.78167000E+00, -.22743100E+00, -.20542100E+01, 0.11190100E+00, -.73105500E+00, -.13293100E+01, 0.13143500E+00, -.29882100E+00, 0.82316300E-01, -.14031100E+00, -.42936700E-01, 0.37378200E+00, -.23237900E+00, 0.93488500E+00, 0.14708800E+00, -.33074900E+00, 0.36228000E-01, -.28468900E+00, -.25564700E+00, -.94442300E-01, -.25419300E+01, -.33544200E-01, 0.14185800E+01, 0.39737900E+00, -.12699500E+00, -.72903200E+00, 0.18422700E+01, 0.17065300E+01, -.50154900E-01, -.89389300E-02, 0.37879800E+00, -.42377200E+00, 0.31443500E-01, -.10246400E+01, 0.73177700E+00, -.80163800E+00, -.64651000E+00, -.40111200E+00, 0.89460800E-01, -.31178900E+00, 0.61397700E+00, -.19201000E+00, -.24187800E+00, -.29534500E-01, 0.78325500E+00, 0.49948200E+00, -.29004100E+00, 0.15548800E+01, 0.14035500E+01, 0.18579500E+00, -.22619000E+01, 0.25667100E+00, 0.20821200E+00, -.20973100E+00, 0.12752500E-02, 0.78249100E+00, -.66138300E-01, -.20495700E+01, -.93472100E+01, -.12219600E+01, -.44427800E+00, -.25215400E+01, 0.11257900E+00, 0.10887800E+01, -.16457100E+00, -.28014800E-02, -.12049300E+01, 0.57066200E+00, -.18483400E+00, -.14255900E+00, -.49249600E+00, -.30404000E+00, 0.11134600E+01, 0.25065800E+00, 0.23198500E+00, 0.10582100E+01, 0.69724800E-02, 0.65706800E+00, 0.26749600E+00, -.47143600E+00, 0.36510500E+00, 0.35269300E-01, 0.10977800E+01, 0.44065200E+00, -.31642000E+00, -.12854600E-01, -.87314100E+00, -.94959200E-01, -.88630100E+00, -.66193100E+00, 0.21049600E+01, 0.65123600E+00, -.74227200E-01, -.10069000E+01, 0.78966600E+00, 0.14440100E+00, -.16733500E+00, 0.75584300E+00, -.20714300E+00, 0.28423400E-01, -.37480200E+00, -.35958600E+00, 0.34244200E+01, 0.28633100E+00, 0.11595100E+01, 0.46135700E+00, -.89105300E+00, 0.74659200E-01, -.20434200E-01, 0.93992700E-01, -.98618700E-01, 0.51979300E+00, 0.16369500E+00, -.25477200E+00, -.66709600E-01, -.87513700E-01, 0.41122000E-01, 0.13587000E+00, -.39238800E-01, -.10958200E+01, -.10643400E+00, -.13383800E+01, 0.13234300E+01, 0.19521500E+00, 0.11328200E+01, -.13154800E+00, -.45923200E-01, -.31685600E+00, 0.13016500E+01, -.59383500E-01, 0.47231300E-01, 0.26225900E-01, 0.11831600E+00, -.11426500E+01, -.13508900E+01, 0.15816700E+00, 0.38328000E-01, -.16039900E+01, 0.10376800E+01, -.10904800E+01, 0.10581600E-01, 0.64364200E-01, 0.59409000E+00, -.17603700E+01, -.27681300E-01, -.75185000E-01, -.76331200E+01, -.14182700E+01, 0.80209600E+00, -.23063000E+00, 0.47652700E+00, 0.85123800E-01, 0.23349400E+00, -.19379800E-02, 0.13713800E+00, 0.18079900E-01, 0.12142100E+01, -.28153500E+00, -.29168600E+00, 0.15058900E+01, 0.61910800E+00, -.61497400E-01, -.22890100E-02, -.13115100E-01, 0.17389100E-01, -.34405100E+00, -.92984200E+00, 0.92414100E-01, 0.56974400E-01, 0.39073200E+00, 0.53076400E+00, 0.60169300E+02, 0.70658100E+01, -.13332600E+01, -.35603900E+02, -.49303500E+01, 0.15443100E+02, 0.92559800E+01, 0.61284100E+00, 0.14253900E+02, 0.60702700E+01, 0.18022700E+02, 0.87499200E+01, 0.10861100E+01, -.17084200E+00, 0.81794700E+01, 0.83789300E+01, 0.10834000E+01, -.96658000E+00, -.88766200E+00, -.78097600E+00, -.26332900E+01, 0.21827200E+01, -.69190100E+00, 0.23639900E+00, -.17616000E+01, -.74139000E+00, -.62049300E+00, 0.11074200E+01, -.83713900E+01, -.10450600E+01, 0.83189500E+01, -.95966100E+00, -.39638100E+01, -.11802600E+01, -.23120400E+01, 0.76002900E+00, -.21137900E+01, -.81324000E+00 },
        { 0.21255400E+02, 0.70320900E+01, -.40975500E+01, -.11580400E+02, -.55557800E+01, -.77467900E+01, -.95243100E+01, 0.19701800E+02, 0.21455900E+01, 0.28098600E+01, -.17216700E+01, -.32564700E+01, -.46776400E+01, 0.71535100E+00, 0.45175200E+01, -.51448200E+02, -.10205500E+02, -.96832800E+01, -.12486000E+02, 0.13660200E+01, 0.89894800E+01, 0.16486600E+01, -.10203400E+00, -.31564500E+01, 0.10920700E+01, 0.37227900E+00, 0.88097400E+00, -.15217400E+01, 0.17678400E+01, -.45228700E+00, 0.12251500E+01, 0.13168200E+01, -.17024800E+00, -.10644800E+02, -.43353700E-01, -.21895500E+00, -.40173300E+00, -.14590600E+01, -.56149000E-01, 0.25523200E+01, -.11299600E+02, -.32013400E+01, -.99242700E-01, -.89148900E+00, 0.29937900E+01, -.24067100E+00, 0.58669900E-01, 0.57869400E-01, 0.13305500E+02, -.43093400E+00, 0.25904300E+01, -.31914900E+01, -.49406100E+00, -.48942100E+01, -.32193700E-01, -.79641100E+01, -.31499200E+01, 0.33535400E+00, 0.62664600E-01, 0.83582900E+00, -.39208500E+00, 0.11837100E+01, -.10657300E+01, 0.15235600E+01, 0.72943200E+00, 0.17634400E+01, -.20158800E+01, -.86815300E+00, -.17814800E+00, 0.28852400E-01, 0.14136300E+00, -.18806200E+02, 0.29844500E-01, 0.28951200E+01, 0.37879400E+01, 0.47922500E+01, -.78636600E-02, 0.67074900E+00, 0.32596600E+01, 0.39136800E+00, -.82391700E-01, -.36557400E+00, -.49859300E+00, -.16205700E+01, 0.94933600E+00, 0.72302700E+00, 0.86000700E+00, -.68767800E+00, 0.29927900E+01, -.29439100E+00, 0.42260600E+01, -.43658500E-02, -.67825200E+00, 0.43834800E+00, -.27426000E+01, 0.46613700E+00, -.21151900E+01, -.45139900E+00, 0.61510600E+00, 0.32182500E+00, -.62407900E-01, -.52505800E+00, -.16006300E+00, 0.38079000E+00, -.56597600E+00, -.12217000E+02, 0.15018900E+01, -.20058700E+01, -.53241600E-01, 0.16783500E+01, 0.33820000E+00, -.10225000E+00, -.57209800E+00, -.75430400E-01, 0.80779900E+00, 0.27312900E+00, 0.95158500E+00, -.21016300E+01, -.94328900E+00, 0.45517500E+01, 0.67988100E+00, 0.43909100E+00, 0.75672600E+00, -.28885700E+00, 0.52746300E+00, -.19054600E+01, -.27875500E+01, -.48838900E+01, -.55789200E+00, 0.50631100E+00, -.64971500E+00, -.66691500E+00, -.19353600E+01, 0.13855200E+01, -.45267400E+00, 0.32057100E-02, 0.19658800E+01, -.30336900E+00, -.13122700E+00, 0.44036700E+01, -.89491400E+00, 0.49948500E+00, -.82973600E+00, 0.22369900E+01, 0.46902400E+00, 0.28215900E+01, 0.36348500E+00, -.91756200E+00, 0.56502800E-01, -.45253900E+01, -.40345700E+01, -.94637500E+00, -.10458400E+01, -.15349600E+01, 0.27822100E+00, 0.11384900E+01, -.39651000E-01, -.11940700E-01, -.48818300E+00, 0.46732800E+00, -.36494600E+00, -.30821800E+00, 0.22370400E+00, -.60026500E+00, 0.14068600E+01, 0.10456200E+01, 0.12180000E+00, 0.92900100E+00, 0.49016900E-01, -.20820200E+01, 0.69978600E+00, -.64420200E+00, 0.14115200E+00, -.20374700E+00, -.57171300E+00, 0.43701900E+00, 0.66881000E+00, -.14243700E+00, -.35729900E+00, -.80429900E+00, -.89298700E+00, -.83972000E+00, 0.77732600E+01, 0.14222200E+01, -.86249900E+00, -.24640200E+00, -.14267500E+01, 0.19185400E+01, -.20297800E+00, -.10048200E+01, -.44220300E+01, -.15843500E+00, 0.11166400E+00, 0.15841200E+01, -.14373800E+01, -.90527700E-01, -.19059900E+01, -.11053700E+01, -.31577700E+01, -.88223600E-02, -.29316200E+00, -.93141500E+00, 0.38171000E+01, -.35631300E+01, -.74973500E+00, -.71727000E+00, 0.39922000E+00, 0.33163100E+01, -.15266400E+01, 0.19172000E+00, -.55128900E-03, -.10900100E+00, -.33611900E+00, 0.31016300E+01, 0.40168300E+01, 0.80497800E+00, 0.21231500E+01, -.18068100E+01, 0.45692800E+00, -.94567100E+00, -.29744200E+01, -.53106100E-01, 0.17412200E+00, 0.10685800E+00, 0.12306200E+01, -.38332800E+01, -.49383000E+00, 0.22210800E+00, -.26200500E+01, -.74852400E+01, -.28950800E+01, 0.91792500E+00, 0.27800800E-01, -.53599900E+00, -.13001400E+01, 0.13464400E+00, -.47766800E+00, 0.63920500E+00, 0.74145200E+01, -.54858100E+01, -.15962000E+01, -.41460700E+00, 0.59170900E+00, -.12886300E+00, 0.18295700E+00, -.10811300E+00, 0.47792500E+00, 0.19292600E+00, 0.31905100E+01, 0.79212700E-01, 0.72325000E-01, -.14477400E+01, 0.26417400E+01, -.42872900E+01, -.12069500E+00, -.10427300E+01, 0.11637200E-01, -.24313100E+01, -.35855100E+01, 0.99230800E+00, -.50839900E+00, 0.24930000E-01, 0.25824500E+00, -.63132900E+00, 0.11510800E+03, -.35594000E+02, -.13598000E+03, -.51194100E+02, 0.78051100E+02, 0.14089800E+03, -.40257500E+02, 0.87239900E+02, 0.71194800E+02, 0.17483900E+03, 0.16414800E+03, 0.20411500E+02, 0.11179100E+02, 0.16567700E+02, 0.17945800E+02, -.86961900E+00, -.22500800E+01, -.13997100E+02, -.81906100E+01, -.22727500E+02, 0.18810800E+02, 0.83506100E+01, -.62008600E+01, -.16757900E+02, 0.35895100E+01, -.84779900E+01, 0.66911200E+01, -.18494000E+02, -.15935800E+02, 0.17290400E+02, -.34208600E+01, -.21174200E+02, -.73169200E+01, -.48050600E+00, -.84180600E+01, -.14524500E+02, -.78217000E+01 },
        { 0.14112300E+02, -.60791400E+01, -.21857000E+01, 0.20529800E+01, -.12281200E+00, 0.21883000E+01, 0.41139400E+01, 0.97452200E+01, 0.36543200E+01, 0.11502300E+01, 0.12316300E-01, -.54573800E+00, -.33298300E+01, 0.71517900E+00, -.78516500E-01, 0.95312300E-01, -.65265500E+01, 0.40315300E+00, -.42765700E+01, -.28988600E-01, 0.78932800E+00, 0.12139100E+01, 0.73713500E+00, 0.52644100E-01, 0.11767100E+01, 0.58892400E-01, -.98376400E-01, 0.34447100E+00, 0.48009200E+01, 0.84153500E-03, -.94997700E+00, 0.73890600E+00, 0.17514900E+01, -.39512600E+01, -.39667600E+00, -.17843300E+00, -.20392600E+00, -.32033900E+01, -.51138300E+00, -.13314500E+01, -.84056200E+01, 0.99522000E+00, 0.38328600E+00, -.16897800E+00, -.56097500E+00, -.11458600E+01, 0.19535900E-01, -.12645200E+00, -.12490500E+01, -.37694300E+00, -.60624000E+00, 0.30574700E+01, -.24623000E+01, 0.27362400E+01, -.68190200E+00, -.43863400E+00, -.11966400E+01, 0.18000000E+00, -.10183000E+00, 0.29156800E-01, 0.27254300E+00, -.11070300E+01, -.17069400E-01, 0.11539300E+01, 0.12775800E+01, 0.20625400E+01, 0.70700600E+00, -.67067700E-02, -.59566700E+00, -.22190300E-01, -.46049100E+00, 0.87912600E-01, -.12205200E+01, 0.60322100E+00, 0.28091600E+00, 0.20432200E+01, -.17655800E-01, -.28477600E+01, 0.30772300E+01, 0.60403900E+00, 0.13705500E+00, -.30065600E+00, -.10734100E+01, -.13269000E+01, -.14377300E-01, -.63277800E-01, 0.14929500E+00, -.61274100E+00, 0.10120800E+01, -.48694000E+00, 0.24571800E+01, 0.68185200E-03, -.45290800E+00, -.22157000E+00, -.34644800E+00, -.13258000E+00, -.86523800E+00, -.80199000E+00, 0.36265500E+00, 0.32549500E+00, 0.29373400E+00, -.30059700E+00, -.39062300E-01, 0.34473800E+00, -.24055200E+00, -.87918400E+01, -.17958200E+00, -.88333200E+00, 0.13647500E+00, 0.15694600E+01, 0.42035400E+00, 0.57902400E-01, 0.79638000E+00, 0.45305700E-02, 0.37988000E+00, 0.47856300E+00, 0.20681200E+00, -.17815200E+00, -.27698600E+01, 0.32999300E+01, -.88247700E+00, 0.27203000E+00, -.32615200E+00, -.10605400E+00, 0.21814500E+00, -.56047300E+00, -.81962200E+00, -.22806500E+01, 0.67431100E+00, -.10210100E+00, -.22120600E+00, 0.32370700E+00, -.53754600E+00, -.70021800E+00, 0.15595400E+00, 0.59136200E-01, -.79107400E+00, -.84631600E+00, 0.29735900E+00, 0.23122800E+01, -.45773700E-01, -.59263600E+00, 0.77840300E+00, 0.29698700E+00, 0.49200200E+00, 0.62336600E+00, -.14691500E+00, 0.20136100E+01, -.15048800E+00, -.68596600E+00, 0.36093300E+00, -.10097600E+01, -.59731300E+00, -.53752500E+00, 0.95738800E-01, 0.24234600E+00, -.19287700E+00, -.69324600E-03, 0.51339600E+00, 0.71288200E+00, -.11385100E+00, -.24817700E+00, -.28873300E+00, -.91113600E+00, -.18140000E+00, 0.10839200E+00, 0.11413400E+00, 0.16336300E+01, -.37140300E-01, 0.31786800E+00, 0.28075800E+00, -.26213500E+00, 0.46680000E-01, -.15754400E-01, 0.53995300E+00, 0.14432500E+00, -.61812000E+00, -.26639400E-02, 0.12103100E+00, 0.44268400E-02, 0.60259800E+00, 0.59907900E+00, 0.80881900E+00, 0.72446000E+00, -.38805300E+00, 0.12756300E+01, -.39635200E+00, -.36116600E+00, 0.10019800E+00, -.50089200E+00, -.16382600E+00, 0.33370400E-01, 0.18501000E+00, 0.79174200E+00, -.17879800E+00, 0.42672100E-01, -.15353300E+01, -.10099900E+00, 0.17130800E+00, -.11809100E-02, -.10331800E+00, -.15384200E+00, -.57690200E+00, 0.51407800E-01, 0.30582400E+00, -.38067500E+00, 0.26534700E-01, 0.82257900E+00, -.26967000E+00, 0.58148300E-01, -.62004700E-01, 0.16520300E+00, -.60390400E-01, 0.12804100E+01, 0.36812900E+00, 0.30385000E+00, -.28913900E-01, -.44936600E+00, -.80524400E-01, -.59582900E-01, 0.12009900E+01, -.27081600E+00, 0.58238800E-02, 0.33546600E-01, 0.16475700E+00, -.34074500E+00, 0.10474400E+00, 0.11215300E-01, -.79875000E+00, -.90197100E+00, -.14377700E+01, 0.90086600E+00, 0.47916200E-01, -.31178500E+00, -.27534900E+00, 0.14005100E+00, -.14345100E+00, 0.55028500E-01, 0.38991200E+01, -.96517800E-01, -.56907300E+00, -.27468800E+00, 0.91100000E-01, 0.95880800E-01, -.66933100E-01, -.23202500E-01, -.96352100E-01, 0.11169900E+00, -.55506800E+00, 0.98510000E-01, 0.14022100E+00, 0.20840100E+00, -.64093600E+00, 0.86972100E+00, 0.47681200E-01, 0.17309200E-01, -.58873400E-02, 0.32268200E-01, 0.11560100E+01, -.26147100E+00, -.14756200E+00, -.90943000E+00, -.56350800E+00, 0.71008700E-01, -.25631500E+00, 0.12248900E+03, 0.92448400E+02, 0.16299400E+01, 0.43587600E+02, 0.52382100E+02, -.33688900E+02, 0.44003300E+02, 0.47219900E+02, 0.32604500E+02, 0.52230600E+02, 0.73665000E-01, 0.32190400E+01, 0.13193900E+02, 0.13136600E+02, 0.17942400E+01, -.35351200E+01, -.10617600E+02, -.35900000E+01, -.60566900E+01, 0.14999400E+01, 0.28803100E+01, 0.15664900E+01, -.93239800E+01, -.15965000E+01, -.37749300E+01, -.20461400E+01, -.12931100E+02, -.88957700E+01, 0.12952500E+02, -.36416100E+01, -.80627600E+01, 0.21323500E+01, 0.84644500E+01, -.33975100E+01, -.97220800E+01, -.29852500E+00 },
        { 0.27424600E+02, 0.53014900E+01, -.85266900E+01, -.11452100E+02, -.11143400E+02, -.61125900E+01, -.10696500E+02, 0.20654500E+02, 0.14099300E+01, -.10076600E-01, -.17284400E+00, -.21000700E+01, -.28841800E+01, 0.71729400E+00, 0.47728600E+01, -.81270600E+02, -.71329900E+01, -.86209600E+01, -.14899900E+02, -.16498900E+01, 0.10189700E+02, 0.32267300E+01, 0.46474600E-02, 0.72784100E-01, 0.27186900E+01, 0.42533300E+00, 0.13996800E+01, -.36159900E+00, -.42220200E+01, -.33973100E+00, 0.26755300E+01, -.94497900E+00, 0.60927500E+00, -.73682300E+01, 0.24446500E-01, -.47815500E-02, -.22661200E+00, -.29429200E+00, 0.55653900E-01, 0.36544500E+00, -.10001500E+02, 0.65026100E-01, -.32669100E-01, -.71204100E+00, -.55920300E+00, 0.12842000E+01, -.34122700E+00, -.10419800E+00, 0.20715200E+01, -.33013200E+00, 0.16752300E+01, -.27503000E+01, -.13107800E+01, -.73993000E+01, -.25837900E-01, -.79972100E+01, -.46169800E+01, 0.28157200E+00, -.16987700E+00, -.19700100E+01, 0.71440100E+00, -.26102200E+01, -.19840100E+01, 0.13962600E+01, -.10658000E+01, 0.24457400E+01, 0.20832200E+01, -.67067600E+00, 0.64565400E+00, 0.41757500E-01, -.20693100E-01, -.58838700E+01, -.42976400E+01, -.15553100E+01, 0.28454600E+01, -.14690800E+01, 0.91061300E+00, -.23741800E+01, 0.13868800E+01, 0.22319400E+00, -.20732700E+00, 0.19972700E-01, -.14417700E+00, 0.52343000E+00, 0.36251500E+00, 0.17052500E+00, -.68081200E+00, -.88368900E+00, -.27048400E+01, -.30712100E+00, 0.16510300E+01, -.34672500E-01, -.67665200E+00, -.11499800E+00, -.17109100E+01, -.33868500E+01, -.19560500E+01, 0.49552400E+00, -.24297600E+00, -.28642200E-01, -.48274500E+00, 0.15469300E+00, -.16240500E+00, 0.20601900E+01, -.13132000E+01, 0.34103100E+01, 0.14425700E+01, -.38045300E+01, 0.19726000E+00, 0.20901300E+01, -.13052100E+01, -.14261200E+00, -.19205300E+01, -.14216800E+00, 0.12817700E+00, -.18054900E+01, 0.82465600E+00, -.71070300E+00, 0.35097900E+01, 0.31264200E+01, 0.14576200E+01, -.23829800E+00, 0.67109700E+00, -.50136000E+00, -.15640500E+00, -.10219900E+00, 0.11184500E+01, -.27986500E+00, -.13119900E+01, 0.21110900E+00, 0.13946400E+01, -.27503300E+00, 0.29844200E+00, 0.10430400E-01, -.14226300E+00, -.43468500E-01, 0.87254200E+00, 0.14380000E+01, 0.12438300E+00, -.17678000E+01, 0.21973200E+00, -.92627900E-01, -.68202600E+00, -.40150900E+00, -.56492600E-01, -.24082500E+01, -.10118900E+00, 0.11740800E+01, -.20445600E+00, -.14624300E+01, -.64481400E+01, -.11397200E+01, 0.28269200E+00, -.28782200E+01, -.15734200E+00, -.13457700E+01, -.41433500E+00, 0.93874100E-02, -.37882900E+01, -.76362100E+00, -.14047200E+00, 0.23443700E+00, -.56241400E+00, -.40012800E+00, 0.46971000E+00, -.13625500E+01, 0.87246700E-01, -.58239900E+00, -.46043600E-01, 0.13286200E+01, 0.50391700E+00, -.22979700E+00, 0.11301800E-02, 0.42011500E+00, 0.23877900E+01, -.31195600E+00, -.22995000E+01, -.92377400E-01, -.83619000E+00, 0.25975200E+00, -.15002900E+00, 0.79818700E+00, 0.15739900E+01, 0.89004700E+00, -.98779700E+00, 0.10488400E+01, 0.36962200E+00, -.13990300E+01, -.10608100E+00, -.66888700E+00, 0.84199300E+00, -.51181900E+00, -.68092200E-01, 0.10289000E+01, 0.24823800E+01, -.38160400E-01, -.17741400E+01, 0.42587800E+00, 0.11774400E+00, 0.82005200E-01, 0.78599400E-01, 0.10919900E+00, 0.84722500E+00, 0.11541700E+01, 0.10092000E+01, -.20689400E+00, 0.10322900E+00, -.17432400E+00, 0.28003800E+00, 0.34669300E+00, -.34256800E-01, -.13974700E+01, -.17933800E+00, -.28244300E+01, -.90396400E+00, 0.24682600E+00, 0.16151100E+01, -.10566000E+01, -.44476800E+00, 0.25927800E+00, 0.27928600E+01, 0.56082900E-01, 0.13028700E+00, 0.23053900E-02, -.10438000E+01, 0.25386100E+00, -.50863100E+00, 0.13193900E+00, 0.60040400E+00, 0.23117500E+01, -.13292200E+01, 0.37100900E+00, 0.56118400E-02, -.61427800E-01, -.19239800E+01, 0.11756900E+01, 0.10966000E-01, 0.20764000E+00, -.52265100E+00, 0.72563500E-01, 0.14621800E+01, -.10059900E+01, 0.11858900E+01, -.96951800E-01, -.18588100E+00, 0.16195000E+00, -.22343900E+00, 0.74951400E+00, 0.22997500E+01, -.30903400E+00, -.61061100E+00, 0.17218800E+01, 0.31506000E+01, 0.20943100E-01, 0.14956100E+00, 0.11650400E+00, 0.10486500E-01, 0.19305200E+01, -.11578100E+00, 0.29516700E+00, -.19457800E+01, 0.18698900E+01, -.99062900E+00, -.45497300E+00, -.27262500E+00, 0.33236100E+00, -.66091800E+03, 0.54293200E+01, 0.15109900E+01, -.12518000E+03, 0.17144700E+03, 0.99280900E+00, 0.62659800E+02, -.50132400E+02, -.20233600E+03, 0.56431500E+01, -.15505800E+02, -.23704300E+02, -.21680700E+02, -.13666500E+02, 0.14493000E+02, 0.25212600E+02, 0.18050100E+02, 0.43736100E+01, -.47414700E+01, -.18841400E+02, -.15097800E+02, 0.16952200E+02, 0.17232800E+02, 0.19226600E+02, 0.94736500E+01, 0.23117300E+02, 0.16406900E+02, -.20916000E+02, 0.15545800E+02, 0.12572700E+02, -.83964500E+01, -.29924800E+02, 0.21657400E+02, 0.21776800E+02, 0.11403500E+01 },
        { 0.14083600E+02, 0.35333100E+01, -.29150000E+01, -.56132900E+00, -.10176400E+02, -.66990500E+01, 0.74188400E+00, -.33344400E+02, 0.17152300E+01, -.67548400E+01, -.49113700E+01, 0.68401000E+00, -.13657400E+01, 0.10158400E+01, 0.26399600E+01, -.64047100E+01, 0.61668300E+01, 0.16299700E+01, -.25738300E+01, -.25369600E+01, -.24070200E+01, -.39572400E-01, 0.68161700E+00, 0.15316400E+01, 0.12740600E+01, 0.14603500E+01, 0.79530500E+00, 0.38387100E+01, -.78419700E+00, -.49807600E+00, 0.44671000E+00, 0.27762100E+01, -.13685000E+01, -.67525700E+01, 0.31824400E-01, 0.39565200E+00, 0.18707500E+00, -.58519500E-01, -.99143900E-01, -.15668000E+00, -.63684800E+01, -.97960800E+00, 0.35919200E+00, -.81765300E-01, -.95621000E-01, 0.20848000E+00, 0.43284900E-01, 0.15206200E+00, -.21513900E+01, 0.82605400E-01, -.22572800E+00, 0.46836600E+00, -.17696700E+01, -.30878800E-01, 0.15955500E+00, -.53842200E-01, -.42382700E+00, 0.49053600E+00, 0.17523700E+00, -.14130900E+00, 0.21328300E+00, 0.13243000E+01, -.47810800E+00, -.32935300E+00, -.23593400E+01, 0.74221300E-01, -.19901400E+00, -.34315300E+00, -.15645500E+01, -.63884500E-01, 0.19784900E+00, -.72315100E+01, -.12624500E+01, 0.10807800E+01, 0.21257400E+01, 0.38258700E+00, -.18609500E+00, 0.15047600E+01, 0.94922000E-01, -.28376500E+00, 0.28655500E+00, -.45861600E-01, 0.78087700E+00, 0.15529800E+01, 0.29771300E+00, -.51082000E+00, 0.30188300E+00, -.33931700E+00, -.10421200E+01, -.50532100E-01, 0.19092200E+01, 0.14212300E-01, -.15561700E+01, -.19311500E+00, 0.69482700E+00, 0.10575500E+00, 0.27292600E+00, 0.97981800E+00, 0.33249300E+00, 0.18809800E+00, -.22688800E-01, 0.77427000E+00, 0.25146300E+00, -.44756300E+00, -.49238100E+00, -.16300400E+02, -.28463600E-03, -.70168900E+00, 0.78600500E-01, 0.70908300E+00, 0.19797800E+00, -.41764400E-01, -.30350800E+01, 0.25498700E+00, 0.10937200E+00, 0.16431400E+01, -.13043100E+00, -.57163300E+00, 0.28824000E+01, 0.28506900E+00, 0.24363900E+01, -.43764300E+00, 0.61306200E-01, 0.41960000E+00, -.24887000E+00, -.15438900E+00, -.68241900E+00, -.22088400E+01, 0.17687400E+01, 0.76079500E+00, 0.49052800E+00, -.64987500E+00, -.68705400E+00, 0.88535400E-01, -.23161400E+00, -.11038800E+00, 0.86187900E+00, 0.29196300E-01, 0.50497600E-01, 0.90796400E+00, -.70001500E-01, -.52264500E+00, 0.51763000E+00, 0.29474300E+00, 0.88418900E-01, 0.17575700E+01, 0.44402200E+00, 0.93962700E+00, 0.30341800E+00, -.11780300E+01, 0.39033900E+01, -.49413400E+00, -.12551300E+01, 0.20364200E+01, 0.17769000E+00, -.98086500E-01, 0.33315700E+00, -.17934800E-01, 0.10394400E+01, 0.10160400E+01, 0.24134100E-01, 0.25995500E+00, -.39535600E+00, -.82395600E+00, -.35063000E+00, -.27579000E+00, 0.66285700E-01, 0.71624300E+00, 0.43408300E-02, 0.14361500E+01, -.81070900E-01, 0.24612100E+00, 0.24333900E+00, -.26401400E+00, 0.11498400E+01, 0.31668300E+00, -.18359600E+01, -.14258600E-01, 0.82899900E+00, -.42614700E+00, 0.10931200E+01, 0.10391800E+01, -.13730100E+01, 0.45678000E+00, -.35753400E+00, 0.13740400E+01, -.23682200E+00, -.83491700E+00, 0.11996400E+00, -.57146300E+00, 0.14012600E+01, 0.10482800E+00, 0.32724100E+00, 0.77622100E+00, -.20392300E+01, 0.44932600E+00, -.19948000E+01, 0.15055100E+00, -.83332400E-01, -.15315400E-01, -.54854700E+00, -.29961800E+00, -.29681300E+00, -.50050200E+00, 0.12823300E+00, -.49684100E+00, 0.15787500E-01, 0.78228800E+00, 0.20781400E+00, -.80446900E-01, -.39994900E-02, -.57804500E+00, 0.34113900E+00, 0.24832200E+00, -.74321300E+00, 0.64383900E+00, -.42116900E+00, -.60030100E+00, -.23288300E+00, 0.98835500E+00, 0.20910500E+01, 0.68756500E-01, 0.13769500E-02, -.26914700E-01, 0.44256500E+00, 0.85360300E+00, 0.55624100E+00, -.50566400E-01, -.17744300E-01, 0.12452000E+01, -.17217200E+01, 0.13074800E+01, -.18043100E-01, -.41839000E+00, 0.73701400E+00, 0.11821100E-01, 0.97643100E-01, -.24264600E+00, 0.19578200E+01, 0.24496100E+01, -.83362600E+00, -.72678900E-01, -.72404500E+00, 0.29726200E-01, -.11289400E+00, -.62071800E-01, -.13254200E+00, 0.23585800E-01, -.17808500E+01, -.75877500E-02, 0.69980700E-01, 0.47947000E+00, -.99643800E+00, 0.29859500E-01, 0.34780400E-01, 0.27371000E+00, -.20299000E+00, 0.84129400E+00, 0.76972300E+00, -.16977400E+00, 0.36823600E+00, -.56713700E+00, -.25603000E+00, -.51062500E-01, -.29550700E+00, 0.35971200E-01, 0.42448600E-02, 0.35068900E+02, 0.39025300E+02, 0.20838200E+02, -.78962300E+00, 0.33924500E+02, 0.20995900E+02, 0.19814800E+02, 0.49764200E+01, -.29154800E+00, 0.34206100E+00, 0.10508800E+02, 0.11321300E+02, -.66969900E-01, -.11503000E+01, -.48901700E+01, -.38345100E+00, -.29033600E+01, 0.11445500E+01, -.82920100E-01, -.46494100E+00, -.38062000E+01, 0.26273600E+00, -.47022200E+00, 0.11653600E+01, -.11001800E+02, -.39761200E+01, 0.10972000E+02, -.93027500E+00, -.21485100E+01, -.12673200E+01, 0.16197200E+00, 0.14881100E+00, -.39842700E+01, -.65332800E+00 },
        { -.32001100E+02, -.73460500E+01, 0.85803800E+01, 0.13055700E+02, 0.11194300E+02, 0.77964500E+01, 0.96738900E+01, -.22214500E+02, -.30959700E+01, -.56442600E+01, 0.79628700E+00, 0.34573800E+01, 0.55599800E+01, -.84049600E+00, -.53456300E+01, 0.50896100E+02, 0.13255100E+02, 0.60060000E+01, 0.13021300E+02, -.49365200E+00, -.48955400E+01, -.38973500E+01, -.15245800E+00, -.12093100E+01, -.61720600E+00, 0.28022500E+00, 0.20310800E+01, -.66165200E+01, -.61503800E+01, 0.11830800E+01, -.40793100E+01, -.56209000E+01, 0.47885200E+01, 0.53034000E+01, -.83813700E-01, -.53839000E+00, 0.51478800E+00, 0.46715400E+01, -.36490200E+00, -.86575700E+00, 0.20351100E+02, -.45040200E-01, -.26031800E+00, 0.55779800E+00, -.22091400E+01, -.16719300E+01, 0.26699000E+00, -.54320200E-01, -.18841800E+02, 0.20880200E+00, -.15877900E+01, 0.60041300E+01, -.41102000E-01, 0.11187800E+02, -.30587200E+00, 0.57752000E+01, 0.29909400E+01, -.15380700E+01, -.37666800E+00, -.13033000E+01, 0.13555600E+01, -.39539100E+01, 0.23887800E+01, -.19078100E+01, -.74409400E+00, -.12903700E+01, 0.48545900E+01, 0.14185200E+01, 0.17205900E+01, -.40472900E-01, -.33611900E+00, 0.16414900E+02, -.11727700E+01, -.10728000E+01, -.31729800E+01, -.68351200E+01, -.69503100E+00, -.13207700E+00, -.28545100E+01, -.74930900E+00, 0.89182400E-01, 0.17125900E+00, -.92923900E+00, 0.41803100E+01, -.42367300E+00, -.24500500E+01, -.23882600E+00, 0.93551100E+00, -.45371800E+00, 0.52416100E+00, -.35166500E+01, -.16234600E-01, 0.17518000E+01, -.30468300E+00, 0.63587500E+01, 0.23829200E+01, 0.15021000E+00, -.38932400E+01, 0.77599800E+00, -.18068600E+01, 0.40309800E+00, 0.57823500E+00, 0.78790100E-01, -.12204400E+01, -.31131300E+00, 0.17571500E+02, -.84084200E+00, 0.60502800E+00, -.20532200E+00, -.12207000E+01, -.37906900E+00, -.49878700E-01, 0.36601400E+01, -.87769100E-01, -.34116600E+00, 0.18243200E+01, -.82814400E+00, 0.10776800E+01, -.44777300E+01, -.15895400E+00, -.44017200E+01, 0.19182300E+00, 0.22837000E-02, -.99122400E+00, 0.19576200E+00, 0.10355900E+01, 0.14144600E+01, 0.17251600E+01, -.66765600E+00, 0.38390100E+00, -.33269900E+01, 0.23738700E+01, 0.36160800E+01, -.39098000E+01, 0.22006300E+01, 0.19953200E+00, -.26395900E+01, -.41263600E+01, 0.45044300E+00, -.66565400E+00, -.18406700E+01, 0.82348100E+00, -.31180500E+01, -.13337700E+01, -.40771200E+00, -.27897200E+01, -.44493500E+00, 0.26876200E-01, 0.72799900E-01, 0.41695800E+01, 0.16193700E+02, 0.43802500E+01, 0.15640800E+01, 0.19563400E+01, -.76941100E+00, 0.93179900E+00, 0.40303100E+00, -.62726100E-02, -.36932500E+01, -.21858700E+01, 0.25062100E+00, 0.18115700E+00, 0.28298300E+00, 0.55359000E+00, -.30595600E+01, -.20731600E+01, -.59509500E+00, 0.39134400E+00, 0.64386800E-02, 0.22302100E+01, -.13132700E+01, 0.93282300E+00, -.68969600E-01, -.34560700E+00, -.16113200E+01, -.15391600E+01, 0.10031000E+01, -.52049600E-02, 0.18821300E+01, 0.28374100E+00, -.12425300E-01, 0.26168600E+01, -.22533100E+01, -.49005000E+01, 0.40953500E+00, -.12577500E+01, -.29580900E+00, 0.23996600E+01, 0.51853300E-01, -.19710100E+01, 0.77781500E+00, -.81870400E+00, -.14269900E+01, -.44945000E+00, -.34279100E+01, -.11231200E+01, 0.25998200E+01, -.20857500E+01, 0.14789200E+01, -.49323700E+00, 0.11949900E+01, 0.44891300E+00, -.38774600E+01, 0.35721600E-01, -.75157200E+00, 0.14969200E+01, 0.43260700E+00, -.51348100E+00, -.31030300E+00, -.53180400E+00, 0.26056400E+00, 0.82179500E+00, 0.33936700E+00, -.64641800E+01, -.54975400E+01, -.31959800E+01, -.28513600E+01, 0.15002800E+01, 0.14232100E+01, -.43487400E+00, -.48284200E+01, 0.29918200E+00, -.28379800E+00, 0.77709100E-02, 0.31846000E+00, -.16960500E+00, -.83818900E+00, 0.32705700E-02, -.66823200E+00, 0.28994100E+01, -.51172500E-01, 0.17088800E+01, -.38934700E-01, 0.55570300E+00, -.38769100E+01, 0.52116000E+01, -.41128600E+00, 0.38236300E-01, 0.43390500E+01, -.10776500E+01, -.33738200E+00, -.67558600E+00, -.89603300E+00, -.29960500E+00, 0.31537800E+00, 0.10026000E+00, 0.20042200E+00, 0.52436500E+00, -.53842900E+00, 0.28343900E+00, -.15585400E+00, -.53527000E+01, 0.25575800E+01, -.55858800E+00, -.99736900E-01, 0.34327500E-02, -.23789000E-01, 0.11902200E+01, -.19403500E+01, 0.45395900E+00, 0.48768300E+00, 0.18536700E+01, 0.18408900E+00, 0.22680200E+01, 0.14604400E+01, -.47611100E+00, -.23578100E+00, 0.68736600E-01, -.50972300E+03, -.43075400E+03, 0.16637000E+03, -.31385400E+03, -.28655900E+03, -.46624000E+03, -.26693900E+03, -.31551300E+01, -.25564200E+02, -.11696900E+03, -.12497500E+03, -.35394100E+01, 0.18476900E+02, 0.71810300E+02, 0.25104500E+02, 0.58180000E+02, -.38122700E+02, -.21258000E+02, 0.42991600E+01, 0.67781500E+02, 0.37810900E+00, 0.25749700E+02, -.66304900E+01, 0.12358900E+03, 0.64881900E+02, -.12089800E+03, 0.17779300E+02, 0.66533100E+02, 0.80702300E+01, -.23431500E+02, 0.20937000E+02, 0.64011700E+02, 0.10726400E+02 },
        { 0.19751800E+02, 0.39272100E+01, -.45035400E+01, -.60910200E+01, -.81662900E+01, -.49255900E+01, -.49477200E+01, 0.35623800E+01, 0.19440300E+01, 0.13109600E+01, -.23398000E+01, -.23193400E+01, -.37765700E+01, 0.54919100E+00, 0.29115300E+01, -.23742300E+02, -.28968200E+01, -.31741900E+01, -.86235700E+01, 0.17956100E+00, 0.53676800E+01, 0.15659100E+01, -.20830200E+00, -.14597800E+01, 0.34825200E+00, -.49228800E-01, -.16955500E+01, 0.11498600E+01, 0.62219200E+01, -.50950400E+00, 0.86695200E+00, -.69607500E-01, -.15652600E+01, -.24055200E+01, 0.93306400E-02, -.11826600E+00, -.40145900E+00, -.13768900E+01, 0.43567800E+00, 0.14737200E+01, -.11813000E+02, 0.25034000E-01, -.16095800E+00, -.75270600E+00, 0.65525100E+00, 0.18168100E+01, -.28659200E+00, 0.25611000E-01, 0.93719400E+01, -.55409700E+00, 0.22980500E+01, -.27359300E+01, -.10341800E+01, -.71698200E+01, -.43572900E+00, -.52482000E+01, -.22988700E+01, 0.79403300E+00, -.33410200E-01, 0.15432300E+01, -.85491700E+00, 0.21079700E+01, -.14197400E+01, 0.14289800E+01, -.17861200E+00, -.82972900E+00, -.53029600E+01, -.11533800E+01, 0.81896300E+00, 0.12127100E+00, 0.36166900E+00, -.67597900E+01, 0.18061000E+01, 0.39052800E+01, 0.63564900E+00, 0.39703500E+01, -.26996100E-01, 0.10299100E+01, 0.63790400E+00, 0.17480800E+00, -.20752600E+00, -.28910000E+00, 0.39831500E+00, -.20470400E+01, 0.59457000E+00, 0.13026300E+01, 0.97449700E+00, -.61503800E+00, 0.17571700E+01, -.33879700E+00, 0.33673100E+01, -.39565500E-02, 0.22916600E+00, 0.25833800E+00, -.36158500E+01, -.40534400E+00, -.44649000E+00, 0.11788900E+01, -.54835300E-01, 0.11475800E+01, -.25904900E+00, -.17010300E+00, -.18368600E+00, 0.49060600E+00, 0.10667000E-02, -.14230400E+02, 0.88837400E+00, -.17107000E+00, 0.75817200E-01, -.16760100E+00, 0.12293800E+01, 0.16902100E+00, -.28012600E+01, -.82447500E-01, -.10582800E+01, 0.60428300E+00, 0.41181100E+00, -.72664600E+00, 0.38286600E+01, -.25236100E+01, 0.31498100E+01, -.10528100E+00, -.29877600E+00, 0.41203200E+00, -.17464700E+00, -.44444000E+00, -.20877800E+00, -.33584500E+00, 0.22879800E+01, 0.22647000E+00, 0.21979400E+01, -.99070300E+00, -.14086400E+01, 0.62937600E+00, -.86673200E+00, -.16452700E-01, 0.43910500E+00, 0.17771000E+01, 0.29234500E-01, 0.30361800E+01, 0.13091500E+01, -.60987500E+00, 0.18677200E+01, 0.12474500E+01, 0.18601600E+00, 0.78851900E+00, -.76544700E-02, 0.39181100E+00, -.44060000E-01, -.12523400E+01, -.49465100E+01, -.17121700E+01, -.65797000E+00, -.30952700E+00, 0.21693900E+00, -.88064900E+00, -.60283200E+00, 0.18202100E-01, 0.41332700E+01, 0.15904100E+01, -.12396300E+00, -.36910900E+00, -.22083100E+00, -.12630400E+00, 0.90942800E+00, 0.20693200E+01, 0.26616600E+00, -.45819100E+00, -.44199300E-01, -.32547500E+00, 0.34629900E+00, -.35370200E+00, 0.40663000E+00, -.32853700E+00, 0.47688400E+00, 0.92715600E+00, -.17412500E+00, 0.13579900E-01, -.71603800E+00, -.16771200E+00, 0.58833800E+00, -.99804000E+00, 0.21316500E+01, 0.26639100E+01, -.12194400E+00, 0.63575800E+00, 0.53775100E+00, -.57198400E+00, -.67580200E-01, 0.67983700E+00, 0.14553500E+01, 0.92490500E+00, 0.50026300E+00, -.64731000E+00, -.19281700E+01, -.23566900E+00, -.20502700E+00, 0.10243100E+01, -.26028800E+01, 0.33299800E+00, -.58542900E+00, 0.17847300E+00, 0.10602000E+01, -.42149100E+00, -.63010000E+00, -.60129100E+00, 0.49554400E+00, 0.38197200E+00, 0.28568900E+00, 0.29637900E+00, -.76435900E-01, 0.45908500E+00, -.24238300E+00, 0.11151900E+01, 0.15156100E+01, 0.16415800E+01, 0.33689000E+01, -.31229000E+01, 0.27027000E+00, 0.35005200E+00, -.56438900E+00, -.10833200E+00, -.14687300E+00, 0.10782200E+00, 0.19174100E+01, -.89682400E+00, -.98181600E+00, -.47676400E+00, 0.84008000E+00, -.96592500E+00, -.42605500E+00, -.24629600E+00, -.26986200E-01, -.41227600E+00, 0.22654800E+01, -.18785200E+01, 0.10247600E+00, -.69609200E+00, -.61228000E+01, 0.17433300E+01, -.94158600E-01, -.23778800E+01, -.27594000E+00, 0.91509000E-01, 0.14412200E+00, 0.52401800E-01, 0.12050800E+00, 0.46557700E+00, 0.15918400E+01, -.37371400E+00, -.10098700E+01, 0.38336900E+01, 0.14292900E+01, -.13300000E+01, 0.72512700E-01, 0.62098400E+00, 0.27052800E-01, 0.38822700E+01, -.22050000E+01, 0.52275600E+00, 0.96502100E+00, 0.23027100E+01, 0.13736500E+01, 0.84068200E+00, 0.56680200E+00, -.38281500E-01, 0.32219500E+00, -.12726900E+00, 0.29972500E+00, -.14031300E+03, 0.10171400E+03, 0.93437100E+02, 0.20529600E+02, -.14437600E+03, -.23969800E+02, -.23386000E+01, -.10418500E+02, 0.15401900E+02, 0.18324100E+02, -.27435500E+01, 0.35109100E+01, 0.16425800E+02, 0.88724400E+01, 0.13916100E+02, -.68792300E+01, -.91338400E+01, 0.30842500E+01, 0.13719300E+02, 0.25021400E+01, 0.92513400E+01, 0.64755900E+01, -.17311000E+02, 0.12653700E+02, 0.17055400E+02, 0.39412100E+01, 0.13943700E+02, -.66223500E+01, -.17217300E+02, 0.99323300E+01, 0.12694700E+02, -.49722200E+01 },
        { -.18570200E+02, -.48428900E+01, 0.46554700E+01, 0.97341600E+01, 0.56047300E+01, 0.43852800E+01, 0.91996300E+01, -.22934300E+02, -.16270600E+01, -.30579900E+01, -.19057500E+00, 0.26294200E+01, 0.34679000E+01, -.59563700E+00, -.35437100E+01, 0.37512000E+02, 0.11501700E+02, 0.68386200E+01, 0.69575600E+01, -.16294200E+01, -.25422100E+01, -.96364300E+00, 0.82606700E-02, 0.23919500E+01, -.72530200E+00, -.10438600E+00, -.70817000E+00, 0.19914600E+01, 0.55527900E+00, 0.29079500E+00, -.25368500E+01, -.23168500E+01, 0.56901300E+00, 0.60914700E+00, 0.33087300E-01, -.35715000E+00, 0.10269200E+00, 0.39898800E+01, -.95241100E-01, -.18406300E-01, 0.91979400E+01, 0.14674600E+01, -.27121700E+00, 0.33571700E+00, -.29168400E+01, -.37661800E+00, -.48402400E-01, -.31563900E+00, -.11702600E+02, 0.37210600E+00, -.33886600E+01, 0.15716600E+01, -.12565000E+01, -.46856600E+00, -.57641600E+00, 0.38472400E+01, 0.11100300E+01, -.64770200E+00, -.34919700E+00, -.61892500E+00, 0.73935400E+00, -.15033400E+01, -.12874200E+00, -.45380000E+00, -.20220100E-01, -.79423500E+00, 0.45382600E+00, 0.81242100E+00, -.10459500E+01, 0.31563300E-01, -.20990500E+00, 0.72210100E+01, -.10958600E+01, -.42307300E+00, -.98790600E+00, -.36476000E+01, -.48630200E+00, 0.71270400E+00, -.89859300E+00, -.67567600E+00, -.21896800E+00, 0.23728300E+00, 0.23440600E+00, 0.72313500E+00, -.10500100E+01, -.10472400E+01, -.52400600E+00, 0.10547400E+00, -.20846000E+01, -.20568300E+00, -.20034800E+01, -.26630100E-01, 0.47020400E+00, -.10225700E+00, 0.27720300E+01, 0.16379100E+01, 0.12059000E+01, 0.54101400E+00, 0.38622500E+00, 0.88518700E+00, -.18192900E+00, 0.60192200E+00, -.81849600E-01, 0.71766100E-01, -.41404000E+00, 0.77705300E+01, -.18711300E+00, -.39206900E+00, -.11012800E+00, -.11187600E+01, 0.19860800E+01, -.47278900E-01, 0.33113900E+01, -.30375600E-01, -.22273400E+01, 0.11670100E+01, -.18606300E+00, -.10117900E+01, 0.18519200E+01, -.78190400E+01, 0.13960000E+01, -.12801100E+00, -.13620600E+01, 0.78596400E+00, -.29557900E+00, 0.15848000E+01, -.14840000E-02, -.26781200E+00, 0.22377800E+01, 0.20593000E+01, -.40106700E-01, -.16423400E+00, -.19563600E+00, 0.71767500E+00, 0.66619900E+00, 0.33087500E-01, -.11421600E+01, 0.63244400E+00, 0.25684700E+00, -.64220100E+01, -.32928500E+00, 0.21065700E+00, 0.99315700E-01, -.29320600E+00, -.12461700E+00, -.51334300E+00, -.14709300E+00, -.19249900E+01, 0.11912400E+00, 0.15642800E+01, -.15977700E+01, 0.10944800E+01, 0.67931400E+00, 0.24672800E+01, -.42280900E+00, 0.19035000E+01, 0.73187500E-01, -.10727000E-01, -.16858300E+01, -.52793000E+00, 0.58701700E+00, 0.22512300E+00, -.30770700E+00, -.35025300E+00, -.25341000E+01, -.15047000E+01, -.25374900E+00, -.91596900E-02, 0.17848100E-02, 0.56645800E+00, -.11721200E+00, 0.17641000E+00, -.10098200E+00, 0.13304000E+00, -.12180700E+00, -.34230900E+00, -.28534500E+00, 0.24093400E-01, 0.41510500E+00, 0.19103700E+00, -.97889000E+00, 0.11956000E+01, -.69410900E+00, -.10385400E+01, -.37740600E+00, 0.41588700E+00, 0.67401800E+00, -.10837000E+00, -.67843600E-01, -.79579600E+00, 0.31542500E+01, -.43816100E+00, -.38592800E+00, -.23011600E+00, -.39143500E+00, 0.40871700E-01, 0.58635800E-01, 0.30071500E+00, 0.73276400E+00, -.32327900E-01, 0.12677600E+00, 0.14110000E+00, -.19330200E+01, 0.38229200E+00, -.38218800E+00, 0.26365400E+00, -.30239000E+00, -.21208500E+00, -.42772600E-01, -.30627300E+00, 0.81179300E-01, -.47841600E+00, 0.72938600E-01, -.29193100E+01, -.32492100E+01, -.11577600E+01, -.14920400E+01, 0.26099900E+00, 0.17198600E+00, -.63567300E+00, 0.25182800E-01, 0.15970700E+00, -.37004800E+00, -.23332400E-01, 0.14078700E+01, -.27418900E+00, 0.38208900E+00, 0.14188400E+00, 0.21319800E+01, 0.68683400E+00, 0.42495200E+00, -.11006600E+00, 0.20551900E-01, 0.41386300E+00, -.31324500E+01, 0.82077200E+00, 0.23095500E-01, 0.72501400E+00, -.60062800E+01, -.22893700E+01, 0.24990400E+01, -.15959000E+00, 0.11313000E+01, -.10090600E+00, 0.31095100E+00, 0.11929200E+00, 0.51446400E+00, 0.20898200E+00, 0.20785400E+01, -.41030300E-01, 0.43941200E-02, -.21424200E+01, 0.13627600E+01, -.51334800E+00, -.38069200E-01, 0.17451900E+00, 0.16220100E-01, 0.15585700E+01, -.87697800E+00, 0.17680700E+00, 0.66329500E+00, 0.11096400E+00, -.12853700E+01, 0.74047900E+00, -.24082500E-01, -.96000500E-01, 0.18062000E-01, -.71947300E-02, 0.26860700E+00, 0.69349700E-02, 0.66334600E+02, 0.25194600E+02, -.40988400E+02, 0.18789600E+02, 0.29154800E+02, -.20272000E+01, -.39116800E-01, -.51381300E+01, -.50984800E+01, -.76416600E+00, -.27057600E+00, -.29029700E+01, 0.15427700E+01, -.14745800E+01, 0.12587200E+00, -.86705700E+00, -.18209100E+01, 0.12522900E+00, 0.19677500E+01, 0.16033200E+01, 0.82041500E-01, 0.49856200E+01, 0.19417400E+01, -.47926600E+01, -.96753700E+00, 0.19349600E+01, -.18930300E+00, -.27860200E+01, 0.93044200E+00, 0.23654000E+01, 0.48876600E+01 },
        { 0.52117300E+01, 0.18396800E+01, -.34140600E+00, -.24014400E+01, -.16728800E+01, -.15349200E+01, -.18454500E+01, 0.44986800E+00, 0.90227700E-01, -.62262600E+00, -.40848900E+00, -.74643200E+00, 0.21357300E-01, 0.30157800E+00, 0.78027600E+00, -.12837600E+02, 0.36743000E+01, 0.27666400E+01, -.44873700E+01, -.77449200E+00, 0.11311400E+01, 0.45501300E+00, -.62529400E-01, -.43505300E+00, 0.32666300E+00, 0.17051700E-01, -.73920900E-01, -.86656900E+00, -.68735600E+00, -.13328100E+00, 0.11522000E+01, -.20754100E+00, -.49882800E+00, -.57053000E+00, 0.25046700E-03, 0.56020400E-01, 0.10391300E+00, 0.39166500E+00, 0.23434900E+00, 0.30874400E+00, -.41936200E+01, 0.61236700E+00, -.43522400E-01, 0.23139200E-01, -.22141200E+00, 0.44595900E+00, -.11170500E+00, 0.87186300E-01, 0.10554500E+01, -.29082500E+00, 0.10339500E+01, -.98508900E+00, 0.40453900E-01, -.37316300E+01, -.80804200E-01, -.16357600E+01, -.14865400E+01, 0.26342800E+00, 0.11607100E+00, -.70994400E+00, 0.24752400E+00, 0.72266700E+00, -.49411300E+00, 0.55593600E+00, -.29602500E-01, 0.41274800E+00, -.86432200E+00, -.45152800E+00, 0.31191500E+00, 0.61848900E-02, 0.10940200E+00, -.15712000E+01, -.13351400E+01, 0.17187000E+01, 0.14356900E+01, 0.69415000E+00, -.21082800E+00, 0.19880000E+00, 0.72562900E+00, 0.13710300E+00, 0.10440800E+00, -.11444800E+00, -.32773300E+00, -.58735200E+00, 0.11595400E+00, 0.94118700E-01, 0.10002000E+00, -.18454100E+00, -.63414600E+00, -.21086700E+00, 0.10934600E+01, -.39511300E-02, -.20421600E+00, -.28752900E+00, -.34277000E+00, 0.79800800E+00, 0.10798100E+00, 0.98608800E+00, 0.10646600E+00, 0.83302600E+00, -.19455400E+00, 0.34120400E+00, -.10415800E-02, -.78953300E-01, -.38295400E+00, -.50888300E+01, 0.16488100E+00, -.61500200E+00, -.22429900E+00, 0.15458500E-01, 0.50321600E+00, -.46608500E-01, -.91872800E+00, -.22446100E-01, -.12533900E+00, 0.88259800E+00, 0.58467000E+00, -.80783400E+00, 0.12281400E+01, -.14353800E+00, 0.17319500E+01, -.21757200E+00, -.19449100E+00, -.17778600E+00, -.15374400E+00, -.91825200E-01, -.91537600E+00, 0.10487700E+01, 0.33711100E+00, 0.56786300E+00, -.29115800E+00, -.39555900E+00, 0.18969800E+00, 0.58896100E+00, -.25736600E+00, -.75430800E-01, 0.11422200E+01, 0.48454600E+00, -.30801600E-02, -.33141400E+00, 0.23611000E+00, -.53174800E-01, 0.11044000E+00, -.12637900E+00, 0.96600800E-01, 0.12041600E+01, 0.16979800E+00, -.30395500E+00, 0.15596800E-01, -.99055400E+00, -.18457400E+01, -.33614000E+00, -.29383600E+00, 0.17337100E+01, 0.12447500E+00, 0.21171200E+00, 0.36801300E+00, 0.38324100E-02, 0.15034100E+01, 0.29388500E+00, 0.57233900E-02, 0.19436200E-01, -.66455100E-01, -.14065400E+00, -.31555600E+00, 0.57391500E-01, -.10158300E-01, -.25732400E+00, -.22503100E-01, 0.17709200E+00, 0.19458900E+00, 0.34909400E-01, 0.26315500E+00, -.32672300E+00, 0.33669800E+00, 0.15616300E+00, -.12672200E+00, -.15609900E-01, 0.11952900E+00, -.57677000E-01, 0.32900000E+00, 0.88136500E+00, 0.70385200E+00, 0.13447400E+00, -.35057900E+00, -.44497100E+00, -.59134500E-01, -.12058500E+00, 0.26751900E-01, -.65400800E+00, 0.65831100E+00, -.21804900E-02, -.27320200E+00, 0.16140900E+00, -.93311100E+00, 0.11883600E+00, -.38426200E-02, 0.59901400E-01, 0.59972200E+00, 0.32288700E-02, -.76945000E-01, -.25962200E-01, -.57248700E+00, 0.63119700E+00, 0.53630500E+00, 0.12583700E+00, -.20872000E+00, 0.91540800E-01, 0.11225100E+00, 0.12862200E+00, 0.68894100E-02, -.75574200E+00, -.35709700E-01, 0.31118700E+00, 0.28948500E+00, 0.21365700E+00, 0.88652700E+00, -.51846100E+00, -.20500600E+00, 0.37526300E+00, 0.25180600E+01, 0.97306100E-03, 0.11263700E+00, -.71824200E-02, 0.38983800E-02, -.35866800E+00, -.89822500E+00, 0.20550400E+00, -.37968100E+00, -.17534000E+01, -.40838200E+00, 0.94330800E-01, 0.10855400E-01, -.10842600E+00, -.20839300E+00, -.21991300E+00, -.21343800E+00, 0.10225100E+00, 0.21259200E+01, -.13697600E+01, 0.20489500E+00, -.61158300E+00, 0.67004900E+00, -.71309600E-01, -.16653000E-01, -.23659600E-02, 0.13581200E+00, 0.42846500E-01, 0.24181300E+00, -.10540700E+00, -.45636600E-01, -.84233900E+00, 0.41262500E+00, -.37874900E+00, -.30909500E-01, 0.73374300E-01, 0.94190200E-02, -.34973900E-01, -.51750300E+00, 0.17903500E+00, 0.16239700E+00, 0.51040100E+00, -.26107400E+00, -.15460400E+00, 0.97893400E-03, 0.31497300E-01, 0.18614200E+00, -.13099200E-01, 0.72741100E-02, -.21027400E+00, 0.79438800E-02, -.29259100E+02, -.51576400E+02, 0.10856800E+02, -.48577700E+02, -.56043500E+00, -.13981100E+01, 0.15201500E+01, 0.23606200E+01, 0.11962800E+00, 0.23908400E+00, 0.78091100E+00, 0.62855700E+00, 0.67644800E+00, 0.34018600E+01, -.62383400E+00, -.28329600E+00, 0.27057800E+01, -.45441200E+00, 0.55648500E+00, 0.40713800E+01, -.22990600E+01, 0.27756700E+01, 0.21989200E+01, 0.55521400E+00, 0.24378100E+01, -.43199900E+01, -.70349700E+01, 0.93871200E+00, 0.25658800E+01, -.25774900E+00 },
        { -.71061100E+01, -.12620300E+01, 0.18628700E-01, 0.29991000E+01, 0.92036200E+00, 0.11307900E+01, -.65214600E-01, -.50727100E+01, -.49194600E+00, -.73837400E+00, 0.12688000E+00, 0.13342300E+01, 0.41922300E+00, -.45111700E+00, -.19920200E+00, 0.54339000E+01, -.56969500E+01, -.46024300E+01, 0.40703000E+01, -.57149300E+00, -.12139500E+01, -.27453500E+00, 0.28239100E+00, 0.29524900E+01, -.26931900E+00, -.15505300E+00, -.53182700E+00, 0.14680600E+01, 0.88316400E+00, 0.41171900E-01, -.10084300E+01, 0.57624800E+00, -.40398200E+00, -.72744100E-01, 0.32769700E-01, 0.29257900E-02, -.33480100E-01, 0.69734300E+00, -.17784100E+00, -.13193400E+00, 0.31886200E+01, -.11625400E-01, 0.54432300E-01, 0.22476500E+00, 0.21554400E+00, -.47176500E+00, 0.12385200E+00, -.56197400E-01, -.21727800E+01, 0.27771400E+00, -.87958600E+00, 0.14487300E+01, -.41009100E+00, 0.33582500E+01, 0.37043600E+00, 0.27827700E+01, 0.16853400E+01, -.66496900E-01, -.71717700E-01, 0.25847200E+00, 0.11827800E+00, -.13482700E+01, 0.44010300E+00, 0.10552700E+00, 0.40035300E+00, -.52353600E+00, 0.78487900E+00, 0.27946100E+00, -.52597400E+00, -.70658400E-02, 0.10807600E-01, 0.19718700E+01, -.21378600E+01, -.29384100E+01, 0.32376700E+00, -.44382400E+00, -.21259100E+00, -.71626800E+00, -.36580500E+00, 0.45923700E-01, 0.32460500E-01, 0.16221800E+00, -.18951300E+00, 0.44845800E+00, -.46175600E+00, -.92119100E+00, -.37371300E+00, 0.18814100E+00, 0.16965600E+00, -.14970500E+00, -.75063400E+00, -.28695100E-02, 0.32521100E+00, -.16787700E+00, 0.64240700E+00, 0.18049900E+01, -.92091500E+00, -.56783500E+00, 0.18759100E+00, 0.63479400E+00, -.19005300E+00, 0.24986200E+00, 0.19452900E-01, -.42778600E+00, -.35898800E+00, 0.14622000E+01, 0.87483100E+00, -.12403300E+00, -.22026400E+00, -.17508300E+01, -.64121700E+00, 0.19724700E-01, 0.83381100E+00, -.72936700E-01, -.16980000E+01, -.26900400E+01, 0.42016500E-01, 0.64928500E+00, 0.18291400E+01, -.18015500E+01, 0.59121900E-01, 0.33679200E-01, 0.46370700E-02, 0.26175600E-01, -.57017200E-02, -.54446100E+00, 0.50450500E+00, -.92029900E+00, -.38813300E+00, 0.37139200E-01, 0.87087000E+00, -.32564600E+00, -.10726200E+01, 0.37940400E+00, -.30377000E+00, -.18593300E-01, 0.83199000E+00, 0.66261400E+00, -.37663000E+00, -.29659300E+01, 0.96334000E+00, 0.29950600E+00, 0.35871400E+00, 0.47863600E+00, -.39389600E-01, 0.15932200E+01, 0.76900700E-01, -.14339300E+01, -.17829500E-01, 0.13523200E+01, -.43053500E+01, -.62109600E+00, -.79957200E-01, -.55152500E+00, 0.22691700E+00, -.25035000E+00, -.21084700E-01, -.55430600E-02, 0.12486000E+01, 0.75871200E+00, 0.68770500E-01, 0.45616900E+00, -.22897300E+00, 0.46639200E+00, 0.80027400E+00, 0.20815500E+00, 0.15118500E+00, -.48647900E+00, 0.12618000E-01, -.88376400E+00, 0.23354200E+00, -.20785600E+00, 0.23032500E-01, 0.19875200E+00, 0.75826200E+00, 0.65344300E-01, 0.23396900E+00, -.13381300E-02, -.76509500E+00, 0.80675400E-02, -.82564400E+00, -.68959300E-01, 0.17802000E+01, 0.37542400E+00, -.26375200E+00, -.75275200E-01, 0.21227800E+00, -.22807000E+00, -.65252800E-01, 0.52491900E-01, -.40488600E+00, 0.10940600E+00, -.48889000E+00, -.55739200E+00, -.18959300E+01, -.18653500E-01, 0.19079500E+01, 0.10415500E+00, 0.23647500E+00, -.38450900E-02, 0.81326300E-02, 0.11064900E+00, -.28524800E+00, 0.10978700E+01, 0.38626600E+00, 0.11214500E+00, -.19598100E+00, -.94586400E+00, 0.48876800E+00, 0.27198700E+00, -.47737800E-02, -.30053900E+00, -.26281400E-01, 0.26077800E+00, 0.11389000E+01, 0.81995300E-01, 0.47879200E+00, -.37547400E+00, -.18716300E+00, 0.23936000E+00, -.46872900E+00, -.98941500E-02, 0.23925900E+00, -.68314400E-02, -.76726100E+00, -.58052300E+00, -.11441800E+00, -.87016700E-01, -.23541200E+00, -.46103900E+00, 0.83455000E+00, -.66292700E+00, 0.82431100E-02, 0.92843200E-01, 0.26185700E+00, -.16517600E+01, -.17745500E+00, 0.12763400E+00, -.39905100E+00, -.36995100E+00, 0.51852000E+00, 0.55143800E+00, 0.14459600E+00, 0.22811200E-01, 0.17614300E+00, -.22876700E-01, 0.28767400E+00, -.18602500E+00, 0.18254200E+01, -.58420200E-01, -.89961000E-01, 0.62711900E+00, 0.68365300E+00, -.82242800E+00, -.28343800E-01, -.15932000E+00, 0.12405800E-01, -.24049500E-01, -.20787800E+00, 0.20455600E+00, 0.40519500E+00, 0.14884100E+00, -.21824900E+00, -.25688200E+00, 0.14018100E+00, 0.32967100E-01, 0.16599500E+00, 0.15302700E-01, -.43944100E-01, 0.27337800E-01, -.85266600E-02, -.60696300E+00, -.65887900E+02, 0.44964000E+01, -.11329300E+03, -.23235300E+01, -.20580900E+01, -.24548300E+01, -.88413000E+00, 0.87517300E+00, -.15271800E+00, 0.19133700E+01, 0.21895700E+01, 0.23094400E+01, 0.13517400E+01, -.12917000E+01, 0.13713400E+00, 0.42415100E+01, -.11831300E+01, 0.19664900E+01, 0.45993900E+01, 0.17744900E+01, 0.32579400E+01, -.11168800E+01, 0.70709600E+00, 0.40506300E+01, -.47888400E+01, -.79269600E+01, 0.14875100E+01, 0.29753400E+01, 0.82586300E+00 },
        { -.21582200E+01, 0.13637000E+00, 0.61616500E-01, -.16415000E+00, 0.14984100E+01, 0.33824700E+00, -.10581000E+00, 0.41666100E+01, -.33706000E+00, 0.88872200E+00, 0.87021100E+00, 0.24702300E+00, 0.57878000E+00, -.83893700E-01, -.72570200E+00, 0.14955100E+00, 0.57323000E+00, -.70379100E-01, -.56200900E+00, -.52709600E-01, 0.33052000E+00, 0.87891500E-01, -.40826600E-01, -.24063000E+00, -.27393700E-01, -.56085000E-01, -.29766100E+00, 0.12464200E+00, 0.37031100E+00, -.75079900E-01, -.10792100E+00, 0.11097900E+00, -.26743800E+00, 0.23391200E+01, 0.51870200E-01, 0.11026200E+00, 0.55872400E-03, -.87667700E+00, 0.15543100E+00, -.50581200E+00, -.22857500E+01, 0.19348700E+00, 0.96120200E-01, -.17163700E+00, -.42381600E+00, 0.64710400E+00, -.11187800E+00, -.84769600E-03, -.98398900E+00, -.30218200E-01, 0.45109800E+00, -.33043400E+00, -.67505500E+00, -.19793900E+00, -.20603800E+00, -.25436900E+00, -.17708500E+00, 0.36655400E-01, -.18954300E-01, 0.62401700E+00, -.16032600E-01, 0.13201100E+00, -.21508000E+00, 0.25661800E-02, 0.13138200E+00, 0.32346100E+00, -.85898600E-02, -.21836800E-01, 0.97222200E-01, 0.57083800E-02, 0.45968400E-01, 0.29050400E+00, 0.10542000E+00, -.31346700E+00, -.44877900E-01, -.21598200E+00, -.83306000E-02, 0.14329900E+00, -.15235100E-01, -.39059300E-01, -.14071500E-01, -.15322900E-01, 0.16899000E+00, 0.10186300E+00, -.32212300E-01, -.49432800E-01, 0.10367800E+00, -.41653100E-01, 0.30324100E-01, 0.12369800E-01, 0.17521100E+00, 0.62374300E-03, 0.14247100E+00, -.57603000E-01, 0.15914200E-01, -.60314800E-01, -.33439000E-01, -.15040200E+00, -.29248900E-01, 0.34161100E-01, -.24534300E-02, 0.16842800E-01, 0.27840400E-02, 0.11143900E+00, -.10584100E+00, -.12632800E+00, 0.99549700E-01, -.12073000E+00, -.40846500E-01, -.67726000E-01, -.15366100E+00, -.18047500E-01, -.62415600E-01, -.65196900E-02, 0.53450300E-01, -.34803500E+00, 0.54812800E-02, 0.19876300E+00, -.11073900E+00, 0.46815500E+00, -.12618800E+00, -.78970700E-02, 0.75541400E-01, 0.13050600E+00, -.24123700E-01, 0.16696500E+00, -.71312300E-01, -.48456800E+00, -.44722600E-01, 0.26270200E-01, 0.10307900E+00, 0.21417000E-01, 0.53880000E-01, -.54612700E-01, 0.31645400E-01, -.38739100E-02, -.78905500E-01, 0.25342300E-01, 0.32628300E-01, -.80670700E+00, -.32014500E-02, 0.90686300E-01, 0.33712200E-01, -.32862800E+00, -.13728000E-01, 0.20544700E+00, 0.51617600E-03, -.73400300E-01, 0.37213000E-01, -.36221100E-01, 0.45073100E+00, -.17108600E-01, 0.12926700E-01, 0.67897700E+00, 0.14678200E-01, 0.25682000E+00, 0.95814500E-01, 0.77680500E-03, 0.33888700E+00, 0.15715400E-01, 0.49417800E-02, -.11673700E+00, 0.34691900E-01, -.86935000E-01, -.93535300E-01, -.24386400E+00, -.35148400E-01, 0.42267500E+00, -.15962500E-01, 0.16098500E+00, 0.69767400E-01, 0.14232500E-01, 0.14861700E+00, -.80158000E-01, 0.16171800E-01, 0.67506700E-01, 0.39650900E-01, 0.85555600E-02, 0.63366300E-01, 0.51967000E-01, 0.21117700E+00, 0.36334500E+00, -.22765400E+00, -.19911700E+00, -.15707400E-01, 0.40489900E-01, 0.57991200E-01, -.72937900E-02, 0.68714600E-02, 0.12322700E-01, -.28695900E-01, -.29173000E-01, 0.11556600E-01, 0.18128500E+00, -.35120200E+00, -.12405200E+00, -.38055100E+00, -.46206700E-01, 0.11325700E+00, -.62649700E-02, 0.27547400E-01, 0.27358900E-01, -.63652400E+00, 0.29679400E+00, 0.25233200E-01, -.27149200E-01, -.16700500E-01, -.70305700E-01, 0.41568300E-01, 0.15132600E-01, 0.37804000E-02, -.22464600E+00, 0.42472200E-02, -.46424400E-01, -.16816400E+00, -.14987600E-02, -.18651600E+00, 0.12181700E+00, -.16938000E+00, 0.85733100E-01, 0.77097400E+00, 0.41296600E-01, 0.51603300E-01, -.13752900E-01, -.21264700E+00, 0.18621500E+00, -.55245500E-01, 0.10016800E+00, 0.59187000E-01, -.44808600E+00, -.51877200E-01, -.19770400E+00, -.10816000E-02, 0.98053000E-02, -.10810100E+00, -.26431000E+00, -.29983300E-01, 0.37555800E-01, -.92830000E+00, -.50510600E+00, -.10191500E+00, 0.35514000E-01, -.22146100E-01, -.17332400E-02, 0.16288300E-01, -.32203700E-02, -.86878300E-01, 0.29757300E-01, -.34612500E+00, 0.92786500E-02, 0.42249600E-01, -.36603100E+00, 0.65091700E-01, 0.17226900E-01, -.98608700E-02, -.61685800E-01, -.48430100E-02, -.19658200E+00, 0.33214000E+00, -.58520400E-01, -.31554600E+00, 0.78337900E-01, 0.36039800E+00, -.10752700E+00, -.46721300E-01, -.50712200E-02, -.27489300E-01, 0.36187400E-02, -.41684100E-01, -.91781600E-01, -.76774200E-01, 0.16634900E+00, 0.60915200E-02, 0.88320600E+01, 0.39810400E+02, -.11002300E+01, 0.71405800E-01, 0.10357400E+02, 0.99597000E+01, 0.72535800E+00, -.10084200E+01, -.13085800E+01, -.52745400E+00, -.26758000E+00, -.72412000E+00, 0.20254900E+00, 0.91674000E+00, -.14619300E+01, -.54609900E+00, -.45820800E+00, -.15527600E+01, -.10565300E+02, -.13226600E+01, 0.99013400E+01, -.13802700E+01, -.13239500E+01, 0.16174300E+01, 0.19487900E+01, -.25054800E+00, -.11182200E+01, -.80180500E-01 },
        { 0.20933300E+02, 0.65798900E+01, -.54871400E+01, -.85752400E+01, -.79412700E+01, -.69670100E+01, -.79627400E+01, 0.11865400E+02, 0.13323900E+01, 0.40551400E+01, -.18694100E+01, -.24916300E+01, -.32801100E+01, 0.42945200E+00, 0.32800100E+01, -.45098700E+02, -.12452400E+02, -.79672600E+01, -.62496100E+01, 0.17974100E+00, 0.35315000E+01, 0.11002300E-02, -.33696700E+00, -.51370500E+01, 0.58268300E+00, 0.13082000E+00, -.11662200E+01, -.44953300E+01, 0.59359300E+00, -.33518400E+00, 0.20151100E+01, 0.10382300E+01, -.22186700E+01, 0.70316000E+01, 0.85929900E-01, 0.62327800E+00, -.36516200E+00, -.24142600E+01, 0.60280400E+00, 0.11736500E+01, -.73722000E+01, -.10866000E+01, 0.23515600E+00, -.11132600E+01, 0.25825800E+01, -.34281200E+00, -.47168100E-01, -.97643000E-01, 0.39845600E+01, 0.18175600E+00, 0.86015100E+00, -.21300200E+01, -.23845800E+01, 0.13528400E+00, 0.35724000E+00, -.75254700E+01, -.27400200E+01, 0.39202800E+00, -.58467000E-01, 0.25938300E+01, -.18008600E+00, -.17693000E+00, -.17658600E+01, 0.12696800E+01, -.25382400E+00, 0.17359100E+01, 0.25079500E+00, -.60242800E+00, 0.94511500E+00, 0.50462300E-01, -.85951900E-01, -.88599100E+01, -.20704500E+00, -.40055100E+00, 0.18130500E+01, 0.46466000E+01, 0.23428100E+00, -.25803500E+01, 0.16851800E+01, 0.31906400E+00, -.16815000E+00, -.36714400E+00, 0.13484400E+00, -.51650500E+00, 0.48438400E+00, 0.94815400E+00, -.14908400E+00, -.79255500E+00, -.37372100E+00, -.26292900E+00, 0.32603400E+01, 0.22454500E-02, -.15764200E+01, 0.94947800E-01, -.21942700E+01, -.17856400E+01, -.17752500E+01, 0.96470300E+00, 0.27276200E+00, 0.83789600E+00, -.58115400E+00, 0.30663600E+00, -.31637600E-01, 0.85120000E-01, -.33945700E+00, -.34005400E+01, 0.14377300E+01, -.11258300E+01, 0.42608700E+00, 0.25147200E+00, -.14756100E-01, -.83240000E-01, -.38342300E+01, 0.76084800E-01, 0.46165900E+00, -.59227300E+00, -.98793000E-01, -.11743700E+01, 0.47826900E+01, 0.34496900E+01, 0.26658600E+01, -.50975700E-01, 0.76574400E+00, -.83896500E+00, 0.24448000E+00, -.29232100E+01, -.17984500E+01, -.11265000E+01, 0.52649600E+00, 0.75702600E+00, -.73303900E+00, -.11834000E+00, -.60649500E+01, 0.24640700E+01, -.47335500E+00, -.13877800E+00, 0.14645000E+01, 0.82901000E+00, -.16472500E+00, -.15435500E+00, -.11091800E+00, 0.21392500E-01, 0.25029100E+01, 0.89311700E-01, 0.78444200E-01, 0.69767700E+00, 0.23445000E+00, -.18015100E+01, 0.30835800E+00, 0.54022400E+00, -.13968400E+01, -.16282000E+01, 0.14045000E+00, -.24922300E+00, 0.35064700E+00, 0.15207600E+01, -.22275900E+00, 0.20770800E-01, -.96625400E+00, -.56322800E-01, 0.20405200E-01, -.11392900E+01, 0.78769600E+00, -.10066700E+01, -.79733400E+00, -.11473300E+01, 0.62664200E-01, -.14277400E+01, -.11779500E+00, -.17538400E+01, 0.12290100E+01, -.67830800E+00, -.10776800E-01, 0.10103400E+00, -.95024300E+00, -.77219400E-02, 0.41011000E+00, -.14597600E+00, 0.23054200E+00, 0.20809000E+00, 0.30275200E+01, -.86520800E+00, -.59552500E-01, -.11344600E+00, 0.28335100E+00, 0.96739700E+00, -.79237800E+00, -.36885300E+00, 0.85037600E-01, 0.11100000E+01, -.32052300E+01, -.45519600E+00, 0.11803700E+01, 0.93921400E+00, 0.40579300E+00, 0.68468000E+00, -.52144400E+00, -.61645600E+00, -.10301600E+01, 0.12682000E+00, -.52592100E+00, -.24591900E+00, 0.10575400E+00, -.12168600E+01, 0.20635700E+00, 0.21723700E+00, -.30298500E+00, 0.23712000E+01, -.66713500E+00, 0.17123400E+00, -.68027600E-01, -.63273200E+00, -.15865600E+00, 0.28041500E+01, 0.38188300E+01, 0.18707500E+00, 0.13270000E+00, -.25777300E+00, -.33877700E+00, -.40987400E+00, -.28787700E+01, -.14039100E+00, 0.26968200E+00, 0.39718100E-01, -.89371400E+00, -.18119600E+01, 0.67039700E+00, -.19435900E+00, -.72494600E+00, 0.22677800E+00, -.60783000E+00, -.27390300E+00, -.24776500E-02, -.14252000E+00, -.37263100E+00, -.35285900E-01, -.16602900E+00, 0.14627000E-01, 0.79369900E+00, -.15817100E+01, -.32580300E+00, -.42226000E+00, 0.41280000E+00, -.37172200E-01, -.20977700E+00, -.32850100E-01, -.87739200E+00, 0.61369300E-01, -.94521700E+00, 0.33150900E+00, 0.35837300E+00, -.16406200E+01, -.13046800E+01, 0.47955000E+00, -.35983000E-01, -.16247200E+00, 0.13972700E-01, -.96076900E+00, 0.89078500E+00, -.86476000E-01, -.15829000E+01, 0.27848800E+00, 0.97301900E+00, -.10245400E+01, -.30817900E+00, 0.45603800E-01, 0.95592900E-02, -.10170000E+00, -.38336900E+00, -.43264900E+00, -.76749100E+00, 0.71695000E+00, 0.83204700E+00, 0.12993500E+01, 0.36533900E+03, -.32347100E+01, 0.31343800E+01, -.16336300E+02, -.19264200E+02, -.17270800E+01, -.23891700E+00, -.32274600E+01, -.25635800E+01, 0.18364300E+01, -.65985400E+01, 0.26913000E+01, 0.34220200E+01, -.56872700E+01, 0.23143500E+01, -.20088600E+01, -.13948400E+02, 0.18390200E+02, -.40220700E+01, -.18369600E+02, -.19460500E+01, -.41426100E+01, 0.14557400E+02, 0.13177400E+02, -.33962800E+01, -.37153700E+01, -.42579000E+00 },
        { 0.25692600E+02, 0.72782400E+01, -.32819500E+01, -.10050600E+02, -.87600300E+01, -.81573300E+01, -.11111800E+02, 0.15787100E+02, 0.18564600E+01, 0.32828900E+01, -.15693900E+01, -.33759900E+01, -.36274000E+01, 0.91165300E+00, 0.33086000E+01, -.41514500E+02, 0.17420800E+01, -.27022600E+01, -.11129500E+02, 0.11120100E+01, 0.35319600E+01, 0.79233000E+00, -.53158400E+00, -.49154200E+01, 0.77733700E+00, 0.13756500E+00, -.13533800E+01, -.51391100E+01, 0.32910200E+01, -.36668600E+00, 0.33921700E+01, 0.10512800E+01, -.24189800E+01, 0.64428300E+01, -.32517500E-01, 0.51538700E+00, -.28263800E+00, -.28518300E+01, 0.42366900E+00, 0.28785900E+01, -.12224400E+02, -.10578600E+01, -.19807400E+00, -.55305800E+00, 0.33812800E+01, -.76196200E-01, -.89962600E-01, 0.17453600E+00, 0.15438500E+02, -.76522100E+00, 0.33664200E+01, -.16344200E+01, 0.50812100E+00, -.69987800E+01, -.43576800E+00, -.86176600E+01, -.28517000E+01, 0.32308300E+00, 0.20231900E+00, 0.10717700E+01, -.11189300E+01, 0.10039400E+01, -.13174000E+01, 0.32664600E+01, 0.22543000E+01, 0.68875000E+00, -.33986100E+01, -.13714300E+01, -.73472600E+00, 0.80755200E-01, 0.18304800E+00, -.10761000E+02, -.63729500E+00, 0.35476000E+01, 0.23689100E+01, 0.43627000E+01, 0.24217600E+00, 0.11581700E+01, 0.28284000E+01, 0.99831400E+00, -.15177200E+00, -.20793400E+00, 0.21717800E+00, -.21422700E+01, 0.98371500E+00, 0.15175700E+01, -.68645300E+00, -.68131100E+00, -.29107200E+00, -.45385700E+00, 0.19389000E+01, -.15810900E-01, -.14041700E+01, 0.56700200E-01, -.19234700E+01, -.18716100E+01, -.13215400E+01, 0.16569700E+01, -.39112800E+00, 0.20435300E+01, -.60913200E+00, -.67494800E+00, -.13620000E+00, -.22019800E+00, 0.59120000E+00, -.10523300E+02, 0.78916300E+00, 0.69558400E-01, 0.61224900E+00, 0.82614800E+00, -.75168100E+00, 0.75382300E-01, -.18120700E+01, 0.44463500E-01, -.35301100E+00, -.28654900E+01, 0.65507000E+00, 0.30884000E+00, 0.10374300E+01, 0.40875700E+00, 0.97060000E+00, 0.22198000E+00, 0.12089000E+00, 0.18757000E+00, 0.18768900E+00, -.40739900E+00, -.13314000E+01, -.93529000E+00, 0.12027600E+01, -.87220300E+00, 0.28203100E+01, -.11635300E+01, -.25976400E+01, 0.22780600E+01, -.35495500E+00, 0.53069200E-01, -.11447200E+00, 0.79412100E+00, -.12282500E+00, 0.23076400E+01, -.11625300E+01, 0.19786100E+00, 0.22557100E+00, 0.17240300E+01, 0.31035300E+00, 0.18431700E+01, 0.17383300E+00, -.66537300E+00, 0.12062300E+00, -.15789400E+01, 0.18479500E+01, 0.45102200E+00, -.56919900E+00, -.10497400E+01, -.21699900E+00, -.28652000E+00, -.40468600E+00, -.10067900E-01, 0.32910000E-01, -.25729200E+00, -.17411900E+00, -.83630000E+00, 0.38655900E+00, -.32156200E+00, -.57499300E+00, 0.13437200E+01, 0.32221900E-01, 0.52080000E+00, 0.32784500E-01, -.15411500E+01, 0.47123200E+00, -.21493800E+00, 0.13061000E+00, -.39476700E+00, -.13069200E+01, 0.71244300E+00, 0.15374800E+01, -.15372600E-01, 0.55840700E-01, -.72109500E+00, -.50480300E+00, -.16317200E+01, 0.25107100E+01, 0.33623400E+00, 0.55889000E+00, -.18693500E+00, -.68545900E+00, 0.19422600E+01, -.68918000E-01, 0.85741600E+00, -.21859500E+01, 0.30860000E+00, 0.47445200E+00, 0.35852300E+00, 0.30461900E+01, -.12627400E+00, -.11782500E+01, -.87995200E+00, -.21722900E+01, 0.87985700E-01, -.64723900E-01, -.70191200E+00, 0.35027900E+01, -.23712100E+01, -.87628600E+00, -.40114000E+00, 0.54245100E+00, 0.10984300E+01, -.84435200E+00, -.15161400E+00, -.86720800E-01, 0.17473400E+01, -.22003400E+00, 0.31588100E+01, 0.13402500E+01, 0.39408900E+00, 0.60477100E+00, -.25426400E+01, 0.13180100E+01, -.11072000E+01, -.89193200E+01, -.27326900E+00, -.32458400E+00, 0.15159200E+00, 0.14770800E+01, -.16165400E+01, -.26391700E+00, -.10875400E+01, 0.19617000E-02, 0.21558500E+01, -.96555400E+00, 0.15292400E+01, -.27607700E-01, -.28929000E+00, 0.12299800E+01, 0.60299900E+00, 0.18658100E+00, -.60051300E+00, -.19416700E+01, 0.21678700E+01, -.10149100E+01, -.66027900E+00, -.12072700E+01, 0.63906300E-01, 0.72223200E-01, 0.16507000E-01, -.27439500E-01, 0.11278300E+00, -.41548700E+00, 0.16624700E-01, -.23635200E+00, 0.22448200E+00, 0.37535300E+00, 0.30116700E+01, 0.11748100E+00, 0.84581000E-02, 0.14130700E+00, 0.12849300E+01, 0.30955500E+01, -.93471600E+00, 0.14212100E+00, -.24597900E+01, -.37755200E+01, 0.14347400E+01, 0.11707900E+01, -.46198000E+00, -.72578100E+00, -.86163600E-01, 0.33342500E+00, 0.89106200E+00, -.18906300E+00, 0.17831600E+01, -.15614500E+01, -.11926600E+02, 0.46067300E-02, -.23977800E+02, -.71633600E+01, 0.10323700E+03, 0.97798200E+02, 0.13089000E+02, -.17198400E+02, -.17004400E+02, 0.30783400E+01, 0.80883600E+01, -.32638200E+02, -.58789200E+01, 0.18785900E+02, -.14179700E+02, -.12364200E+02, 0.43223600E+01, -.30619900E+02, -.10136100E+03, -.15326300E+02, 0.98385100E+02, -.18275900E+02, -.10138400E+02, 0.32952200E+02, 0.37456600E+02, 0.52748300E+01, -.13445400E+02, 0.14672100E+02 },
        { -.30801500E+01, -.11200800E+01, 0.84840100E+00, 0.18616400E+01, 0.22399000E+01, 0.84453700E+00, 0.15847200E+01, -.11905300E+01, -.13219100E-01, 0.64767400E+00, 0.11457800E+00, 0.22691800E+00, 0.28263200E+00, -.63429700E-01, -.52266800E+00, 0.12284900E+02, 0.10642200E+01, 0.11854200E+01, 0.89552900E+00, -.29717000E-02, -.49608100E+00, -.11033700E-01, 0.60736200E-01, 0.88124800E+00, -.11177400E+00, -.63583200E-01, -.98818500E-01, 0.10547200E+01, 0.60539100E+00, 0.25023900E-01, -.58821800E+00, -.13005200E+00, 0.40858800E-01, -.78659600E+00, -.65049700E-02, -.83022500E-01, -.10760300E-01, 0.41497000E+00, -.16579600E+00, 0.21357900E+00, 0.49717500E+00, -.39957700E+00, -.39369700E-01, -.53136000E-01, -.20264600E+00, -.69765200E-02, 0.55967600E-03, -.27656700E-01, -.65808100E+00, 0.23353700E-02, -.91624000E-01, -.28098100E+00, 0.11978500E+00, -.27923400E+00, -.73254300E-01, 0.16097800E+00, 0.36571800E-01, 0.14021600E-01, -.20420100E-01, 0.36667300E+00, -.34817100E-01, 0.41328400E+00, -.25014400E-01, -.17772600E+00, -.10514400E+00, -.16017100E+00, -.32869200E+00, 0.29553600E-01, -.48709800E+00, 0.32679400E-02, -.24936000E-01, -.17372600E+01, 0.11192100E+00, 0.11913400E+01, -.98278300E-01, -.26567300E+00, 0.30147500E-01, 0.79303900E+00, -.69888800E-01, -.78291900E-01, -.20557200E-01, 0.12605600E-01, 0.62053800E-01, 0.76895800E-01, 0.12194500E+00, 0.68366600E-01, 0.11242500E+00, -.63646300E-01, 0.54922400E-01, 0.37271200E-01, 0.18458800E+00, -.98172900E-03, 0.18405800E+00, 0.39969500E-01, 0.94110100E-01, -.15193500E+00, 0.26840300E+00, 0.22345000E+00, 0.12355900E-01, -.12640600E+00, 0.92569600E-01, -.14689800E-01, 0.80639600E-02, -.84828500E-01, 0.10352200E+00, -.11610200E+01, -.23967600E+00, 0.16746100E+00, 0.13772200E+00, 0.17296900E-01, 0.28883700E+00, 0.54867600E-02, -.84025800E+00, 0.30582400E-01, 0.19045000E+00, 0.16264700E+00, -.77144000E-01, 0.20849300E-01, -.15422300E+00, 0.82924400E+00, 0.38734100E+00, 0.41151700E-01, 0.77474800E-01, -.76998900E-01, 0.46513400E-01, -.75265900E-01, -.95782000E-01, -.60281300E+00, -.21706000E+00, 0.13274600E-01, -.10254800E-01, 0.97451500E-01, 0.49742600E+00, -.22050100E+00, 0.93772200E-01, 0.13951700E-01, -.91172200E-01, -.37959600E+00, 0.10170500E+00, 0.93742500E+00, -.49189300E+00, 0.72715900E-03, -.81765300E-01, -.52998400E-01, 0.60757800E-02, -.29423900E+00, -.74425500E-02, 0.23044300E+00, 0.75319300E-01, -.25783500E+00, 0.28689600E+01, 0.51566500E-02, -.93395700E-01, 0.11125900E+00, -.41918100E-01, 0.54534300E-01, -.14623900E+00, -.11338500E-02, 0.18265200E+00, 0.13560900E+00, 0.23469700E-01, -.66619300E-01, 0.68705900E-01, -.24441900E+00, -.60641400E-01, 0.43411400E-01, -.33829500E-01, -.92594200E-01, 0.59908400E-02, 0.29305900E+00, -.88900000E-01, 0.67621100E-01, -.50033100E-01, 0.79129300E-03, 0.17519900E+00, -.42686000E-01, -.22264200E+00, -.11380500E-01, 0.12916700E+00, 0.67550900E-02, 0.28811500E-01, 0.24917300E+00, -.40157800E+00, 0.76420400E-02, -.20182500E-01, 0.62570000E-01, -.96549700E-02, -.17102300E+00, 0.44229200E-02, -.25839900E+00, 0.39888600E+00, 0.81378900E-02, 0.53836800E-01, 0.10617300E+00, -.50165700E+00, 0.24956400E-02, -.19157400E+00, -.76920500E-01, 0.16144800E-01, -.27646900E-01, -.43090800E-02, -.31011500E-01, -.12998100E+00, -.72600900E-01, 0.48909200E-01, 0.18713000E-01, -.41741800E-01, 0.18504300E+00, -.37645000E-01, -.55677200E-01, 0.43413900E-02, 0.14403000E+00, 0.11669300E-01, 0.12857100E+00, 0.16922800E+00, -.56133200E-01, -.22761600E+00, 0.14194500E+00, 0.60099300E-01, -.14998900E+00, -.48715000E+00, -.13371700E-01, -.25866200E-01, 0.25985600E-02, 0.98992600E-01, -.15764900E+00, 0.85762800E-01, 0.13776500E-01, -.60466400E-01, 0.63909100E-01, -.25658400E+00, -.14854800E-01, 0.46810200E-03, -.22059700E-01, -.18938300E+00, 0.28967500E+00, 0.23020700E-01, 0.58274600E-02, -.56643300E+00, -.33081400E+00, 0.15363700E+00, -.31242200E+00, 0.63031600E-01, -.11661800E-01, -.59176500E-01, 0.48716100E-02, -.15342200E+00, 0.57443500E-01, -.17777700E+00, 0.61892300E-01, -.14694200E-02, 0.61806200E-01, -.94898700E-02, 0.43201700E+00, 0.19682900E-01, 0.37992600E-01, -.45794300E-02, 0.27215700E+00, 0.37743600E+00, -.26709400E-01, -.44292300E+00, 0.22693900E-01, 0.46743100E-01, -.42215000E-02, 0.29383500E-01, 0.25621000E-02, -.30532400E-01, 0.71787000E-02, -.49321700E-02, 0.90893000E-01, -.52141100E-02, -.37005300E+00, 0.60328100E-01, 0.30098300E+00, 0.25513700E-01, 0.54261900E-02, -.16799800E+01, -.20301300E+01, -.18059100E+01, -.67411700E-01, 0.67334100E-01, -.72174600E-01, 0.92171900E+00, 0.54692100E+00, -.23038900E+00, -.11504300E+01, -.88255900E-01, 0.13940700E+00, 0.88931500E-02, 0.94064000E+00, 0.84164400E+00, 0.20252000E+01, 0.31416000E+00, -.18394500E+01, 0.15196800E+00, 0.55737600E+00, -.83388900E+00, -.13989600E+01, 0.12789500E+01, 0.27534600E+00, 0.66954000E-01 },
        { -.36374600E+01, -.11104800E+01, 0.70742300E-02, 0.13096400E+01, 0.26637400E+01, 0.87641900E+00, 0.93807400E+00, 0.12947300E+01, -.13426900E+00, 0.11393200E+01, 0.46236200E+00, 0.25026700E+00, 0.20686800E+00, -.23506400E+00, -.44336500E-01, 0.28262500E+01, -.16710700E+01, -.14135300E+01, -.11094200E+00, -.18852000E+00, 0.15836900E+01, 0.21695300E+00, 0.23577400E+00, 0.22856000E+01, -.80461100E-01, -.10890000E-01, 0.92870800E+00, 0.34843500E+01, -.16603200E+01, -.18910500E-02, -.52264400E+00, 0.64785200E+00, 0.46081000E+00, -.25854700E+01, 0.25203900E-01, -.59029200E-01, -.38067300E-01, -.16586700E+00, -.16440600E+00, -.57208300E+00, 0.20625900E+01, 0.26748800E+00, -.21041000E-01, 0.21023500E+00, -.93123500E+00, -.23373500E+00, 0.33263200E-01, -.89335300E-01, -.72147400E+00, 0.16176600E+00, -.96281800E+00, -.95898000E-01, -.20420300E+00, 0.17944600E+01, 0.20905800E+00, 0.16091500E+01, 0.36771300E+00, 0.69107300E-02, -.61620200E-01, -.41393400E+00, 0.40412900E+00, -.12953100E+01, 0.11936400E+00, -.18055700E+00, -.47841000E-01, 0.81511400E-01, 0.79445600E+00, 0.26696000E+00, 0.62895300E+00, -.16078000E-01, 0.87175700E-02, 0.31083900E+01, -.64688500E-01, -.93872600E+00, -.26449900E+00, -.10470100E+01, -.10381000E+00, -.53584400E+00, -.40816000E+00, -.17878300E+00, 0.62793500E-01, 0.18834400E-01, -.10364200E+00, 0.14264900E+00, -.18114300E+00, -.68419300E-01, -.22218400E+00, 0.23295300E-01, -.10506600E+01, -.28191300E-01, -.35519100E+00, -.25385500E-03, 0.10362100E+00, -.10514900E+00, 0.28792700E+00, 0.31342300E+00, 0.16156800E+00, -.26522400E-01, -.35030600E-01, 0.19087500E+00, -.54483600E-01, 0.13099900E+00, 0.20229600E-02, 0.15701300E+00, -.54767100E-01, 0.25247800E+00, -.83005900E-01, -.33897800E-01, -.85354900E-01, -.25566600E+00, -.42459000E-01, -.23927900E-02, -.73731000E+00, -.13610100E-01, -.25158600E+00, 0.59171900E-01, 0.17780300E-01, 0.34774400E-01, 0.65029700E+00, -.36802800E+00, 0.24750500E+00, -.42493200E-01, -.51576900E-01, 0.29741600E-01, -.44235200E-01, -.33125100E-01, 0.11683000E+00, 0.61947200E+00, -.58263500E-01, 0.14188600E+00, -.30484300E+00, 0.29223700E+00, 0.19212700E-01, -.24104900E+00, -.15093300E+00, -.11152100E-01, 0.96728900E-01, 0.14411800E+00, -.11418700E+00, -.11122400E+00, 0.51413000E+00, 0.45887500E-01, 0.21131400E-01, -.10213400E+00, -.20441200E-01, 0.19056400E+00, 0.13132000E-01, -.48977100E-01, 0.10379500E-01, 0.41131500E+00, -.52707300E+00, -.44451100E+00, -.14510600E+00, 0.13703300E+00, 0.15629400E+00, -.34087200E+00, 0.83873200E-02, 0.28814900E-02, 0.16468100E+00, 0.13512300E+00, 0.51879600E-03, 0.14341000E+00, 0.40532900E-01, -.92166000E-02, 0.41924500E+00, -.24146600E+00, 0.19400000E-01, 0.18127700E+00, -.28983900E-02, -.25784400E+00, -.14122700E-02, 0.43935200E-01, -.75707500E-01, 0.11832400E+00, 0.19372800E+00, -.17265500E+00, -.19603800E+00, -.27416900E-02, -.57997700E-01, 0.12479800E+00, 0.71872100E-01, 0.31400400E+00, -.59236600E+00, -.51284900E-01, -.86676300E-01, 0.24077200E+00, 0.10631500E+00, -.45286300E+00, 0.27797200E-01, -.49045200E-01, 0.24290100E+00, -.10781300E+00, -.15074300E+00, -.26276800E-01, 0.13701700E+00, 0.54980200E-01, 0.28480200E+00, 0.94374700E-02, 0.56816700E+00, -.37736500E-01, 0.32705600E-01, 0.90977600E-01, -.64513600E+00, 0.61272800E+00, 0.53521600E+00, 0.14946300E+00, -.16321300E+00, 0.53775000E-01, -.39704100E-02, -.17104700E-01, 0.61251900E-02, -.26188400E+00, 0.50455500E-01, -.34076500E+00, -.18729200E-01, -.29719700E+00, -.11568000E+01, 0.83467100E+00, -.87639900E-01, 0.57064500E-01, 0.89936100E+00, -.18893100E-02, 0.10767100E-01, -.10861100E-01, -.18122600E+00, 0.26145600E+00, -.96052000E-01, 0.56484900E-01, -.17125200E+00, 0.35103900E+00, -.32686000E+00, 0.19351700E+00, 0.46861700E-03, -.42416300E-01, -.20934400E+00, -.50953200E-02, -.28817600E-01, -.18875400E-01, -.37277100E+00, 0.42019300E+00, 0.15820900E-01, 0.11718400E+00, -.67495600E-01, 0.20125600E-02, 0.20741500E-02, -.17138300E-02, -.23225000E-01, 0.92198200E-02, -.63688000E+00, -.75080000E-02, 0.72209000E-01, 0.61424100E-01, -.29023700E+00, -.15069300E+00, 0.63803600E-03, 0.79271900E-01, -.42279800E-02, 0.10995100E+00, 0.14108300E+00, -.13562500E-01, -.34053300E-01, 0.11299200E+00, 0.79763000E+00, 0.10035300E+00, 0.11219300E+00, -.47745100E-01, -.84082000E-01, 0.10298700E-01, 0.35657100E-01, 0.48376000E-01, -.83545400E-01, 0.22030900E+00, -.89771600E-01, 0.26618100E+00, -.47971600E-01, 0.86007600E-01, -.39246500E+00, -.14911600E+02, -.14888800E+02, 0.40485700E-01, 0.14986300E+00, -.33727500E+00, -.34216400E+00, -.14679600E+00, 0.43941400E+00, 0.24053500E+00, -.38653200E+00, -.31306600E+00, -.10295200E+00, -.45202000E+00, -.69430200E+00, 0.15268900E+02, -.66096500E+00, -.14752900E+02, 0.36419400E+00, -.15386900E+00, 0.69222200E+00, 0.18539900E+00, -.30389100E+00, -.89425800E+00, 0.12567600E+00 },
        { 0.69066500E+00, 0.68457900E+00, -.14290700E+00, 0.13125400E+00, -.21322900E+00, 0.56484400E-01, 0.33270700E+00, -.71794700E+00, 0.53496300E-02, 0.12815000E+00, -.14700000E+00, -.11128900E+00, 0.76894700E-01, 0.27654900E-02, 0.77860600E-01, -.30076400E-01, 0.67292200E+00, 0.34991600E+00, -.33908500E-02, -.37125700E-01, -.31420200E+00, -.13830900E+00, -.53023200E-01, -.59475600E+00, -.41992300E-01, -.51851400E-02, 0.61522200E-01, -.11020400E+01, 0.21734800E-01, 0.66428600E-02, 0.62948300E-01, -.17718300E-01, 0.85074100E-03, 0.51179700E+00, -.51737600E-01, -.12469000E-02, 0.95266800E-02, -.17802500E+00, 0.20076300E-01, -.66193100E-01, -.19511300E+00, 0.78369500E-01, 0.18019100E-01, 0.91846000E-03, -.75500200E-03, 0.59082000E-01, -.12011000E-01, 0.10257500E-01, -.27919100E+00, -.66904300E-02, 0.15595100E+00, 0.33915900E-01, -.21341200E-01, -.52614200E-01, -.49923900E-01, 0.12435800E+00, 0.40641000E-01, -.27807000E-01, 0.43582500E-02, -.93696100E-02, 0.13422800E-01, -.22953600E-01, 0.61077400E-01, -.13814000E-01, 0.12178100E+00, 0.10335700E+00, -.52528900E-01, 0.47191800E-01, 0.20116700E-01, -.72129500E-02, -.56011100E-01, 0.82788500E+00, 0.20431900E+00, 0.93180000E-01, -.21506800E+00, 0.75123500E-01, -.66547500E-02, -.14010300E+00, -.78631500E-01, 0.22291400E-01, 0.54909400E-02, -.12430900E-01, -.37505900E-01, -.91399400E-01, -.13142000E-02, 0.47213600E-01, -.48323600E-01, 0.16174200E-01, -.75643700E-02, 0.85854100E-02, -.10856300E+00, 0.60980800E-03, 0.38419200E-01, 0.51626800E-02, 0.27399100E-01, 0.80604300E-01, 0.24319100E-01, -.26162800E-01, -.46305300E-02, 0.18785500E-01, 0.73172400E-02, -.90226800E-02, 0.55573500E-03, -.24082200E-01, 0.27147700E-01, 0.36399000E+00, -.73236400E-01, 0.43569800E-01, 0.12058800E-01, 0.36567600E-01, -.22432600E-01, 0.21992700E-02, 0.90500300E-01, 0.12324600E-02, 0.33566800E-01, 0.56040200E-01, -.45286800E-01, -.31093100E-01, 0.10300300E+00, -.24504000E+00, 0.86312200E-02, -.11720000E-01, -.49113800E-01, 0.94099000E-02, -.12938200E-01, 0.49941700E-01, 0.45424600E-01, 0.23398400E+00, 0.26502600E-01, -.53888900E-03, -.71262400E-01, -.71347800E-02, -.42518700E-01, 0.85008900E-01, -.30909400E-01, -.43060300E-02, -.17100200E-01, 0.13184500E+00, -.41051300E-01, 0.43818500E-01, 0.10239400E+00, -.59285300E-01, 0.61160600E-01, -.30816600E-01, 0.24929700E-02, -.34449400E-01, -.18370600E-02, 0.33649100E-01, 0.10744400E-02, 0.74826900E-01, 0.87277600E-01, 0.30979700E-01, 0.34596500E-01, -.16031500E+00, 0.39276900E-02, 0.82240600E-01, -.52884400E-02, -.22837900E-03, -.58653400E-01, -.38137300E-01, 0.27161400E-01, 0.48020100E-01, -.51022800E-02, 0.23808200E-01, -.33939200E-01, -.47118100E-01, -.24882400E-01, -.29614800E+00, 0.67331400E-03, -.68258800E-02, -.64936600E-02, 0.93973600E-02, -.44072100E-01, 0.48304200E-01, 0.88364700E-01, -.53792800E-01, -.49787300E-01, 0.44952600E-02, -.36083800E-01, 0.53189100E-03, -.45698400E-02, 0.14255200E-01, -.66928600E-01, -.49377900E-01, 0.21652300E-01, 0.13513900E-01, 0.34920200E-01, -.48487300E-01, 0.10945900E-01, 0.71361500E-01, -.17663900E-01, -.48460800E-01, 0.83384200E-03, -.24148600E-01, 0.37991800E+00, -.24635700E-01, 0.81195100E-01, 0.46055800E-01, 0.72203600E-01, 0.11376200E-01, 0.37146500E-01, 0.15096200E-01, -.72631100E-01, 0.15955500E+00, 0.65563600E-01, 0.31779700E-01, -.32214000E-01, -.50089900E-01, -.36312300E-01, 0.28409200E-01, -.94508600E-03, 0.72614200E-03, -.18858600E-02, -.12670300E-01, 0.57215000E-01, -.59339100E-01, -.54062000E-01, 0.11941900E-02, 0.11038300E-01, -.56775000E-01, 0.50187000E-02, -.16230000E-01, -.21488900E-01, 0.11389300E-02, 0.17945200E-01, -.45325100E-01, -.32417800E-01, 0.24585400E-02, -.73743900E-01, 0.17641800E-01, -.37770200E-01, 0.25569500E-01, 0.82269400E-03, -.73320900E-02, -.53998800E-01, -.12860900E-01, -.11170300E-01, 0.11448300E-01, 0.10953200E+00, 0.32029500E-01, 0.33537700E-01, 0.74521600E-02, 0.16202800E-01, 0.28129500E-03, 0.23418800E-02, 0.36576200E-04, 0.11867000E-01, 0.39358800E-02, 0.25719700E-01, -.55740400E-02, -.13039400E-02, 0.56390500E-01, -.17406400E-01, 0.39416300E-01, 0.73397400E-03, 0.72754100E-02, 0.44573800E-03, -.35563100E-02, -.18113800E-01, 0.32988500E-03, 0.19823600E-01, 0.81730100E-02, 0.10269100E-01, 0.20433300E-01, 0.37599100E-02, 0.37634800E-04, -.18953600E-02, 0.88437200E-03, 0.37472900E-02, 0.55312300E-02, -.86080300E-03, 0.13533200E-01, -.15383900E-01, -.68635400E-01, 0.19285200E-02, 0.43164400E-02, 0.20097000E-01, 0.27384100E-03, -.30455600E+00, 0.21911200E-01, -.42994400E-01, -.23134300E-01, 0.63719800E-02, -.23010600E-01, 0.11774200E-01, -.32395300E-01, 0.11005700E-01, -.22042600E-01, -.26165000E-01, 0.52293700E-03, -.22090000E-01, 0.29231100E+00, -.27941200E-01, -.15122300E+00, -.35301700E-01, -.18921600E-01, 0.21051700E-01, -.47246400E-01, 0.22153100E-01, -.39227900E-01, 0.36999300E-02 },
        { -.12891800E+01, 0.18828200E+00, 0.39695200E+00, 0.71647000E+00, 0.36125400E+00, 0.22036000E+00, -.16500400E+00, -.89045400E-01, -.22059300E+00, 0.76300100E+00, -.84214600E-01, -.53039900E-01, 0.86394900E-01, -.72740400E-01, 0.12015800E+00, -.20677900E+01, -.16958400E+01, -.78691700E+00, 0.20671600E+00, 0.11316900E+00, 0.14982300E+00, -.17403900E+00, -.16880200E-02, -.27547300E+00, -.11595200E+00, -.17172700E-02, 0.22810600E+00, -.42265000E+00, -.72077700E+00, -.86816000E-03, -.53296300E-02, 0.10359700E+00, 0.63753200E-01, -.67596600E+00, -.12496900E-01, -.18391800E-01, 0.33024300E-01, 0.35269000E+00, 0.35239600E-01, 0.10959100E+00, 0.11220800E+01, -.65967800E-01, -.44034200E-01, -.20819300E-01, -.12528700E+00, -.13679500E+00, 0.11419700E-01, -.56628100E-02, -.61675700E+00, 0.10623800E-01, -.14510500E+00, 0.31959800E+00, -.50303600E-02, 0.41849100E+00, 0.61766300E-01, 0.35994500E+00, 0.99376700E-01, -.36756600E-01, -.12177900E-01, -.16781700E+00, 0.67819600E-01, -.39157000E+00, 0.42297100E-01, 0.29320000E-02, 0.20855200E+00, 0.29410400E-01, 0.28552100E+00, 0.73396800E-01, 0.23806800E+00, 0.89939900E-03, -.20433400E-01, 0.12325400E+01, -.26476300E+00, -.74692300E+00, -.18506700E+00, -.40054000E+00, 0.47679500E-01, -.49902900E+00, -.66429900E-01, 0.16255800E-01, -.56864500E-02, 0.11875400E-01, -.88944400E-01, 0.88116000E-01, -.92584500E-01, -.87350700E-01, -.10692000E+00, -.39461500E-02, -.34043600E-01, 0.32023700E-01, -.22301900E+00, 0.21694300E-03, 0.17504000E+00, -.24649400E-01, 0.83213800E-01, -.12335500E+00, 0.33571000E-01, -.17704200E+00, -.86424300E-02, -.11596600E+00, 0.10361700E-01, 0.11642100E-01, 0.39380500E-02, 0.42556000E-01, -.33439100E-01, 0.12773200E+01, -.42142600E-01, 0.28772800E-01, -.52472100E-02, -.60561300E-01, -.79213600E-01, -.25408800E-02, 0.21725500E+00, -.57263400E-02, -.19057700E-01, 0.23385300E-01, -.53767400E-01, 0.58504800E-01, -.31373500E+00, -.45689900E-01, -.23427200E+00, -.67363600E-02, -.22634000E-01, -.35973400E-01, -.61558700E-02, 0.15585700E+00, 0.48890200E-01, 0.30723600E+00, 0.43885400E-01, 0.13110100E-01, -.22399400E+00, 0.15707900E+00, 0.18888700E+00, -.26632600E+00, 0.84611800E-01, 0.86629100E-02, -.14048500E+00, -.63794500E-01, 0.10705300E-01, 0.13079000E-01, 0.21670300E-01, 0.15974200E-01, -.28040100E+00, -.94311000E-01, -.19003300E-01, -.21230700E+00, -.28342500E-01, 0.38002100E-01, -.31862500E-01, 0.19692000E+00, -.17139000E+00, 0.80550200E-01, 0.78323400E-01, 0.62588800E-01, 0.33166500E-02, -.10234000E+00, -.34268200E-01, 0.40618400E-03, 0.74518600E-01, 0.31230700E-01, -.29796200E-02, 0.15219300E-01, 0.26945500E-02, 0.29502200E-01, 0.85507700E-02, -.16243800E+00, -.74381900E-02, -.25179400E+00, -.13040700E-02, 0.78928500E-01, -.43366000E-01, 0.16795400E-01, 0.15168300E-01, -.72743700E-02, -.45081400E-01, -.37560500E-01, 0.13185900E-01, 0.75950900E-03, -.84853500E-02, 0.32015700E-01, 0.84005100E-01, 0.32987800E-02, -.17306400E+00, -.14592400E+00, 0.64435500E-01, -.10084600E+00, 0.26932300E-01, 0.61865200E-01, 0.84771000E-02, 0.65316800E-01, -.87661300E-01, -.11117900E-01, -.23486700E-01, -.42068900E-01, 0.11539100E+00, -.43675900E-01, 0.14333000E+00, -.56635200E-01, 0.36520100E-01, -.10707900E-01, 0.41423100E-01, 0.33563900E-01, -.65035500E-01, 0.22917200E-01, -.39349900E-01, 0.26140800E-01, 0.20213400E-01, -.66802000E-01, -.30869100E-01, -.22671600E-02, 0.59777500E-02, -.21905900E-01, 0.94989500E-02, -.27832000E+00, -.37811300E-01, -.84962700E-01, -.76414000E-01, 0.99556300E-01, 0.21191800E-01, -.36754400E-01, 0.47599700E-01, 0.62814500E-03, -.18104500E-01, 0.28916100E-02, 0.45843500E-01, -.29001100E-02, -.93660200E-01, 0.59123500E-03, -.46947800E-01, 0.88468400E-01, 0.28612100E-02, 0.88817600E-01, -.87024900E-03, 0.65958000E-02, -.73995200E-01, 0.79722400E-02, -.15429900E-01, -.24282300E-01, -.37710300E+00, 0.95712000E-01, 0.93123400E-01, -.62558900E-01, -.86404800E-01, 0.56085200E-02, 0.38945900E-01, 0.15607300E-02, 0.14910700E-01, 0.17604000E-01, -.17929400E-01, -.39574300E-02, -.15866600E-01, 0.46449100E-02, 0.59413000E-01, 0.74803800E-01, 0.19245900E-02, 0.87995100E-02, -.67273900E-03, 0.46969700E-01, 0.15246700E-01, 0.58715900E-02, -.21233200E-01, 0.53947900E-01, 0.23841300E-01, 0.73490900E-01, 0.44442300E-01, -.11939200E-01, -.85287000E-02, -.25474700E-02, 0.24718700E-01, 0.27139600E-01, 0.50958200E-02, -.10085800E-01, -.33626600E-01, -.74151200E-02, -.32657400E-01, 0.12907700E-01, -.43840100E-01, 0.10942000E+00, -.14015600E-01, 0.32676600E+00, -.96139400E-01, 0.39219900E-01, 0.13448900E-01, 0.69591200E-01, 0.11723300E+00, 0.47942200E-01, 0.15493400E+00, 0.70099200E-01, -.29341100E+00, 0.23539000E-01, 0.70014800E-01, -.10786100E-01, 0.11422100E+00, 0.16280500E-01, -.12480200E+00, 0.27843800E-01, -.82865300E-01, -.11704100E+00, -.17573800E-01, 0.12692100E+00, 0.41043700E-01 },
        { 0.58662400E+00, -.20598700E+00, 0.21023600E+00, -.15641100E+00, 0.34294200E+00, -.22841900E+00, -.23943800E+00, 0.18750000E+01, 0.11389300E+00, -.13260900E+00, 0.35254800E+00, 0.31065300E-01, -.27478400E-01, 0.12883300E+00, -.11012600E+00, 0.95307000E+00, 0.19196300E+01, 0.36001600E+00, -.61271200E-01, 0.70581800E-01, -.44887500E-01, 0.65951200E-01, 0.41060400E-01, 0.68086300E+00, 0.57497900E-01, 0.10051000E-01, 0.11354700E+00, 0.11910000E+01, -.35589200E+00, 0.38299600E-02, 0.27199600E-01, 0.23399600E+00, 0.37070800E-01, 0.64377100E+00, 0.26271200E-01, 0.59414900E-01, -.29193000E-01, -.53555100E+00, -.77088900E-01, -.17865200E+00, -.49669800E+00, 0.63486000E-01, 0.32772400E-01, 0.81115200E-01, 0.10955400E-01, 0.14152400E+00, -.39775600E-02, 0.64050900E-02, 0.67797300E+00, 0.56724200E-01, 0.40241400E-02, -.85889200E-01, -.30153600E-01, -.25681800E+00, 0.87040600E-01, 0.86151400E-01, 0.24419400E+00, 0.65470900E-01, 0.16416900E-01, 0.17834600E+00, -.82034300E-01, 0.19176800E+00, -.18347100E-01, 0.94314900E-01, -.15870700E+00, -.35695600E+00, -.51976600E+00, -.10376100E-01, -.81291500E-01, -.15114800E-02, 0.11124900E-01, -.41524600E-01, 0.15837700E+00, 0.65219000E+00, 0.33813000E-01, 0.39759900E+00, -.80345300E-01, 0.45240600E+00, -.72185200E-02, -.11852400E-01, 0.20613800E-01, -.95924200E-02, 0.11575300E-01, -.53435200E-01, 0.44307000E-01, 0.12285600E-01, -.23730800E-01, -.87601500E-02, -.11196100E+00, -.39820700E-01, -.23852200E-02, -.48257600E-03, -.55004000E-01, 0.52219700E-01, 0.30510100E+00, 0.45343800E+00, 0.70672800E-01, 0.13047300E+00, 0.65720400E-01, 0.12027600E+00, -.15724700E-01, 0.11593600E-01, 0.77710800E-02, -.90868600E-01, 0.65769200E-02, -.12185600E+01, 0.59016200E-01, -.22534800E-01, -.58524100E-01, -.21257300E-01, 0.27947700E-01, -.51875500E-02, -.29226400E+00, 0.71383200E-02, -.84113500E-01, 0.42193400E-01, 0.42254600E-01, -.59807000E-01, 0.31655600E+00, -.26364800E+00, 0.12131600E+00, 0.15291700E-01, -.59954900E-02, 0.23539800E-01, 0.17483300E-01, -.16197300E+00, 0.25216700E-01, -.19997700E+00, 0.27273200E-01, -.13319200E-01, 0.20855700E+00, 0.10413600E-01, -.12504000E+00, 0.83104100E-01, 0.17202100E-01, 0.66660200E-02, -.17008900E+00, -.28152100E-01, -.27071900E-04, 0.12384200E+00, -.23297400E-01, 0.48539000E-01, 0.89762400E-01, 0.11896400E+00, 0.58237100E-03, 0.28493000E-01, 0.16823800E-01, -.69736700E-01, 0.19408900E-01, 0.12146400E-01, 0.38018700E+00, 0.59794700E-01, 0.37484600E-02, -.64015600E-01, -.43028100E-02, 0.12218400E+00, -.27857100E-01, -.16286600E-02, -.15841700E-01, -.77278400E-02, 0.40814000E-01, 0.62123300E-01, 0.13253300E-01, 0.23380200E-01, 0.11868900E-01, 0.47665900E-02, -.11749500E-02, -.25490100E+00, 0.52718300E-02, -.90380900E-01, -.23009900E-01, 0.18481400E-01, -.67176000E-01, 0.53421700E-01, 0.79112600E-01, -.55539600E-01, -.26724900E-01, -.18827300E-02, 0.59930300E-01, -.97200300E-03, 0.14012400E-01, 0.47954500E-01, -.63968800E-01, -.53812300E-01, -.13049400E-01, 0.10759100E+00, -.63906400E-01, -.52307000E-01, 0.10920100E-01, -.80350200E-01, -.22471700E-01, -.99787500E-02, 0.48324900E-01, -.15878100E-02, -.53740700E+00, 0.12975500E-01, 0.77694700E-01, -.46426400E-01, 0.47986900E-01, -.60867200E-02, -.48654400E-02, -.35297600E-01, 0.13303900E+00, 0.40391400E-03, 0.94743400E-01, 0.81632100E-02, -.24753800E-01, 0.10482600E+00, -.21355900E-01, -.48073900E-02, 0.87567900E-03, -.60000900E-01, -.22739100E-02, 0.38927000E-01, -.19505300E-01, -.15011300E-01, -.65050700E-01, 0.40235100E-01, -.12325700E-01, 0.38314300E-01, -.98502500E-02, 0.15706700E-01, -.88197000E-02, -.36089800E-02, 0.91668800E-01, -.73439200E-02, 0.13382900E+00, 0.72998000E-02, -.66449700E-02, -.84305700E-01, 0.72270900E-02, -.11588400E-01, -.48553200E-04, 0.14955700E-03, -.32468300E-01, 0.22675800E-01, 0.27095200E-02, 0.35541600E-01, 0.46204100E+00, -.11025500E+00, -.11985500E+00, 0.28390900E-01, -.59728000E-02, -.27264700E-02, -.14422700E-01, -.11338800E-02, -.12029100E-01, -.69312400E-02, -.49104100E-01, 0.73584500E-02, 0.87740400E-02, -.51825600E-01, -.22436600E-01, -.70194400E-02, -.21555400E-02, -.48314500E-02, 0.17661800E-02, -.78488900E-01, -.61704000E-01, -.26862200E-02, 0.43161800E-01, -.80485900E-01, -.76119000E-01, -.14766000E-01, -.30837800E-01, 0.55007600E-02, 0.40319900E-02, 0.59825500E-02, -.91640400E-02, -.18808900E-01, -.19315900E-03, -.38984500E-01, 0.23889500E-01, -.27089900E-01, 0.11147200E-01, -.16401400E-01, 0.36930500E-01, -.16067400E+00, -.61132400E-01, -.24385800E+00, 0.26329800E+00, -.52234400E-01, -.42410400E-01, -.10883900E+00, -.67879800E-01, -.56652500E-01, -.92478300E-01, -.77721100E-01, 0.28379900E-01, -.49014800E-01, -.13144400E+00, 0.24995200E-02, -.12895200E+00, -.58993800E-03, 0.17300300E+00, -.11578400E+00, 0.14458600E+00, 0.64403600E-01, 0.15934000E-01, -.15566100E+00, -.28441100E-01 },
        { 0.28497600E+02, 0.87213600E+01, -.82981800E+01, -.15613600E+02, -.89097100E+01, -.90614900E+01, -.13321000E+02, 0.32542000E+02, 0.19157300E+01, 0.47117700E+01, 0.26821400E+00, -.32969300E+01, -.38678800E+01, 0.12660600E+01, 0.51969300E+01, -.73111600E+02, -.70100700E+01, -.73960200E+01, -.13824100E+02, 0.91371900E+00, 0.41492600E+01, 0.22618100E+01, -.62159100E-01, -.19664000E+01, 0.11357100E+01, 0.17899700E+00, 0.11760800E+01, 0.64004100E+00, 0.46797700E+00, -.43963400E+00, 0.42206000E+01, 0.32411400E+01, -.18016500E+01, -.49738900E+01, 0.53729700E-01, 0.56099500E+00, -.20351800E+00, -.34699000E+01, 0.51553800E+00, -.24422900E+00, -.21249300E+02, -.16985100E-01, 0.48875000E+00, -.26309000E+00, 0.12441900E+01, -.29124300E+00, -.93975300E-01, 0.11937400E+00, 0.79417200E+01, -.95050300E+00, 0.13209500E+01, -.27143700E+01, -.14390800E+01, -.85986600E+01, -.12693500E+01, -.33584100E+01, -.33908000E+01, 0.42632200E+00, 0.28742400E+00, 0.18354000E+00, 0.24167300E+00, -.65561400E+00, -.64206400E+00, 0.18385100E+01, 0.19980600E+01, 0.69245300E+00, -.49003800E+01, -.13663400E+01, 0.15910300E+01, 0.72629500E-02, 0.16600100E+00, -.50621800E+01, 0.46398200E+00, 0.70503000E+01, 0.10533400E+01, 0.39211700E+01, 0.23960800E+00, -.85488400E-02, 0.29279600E+01, 0.10107300E+01, 0.30848100E+00, -.48521200E+00, -.96225600E+00, -.30787000E+01, 0.14157700E+01, 0.12522600E+01, -.10606100E+01, -.97840300E+00, -.41411100E+00, -.55388200E+00, 0.25155500E+01, 0.75769400E-01, -.10275400E+00, -.15493700E+00, -.23744400E+01, -.16595000E+01, -.98155100E-01, 0.19325900E+01, -.49955000E+00, 0.53075200E-01, -.34224900E+00, 0.16446900E+00, 0.35964000E-01, 0.29207500E+00, 0.40958900E+00, -.79726100E+01, 0.11288800E+01, 0.29794000E+00, -.77149800E+00, -.43294100E+00, -.20204800E-01, -.18053900E-01, -.65588200E+01, 0.22536400E+00, -.52422100E+00, 0.21441000E+01, 0.97975500E+00, -.28371900E+01, 0.93684100E+01, -.46617900E+01, 0.58031000E+01, -.35417800E+00, -.41058900E+00, -.66631300E-01, -.28950000E+00, -.11760300E+01, -.97717800E+00, 0.43368800E+01, 0.45971500E+00, 0.85656400E+00, -.93031900E-01, -.23884700E+00, 0.15825600E+00, 0.81065000E+00, -.11701600E+01, -.15306700E+00, 0.23426300E+01, 0.11262600E+01, 0.31946300E-01, 0.38328500E+01, -.78403300E+00, 0.54340900E+00, -.35752600E+01, 0.11361400E+01, 0.45722100E+00, -.76086600E-01, 0.51286700E+00, 0.62822000E+00, -.55645100E+00, -.48219200E+01, -.11974100E+02, 0.74331200E+00, 0.21868300E+00, -.50675900E+00, -.68062000E-01, -.21476600E-01, 0.40890800E+00, 0.20114600E-01, -.11973100E+01, -.61268200E+00, -.17211600E+00, 0.86310900E+00, 0.56462600E+00, 0.14646700E+01, 0.28251000E+01, 0.40378900E+00, 0.17867800E-01, -.23486900E+01, -.75682700E-02, -.32196100E+01, 0.85090200E+00, -.37692100E+00, 0.42183200E+00, -.36597000E+00, 0.38360300E+00, 0.59571200E+00, 0.50778700E+00, -.69117700E-01, 0.42085300E+00, -.10714600E+00, -.53652400E+00, -.35982600E+00, 0.17070600E+01, 0.29567800E+00, -.41756500E+00, -.42305900E-01, 0.68954500E+00, 0.97278400E-01, -.15187900E+00, 0.25778800E-01, 0.30832100E+01, -.79082700E-01, -.10361100E+01, -.71582400E+00, 0.58969500E+01, 0.70568100E+00, 0.10062100E+00, 0.63991500E+00, 0.14318800E+01, 0.73783900E-01, 0.73283300E+00, 0.13766600E+00, -.17825800E+01, 0.23276300E+01, 0.12307100E+01, 0.69263100E+00, -.93082100E+00, -.66234200E+00, 0.37766600E+00, -.31412700E+00, -.80477700E-01, -.19207900E+01, 0.12939100E+00, 0.64855200E-02, 0.61589200E+00, 0.82475600E+00, 0.37101900E+00, -.74321200E+00, 0.34867300E+00, -.30079000E+00, 0.43934200E+01, 0.72603700E-01, -.42208500E+00, -.63015900E-01, 0.20869300E+00, 0.15739400E+01, -.23263100E+01, -.32448800E+00, 0.18188600E+01, 0.64816100E+01, -.22182100E+01, 0.33475300E+01, -.33131200E-01, -.41344800E+00, 0.10652200E+00, -.12047300E+00, 0.34889900E+00, -.11270900E+01, -.26989200E+02, 0.25157000E+01, 0.25711000E+01, -.69797200E+00, -.14651200E+01, 0.14566500E+00, 0.82375800E+00, 0.10598900E+00, 0.44387300E+00, 0.14359600E+00, 0.19326200E+01, -.11304400E+00, -.77829300E+00, -.57785300E+00, 0.23336600E+01, -.25211600E+00, -.38574200E-01, 0.43315700E+00, -.21674900E-01, 0.19117700E+01, -.31009200E+01, 0.67544700E+00, 0.58797300E+00, 0.35782800E+01, 0.92998800E+00, 0.12526900E+00, 0.55475700E+00, 0.62087000E-01, 0.63043600E+00, -.33969300E-02, 0.44843600E+00, 0.25178800E+00, 0.21299100E+00, 0.17266600E+01, -.22100500E+00, 0.27589300E+01, -.39214000E+00, -.59327000E-01, -.25193300E+01, 0.33085300E+01, -.44223500E+00, -.96156100E+01, 0.80593600E+01, 0.69061500E+01, 0.43968300E+01, 0.76667200E+01, -.12459000E+01, 0.40055900E+00, 0.23171400E+01, 0.61487800E+01, 0.33779600E+00, 0.52120600E+01, 0.65430400E+01, -.13674500E+00, 0.96211900E+01, 0.51296500E+00, -.36602500E-01, 0.65693800E+01, -.69611000E+01, -.37242900E+01, 0.47630500E+00, 0.11456800E+02, 0.49911500E+00 },
        { -.55157200E+01, 0.10401200E+01, 0.41777000E+01, 0.13357800E+01, 0.28237200E+01, 0.30899300E+00, 0.49762600E+00, -.47788500E+01, -.16292100E+00, -.34381700E+00, -.45431600E+00, 0.16558100E+00, 0.35048800E+00, -.22177800E+00, 0.22721000E+00, 0.86246700E+01, -.35882000E+00, -.92043000E+00, -.64747000E-01, -.47318100E+00, 0.14275500E+00, -.50936900E+00, 0.13778300E+00, 0.34135300E+00, -.54599000E+00, -.20263200E+00, -.39672800E+00, 0.34714600E+00, 0.16554600E+01, -.16053000E+00, -.90835400E+00, 0.55565700E+00, -.24841400E+00, -.33107400E+01, -.43837300E-01, -.23730200E+00, 0.14912200E-01, 0.52928800E+00, -.18388800E+00, 0.71607500E+00, 0.49091400E+00, -.89012500E+00, -.97400400E-01, -.13160900E+00, 0.10249500E+00, 0.25911300E+00, -.88950700E-03, 0.28530600E-01, 0.11709100E+01, 0.99407100E-01, 0.52314200E+00, -.66794200E+00, 0.76192200E+00, -.28421000E+00, 0.21791400E+00, 0.57572100E+00, 0.35227700E+00, 0.12423300E+00, 0.53064300E-01, -.32737200E-02, -.83044400E-01, 0.15531500E+01, -.16631800E+00, -.23510800E+00, -.32309000E+00, -.22422800E+00, -.95381900E-02, 0.18904000E+00, -.50552500E+00, -.42997400E-02, 0.16361300E-01, -.14797400E+01, -.37029700E+00, -.52357700E+00, 0.35147700E+00, -.23289700E+00, -.51876000E-01, 0.77510600E+00, -.47315600E-02, -.82986000E-01, -.37111400E-01, 0.43595600E-01, 0.25637000E+00, -.38104700E-01, -.10926800E+00, -.14475000E+00, -.19808500E+00, 0.90560300E-01, 0.29761000E+00, 0.88602400E-02, -.97681700E-01, 0.12798600E-02, 0.27241900E+00, 0.11840800E-01, -.14727300E+00, 0.29104300E+00, 0.67531500E+00, 0.79966900E+00, 0.18577600E+00, 0.34065300E+00, 0.63639000E-01, 0.16895900E+00, 0.33192400E-01, -.36771600E+00, 0.31064000E+00, 0.26385700E+01, -.88085100E+00, 0.60073400E+00, 0.82653200E-01, -.22863900E+00, 0.61379800E+00, -.48200100E-02, 0.62371700E+00, 0.26044600E-01, 0.26828400E+00, 0.10028800E+01, 0.12279700E+00, -.81575200E-01, -.18041900E+01, 0.13410700E+01, 0.74691100E-01, 0.39795600E-01, -.86581600E-01, -.13817500E+00, 0.46443600E-01, -.31436600E+00, -.88612000E+00, -.15809800E+00, 0.43550100E+00, -.46232700E-01, -.49516200E+00, -.81460100E-01, 0.61766800E+00, -.55329100E-01, 0.22739300E-01, -.37597000E-02, 0.28610700E+00, -.49491600E+00, 0.53004300E-01, 0.38854700E+00, -.14069400E+00, -.11011500E+00, 0.31310200E+00, -.47244600E+00, -.38818500E-01, 0.60245300E-01, -.35811900E-01, 0.22725400E+00, 0.78796600E-01, 0.36538300E+00, 0.18706100E+01, -.23390500E+00, -.25484600E+00, 0.69644700E+00, 0.15301000E-01, -.34331600E+00, -.10343300E+00, -.12571800E-02, 0.13003700E+01, 0.56088700E+00, -.67175000E-01, -.18999000E+00, -.58997900E-01, -.17327400E+00, 0.52431400E+00, 0.50519900E+00, 0.85028400E-01, 0.12972600E+01, -.38785600E-02, -.43095700E-01, -.89179100E-01, 0.15549300E-03, 0.64583100E-01, -.64546100E-01, -.35786000E+00, 0.54185800E-01, 0.13171400E+00, 0.47011400E-02, 0.38206300E-01, -.91329900E-02, 0.95353900E-01, 0.10380000E+00, -.46456100E+00, 0.39591600E+00, -.45845700E-01, 0.42640300E+00, -.10610100E+00, -.30502300E+00, 0.27952800E-01, -.18078600E+00, -.26713500E+00, 0.25130600E+00, 0.33283400E-01, -.68841800E-01, -.24212700E+01, -.69837300E-01, 0.24518700E+00, 0.48834200E-01, 0.92819600E-01, -.15094700E-01, -.11104000E+00, 0.40966400E-01, -.54513100E-01, 0.12770200E+00, 0.20581000E+00, -.10801700E-01, -.14144000E-01, 0.24664600E+00, 0.37232500E-01, 0.68826000E-01, 0.11271200E-01, -.15147300E+00, -.23954300E-01, -.51669700E+00, 0.86281900E+00, -.89081000E-01, -.50670100E+00, 0.11196600E+00, 0.36798300E-01, -.38157400E-01, 0.59694500E+00, -.19894300E-01, 0.63329300E-01, 0.28397200E-01, 0.18375200E+00, -.43338900E+00, -.27003200E+00, -.50477000E-01, -.29619500E+00, -.99407900E+00, -.56185400E+00, 0.44651900E+00, 0.31897900E-02, -.97404900E-01, -.62766600E+00, 0.65550500E-01, -.17369000E+00, -.52269100E-01, 0.76698100E+00, 0.67582900E+00, -.11153100E+00, -.21668700E+00, -.17885500E-01, -.16015200E-01, -.28563000E-02, 0.10070100E-01, -.17350500E+00, 0.74092800E-01, -.14798400E+01, 0.44826600E-01, -.15996100E+00, -.11403600E+01, 0.60095600E+00, 0.49672000E-01, 0.12660600E-02, 0.33772500E-01, -.62566400E-02, 0.44772200E+00, 0.44848600E+00, 0.65762500E-01, -.29849800E+00, -.60682300E+00, -.83562100E+00, 0.59116300E-01, 0.18137500E+00, -.51419100E-01, -.54953000E-01, -.27450000E-01, 0.31664600E-01, 0.92610200E-01, 0.36784400E-01, 0.68396800E-01, -.28043700E-01, -.17283500E+01, 0.80865400E-01, 0.57069700E-01, 0.10121900E+01, -.10705500E+01, 0.60405800E+00, 0.16756900E+01, -.20401800E+01, -.48605100E-01, 0.94475200E+00, -.22857200E+00, -.21660700E+01, -.10901200E+01, -.73875900E+00, -.89864900E+00, 0.30401600E+00, 0.79376900E+00, 0.36391400E+01, -.33930800E-01, -.14141900E+01, -.73751500E-01, -.14476700E+00, -.91084100E+00, -.39462000E+01, -.17983000E+01, 0.26758900E+00, -.14897500E+01, 0.96840200E-01 },
        { -.27562000E+02, -.63375800E+01, 0.71788300E+01, 0.13569200E+02, 0.10321500E+02, 0.65153500E+01, 0.11236500E+02, -.29062900E+02, -.19722600E+01, -.27453600E+01, 0.35064900E+00, 0.36949300E+01, 0.43761500E+01, -.12463500E+01, -.40561500E+01, 0.57914400E+02, 0.25891500E+01, 0.62936900E+01, 0.13776100E+02, -.20881200E+01, -.60752600E+01, -.11708500E+01, 0.13891700E-01, 0.38061300E+01, -.12938600E+01, -.16295800E+00, -.13353900E+01, 0.40438600E+01, -.64810000E+00, 0.36919200E+00, -.26176700E+01, -.18644400E+01, 0.32728500E+00, 0.65091600E+01, 0.12970300E-01, -.25736000E+00, 0.28228600E+00, 0.19690500E+01, -.12612000E+00, -.19987600E+01, 0.16095200E+02, 0.12810500E+01, -.31479300E-01, 0.65120800E+00, -.24645100E+01, 0.32730800E+00, -.22531200E-01, -.11727300E+00, -.13038300E+02, 0.92621700E+00, -.31854900E+01, 0.18418700E+01, -.55256800E+00, 0.82919900E+01, 0.91785300E+00, 0.71037200E+01, 0.28730600E+01, -.44587100E+00, -.20669500E+00, -.15697800E+01, 0.14338700E+01, -.37262100E+01, 0.69437400E+00, -.16178100E+01, 0.14722600E-01, -.10781200E+01, 0.10733000E+01, 0.12982900E+01, -.11431300E+00, -.69369800E-01, 0.21044500E-01, 0.13124900E+02, 0.96199600E-01, -.31384800E+01, -.29901900E+01, -.48133100E+01, -.28474100E+00, 0.30943800E+00, -.29352300E+01, -.88512700E+00, 0.28831800E+00, 0.27286400E+00, 0.54982600E+00, 0.19856500E+01, -.56648300E+00, -.14803600E+01, -.96045600E+00, 0.11647200E+01, -.35758000E+01, 0.22117000E-01, -.35363300E+01, -.79525200E-02, 0.86145200E-01, -.33038900E+00, -.11712500E+00, -.11731600E+01, 0.17942200E+01, 0.16796400E+01, -.67153200E+00, -.95457500E+00, 0.90466500E-01, 0.37523200E+00, -.27420900E-01, -.12590600E+01, 0.14576000E+01, 0.99196800E+01, -.22143800E+01, 0.10752700E+01, 0.76690200E+00, 0.79740200E+00, -.22194200E+01, -.27941500E-01, 0.10855300E+01, 0.63343600E-01, 0.13096900E+01, 0.10212200E+00, -.86596900E+00, 0.11277600E+01, 0.30388100E+00, 0.24087500E+01, -.23533300E-01, -.11676000E+00, -.14779500E+00, -.11734800E+01, -.59512100E-01, -.53464000E+00, 0.79254700E+00, 0.35599100E+01, -.37587200E+01, -.13311100E+01, 0.28439900E+00, -.25683700E+00, 0.49338400E+00, 0.18433300E+01, -.88354800E+00, -.12379000E+00, 0.36863000E+01, -.53024700E+00, -.94087200E+00, -.13401000E+01, -.23451400E+00, 0.79445300E+00, -.11956700E+01, -.25841200E+01, -.86774200E-01, -.26479900E+01, -.15648300E+00, 0.56711000E+00, 0.21855400E+00, 0.16152600E+01, -.15059900E+01, -.99808300E+00, -.43639500E+00, -.36863600E+01, -.16516600E+00, -.24894100E+00, -.86341200E+00, -.29234800E-02, -.18958900E+01, -.19260300E+00, -.19865700E+00, -.68506100E+00, -.34098600E+00, -.14442400E+01, -.12537000E+01, 0.10895200E+01, 0.14483300E+00, 0.12726400E+01, -.46344300E-02, 0.30758900E+01, -.90835000E+00, 0.52584400E+00, -.25549400E+00, 0.18817000E+00, 0.16613300E+01, -.85264100E+00, -.10256900E+01, 0.19405400E-01, -.43728200E+00, 0.34110700E+00, -.77070500E+00, -.11468900E+00, -.31498700E+01, 0.66265400E+00, -.19650300E-01, 0.24301400E+00, -.21625000E+00, -.23795100E+01, 0.67331000E-01, -.17185800E+01, 0.53137700E+00, 0.10970900E+01, 0.10761200E+01, -.32201900E+00, -.88573900E+01, -.35863800E+00, -.74330900E+00, 0.10061100E+01, 0.17085900E+00, -.87404700E-01, -.99025100E+00, 0.29889400E-01, 0.31783600E+01, -.19914300E+01, 0.44470300E+00, 0.57411300E+00, -.55410500E+00, 0.15676200E-01, 0.11302400E-01, -.14629600E-01, 0.19186600E-01, -.30188700E+01, 0.37764900E-01, -.55546500E+01, -.32245700E+01, -.14106900E+01, -.30430900E+01, 0.10392600E+01, 0.51827200E+00, 0.24224000E+01, -.42307300E+01, 0.48288000E+00, -.32882500E+00, 0.11060800E-01, 0.20411500E+01, 0.19812900E+01, 0.85568000E+00, -.50140500E+00, -.74576000E+00, 0.61247900E+01, -.25479900E+01, 0.33739700E+01, -.11252300E+00, -.33300900E+00, 0.32765600E+00, 0.35391300E+01, 0.12146600E+00, -.82670800E+00, 0.96144000E+01, 0.79927200E+01, -.49876600E+01, 0.85467000E+00, -.37448100E+01, -.65396200E-01, -.18966600E+00, 0.21468800E-01, -.10260000E+00, 0.47090200E+00, -.65356400E+01, -.85608700E-01, 0.15483900E+00, -.27386000E+01, 0.72623300E-01, -.37705400E+01, 0.89469700E-02, 0.31913300E+00, -.36244900E-01, 0.24722400E+01, 0.41777900E+00, 0.45231900E-01, 0.13925500E+01, -.13788300E+01, -.24934100E+01, 0.76954100E+00, 0.85104700E+00, -.22359200E+00, -.21194100E-01, -.11818600E-01, 0.40535500E+00, 0.60018000E+00, -.13621800E-01, 0.14034100E+01, -.73056300E+00, -.66880900E+01, -.10040000E+00, 0.41123000E+00, 0.14167500E+00, -.68207800E+00, 0.23356900E+01, -.42353200E+00, -.11525800E+01, -.30500500E+00, 0.26995300E+01, 0.49360100E+01, 0.16673600E+01, 0.20244600E+01, 0.10001800E+01, 0.41745300E+01, -.32480100E+00, 0.34015000E+00, -.68772400E+01, -.43104800E+00, 0.64886600E+01, 0.25036200E+00, 0.20566100E+00, 0.11748500E+02, 0.74713900E+01, 0.60106600E+01, 0.62165800E-01, 0.73124000E+01, -.26236100E+00 },
        { -.19479800E+01, -.51581300E+00, 0.52784900E+00, 0.13536600E+01, 0.13193900E+01, 0.25878600E+00, 0.69370300E+00, -.14209200E+01, -.77772300E-01, 0.32403500E+00, 0.26137900E-01, 0.13470100E+00, 0.30807500E+00, 0.69934200E-02, -.33602300E+00, 0.78260800E+01, 0.18163100E+01, 0.11397900E+01, 0.92968900E+00, 0.55126500E-02, -.83200000E+00, -.17039200E+00, -.32662200E-01, 0.23990400E+00, -.15997800E+00, -.46722100E-01, -.22894400E+00, 0.18305700E+00, 0.47653700E+00, 0.32184300E-01, -.16098300E+00, -.14529900E+00, -.12092700E+00, 0.14338800E+01, -.13540500E-02, 0.40625000E-02, 0.15700500E-01, 0.33988400E-01, -.33201100E-01, 0.69368900E-01, 0.69969400E+00, -.80894000E-01, -.22691400E-01, 0.30864800E-01, 0.64922900E-01, -.81885700E-01, 0.21426000E-01, 0.13022700E-01, 0.25438900E+00, 0.20264400E-01, 0.47010700E-01, 0.10797500E+00, 0.20631300E+00, 0.59147100E+00, 0.37821000E-01, 0.34511200E+00, 0.26589800E+00, -.13909300E-02, 0.15595300E-01, 0.13311100E+00, -.20304600E-01, 0.22340500E+00, 0.14142500E+00, -.60398700E-01, 0.79125600E-01, -.19545200E+00, -.21489100E+00, 0.14834500E-01, -.14065600E+00, -.22169400E-02, 0.19872200E-01, -.32403800E+00, 0.24553800E+00, 0.31690600E-01, -.22529500E-01, 0.32916000E+00, -.66117100E-01, 0.24213000E+00, 0.41456500E-01, 0.13949200E-01, 0.13723800E-01, -.30154600E-01, 0.35698000E-01, 0.75488500E-01, 0.18749300E-01, -.11757800E-01, 0.75213300E-01, 0.48386300E-01, 0.46652700E-01, 0.23429000E-01, -.46573600E-01, 0.87847500E-03, -.76342300E-01, 0.60470100E-02, 0.32605400E+00, 0.14603800E+00, 0.11640700E+00, -.27713600E-02, -.24479300E-02, 0.24239000E-01, 0.46293400E-01, 0.97560100E-02, 0.13863500E-01, -.97361600E-01, 0.86723000E-01, -.92909100E+00, -.27221400E+00, 0.88650200E-01, -.32068400E-02, -.53722200E-01, -.52298400E-01, 0.10060400E-01, -.36676700E-01, 0.99617900E-02, 0.77842300E-02, 0.73850000E-01, 0.58735900E-02, -.32473200E-02, -.13548400E+00, -.21361700E+00, -.14640600E+00, 0.20653300E-01, -.28898500E-01, 0.57916300E-01, 0.17562000E-01, 0.24567800E-01, -.17073100E+00, -.89924600E-01, 0.13392600E+00, -.37691400E-01, 0.88146100E-01, 0.10104800E-01, 0.15869300E-01, -.54358900E-01, -.58092200E-02, 0.79803300E-02, -.96242100E-01, -.15143200E+00, -.10967600E-01, 0.40933300E+00, 0.23953500E-01, 0.67774300E-01, 0.10850600E+00, 0.12897700E+00, 0.35639500E-02, 0.71464800E-01, 0.83570300E-02, -.25632300E-02, -.75267000E-02, 0.92470000E-01, -.11144300E+00, 0.23786300E-01, -.25829400E-01, -.17400200E+00, 0.12869500E-01, -.14482500E+00, -.25467300E-01, 0.14635700E-03, 0.30319100E+00, 0.64191900E-01, -.50412500E-02, 0.57631300E-01, 0.47498300E-01, 0.62467000E-01, 0.15487100E+00, 0.79798100E-01, -.74320600E-02, -.86356300E-01, 0.49719200E-02, -.64939800E-01, -.75069400E-01, 0.40982600E-01, -.15389200E-01, -.15079500E-01, -.62740800E-01, -.12849500E-01, 0.31841500E-01, 0.49371100E-02, -.10819000E-02, -.30107000E-02, 0.48178900E-01, 0.37682600E-01, -.26580300E+00, -.68534800E-02, 0.72102400E-01, 0.53829200E-01, -.45568500E-01, -.36227300E-01, 0.99875700E-02, -.30331200E-01, -.10330600E+00, 0.63741600E-01, 0.78327400E-01, 0.98665100E-03, -.61364700E+00, -.59055000E-01, -.92664200E-02, -.42319700E-01, -.65967500E-01, -.56982400E-02, -.48199900E-01, -.14289500E-01, -.15300300E-01, -.30112200E+00, -.20963700E+00, -.39794000E-01, 0.49855800E-01, 0.17014500E+00, -.94930500E-01, -.15544400E-01, 0.90310300E-02, 0.15268400E+00, 0.94039400E-02, 0.55498800E-01, 0.11036600E+00, -.62900500E-01, -.84566600E-01, 0.20579700E+00, -.52017300E-03, -.19925000E-01, -.54600000E+00, 0.14180500E-02, -.11001100E-01, 0.74464800E-02, 0.20195700E+00, -.13135400E+00, 0.53490600E-01, -.89245500E-02, -.15888200E+00, -.68196400E-01, 0.13549600E+00, -.79883600E-01, -.23885400E-02, 0.15460200E-01, 0.11695700E+00, -.35241400E-01, -.88209100E-02, -.15622800E-01, 0.42048000E+00, -.17580000E-01, -.19014200E-01, -.70803800E-01, -.15477500E+00, 0.13119800E-01, 0.17610600E-01, -.44690200E-02, -.21923800E-01, -.29476800E-01, -.34306800E-01, 0.41135400E-01, 0.27560600E-01, 0.61570700E-01, -.11639400E+00, 0.83617500E-01, -.49938500E-03, -.76757300E-02, -.20256500E-04, 0.50514900E-02, 0.10125100E+00, -.12361300E-01, -.12493500E-01, -.83115700E-01, -.35779400E-01, -.88021700E-03, 0.53516400E-02, -.65756200E-02, -.26836800E-01, -.75129600E-03, -.44605000E-02, 0.76682200E-02, 0.25786300E-02, -.33396900E-01, 0.17953500E-01, -.11615800E+00, 0.21074600E-01, 0.90182500E-02, 0.10030100E+00, -.42542400E-01, -.42903500E-01, 0.10794400E+00, -.72982400E-01, 0.24419300E-02, 0.20911000E+00, 0.12234100E-02, 0.55969300E+00, 0.20693000E+00, 0.16404400E+00, 0.12801500E+00, -.58607200E-01, 0.77064400E-01, -.65932400E+00, 0.86409200E-03, 0.22216100E+00, 0.79483700E-02, 0.35156500E-01, 0.83226300E-01, 0.71826800E+00, 0.80691500E-01, -.46408700E-01, 0.20683100E+00, -.13163200E-01 },
        { -.36099500E+01, -.92639900E+00, 0.95710600E+00, 0.20727200E+01, 0.24938600E+01, 0.33838400E+00, 0.17282400E+01, -.28106100E+01, -.86143000E-01, 0.47745000E+00, -.11840700E-02, 0.31480400E+00, 0.35765900E+00, -.45468700E-01, -.67501400E+00, 0.14383300E+02, 0.17620400E+01, 0.13262000E+01, 0.86291900E+00, -.33163100E+00, -.95928800E+00, -.23519400E-01, 0.58241700E-01, 0.86927400E+00, -.68584300E-01, -.59261900E-01, -.42265100E+00, 0.30157300E+00, 0.15530700E+01, 0.34100400E-01, -.67707800E+00, -.58345400E+00, -.11853600E-01, 0.98634500E+00, 0.50773300E-02, -.50712300E-01, -.93860000E-01, 0.45646200E+00, -.98136000E-01, 0.44951400E-01, -.22985100E+00, 0.23439300E+00, -.26003500E-01, 0.53772000E-02, -.53411200E+00, 0.22027200E+00, -.33990000E-01, -.10737600E+00, -.15129100E+01, -.15844500E-01, -.28122400E+00, -.54902000E+00, 0.15465300E+00, -.38076200E+00, -.27546900E+00, 0.68719200E+00, 0.88618800E-01, -.33364500E-01, -.87576400E-01, 0.12842200E+00, 0.52557000E-01, 0.16231100E+00, -.52577600E-01, -.11879300E+00, -.17215800E+00, 0.57899800E-01, -.24408000E-01, 0.23146900E-01, -.11273700E+01, 0.90835600E-02, -.64668200E-01, -.14407500E+01, -.11052800E+01, -.30666400E+01, 0.18556000E+00, -.50838200E+00, 0.27814000E+00, -.51516200E+00, 0.15018600E+00, -.76400600E-01, -.15103800E+00, 0.10421700E+00, 0.32221300E+00, -.54222000E+00, -.41657400E+00, 0.28838300E+00, 0.30179300E+00, -.21711000E+00, 0.54553500E-01, 0.37594500E-01, -.28078000E+00, 0.23817300E-02, 0.51024400E+00, 0.11977200E+00, -.41983300E+00, -.11858500E+00, 0.22610300E+00, -.25109800E-01, 0.13551600E-02, -.19515400E+00, 0.56244500E-01, -.59509000E-01, -.70582200E-02, 0.15966000E+00, 0.15502200E+00, -.20016800E+00, -.16878800E+00, 0.24789300E+00, 0.85038000E-01, 0.43833800E+00, 0.90959300E-01, -.13311100E-01, -.10689900E+00, 0.26231800E-01, 0.84061500E-01, 0.45253500E+00, -.16533700E+00, 0.14093800E+00, -.47900700E+00, 0.12164000E+01, 0.55507500E+00, 0.77072600E-01, 0.34507300E-02, -.68577400E-01, 0.58265700E-01, -.78075800E-01, -.22203400E-01, -.84675000E+00, 0.37948000E-02, -.47672800E-01, -.17050500E+00, 0.46491900E+00, 0.96268400E+00, -.50065200E+00, 0.23356800E+00, 0.41605000E-01, -.93249900E+00, -.68131600E+00, 0.10107900E+00, 0.11880100E+01, 0.17188900E+00, 0.22929300E+00, 0.52751000E-01, 0.10944200E+00, -.33129400E-01, -.40944900E-01, -.19236000E-01, -.17450200E+00, 0.14023400E+00, 0.33498400E+00, 0.61577400E+00, -.15272400E+00, -.95511000E-01, -.24604100E+00, 0.18490000E-01, 0.62948800E+00, -.12430100E+00, -.27886200E-02, 0.56163400E+00, 0.44517900E+00, -.34850600E-01, -.20323100E+00, 0.90747700E-01, -.12557900E-01, 0.84952800E+00, -.11173900E-01, 0.62765100E-01, 0.87618700E+00, -.19168400E-02, 0.44594100E+00, -.24168500E+00, -.78331900E-01, 0.54333400E-01, -.22893700E-01, -.57158300E+00, -.62388700E-01, 0.45050800E-01, -.24013800E-01, 0.18615900E+00, 0.68708900E-01, 0.32018200E+00, -.25840200E+00, -.20489400E+00, -.22189500E-01, 0.11413500E+00, 0.77015600E+00, -.89335300E-01, 0.57732000E-01, -.28893000E-02, -.16464500E-01, -.73155900E+00, 0.14641200E+00, 0.27393100E+00, -.25579600E-02, -.20675500E+01, 0.23472800E-01, -.11550100E+00, 0.15765700E-01, -.16366800E+00, -.37281400E-01, -.16357500E+00, -.68567200E-01, -.23243600E+00, -.51295400E+00, -.27034200E+00, -.43061700E-02, -.16248200E+00, 0.42349300E+00, -.15469800E+00, -.74631100E-01, 0.14331400E-01, -.87996800E-01, 0.16013400E-01, 0.18171000E+00, 0.90084100E+00, -.10424500E+00, -.37777600E+00, 0.39649200E+00, 0.63054700E-01, -.33433300E+00, -.12958700E+01, 0.32978100E-01, -.10224100E+00, 0.49124800E-02, 0.74890500E+00, -.61298200E+00, 0.43176200E+00, -.70642500E-01, 0.39653500E-01, 0.32332400E+00, -.38508400E+00, 0.16765300E+00, -.54831000E-02, -.31753000E-01, -.64671500E+00, 0.13473500E+00, 0.21116200E-01, -.11280000E-01, -.40787300E+01, -.64248600E+00, 0.26429800E+00, -.55426200E+00, 0.12276500E+00, -.17132200E-01, -.64451200E-02, 0.21752800E-01, -.13296600E+00, 0.76051100E-01, 0.70197000E-01, 0.22005900E-01, -.23350000E-01, -.54096400E+00, 0.78000800E-01, 0.31463400E+00, -.75660100E-02, 0.10227800E-01, -.12513300E-02, 0.25772900E+00, 0.10850500E+00, 0.56492300E-01, 0.67961300E-01, -.16955300E+00, -.58299900E+00, 0.71767300E-01, 0.90204500E-01, -.14501500E-01, 0.28534100E-01, -.12552700E-01, 0.44771600E-01, 0.32749500E-01, -.79579400E-03, -.15269400E+00, 0.98708600E-01, -.59181300E+00, 0.10769600E+00, 0.42673100E-01, 0.36447500E+00, -.36682200E+00, -.10545600E+01, 0.10815300E+01, -.86915400E+00, -.24768200E-01, -.16519000E+00, 0.11820100E+00, 0.14330900E+01, -.48646500E+00, -.39680600E+00, -.77730400E+00, 0.14013400E+00, -.22620300E+00, 0.34179200E+01, 0.91216900E-01, -.14158900E+01, -.76946600E-01, -.13634300E+00, -.14774600E+01, -.37733300E+01, -.23792800E+01, -.62761600E-01, -.16663800E+01, 0.21128200E+00 },
        { -.17034900E+01, 0.15807700E+00, 0.58213600E+00, 0.26744700E+00, 0.45985000E+00, 0.36307200E+00, -.38931900E+00, -.44917800E+00, -.13648700E+00, -.31320400E+00, 0.12036000E+00, 0.14290000E+00, 0.26336200E+00, -.92601900E-01, 0.11629400E+00, 0.11899900E+01, -.53839900E+00, -.28470300E+00, 0.52489500E+00, -.72620100E-01, -.32044100E+00, -.85362600E-01, -.64819500E-02, 0.19179200E+00, -.67649100E-01, -.71931900E-01, -.20576000E+00, -.16669300E+00, 0.10837500E+00, -.10916000E-01, 0.46639800E-01, 0.31636600E-01, -.14873800E+00, -.39114200E+00, -.10700700E-01, -.38248700E-01, 0.65578400E-01, 0.22466100E+00, -.22967800E-01, 0.27823400E+00, 0.75036300E+00, -.18436600E+00, -.72992700E-01, 0.16191100E-01, -.31827900E-01, -.27882700E-01, -.99921500E-02, 0.40588300E-01, -.33346100E-01, 0.31695900E-01, 0.10661700E+00, 0.42507700E+00, -.11879700E+00, -.48839900E+00, 0.11237300E+00, -.58735000E+00, -.91916000E-01, -.46719200E-01, 0.14676800E-01, -.70265800E-01, 0.70829900E-02, 0.81961700E-01, -.80966100E-01, 0.15798700E+00, 0.71733100E-01, -.73496800E-01, 0.27795100E+00, 0.11385400E+00, 0.16733300E+00, -.68690600E-03, -.10663000E-02, 0.91315900E+00, -.31177800E+00, 0.84910100E-01, 0.12776500E+00, 0.96123300E-01, -.10570000E+00, 0.13303800E+00, -.94941400E-01, 0.28628900E-02, 0.83546200E-02, 0.30172300E-01, -.82028300E-01, -.39078100E-01, -.26044300E-01, -.12208900E+00, -.74289100E-01, 0.46045500E-01, -.44908900E-01, -.39030600E-01, -.20198600E+00, -.23572400E-02, -.16000600E-01, 0.90678700E-02, 0.20676100E+00, 0.22533800E+00, 0.86589800E-01, 0.21474000E+00, 0.12708100E+00, 0.53936800E-01, -.12699400E-01, 0.11172700E+00, 0.11634500E-01, -.27624600E+00, -.92528200E-01, 0.16861400E+01, 0.13484500E+00, 0.16991300E+00, -.20229700E-01, -.35061100E+00, 0.17964200E+00, -.15759400E-01, 0.57650800E+00, -.79634400E-02, -.23483400E+00, 0.27049900E+00, -.82628800E-01, -.63970500E-01, 0.10499700E-01, -.17374400E+00, 0.40389200E+00, -.44449100E-01, -.11956300E+00, -.31629400E-01, -.45382700E-01, 0.10715600E+00, -.11866300E+00, 0.39106700E+00, 0.83272900E-01, 0.12787600E+00, -.31988100E-01, -.52319600E-02, 0.13124900E+00, 0.56404900E-01, -.45797600E-01, -.88165700E-02, 0.24545300E+00, 0.78146300E-01, -.30464900E-01, -.43488200E+00, -.32517500E-01, 0.57938400E-01, -.21038900E-01, -.17763900E+00, -.57943400E-02, 0.24142200E+00, 0.17964400E-01, -.13030000E+00, -.47853800E-01, 0.38481400E-01, -.32368000E+00, -.22360600E-01, 0.63314000E-01, -.10683000E+00, -.44871900E-02, -.31583300E+00, -.34309700E-01, 0.34663400E-03, 0.36874200E+00, 0.57911400E-01, -.22291800E-01, -.24832600E-01, 0.40446700E-01, 0.11346500E+00, 0.27460300E+00, 0.59902400E-01, -.60744800E-02, -.46198000E-01, 0.85125400E-03, 0.49316000E-02, -.54535300E-02, 0.10800100E-01, -.86656000E-02, 0.74739300E-03, -.77931800E-02, 0.33612300E-02, 0.26182700E-01, 0.40285800E-02, -.11139500E+00, 0.70607400E-02, -.12567300E+00, -.75377000E-01, -.46840900E-01, 0.55110300E-01, 0.32197500E-01, -.11978500E+00, 0.87418900E-01, -.58408900E-01, -.74148300E-02, 0.46334300E-01, 0.14001200E+00, 0.31744700E-01, -.15088400E-01, -.11310700E+00, 0.17421900E+00, -.59964600E-01, 0.10608600E+00, 0.44017800E-01, 0.46988000E-01, 0.59186400E-02, 0.64078100E-01, 0.36913900E-01, -.81296100E-01, 0.60511600E-02, -.67136300E-01, 0.44823900E-01, 0.82354500E-02, -.13769100E-01, -.57696400E-01, -.16488900E-01, 0.90018600E-03, 0.13673900E-01, 0.17281500E-01, -.39014400E+00, 0.33917400E-01, -.10938000E+00, -.45129900E-01, 0.16011200E+00, 0.46341600E-01, -.13169400E+00, -.10240800E+00, -.44146500E-02, -.49972000E-01, 0.67509700E-02, 0.17229100E+00, -.11521300E+00, -.70580800E-01, -.50821800E-01, 0.18879400E+00, 0.32064200E+00, 0.35876700E-01, 0.11067100E+00, 0.26808500E-03, 0.21512000E-01, -.26060600E+00, 0.58490900E-01, 0.59185200E-02, -.24573200E-03, -.92062100E+00, 0.68167200E-01, 0.26589900E+00, -.18435900E+00, 0.64932800E-01, -.81052400E-03, 0.19437100E-01, 0.11225800E-01, 0.27993100E-02, 0.26109600E-01, 0.21039500E+00, -.28563400E-02, -.86808300E-02, 0.76897100E-01, -.36227500E-01, 0.96915800E-01, 0.30863900E-02, 0.39153400E-01, 0.97204900E-03, 0.18463300E+00, -.37047700E-01, 0.29785900E-01, -.49034900E-01, 0.15781800E+00, 0.80284700E-01, 0.54343400E-01, 0.14119000E-01, -.18569400E-02, 0.31588100E-02, -.21782000E-02, 0.20198300E-01, 0.27259900E-01, 0.32007500E-01, -.83197800E-01, 0.23420900E-01, 0.26928000E+00, 0.17760200E-03, -.12199400E-02, 0.86819900E-01, 0.14980300E+00, -.13858900E+00, 0.32205600E+00, -.20001400E+00, -.10167800E-01, -.18882300E-01, 0.36715300E-01, 0.33694800E+00, -.37782300E-01, 0.54833700E+00, -.99274900E-01, 0.45383300E-01, -.27508500E-02, 0.74972900E+00, 0.29244200E-01, -.16492000E+00, 0.10816000E-01, -.82196700E-01, -.56031700E+00, -.84030400E+00, -.56965300E+00, -.78449300E-01, -.17490900E+00, 0.91866200E-01 },
        { -.12245900E+01, 0.13125500E+00, 0.10335500E+01, -.56811800E-01, 0.34475300E+00, 0.34913300E+00, 0.38292200E+00, -.38343500E+00, -.30153300E-01, -.92890400E+00, 0.62289600E-01, 0.79289900E-01, 0.41714100E-01, -.51169700E-01, 0.70310000E-01, 0.17672600E+01, -.33021800E+00, -.45445300E+00, 0.46058500E+00, 0.17191500E+00, -.92844800E-02, -.42682800E-01, 0.51059400E-01, 0.39897000E+00, -.28711000E-01, -.39372700E-01, -.13021800E-01, 0.38111000E+00, 0.16383800E+00, -.11912800E-01, -.24879000E+00, 0.31654600E-02, 0.70937400E-01, -.53727000E+00, -.67814100E-02, -.43851100E-01, 0.51883100E-02, 0.86292800E-01, -.73672800E-01, 0.14835700E+00, 0.10615900E+00, -.97249200E-01, -.31475000E-01, 0.55118100E-01, 0.27444900E-01, -.37925200E-01, 0.21277400E-01, 0.13042500E-01, 0.40601800E+00, 0.31999700E-03, 0.45525800E-01, 0.77124100E-01, 0.15602200E+00, -.88687000E-01, 0.97555000E-02, 0.35623100E+00, 0.19073400E+00, 0.14854500E-01, 0.24996700E-01, 0.66687500E-01, -.36157700E-01, 0.33193700E+00, 0.10060900E+00, -.17536900E-01, 0.88591500E-01, -.99481800E-01, -.26038500E+00, -.16776900E-03, -.45074900E-01, -.28715000E-02, 0.76200400E-02, -.46677900E-01, 0.22616500E+00, 0.40016200E+00, -.74863000E-01, 0.23827400E+00, -.75686600E-01, 0.21577600E+00, -.55085600E-01, -.58404600E-02, 0.25005700E-01, -.10417500E-01, -.34883000E-01, -.42575500E-02, 0.21453200E-01, -.92722100E-02, 0.13206200E+00, 0.82821500E-01, 0.10779200E+00, 0.51189800E-02, 0.31930000E-01, 0.98084800E-03, -.27971300E-01, -.43387500E-02, 0.74682700E-01, 0.22153500E+00, 0.12521900E+00, 0.10800300E+00, 0.21621600E-01, -.83858100E-02, 0.36899500E-01, 0.41763400E-01, 0.95008300E-02, -.10419200E+00, 0.51797000E-01, 0.11803300E+00, -.14694700E+00, 0.10341100E+00, 0.29462300E-01, 0.30200700E-02, 0.98247500E-01, 0.46528800E-03, 0.19078900E+00, 0.98125000E-02, 0.71546200E-01, 0.69699100E-01, -.25927800E-01, -.17370300E-01, -.29534300E+00, 0.84423000E-01, 0.17502000E-01, 0.71715500E-02, -.19976300E-01, -.26831100E-01, 0.97066900E-02, 0.11176900E-01, -.85105400E-01, -.18849000E-01, 0.48253400E-01, -.17318000E-01, 0.10155000E-01, -.38206300E-01, 0.11850200E+00, -.11547700E-01, 0.11913200E-01, 0.31147400E-02, 0.32698700E-01, -.84776300E-01, 0.20629400E-01, 0.12237500E+00, -.62906600E-01, 0.16918600E-01, 0.91861700E-01, -.26660800E-01, -.48401900E-02, -.13629500E+00, -.99062800E-02, 0.95855500E-02, -.25321800E-02, 0.73982300E-01, 0.19200000E+00, -.27783600E-01, -.83479100E-02, 0.67008700E-01, -.26429200E-02, -.14777300E+00, -.48436900E-01, 0.47731900E-04, 0.24893900E+00, 0.67015400E-01, 0.25918000E-02, -.91776200E-02, -.14352700E-02, -.20583100E-01, -.30475500E-01, 0.75169500E-01, 0.43152300E-02, 0.15853700E-01, -.35811700E-04, -.44220300E-01, -.97621100E-02, 0.11187400E-01, -.83736200E-02, -.17048700E-02, -.37113300E-01, 0.56182000E-02, 0.15928300E-01, 0.22314500E-03, -.24125100E-01, 0.21980700E-02, 0.64409500E-02, -.75674600E-02, -.10011600E+00, 0.68061600E-01, 0.11514600E-01, 0.31614800E-01, -.27076200E-01, -.59641000E-01, 0.83522300E-02, -.31187400E-01, -.10572400E-01, 0.48678800E-01, 0.39176300E-01, -.11794800E-01, -.40753700E+00, -.21907600E-01, 0.21653100E-01, -.18385200E-02, -.45094800E-03, 0.42404500E-03, -.26709500E-01, 0.16481300E-02, -.63674500E-02, -.64749300E-01, -.43438200E-01, -.14346500E-01, 0.11277200E-01, 0.59464900E-01, -.21670000E-01, 0.39378300E-02, 0.36618200E-02, -.19304900E-01, 0.22410400E-02, -.46839400E-01, 0.90181400E-01, -.23781800E-01, -.36680100E-01, 0.64946400E-01, -.22670700E-01, 0.30809800E-01, -.18817800E-01, 0.40437400E-02, -.49788100E-02, 0.30742800E-02, 0.96493500E-01, -.13445200E-01, 0.12249300E-02, -.12083500E-01, -.18589100E-01, -.55214200E-01, -.62467800E-01, 0.99348300E-01, -.71077600E-03, -.11959800E-01, -.22240100E-01, 0.64197700E-01, -.17457100E-01, -.25323500E-01, 0.14031700E+00, 0.51616800E-01, -.11044300E+00, -.74277800E-01, -.27560300E-01, -.51631000E-02, -.10636200E-01, 0.22616600E-02, -.43360400E-01, 0.10363900E-01, -.22825700E+00, 0.13196100E-01, -.67342700E-02, -.20260100E+00, 0.23733400E-01, -.45490300E-01, -.86547600E-03, 0.70038100E-02, -.10538800E-02, 0.46321200E-01, 0.26669700E-01, 0.12386600E-01, -.28278000E-01, -.12761700E-01, -.22646100E-01, -.32924500E-02, 0.10388200E-01, -.23468500E-02, -.12308500E-03, -.15772100E-02, 0.27782800E-02, 0.59348900E-02, 0.55945400E-02, -.29461500E-01, 0.14936500E-01, -.10290400E-01, 0.64101000E-02, -.21109400E-02, 0.45857700E-01, -.56282000E-01, -.99216500E-01, 0.65080400E-01, -.16648000E+00, -.34769200E-02, 0.50959900E-01, 0.65211200E-02, 0.12614100E+00, -.34643600E+00, -.23728700E+00, -.30182200E+00, 0.73059800E-01, -.97933100E-01, 0.15881900E+01, 0.54998100E-01, -.54969300E+00, -.27437000E-01, -.82349500E-01, -.68473100E+00, -.17717100E+01, -.10254400E+01, -.59257300E-01, -.64448800E+00, 0.10586100E+00 },
        { 0.21751600E+01, 0.18206600E+00, -.21862000E+00, -.79112200E+00, -.78671600E+00, -.65417000E+00, 0.17621100E-01, -.18781500E+00, 0.21490900E+00, -.88658600E+00, -.88654500E-01, -.29991300E-01, -.17446000E+00, 0.15117600E+00, -.11382300E-01, -.88073800E+00, 0.20931800E+01, 0.60923600E+00, -.40881400E+00, -.11062400E+00, 0.30851100E-01, 0.14545900E+00, -.34566900E-01, -.86222600E-01, 0.10486400E+00, -.60819800E-03, -.33484200E+00, 0.13222500E-01, 0.12733700E+01, -.83060700E-02, 0.11600300E+00, -.36096900E+00, -.16231100E+00, 0.81405100E+00, 0.26340400E-01, 0.32341000E-01, -.45976400E-01, -.21415800E+00, 0.12667000E-01, -.23589300E-01, -.14383600E+01, 0.44350400E-01, 0.46272900E-01, -.55381700E-01, 0.25650500E+00, 0.14797900E+00, -.99556900E-02, -.34772400E-03, 0.83013700E+00, 0.24197800E-01, 0.14478500E+00, -.56928800E+00, -.17113400E+00, -.67971600E+00, -.18480200E-01, -.63998200E+00, -.18348300E+00, 0.73501900E-01, 0.51739800E-02, 0.28165200E+00, -.75138800E-01, 0.41184700E+00, -.16597000E+00, 0.53402300E-01, -.21975300E+00, -.79655600E-01, -.34664900E+00, -.75644000E-01, -.18713200E-01, 0.62921400E-02, 0.34601000E-01, -.10878400E+01, 0.45998600E+00, 0.84359600E+00, 0.12698000E+00, 0.82597300E+00, -.33282600E-01, 0.32960500E+00, 0.17930800E+00, 0.40942800E-02, 0.41936500E-02, -.38564300E-01, 0.64457600E-01, -.15847200E+00, 0.10800600E+00, 0.11913400E+00, 0.95579700E-01, -.46421800E-01, 0.64894800E-01, -.62015900E-01, 0.44754100E+00, -.48734100E-03, -.19619600E+00, 0.21335500E-01, -.21113900E+00, 0.14421800E+00, -.13292800E+00, 0.20178700E+00, 0.12468600E-01, 0.21360400E+00, -.47623000E-01, 0.10771000E-01, -.71194200E-02, -.14733200E-01, -.26666700E-02, -.21468400E+01, 0.17276800E+00, -.11758900E+00, -.22541400E-01, 0.75896500E-01, 0.51776000E-01, 0.95158700E-03, -.43302900E+00, 0.43494400E-02, 0.49664900E-01, -.11105500E+00, 0.54519000E-01, -.12155300E+00, 0.63541200E+00, 0.30522500E+00, 0.40355700E+00, 0.63078600E-02, 0.58871200E-01, 0.35027500E-01, 0.65606300E-02, -.28434300E+00, -.10437400E+00, -.39916000E+00, -.62009500E-01, -.10538600E-01, 0.25740800E+00, -.15776100E+00, -.27055200E+00, 0.33198200E+00, -.10119700E+00, -.12670000E-01, 0.14089100E+00, 0.11489900E+00, 0.15278100E-02, -.94522600E-01, -.89660600E-02, 0.23350200E-01, 0.30670400E+00, 0.11873100E+00, 0.16745900E-01, 0.18777500E+00, 0.34362000E-01, -.17798500E+00, 0.38965900E-01, -.20527200E+00, -.34319500E+00, -.17237700E+00, -.53421600E-01, -.99874800E-01, 0.17489600E-02, 0.16653600E+00, -.19077200E-01, 0.11484900E-02, -.60934200E-01, 0.17738600E-02, 0.14205400E-01, -.61770300E-01, 0.11282600E-01, -.89628600E-01, -.78240000E-01, 0.81046100E-01, 0.15639000E-01, 0.79446200E-01, -.57446600E-02, -.13732300E+00, 0.10011400E+00, -.57580600E-01, -.26888300E-03, 0.15039700E-01, 0.54146500E-01, 0.62172600E-01, 0.18726500E-01, -.91435200E-02, -.23384200E-01, 0.32327500E-02, 0.39026500E-01, -.35468900E-01, 0.26868000E+00, 0.17683500E+00, -.64605100E-01, 0.16681500E+00, -.48912800E-01, -.10280700E+00, -.28066400E-02, -.35952000E-01, -.76381600E-02, 0.12463800E-01, 0.82925400E-01, 0.75036200E-01, -.19274700E+00, 0.81027600E-01, -.13340900E+00, 0.47189500E-01, -.57773800E-01, 0.19142800E-01, -.71647400E-01, -.31967700E-01, 0.28141700E-01, 0.18389000E-01, 0.97585700E-01, -.12239400E-01, -.57156100E-01, 0.12658400E+00, 0.24852800E-01, 0.26070100E-01, -.10411700E-01, -.40728900E-01, -.22482400E-01, 0.42148300E+00, 0.24729700E+00, 0.10794800E+00, 0.11840000E+00, -.14715900E+00, -.45604300E-01, 0.26342100E-01, -.20357800E+00, -.52057400E-02, 0.29888600E-01, -.48040400E-03, -.46156100E-01, -.13662300E+00, 0.11908600E+00, -.28124600E-01, 0.49318800E-01, -.92905800E-01, 0.27094300E-01, -.17456500E+00, -.65149900E-03, -.11433800E-01, 0.69548500E-01, -.94041300E-02, 0.12480000E-01, 0.74703400E-02, 0.17719400E+00, -.17353400E+00, -.14537400E+00, -.80464800E-01, 0.18994100E+00, -.11853000E-01, -.70369400E-01, 0.81595500E-03, -.56629600E-01, 0.57104900E-02, 0.11362400E+00, 0.13199100E-01, 0.38342000E-02, 0.44228800E-01, -.12825500E+00, -.13437700E+00, -.14551100E-02, 0.65758300E-02, 0.36590400E-02, 0.47767100E-01, -.12213100E+00, 0.30353800E-01, -.18203600E-01, -.40230200E-01, 0.38791900E-03, -.94976400E-01, -.48303900E-01, 0.15148500E-01, 0.93153500E-02, -.21434000E-02, -.32221500E-01, -.33272800E-01, -.21507700E-01, 0.23071800E-01, 0.58531400E-01, 0.43596400E-01, 0.57964400E-01, -.12151800E-01, 0.43964000E-01, -.11139800E+00, -.26013200E-01, -.87358300E+00, 0.97649500E-01, -.65364800E-03, 0.27616500E-01, 0.76279100E-02, 0.33021100E-01, -.80374500E-02, 0.53743000E-01, 0.40215300E-01, 0.16273900E+00, 0.48870300E-02, -.68193900E-01, 0.16908000E-01, 0.86613800E-02, -.12939400E-02, 0.16121800E-01, -.86763400E-03, 0.78353800E-01, 0.48634400E-01, 0.44145500E-02, 0.13023300E-01, -.10132900E-02 },
        { -.24837000E+01, -.57162100E+00, 0.71328800E+00, 0.15523100E+01, 0.15140400E+01, 0.28518200E+00, 0.95770600E+00, -.23367300E+01, -.10128400E+00, 0.37920400E+00, -.51653000E-01, 0.19959500E+00, 0.37230300E+00, -.16302500E-01, -.45549900E+00, 0.89234700E+01, 0.19969600E+01, 0.12010100E+01, 0.12809600E+01, -.60709400E-02, -.96705100E+00, -.27059100E+00, -.40795100E-01, 0.16473500E+00, -.23559800E+00, -.47671200E-01, -.26888500E+00, 0.23116600E+00, 0.68316400E+00, 0.37191400E-01, -.16182800E+00, -.77053600E-01, -.21810700E+00, 0.18649700E+01, -.10689200E-02, 0.27506900E-01, 0.83079400E-02, -.48503600E-01, -.26047000E-01, 0.86293000E-01, 0.75544100E+00, -.18434600E+00, -.74577300E-02, 0.34753300E-01, 0.17596700E+00, -.15982400E+00, 0.39785000E-01, 0.14018300E-01, 0.55853800E+00, 0.38612000E-01, 0.91361300E-03, 0.88442100E-01, 0.19562300E+00, 0.15084600E+01, 0.25280300E-01, 0.41326000E+00, 0.32201400E+00, 0.18548700E-02, 0.18337000E-01, 0.21289700E+00, -.33824800E-01, 0.29873900E+00, 0.16788900E+00, -.94218200E-01, 0.56167100E-01, -.21013200E+00, -.11341000E+00, 0.25519300E-01, -.24004200E+00, -.32714100E-02, 0.20406500E-01, -.36685400E+00, 0.30008300E+00, 0.39105500E-02, -.23917400E-01, 0.36286400E+00, -.64732500E-01, 0.25428800E+00, 0.12197000E-01, 0.50972400E-02, 0.13055600E-01, -.31076200E-01, 0.57031800E-01, 0.11849000E+00, 0.21571600E-01, -.32374800E-01, 0.10872300E+00, 0.63446400E-01, 0.94544800E-01, 0.31031600E-01, -.39829200E-01, 0.98786200E-03, -.11431900E+00, 0.12189400E-01, 0.44106800E+00, 0.24294900E+00, 0.12554900E+00, -.78232500E-01, 0.17543500E-01, -.91393500E-02, 0.60296500E-01, -.10929100E-01, 0.11609400E-01, -.13850800E+00, 0.80682500E-01, -.15219800E+01, -.26250600E+00, 0.49545800E-01, 0.42796500E-02, -.38520100E-01, -.69130900E-01, 0.94946000E-02, 0.29849300E-01, 0.89168300E-02, 0.47546000E-01, 0.11317400E+00, -.28746800E-01, -.28015900E-01, -.13017400E+00, -.37848000E+00, -.23092700E+00, 0.14767200E-01, -.55512600E-01, 0.48944200E-01, 0.12281700E-01, 0.15470600E-01, -.13639600E+00, 0.72231100E-01, 0.11312800E+00, -.55578500E-01, 0.81653600E-01, -.18368300E-01, -.82765600E-01, 0.40998500E-01, -.29178100E-01, 0.40095000E-02, 0.86415400E-03, -.12653300E+00, -.38872000E-01, 0.40493000E+00, 0.39592300E-01, 0.74280000E-01, 0.16149700E+00, 0.18718100E+00, 0.18168200E-02, 0.10294200E+00, 0.17285100E-01, -.42373400E-01, -.29683500E-01, 0.95468200E-01, -.67541500E+00, 0.12961800E+00, 0.65898900E-02, -.24121800E+00, -.13192500E-01, -.17190000E+00, -.14171600E-01, -.60580800E-04, 0.40121900E+00, 0.41234700E-01, -.97234200E-02, 0.65314300E-01, 0.42678400E-01, 0.14404600E+00, 0.22216200E+00, 0.10079800E+00, -.21733300E-01, -.11206800E+00, 0.64728400E-02, 0.91908000E-03, -.10693900E+00, 0.43882400E-01, -.16529000E-01, -.14310100E-01, -.12581100E+00, -.16619600E-01, 0.39764100E-01, 0.60458600E-02, 0.67092200E-01, 0.13271100E-02, 0.25229100E-01, 0.29352500E-01, -.25719400E+00, -.54424900E-01, 0.53320600E-01, 0.52237600E-01, -.50818700E-01, 0.37483600E-01, 0.64709300E-02, -.39095900E-01, -.51794500E-01, 0.51982800E-01, 0.57607400E-01, 0.35689500E-02, -.56491200E+00, -.18828000E-01, -.19960700E-01, -.40432600E-01, -.22368800E-01, -.90772200E-02, -.33626500E-01, -.20222700E-01, -.20096100E+00, -.34428500E+00, -.25182500E+00, -.26033800E-01, 0.18706200E-01, 0.22263700E+00, -.10272700E+00, -.44645000E-01, 0.78993100E-02, 0.11743100E+00, 0.16741900E-01, 0.76477800E-01, 0.79466200E-01, -.38451800E-01, -.14782200E+00, 0.31953000E+00, -.17763000E-01, -.44942600E-01, -.11547800E+00, 0.64534200E-02, -.24087300E-01, 0.36862700E-02, 0.27069700E+00, -.84807400E-01, -.25481500E-01, 0.33621700E-01, -.23521300E+00, -.18983000E+00, 0.68623200E-01, -.14754200E+00, -.23106300E-02, 0.54308100E-02, 0.18590700E-01, -.63246400E-01, -.10027000E-01, 0.27953400E-01, 0.78760900E+00, 0.10982900E+00, -.11517900E+00, 0.58100300E-01, -.22607200E+00, 0.23560900E-01, 0.16532600E-01, -.28042100E-02, -.51325500E-01, -.21440100E-01, -.32035800E+00, 0.21538000E-01, 0.22798200E-01, 0.62267600E-01, -.92968100E-01, 0.65253000E-01, -.36161400E-03, -.10079300E-01, -.30508400E-03, 0.30242900E-02, 0.10524700E+00, -.18243200E-01, -.50827800E-02, -.74288700E-01, -.97397800E-02, 0.57255800E-03, 0.89379300E-02, -.86926200E-02, -.30472000E-01, -.72814700E-03, -.35635100E-02, 0.81580900E-02, -.73971800E-03, -.17989500E-01, 0.17283900E-01, -.10051400E+00, 0.19647000E-01, 0.92148200E-02, 0.92182500E-01, -.19846300E-01, 0.21693000E-01, 0.86611700E-01, -.56429500E-01, 0.72540300E-03, 0.30114400E+00, 0.87541100E-02, 0.12440900E+01, -.46331300E-01, -.39838500E-01, 0.32358000E-01, -.38426400E-01, -.12921900E+00, -.25599500E-01, 0.13554200E-02, 0.12495200E-02, 0.51229400E-03, 0.14982000E-02, -.55491000E-01, 0.30397700E-01, 0.62546400E-01, 0.36478700E-02, 0.26311400E-03, 0.40674500E-02 },
        { -.44603600E+01, -.12054800E+01, 0.12055700E+01, 0.22490000E+01, 0.14843400E+01, 0.13820000E+01, 0.16083600E+01, -.43732800E+01, -.34307100E+00, -.74113600E+00, 0.93383000E-01, 0.56800600E+00, 0.67111000E+00, -.17848300E+00, -.59578000E+00, 0.82102600E+01, 0.57973200E+00, 0.89387500E+00, 0.20927700E+01, -.25392800E+00, -.10914000E+01, -.18223700E+00, 0.36946400E-01, 0.56875600E+00, -.16703200E+00, -.57880500E-01, -.24444100E+00, 0.26540600E+00, 0.73596200E-01, 0.41753900E-01, -.39818600E+00, -.10408200E+00, 0.79966200E-02, 0.68761600E+00, -.69320800E-02, -.34598700E-01, 0.47711500E-01, 0.37477500E+00, -.93517700E-01, -.44176900E-01, 0.23888500E+01, 0.58960300E-01, -.34020600E-01, 0.12380100E+00, -.15321600E+00, -.16953800E+00, 0.43879600E-01, 0.25904000E-02, -.15605500E+01, 0.92867400E-01, -.42826100E+00, 0.46653800E+00, 0.17886700E+00, 0.91743900E+00, 0.59625700E-01, 0.13770500E+01, 0.68285800E+00, -.75284900E-01, 0.21560200E-02, 0.43885500E-01, -.11747700E-01, -.14335800E-01, 0.17515500E+00, -.23841800E+00, 0.88348900E-01, -.31623500E+00, 0.26750000E+00, 0.16481800E+00, -.85766500E-01, -.29169800E-02, -.35949600E-01, 0.20451100E+01, 0.55887400E-01, -.43234400E+00, -.53979600E+00, -.75518800E+00, -.23698500E-01, 0.95623500E-01, -.52913700E+00, -.70808100E-01, -.20765100E-01, 0.74442600E-01, 0.25571500E-01, 0.25513600E+00, -.13983400E+00, -.17032300E+00, -.48586900E-01, 0.17853900E+00, -.85560200E-01, 0.54828700E-01, -.79245400E+00, -.13230400E-02, 0.17061800E+00, 0.24883000E-01, 0.59146400E+00, 0.24255600E+00, 0.14304800E+00, -.20250100E+00, -.15624500E-02, -.14178100E+00, 0.49970400E-01, -.44868100E-02, 0.26096600E-02, -.87064600E-01, 0.64287100E-01, 0.35953300E+01, -.21213900E+00, 0.19384900E+00, 0.41905300E-01, -.27415600E+00, -.14342100E+00, 0.12552500E-01, 0.73081800E+00, -.16266600E-01, -.13027100E+00, -.44488500E+00, -.13476300E+00, 0.28256800E+00, -.55484000E+00, -.58599500E+00, -.64126500E+00, 0.15373600E-01, -.63813400E-01, 0.13583100E-01, -.40484600E-02, 0.23592500E+00, 0.41978000E+00, 0.13328200E+00, -.13514200E+00, -.99949200E-01, 0.62943300E-01, 0.90828000E-01, 0.25267100E+00, -.34892500E+00, 0.11634100E+00, 0.17865900E-01, -.13260700E+00, -.73831900E-01, -.22316300E-01, -.73593800E+00, -.19044800E-01, 0.31007700E-01, -.73253800E-02, -.19133000E+00, -.80850700E-01, -.43144100E+00, -.70942600E-01, -.43212900E-01, -.38910900E-01, 0.71118900E+00, 0.63024000E+00, 0.34469600E+00, 0.22174000E+00, 0.30592500E-01, -.57419700E-01, -.13046700E+00, 0.35729100E-02, -.12376000E-02, 0.13312200E-01, -.10809400E+00, 0.18735000E-01, 0.55119400E-01, -.37969100E-01, 0.19843800E+00, -.41854000E-01, -.12443900E+00, -.17097300E-01, -.15070600E+00, 0.53709900E-02, 0.26261400E+00, -.14833400E+00, 0.74730300E-01, -.37857900E-01, 0.42616700E-01, -.70637900E-01, -.95602100E-01, -.64290200E-03, 0.24962300E-01, -.38762900E-01, 0.45639400E-01, -.71533100E-01, -.10209900E+00, -.60974400E+00, -.18624800E+00, 0.14782500E+00, -.15667300E+00, 0.12859300E+00, -.15399300E-01, 0.41329800E-02, 0.14374100E+00, 0.62302600E-01, 0.34236200E-01, 0.17718000E-01, -.28379300E+00, -.32522500E+00, -.93565600E-01, 0.52487900E+00, 0.82793100E-01, 0.66157700E-01, 0.28201900E-02, 0.18737100E-01, 0.81966300E-01, 0.12923200E+00, 0.37398500E-01, -.16977500E+00, 0.44278000E-01, 0.46862900E-01, -.25571600E+00, 0.46948700E-01, 0.16911100E-01, 0.12556000E-01, 0.11018600E+00, 0.33615300E-01, -.55767000E+00, -.15638000E+00, -.23159100E+00, -.22119000E+00, 0.40254800E+00, -.28174700E-01, 0.25218700E-01, -.49724600E+00, 0.41658300E-01, -.56337700E-02, 0.79782600E-05, 0.35180700E-01, 0.13060100E+00, 0.11984400E+00, -.32344000E-01, 0.10059500E+00, 0.32617600E+00, 0.54654200E+00, -.22047200E+00, -.38234100E-02, 0.11667900E+00, -.90132400E-02, 0.23352200E-01, -.13031800E-02, 0.31637800E-02, 0.50192100E+00, 0.29576700E+00, -.10657000E+00, 0.14390200E+00, -.16574700E+00, 0.70580900E-02, 0.20476000E-01, -.76271800E-02, 0.24630600E-01, -.37498300E-02, -.21517300E+00, 0.92764700E-02, 0.30395700E-01, -.83689900E-01, -.10783900E+00, 0.37135300E-01, -.22900400E-02, -.43237300E-02, -.36338500E-03, -.85944300E-01, 0.51295100E-01, -.22962200E-01, 0.11978400E+00, -.12866800E+00, -.84426800E-01, 0.86747800E-02, -.30020900E-01, -.19569700E-02, -.89414200E-03, -.85425100E-02, -.80038500E-02, -.77753900E-03, 0.61148300E-02, 0.30844900E-01, -.21853800E-01, -.25338400E+00, 0.39903300E-02, -.28169700E-01, 0.70121700E-01, -.36619300E+00, 0.70627100E+00, 0.11766500E+01, -.12625300E+01, -.83358800E-01, 0.26267000E+00, 0.10237800E+00, -.16541900E+01, -.40743900E+00, 0.79667300E+00, 0.12747600E+01, -.85996800E+00, -.15884200E+01, -.32268500E+01, -.55829900E-01, 0.12331000E+00, -.88862000E-02, 0.13791400E+00, -.17858900E+00, 0.35824200E+01, 0.20169500E+01, 0.50140900E-01, 0.13151400E+00, -.78978200E-01 },
        { -.24243400E+01, 0.32624200E-01, -.30571200E-01, -.34335300E+00, 0.18643000E+01, -.77375500E-01, -.23088000E+00, 0.36774900E+01, -.39698600E+00, 0.93219400E+00, 0.76294300E+00, -.87581800E-03, 0.86524100E+00, -.88640300E-01, -.15534100E+00, -.25828400E+01, -.15032600E+01, -.21958300E+00, -.55178700E+00, -.47454500E-01, -.72525400E+00, -.48965800E+00, 0.13038200E+00, -.91350400E+00, -.94339400E-01, 0.14372400E-01, 0.13961900E-02, -.10512500E+01, 0.74292700E+00, -.53176000E-01, 0.31903600E+00, 0.17941600E+01, -.72578800E+00, -.69360600E+00, 0.10303800E-01, 0.24988600E+00, -.70260600E-01, -.85682200E+00, -.11574000E+00, 0.29982000E+00, -.14052600E+01, -.68493800E+00, 0.98658200E-01, -.41970800E-01, 0.45473200E+00, -.58334600E+00, 0.76815100E-01, -.14978500E-01, -.33990700E-01, 0.13743300E+00, -.15716400E+00, 0.66232100E+00, -.53666900E+00, 0.90561900E+00, 0.32037900E-01, 0.10846200E+00, 0.98208300E-01, 0.28221700E-01, -.17674600E-01, 0.58413000E+00, 0.28038500E-01, -.33494100E-01, -.31083000E-02, 0.10916500E+00, 0.31353200E+00, 0.56054200E+00, 0.85513800E-01, 0.80949000E-01, -.39054900E+00, -.16682200E-01, -.11642400E+00, -.27884600E+00, -.70647200E-01, 0.24596800E-01, 0.68983100E-01, 0.20154000E+00, 0.72162300E-01, -.28446200E+00, 0.28735500E-02, 0.44123600E-01, -.63884500E-02, 0.21594700E-02, -.10699200E-01, -.28745100E-01, 0.30935700E-01, 0.10158400E+00, -.24051500E-01, 0.32142500E-01, -.12373900E-01, 0.56754700E-01, 0.29040500E-01, 0.87628600E-03, -.18102700E+00, -.79017000E-02, -.31603200E+00, -.33374300E+00, 0.66173700E-01, 0.25349200E+00, -.30978500E-01, -.10614500E+00, 0.36604300E-01, 0.59909200E-01, 0.11292300E-01, -.11525700E+00, 0.91202800E-01, 0.20549600E+00, -.14383600E+00, 0.27898800E+00, -.20835200E-01, -.61844700E-01, 0.24548800E+00, -.21789500E-01, -.10774800E+00, 0.15988500E-01, 0.16047600E+00, 0.10361800E+00, 0.81729000E-01, 0.36446300E-01, -.41482100E+00, 0.23853900E+00, 0.18692800E+00, -.21931200E-01, 0.60322600E-01, -.33763300E-01, -.49122400E-02, 0.81606100E-01, -.41136600E-01, 0.31480100E+00, -.62215500E-01, -.57199400E-01, -.10951400E+00, -.10246000E+00, -.30004100E-01, 0.16535400E-01, -.36084700E-01, -.87513100E-02, 0.89814500E-01, 0.17749500E-02, 0.23722200E-01, -.48771000E-01, -.31591200E+00, -.16494700E+00, 0.33134900E+00, -.11921500E+00, -.16361100E-01, 0.17869500E-01, -.79702500E-03, -.86352000E-01, 0.18901300E-01, 0.71275300E-01, 0.76829700E+00, 0.36656600E-01, 0.23129800E-01, 0.31812100E+00, -.53003700E-02, -.74047600E-01, -.16531500E-01, 0.60159200E-05, 0.12918700E+00, -.71195900E-01, 0.31637200E-01, -.21606800E-01, 0.70591200E-01, -.44319100E-01, -.10053500E+00, -.95082800E-01, -.21928000E-01, 0.68238800E-01, 0.84925600E-02, -.38274400E+00, 0.57639100E-01, 0.41970500E-01, -.85264700E-01, -.36127100E-01, -.14302400E+00, 0.18827700E-01, 0.66037600E-01, -.11935500E-01, 0.11562600E+00, -.33501300E-01, 0.55579400E-01, 0.45631600E-01, -.89588300E-01, -.17944900E+00, 0.48783000E-01, -.80278200E-01, -.63829200E-01, 0.47761800E-01, 0.12989400E-01, -.12912300E+00, 0.66294200E+00, -.53565000E-01, 0.71405700E-01, 0.40217300E-01, 0.66625500E+00, 0.11425800E+00, -.12627500E+00, 0.15418800E+00, 0.29400200E-01, 0.72986000E-01, -.38730000E-01, -.74586600E-02, -.45290100E+00, 0.72686100E-01, -.21903400E+00, -.68966900E-01, 0.49856800E-01, 0.86084700E-01, 0.27167600E-01, 0.91770500E-02, -.18559400E-02, -.14024100E+00, 0.10560300E-01, -.11343700E+00, -.65836400E+00, 0.17431900E+00, 0.48437800E+00, -.75673900E-01, -.21178400E+00, 0.30397200E+00, 0.54296600E+00, 0.53347700E-01, 0.10674800E-01, -.19761200E-01, -.98276600E-01, 0.61272900E+00, 0.48692900E+00, -.18185600E-01, 0.87649000E+00, -.47051000E+00, 0.26712000E+00, -.21396600E+00, -.61048800E-03, 0.61918800E-01, 0.10992000E+00, -.12850100E+00, 0.74364400E-01, 0.59503000E-01, -.30066900E+00, -.43243600E+00, -.10451700E+00, -.19716000E-01, 0.98068500E-01, -.64786300E-02, -.26772000E-01, 0.52230700E-03, -.92113100E-01, 0.29884200E-01, -.10086300E+00, 0.14157700E-01, 0.77328800E-02, -.13363400E+00, 0.12184300E+00, -.84717700E-01, 0.24219200E-02, -.42983700E-01, -.21696300E-02, 0.49833600E-01, 0.34821300E+00, -.45247500E-01, -.28881400E+00, 0.22880000E-01, 0.20371800E+00, -.12523000E+00, -.55536200E-01, 0.10174200E-01, -.58252700E-02, 0.62507300E-02, -.42493300E-01, -.73089700E-01, -.46130500E-01, 0.94491800E-01, 0.54443500E-01, 0.72586400E+00, -.69523500E-02, 0.78477400E-02, 0.11508100E+00, -.11617400E+00, -.19541800E+01, 0.44892200E-01, -.28419100E+00, -.27656300E-01, 0.14971200E+00, 0.17755700E-01, 0.20375300E+00, 0.18053800E-03, 0.25504800E+00, -.74591700E-01, -.42814300E-01, -.32236100E-01, 0.80822700E-01, 0.96383900E+00, 0.61072500E-01, 0.17678300E+00, -.17931700E-01, 0.52528800E-01, 0.53733400E-02, 0.22784400E-01, 0.55892000E-01, 0.58784900E-01, 0.28651100E-01 },
        { -.20865000E+01, -.41915100E+00, 0.72467900E+00, 0.94500000E+00, 0.10223000E+01, 0.41142700E+00, 0.77623800E+00, -.24689600E+01, -.23641600E-02, -.71242400E+00, -.20052900E+00, 0.26765800E+00, 0.27230900E-01, -.15708600E+00, 0.57154900E-01, 0.80241500E+00, -.17557400E+01, -.88059400E+00, 0.58867000E+00, -.80148800E-01, 0.19054600E+00, 0.11737600E+00, 0.80613600E-01, 0.48843200E+00, 0.18909800E-02, -.13347200E-01, -.11922600E+00, 0.29743200E+00, 0.57419300E+00, -.26269200E-01, -.31230300E+00, 0.21504000E+00, -.74383300E-01, -.17477900E+01, -.11863000E-01, -.74848700E-01, 0.25696300E-02, 0.38018300E+00, -.75966200E-01, 0.23398900E+00, 0.72719000E-01, -.15741800E+00, -.28387600E-01, -.94091800E-03, -.63273800E-01, -.12031000E+00, 0.18208900E-01, -.12165300E-01, -.30610400E+00, 0.31372300E-01, -.19832400E+00, 0.26874000E+00, -.21766600E+00, 0.37881400E+00, 0.41639200E-01, 0.39360400E-01, 0.53627600E-01, 0.11420000E-01, -.15604800E-01, 0.10270200E+00, 0.11118200E-01, 0.66381300E-02, -.53963500E-01, -.13414000E+00, -.28650600E+00, 0.67616200E-01, 0.32250200E+00, 0.62026800E-01, -.29062400E+00, -.65712300E-02, -.13012600E-01, -.56650000E+00, -.69725700E-01, -.44395900E+00, 0.19404300E+00, -.50088200E-01, 0.17900900E-01, -.86089200E-01, 0.74558600E-01, -.54236700E-01, -.74913700E-02, 0.88392700E-02, 0.58737800E-01, 0.18595900E+00, -.48058900E-01, -.96258300E-01, -.46563100E-01, -.18716100E-01, 0.22649100E-01, 0.37011800E-02, 0.86676000E-01, 0.50152900E-03, -.44625300E-01, 0.16981700E-02, -.65431300E-01, 0.32512200E-01, -.11139600E+00, -.30043300E-01, 0.17881300E-01, 0.52804500E-01, -.93897100E-02, -.38653100E-01, 0.13618000E-02, -.14126000E+00, 0.42402000E-01, -.28964900E+00, 0.65382000E-01, 0.97555300E-01, 0.44942600E-01, -.51694300E-01, -.95535000E-01, -.14257500E-02, -.19802800E-01, 0.88055500E-02, -.23529400E-01, -.86242700E-01, -.14208700E-01, 0.65957200E-01, 0.23969400E-01, 0.14119300E+00, 0.54743700E-01, 0.33132900E-02, 0.29963700E-01, 0.12891700E-01, 0.44147300E-02, -.54258600E-01, -.55022900E-01, -.43346700E+00, -.40037100E-01, -.29356500E-01, 0.20165200E+00, -.11898500E+00, -.92025100E-01, 0.11568800E+00, -.30820700E-01, -.50944600E-02, 0.16370700E+00, -.31559100E-01, -.21954700E-01, 0.19598800E+00, -.14048000E+00, 0.28963900E-02, 0.19560700E-01, 0.23963800E-01, 0.13931300E-01, 0.90731300E-01, 0.20294000E-01, 0.61811600E-01, 0.75368700E-02, -.22322600E+00, 0.62776100E+00, 0.10022300E+00, -.45735700E-01, 0.93449500E-01, -.10409500E-01, 0.23889400E-01, 0.19969500E-01, -.57533800E-03, 0.12797900E+00, 0.40865000E-01, -.29366900E-01, -.57521200E-01, 0.15996600E-01, -.29344400E-01, 0.10398300E+00, -.81505700E-02, 0.34203000E-02, 0.93595500E-01, -.67503900E-03, 0.28152400E-01, 0.44082800E-01, -.26746000E-01, 0.28387500E-01, -.28202100E-01, 0.44509600E-02, 0.14886500E-01, -.34930300E-01, -.63106600E-02, 0.16818600E-01, -.55431900E-01, 0.29031200E-01, -.60510000E-01, 0.34914100E+00, 0.25431900E-01, -.76814400E-02, 0.10723500E-01, -.27243100E-01, 0.11595000E+00, -.16228900E-01, -.68021500E-02, -.22787300E+00, -.70387600E-02, -.20784500E-02, 0.24857000E-01, -.11891900E+00, -.14482100E-01, -.80870500E-03, -.35510700E-01, -.15394900E+00, -.16933800E-02, -.38920800E-02, -.39156500E-01, 0.13439200E+00, -.74126000E-01, -.28208400E-01, -.36373000E-01, -.10116000E-02, 0.46975000E-01, -.21881800E-01, 0.51145700E-02, -.17413900E-02, 0.12654800E-01, -.61710000E-02, 0.23091300E+00, 0.25737100E+00, 0.72723200E-01, 0.23323800E+00, -.14009000E+00, 0.34642900E-01, -.40517300E-01, -.12654000E+00, -.11580800E-01, 0.10386200E-01, 0.15274800E-02, -.10912100E-02, -.14864500E+00, -.47838900E-01, -.43368000E-02, -.13703800E+00, -.36129600E+00, -.11618200E+00, 0.53014100E-02, 0.19086100E-02, -.24157200E-01, -.56621300E-01, -.24699700E-01, -.23496100E-01, 0.34330000E-01, 0.32730200E+00, -.22490100E+00, -.11709200E+00, 0.24551800E-01, 0.16806400E-01, -.29096300E-02, 0.22606500E-02, -.54968200E-02, 0.46694800E-02, 0.83927600E-02, 0.26475300E-01, -.16894200E-02, 0.32379400E-02, -.65020700E-01, 0.31080500E-01, -.15614700E+00, -.65868000E-02, -.30824100E-01, -.18018700E-02, -.11347000E+00, -.15970100E+00, 0.45442300E-01, 0.67714100E-01, -.91000400E-01, -.55450300E-01, -.18552700E-01, 0.41506500E-01, -.64022100E-04, 0.13837400E-02, 0.46808400E-02, 0.10058800E-03, 0.93419500E-02, -.44844600E-02, -.28873700E-01, 0.15016000E-01, -.52002100E-01, -.12913500E-02, -.44446800E-02, 0.48352400E-01, -.79821600E-01, 0.78008200E-01, 0.10602100E+00, -.81862000E-01, 0.15787100E-01, -.10725000E+00, -.28548600E-01, -.50969000E+00, -.49411100E-01, -.71372300E-01, -.18183500E+00, 0.65564400E-01, 0.11246800E+00, -.45183900E-01, -.11653700E-01, -.26873600E+00, -.15021600E-01, -.29577100E-01, -.81476400E-01, -.12221300E-01, 0.26168200E-01, -.26154800E-01, -.34435400E+00, 0.25503200E-02 },
        { 0.69620000E+00, 0.88838000E+00, -.19675000E+00, -.84742100E-01, -.19779100E+00, 0.35592100E-01, 0.14100500E+00, 0.20412900E+00, 0.64482000E-01, 0.10215300E+00, 0.11284800E+00, 0.21593900E-01, 0.73689000E-01, 0.10566000E-01, 0.55809000E-01, 0.12837600E+01, 0.86170300E+00, 0.38519500E+00, 0.23831600E+00, -.43086300E-01, -.32902800E+00, -.15200500E+00, 0.13179800E-01, 0.34244900E+00, -.21205400E-01, 0.63221200E-02, 0.21530100E+00, 0.53069300E+00, -.45394900E+00, -.13240300E-01, 0.12464600E+00, 0.38662900E+00, -.83983400E-01, -.24324000E+00, -.25846500E-01, 0.21655100E-01, -.11294400E-01, -.22994100E+00, -.10990700E-01, -.10325500E+00, 0.44045500E+00, -.17574500E-01, 0.22609700E-01, 0.41547500E-01, 0.12370200E-01, 0.27701900E-01, -.61233500E-02, -.44686200E-02, 0.12349900E+00, 0.76480800E-01, -.73410900E-01, 0.15474300E+00, 0.22535700E-01, 0.21063100E+00, 0.85703400E-02, 0.16453500E+00, 0.88135200E-01, -.25769600E-01, -.17640300E-02, 0.16731900E-01, 0.17206100E-01, -.85429300E-01, 0.99536600E-01, -.30830400E-01, 0.58162200E-01, 0.40110900E-01, -.67939500E-01, 0.34606700E-01, -.11195200E-01, -.70385200E-02, -.43785000E-01, 0.34808500E+00, 0.10589400E+00, 0.14661500E+00, -.11498900E+00, 0.76908700E-01, -.22234800E-01, -.91458400E-01, -.88366400E-01, 0.11763000E-01, 0.10291200E-01, 0.22000300E-03, -.86499400E-01, -.69730500E-01, 0.84516400E-02, 0.36597300E-01, -.13159300E-01, 0.25355000E-01, 0.43844000E-01, 0.14694300E-01, -.63019100E-01, 0.80740200E-03, 0.22891800E-01, 0.37322200E-02, -.19723800E-01, 0.10876600E+00, 0.37167200E-01, -.13233300E-01, 0.99040700E-04, 0.67497600E-02, 0.10712700E-01, -.72422900E-02, -.19170600E-02, -.19766200E-01, 0.26470800E-01, 0.11243900E+00, -.63406700E-01, 0.39550000E-01, 0.18653000E-02, 0.38592800E-01, 0.17228100E-01, -.25175900E-02, 0.46389300E-01, 0.30408200E-04, 0.37114000E-01, 0.68221100E-01, -.11855500E-01, -.35973500E-01, 0.18351700E-01, -.12079300E+00, 0.25764000E-01, -.67043700E-02, -.18932300E-01, -.93817600E-02, -.60294200E-02, 0.10685700E-02, 0.30264400E-01, 0.16478100E+00, 0.11673100E-02, -.63704800E-02, -.71282800E-01, -.18501400E-01, -.38504900E-01, 0.32118000E-01, -.35824600E-01, -.47671400E-02, 0.54945100E-01, 0.97878700E-01, -.32768600E-01, 0.83529800E-01, 0.27059700E-01, -.70744200E-01, -.32313900E-01, 0.22000700E-01, 0.22923100E-02, -.12989400E-01, -.10271000E-03, 0.61434300E-02, -.71830500E-05, 0.26140500E-01, 0.37554300E-02, 0.68011700E-02, 0.65733100E-02, -.11846300E+00, 0.84903900E-03, 0.19039300E-01, -.18493600E-01, -.15172300E-03, -.42824000E-01, -.71702500E-02, 0.15057300E-01, 0.34319100E-01, -.55219600E-02, 0.10539300E-01, 0.49839000E-03, 0.11392700E-01, -.62381400E-02, -.18806300E+00, 0.82045500E-03, -.68093600E-01, -.31617400E-02, -.16831300E-03, -.41087200E-01, 0.35488800E-01, 0.39259900E-01, -.12949900E-01, -.21624200E-01, 0.21689100E-03, -.21977400E-01, -.91554300E-02, -.27379800E-01, -.40667500E-01, -.88104200E-02, 0.81123900E-02, 0.13255100E-01, -.54862800E-04, 0.30509400E-02, -.18121400E-01, 0.13399100E-01, 0.36225400E-01, 0.92703700E-01, -.25905000E-01, 0.17459200E-01, -.47416500E-01, 0.31219000E+00, 0.12629000E-01, 0.11354100E+00, 0.44580400E-01, 0.27577100E-01, 0.15875100E-01, 0.19220000E-01, 0.60639100E-02, -.29040400E-01, 0.11792200E+00, 0.15560300E-01, 0.11410500E-01, -.95057700E-02, -.14647700E-01, -.17399800E-01, 0.15927600E-01, -.26639200E-04, 0.13698600E-01, -.24866600E-02, -.12214500E-01, 0.30177000E-01, -.14991000E-01, -.28150900E-02, -.34143400E-01, 0.24180800E-01, -.21379200E-01, -.77433600E-01, -.94380100E-02, -.10575300E-01, 0.23102100E-02, 0.35529600E-01, -.41838300E-01, 0.18911500E-02, -.10401700E-01, -.35956400E-01, 0.44079400E-01, -.20336400E-01, 0.31822900E-01, 0.69098100E-03, -.59593300E-02, -.14610400E-01, 0.42717900E-02, -.36410700E-02, 0.45494800E-02, 0.15473100E+00, 0.52484500E-01, 0.21252200E-01, 0.10618100E-02, 0.12567400E-01, 0.10487900E-03, -.60608200E-03, 0.56678600E-03, 0.15284000E-01, -.93689800E-03, 0.61427400E-01, -.37465400E-02, -.62689300E-02, 0.72786500E-01, -.31584500E-02, 0.19699800E-01, 0.15848100E-02, 0.78062700E-02, 0.31559300E-03, 0.21467400E-01, -.26468500E-01, 0.18743200E-02, 0.36977800E-01, -.83565700E-03, -.30730700E-01, 0.18145200E-01, 0.48270800E-02, 0.17305400E-02, 0.35141800E-02, -.93918100E-04, 0.48027100E-02, 0.11572400E-01, 0.57937800E-02, -.25871200E-02, -.69356000E-02, -.13959700E+00, 0.36441200E-02, 0.17888500E-02, 0.10592600E-01, -.57312000E-02, 0.55644200E+00, 0.63879700E-01, -.69398400E-02, -.17187300E-02, 0.93057200E-02, 0.22162500E-02, -.67444000E-01, -.11440400E-01, 0.54591600E-01, -.43126700E-02, -.50468600E-01, -.36938000E-01, 0.25625000E-01, -.86511300E-02, 0.22637900E-01, 0.11236600E+00, -.11672100E-01, 0.68991400E-02, 0.27157600E-03, 0.98320800E-02, 0.15345400E-02, 0.16747800E-02, 0.66610300E-03 },
        { 0.93183000E+00, -.30865700E+00, 0.31549800E+00, 0.19151300E+00, -.43871200E-01, -.25589300E+00, 0.15301300E+00, 0.93581300E-01, 0.10324700E+00, -.45317800E+00, -.77980600E-01, -.94286500E-01, -.17074000E+00, 0.14779700E+00, -.15273700E+00, 0.11606100E+01, 0.13149900E+01, 0.40409100E+00, -.11206600E+00, 0.83030600E-01, 0.27936700E+00, 0.18335800E+00, -.58636300E-02, 0.79949600E-01, 0.68304400E-01, 0.35370200E-01, -.45593200E-01, 0.17481900E+00, 0.17013900E+00, 0.40816300E-01, -.13362200E+00, -.45684500E+00, 0.23478400E+00, 0.95036100E+00, 0.14589200E-01, 0.63204700E-02, -.25698200E-01, -.70418400E-01, -.31843400E-01, -.92511200E-01, -.72721400E+00, 0.23115100E+00, 0.12651600E-01, 0.47426800E-01, -.86392600E-02, 0.10540600E+00, 0.30510000E-02, -.51942600E-02, 0.94224100E-01, -.23538300E-01, 0.91218800E-01, -.34948700E+00, -.14992100E-01, -.45774500E+00, 0.11766700E-01, 0.20228400E+00, 0.16991200E+00, 0.82822600E-01, 0.61858700E-02, 0.16093800E+00, -.64871600E-01, 0.23626000E+00, -.32991800E-01, 0.24342300E-01, -.15499900E+00, -.88744100E-01, -.26519000E+00, -.53675400E-01, -.25123400E+00, -.20668400E-03, 0.99760600E-02, -.60029600E+00, 0.30208900E-01, 0.45645000E-01, 0.13359400E+00, 0.36986100E+00, 0.16343700E-01, 0.15665600E+00, 0.12335000E+00, -.65447100E-02, 0.75576200E-03, -.44635900E-02, 0.52216400E-01, -.57119800E-01, 0.72147700E-02, 0.93819900E-02, 0.80556200E-01, -.10209000E-01, 0.45588700E-01, -.39157400E-01, 0.11509200E+00, -.25893400E-03, -.72875800E-01, 0.27126500E-01, -.56553500E-01, 0.19036100E+00, -.11507600E+00, 0.86039500E-01, 0.23926800E-01, 0.12766500E+00, -.39373100E-01, -.12364000E-01, -.59964400E-03, -.73383400E-01, -.61883500E-02, -.12204800E+01, 0.11119500E+00, -.48150600E-01, -.10708400E-01, 0.23530000E-01, -.30038500E-01, 0.48044200E-02, -.13805600E+00, 0.33646800E-02, 0.21563300E-01, -.40584300E-01, 0.12096800E-01, -.51477200E-01, 0.36748300E+00, 0.10171300E+00, 0.27544900E-01, 0.88750600E-02, 0.38301900E-01, -.68549700E-01, 0.18651500E-01, -.25663700E+00, 0.56380000E-01, 0.40469700E-01, -.71833800E-01, -.36521100E-01, 0.49380900E-01, -.69607800E-01, -.28764800E+00, 0.16704100E+00, 0.68698300E-02, -.38752000E-02, 0.17502000E+00, 0.38929200E-01, -.28010100E-01, -.16460500E+00, -.13565700E+00, -.10312900E-02, -.33176400E-02, 0.12511800E+00, 0.32456700E-02, 0.41738800E-01, 0.17464400E-01, -.13934700E+00, 0.14056900E-01, -.47533000E-03, 0.38263200E+00, 0.13966400E+00, 0.23681400E-01, -.44906000E-01, -.47719800E-01, 0.13255000E+00, -.22900800E-01, -.19800000E-02, -.31800600E+00, -.66890000E-01, 0.21449500E-01, -.25853900E-01, -.77347800E-02, -.62570800E-01, -.16935700E+00, -.63827000E-01, -.14597200E-01, -.70226800E-01, 0.29600100E-02, -.11460600E+00, 0.51479800E-01, -.30153600E-01, -.33755800E-01, 0.36834700E-01, -.41703900E-02, 0.27916700E-01, 0.38757000E-01, -.42423900E-02, 0.70286900E-01, -.89566900E-02, -.26142100E-01, -.19249800E-01, 0.58796700E-01, -.73123800E-01, -.22992900E-01, -.26557600E-01, -.67590600E-01, 0.91848500E-01, -.33515400E-02, -.41695600E-02, 0.27031100E-01, -.46196400E-01, 0.17654700E-01, 0.44574500E-01, 0.10697500E+00, 0.10947500E+00, 0.42587700E-01, -.62312700E-01, -.67602900E-01, -.18786600E-02, -.48073100E-02, -.37293200E-01, 0.26703300E-01, -.10839800E+00, -.34623300E-01, -.27376800E-01, -.96541700E-02, 0.77304100E-01, 0.25144000E-01, -.12201100E-01, -.21313700E-02, -.24172100E-01, -.58150900E-02, 0.13192900E+00, 0.18355200E-01, 0.47003400E-01, 0.99233800E-01, -.14484700E-01, -.19488400E-01, 0.27963600E-01, -.14383700E+00, 0.91937400E-02, 0.19423900E-01, -.78117700E-03, -.31570700E-01, -.19653600E-01, 0.22290300E-01, 0.24188600E-01, 0.18351200E-01, -.14901600E+00, 0.14200500E+00, -.11832900E+00, 0.20938400E-03, 0.19780400E-01, 0.16739800E+00, 0.68288500E-01, 0.15403400E-01, -.30107100E-03, 0.49158300E+00, -.14532300E+00, -.10285300E+00, 0.49117600E-01, 0.21357300E-01, -.20961600E-02, -.21593000E-01, -.44515500E-02, -.11980500E-01, -.15572500E-01, -.37229100E-01, 0.36385500E-02, 0.13842400E-01, -.26197000E-01, -.35713200E-01, -.17196600E-01, -.24529900E-02, -.10697200E-01, 0.11519800E-02, -.10905500E+00, -.42740900E-01, -.87415100E-02, 0.38618700E-01, -.93013200E-01, -.57666500E-01, -.40862400E-01, -.51457200E-01, 0.96124700E-02, 0.50222500E-02, 0.60870600E-02, -.21196300E-01, -.26767800E-01, -.12289400E-02, -.43193300E-01, 0.36139700E-01, 0.32646700E-02, 0.15681300E-01, -.20151000E-01, 0.23910700E-01, -.15389400E+00, -.30350600E-01, -.27234000E+00, 0.59117000E+00, -.71700900E-02, 0.52379300E-02, -.22136000E-02, -.23491300E-01, 0.94749700E-02, -.63339900E-01, 0.74086100E-02, 0.45523100E-01, -.35864100E-01, 0.34701800E-01, -.75360200E-02, -.64784300E-01, -.10567800E+00, 0.11687600E+00, -.68892000E-02, -.44488500E-02, -.37554800E-01, 0.26028300E-02, -.31171300E-02, -.64994100E-02 },
        { -.38979200E+01, -.87528800E+00, 0.79022600E+00, 0.15990500E+01, 0.15664500E+01, 0.92299300E+00, 0.16078900E+01, -.35244200E+01, -.22770300E+00, -.69763500E+00, 0.13585100E+00, 0.55473700E+00, 0.59272700E+00, -.24918900E+00, -.46844500E+00, 0.64681700E+01, 0.31751400E-01, 0.50174700E+00, 0.17014300E+01, -.23671800E+00, -.10074900E+01, -.61458600E-01, 0.45993500E-01, 0.62869400E+00, -.14736800E+00, -.68528700E-01, -.21532000E+00, 0.15064600E+00, 0.37625400E+00, 0.17989300E-01, -.37095500E+00, 0.60635100E-01, -.60653600E-01, -.38253100E+00, 0.24502900E-03, -.63129100E-01, 0.25662200E-01, 0.46780600E+00, -.58324400E-01, -.58965400E-01, 0.93256300E+00, 0.33861700E-01, 0.16561900E-01, 0.55616000E-01, -.11472600E+00, 0.93697600E-02, 0.48800500E-02, -.80356300E-02, -.13313000E+01, 0.65669300E-01, -.18112400E+00, 0.14749000E+00, 0.13686200E+00, 0.22943700E+00, 0.24953600E-01, 0.54085400E+00, 0.20825100E+00, -.14156600E-01, -.10067500E-01, -.10638200E-01, -.40508900E-01, 0.29221600E+00, -.23097800E-01, -.33386400E+00, -.41855800E+00, -.14670900E+00, 0.36144500E+00, 0.97126000E-01, -.26823500E+00, -.15342500E-02, -.19853700E-01, 0.24695600E+00, -.12019700E+00, -.57065500E+00, -.15993700E+00, -.35977900E+00, 0.41466500E-01, -.74348000E-01, -.19238500E+00, -.62210500E-01, -.19732800E-01, 0.28619900E-01, 0.12462900E+00, 0.28134600E+00, -.92987200E-01, -.13796800E+00, -.46990500E-01, 0.65858700E-01, 0.34598000E-02, 0.44438500E-01, -.23242700E+00, 0.44127600E-03, -.10009300E-01, 0.21525200E-01, 0.19814600E+00, 0.16931400E+00, 0.30080000E-01, -.12413300E+00, 0.26543000E-01, -.39231400E-01, 0.36256400E-01, -.84061600E-01, -.44066800E-02, -.10142500E+00, 0.12119100E+00, 0.87820300E+00, -.15741600E+00, 0.84670500E-01, 0.94843300E-01, 0.13067500E+00, -.71326100E-01, -.82022300E-03, 0.21263100E+00, 0.82131700E-02, 0.11766300E+00, -.21242500E+00, -.33339100E-01, 0.86617500E-01, -.49107600E+00, 0.21615100E+00, -.21085800E+00, 0.21659500E-01, 0.32651000E-01, 0.14905200E-01, 0.17384400E-01, 0.37709000E-01, -.48651200E-01, -.63762200E+00, -.11038100E+00, -.74665100E-01, 0.18430100E+00, -.81614900E-01, 0.42352100E-01, 0.69416300E-01, 0.50652300E-01, 0.16963200E-02, -.23648000E-01, -.15942500E+00, 0.10886800E-01, 0.75291700E-01, -.22328200E+00, -.22162200E-01, 0.79912900E-01, -.26959300E-01, -.91864100E-02, -.14044200E+00, -.72343600E-02, 0.11112300E+00, 0.26870400E-01, -.19068100E-01, 0.11063100E+01, 0.14674000E+00, -.55762200E-01, 0.31262600E+00, -.28261100E-01, 0.79370200E-02, -.42373100E-02, -.94186200E-03, 0.40526500E+00, 0.12876600E+00, -.19068000E-01, -.66144700E-01, 0.27247400E-02, -.15443400E-01, 0.14108500E+00, 0.39076400E-01, 0.39040400E-03, 0.19679800E+00, 0.43803700E-03, 0.19093200E+00, -.43722900E-01, 0.13008400E-02, 0.11464500E-01, -.11427600E-01, -.34222500E-01, -.21886200E-01, -.35886100E-01, 0.16885300E-03, 0.40647600E-01, -.21428700E-01, 0.10844300E+00, -.46056300E-02, 0.16276900E+00, 0.11826500E-01, 0.59898300E-02, 0.81704700E-01, -.29272000E-01, 0.68761300E-01, -.10039200E-01, -.46315100E-02, -.29982900E+00, 0.11474700E-01, 0.97115700E-02, -.32837300E-02, -.49993200E+00, -.33531200E-01, 0.62710200E-01, -.41098400E-01, -.99011600E-01, -.15971300E-01, -.16944800E-01, -.24299000E-01, 0.58334000E-01, -.76301000E-01, -.33372000E-01, -.40371400E-01, -.79635400E-02, 0.30853200E-01, -.13581200E-02, -.73541000E-02, 0.64792400E-02, 0.55083300E-01, 0.46569600E-02, 0.19541300E+00, 0.21192600E+00, 0.12492700E-01, 0.12736700E+00, 0.36612700E-01, -.49001100E-02, 0.18878300E-02, -.43706900E-01, -.29157600E-02, 0.13420200E-01, -.58655100E-02, -.39547000E-01, -.35352500E-01, 0.22485200E-02, 0.15035800E-01, -.24734900E+00, -.37258800E+00, -.63196600E-01, -.77882400E-01, 0.26728700E-03, -.11044000E-01, -.68923100E-01, -.26166000E-03, -.22879000E-01, 0.48531200E-01, 0.90931800E+00, -.85237000E-01, -.18016700E+00, 0.92492700E-01, -.48792600E-01, -.30953300E-02, -.17607700E-01, -.47648800E-02, -.24798500E-01, -.45838900E-02, -.20683000E+00, 0.54125900E-03, 0.11344000E-01, -.10551100E+00, -.96299300E-02, -.74619300E-01, -.61290700E-02, -.31082700E-01, -.11913100E-02, -.99870300E-01, 0.26372500E-01, 0.12398900E-01, 0.12174200E+00, -.34459800E+00, -.37260800E+00, -.58920100E-02, 0.33781300E-01, -.70415000E-02, -.34743200E-02, -.25592900E-02, -.42438600E-02, 0.18232800E-01, -.12914600E-01, -.22355500E-01, 0.57942400E-02, -.52633100E+00, 0.15319900E-01, 0.59141600E-02, 0.21047700E+00, -.35296800E+00, 0.28389900E+00, 0.39556400E+00, -.42893100E+00, 0.34912100E-01, -.12183300E+00, -.76233600E-01, -.10187100E+01, 0.24916900E-02, -.41584500E+00, 0.16648000E+00, -.19479800E+00, -.36621800E+00, 0.33341700E+00, -.45697900E-01, 0.97980000E+00, 0.58569300E-01, -.13580500E+00, 0.55293100E+00, -.65286900E-02, 0.96173300E-01, 0.45102200E-01, -.12388300E-02, -.37635300E-01 },
        { -.78352700E+00, -.49215600E+00, -.35015000E+00, 0.82395000E+00, 0.10167800E+01, 0.29635300E+00, 0.54372700E+00, 0.12936000E+01, -.47478900E-03, 0.12444000E+01, 0.13669100E+00, -.24278700E-01, 0.11154700E-01, -.25470100E-02, -.42320800E-01, 0.16351900E+01, -.96035200E+00, 0.41691900E+00, 0.59627100E+00, 0.28407500E+00, -.78615000E+00, -.84984600E-01, 0.16088500E-02, -.42596200E-01, -.17048800E-01, 0.31856000E-03, 0.15009200E-01, -.44096200E-02, -.47457100E-01, -.99356500E-03, 0.26662500E-01, -.59135600E-01, -.17985100E-01, 0.65394200E-01, 0.17711400E-03, 0.72275200E-02, 0.90871800E-02, 0.73519900E-01, 0.39358700E-01, -.91462800E-02, 0.39859300E-01, 0.77369200E-01, -.23963700E-02, 0.13955200E-01, -.27562200E-01, -.26183700E-01, 0.70729700E-02, 0.83178700E-03, 0.75333300E-01, -.23797500E-02, -.13739000E+00, 0.62696500E-01, -.95927200E-02, 0.16923400E+00, -.42148200E-01, 0.24876100E+00, 0.83267200E-01, -.97716000E-02, 0.93507900E-02, 0.14554200E-01, 0.32038300E-02, 0.54466900E-01, 0.89317100E-01, -.47871100E-01, 0.28436600E-01, 0.59841600E-02, -.41023300E-01, 0.18617900E-01, 0.54593100E-01, -.50210900E-02, -.54035000E-02, 0.42386500E+00, 0.36883900E+00, 0.46403600E+00, -.80392800E-01, 0.18651100E+00, -.55359400E-01, 0.40998800E-01, -.59131200E-02, -.42603400E-02, 0.26067900E-01, -.17094300E-01, -.25816600E-01, 0.68183400E-02, 0.23573400E-01, -.29956900E-02, -.73699300E-02, 0.30160700E-01, 0.34189600E-01, -.69456300E-02, 0.99935800E-02, 0.13068100E-02, -.65175900E-01, -.12458500E-01, 0.47808000E-01, 0.15453700E+00, -.12564500E-01, -.46956300E-01, -.89897800E-02, 0.77084200E-01, -.15521100E-01, 0.12477900E-01, 0.38428400E-02, -.18883800E-01, 0.10050000E-02, -.36048200E+00, 0.28689400E-01, 0.36226400E-01, -.40992100E-01, -.69345300E-01, 0.36661500E-01, 0.71511600E-02, 0.63047300E-01, -.10251000E-02, -.10772500E+00, 0.15013900E-02, 0.96111500E-02, 0.70554500E-02, 0.12311700E+00, -.45635600E+00, 0.10093900E-01, 0.10979200E-01, -.60154300E-01, 0.96755100E-01, -.11496500E-02, 0.38749900E-01, 0.47475900E-01, -.11978400E+00, 0.90421600E-01, 0.19943400E-01, -.23832200E-01, -.22879600E-01, -.18070700E+00, 0.12385300E+00, -.10245800E-02, -.15339800E-03, -.83984700E-01, 0.11405200E-01, -.54407100E-02, 0.17162400E-02, 0.35783200E-01, 0.30675600E-01, 0.15415000E+00, 0.94025200E-01, 0.97030700E-02, 0.51390400E-01, 0.10823400E-01, -.16198200E+00, -.12004300E-01, 0.95419500E-01, -.79760700E+00, 0.15352000E-01, 0.37598300E-01, -.24412900E-01, 0.18253600E-01, 0.99862700E-01, 0.19313400E-01, 0.13799900E-03, 0.18835900E+00, -.25354400E-02, 0.25294100E-01, 0.15233900E-01, 0.16255400E-01, 0.40248000E-01, -.18537400E+00, 0.53041700E-02, -.19876500E-01, -.26952400E+00, -.39945400E-03, 0.95097600E-02, 0.18146100E-02, 0.15914400E-03, 0.20428100E-02, -.95656700E-02, -.61949500E-01, 0.58227000E-02, 0.35562200E-01, 0.81435700E-03, 0.83957200E-02, -.60995900E-03, -.20460600E-01, -.25514400E-01, 0.66977900E-02, -.31781300E-01, 0.15205700E-01, -.49251700E-01, 0.10126600E-01, 0.42358300E-01, -.13191200E-02, 0.12577600E-01, 0.21924100E-01, 0.51652700E-02, -.62245300E-02, -.17740600E-01, 0.37505700E-01, -.47614200E-02, -.55467500E-02, -.80354700E-02, 0.13625900E-01, -.44090800E-02, -.28499500E-02, -.47847700E-02, 0.66300800E-01, -.47667800E-01, -.70742900E-02, 0.22756100E-01, -.13962700E-01, -.30216100E-01, -.76577700E-02, -.50351300E-02, -.14939300E-02, 0.39533900E-01, 0.51250000E-02, 0.13785300E+00, 0.19484300E-01, 0.12183900E-01, 0.36475300E-01, -.20137700E-01, 0.30136100E-01, -.79365700E-02, -.26234900E+00, -.84390300E-02, -.37941800E-02, 0.16056600E-02, 0.85383600E-01, -.10247600E+00, -.47276700E-03, -.12312300E-01, 0.12530000E-01, 0.18047100E+00, 0.34033400E-01, -.23366000E-01, 0.20275400E-03, 0.16846500E-02, 0.62463800E-01, -.54502400E-02, 0.20868300E-02, -.45881200E-02, -.15181700E+00, -.20581100E+00, -.22255600E+00, 0.27010500E-01, -.11845800E-01, 0.58446800E-02, 0.48715400E-02, 0.72958300E-05, 0.29334400E-02, -.15667700E-01, 0.48779500E-01, 0.70656400E-02, 0.10778600E-01, 0.59930900E-02, 0.17945400E-01, -.28655800E-02, 0.67427600E-03, 0.60541700E-03, 0.44647900E-04, 0.10783000E-01, -.78438300E-02, 0.21778000E-02, -.16527400E-03, 0.56275100E-03, -.12080600E-01, 0.14608900E-02, 0.58115400E-03, 0.20026700E-02, 0.27717800E-02, 0.20883500E-03, 0.11876500E-02, 0.21018300E-02, 0.20148000E-02, -.39698600E-02, -.23208900E-02, -.11523400E-01, -.23033100E-02, -.21574100E-03, 0.42095500E-02, 0.56664500E-03, 0.17530300E-01, -.21443400E-01, 0.10551000E-01, 0.27760600E-03, -.55498600E-03, 0.13040700E-03, -.22353500E-01, 0.15158500E-01, 0.10059500E-01, -.53155100E-01, -.56962700E-02, 0.28645400E-02, -.82852500E-02, -.56755400E-02, -.72345300E-02, 0.21645700E-02, -.36818900E-02, -.76704600E-03, 0.10229100E+00, 0.20005200E-01, 0.25798900E-02, 0.14564300E-02, -.33958900E-03 },
        { 0.14139300E+01, 0.61316700E+00, -.81165200E-01, -.12253300E+01, -.12935300E+01, -.26423300E+00, -.41624300E+00, 0.60142500E+00, -.18695200E-02, -.11694900E+01, 0.37651600E-01, 0.46074000E-02, -.12939600E+00, -.22905800E-01, 0.32473800E+00, -.99986600E+01, -.20000500E+01, -.14039300E+01, -.89075800E+00, -.19687800E+00, 0.11677200E+01, 0.15143100E+00, 0.10262100E+00, 0.13018600E-01, 0.13963300E+00, 0.32646400E-01, 0.38465700E+00, 0.23191100E+00, -.57687400E+00, -.16746400E-01, 0.70929300E-01, 0.14796000E+00, 0.28325500E+00, -.13678100E+01, 0.34642200E-03, 0.19566600E-01, -.90627800E-02, -.20102000E+00, -.19929600E-01, -.25387500E+00, -.81070200E-01, 0.91993800E-01, 0.41038700E-01, 0.43193600E-01, -.19855800E+00, 0.76879000E-01, -.24981100E-01, -.14203500E-01, -.39018900E+00, 0.32787700E-01, -.51902500E-02, 0.40400000E-01, -.21550100E+00, 0.55197200E+00, 0.11122800E+00, -.32267500E+00, -.24362300E+00, 0.31968200E-01, -.27769900E-01, -.32652000E+00, 0.61820300E-01, -.54793200E+00, -.19840200E+00, 0.14807000E+00, 0.21777700E-01, 0.17217600E+00, 0.66962600E-01, -.83223700E-02, 0.19420600E+00, 0.40179800E-02, -.13765700E-01, -.79823200E-01, -.52206700E+00, -.32732200E+00, -.25230300E-01, -.76586000E+00, 0.12403400E+00, -.23268900E+00, -.10662100E+00, -.12419500E-01, -.22171100E-01, 0.53835000E-01, 0.36031200E-01, 0.13631200E+00, -.93856600E-02, -.80854100E-01, -.17439400E+00, -.76984100E-01, -.64341400E-01, -.42685100E-02, 0.74188400E-01, -.91851800E-03, 0.23587400E+00, -.46586300E-01, -.48575400E+00, -.46412800E+00, -.35089000E-01, 0.13339600E+00, -.46858700E-01, -.18228500E+00, -.27644000E-01, 0.43881300E-01, -.63286600E-03, 0.22999500E+00, -.21745200E-01, 0.20752700E+01, 0.13049800E+00, -.12317300E+00, 0.97207800E-01, 0.18902300E+00, -.12319000E+00, -.37388400E-02, -.18372000E+00, 0.10222100E-01, 0.13287400E+00, -.21922300E+00, -.30722500E-01, 0.17362900E+00, -.42826900E+00, 0.11759900E+01, -.84133100E-01, 0.12119500E-02, 0.14335000E+00, -.96680200E-01, 0.12333900E-01, -.74101200E-01, -.96430500E-01, -.41617700E+00, -.10974300E+00, -.51347400E-01, 0.12190700E+00, 0.13553700E+00, 0.46984800E+00, -.44847400E+00, 0.94427500E-01, 0.10187100E-01, -.16086300E+00, -.70474200E-01, 0.51091800E-01, 0.54462600E-02, -.24624200E+00, -.84272800E-01, -.27021600E+00, -.11865100E+00, -.23899600E-01, -.61603500E-02, -.13671100E-01, 0.17869700E+00, 0.76007500E-01, -.56874300E-01, 0.32560900E+01, 0.48109600E-01, -.63501300E-01, 0.35464500E+00, -.11327300E-01, 0.10944400E+00, 0.20066000E-01, -.55492500E-03, -.45606800E+00, -.32208300E-01, -.94353100E-02, -.38896100E-01, 0.34691100E-01, -.13072900E+00, 0.30900000E+00, -.13644400E+00, 0.16778800E-01, 0.34774100E+00, 0.46128600E-02, -.19862200E+00, -.82543100E-02, 0.36505200E-03, -.13848000E-01, 0.17194900E-01, -.29885800E-01, -.13140200E-01, 0.54039100E-01, 0.20884600E-03, 0.48820100E-01, -.15410900E-01, 0.56649700E-02, 0.56107500E-01, -.15226600E-01, -.10915100E-01, -.14677700E-01, -.31132400E-01, -.18101800E-01, 0.13294400E-01, 0.17227000E-02, 0.23409700E-02, -.12231800E+00, -.57077900E-01, -.47403800E-01, 0.14581100E-01, 0.68064700E-01, -.10484700E-01, 0.14123500E+00, -.55676900E-01, 0.99211800E-01, -.99950500E-02, 0.47539400E-01, 0.12405000E-01, -.87866100E-01, 0.36492900E+00, 0.17605500E+00, -.19386600E-01, -.12485600E-01, -.15348500E+00, 0.75077200E-01, -.37931300E-02, 0.49664700E-02, 0.12510300E+00, 0.29612600E-02, 0.21529200E+00, -.63529900E-01, -.52050300E-01, -.17274000E+00, -.18217800E+00, 0.21769900E-01, -.24067600E-01, 0.48830300E-02, -.95186800E-02, -.67359100E-02, -.63335300E-02, -.19797800E+00, 0.25639300E+00, 0.10366700E-01, 0.51484100E-02, -.41999600E-01, -.41848300E+00, -.18016700E+00, 0.11878900E+00, -.12801200E-02, -.16377900E-01, 0.39542100E-02, 0.10756100E+00, 0.53691300E-02, -.11163300E-01, -.16698400E+00, 0.29928700E+00, 0.31125900E+00, -.52273200E-01, 0.32033200E-01, -.12249300E-01, -.51729300E-02, 0.86579800E-02, 0.27194900E-01, 0.47863000E-01, 0.10692000E+00, -.28489600E-01, -.52946600E-01, -.53671400E-01, 0.14209800E+00, -.23130700E+00, 0.26764100E-02, 0.50219600E-02, -.11449000E-02, 0.31204800E-01, -.28201700E+00, 0.51821200E-01, 0.13433400E+00, 0.28498200E-01, -.11309800E+00, -.40669900E-02, 0.12301300E-01, 0.14399500E-01, 0.41032800E-01, 0.16886000E-02, 0.19175000E-01, 0.37529400E-02, 0.39017400E-01, -.12070000E-01, -.41417000E-01, -.37576900E-01, -.46348000E-01, -.13160600E-01, -.10541400E+00, -.45345900E-01, -.16398700E+00, -.25990900E+00, -.45917900E-01, 0.22063300E-01, -.18847200E+00, 0.73826500E-02, -.70600700E+00, -.16828300E+00, -.29131300E+00, 0.67799100E+00, 0.75499300E-01, -.14748600E+00, 0.58861200E-02, -.18722200E-01, 0.29325900E+00, 0.96989000E-01, -.31748900E+00, 0.19566800E+00, -.42912500E+00, 0.23749100E+01, -.53949300E-01, 0.12373000E-01, -.12491100E-01 },
        { -.46450800E+01, -.14462100E+01, 0.16305100E+01, 0.26722800E+01, 0.28125100E+01, 0.12795600E+01, 0.17323200E+01, -.30692400E+01, -.97872000E-01, 0.40796700E+00, -.46220500E-01, 0.22942000E+00, 0.35258200E+00, -.75052400E-01, -.74062600E+00, 0.19136800E+02, 0.22686400E+01, 0.19074000E+01, 0.22069100E+01, 0.36800700E+00, -.13950100E+01, -.39063200E+00, -.26153100E-01, 0.56115100E+00, -.39314900E+00, -.10339600E+00, -.48129300E+00, 0.90590100E+00, 0.96341000E+00, 0.29603600E-01, -.72613100E+00, -.21569800E+00, -.93677500E-01, 0.96697700E+00, -.96306600E-02, -.10374400E+00, 0.21855700E-01, 0.14151100E+00, -.70583900E-01, 0.30447300E+00, 0.12808700E+01, -.23969400E+00, -.92240600E-01, 0.42219000E-01, 0.59865000E-01, -.59466200E-01, 0.42870000E-01, 0.21866700E-01, 0.63524400E+00, 0.15622500E-01, -.18984500E+00, -.18985000E+00, 0.28091400E+00, 0.30993500E+00, -.19046500E+00, 0.87146300E+00, 0.53619400E+00, -.11783300E+00, 0.40383100E-01, 0.43326600E+00, -.63606200E-01, 0.75759600E+00, 0.40442800E+00, -.37695300E+00, 0.15540600E+00, -.58555300E+00, -.98722300E+00, 0.10007800E+00, 0.17900100E+00, -.78610600E-02, 0.11139400E-01, 0.18034600E+01, 0.16521700E+01, 0.15971700E+01, -.70467200E+00, 0.80438500E+00, -.31029200E+00, 0.75957200E+00, -.39248200E+00, -.57653100E-01, 0.59693600E-01, -.36344400E-01, -.10354400E+00, -.33179900E+00, 0.53784200E-01, 0.67218800E-01, 0.33164100E+00, 0.23406600E+00, 0.46513300E+00, -.89016300E-02, -.21102400E+00, 0.28831600E-02, 0.69900100E-01, 0.21348900E-01, 0.54179700E+00, 0.12078400E+01, 0.18533500E+00, -.16513200E-01, 0.75578600E-01, 0.32040400E+00, 0.48897000E-01, 0.19135000E-01, 0.12326600E-01, -.15527900E+00, 0.24431300E+00, 0.10359200E+01, -.55326400E+00, 0.27381400E+00, -.56298500E-01, -.34278600E+00, 0.84725500E-01, 0.20663300E-01, 0.28310700E+00, -.55974700E-02, -.39274100E-01, 0.34911900E-01, 0.68490100E-01, -.17220600E+00, 0.17760400E+00, -.13448500E+01, -.38497900E+00, 0.18194800E-02, -.10594500E+00, 0.86829000E-01, 0.90636400E-03, -.63014400E-01, -.79299900E-01, 0.59722600E+00, 0.15936200E+00, -.97328100E-01, 0.95897100E-01, -.35968200E+00, -.79631800E+00, 0.57405700E+00, -.14054500E+00, -.18428400E-01, 0.48243900E+00, 0.18129000E+00, -.10533000E+00, -.34130000E+00, 0.12400000E+00, 0.26879000E-02, 0.37760700E+00, 0.10848300E+00, 0.19896200E-01, -.11144600E+00, -.17697100E-02, -.87887900E-01, -.11156500E+00, 0.21788000E+00, -.27533800E+01, 0.70514100E-01, 0.11371700E+00, -.41911700E+00, -.11401800E-02, -.32320600E+00, -.75160100E-01, 0.10796900E-02, 0.67097500E+00, 0.64954600E-01, 0.17682300E-01, 0.90572100E-01, -.42918800E-01, 0.98675100E-01, -.28991300E+00, 0.32885800E+00, -.86744200E-02, -.67679500E+00, 0.35012200E-02, -.20479000E+00, -.40766600E-02, 0.26411100E-01, -.82420200E-04, -.52293100E-01, -.70774600E-01, 0.86076700E-01, 0.13189700E+00, 0.10016500E-01, -.12699300E+00, -.38014600E-01, -.45670100E-01, -.24345000E+00, -.46578500E+00, 0.44215600E-01, 0.19492400E+00, -.28311800E+00, 0.31958200E-01, -.60883000E-01, 0.11226900E-01, 0.15253100E+00, 0.22984500E+00, 0.15357400E+00, 0.12396100E+00, -.17844200E+00, -.31756300E+00, 0.13554600E-01, 0.14806400E+00, 0.12774300E+00, -.14695400E+00, 0.27350500E-01, -.11438000E+00, 0.89147300E-02, 0.30095900E+00, -.40047400E+00, -.29801500E+00, -.44742700E-01, 0.22681000E-01, -.15893300E-01, -.63628600E-01, 0.16208800E-01, -.52750400E-02, -.21918300E+00, -.59090700E-02, -.20960200E+00, 0.11955700E+00, 0.31429300E-01, 0.69017000E-01, 0.16131400E+00, -.20211200E-02, 0.16800900E+00, 0.14736700E+00, 0.10902800E-01, -.35320700E-01, 0.15427700E-01, 0.43834600E+00, 0.20696500E-01, -.30533500E-01, -.10996500E+00, 0.10502900E+00, 0.24919600E+00, 0.10239200E+00, 0.24073200E+00, -.22334700E-02, -.16274400E-01, 0.86057500E-01, -.20176900E+00, -.16354500E-01, -.79440700E-01, -.38626100E+00, 0.74702900E+00, -.46653500E+00, 0.34689600E+00, -.14373000E+00, 0.18201200E-01, 0.52159900E-01, 0.41797800E-02, 0.98813800E-01, -.53080800E-01, 0.32079400E-01, -.44961400E-01, -.78317200E-01, -.21236400E+00, 0.10092300E+00, -.41261300E+00, -.17595700E-01, -.27345800E-01, 0.22420900E-02, -.16702100E+00, -.52157000E+00, 0.74591900E-01, 0.45362200E+00, -.14056800E+00, -.14576200E+00, 0.76042600E-01, 0.76979800E-01, -.21871900E-01, 0.48424700E-02, -.13235200E-01, 0.46165700E-01, -.34734400E-01, 0.12591400E-01, 0.16025200E+00, -.33952700E-01, -.53646000E+00, -.34138600E-01, 0.23850000E-01, -.11081800E+01, 0.53346000E-01, -.42911200E+00, -.24214100E+00, -.60814900E-01, 0.34416500E-01, -.61962100E+00, -.93237300E-01, -.97827300E+00, -.90974800E+00, -.10930700E+01, 0.27826600E+01, 0.36702100E+00, 0.31039800E+00, -.35899900E+00, -.13244600E+00, 0.84849200E+00, 0.11655300E+00, 0.11466700E+00, 0.34661500E+00, 0.42263100E-01, -.30888100E-01, -.74428800E+00, 0.99800200E-01, 0.36925100E-01 },
        { -.16330000E+01, -.32064600E+00, 0.12717600E+01, 0.97716300E+00, 0.14498800E+01, 0.32387300E+00, 0.71154300E+00, -.62115300E+00, -.35434800E-01, -.11986000E+00, -.72966500E-01, 0.83155800E-01, -.36105000E-01, -.21319500E-01, -.25105800E-01, -.27291100E+00, -.88519100E+00, -.42060700E+00, 0.20255400E+00, 0.64829200E-01, 0.37788400E+00, -.76204500E-02, 0.49249000E-01, 0.11351500E+00, 0.16568900E-01, -.26787600E-01, 0.22192500E-01, 0.77204800E-01, 0.27012500E+00, -.45349200E-02, -.24728100E+00, -.92392400E-01, 0.71805200E-01, -.92314200E+00, -.83576600E-02, -.33482300E-01, -.53156300E-03, 0.25440100E+00, -.49923300E-02, 0.66538200E-01, -.10243400E+00, -.43290900E-01, -.54697000E-02, -.32920100E-01, -.11880300E+00, -.82981200E-01, 0.37874200E-03, -.18737600E-01, -.67918800E+00, -.26621500E-02, -.16089500E+00, 0.44386300E-01, -.28967200E+00, 0.11065800E+00, -.72515000E-01, -.57700900E-01, -.13633700E+00, 0.12726400E-02, -.21091600E-01, 0.84890500E-01, 0.51654100E-01, -.16775200E+00, -.10037700E+00, 0.37735800E-01, -.23485800E-01, 0.57583100E-01, 0.29546900E+00, 0.82319700E-02, 0.70566100E-01, 0.59272600E-02, -.26922800E-02, 0.40674300E+00, -.27546400E+00, -.46943000E+00, -.31555000E-01, -.18803800E+00, 0.53203800E-01, -.35113600E+00, 0.32539500E-01, -.35552000E-01, -.12435400E-01, 0.96996800E-02, -.38467100E-01, -.11553100E+00, -.78373700E-01, 0.82194400E-01, -.17103600E-01, -.45910700E-01, -.13317500E+00, -.15113100E-02, 0.42100300E-01, 0.56905800E-03, 0.10050600E+00, 0.26885900E-04, -.19881700E+00, -.51133900E-01, -.46953900E-01, -.57040500E-01, 0.46078900E-02, 0.61448200E-02, -.53503800E-02, -.15353500E-01, -.52799400E-02, 0.19918400E-01, -.12837400E-01, 0.12551500E+00, 0.52151400E-01, 0.39778400E-01, -.11310500E-01, -.82007100E-01, 0.26984300E-01, 0.10860200E-02, -.10424000E+00, -.58484200E-02, 0.62944800E-02, -.29001600E-01, 0.51886800E-02, 0.35433500E-01, -.88426500E-01, 0.26274500E+00, -.82087900E-01, 0.27543900E-01, 0.42015600E-01, -.72587000E-01, 0.26847800E-01, -.11870800E+00, 0.99464200E-01, -.22808500E-01, -.12460000E+00, -.17676700E-01, -.18794600E+00, 0.27068900E-01, 0.43269900E-01, -.46966400E-01, -.36616700E-01, 0.14451300E-02, 0.54591800E-01, -.36136200E-01, -.13319000E-01, 0.22863400E+00, 0.93101600E-01, 0.22331700E-01, 0.14024600E-01, -.83601300E-01, 0.78339800E-02, -.42816900E-01, -.14220800E-01, 0.44893000E-01, -.12285100E-03, -.52921000E-01, -.12090900E-01, -.11141600E+00, 0.29213500E-01, -.21279900E+00, 0.34125400E-01, 0.92527400E-01, 0.10156700E-01, 0.74994100E-03, -.10393200E+00, -.34763000E-01, -.15270400E-03, 0.42746200E-02, -.52587900E-02, -.17915900E-01, 0.10999300E-01, 0.28439400E-01, 0.12671700E-01, -.68588200E-01, 0.37167700E-03, -.39088800E-01, 0.37524600E-01, -.21746700E-01, -.10574800E-01, 0.23643700E-01, 0.13191500E+00, -.64270300E-02, 0.15939800E-01, -.55403300E-02, 0.53032500E-01, -.84145300E-02, -.38031400E-01, -.67257700E-01, 0.85743900E-01, -.22443500E-01, 0.16218300E-01, -.65195800E-01, 0.14865200E-01, 0.54376300E-01, -.67792100E-02, 0.54525300E-01, -.77029400E-01, -.16548600E-02, -.30715400E-01, -.36927600E-01, 0.13199700E+00, -.12317400E-01, 0.91437700E-01, -.67030700E-02, -.41603900E-01, 0.24702700E-02, 0.89054800E-02, 0.38262700E-02, -.48496400E-01, -.90635100E-02, -.51467600E-01, -.23177600E-01, 0.11077800E-01, -.83228100E-02, -.15428100E-01, 0.69525800E-03, -.22588300E-03, -.19848500E-01, 0.36360500E-02, -.28830200E-01, 0.88243800E-01, 0.13964200E-01, 0.12582000E+00, 0.26923200E-01, -.13482700E-01, -.31574300E-02, 0.18865400E+00, -.10199800E-01, -.26419200E-02, -.26196000E-02, -.45537900E-01, 0.46231300E-01, -.31213900E-01, 0.67914300E-02, -.39952400E-01, -.10769600E-01, -.20737300E-01, -.24871300E-02, 0.11678100E-02, -.28637200E-02, -.46860700E-01, -.58176700E-01, -.81171800E-02, 0.13858900E-01, -.10589200E+00, 0.79933700E-02, 0.40485300E-01, 0.49574900E-01, 0.88905300E-02, 0.37287000E-02, 0.63181500E-02, -.27496100E-03, -.30802600E-02, -.20902900E-02, -.91866800E-01, -.81267100E-02, 0.10425500E-01, 0.31106000E-01, -.57576800E-01, -.78881500E-02, -.12378400E-02, 0.10651100E-01, 0.16692800E-02, -.28927400E-01, 0.40615100E-02, -.13538200E-02, 0.39084000E-02, 0.23080700E-01, 0.11671400E+00, 0.20099900E-01, -.25266800E-02, -.12824500E-02, -.58715400E-02, 0.23627500E-03, -.12849500E-02, -.27468900E-02, -.94840600E-02, 0.11263100E-01, 0.27466200E-02, 0.95514700E-01, -.12498300E-02, -.93729000E-03, -.17378000E-01, 0.68163800E-01, 0.50923300E-01, 0.62664600E-01, -.25381400E-01, -.42959700E-02, 0.35277300E-01, 0.50843500E-02, -.15534400E-01, -.81968300E-02, 0.58382500E-01, -.44815500E-01, -.47183200E-01, -.27484500E-02, 0.33214100E-01, 0.46711700E-02, -.48979500E+00, -.92971700E-01, -.12674000E+00, -.14176600E+00, -.98024200E-01, 0.73779700E-02, -.19837500E-01, -.19169300E+00, -.80118300E-02 },
        { 0.26538100E+01, 0.74198800E+00, -.86864100E+00, -.13270700E+01, -.10308800E+01, -.74012300E+00, -.12168200E+01, 0.21447400E+01, 0.15747000E+00, 0.30462000E+00, -.97551200E-01, -.37342100E+00, -.33241800E+00, 0.92624800E-01, 0.45542400E+00, -.56179000E+01, -.44593800E+00, -.46426700E+00, -.11898700E+01, 0.96989100E-01, 0.46646900E+00, 0.73380900E-01, -.61276100E-01, -.63782300E+00, 0.74927300E-01, 0.13517700E-01, -.22139800E-01, -.60107200E+00, 0.17269300E-01, -.34994300E-01, 0.36848500E+00, -.19665500E-01, -.86287800E-01, 0.18715800E+00, -.39904100E-02, 0.20463400E-01, 0.14810600E-02, -.26465600E+00, 0.71929100E-01, 0.10064100E+00, -.10721000E+01, -.42774600E-01, -.64773600E-02, -.77144600E-01, 0.15418100E+00, 0.15120300E+00, -.32786900E-01, 0.26576700E-01, 0.11008000E+01, -.40045500E-01, 0.33639800E+00, -.32598500E+00, -.36259400E-01, -.47494000E+00, 0.11700000E-01, -.92897300E+00, -.40001900E+00, 0.37719900E-01, 0.21312500E-01, -.32223300E-01, 0.43460400E-02, 0.74444800E-01, -.10036900E+00, 0.13316700E+00, 0.37668300E-01, 0.11857300E+00, -.24381500E+00, -.81267400E-01, 0.23985000E+00, 0.35908300E-03, 0.33744400E-01, -.63199300E+00, 0.21300400E+00, 0.38792800E+00, 0.20627400E+00, 0.51541800E+00, -.31732300E-01, -.16795600E-01, 0.26000900E+00, 0.32246200E-01, 0.28794000E-01, -.62286500E-01, -.59079600E-01, -.12693800E+00, 0.96083300E-01, 0.92564500E-01, 0.12426400E+00, -.65209300E-01, 0.78625300E-01, -.25748900E-01, 0.44290200E+00, 0.10233200E-02, -.47552400E-01, -.19155800E-01, -.27486800E+00, -.72642500E-01, -.62955100E-01, 0.78580300E-01, -.11997600E-01, 0.48506100E-01, -.17689700E-01, 0.55598400E-02, 0.63865600E-03, 0.86588500E-01, -.45689100E-01, -.19488100E+01, 0.82442100E-01, -.17055100E+00, -.55547900E-01, 0.18557400E+00, 0.50398900E-01, -.50964900E-02, -.30544500E+00, 0.55379100E-02, 0.97310500E-01, 0.27270400E+00, 0.10720400E+00, -.18394600E+00, 0.27537400E+00, 0.13945400E+00, 0.21645400E+00, -.18592700E-01, 0.25190200E-01, 0.42738700E-02, -.51725200E-02, -.71548900E-01, -.26123300E+00, 0.14622500E+00, 0.99153500E-01, 0.65447200E-01, -.38251300E-01, -.64955600E-01, -.16721600E+00, 0.16712500E+00, -.67898000E-01, -.11113300E-01, 0.10574700E+00, 0.13310300E+00, 0.15497400E-01, 0.30735100E+00, 0.11967000E-01, -.42862300E-01, -.10590000E+00, 0.49483500E-01, 0.47725200E-01, 0.89080900E-01, 0.25818100E-01, 0.10659700E+00, -.39881600E-02, -.43312600E+00, -.66042500E+00, -.18639900E+00, -.71160500E-01, -.15044000E+00, 0.26610500E-01, 0.77329900E-01, -.12035000E-01, 0.10782300E-02, -.31527800E+00, -.33409800E-01, 0.11424800E-01, 0.27558100E-01, -.57943200E-02, -.12094700E+00, -.15790300E+00, 0.75521700E-01, 0.10170200E-01, -.72361700E-01, -.18501600E-02, -.22366100E+00, 0.95334100E-01, -.30741500E-01, -.35302100E-03, -.26788700E-03, 0.12730200E+00, 0.57493500E-01, 0.39782900E-02, -.83289700E-02, -.45192200E-01, -.14454200E-01, -.92993300E-02, 0.27640900E-01, 0.20013600E+00, 0.87530800E-01, -.43300000E-01, -.28499800E-01, -.49152600E-01, -.26747800E-01, 0.30421400E-02, -.85197600E-02, 0.29323600E-01, -.19859500E-01, 0.57942300E-02, 0.12329700E+00, 0.47225400E+00, 0.47669200E-01, -.22908600E+00, -.20091000E-01, -.34611700E-01, 0.90775500E-02, 0.20496900E-02, -.20802400E-01, -.13235600E-01, -.16022500E-01, 0.78036400E-01, -.17222000E-01, 0.89888100E-02, 0.82174200E-01, -.22569800E-01, 0.16925500E-02, -.10067900E-01, -.72650300E-01, -.19935600E-01, 0.98272000E-01, -.10574900E+00, 0.95347200E-01, 0.24778800E-01, -.23360300E+00, 0.44883100E-01, 0.21381000E-01, 0.18293400E+00, -.18357400E-01, -.14641500E-03, 0.47179300E-02, -.20150100E-01, -.43425000E-02, -.79808500E-01, -.19481100E-01, 0.10663400E-01, 0.58784400E-01, -.18061200E+00, 0.13661000E+00, 0.50974300E-04, -.50058000E-01, 0.10562700E+00, -.53728300E-01, 0.58218400E-02, -.30455000E-01, -.53133700E-02, 0.13840300E+00, 0.37081800E-01, -.44115000E-01, 0.13300900E-01, 0.14014900E-02, -.35596500E-02, 0.33261100E-02, -.11662600E-02, -.51346600E-02, 0.13576600E+00, -.32590600E-02, -.20614900E-01, 0.22890600E+00, 0.20299100E-01, -.45617300E-01, 0.45003100E-02, 0.20410700E-01, 0.16482900E-05, 0.11030900E+00, -.40547900E-01, 0.49377500E-02, -.83071300E-01, 0.17767100E+00, 0.22725900E+00, 0.99997300E-02, 0.11456700E-01, -.11821600E-03, -.50775000E-02, 0.35345600E-02, 0.67648700E-02, -.15377500E-02, -.15226000E-02, 0.44519500E-02, -.11000300E-01, 0.15160000E+00, -.37468200E-02, 0.15046600E-01, -.37888300E-01, 0.21166000E+00, -.33255300E+00, -.47002700E+00, 0.53282200E+00, 0.33498900E-01, -.96136700E-01, -.40515000E-01, 0.82919300E+00, 0.16649000E+00, -.27661700E+00, -.57060200E+00, 0.38744900E+00, 0.73603400E+00, -.45701400E+00, 0.95248700E-02, -.10166900E+00, 0.97271800E-02, -.46623900E-01, -.47843300E-01, 0.24784600E-01, -.66330700E-02, -.23596400E-02, -.33838500E-01, 0.59181100E-01 }
    },
    {
        { 0.61755700E+05, -.28185200E+05, 0.12832100E+05, -.31656500E+05, 0.32315700E+05, 0.35050300E+05, -.16843500E+05, 0.16374000E+05, -.24136900E+05, 0.26931200E+05, -.47127200E+05, 0.51871800E+05, -.23305000E+05, 0.12970000E+05, -.26106800E+05, 0.36509000E+05, 0.34650300E+05, -.94305000E+04, 0.27686900E+05, -.16193900E+05, 0.25641300E+05, -.49879400E+05, -.49658800E+04, -.23796200E+03, -.24890300E+05, 0.34520800E+04, -.46175900E+05, -.38641500E+05, 0.40576600E+04, -.20004100E+05, 0.56925600E+04, -.29815600E+05, 0.38033800E+05, 0.12603500E+05, -.70746000E+04, -.11734400E+05, -.59388900E+04, -.12457700E+05, -.58110500E+04, -.37331800E+04, -.62273900E+04, -.31367400E+04, -.41803900E+04, 0.82458400E+04, 0.62005400E+04, -.58011800E+04, -.13406000E+05, -.23986900E+04, -.28600000E+05, -.16750400E+05, -.18945900E+04, -.12014500E+05, 0.53921100E+03, -.12399500E+05, 0.27372300E+05, -.60506500E+05, 0.30508300E+05, 0.19235200E+05, 0.29695600E+05, 0.13860200E+05, 0.10014100E+05, 0.73404500E+04, -.67098900E+04, 0.14970800E+05, 0.90437900E+04, 0.15793000E+05, 0.13036800E+04, -.38639900E+03, 0.27023300E+04, -.73785100E+03, 0.43991300E+04, 0.38421300E+04, -.62340000E+03, 0.18744900E+04, -.81696600E+03, 0.29447400E+04, -.38793200E+04, 0.46909700E+05, -.21468200E+05, 0.10114600E+05, -.23482700E+05, 0.25684900E+05, 0.25460200E+05, -.79426200E+04, 0.22019800E+05, -.14046300E+05, 0.18577400E+05, -.39765100E+05, 0.45753500E+05, -.23413600E+05, -.27070900E+05, -.22589500E+05, -.15761600E+05, -.11917600E+05, -.92442700E+04, -.39026200E+04, -.12141200E+05, -.10463700E+05, 0.21118500E+04, -.19578000E+05, 0.10132900E+05, 0.15142800E+05, 0.97567800E+04, 0.91650400E+04, 0.11663700E+05, 0.19490800E+04, 0.12035700E+04, 0.30840300E+04, 0.10200000E+05, -.37621100E+04, -.11590600E+05, 0.58265800E+04, 0.35911800E+04, 0.57793000E+04, 0.23827200E+04, 0.17866200E+04, 0.98379600E+03, -.21754000E+04, 0.28097400E+04, 0.16627100E+04, 0.36821600E+04, 0.57205400E+05, -.25299900E+05, 0.14278100E+05, -.28908700E+05, 0.29502000E+05, 0.28422400E+05, -.12521500E+05, 0.19475400E+05, -.19860400E+05, 0.20517500E+05, -.46045700E+05, -.13809200E+05, 0.71298000E+04, 0.47794700E+04, 0.64955100E+04, 0.58416600E+04, 0.20281600E+04, 0.23061200E+04, -.82527800E+03, 0.26958600E+04, 0.20777800E+04, -.20676900E+04, 0.24358000E+05, -.12230300E+05, -.61209200E+04, -.11958800E+05, -.62750100E+04, -.54194400E+04, -.11830600E+04, 0.48701100E+04, -.56240400E+04, -.47111600E+04, -.80081900E+04, -.23915200E+05, 0.12452300E+05, 0.16230200E+05, 0.11845400E+05, 0.10146200E+05, 0.11660600E+05, 0.31084000E+04, 0.13436900E+04, 0.43193900E+04, 0.10372600E+05, -.37908400E+04, -.36720500E+05, 0.15892100E+05, -.18386400E+05, 0.18970900E+05, -.36133000E+05, -.36646200E+05, 0.10405900E+05, -.17824100E+05, 0.15126400E+05, -.28386900E+05, 0.41959500E+05, 0.29676000E+05, -.15960800E+05, -.21543800E+05, -.14381000E+05, -.22553100E+05, -.15108400E+05, -.46406900E+04, -.64356700E+04, -.81166400E+04, -.11604800E+05, 0.69438200E+04, 0.12942200E+05, -.69692900E+04, -.11118900E+05, -.63557500E+04, -.14712100E+05, -.30591500E+04, -.49426700E+04, -.78161600E+04, -.46564700E+04, -.22006300E+04, 0.13578500E+05, -.10015300E+05, 0.46403900E+04, 0.26365400E+03, 0.50404600E+04, -.37609600E+04, -.56079100E+04, 0.36476100E+04, -.60130800E+03, 0.44612900E+04, -.44648600E+04, 0.58845700E+04, 0.44971700E+04, -.35291100E+04, -.15194100E+05, -.19094500E+04, -.22247700E+05, -.98770500E+04, -.33261900E+04, -.12489700E+05, -.10049200E+04, -.72385100E+04, 0.23735800E+05, -.62805300E+05, 0.31699000E+05, 0.21026300E+05, 0.30800400E+05, 0.17759400E+05, 0.11501600E+05, 0.84300600E+04, -.37345300E+04, 0.17472000E+05, 0.98736500E+04, 0.12982800E+05, 0.33942700E+05, -.17145200E+05, -.99340800E+04, -.16564300E+05, -.74759100E+04, -.62543000E+04, -.22563400E+04, 0.71536700E+04, -.72830200E+04, -.56107000E+04, -.11315500E+05, -.15883600E+05, 0.80585300E+04, 0.11084800E+05, 0.78775800E+04, 0.58780600E+04, 0.56262600E+04, 0.31719000E+04, 0.22550200E+04, 0.40872300E+04, 0.46437500E+04, -.71970200E+03, 0.26399500E+05, -.13407100E+05, -.66931700E+04, -.12900000E+05, -.78398300E+04, -.61294000E+04, -.23764500E+04, 0.28982600E+04, -.68713600E+04, -.52900300E+04, -.65061600E+04, -.20358300E+05, 0.10405900E+05, 0.14344400E+05, 0.10006400E+05, 0.89798700E+04, 0.77883100E+04, 0.32537500E+04, 0.13925800E+04, 0.46045100E+04, 0.67730400E+04, -.24997300E+04, -.31569100E+04, 0.11924600E+05, -.10129900E+05, -.45515200E+04, 0.19638100E+05, -.17648500E+05, 0.10484100E+05, -.62504300E+04, 0.92103700E+04, 0.22610700E+05, -.27663800E+05, 0.11355400E+05, -.14823700E+05, -.18509400E+05, -.10156100E+05, 0.25944400E+05, -.12649800E+04, -.81043600E+04, -.21873600E+05, 0.14276200E+05, 0.19300500E+05, -.11120900E+05, 0.98328700E+04, 0.27337800E+05, 0.67136500E+04, 0.22161700E+05 },
        { -.16209100E+02, 0.72622200E+05, 0.50480900E+06, -.25133800E+05, 0.51407100E+06, 0.39422400E+06, -.54250400E+05, 0.10868500E+06, -.10554300E+06, 0.30437200E+06, -.42010600E+06, -.14329200E+06, 0.14358600E+06, 0.47586800E+06, 0.66126100E+05, 0.57062100E+06, 0.36822400E+06, 0.10790400E+06, 0.39522100E+06, 0.74990600E+05, 0.26033700E+06, -.45038000E+06, 0.14081700E+07, -.77978400E+06, -.94152800E+06, -.67273900E+06, -.78895000E+06, -.47260000E+06, -.24289800E+06, -.12813100E+06, -.30964300E+06, -.36878200E+06, 0.11836800E+06, 0.79808200E+06, -.42382900E+06, -.41435900E+06, -.38730700E+06, -.22422000E+06, -.41749900E+05, -.18755900E+06, -.32632700E+05, -.21183000E+06, -.29043000E+05, -.59088700E+05, 0.13882100E+07, -.77027600E+06, -.71276900E+06, -.67140000E+06, -.50018200E+06, -.14969500E+06, -.30973400E+06, -.44584500E+05, -.34482000E+06, -.11242400E+06, 0.26088400E+05, -.15604500E+07, 0.78783500E+06, 0.55565200E+06, 0.76211000E+06, 0.28863100E+06, 0.22103800E+06, 0.17904100E+06, -.25341900E+06, 0.31561800E+06, 0.20326100E+06, 0.45132200E+06, -.11828300E+06, 0.66456200E+05, 0.89013000E+05, 0.56359900E+05, 0.74231700E+05, 0.46577100E+05, 0.19809700E+05, 0.13710900E+05, 0.25726700E+05, 0.35936400E+05, -.15023600E+05, 0.15293000E+06, -.23623800E+05, 0.31153400E+06, -.77360200E+05, 0.39102900E+06, 0.26904200E+06, 0.46601600E+05, 0.34106200E+06, -.16396700E+04, 0.18188700E+06, -.42544100E+06, 0.15937700E+07, -.82245300E+06, -.73494800E+06, -.78752300E+06, -.30844900E+06, -.11767100E+06, -.32479100E+06, 0.48851500E+05, -.42239500E+06, -.11873000E+06, -.20128500E+06, -.98902100E+06, 0.51050200E+06, 0.47064600E+06, 0.49345200E+06, 0.17425800E+06, 0.13430700E+06, 0.16434100E+06, -.79713000E+05, 0.22250300E+06, 0.12891000E+06, 0.15371000E+06, -.29733100E+06, 0.14998500E+06, 0.10602200E+06, 0.14814300E+06, 0.50674100E+05, 0.39394700E+05, 0.26418400E+05, -.65816500E+05, 0.59812700E+05, 0.37079300E+05, 0.96089900E+05, -.34493700E+05, 0.10554600E+06, 0.48880700E+06, 0.73663300E+04, 0.45952800E+06, 0.24939500E+06, 0.51925100E+05, 0.24149500E+06, 0.73761800E+04, 0.15910800E+06, -.42622000E+06, -.57679300E+06, 0.29445300E+06, 0.23370500E+06, 0.27515700E+06, 0.11693100E+06, 0.35438900E+05, 0.99323300E+05, -.68344500E+05, 0.11782000E+06, 0.42767200E+05, 0.80007100E+05, 0.68537200E+06, -.34435300E+06, -.21839600E+06, -.33553200E+06, -.12886900E+06, -.11707600E+06, -.44893600E+05, 0.15976700E+06, -.13449300E+06, -.10116600E+06, -.23700100E+06, -.10696700E+07, 0.55370100E+06, 0.49827700E+06, 0.53118300E+06, 0.19637200E+06, 0.13385100E+06, 0.18509700E+06, -.79495600E+05, 0.24416400E+06, 0.13179700E+06, 0.14595300E+06, 0.44689000E+06, -.29036500E+06, -.60823800E+06, -.20367500E+06, -.59138200E+06, -.44660300E+06, -.69093200E+05, -.17617900E+06, -.51726900E+05, -.35061200E+06, 0.31324700E+06, 0.12354300E+07, -.64576200E+06, -.59605900E+06, -.60295100E+06, -.39950700E+06, -.21430500E+06, -.23247700E+06, -.42370000E+05, -.33898500E+06, -.16625300E+06, -.15328300E+06, 0.96502100E+06, -.50012300E+06, -.47763100E+06, -.47877900E+06, -.25790300E+06, 0.39518900E+05, -.26510900E+06, -.76811600E+05, -.32103400E+06, 0.34433000E+05, -.12577900E+05, -.37730400E+05, 0.10763600E+05, -.35218700E+05, 0.19927900E+05, -.58315200E+05, -.79668600E+05, 0.36342600E+05, 0.12900300E+05, 0.41718300E+05, -.64411900E+05, 0.43178700E+05, 0.10703600E+07, -.57459900E+06, -.61786700E+06, -.52422200E+06, -.38153400E+06, -.34994900E+05, -.29188200E+06, -.11615200E+06, -.32144000E+06, -.20975300E+05, 0.65892100E+05, -.17649900E+07, 0.89129900E+06, 0.64670000E+06, 0.86302400E+06, 0.35100100E+06, 0.21738400E+06, 0.23973000E+06, -.21421800E+06, 0.43025700E+06, 0.19063400E+06, 0.45889300E+06, 0.88522000E+06, -.44779800E+06, -.30490900E+06, -.42940200E+06, -.16192100E+06, -.14533800E+06, -.61687200E+05, 0.21667200E+06, -.14638700E+06, -.13113800E+06, -.30072600E+06, -.65428600E+06, 0.33623900E+06, 0.31196800E+06, 0.32505600E+06, 0.11217000E+06, 0.57235400E+05, 0.13167800E+06, -.17199200E+05, 0.17051200E+06, 0.52153800E+05, 0.11714100E+06, 0.69329900E+06, -.35205200E+06, -.20743600E+06, -.33700000E+06, -.15183900E+06, -.12628800E+06, -.69476600E+05, 0.96993500E+05, -.16466500E+06, -.10973800E+06, -.20486400E+06, -.79888200E+06, 0.41240900E+06, 0.38746500E+06, 0.39382700E+06, 0.17237200E+06, 0.84491500E+05, 0.14851000E+06, -.39900300E+05, 0.19616400E+06, 0.81933600E+05, 0.93435400E+05, 0.17875400E+06, 0.29444200E+06, -.25558900E+06, -.22362400E+05, 0.29181000E+06, -.27982900E+06, 0.11714800E+05, -.84136100E+05, 0.26693000E+06, 0.28310300E+06, -.42046000E+06, 0.33164000E+05, -.32647400E+06, -.21848200E+06, -.22719100E+05, 0.37391400E+06, -.84895500E+05, 0.16048500E+05, -.35047700E+06, 0.33536300E+06, 0.32093000E+06, -.45342200E+05, -.45797900E+04, 0.40818700E+06, -.90468500E+05, 0.28213300E+06 },
        { -.10547000E+02, -.62978600E-02, 0.65615400E+06, -.20727800E+05, 0.38484400E+06, 0.32777900E+06, -.54781500E+05, 0.54651300E+05, -.10171800E+06, 0.25066700E+06, -.32863600E+06, -.43616100E+05, 0.20742100E+05, 0.64950600E+06, 0.17255100E+05, 0.41391700E+06, 0.30314600E+06, 0.55631600E+05, 0.27637600E+06, 0.15341600E+05, 0.21508100E+06, -.36620500E+06, 0.10967200E+07, -.54549900E+06, -.10268400E+07, -.52249700E+06, -.56282100E+06, -.35327100E+06, -.18264900E+06, -.51690000E+05, -.20980400E+06, -.27619800E+06, 0.74741600E+05, 0.61111500E+06, -.30144000E+06, -.42844400E+06, -.29587700E+06, -.16260200E+06, -.38426700E+05, -.13733500E+06, -.60871400E+04, -.14682500E+06, -.28512700E+05, -.47200100E+05, 0.11299800E+07, -.56150500E+06, -.80594000E+06, -.54625300E+06, -.35434900E+06, -.10432700E+06, -.24666100E+06, 0.56176100E+04, -.25688400E+06, -.80260200E+05, -.15781800E+05, -.11435400E+07, 0.57059900E+06, 0.49372800E+06, 0.55681200E+06, 0.19841100E+06, 0.15646300E+06, 0.13005700E+06, -.20842500E+06, 0.19895300E+06, 0.14667600E+06, 0.32393500E+06, -.83513800E+05, 0.41553700E+05, 0.10019200E+06, 0.39462100E+05, 0.53750100E+05, 0.37275300E+05, 0.12627100E+05, 0.70906100E+04, 0.13915500E+05, 0.28767500E+05, -.14313500E+05, 0.15950500E+06, -.78989400E+05, 0.42558200E+06, -.80490500E+05, 0.28763900E+06, 0.22444800E+06, 0.14876600E+05, 0.24267600E+06, -.25377100E+05, 0.15249100E+06, -.33748700E+06, 0.11188600E+07, -.54827500E+06, -.72320700E+06, -.55169100E+06, -.22855400E+06, -.11013500E+06, -.21702400E+06, 0.53763400E+05, -.26765800E+06, -.10568700E+06, -.10405300E+06, -.68446700E+06, 0.33528100E+06, 0.50119600E+06, 0.34135700E+06, 0.13297500E+06, 0.12127200E+06, 0.10231400E+06, -.73819600E+05, 0.12705100E+06, 0.11230800E+06, 0.77612000E+05, -.22150200E+06, 0.11020900E+06, 0.92925900E+05, 0.11031900E+06, 0.34635100E+05, 0.27700200E+05, 0.20116400E+05, -.52535600E+05, 0.39221700E+05, 0.26517200E+05, 0.70062200E+05, 0.19621800E+05, -.88023900E+04, 0.65707600E+06, -.17959800E+05, 0.34810700E+06, 0.22635800E+06, 0.13838200E+05, 0.16187600E+06, -.26805800E+05, 0.14638500E+06, -.35514800E+06, -.46688100E+06, 0.23328700E+06, 0.22662100E+06, 0.22251600E+06, 0.81982100E+05, 0.22687900E+05, 0.81576000E+05, -.61802300E+05, 0.88718500E+05, 0.30686200E+05, 0.75344300E+05, 0.50194600E+06, -.25034200E+06, -.20916900E+06, -.24506600E+06, -.86675600E+05, -.80897500E+05, -.34277200E+05, 0.12686600E+06, -.83977300E+05, -.70689700E+05, -.16877700E+06, -.75145700E+06, 0.37002100E+06, 0.51813700E+06, 0.37271000E+06, 0.14765900E+06, 0.11881100E+06, 0.11898800E+06, -.74924300E+05, 0.14628000E+06, 0.11275100E+06, 0.75314500E+05, 0.28983300E+06, -.14442500E+06, -.73380900E+06, -.12860200E+06, -.43353600E+06, -.36091900E+06, -.30153800E+05, -.10959900E+06, 0.39566800E+04, -.28249000E+06, 0.25954100E+06, 0.83531300E+06, -.41925900E+06, -.60991300E+06, -.40548000E+06, -.28413600E+06, -.17338900E+06, -.15093800E+06, -.19303100E+05, -.19851800E+06, -.13597400E+06, -.75061300E+05, 0.75708300E+06, -.37405800E+06, -.49786200E+06, -.37546200E+06, -.18324500E+06, 0.29184000E+05, -.20173800E+06, -.38849600E+05, -.23995500E+06, 0.22310100E+05, -.21052400E+05, -.22437100E+05, 0.95177200E+04, -.60487800E+05, 0.12095500E+05, -.43052400E+05, -.60800300E+05, 0.26376700E+05, 0.12329800E+05, 0.32523900E+05, -.48923600E+05, 0.30583900E+05, 0.83491600E+06, -.41242300E+06, -.66899900E+06, -.40842000E+06, -.27510000E+06, -.36663900E+05, -.21599100E+06, -.58623100E+05, -.23133700E+06, -.26177000E+05, 0.37932300E+05, -.12945600E+07, 0.64582400E+06, 0.59526500E+06, 0.63121600E+06, 0.24001400E+06, 0.15087500E+06, 0.17552600E+06, -.18284000E+06, 0.28383700E+06, 0.13500400E+06, 0.32699500E+06, 0.65657100E+06, -.32753700E+06, -.27315900E+06, -.31738100E+06, -.11137700E+06, -.10392500E+06, -.46479400E+05, 0.17234900E+06, -.88733200E+05, -.95001000E+05, -.21823300E+06, -.45097300E+06, 0.21940400E+06, 0.32014300E+06, 0.22376300E+06, 0.85415200E+05, 0.56388100E+05, 0.84928800E+05, -.21227700E+05, 0.10176000E+06, 0.49424800E+05, 0.64122500E+05, 0.48571700E+06, -.24256700E+06, -.20417100E+06, -.23490500E+06, -.10124700E+06, -.86939600E+05, -.49303800E+05, 0.75806300E+05, -.10057800E+06, -.76917900E+05, -.13852700E+06, -.54832500E+06, 0.26730400E+06, 0.39212500E+06, 0.26952600E+06, 0.12920300E+06, 0.78677900E+05, 0.94711200E+05, -.37619300E+05, 0.11634700E+06, 0.73099600E+05, 0.39334400E+05, 0.12561500E+06, 0.20839300E+06, -.20355300E+06, -.37422800E+05, 0.21785300E+06, -.22238700E+06, 0.17817600E+05, -.60253200E+05, 0.19576100E+06, 0.19947800E+06, -.29504700E+06, 0.35195200E+05, -.24902700E+06, -.16740000E+06, -.30242100E+05, 0.26461200E+06, -.68427900E+05, 0.17689400E+05, -.26631100E+06, 0.22721700E+06, 0.24397200E+06, -.46102100E+05, 0.68685100E+04, 0.28672700E+06, -.65558200E+05, 0.19379000E+06 },
        { 0.45699600E+00, 0.43264500E-01, 0.19916700E-01, -.68982300E+04, 0.40534900E+04, 0.68206600E+04, -.73473200E+04, -.13008100E+05, -.13685100E+05, 0.65852400E+04, -.25281700E+04, 0.34246000E+05, -.17133100E+05, -.14188500E+05, -.18605500E+05, -.48484400E+04, 0.19915000E+04, -.15468300E+05, -.14932700E+05, -.19760600E+05, 0.23508000E+04, -.53546700E+04, -.79621700E+04, 0.42317100E+04, 0.17257000E+04, 0.12500600E+05, -.51404800E+04, -.10186300E+05, 0.17559000E+05, 0.29600400E+05, 0.29745600E+05, -.10208000E+05, 0.10697800E+04, -.10099600E+05, 0.52822300E+04, 0.20240700E+04, 0.81963200E+04, -.24184700E+04, -.54864600E+04, 0.81987200E+04, 0.10067000E+05, 0.13177500E+05, -.49298400E+04, 0.25949000E+04, -.20618500E+05, 0.10559900E+05, 0.34612900E+04, 0.16428600E+05, -.58317700E+04, -.10602300E+05, 0.15888800E+05, 0.17958600E+05, 0.25373500E+05, -.91083000E+04, 0.69019000E+04, -.97915900E+04, 0.45785000E+04, 0.77458700E+04, 0.11024600E+03, 0.66128300E+04, 0.49901800E+04, -.59692000E+04, -.16882300E+05, -.14514600E+05, 0.46775300E+04, 0.35890300E+03, 0.11644200E+04, -.60051500E+03, -.19650600E+03, -.13386500E+04, 0.39884900E+03, 0.92468600E+03, -.17052800E+04, -.26959000E+04, -.28245000E+04, 0.91869200E+03, -.21251800E+03, 0.25974600E+05, -.12893700E+05, -.12298700E+05, -.13227200E+05, -.48823300E+04, 0.67696000E+03, -.11204300E+05, -.10176700E+05, -.12864900E+05, 0.11214200E+04, -.27450600E+04, -.76919200E+04, 0.42351500E+04, -.18012000E+04, 0.61135700E+04, -.44209000E+04, -.80798800E+04, 0.14122900E+05, 0.22415100E+05, 0.22414000E+05, -.75928500E+04, 0.24093000E+04, 0.14868400E+05, -.76946600E+04, -.20512000E+04, -.76742100E+04, 0.18573300E+04, 0.45719500E+04, -.96555200E+04, -.11854600E+05, -.17126700E+05, 0.42204500E+04, -.60496000E+04, -.15685800E+04, 0.70550100E+03, 0.11065100E+04, 0.65605800E+03, 0.89759100E+03, 0.24626300E+03, -.98150700E+02, -.13819900E+04, -.12452500E+04, 0.25527300E+03, -.95168300E+03, 0.23325100E+05, -.11503200E+05, -.67052400E+04, -.14385300E+05, 0.27410900E+04, 0.65023600E+04, -.98453100E+04, -.51969400E+04, -.14303500E+05, 0.56553900E+04, -.10433800E+05, -.33471400E+04, 0.15987700E+04, 0.28247700E+04, -.19254400E+04, 0.33469000E+04, 0.34506500E+04, -.35558400E+04, -.76878200E+04, -.69125100E+04, 0.29096900E+04, 0.13636600E+04, 0.35407900E+04, -.16833800E+04, -.32695100E+04, 0.13632300E+03, -.33405100E+04, -.15526300E+04, 0.88819900E+03, 0.40292800E+04, 0.51628600E+04, -.15629500E+04, 0.18693600E+04, 0.97595900E+04, -.51044800E+04, 0.11625700E+03, -.57359200E+04, 0.30820300E+04, 0.59913600E+04, -.10418000E+05, -.14868100E+05, -.18034000E+05, 0.55933700E+04, -.43170200E+04, -.47427000E+04, 0.24790200E+04, 0.61545700E+03, 0.77351100E+04, -.17729600E+04, -.46178600E+04, 0.12351900E+05, 0.21093700E+05, 0.19655800E+05, -.47305000E+04, -.18879000E+04, -.19046100E+05, 0.96411300E+04, 0.40282400E+04, 0.13515700E+05, -.23299500E+04, -.59032300E+04, 0.14023400E+05, 0.17803800E+05, 0.22065500E+05, -.55542200E+04, 0.30043600E+04, -.25318700E+05, 0.12839100E+05, 0.92090700E+04, 0.13646200E+05, -.87297000E+03, -.52236100E+04, 0.98041300E+04, 0.55908800E+04, 0.13521500E+05, -.46960700E+04, 0.89739300E+04, 0.14762500E+03, -.12909900E+03, -.41029400E+03, 0.19306100E+03, -.41925000E+03, -.39374900E+03, 0.50617900E+03, 0.10536100E+04, 0.18263100E+04, -.38999000E+03, 0.47390000E+03, -.27030300E+05, 0.13768000E+05, 0.89488200E+04, 0.16459900E+05, -.22900100E+04, -.87624400E+04, 0.13814900E+05, 0.11560900E+05, 0.19498500E+05, -.78486900E+04, 0.95230800E+04, 0.49633600E+04, -.27739000E+04, 0.10513600E+04, -.77245000E+04, 0.55673500E+04, 0.35861300E+04, -.79367000E+04, -.14214600E+05, -.16117600E+05, 0.36370900E+04, -.48631200E+04, 0.14556200E+05, -.70110400E+04, -.83364500E+04, -.37851600E+04, -.54364900E+04, -.34067100E+04, 0.61169700E+03, 0.83442500E+04, 0.64121900E+04, -.30927200E+04, -.14451500E+04, 0.10991400E+05, -.57075800E+04, -.22261700E+04, -.59970800E+04, 0.69164400E+03, 0.25560300E+04, -.63555100E+04, -.74064600E+04, -.10660800E+05, 0.22479200E+04, -.32094300E+04, -.24810200E+04, 0.14271400E+04, -.15048100E+04, 0.38612800E+04, -.21156200E+04, -.19926400E+04, 0.44631400E+04, 0.78239700E+04, 0.94925300E+04, -.22255300E+04, 0.87238400E+03, 0.17378100E+04, -.11059600E+04, 0.22782100E+04, -.22539400E+04, 0.26317200E+04, 0.42264600E+04, -.68878200E+04, -.11914700E+05, -.11404800E+05, 0.39953900E+04, -.70605400E+03, -.18457700E+04, -.36866200E+04, -.24006600E+04, -.30337300E+04, 0.15010900E+04, -.11782400E+04, 0.99573700E+04, 0.64957600E+03, 0.22676700E+04, 0.19073300E+04, -.27276500E+04, 0.13499200E+05, 0.82005200E+03, -.12569900E+04, -.11451900E+05, 0.20256200E+04, -.94090000E+03, 0.22332900E+04, -.28980800E+04, -.25767900E+04, 0.14723600E+04, -.10631600E+05, 0.11091400E+05, 0.36942000E+04, 0.11653000E+04, 0.17933300E+04 },
        { 0.62758100E+01, 0.40946000E-01, -.22187100E+00, 0.49177100E+00, -.94041600E+05, 0.18034900E+03, -.26496500E+05, -.72298300E+05, -.32007400E+05, 0.18892900E+04, 0.90149800E+05, 0.81627400E+05, -.40021200E+05, -.14428400E+05, -.40831400E+05, -.11847300E+06, -.29739800E+04, -.61211500E+05, -.10752200E+06, -.63573000E+05, 0.49115400E+04, 0.80154300E+05, -.12581600E+06, 0.64055700E+05, 0.23341100E+05, 0.62976100E+05, 0.14442200E+06, -.61521100E+04, 0.77873600E+05, 0.12647500E+06, 0.10431400E+06, -.10918300E+05, -.10208200E+06, -.90779100E+05, 0.44716700E+05, 0.17679800E+05, 0.45435300E+05, 0.41762200E+05, -.29804000E+05, 0.46847200E+05, 0.47180600E+05, 0.57698500E+05, -.26450100E+05, -.26632700E+05, -.12026400E+06, 0.59986700E+05, 0.60848000E+04, 0.60212700E+05, 0.97405600E+05, -.38957200E+05, 0.71981800E+05, 0.88822900E+05, 0.92454700E+05, -.34479900E+05, -.86314700E+05, 0.75186400E+05, -.40657800E+05, 0.11718200E+05, -.37732600E+05, -.35786700E+05, -.42470500E+04, -.24365600E+05, -.30773800E+05, -.60576000E+05, -.65874100E+04, 0.39731800E+04, 0.12758700E+05, -.64817300E+04, -.18186800E+04, -.63850600E+04, -.13480100E+05, 0.67807100E+03, -.73151300E+04, -.11268400E+05, -.98810900E+04, 0.11083800E+04, 0.85262100E+04, 0.39327400E+05, -.19133400E+05, -.21536600E+05, -.19665700E+05, -.82562500E+05, -.83705300E+04, -.40004000E+05, -.79501700E+05, -.35161600E+05, 0.15832600E+03, 0.64035100E+05, -.27423000E+06, 0.13238900E+06, 0.56713400E+05, 0.13730200E+06, 0.42200700E+05, -.43703900E+05, 0.92093800E+05, 0.38946700E+05, 0.12660500E+06, -.31532900E+05, 0.27769900E+05, 0.12714000E+06, -.61074500E+05, -.46868600E+04, -.63602700E+05, -.17935200E+05, 0.21996700E+05, -.45066700E+05, -.22855500E+05, -.67220200E+05, 0.13599400E+05, -.55406200E+04, 0.14850200E+05, -.81673500E+04, 0.18033400E+04, -.74349800E+04, -.64665000E+04, -.70473500E+03, -.27739600E+04, -.21604300E+04, -.10648500E+05, -.15187900E+04, -.14111000E+04, 0.10840600E+06, -.53148300E+05, -.35522300E+05, -.54198900E+05, -.93289000E+05, 0.20675900E+05, -.60194200E+05, -.75014300E+05, -.66195200E+05, 0.24288400E+05, 0.55084900E+05, 0.49052900E+04, -.32645500E+04, 0.10400700E+05, -.24847700E+04, -.18542900E+05, 0.55979300E+04, -.92679100E+04, -.17369400E+05, -.15879900E+05, 0.24381400E+04, 0.31306300E+05, -.11872400E+05, 0.69072900E+04, -.20445800E+05, 0.59831800E+04, 0.16363700E+05, 0.50864300E+04, 0.12946200E+04, 0.88095100E+04, 0.18586200E+05, 0.51768300E+04, -.38179900E+04, 0.14697600E+06, -.71370200E+05, -.12374500E+05, -.73574500E+05, -.20993000E+05, 0.23112600E+05, -.50895200E+05, -.24088100E+05, -.73806200E+05, 0.14233900E+05, -.77814100E+04, -.50640200E+05, 0.26290600E+05, 0.55829200E+04, 0.25376300E+05, 0.10778600E+06, 0.13081600E+05, 0.43795800E+05, 0.86214400E+05, 0.57825800E+05, 0.81203600E+04, -.85440600E+05, -.11224700E+06, 0.59434700E+05, 0.96172100E+04, 0.56157100E+05, 0.70468600E+05, -.28133700E+04, 0.50630500E+05, 0.63988000E+05, 0.73016600E+05, -.62731000E+04, -.30853600E+05, -.13108100E+06, 0.64014700E+05, 0.35547500E+05, 0.65562700E+05, 0.58332300E+05, -.38730900E+05, 0.59197100E+05, 0.49275700E+05, 0.67123500E+05, -.34887600E+05, -.37608000E+05, 0.34331400E+05, -.16157000E+05, -.14583200E+05, -.17152000E+05, 0.90306900E+04, 0.87062400E+04, -.82364500E+04, 0.57744900E+04, -.86762600E+04, 0.70781300E+04, -.20162100E+05, -.14782100E+06, 0.72503700E+05, 0.35552500E+05, 0.73945800E+05, 0.79813600E+05, -.46837800E+05, 0.75292400E+05, 0.75955800E+05, 0.86159000E+05, -.42159400E+05, -.52913000E+05, 0.11402800E+06, -.59825900E+05, 0.13161100E+04, -.57078000E+05, -.54060300E+05, -.97056200E+03, -.37480900E+05, -.41194300E+05, -.75718600E+05, -.22485700E+04, 0.10419400E+05, -.20263600E+05, 0.12751300E+05, -.18723100E+05, 0.10225700E+05, 0.16887000E+05, 0.32442100E+04, 0.43168400E+04, 0.10962900E+05, 0.28522100E+05, 0.43707100E+04, -.90161600E+03, 0.98199000E+05, -.46816600E+05, -.13527400E+05, -.49140400E+05, -.14145000E+05, 0.19651500E+05, -.36791900E+05, -.21137800E+05, -.50601600E+05, 0.14809300E+05, -.99880600E+04, -.29567800E+05, 0.17099600E+05, -.15558200E+05, 0.14786500E+05, 0.22006000E+05, 0.74694400E+04, 0.72629200E+04, 0.11401700E+05, 0.22715500E+05, 0.65991800E+04, -.48140500E+04, 0.13402100E+06, -.64091600E+05, -.24004500E+05, -.67103200E+05, -.23033600E+05, 0.20920200E+05, -.44040200E+05, -.17450800E+05, -.63499500E+05, 0.14402100E+05, -.11445800E+05, -.18099400E+05, -.34714300E+05, 0.15078800E+05, -.27234600E+04, -.35790400E+05, 0.16172800E+05, 0.16072300E+05, 0.19931400E+05, -.21011000E+05, -.86403300E+05, 0.10712200E+06, 0.16437900E+05, 0.14304700E+05, 0.57076700E+04, -.25980800E+05, -.10315100E+06, -.89629400E+04, -.16701700E+04, 0.24933900E+05, -.83565200E+05, -.23629900E+05, -.18695900E+05, 0.18908600E+05, -.98691600E+05, 0.13278700E+05, -.86039100E+05 },
        { 0.25106200E+01, 0.21497000E-01, -.16306600E-01, 0.13114300E+01, 0.25195400E+00, 0.76935100E+05, -.42457100E+05, -.54319900E+05, -.58336500E+05, 0.74139200E+05, 0.32574600E+05, 0.59130300E+05, -.28907500E+05, -.31147900E+05, -.29611900E+05, -.13688600E+05, 0.63107200E+05, -.45024200E+05, -.37796000E+05, -.51147300E+05, 0.61299300E+05, 0.11624300E+05, 0.19755300E+06, -.96020200E+05, -.88018900E+05, -.98633700E+05, -.39342300E+05, -.15446200E+06, 0.68933000E+05, 0.14793300E+06, 0.74859800E+05, -.14987700E+06, -.12191100E+06, 0.48358900E+05, -.23352000E+05, -.20671800E+05, -.24067600E+05, -.46717800E+04, -.47345300E+05, 0.22158600E+05, 0.47632200E+05, 0.30534800E+05, -.46082400E+05, -.44145200E+05, 0.70860000E+05, -.34135000E+05, -.21306200E+05, -.35249500E+05, 0.12406600E+04, -.75715700E+05, 0.35333800E+05, 0.76196800E+05, 0.54192700E+05, -.74205900E+05, -.75191800E+05, -.28862200E+06, 0.13946600E+06, 0.12488200E+06, 0.14400600E+06, 0.42725900E+05, 0.68700400E+05, 0.85578600E+03, -.98888700E+05, 0.10343800E+05, 0.64585900E+05, 0.11593600E+06, -.17684700E+05, 0.86197900E+04, 0.74952400E+04, 0.88304100E+04, 0.33652400E+04, 0.13823800E+05, -.61838100E+04, -.13103500E+05, -.64919100E+04, 0.13450000E+05, 0.10879000E+05, 0.72524700E+05, -.35178400E+05, -.37202500E+05, -.36269600E+05, -.14064500E+05, 0.35925600E+05, -.31642500E+05, -.16669900E+05, -.36028300E+05, 0.35685800E+05, -.50704300E+04, 0.12630400E+06, -.65034900E+05, -.68650400E+05, -.62694300E+05, -.45701800E+05, -.10481500E+06, 0.46666900E+05, 0.87348100E+05, 0.57106400E+05, -.99991000E+05, -.65415800E+05, -.10350300E+06, 0.52372200E+05, 0.53043600E+05, 0.51673000E+05, 0.26159100E+05, 0.61317700E+05, -.18112500E+05, -.52422800E+05, -.26971700E+05, 0.57259600E+05, 0.54987500E+05, -.45465600E+05, 0.21434900E+05, 0.19603300E+05, 0.22709500E+05, 0.55651300E+04, 0.10442100E+05, 0.11996300E+04, -.14696400E+05, 0.31912900E+04, 0.94875500E+04, 0.19124000E+05, 0.88943500E+05, -.42577000E+05, -.53190400E+05, -.44457500E+05, -.21307000E+05, 0.44225600E+05, -.40385000E+05, -.22160800E+05, -.53095600E+05, 0.45824900E+05, 0.78684600E+04, -.66271100E+05, 0.31987200E+05, 0.29231400E+05, 0.33072600E+05, 0.56377900E+04, 0.17587200E+05, -.11434100E+04, -.27700200E+05, -.76081500E+04, 0.16865100E+05, 0.34802900E+05, 0.13995400E+06, -.68376300E+05, -.58236300E+05, -.69879700E+05, -.19816900E+05, -.32735900E+05, -.15576800E+04, 0.44085600E+05, -.11421600E+05, -.30507200E+05, -.57482300E+05, -.11955100E+06, 0.60399800E+05, 0.63374900E+05, 0.59557400E+05, 0.35013200E+05, 0.72163900E+05, -.24368400E+05, -.62997700E+05, -.34334500E+05, 0.68370500E+05, 0.57715000E+05, 0.98248200E+05, -.47577300E+05, -.43803400E+05, -.49012600E+05, -.19927400E+05, -.89837700E+05, 0.41725300E+05, 0.79257600E+05, 0.53694000E+05, -.87123100E+05, -.66401300E+05, 0.22419500E+06, -.10823500E+06, -.89831500E+05, -.11201100E+06, -.34373900E+05, -.79169100E+05, 0.23747800E+05, 0.99292700E+05, 0.10505000E+05, -.78880700E+05, -.10645400E+06, -.13567900E+05, 0.65298500E+04, 0.10626700E+05, 0.68397800E+04, 0.96356100E+04, -.41252300E+05, 0.27957300E+05, 0.33845300E+05, 0.32170800E+05, -.41524200E+05, -.30237500E+05, 0.35780000E+05, -.17251800E+05, -.14921300E+05, -.17854100E+05, -.49385900E+04, -.98836900E+04, 0.70843500E+03, 0.11847300E+05, 0.30496200E+03, -.97434200E+04, -.16114400E+05, -.33050800E+04, 0.18646600E+04, 0.61036000E+04, 0.17436400E+04, 0.87238700E+04, -.62181300E+05, 0.38313800E+05, 0.55195500E+05, 0.49537400E+05, -.62045200E+05, -.36641100E+05, -.26221700E+06, 0.12654000E+06, 0.11032600E+06, 0.13095300E+06, 0.37060000E+05, 0.75126300E+05, -.72025000E+04, -.96375700E+05, 0.93061800E+04, 0.71230900E+05, 0.11813600E+06, 0.18129700E+06, -.86589300E+05, -.78171500E+05, -.90436400E+05, -.24635400E+05, -.39309800E+05, -.44587700E+04, 0.58846700E+05, -.10445000E+05, -.36264500E+05, -.71627100E+05, -.46502800E+05, 0.23883600E+05, 0.23662300E+05, 0.23146400E+05, 0.11211500E+05, 0.36694000E+05, -.13720800E+05, -.31198200E+05, -.17958300E+05, 0.34271400E+05, 0.29857900E+05, 0.19956700E+06, -.96428700E+05, -.85749100E+05, -.99756000E+05, -.36570800E+05, -.54133200E+05, 0.82381000E+04, 0.67129800E+05, -.75262700E+04, -.52182900E+05, -.79976000E+05, -.72321400E+05, 0.37319700E+05, 0.38267400E+05, 0.35928600E+05, 0.24595700E+05, 0.55269500E+05, -.23103500E+05, -.45615900E+05, -.29702400E+05, 0.52503600E+05, 0.37043500E+05, 0.28841500E+05, 0.37214500E+05, -.43290700E+05, -.35735400E+04, 0.34132600E+05, -.51989600E+05, 0.40418300E+05, 0.38848000E+04, 0.45461700E+05, -.33356300E+05, 0.17705400E+05, 0.46672900E+05, -.61962400E+05, -.59149400E+05, -.49805400E+05, -.28476100E+05, -.31926800E+05, 0.20356300E+04, -.54158700E+05, -.10733400E+05, 0.49911100E+05, -.44812400E+05, 0.43492400E+05, -.76704700E+04, -.65182700E+03, -.31571500E+05 },
        { 0.20066100E+01, -.90636500E-01, -.14938000E-01, 0.10776700E-01, -.40703600E-01, -.16109100E+00, 0.13446900E+05, 0.34777900E+05, 0.60299900E+04, -.21481700E+04, 0.31508800E+04, -.16154700E+06, 0.80855800E+05, 0.79350200E+05, 0.80768200E+05, 0.53546900E+04, -.92641600E+04, 0.88930500E+05, 0.10665900E+06, 0.82460900E+05, -.11314100E+05, 0.36098300E+05, 0.12348000E+06, -.62331300E+05, -.67732700E+05, -.61718600E+05, -.76660400E+04, 0.67107900E+04, -.77204400E+05, -.10740900E+06, -.60305600E+05, 0.84918300E+04, -.24101700E+05, 0.69445400E+05, -.35272500E+05, -.34920000E+05, -.34708900E+05, -.30077600E+04, 0.46399700E+04, -.41343700E+05, -.53266200E+05, -.35082700E+05, 0.52524100E+04, -.16428800E+05, 0.15004400E+06, -.75582700E+05, -.72873500E+05, -.74997500E+05, -.10260400E+04, 0.11786700E+05, -.89885300E+05, -.11440900E+06, -.78386700E+05, 0.12515200E+05, -.38130600E+05, -.20375400E+04, 0.17292200E+04, 0.11374100E+05, 0.97591400E+03, -.42536500E+02, -.40783100E+04, 0.16635400E+05, 0.32880800E+05, 0.46664400E+04, -.29610300E+04, -.93141400E+04, -.14075700E+05, 0.70814800E+04, 0.73859400E+04, 0.70360800E+04, 0.56731500E+03, -.84176200E+03, 0.83431300E+04, 0.10970400E+05, 0.68231000E+04, -.96478800E+03, 0.32378100E+04, -.12400300E+06, 0.61812800E+05, 0.56993100E+05, 0.62000800E+05, 0.46450700E+04, -.74312300E+04, 0.65288600E+05, 0.74400800E+05, 0.62915100E+05, -.87854400E+04, 0.28471200E+05, 0.76346300E+05, -.38971000E+05, -.44706800E+05, -.38117300E+05, -.92429900E+04, -.62699500E+04, -.43808800E+05, -.61980400E+05, -.33483700E+05, -.45426900E+04, -.99850000E+04, -.45404400E+05, 0.23194100E+05, 0.26752200E+05, 0.22692500E+05, 0.40573600E+04, 0.35115000E+04, 0.31234300E+05, 0.46434200E+05, 0.22264600E+05, 0.29720300E+04, 0.60822400E+04, 0.11716400E+05, -.56781400E+04, -.37442700E+04, -.58611500E+04, -.12226800E+04, -.12319000E+04, -.10383900E+04, 0.33737600E+04, -.33172700E+04, -.10428400E+04, -.43609700E+04, -.71545700E+05, 0.35442800E+05, 0.23810800E+05, 0.35774100E+05, -.13259800E+03, -.93424900E+04, 0.42824000E+05, 0.55322600E+05, 0.39313700E+05, -.12153500E+05, 0.25698800E+05, -.44009000E+05, 0.22146400E+05, 0.23313700E+05, 0.21994500E+05, -.60697300E+03, -.36271900E+04, 0.26120200E+05, 0.32994300E+05, 0.22196600E+05, -.26941800E+04, 0.89811600E+04, -.32226500E+05, 0.15871900E+05, 0.86533000E+04, 0.16127800E+05, 0.19963100E+04, 0.31435200E+04, 0.29236300E+04, -.81481000E+04, 0.10950200E+05, 0.21096700E+04, 0.13578100E+05, -.51432700E+05, 0.26094500E+05, 0.29749400E+05, 0.25691000E+05, 0.57411200E+04, 0.53382700E+04, 0.31579400E+05, 0.45672000E+05, 0.23061000E+05, 0.46053600E+04, 0.72478700E+04, 0.13378700E+06, -.67103700E+05, -.65438700E+05, -.66875700E+05, -.42000500E+04, 0.17880600E+04, -.70987700E+05, -.85757000E+05, -.63142800E+05, 0.29489400E+04, -.32297300E+05, 0.15482600E+06, -.77718700E+05, -.77371600E+05, -.77402700E+05, -.42787900E+04, 0.13349300E+05, -.81183500E+05, -.90659800E+05, -.70579100E+05, 0.11603400E+05, -.31538600E+05, 0.10237800E+06, -.51691500E+05, -.49332700E+05, -.51182100E+05, -.47162800E+03, 0.12272700E+05, -.61144100E+05, -.76328400E+05, -.54435900E+05, 0.12882200E+05, -.27375600E+05, 0.58697600E+04, -.28012100E+04, -.28862000E+04, -.29308500E+04, 0.59340700E+03, 0.85110500E+02, -.40132400E+04, -.60007700E+04, -.25655500E+04, -.11296000E+03, -.25936400E+04, 0.12111900E+06, -.61182700E+05, -.57006200E+05, -.60549000E+05, -.18590200E+04, 0.13964200E+05, -.72103700E+05, -.90870300E+05, -.64602900E+05, 0.15158400E+05, -.29612500E+05, -.17056400E+04, 0.15782700E+04, 0.12292300E+05, 0.83348200E+03, -.26223300E+03, -.69427900E+04, 0.24338300E+05, 0.47633900E+05, 0.98889700E+04, -.60185100E+04, -.11398300E+05, -.31061500E+05, 0.14965800E+05, 0.80440700E+04, 0.15559500E+05, 0.25925500E+04, 0.37017800E+04, 0.25684000E+04, -.81694800E+04, 0.10548900E+05, 0.28799400E+04, 0.12796900E+05, -.26444800E+05, 0.13686800E+05, 0.16612200E+05, 0.13210400E+05, 0.31256000E+04, 0.40216800E+03, 0.19582200E+05, 0.29426300E+05, 0.13842100E+05, -.17288100E+03, 0.84196900E+03, 0.34457600E+05, -.17695300E+05, -.23806500E+05, -.17228600E+05, -.16175900E+04, 0.72935600E+03, -.21518600E+05, -.27469700E+05, -.13573100E+05, -.35488700E+03, -.56653800E+04, -.45387000E+05, 0.23198100E+05, 0.25569900E+05, 0.22666000E+05, 0.39229700E+04, 0.38336300E+04, 0.24961300E+05, 0.34434700E+05, 0.19439900E+05, 0.31177800E+04, 0.84050800E+04, 0.23149100E+05, 0.26995500E+05, 0.10196000E+05, 0.11486200E+05, -.39947700E+04, -.48706900E+04, -.18765400E+05, -.24455500E+04, -.13739200E+05, -.38733700E+04, -.18687500E+03, -.21034700E+05, -.17306400E+05, -.73141100E+04, 0.23906000E+05, -.15960800E+04, 0.13445100E+05, -.66251100E+04, -.89038500E+04, 0.19032800E+05, 0.10390900E+05, 0.19143200E+05, -.21253900E+05, -.44956600E+04, -.20018700E+05, 0.12841000E+04 },
        { 0.92297000E+00, -.26865300E-01, -.23346400E-01, -.16830100E-02, 0.96675300E-02, -.53399400E-01, -.11206200E+01, 0.24343400E+05, -.73075200E+04, -.17799000E+02, 0.88531800E+04, -.80149800E+05, 0.40202800E+05, 0.56901300E+05, 0.40067300E+05, -.55272800E+04, -.22086400E+05, 0.58150700E+05, 0.82808400E+05, 0.42972900E+05, -.20884300E+05, 0.11995400E+05, 0.14670100E+06, -.74434700E+05, -.11766500E+06, -.73318900E+05, -.54326000E+05, -.57468100E+05, 0.34858800E+05, -.24664900E+05, 0.12828400E+05, -.57689100E+05, -.40153000E+05, 0.12055600E+05, -.69405000E+04, -.22728800E+05, -.60075500E+04, -.34353700E+04, 0.36635600E+04, -.16387600E+05, -.40199700E+05, -.15224500E+04, 0.30349600E+04, 0.37005900E+04, 0.15433000E+05, -.86698800E+04, -.45326100E+05, -.76798800E+04, 0.78969700E+04, 0.21469100E+05, -.48254300E+05, -.97824100E+05, -.16324400E+05, 0.18898000E+05, 0.73769600E+04, 0.11099700E+06, -.54223000E+05, 0.10598000E+05, -.55562600E+05, -.16621300E+04, 0.12402300E+04, -.37954400E+05, 0.22879100E+05, -.54284800E+05, 0.41562600E+04, -.53018400E+05, -.15630100E+05, 0.78971900E+04, 0.12453300E+05, 0.78124100E+04, 0.50209100E+04, 0.51994200E+04, -.26590100E+04, 0.28377300E+04, -.40707600E+03, 0.53003100E+04, 0.43258300E+04, -.82492500E+05, 0.40922800E+05, 0.36252000E+05, 0.41245500E+05, -.36180400E+04, -.17461300E+05, 0.48890300E+05, 0.56912900E+05, 0.43635100E+05, -.16764500E+05, 0.19752900E+05, 0.12763000E+06, -.64998900E+05, -.10068100E+06, -.63732700E+05, -.54805200E+05, -.70771900E+05, 0.44682700E+05, 0.83130400E+04, 0.17562100E+05, -.68260300E+05, -.40596200E+05, 0.15878800E+05, -.71602800E+04, 0.21064500E+05, -.79537400E+04, 0.51981500E+04, 0.65182300E+04, 0.21860400E+04, 0.31153800E+05, -.17463200E+05, 0.69971200E+04, -.12046900E+05, 0.42742900E+05, -.21054600E+05, -.96761300E+04, -.21375800E+05, -.62851400E+04, -.56814600E+04, -.57496400E+04, 0.87093800E+04, -.11918100E+05, -.52665300E+04, -.16372500E+05, -.67124400E+05, 0.32963400E+05, 0.15666900E+05, 0.33563900E+05, -.77477000E+04, -.19907200E+05, 0.40995700E+05, 0.49788600E+05, 0.36408700E+05, -.20834400E+05, 0.30909900E+05, 0.88017800E+04, -.40980700E+04, 0.12873000E+05, -.44160800E+04, -.25687800E+04, -.47721300E+04, 0.11038500E+05, 0.30029100E+05, -.13638400E+04, -.32459500E+04, -.95966500E+04, -.97737100E+05, 0.48426200E+05, 0.94558700E+04, 0.48890400E+05, 0.47404000E+04, 0.47877300E+04, 0.24676600E+05, -.12630000E+05, 0.39471100E+05, 0.21442900E+04, 0.42617300E+05, -.39894500E+05, 0.20545000E+05, 0.47089900E+05, 0.19910200E+05, 0.23426400E+05, 0.30588300E+05, -.15081000E+05, 0.10893700E+05, -.17523700E+05, 0.30204300E+05, 0.10020900E+05, 0.16355500E+06, -.82204400E+05, -.99754800E+05, -.81751200E+05, -.34312400E+05, -.39161800E+05, 0.35056600E+04, -.19436900E+05, -.15635600E+05, -.39789600E+05, -.50342300E+05, 0.16049900E+06, -.80940700E+05, -.12903000E+06, -.80234700E+05, -.50387900E+05, -.49025300E+05, 0.26239200E+05, -.15935200E+05, -.19476300E+04, -.51851500E+05, -.34102000E+05, 0.23405700E+05, -.12515900E+05, -.27408700E+05, -.11693000E+05, 0.15968600E+04, 0.14273900E+05, -.35073500E+05, -.68495500E+05, -.20049200E+05, 0.14844200E+05, -.10187800E+04, 0.11569200E+05, -.56221100E+04, -.86580900E+04, -.57787300E+04, -.48543800E+04, -.57708700E+04, 0.52422000E+04, 0.11392500E+04, 0.30902800E+04, -.63246900E+04, -.44149000E+04, 0.28754700E+05, -.15370000E+05, -.29043400E+05, -.14362100E+05, 0.42069900E+04, 0.20235800E+05, -.43766800E+05, -.81621500E+05, -.24806600E+05, 0.20642700E+05, -.19512500E+04, 0.13473500E+06, -.66055000E+05, 0.79638300E+04, -.67396200E+05, -.15419100E+04, -.13389300E+04, -.39261700E+05, 0.37169500E+05, -.56340800E+05, 0.25251400E+04, -.65141300E+05, -.11555700E+06, 0.56790800E+05, 0.18236800E+05, 0.57821000E+05, 0.13234700E+05, 0.12698100E+05, 0.20898100E+05, -.18708900E+05, 0.40219400E+05, 0.10927600E+05, 0.46986900E+05, 0.18680000E+05, -.86231100E+04, 0.97203100E+04, -.93575400E+04, 0.11668900E+04, -.10067000E+04, 0.43108000E+04, 0.23608100E+05, -.98354700E+04, -.85536200E+03, -.13495000E+05, 0.71540500E+05, -.36644400E+05, -.80676300E+05, -.35770500E+05, -.45610900E+05, -.55595300E+05, 0.59853000E+05, 0.29938800E+05, 0.32404300E+05, -.57244300E+05, -.14955700E+05, -.69287900E+05, 0.35392200E+05, 0.54361300E+05, 0.34603600E+05, 0.26835200E+05, 0.36558200E+05, -.21266200E+05, -.27228900E+04, -.80241200E+04, 0.35663600E+05, 0.23180200E+05, 0.25888400E+05, 0.27571600E+05, -.62971900E+03, -.63010000E+04, 0.70113600E+04, -.12643100E+05, 0.23564200E+05, -.29262200E+04, -.44915600E+04, 0.12287500E+05, -.26377400E+05, 0.28345300E+05, -.16200200E+05, -.14347100E+05, -.20471500E+05, 0.20939300E+05, 0.13826700E+05, 0.17867700E+04, -.14238500E+05, 0.17851700E+05, 0.16707300E+05, -.21653200E+05, 0.27655800E+05, 0.22792500E+05, -.64476400E+04, 0.18918300E+05 },
        { 0.12017100E+01, -.27895000E-01, -.25992400E-01, 0.11546100E+00, 0.79869300E-01, -.11733000E+00, -.15919600E+00, -.15155200E+00, -.18304000E+05, 0.21661900E+04, 0.13337800E+04, 0.26616100E+04, -.11275600E+04, 0.12978600E+05, -.13485900E+04, -.35052300E+04, -.11281600E+05, 0.16663000E+05, 0.25721000E+05, -.51520500E+04, -.82250700E+04, -.10864400E+05, -.21269800E+05, 0.10614000E+05, -.24997500E+05, 0.10694800E+05, -.11510100E+05, -.50522000E+04, 0.62464700E+04, -.46031300E+04, 0.61974500E+05, -.11202700E+05, 0.24151800E+05, -.11468900E+05, 0.56545300E+04, -.88750200E+04, 0.57783100E+04, -.25538300E+04, 0.13360600E+04, -.30826300E+04, -.79854900E+04, 0.20139800E+05, -.67236700E+03, 0.10244100E+05, -.15729600E+05, 0.78827400E+04, -.23698600E+05, 0.79383000E+04, -.26988800E+03, 0.61732500E+04, -.11118100E+05, -.20945100E+05, 0.29471100E+05, 0.22701100E+04, 0.15707500E+05, 0.87103300E+05, -.43874500E+05, 0.61204500E+04, -.43677300E+05, -.28553000E+04, -.10366000E+05, -.96628100E+04, 0.67301300E+04, -.61533700E+05, -.50269000E+04, -.47868900E+05, 0.18452900E+04, -.91977200E+03, 0.28889300E+04, -.92765000E+03, 0.95868900E+03, 0.22117300E+03, -.33796000E+03, 0.78056800E+03, -.54554300E+04, 0.84346500E+03, -.22753600E+04, -.15866300E+05, 0.80702100E+04, 0.52590700E+04, 0.79306900E+04, -.23214700E+04, -.72508300E+04, 0.14650700E+05, 0.17841700E+05, 0.82310800E+04, -.58581200E+04, 0.10186000E+04, 0.14211800E+05, -.75897100E+04, -.31417900E+05, -.69252700E+04, -.14718500E+05, -.15398700E+05, 0.76733900E+04, 0.52254100E+04, 0.35375000E+05, -.17674000E+05, 0.42897300E+04, 0.29278500E+05, -.14324200E+05, 0.97950500E+04, -.14670900E+05, 0.31323100E+04, -.45190700E+03, -.50878400E+03, 0.56022300E+04, -.35386900E+05, 0.25556600E+04, -.19134700E+05, 0.23542500E+05, -.11908900E+05, -.41488100E+04, -.11780600E+05, -.26436700E+04, -.38195400E+04, -.16945000E+04, 0.31215200E+04, -.11222400E+05, -.28471500E+04, -.10891600E+05, -.27193600E+05, 0.13738800E+05, 0.22993600E+04, 0.13601800E+05, -.38293500E+04, -.83203500E+04, 0.13929100E+05, 0.11702600E+05, 0.78981200E+04, -.68863000E+04, 0.12565600E+05, 0.87028200E+04, -.44370600E+04, 0.95647100E+04, -.43786700E+04, 0.11445300E+04, 0.16562600E+03, 0.14142400E+04, 0.49177600E+04, -.14104100E+05, 0.13818300E+04, -.73103400E+04, -.79167700E+05, 0.39538100E+05, 0.82667600E+04, 0.39624900E+05, 0.42522000E+04, 0.10622200E+05, 0.76486600E+04, -.83231600E+04, 0.40733300E+05, 0.66228500E+04, 0.39101400E+05, 0.62027800E+04, -.28430800E+04, 0.17135100E+05, -.31870500E+04, 0.82024000E+04, 0.69697000E+04, -.34862100E+04, -.12165800E+04, -.32778600E+05, 0.94263100E+04, -.10022200E+05, 0.36109700E+05, -.17913700E+05, -.32018300E+05, -.18006900E+05, -.88634900E+04, -.74304100E+04, -.32555700E+04, 0.67114000E+03, 0.21844700E+05, -.10646800E+05, -.57848000E+04, -.30602900E+05, 0.15453100E+05, -.27027400E+05, 0.15334700E+05, -.81357900E+04, 0.25358300E+04, 0.24924900E+04, -.11429000E+05, 0.47217000E+05, -.36564500E+04, 0.31387300E+05, -.32201400E+05, 0.15743700E+05, -.87342600E+03, 0.16122500E+05, 0.16698300E+04, 0.85914900E+04, -.77558200E+04, -.22938800E+05, 0.15860700E+05, 0.64740300E+04, 0.19447700E+05, -.47580000E+04, 0.24582200E+04, -.16430800E+04, 0.23927900E+04, -.11030400E+04, -.15617900E+03, 0.13391400E+04, 0.50620200E+03, 0.77304800E+04, -.10257200E+04, 0.30710600E+04, -.13740700E+05, 0.66718800E+04, -.72720600E+04, 0.69053000E+04, 0.83155500E+03, 0.72398300E+04, -.10522500E+05, -.21449700E+05, 0.14259700E+05, 0.51140800E+04, 0.12084800E+05, 0.13188700E+06, -.66060200E+05, -.82785500E+04, -.66004600E+05, -.69330300E+04, -.18279100E+05, -.10292900E+05, 0.19615800E+05, -.70069300E+05, -.11169700E+05, -.68650800E+05, -.66962100E+05, 0.33845400E+05, 0.40162400E+04, 0.33567200E+05, 0.48464000E+04, 0.99311200E+04, 0.62613200E+04, -.46184700E+04, 0.41377100E+05, 0.65359600E+04, 0.33185500E+05, 0.24878700E+05, -.12171800E+05, 0.41346200E+04, -.12480200E+05, 0.97127600E+03, -.26242700E+04, 0.40886000E+03, 0.60553300E+04, -.21824400E+05, -.67732100E+03, -.15254200E+05, -.47167100E+05, 0.23695300E+05, -.13822000E+05, 0.23590800E+05, -.74501800E+04, -.15905600E+04, 0.13252200E+05, 0.11266000E+04, 0.45853600E+05, -.61760600E+04, 0.31051300E+05, -.11881100E+05, 0.62235300E+04, 0.19297300E+05, 0.58500200E+04, 0.75089200E+04, 0.86137000E+04, -.33996800E+04, -.34850500E+04, -.18602100E+05, 0.98674800E+04, 0.15941000E+03, -.27368700E+04, -.25810600E+04, 0.82295200E+04, -.44554200E+04, -.74979300E+04, 0.63023800E+04, 0.17639700E+05, -.27404100E+03, -.10929700E+05, 0.88526900E+04, -.11910700E+05, 0.22625600E+05, 0.60309200E+04, 0.67954500E+04, -.14260200E+05, 0.10477600E+05, 0.14576400E+05, 0.22981900E+04, 0.31211900E+04, 0.22846300E+04, -.46406900E+04, -.17349700E+05, 0.18914300E+05, 0.91051300E+04, -.49448500E+04, 0.12568600E+05 },
        { -.17225800E+01, 0.54988000E-01, 0.60340900E-01, 0.73136400E+00, -.25174000E+00, 0.65271700E+00, -.22707000E+00, 0.21418100E+00, 0.23926600E+00, -.10199100E+05, 0.58692200E+04, -.79084100E+04, 0.40244100E+04, -.94772800E+04, 0.39406600E+04, 0.40012400E+04, 0.75922300E+04, -.67883100E+04, -.71936200E+04, 0.15142200E+04, -.15662800E+04, 0.10286700E+05, 0.63354800E+04, -.22093700E+04, 0.41520300E+05, -.30983100E+04, 0.15054900E+05, 0.13580600E+05, -.22364800E+05, -.10131600E+05, -.23861900E+05, 0.31393400E+05, -.23165700E+05, 0.14378500E+05, -.66772900E+04, 0.58286500E+04, -.71500300E+04, -.13911400E+04, -.91381000E+04, 0.32737500E+04, 0.69055600E+04, -.23991300E+04, -.12668700E+04, -.12665600E+05, 0.22164200E+05, -.10503000E+05, 0.19098800E+05, -.11005900E+05, -.88483200E+04, -.28922900E+05, 0.15924500E+05, 0.22852700E+05, 0.51636300E+04, -.11442900E+05, -.23792000E+05, -.12757400E+06, 0.62520600E+05, -.26191100E+04, 0.63651700E+05, 0.12377900E+05, 0.21243700E+05, 0.14459000E+05, -.23211100E+05, 0.31642000E+05, 0.90251200E+04, 0.65691300E+05, -.41179600E+03, 0.12935100E+03, -.43658500E+04, 0.20009300E+03, -.12976800E+04, -.10730200E+04, 0.20193300E+04, 0.88688200E+03, 0.22435900E+04, -.27500300E+04, 0.20611300E+04, 0.82021400E+04, -.37885900E+04, -.18856600E+03, -.41017400E+04, 0.17659200E+04, 0.11293700E+04, -.49395800E+04, -.28533600E+04, -.30443100E+04, -.28889400E+04, -.14576800E+04, -.41677700E+05, 0.21217600E+05, 0.46212700E+05, 0.20997300E+05, 0.19722100E+05, 0.15873600E+05, -.15347900E+05, -.16036000E+05, -.86503600E+04, 0.26711100E+05, 0.31398700E+04, -.24866500E+05, 0.12011300E+05, -.72733200E+04, 0.12405200E+05, -.53947200E+03, 0.94890300E+04, -.17600900E+04, -.83248600E+04, 0.69558900E+04, 0.43613100E+03, 0.18707300E+05, -.30232100E+05, 0.14774600E+05, 0.34346300E+04, 0.15107400E+05, 0.44404000E+04, 0.64731500E+04, 0.11764900E+04, -.72186600E+04, 0.53580500E+04, 0.41218300E+04, 0.15034000E+05, 0.52632400E+05, -.25764800E+05, -.86772300E+04, -.26314100E+05, 0.18724200E+04, 0.13743900E+05, -.19818000E+05, -.64349200E+04, -.22527000E+05, 0.50306300E+04, -.16320200E+05, -.19578500E+05, 0.94583000E+04, -.61351200E+04, 0.97547700E+04, 0.37105800E+04, 0.11468300E+05, -.50890800E+04, -.11975300E+05, -.61842400E+03, 0.53359600E+04, 0.14058800E+05, 0.80332100E+05, -.39692600E+05, -.39635100E+03, -.40118000E+05, -.72445800E+04, -.11394400E+05, -.87968000E+04, 0.14451200E+05, -.23155200E+05, -.56644500E+04, -.40267900E+05, 0.51989600E+04, -.29258100E+04, -.20087900E+05, -.26682800E+04, -.83081400E+04, -.14598400E+04, 0.43271400E+04, 0.18144200E+04, 0.65628700E+04, -.10347800E+05, 0.65972900E+04, -.28052100E+05, 0.14466200E+05, 0.32213500E+05, 0.14085700E+05, 0.11272700E+05, 0.65913200E+04, -.71062300E+04, -.43363600E+04, -.37827100E+04, 0.18166400E+05, -.84376900E+03, 0.61215100E+04, -.21456800E+04, 0.46986200E+05, -.30338400E+04, 0.11323300E+05, 0.50345800E+04, -.18379900E+05, -.55591000E+04, -.22615500E+05, 0.16382300E+05, -.18650100E+05, -.14886300E+05, 0.77501600E+04, 0.21079500E+05, 0.74617100E+04, -.76035600E+03, -.12437800E+05, 0.12825600E+05, 0.74805400E+04, 0.58319500E+04, -.28941700E+04, -.46978900E+04, 0.30282000E+04, -.14517300E+04, 0.20613700E+04, -.15035500E+04, 0.15031700E+04, 0.41547300E+03, -.19844800E+04, 0.29286500E+03, -.22772700E+04, 0.19530200E+04, -.23847900E+04, -.11878700E+05, 0.63561800E+04, 0.16215100E+05, 0.59672400E+04, -.30431200E+04, -.13881200E+05, 0.13314900E+05, 0.90527500E+04, 0.79277200E+04, -.16198700E+04, -.52107000E+04, -.13044000E+06, 0.63961300E+05, -.10320700E+05, 0.65164200E+05, 0.10853300E+05, 0.21708000E+05, 0.15484400E+05, -.22686000E+05, 0.37984200E+05, 0.76219500E+04, 0.71558700E+05, 0.99597000E+05, -.48782100E+05, -.91716000E+04, -.49710200E+05, -.13296200E+05, -.18661100E+05, -.62044400E+04, 0.23122300E+05, -.19604200E+05, -.11654700E+05, -.47901700E+05, -.21819500E+05, 0.10592000E+05, -.25315900E+04, 0.10877700E+05, 0.13487800E+04, 0.73771200E+04, -.13971800E+04, -.64348800E+04, 0.51639400E+04, 0.19269700E+04, 0.13901700E+05, 0.18846200E+05, -.85459900E+04, 0.35300100E+05, -.94303600E+04, 0.13183000E+05, 0.13032700E+05, -.26195600E+05, -.12801800E+05, -.29967700E+05, 0.18586000E+05, -.18187300E+05, 0.19505700E+05, -.99764300E+04, -.23696600E+05, -.98288100E+04, -.95543000E+04, -.68898100E+04, 0.71553800E+04, 0.70440500E+04, 0.37072300E+04, -.12878800E+05, -.35001900E+03, 0.84299900E+03, -.11985000E+04, -.37090700E+03, 0.62747200E+04, -.20263500E+04, 0.35044400E+04, -.11387000E+05, 0.74475800E+03, 0.14557800E+04, -.81551400E+04, 0.10398800E+05, -.12132000E+05, 0.24409600E+04, -.12222200E+04, 0.45718900E+04, -.10329600E+05, -.35850900E+04, -.31854000E+04, -.56083700E+04, -.61363500E+04, 0.36852900E+04, 0.60256800E+04, -.14531700E+05, -.10470100E+05, -.13192700E+04, -.79445100E+04 },
        { -.12080000E+02, 0.45551300E-01, 0.46190000E+00, 0.16235100E+01, -.14230900E+01, 0.11969800E+01, 0.13643900E+01, -.23572700E+00, -.75149600E+00, 0.72752500E+00, 0.14019500E+06, 0.76829800E+05, -.38676400E+05, -.40713400E+05, -.38435200E+05, 0.10423500E+05, -.49687100E+03, -.42732600E+05, -.57309700E+05, -.46688200E+05, 0.23101800E+04, 0.88220300E+05, -.12665500E+06, 0.62787900E+05, 0.40820600E+05, 0.63365700E+05, 0.21760500E+04, -.39312500E+03, 0.65506600E+05, 0.40573600E+05, 0.56988600E+05, -.23620400E+04, -.16465200E+06, -.37386500E+05, 0.18942600E+05, 0.19219700E+05, 0.18736100E+05, 0.90340500E+04, 0.92494000E+04, 0.19536300E+05, 0.31152500E+05, 0.23303800E+05, 0.59726000E+04, -.80279000E+05, -.60887100E+05, 0.30502600E+05, 0.23726900E+05, 0.30501900E+05, 0.17291400E+05, 0.13159300E+05, 0.42324300E+05, 0.78732800E+05, 0.48043600E+05, 0.79693900E+04, -.18283400E+06, 0.12537400E+06, -.61405800E+05, -.18376000E+05, -.62780000E+05, -.28099400E+05, -.25263500E+05, -.21999700E+05, 0.52821000E+04, -.44541700E+05, -.23731700E+05, 0.34359000E+05, 0.12464900E+05, -.61843100E+04, -.40282700E+04, -.62356400E+04, 0.22736400E+03, -.51930300E+02, -.67958400E+04, -.47704800E+04, -.58518700E+04, 0.16567900E+03, 0.14093800E+05, 0.65070200E+05, -.32714500E+05, -.35263900E+05, -.32539500E+05, 0.10602000E+05, 0.59552900E+04, -.33589800E+05, -.37285900E+05, -.33869600E+05, 0.60127700E+04, 0.48041200E+05, -.93313900E+05, 0.48441400E+05, 0.61291500E+05, 0.46834000E+05, 0.18032800E+05, 0.14456200E+05, 0.39997500E+05, 0.80653400E+04, 0.20034500E+05, 0.98589300E+04, -.14118900E+06, 0.60164000E+05, -.30972300E+05, -.39407600E+05, -.30111500E+05, -.19632900E+05, -.24300400E+05, -.11673400E+05, -.10143500E+05, -.17865900E+05, -.20278600E+05, 0.97382400E+05, 0.13127300E+05, -.62873000E+04, 0.76691600E+03, -.65721700E+04, -.55908600E+04, -.45276200E+04, -.28057500E+03, 0.12578600E+04, -.60085200E+04, -.47144900E+04, 0.10945900E+05, 0.66453400E+04, -.37374900E+04, -.16860600E+05, -.33148400E+04, 0.81024500E+02, 0.74844200E+04, -.13094400E+05, -.25588300E+05, -.12417500E+05, 0.91980700E+04, 0.14568700E+06, 0.17511600E+05, -.84448100E+04, -.28351100E+04, -.87695500E+04, -.74330600E+04, -.51161700E+04, -.13220300E+05, -.27036000E+05, -.14091800E+05, -.39189200E+04, 0.50088400E+05, -.39214900E+05, 0.19140200E+05, -.73565500E+04, 0.19633100E+05, 0.13988800E+05, 0.13873900E+05, 0.29893700E+04, -.22365700E+04, 0.18461700E+05, 0.13220800E+05, -.19348300E+05, 0.67830100E+05, -.34656700E+05, -.47242200E+05, -.34005200E+05, -.19709300E+05, -.21532600E+05, -.18580100E+05, -.56532400E+04, -.13048600E+05, -.17894200E+05, 0.10472600E+06, -.87891400E+05, 0.43562100E+05, 0.37214300E+05, 0.43971100E+05, -.10387000E+05, -.11833900E+05, 0.57257300E+05, 0.47746600E+05, 0.46109800E+05, -.12441000E+05, -.10247300E+06, -.12888800E+06, 0.63045100E+05, 0.36617200E+05, 0.64480200E+05, -.12995700E+03, 0.73733600E+03, 0.72400900E+05, 0.55553500E+05, 0.64082100E+05, -.13408100E+04, -.46058300E+05, -.28751300E+05, 0.14905100E+05, 0.20990100E+05, 0.14397900E+05, 0.86068700E+04, 0.88087000E+04, 0.26724400E+05, 0.52839700E+05, 0.27117600E+05, 0.50075500E+04, -.11549900E+06, -.52599500E+04, 0.22311500E+04, -.20882200E+04, 0.26454700E+04, -.16826800E+04, -.10835700E+04, 0.52282600E+04, 0.57520100E+04, 0.48357000E+04, -.97424400E+03, -.78567000E+04, -.27023300E+05, 0.14034900E+05, 0.23217200E+05, 0.13549900E+05, 0.12897900E+05, 0.17486200E+05, 0.24754800E+05, 0.55825600E+05, 0.24285500E+05, 0.12494100E+05, -.14980600E+06, 0.10955300E+06, -.53531400E+05, -.87372900E+04, -.54834700E+05, -.28325000E+05, -.22407800E+05, -.25896000E+05, -.11940400E+05, -.48411800E+05, -.21086400E+05, 0.65240900E+05, -.70767400E+05, 0.34329900E+05, 0.65372500E+04, 0.35453100E+05, 0.19782200E+05, 0.18734100E+05, 0.33306200E+04, -.12535600E+05, 0.24970200E+05, 0.17984600E+05, -.17761500E+05, 0.26314700E+05, -.14012000E+05, -.16590300E+05, -.13201600E+05, -.96625100E+04, -.14432300E+05, -.44564200E+04, -.78134100E+04, -.10889300E+05, -.10754100E+05, 0.58739200E+05, -.89364300E+05, 0.43685900E+05, 0.14623000E+05, 0.44706900E+05, 0.45877300E+02, 0.28811500E+04, 0.42429900E+05, 0.14405900E+05, 0.37504300E+05, 0.15826600E+04, 0.10202900E+05, 0.53871600E+05, -.28053500E+05, -.34377900E+05, -.27029300E+05, -.90015800E+04, -.68635600E+04, -.23541700E+05, -.75069400E+04, -.14461000E+05, -.48033300E+04, 0.73340100E+05, -.20723000E+05, -.13942100E+05, 0.82007400E+03, -.81306700E+04, -.15417100E+05, 0.11769300E+05, 0.10146700E+05, 0.63006400E+03, 0.63436200E+04, 0.81472600E+04, -.45475600E+04, 0.11752700E+05, 0.13995100E+05, 0.25735600E+05, -.14323700E+05, 0.93579200E+04, 0.48643300E+04, 0.74603500E+04, 0.12163400E+05, -.13365700E+05, -.59117600E+04, -.13424000E+05, 0.97436200E+04, -.50974400E+04, 0.11631200E+05, 0.67941600E+04 },
        { -.62998600E+00, -.56314200E-02, 0.19084600E-01, -.20855900E+00, -.47808500E-02, -.59398900E+00, 0.30949600E+00, -.13358000E+00, 0.12148300E+00, 0.18680400E+00, -.97207200E-02, 0.34637900E+05, -.17277600E+05, -.11643600E+05, -.17322000E+05, -.34106700E+04, -.67841600E+04, -.64736400E+04, -.58868400E+04, -.10966900E+05, -.74028300E+04, -.12437300E+05, -.56443800E+05, 0.27667100E+05, 0.42536800E+03, 0.28215500E+05, -.56391900E+04, -.46709000E+04, 0.27360500E+05, 0.15377200E+05, 0.38882200E+05, -.61808900E+04, 0.25433100E+05, -.24986800E+05, 0.12172100E+05, 0.62356700E+04, 0.12497000E+05, 0.25705200E+04, 0.75215800E+04, 0.45550400E+04, 0.32259900E+04, 0.96919700E+04, 0.64862400E+04, 0.10206700E+05, -.38350400E+05, 0.18807300E+05, 0.44011100E+04, 0.19173600E+05, 0.90782900E+04, 0.19469100E+05, 0.34244000E+04, 0.24713000E+04, 0.94622400E+04, 0.16854500E+05, 0.13163600E+05, 0.13519900E+06, -.66796100E+05, -.23023700E+05, -.67592900E+05, -.13282800E+05, -.18079100E+05, -.19294300E+05, 0.13684100E+05, -.42698300E+05, -.14157100E+05, -.56263700E+05, 0.52303400E+04, -.25717000E+04, 0.11527200E+03, -.26146300E+04, 0.47313100E+03, 0.26274500E+03, -.25767300E+04, -.15393000E+04, -.36560700E+04, 0.43311700E+03, -.23556800E+04, 0.81371600E+04, -.42053100E+04, -.83119500E+04, -.40698700E+04, -.93979000E+03, -.19881100E+04, -.31592800E+04, -.55931800E+04, -.25552400E+04, -.32476400E+04, -.10131700E+04, -.10354300E+05, 0.50550600E+04, -.78296900E+04, 0.51915400E+04, -.72805400E+04, -.77215700E+04, 0.20309200E+05, 0.17941900E+05, 0.22982900E+05, -.81550000E+04, 0.22881000E+04, 0.43289500E+05, -.21502000E+05, -.11493300E+05, -.21646100E+05, -.33313500E+04, -.87142400E+04, -.67988200E+04, -.12659300E+04, -.16933800E+05, -.74689400E+04, -.16313000E+05, 0.29944500E+05, -.14800200E+05, -.72711900E+04, -.14972600E+05, -.41669100E+04, -.50990600E+04, -.21931700E+04, 0.58227500E+04, -.70487100E+04, -.44468300E+04, -.12139600E+05, -.47676500E+05, 0.23525100E+05, 0.72493800E+04, 0.23840300E+05, -.26456000E+04, -.13084700E+05, 0.16359000E+05, 0.18039800E+04, 0.22175500E+05, -.13209600E+05, 0.20135800E+05, 0.27583200E+05, -.13629900E+05, -.48829500E+04, -.13786600E+05, -.37132700E+04, -.53057500E+04, -.43176600E+04, 0.80162900E+03, -.75383500E+04, -.44699400E+04, -.94391600E+04, -.70757500E+05, 0.35071200E+05, 0.86157700E+04, 0.35374000E+05, 0.72717600E+04, 0.11393800E+05, 0.67754800E+04, -.11500900E+05, 0.22575100E+05, 0.86484200E+04, 0.32104000E+05, 0.22682200E+05, -.11237400E+05, -.31079200E+04, -.11351000E+05, 0.15065200E+04, -.11747900E+04, -.10828500E+05, -.82304400E+04, -.17170200E+05, -.37965400E+03, -.71132800E+04, -.16711700E+05, 0.81305100E+04, -.12313800E+04, 0.83477600E+04, -.64276200E+04, -.60858200E+04, 0.17681600E+05, 0.14040800E+05, 0.19774300E+05, -.61545900E+04, 0.64816000E+04, -.53653900E+05, 0.26234700E+05, -.14664500E+04, 0.26831600E+05, -.24153400E+04, 0.30095300E+04, 0.24042600E+05, 0.14209900E+05, 0.36718900E+05, 0.19852500E+03, 0.23619300E+05, -.14251200E+05, 0.68608400E+04, 0.41670600E+04, 0.71279000E+04, 0.52266500E+04, 0.13164600E+05, -.88646700E+03, 0.11092000E+04, 0.26307000E+04, 0.13267900E+05, 0.38076800E+04, -.47827000E+04, 0.23910800E+04, -.17442100E+03, 0.23935500E+04, -.91568100E+03, -.79277700E+01, 0.19272400E+04, 0.82848000E+03, 0.32174700E+04, -.40974500E+03, 0.25747900E+04, -.14813700E+05, 0.70836500E+04, 0.69338700E+04, 0.74120400E+04, 0.66224000E+04, 0.13547500E+05, -.14035400E+03, 0.16437500E+04, 0.17733000E+04, 0.13516700E+05, 0.12178500E+04, 0.14028700E+06, -.69294500E+05, -.20915400E+05, -.70147600E+05, -.14373500E+05, -.21925100E+05, -.18624300E+05, 0.14946000E+05, -.45699900E+05, -.17227900E+05, -.60508200E+05, -.90882700E+05, 0.44819900E+05, 0.17738300E+05, 0.45440100E+05, 0.11075200E+05, 0.14718800E+05, 0.76444900E+04, -.17358700E+05, 0.24371900E+05, 0.12255100E+05, 0.38146000E+05, 0.30956300E+05, -.15364200E+05, -.74753300E+04, -.15483600E+05, -.27165000E+04, -.63201400E+04, -.36224600E+04, 0.94275000E+03, -.10880700E+05, -.53851900E+04, -.12620800E+05, -.44239000E+05, 0.21521700E+05, -.77455500E+04, 0.22130000E+05, -.55274100E+04, -.35111000E+04, 0.22081600E+05, 0.11227300E+05, 0.34420600E+05, -.63688300E+04, 0.23037500E+05, 0.76694100E+04, -.37643500E+04, 0.30114200E+04, -.38446300E+04, 0.33403200E+04, 0.33104400E+04, -.10597400E+05, -.96272100E+04, -.11895700E+05, 0.36748500E+04, -.22180900E+04, -.86992000E+04, -.63782200E+04, 0.40649900E+04, -.61591300E+04, -.39404400E+04, 0.74308100E+04, 0.12888500E+05, -.21864000E+03, -.54952000E+04, 0.81181500E+04, -.83293400E+04, 0.15422400E+05, 0.77828700E+04, 0.11908300E+05, -.11351700E+05, 0.91405900E+04, 0.44701900E+04, 0.31784400E+04, 0.83945600E+04, -.14464000E+04, -.73107100E+04, -.10902600E+05, 0.15875100E+05, 0.65874200E+04, 0.36075700E+04, 0.83863700E+04 },
        { -.45922900E+01, 0.21304300E+00, 0.10864900E+00, -.48611000E+00, -.37379200E+00, 0.11093700E+01, -.48721300E+00, 0.31573700E+00, -.57833100E+00, 0.99749000E+00, -.16697000E-01, -.10914000E+00, -.11613000E+04, 0.99335000E+04, 0.49360800E+02, -.45516400E+04, -.26883500E+04, 0.26309500E+04, 0.66122800E+04, -.34102900E+04, -.11040400E+04, 0.70916400E+04, 0.66712400E+05, -.41030100E+05, -.19109700E+05, -.33514700E+05, -.18828600E+05, -.70389800E+04, -.10602900E+05, 0.19151800E+02, -.33512800E+05, -.53502500E+04, -.33295100E+05, -.83522100E+04, 0.29634200E+03, -.60541300E+04, 0.40558800E+04, -.34554100E+04, -.32508500E+04, -.81695300E+03, -.67803300E+04, 0.14285900E+04, -.26689300E+04, 0.30979000E+04, 0.74866100E+03, -.51858100E+04, -.16595500E+05, -.57161900E+03, -.10051700E+05, -.87686100E+04, -.43171100E+04, -.12452400E+05, 0.14746200E+04, -.72005300E+04, 0.10202500E+04, -.16461000E+06, 0.94238800E+05, 0.47658400E+05, 0.82640000E+05, 0.46468700E+05, 0.31347600E+05, 0.92259200E+04, -.35135300E+05, 0.47029800E+05, 0.26337700E+05, 0.66141500E+05, -.56800700E+04, 0.34446800E+04, 0.19706700E+04, 0.28532900E+04, 0.16044000E+04, 0.59905400E+03, 0.10659600E+04, 0.30040000E+03, 0.28762700E+04, 0.45515500E+03, 0.29000600E+04, 0.42167400E+04, -.51002700E+04, 0.11487900E+04, -.21011100E+04, -.80345900E+04, -.45075700E+04, 0.12598300E+04, 0.37946500E+04, -.34832200E+04, -.27532800E+04, 0.57153000E+04, 0.15329800E+05, -.76791000E+04, -.11993200E+05, -.81509500E+04, -.93769200E+04, -.88763400E+04, 0.28302200E+03, 0.19698800E+04, -.14655200E+05, -.67482700E+04, -.86332600E+04, 0.69202700E+04, -.23635700E+04, 0.19803900E+05, -.33785900E+04, 0.34157800E+04, 0.70018300E+04, -.27253100E+04, -.15599600E+04, -.48846100E+04, 0.62854700E+04, -.59768400E+04, -.53951400E+05, 0.30384700E+05, 0.14972900E+05, 0.27000600E+05, 0.12959900E+05, 0.97768000E+04, 0.32109900E+04, -.11671200E+05, 0.13925000E+05, 0.82882200E+04, 0.20551200E+05, 0.24668200E+05, -.17386000E+05, -.25265300E+04, -.12348600E+05, -.75313800E+02, 0.69703100E+04, -.47696000E+04, 0.80541000E+04, -.11478900E+05, 0.59090500E+04, -.79333600E+04, -.13871200E+05, 0.98400600E+04, 0.10012200E+05, 0.70065600E+04, 0.49237600E+04, 0.14181900E+04, 0.45816000E+04, 0.21739800E+04, 0.37006200E+04, 0.12120100E+04, 0.21298100E+04, 0.88569300E+05, -.48125500E+05, -.27856700E+05, -.44393000E+05, -.27679300E+05, -.18922600E+05, -.45533200E+04, 0.20013800E+05, -.22365300E+05, -.15976800E+05, -.34427100E+05, 0.72363100E+04, -.30393100E+04, 0.12358200E+05, -.33912500E+04, 0.27005300E+04, 0.55643400E+04, -.19151600E+04, 0.30447500E+03, 0.10795600E+04, 0.46590900E+04, -.47107200E+04, 0.20213600E+05, -.14080100E+05, -.55183700E+04, -.10232200E+05, 0.89803000E+03, 0.59452000E+04, -.88070400E+04, -.71167900E+04, -.17790900E+05, 0.53935400E+04, -.14313600E+05, 0.53520300E+05, -.35125200E+05, -.18117800E+05, -.26852100E+05, -.20802500E+05, -.99602200E+04, -.88273700E+04, -.32589900E+04, -.26687400E+05, -.78041900E+04, -.26702500E+05, -.78041100E+04, 0.25883800E+04, -.10978600E+05, 0.38425700E+04, -.62891500E+04, -.66037900E+04, -.21970500E+04, -.10924500E+05, 0.66144600E+04, -.69943600E+04, 0.71342400E+04, -.31773500E+03, -.59221500E+03, -.23705700E+04, 0.12120800E+03, 0.56417800E+03, 0.10454100E+04, -.13232800E+04, -.18268800E+04, -.62551400E+03, 0.97781600E+03, 0.42291200E+03, -.51276100E+04, -.24091200E+03, -.12164700E+05, 0.24672100E+04, -.63659300E+04, -.75689900E+04, -.20911000E+04, -.96207100E+04, 0.53080000E+04, -.74613600E+04, 0.72382100E+04, -.17576400E+06, 0.99117400E+05, 0.53041600E+05, 0.88048600E+05, 0.53971200E+05, 0.37483000E+05, 0.76995100E+04, -.40098400E+05, 0.45138700E+05, 0.31825100E+05, 0.71168000E+05, 0.12977200E+06, -.74860300E+05, -.35904800E+05, -.65117200E+05, -.35084700E+05, -.24264900E+05, -.80942200E+04, 0.27078200E+05, -.37590300E+05, -.20277200E+05, -.49879000E+05, 0.67080800E+04, -.24297700E+04, 0.11821800E+05, -.32446100E+04, 0.23830100E+04, 0.41786700E+04, -.28586800E+04, -.17703100E+04, -.46403800E+04, 0.34096300E+04, -.29509100E+04, 0.35238600E+05, -.25626000E+05, -.95922000E+04, -.17644300E+05, -.16401100E+05, -.68505400E+04, -.46201500E+04, 0.58026700E+03, -.20905300E+05, -.52180900E+04, -.17440500E+05, -.14726200E+05, 0.74407600E+04, 0.96496300E+04, 0.76089500E+04, 0.60542700E+04, 0.50864400E+04, 0.15092700E+04, -.24044600E+03, 0.10036600E+05, 0.39554300E+04, 0.66940700E+04, 0.98191000E+04, 0.69385800E+04, -.42235300E+04, 0.21911200E+04, 0.65534100E+04, -.75717700E+04, -.38822700E+04, -.15392600E+04, 0.32107900E+04, 0.84266700E+04, -.95084300E+04, 0.65281100E+04, -.67818400E+04, -.91099000E+04, 0.19057400E+04, 0.10061500E+05, -.45176000E+04, 0.21671000E+04, -.98408400E+04, 0.91076100E+04, 0.79515900E+04, 0.14277300E+04, -.27711400E+04, 0.93526200E+04, -.51215900E+04, 0.59793800E+04 },
        { 0.97985900E+01, -.24033800E+00, -.59253000E+00, -.19734200E+00, 0.52279000E+00, -.22064200E+01, 0.15789200E+01, -.20927200E+01, 0.15189000E+01, -.11935900E+01, -.38958800E-01, -.13209300E+01, 0.25728800E+00, -.11903900E+06, -.85674500E+02, 0.17176000E+05, 0.10669900E+05, -.28566800E+05, -.46989100E+05, -.84201400E+03, 0.34531100E+04, 0.43562000E+04, -.17239500E+06, 0.79588900E+05, 0.46392400E+06, 0.86520800E+05, -.18990500E+05, 0.10072700E+05, 0.98030300E+05, 0.26553400E+05, 0.77663000E+05, 0.94315900E+04, 0.56888900E+05, -.19717800E+05, 0.61569200E+04, 0.14034900E+06, 0.10079200E+05, 0.52234700E+04, 0.28958600E+05, 0.10685700E+05, 0.20248700E+05, 0.71853400E+04, 0.24888500E+05, 0.59951600E+04, 0.19911900E+06, -.10376200E+06, 0.21887800E+06, -.99176200E+05, -.44457100E+04, 0.44485000E+05, -.11328800E+05, 0.71486400E+05, -.71384700E+05, 0.37044400E+05, -.10866800E+06, 0.25681600E+06, -.11888700E+06, -.69039800E+06, -.12907000E+06, -.16731700E+05, -.44589000E+05, -.58278900E+05, 0.37970600E+05, -.51014100E+05, -.46528600E+05, -.64906400E+05, 0.80871500E+04, -.35236500E+04, -.44445500E+05, -.40706100E+04, 0.36942900E+04, 0.19731600E+04, -.10039200E+05, -.48008800E+04, -.47433800E+04, 0.14201500E+04, -.15584900E+04, 0.43851600E+05, -.23855400E+05, -.44656400E+03, -.21935900E+05, 0.91793300E+04, 0.69483200E+04, -.22785400E+05, -.26875300E+05, -.19776700E+05, 0.17399900E+04, -.21838000E+05, -.38132900E+05, 0.17167200E+05, 0.23562700E+06, 0.19956500E+05, -.10425800E+05, -.65074000E+04, 0.67832500E+05, 0.22486000E+05, 0.26675300E+05, -.18884900E+04, -.58600200E+04, 0.10377000E+06, -.49764000E+05, -.23663000E+06, -.52037100E+05, -.22061500E+05, -.39043600E+05, -.14247500E+05, 0.80890900E+04, -.19750500E+05, -.38367100E+05, -.35500500E+05, 0.74410700E+05, -.34902800E+05, -.13432100E+06, -.37252000E+05, -.75549700E+04, -.15727500E+05, -.56568200E+04, 0.18293600E+05, -.14244500E+05, -.15280500E+05, -.23696500E+05, -.20255300E+06, 0.97486100E+05, 0.12543700E+06, 0.10129800E+06, 0.89668200E+03, -.34532900E+05, 0.55682400E+05, -.12250700E+05, 0.75054300E+05, -.33529800E+05, 0.76057400E+05, -.47054900E+05, 0.25531200E+05, -.10189800E+06, 0.23376500E+05, 0.54681200E+04, -.49802100E+04, -.44054300E+04, -.20738300E+05, 0.16477000E+05, -.32240700E+04, 0.34236300E+05, -.13213600E+06, 0.62513800E+05, 0.40578200E+06, 0.66289900E+05, 0.10335400E+05, 0.27753900E+05, 0.19477300E+05, -.34866500E+05, 0.22816900E+05, 0.28661500E+05, 0.35840200E+05, 0.86119500E+05, -.41491000E+05, -.20038800E+06, -.43465600E+05, -.11472000E+05, -.25927400E+05, -.30434800E+05, 0.15131900E+03, -.24854800E+05, -.26414900E+05, -.23949600E+05, 0.11517600E+04, -.34101800E+04, 0.15410200E+06, -.31133700E+03, -.41420500E+05, -.34774500E+05, 0.71376400E+05, 0.53392300E+05, 0.29022400E+05, -.29105600E+05, -.71340800E+04, -.59772900E+05, 0.23170100E+05, 0.51022500E+06, 0.30049100E+05, -.39326700E+05, -.84004000E+04, 0.96005600E+05, 0.45342400E+05, 0.35272400E+05, -.43064000E+04, 0.27505800E+04, 0.65791100E+05, -.35475600E+05, 0.11853000E+06, -.32788100E+05, 0.68679700E+04, 0.42920100E+05, -.96528100E+04, 0.29561200E+05, -.24661400E+05, 0.38954700E+05, -.35492100E+05, -.92132800E+04, 0.44549100E+04, 0.40023900E+05, 0.46723700E+04, -.28725400E+04, -.19252000E+03, 0.84196800E+04, 0.38763100E+04, 0.56990600E+04, -.66917200E+03, 0.41140000E+04, 0.63003800E+05, -.34919000E+05, 0.10746000E+06, -.31331700E+05, 0.13403000E+05, 0.47277000E+05, -.91567100E+04, 0.31958800E+05, -.27044400E+05, 0.42787900E+05, -.46351400E+05, 0.27955700E+06, -.13006400E+06, -.77749000E+06, -.14008700E+06, -.20836800E+05, -.61735200E+05, -.56469000E+05, 0.45897400E+05, -.51558000E+05, -.61454500E+05, -.76304700E+05, -.19409000E+06, 0.89490400E+05, 0.44999200E+06, 0.97492300E+05, 0.17719400E+05, 0.38770200E+05, 0.21471300E+05, -.48749300E+05, 0.37745200E+05, 0.39134000E+05, 0.57649200E+05, 0.55109300E+05, -.25869800E+05, -.15211200E+06, -.27748300E+05, -.12617600E+05, -.21188000E+05, -.57235000E+04, 0.51898800E+04, -.10155900E+05, -.20169200E+05, -.21103700E+05, -.95342300E+05, 0.40910000E+05, 0.43050400E+06, 0.47688300E+05, -.29321300E+05, -.14036800E+05, 0.87075700E+05, 0.23206200E+05, 0.44954600E+05, -.11477900E+05, 0.26980700E+05, 0.18941400E+05, -.83472500E+04, -.13281100E+06, -.99130600E+04, 0.47516200E+04, 0.57126100E+04, -.37794700E+05, -.15632900E+05, -.12474500E+05, 0.24798900E+04, 0.55676700E+04, -.13611900E+05, -.44742400E+04, -.29241400E+04, 0.72843300E+04, -.30200300E+04, 0.21508100E+05, 0.20478900E+05, -.25721800E+04, 0.69063800E+04, 0.28602800E+05, -.28573500E+05, 0.11808100E+05, 0.36718800E+04, 0.54218000E+05, -.19121800E+05, 0.27290200E+05, 0.45308800E+04, -.12435000E+05, 0.18468700E+05, 0.71195700E+04, -.11914800E+05, -.15877000E+05, 0.14323900E+05, 0.30243200E+05, 0.17769500E+05, 0.35861900E+05 },
        { 0.21195100E+01, -.15938000E-01, -.72127300E-01, 0.15654700E+01, -.13554500E+00, -.43550300E+00, -.39280800E+00, 0.30810800E+00, -.30382800E-01, -.42778800E+00, 0.39699000E-01, 0.61938400E-01, 0.23176700E-01, -.49804900E-01, -.88179000E+02, -.24888000E+03, -.13656600E+04, 0.89535800E+04, 0.10767800E+05, 0.65025000E+04, -.90931600E+03, -.63100300E+04, 0.73764400E+05, -.40195200E+05, 0.23035000E+05, -.36572200E+05, -.60705400E+05, -.26680700E+05, -.73885100E+04, 0.83101900E+04, -.14210600E+05, -.27024300E+05, -.54373200E+04, -.38163600E+05, 0.16908500E+05, 0.20144500E+05, 0.19303200E+05, -.73774300E+04, -.16686500E+04, 0.26337100E+04, -.10031500E+05, 0.10172800E+05, -.23879500E+04, 0.23543000E+05, -.26512500E+05, 0.10864800E+05, 0.36278900E+05, 0.13631400E+05, -.15023900E+05, -.53304200E+04, -.60807300E+03, -.16283700E+05, -.11722900E+04, -.53606100E+04, 0.19930700E+05, -.10171700E+06, 0.55501400E+05, -.53004000E+05, 0.50215900E+05, 0.85321400E+05, 0.30695700E+05, 0.10167500E+05, -.39825700E+04, 0.40250900E+05, 0.28570200E+05, 0.16389400E+05, -.69285900E+04, 0.37210500E+04, -.21665800E+04, 0.34383700E+04, 0.55436400E+04, 0.25330900E+04, 0.80770700E+03, -.57739300E+03, 0.13754500E+04, 0.25352500E+04, 0.56799200E+03, -.96878900E+04, 0.37935000E+04, 0.11216400E+05, 0.48323100E+04, -.72839200E+04, -.36796400E+04, 0.86598100E+04, 0.70039400E+04, 0.65424700E+04, -.29238600E+04, 0.59243000E+03, 0.85785700E+05, -.44528800E+05, -.23647300E+05, -.42003800E+05, -.44469100E+05, -.37531000E+05, -.42914000E+04, 0.14322600E+05, -.61588600E+04, -.33420000E+05, -.10255400E+05, 0.60998300E+05, -.29147000E+05, -.13183500E+05, -.30647500E+05, 0.72554100E+04, -.16028100E+04, -.62376300E+01, 0.18873700E+05, -.16165400E+05, -.13027600E+04, -.43397800E+05, -.15958000E+05, 0.92333200E+04, -.17506900E+05, 0.79330100E+04, 0.15716500E+05, 0.54543400E+04, 0.12011500E+04, 0.65702900E+03, 0.97325800E+04, 0.48267500E+04, 0.45636400E+04, 0.12072100E+04, -.25787500E+04, 0.34700700E+04, -.57955200E+03, -.17756800E+05, -.40666500E+04, -.51181500E+03, -.50785500E+04, 0.27374900E+04, -.32820900E+04, 0.12026200E+05, 0.10327000E+05, -.41497300E+04, -.19003100E+05, -.53056100E+04, 0.11246500E+05, 0.38489000E+04, -.84526900E+03, 0.74556700E+04, 0.58057300E+03, 0.31189100E+04, -.10316400E+05, 0.34916500E+05, -.19093400E+05, 0.37553700E+05, -.17245900E+05, -.44831300E+05, -.13628800E+05, -.18539500E+04, 0.18560800E+04, -.12393200E+05, -.13801100E+05, -.37802300E+04, 0.24829800E+04, -.23572200E+03, 0.50380400E+04, -.16475000E+04, 0.17810300E+05, 0.11283100E+05, 0.17251800E+04, 0.41012000E+04, -.93443900E+04, 0.10242000E+05, -.21966900E+05, 0.53114700E+05, -.27963500E+05, 0.18648000E+03, -.26307500E+05, -.24905700E+05, -.14843200E+05, -.86672400E+04, 0.41168000E+03, -.14742500E+05, -.13972000E+05, -.85158300E+04, 0.69574900E+05, -.37746800E+05, 0.34440200E+05, -.34621400E+05, -.59645600E+05, -.21508400E+05, -.11284100E+05, 0.21208200E+04, -.16134300E+05, -.22881600E+05, -.32209000E+04, -.59891600E+05, 0.28418600E+05, 0.25350400E+05, 0.30054200E+05, -.46289000E+03, 0.10777800E+04, 0.54997200E+04, -.11901500E+05, 0.17708300E+05, 0.57462600E+03, 0.26132800E+05, -.11794900E+05, 0.59786400E+04, 0.45570200E+04, 0.59645700E+04, -.29739300E+03, 0.34973300E+04, -.57760200E+03, -.27364000E+04, 0.36247400E+04, 0.24548500E+04, 0.77308900E+04, -.38540700E+05, 0.17187000E+05, 0.17022700E+05, 0.19444400E+05, -.25343200E+04, -.14168400E+04, 0.24483400E+04, -.11524100E+05, 0.90359000E+04, -.15027900E+04, 0.21874200E+05, -.93366900E+05, 0.51314400E+05, -.66288000E+05, 0.46375500E+05, 0.92032900E+05, 0.33655500E+05, 0.80704200E+04, -.14658000E+04, 0.36088100E+05, 0.32281100E+05, 0.15820500E+05, 0.54974300E+05, -.31258100E+05, 0.43735400E+05, -.27049000E+05, -.54380000E+05, -.17031800E+05, -.39700700E+04, 0.18743300E+04, -.25272100E+05, -.15852100E+05, -.10826100E+05, 0.47696500E+05, -.22642300E+05, -.12196600E+05, -.24043600E+05, 0.37092800E+04, -.23726100E+04, -.29408200E+03, 0.14639600E+05, -.12364900E+05, -.18883700E+04, -.30007700E+05, 0.47698500E+05, -.27051400E+05, 0.26216100E+05, -.23818800E+05, -.47536700E+05, -.15267200E+05, -.73763600E+04, 0.38744800E+04, -.54437200E+04, -.16634700E+05, -.12710400E+03, -.48546700E+05, 0.25287800E+05, 0.13215400E+05, 0.23827300E+05, 0.25288100E+05, 0.21111000E+05, 0.20029000E+04, -.81318200E+04, 0.71836900E+04, 0.18548500E+05, 0.74096800E+04, 0.12278600E+05, 0.11350600E+05, -.93142800E+04, 0.21424600E+04, 0.16772200E+05, -.12443000E+05, 0.14651300E+05, -.56262700E+04, 0.60268800E+04, 0.36148100E+05, -.44087100E+05, 0.31342400E+05, -.11536000E+05, -.16793600E+05, -.46842200E+04, 0.44454500E+05, -.78002900E+04, 0.18148800E+04, -.13618300E+05, 0.28363200E+05, 0.12085900E+05, -.10471600E+05, 0.16008600E+05, 0.39091200E+05, -.95344500E+04, 0.34027200E+05 },
        { -.11764200E+02, 0.42045500E+00, 0.40723300E+00, 0.47684100E-01, -.13110400E+01, 0.29686100E+01, -.35255300E+01, 0.14784000E+01, 0.16117500E+01, 0.24770600E+01, -.21249200E+00, -.96510100E+00, 0.33284000E+00, -.74568800E-01, 0.10866300E+01, -.35158700E+05, -.20695800E+05, 0.13480800E+05, 0.91861900E+04, 0.15845200E+05, -.20072500E+05, 0.47782000E+05, -.95839400E+05, 0.47488000E+05, -.49846200E+05, 0.47983000E+05, 0.76985500E+05, 0.37021500E+05, -.30891300E+04, 0.72811700E+04, 0.46974500E+05, 0.25758100E+05, 0.19721100E+05, 0.18823200E+05, -.96169200E+04, -.14812800E+05, -.93983200E+04, 0.11693300E+05, 0.41235100E+04, -.87823900E+04, -.24456400E+04, -.16075400E+05, 0.36086700E+04, -.24954300E+05, 0.15609700E+05, -.83378500E+04, -.48214100E+05, -.77505000E+04, 0.35564900E+05, 0.15575700E+05, -.24168300E+05, -.29040400E+05, -.32066400E+05, 0.14942700E+05, -.34934400E+05, 0.32839400E+06, -.16226000E+06, 0.92127300E+04, -.16430700E+06, -.10845000E+06, -.65534100E+05, -.25220100E+05, 0.18656900E+05, -.10409000E+06, -.49155400E+05, -.16110400E+06, 0.68700100E+04, -.34090000E+04, 0.56548500E+04, -.34402000E+04, -.75789900E+04, -.36622000E+04, 0.11481000E+04, -.13147400E+02, -.34327800E+04, -.26805900E+04, -.51526800E+03, -.20543500E+05, 0.10005700E+05, -.41874100E+04, 0.10275200E+05, -.15832600E+05, -.80870100E+04, 0.69433200E+04, 0.43793100E+04, 0.12060500E+05, -.89236300E+04, 0.49327400E+05, -.16743200E+05, 0.11032700E+05, -.28419100E+05, 0.84797400E+04, 0.17562600E+05, -.76081500E+04, 0.29622200E+05, 0.73499300E+05, 0.58235100E+05, -.12972200E+05, -.21382400E+05, -.45323400E+05, 0.20514500E+05, 0.61381200E+04, 0.22620700E+05, 0.22723100E+04, 0.97286200E+04, -.91612200E+04, -.44479100E+05, 0.36439700E+04, 0.11261200E+05, 0.38739900E+05, 0.79108000E+05, -.39135400E+05, 0.10820100E+04, -.39562000E+05, -.23026800E+05, -.17302700E+05, -.38831200E+04, 0.95136800E+04, -.20867100E+05, -.13725100E+05, -.41876400E+05, 0.25577800E+05, -.13386100E+05, -.10456900E+05, -.12794100E+05, 0.61001100E+04, 0.12731400E+05, -.12461300E+04, 0.19964500E+05, -.27324000E+04, 0.69054000E+04, 0.78821300E+04, -.12282200E+05, 0.63579400E+04, 0.25465400E+05, 0.61032400E+04, -.18295500E+05, -.13631300E+05, 0.12703100E+05, 0.71050400E+04, 0.16534100E+05, -.11087500E+05, 0.71640000E+04, -.14126100E+06, 0.70262500E+05, -.21507800E+05, 0.70676300E+05, 0.55334900E+05, 0.33119000E+05, 0.65215100E+04, -.15048000E+05, 0.45011900E+05, 0.24966800E+05, 0.77937500E+05, -.54001800E+05, 0.24981000E+05, 0.23776800E+05, 0.26932000E+05, 0.47658900E+04, 0.16632900E+05, -.15520400E+05, -.59079400E+05, -.14946000E+05, 0.18928600E+05, 0.43654800E+05, -.35879900E+05, 0.17563000E+05, -.22490100E+05, 0.18003200E+05, 0.45036300E+05, 0.19834000E+05, -.56184500E+04, -.27333100E+04, 0.21613000E+05, 0.14241200E+05, -.15393600E+05, -.99855200E+05, 0.48445100E+05, -.58821700E+05, 0.49931000E+05, 0.84013200E+05, 0.37172300E+05, -.69695700E+04, -.39577200E+04, 0.41099000E+05, 0.27743600E+05, 0.16820400E+05, 0.87227400E+05, -.43491800E+05, -.33721500E+05, -.43606600E+05, 0.16342300E+05, 0.84265500E+04, -.31004300E+05, -.17663600E+05, -.49209200E+05, 0.86590400E+04, -.61472500E+05, 0.19972900E+05, -.10057300E+05, -.71655700E+04, -.99826300E+04, 0.57148700E+03, -.70572500E+03, -.54321600E+04, -.78431900E+03, -.84415000E+04, -.93336600E+03, -.88251200E+04, 0.63858400E+05, -.32154400E+05, -.28399300E+05, -.31926000E+05, 0.15079100E+05, 0.62368300E+04, -.23411700E+05, -.18212900E+05, -.38518500E+05, 0.71539400E+04, -.52223000E+05, 0.32823600E+06, -.16229200E+06, 0.22935600E+05, -.16414300E+06, -.12148800E+06, -.72903700E+05, -.22004900E+05, 0.23326700E+05, -.10373500E+06, -.55008400E+05, -.15461000E+06, -.21983000E+06, 0.10827800E+06, -.90436500E+04, 0.10997800E+06, 0.70811800E+05, 0.45559000E+05, 0.11899400E+05, -.29622800E+05, 0.66367000E+05, 0.35115300E+05, 0.11984100E+06, -.90502700E+04, 0.31314000E+04, -.43163100E+04, 0.45001000E+04, -.20250100E+04, 0.35736600E+04, -.93705200E+04, -.26021800E+05, -.46753400E+03, 0.39006200E+04, 0.18867100E+05, -.65448200E+05, 0.31264100E+05, -.49359000E+05, 0.32686000E+05, 0.51428200E+05, 0.18824100E+05, -.98788400E+03, 0.19852400E+04, 0.38306700E+05, 0.10759400E+05, 0.25523200E+05, 0.19053100E+05, -.11000200E+05, 0.10994000E+05, -.95647300E+04, -.14170700E+05, -.97366400E+03, -.11357900E+05, -.32057000E+05, -.29297200E+05, 0.27021200E+04, 0.44783300E+04, -.12741200E+05, -.14788500E+05, 0.23541900E+05, -.20266800E+04, -.25310600E+05, 0.18418900E+05, -.40607800E+04, 0.86262200E+04, -.26580400E+05, -.47376500E+05, 0.48449100E+05, -.16893800E+05, 0.16278100E+05, 0.20588500E+05, -.11510000E+04, -.50116800E+05, 0.11268200E+05, 0.10063500E+04, 0.24108100E+05, -.24439500E+05, -.19213200E+05, 0.86820800E+04, 0.29030300E+04, -.43270400E+05, 0.51096300E+04, -.47706800E+05 },
        { -.14053300E+01, 0.10088600E+00, 0.97719400E-01, 0.27169700E+01, -.28698800E+00, 0.49408300E+00, 0.38555300E-01, 0.22495600E+00, -.30253500E+00, 0.30037100E+00, 0.23398200E-01, 0.96485000E+00, -.52226100E-01, 0.12832400E-01, -.92696500E-01, 0.33842200E-01, 0.94448100E+04, -.37076500E+04, -.12066800E+04, -.23757400E+04, 0.11466600E+05, -.13931000E+04, 0.55637800E+05, -.29490700E+05, -.84949100E+03, -.27823000E+05, -.13056000E+05, -.10305700E+05, -.19539500E+05, 0.35405200E+03, -.27207900E+05, -.10388200E+05, -.14894800E+05, -.61012100E+04, 0.18067300E+04, 0.40510600E+04, 0.30497400E+04, -.24991900E+04, -.10115100E+05, 0.40655100E+04, 0.83822300E+03, 0.29606300E+04, -.10261500E+05, 0.37605500E+04, -.19970600E+05, 0.85654900E+04, 0.18189500E+05, 0.99818300E+04, -.57712000E+04, -.25021600E+05, 0.13974300E+05, 0.66788800E+04, 0.11690100E+05, -.24280700E+05, 0.98967200E+04, -.16954900E+06, 0.87273800E+05, 0.35474800E+05, 0.84781300E+05, 0.42142500E+05, 0.30474700E+05, 0.22607900E+05, -.18863100E+05, 0.53007100E+05, 0.26955300E+05, 0.54718800E+05, -.46836700E+04, 0.24670900E+04, -.17368700E+03, 0.23421700E+04, 0.10994200E+04, 0.95263400E+03, 0.18511000E+04, 0.11035300E+03, 0.24108200E+04, 0.96960800E+03, 0.11835100E+04, 0.77004900E+04, -.44649300E+04, 0.10324300E+04, -.38504600E+04, -.32421900E+04, 0.28316700E+04, -.24048200E+04, 0.16321700E+03, -.38766100E+04, 0.52173400E+04, -.47469500E+04, 0.29305100E+05, -.15484200E+05, -.52810800E+04, -.14659000E+05, -.59833700E+04, -.91824900E+04, -.17161800E+05, -.42943200E+04, -.16316900E+05, -.79462700E+04, 0.51336600E+03, -.27502400E+05, 0.14287100E+05, 0.16383500E+05, 0.13753500E+05, 0.67920600E+04, 0.11217800E+05, 0.46883900E+04, 0.74598100E+03, 0.91159200E+04, 0.10116300E+05, 0.14806500E+04, -.36903500E+05, 0.19102800E+05, 0.77060500E+04, 0.18452200E+05, 0.93903500E+04, 0.76331000E+04, 0.26486900E+04, -.64328800E+04, 0.10177900E+05, 0.68744100E+04, 0.13184500E+05, 0.76770600E+05, -.39485900E+05, -.27187000E+05, -.38385000E+05, -.13172200E+05, 0.16143400E+05, -.30395700E+05, -.18576300E+05, -.34116300E+05, 0.18786900E+05, -.18141400E+05, -.87798700E+04, 0.49300600E+04, -.18704000E+04, 0.43923400E+04, 0.57635000E+04, 0.70750000E+04, -.89729700E+02, -.56541400E+03, 0.16372300E+04, 0.60890300E+04, -.70080200E+03, 0.83894800E+05, -.42703800E+05, -.14915400E+05, -.41950300E+05, -.22604100E+05, -.16692000E+05, -.79693400E+04, 0.13821300E+05, -.25107800E+05, -.14726100E+05, -.29910400E+05, -.25681100E+05, 0.13203400E+05, 0.13096000E+05, 0.12844400E+05, 0.51889500E+04, 0.81408600E+04, 0.95668600E+04, 0.25392300E+04, 0.11185200E+05, 0.70860700E+04, -.13298700E+04, 0.30293200E+04, -.22651100E+04, 0.83406400E+04, -.15187000E+04, 0.10728800E+04, -.45466000E+04, -.94393600E+04, -.35820100E+04, -.95828100E+04, -.48752900E+04, 0.17411600E+04, 0.49807900E+05, -.26353800E+05, 0.29974000E+04, -.24904200E+05, -.13386000E+05, -.12424800E+05, -.18620400E+05, 0.25501100E+03, -.25032200E+05, -.12618800E+05, -.11906000E+05, -.37466800E+05, 0.17868600E+05, 0.13748200E+05, 0.18733000E+05, -.20854200E+03, -.15363100E+05, 0.15230800E+05, 0.67015000E+04, 0.18492300E+05, -.16819600E+05, 0.13960100E+05, 0.11518400E+04, -.44219500E+03, 0.47961300E+02, -.57612900E+03, 0.62448500E+03, 0.98666500E+03, -.21392500E+04, -.96822900E+03, -.15470600E+04, 0.96955100E+03, 0.29420500E+03, -.25145200E+05, 0.11306100E+05, 0.77078500E+04, 0.12572400E+05, -.23992900E+04, -.15752100E+05, 0.12700000E+05, 0.68549300E+04, 0.14599200E+05, -.17207200E+05, 0.13893200E+05, -.16544600E+06, 0.85130800E+05, 0.29972700E+05, 0.82724400E+05, 0.44135800E+05, 0.36762400E+05, 0.18331700E+05, -.23130800E+05, 0.49529200E+05, 0.33104700E+05, 0.57620700E+05, 0.11210300E+06, -.58126100E+05, -.23307700E+05, -.56055500E+05, -.29609200E+05, -.21372500E+05, -.96427500E+04, 0.19453900E+05, -.33390900E+05, -.19295800E+05, -.38081600E+05, -.12661000E+05, 0.68985700E+04, 0.71170100E+04, 0.63318800E+04, 0.37755700E+04, 0.74374200E+04, 0.10489700E+04, -.58630700E+02, 0.38382900E+04, 0.69677200E+04, 0.99206600E+03, 0.56877400E+05, -.30111300E+05, -.19463800E+04, -.28436300E+05, -.11252400E+05, -.21080600E+04, -.24573900E+05, -.57956000E+04, -.30127500E+05, -.70365600E+03, -.17229400E+05, -.18245300E+05, 0.96785000E+04, 0.41016800E+04, 0.91249000E+04, 0.43807900E+04, 0.59505300E+04, 0.88331000E+04, 0.24823200E+04, 0.95614700E+04, 0.49132600E+04, 0.11413600E+04, 0.79341100E+04, 0.66594100E+04, -.70263700E+04, 0.41454700E+04, 0.96699300E+04, -.12010700E+05, -.17978800E+04, -.12457000E+04, 0.71810400E+04, 0.12182200E+04, -.28450300E+04, 0.19658300E+04, -.94814600E+04, -.20927200E+05, 0.37845500E+04, 0.20551400E+04, -.83230700E+04, -.24774900E+04, -.10620500E+05, 0.74663600E+04, 0.89953400E+04, 0.17793200E+04, -.32391700E+04, 0.42421400E+04, -.32576700E+04, -.33700200E+03 },
        { 0.50096100E+01, -.21380900E+00, -.11442600E+00, -.96228700E+00, 0.40128000E-01, -.40095300E+00, 0.10186500E+01, 0.12654300E+00, -.35185400E+00, -.13299200E+00, 0.24603300E-01, 0.95553900E+00, 0.51412800E-01, 0.47938700E-01, -.19795200E+00, 0.48285300E-01, -.31237700E+00, -.13351300E+05, -.19604000E+05, -.70315600E+04, 0.37978100E+03, 0.11239500E+05, 0.84577200E+05, -.41628000E+05, -.39362300E+04, -.42270800E+05, -.14356800E+05, -.31376700E+04, -.23738100E+05, 0.15306000E+05, -.37860200E+05, -.82975800E+03, -.40320300E+05, -.43105700E+04, 0.24419000E+04, 0.31342500E+04, 0.21597300E+04, -.74681200E+04, -.12475900E+05, 0.87151300E+04, 0.60298900E+04, 0.42553800E+04, -.10376700E+05, -.35217600E+03, -.30326600E+05, 0.15562000E+05, 0.24634300E+05, 0.15178400E+05, -.18677500E+05, -.26477200E+05, 0.23542900E+05, 0.98819500E+04, 0.16602400E+05, -.20856000E+05, 0.10393900E+05, -.21916400E+06, 0.10845500E+06, 0.42055000E+05, 0.10955300E+06, 0.52830300E+05, 0.42553600E+05, 0.19915900E+05, -.38260400E+05, 0.65295600E+05, 0.37911800E+05, 0.84016800E+05, -.63416800E+04, 0.31188200E+04, -.31967100E+03, 0.31693500E+04, 0.11940900E+04, 0.27488500E+03, 0.19319900E+04, -.14930500E+04, 0.30036300E+04, 0.32234000E+02, 0.31815000E+04, 0.18080100E+05, -.88541900E+04, -.22677500E+04, -.90391600E+04, -.56367400E+04, -.55620800E+04, -.11468000E+05, -.14755000E+05, -.11230700E+05, -.41256600E+04, 0.14548300E+04, 0.17422300E+05, -.90555400E+04, 0.25130500E+04, -.86981100E+04, -.38283300E+04, -.66089400E+03, -.15250200E+05, 0.62727000E+04, -.11130600E+05, 0.53095100E+03, -.64675200E+04, -.17576000E+05, 0.89310500E+04, 0.12640900E+05, 0.87865900E+04, 0.75683800E+04, 0.14101500E+05, -.66142900E+04, -.12022400E+05, 0.51598400E+03, 0.12977400E+05, 0.71902200E+04, -.50148600E+05, 0.24851800E+05, 0.10509900E+05, 0.25073300E+05, 0.12618400E+05, 0.10588500E+05, 0.36545200E+04, -.76383800E+04, 0.14471400E+05, 0.97165900E+04, 0.18524000E+05, 0.59091300E+05, -.29123900E+05, -.95149100E+04, -.29546900E+05, 0.83504700E+02, 0.68008700E+04, -.14955100E+05, 0.73729900E+04, -.21483900E+05, 0.41790400E+04, -.20783900E+05, -.65247900E+04, 0.30297600E+04, -.59879500E+04, 0.32522400E+04, 0.90552300E+04, 0.96186600E+04, -.55207900E+04, -.64935500E+04, -.12022000E+04, 0.82486400E+04, 0.77346600E+03, 0.11712200E+06, -.58169500E+05, -.20561500E+05, -.58548600E+05, -.29232000E+05, -.24897600E+05, -.10919600E+05, 0.16959800E+05, -.37916400E+05, -.21569500E+05, -.45576000E+05, -.10255800E+05, 0.52758300E+04, 0.60782000E+04, 0.51282000E+04, 0.40564200E+04, 0.75045000E+04, 0.68242200E+03, -.92977000E+04, 0.19144100E+04, 0.67663800E+04, 0.21539700E+04, 0.84435900E+04, -.38988000E+04, 0.95882800E+04, -.42046000E+04, 0.26514300E+04, 0.11185300E+05, -.94362800E+04, 0.10502700E+05, -.10464500E+05, 0.11130200E+05, -.96559700E+04, 0.61935800E+05, -.30049500E+05, 0.64541000E+04, -.30966700E+05, -.16556800E+05, -.10127500E+05, -.17303300E+05, 0.15660900E+05, -.29903700E+05, -.60104700E+04, -.31309300E+05, -.32123700E+05, 0.16228300E+05, 0.99208900E+04, 0.16063300E+05, -.91968200E+04, -.16897400E+05, 0.15326200E+05, 0.34575300E+04, 0.14938400E+05, -.14994700E+05, 0.12138300E+05, 0.85240200E+03, -.35718800E+03, 0.44188700E+03, -.42634900E+03, 0.12381600E+04, 0.13909600E+04, -.22030900E+04, -.59572700E+03, -.18147000E+04, 0.15151000E+04, -.68118100E+02, -.30570700E+05, 0.15535600E+05, 0.76979200E+04, 0.15286300E+05, -.11540700E+05, -.19011800E+05, 0.17702300E+05, 0.78042100E+04, 0.16856500E+05, -.16973500E+05, 0.14692500E+05, -.21775200E+06, 0.10772100E+06, 0.36206300E+05, 0.10886900E+06, 0.57091400E+05, 0.47807000E+05, 0.18262000E+05, -.36782100E+05, 0.67258700E+05, 0.41730600E+05, 0.86916900E+05, 0.16034000E+06, -.79287500E+05, -.35093900E+05, -.80153400E+05, -.39206700E+05, -.31959600E+05, -.12861800E+05, 0.27318200E+05, -.47704500E+05, -.28738500E+05, -.59903300E+05, -.13800700E+05, 0.70253600E+04, 0.80074300E+04, 0.69007400E+04, 0.50124400E+04, 0.89172400E+04, -.36966300E+04, -.61547200E+04, 0.18147300E+04, 0.77071700E+04, 0.82629400E+04, 0.66720900E+05, -.32515400E+05, 0.33909400E+04, -.33369800E+05, -.88303600E+04, -.23899500E+04, -.24961100E+05, 0.67389500E+04, -.35102400E+05, 0.13891900E+03, -.30262900E+05, -.12086400E+05, 0.62506400E+04, 0.21453300E+03, 0.60389000E+04, 0.37464700E+04, 0.17200500E+04, 0.67872800E+04, -.45568300E+04, 0.60756900E+04, 0.97156400E+03, 0.41928100E+04, 0.10925200E+05, 0.61222800E+04, -.10295300E+05, 0.49626400E+04, 0.10655900E+05, -.10409600E+05, -.40599000E+04, -.72840400E+03, 0.11802700E+05, 0.44261800E+04, -.64333500E+04, 0.74047600E+03, -.54060200E+04, -.17921700E+05, 0.56200800E+04, 0.55426600E+04, -.10582900E+05, 0.40073600E+04, -.12891400E+05, 0.66891500E+04, 0.10679100E+05, 0.38896600E+04, -.51438700E+04, 0.82390000E+04, -.56084100E+04, 0.18687900E+04 },
        { 0.54428700E+01, -.19319500E+00, -.13278200E+00, -.36356000E+00, 0.22844300E+00, -.89117900E+00, 0.15980700E+01, -.96282500E-01, -.16333200E+00, -.62297800E+00, -.25153400E-01, -.21850500E+00, 0.92028100E-01, -.29341400E-02, 0.10927900E+00, -.18745800E-01, 0.90453100E-02, 0.33150100E+00, 0.57617100E+04, -.25231200E+04, -.69805100E+03, 0.17920300E+04, -.51299400E+05, 0.25264300E+05, -.55597700E+04, 0.25640200E+05, 0.88403000E+04, -.38344200E+03, 0.18979300E+05, -.56209700E+04, 0.35125700E+05, -.12863200E+04, 0.20251800E+05, 0.21065300E+04, -.12248300E+04, -.29533700E+04, -.10556400E+04, 0.32009100E+04, 0.53613000E+04, -.31313900E+03, -.17259700E+04, 0.26713200E+04, 0.45272600E+04, -.22984800E+04, -.80498200E+03, 0.11831600E+03, -.82258300E+04, 0.39444900E+03, 0.10268800E+05, 0.16178800E+05, -.44501000E+04, -.35893700E+04, -.13537600E+03, 0.13491500E+05, -.31660600E+04, 0.13043800E+06, -.64359600E+05, -.11383600E+05, -.65203500E+05, -.30459600E+05, -.21934400E+05, -.15276400E+05, 0.30931300E+05, -.47782600E+05, -.18872100E+05, -.52264300E+05, 0.42930300E+04, -.21178500E+04, 0.71712900E+03, -.21457200E+04, -.81446800E+03, -.89674500E+02, -.16629800E+04, 0.43731700E+03, -.30761100E+04, 0.31502400E+02, -.16849000E+04, -.53006700E+04, 0.25210600E+04, -.32864800E+04, 0.26498600E+04, 0.23517700E+04, 0.16499600E+04, 0.10252800E+04, -.22418100E+03, 0.27949800E+04, 0.56894600E+03, 0.28729300E+04, -.74721400E+04, 0.42293700E+04, -.55051900E+04, 0.37290800E+04, 0.29579100E+04, 0.84845900E+03, 0.11139400E+05, 0.29476800E+04, 0.16659000E+05, 0.31705100E+02, -.55191000E+03, -.93609500E+03, 0.13911400E+03, -.11098600E+04, 0.46883100E+03, -.28246900E+04, -.56555900E+04, -.19589800E+03, 0.46338200E+04, -.51623900E+04, -.52433300E+04, 0.39654900E+04, 0.32453800E+05, -.16075300E+05, -.46304100E+04, -.16226400E+05, -.76252500E+04, -.59740600E+04, -.26234900E+04, 0.81316600E+04, -.10021000E+05, -.53288000E+04, -.12869000E+05, -.46772400E+05, 0.23085200E+05, 0.71300500E+04, 0.23386800E+05, -.34500000E+03, -.10567100E+05, 0.13759900E+05, -.14869400E+04, 0.19843700E+05, -.95203300E+04, 0.19318300E+05, 0.12705300E+05, -.62092900E+04, 0.11176500E+04, -.63472400E+04, -.45774600E+04, -.37141800E+04, -.15808200E+04, 0.33723700E+04, -.50116100E+04, -.31554400E+04, -.25912600E+04, -.78703600E+05, 0.39102900E+05, 0.76025300E+04, 0.39345200E+05, 0.18175200E+05, 0.15234900E+05, 0.64475900E+04, -.15536200E+05, 0.24610600E+05, 0.12898100E+05, 0.33707900E+05, -.29093800E+04, 0.11576000E+04, 0.14003400E+04, 0.14545700E+04, -.12775400E+04, -.27891100E+04, -.35275800E+04, -.18984000E+03, -.71654900E+04, -.24809000E+04, 0.50660500E+04, -.11538700E+05, 0.55627600E+04, -.36467900E+04, 0.57601700E+04, -.15494000E+04, -.43532900E+04, 0.98127500E+04, 0.22485300E+04, 0.13773000E+05, -.43249300E+04, 0.43788700E+04, -.43929800E+05, 0.21307000E+05, -.94197500E+04, 0.21964200E+05, 0.11495400E+05, 0.63342700E+04, 0.15006200E+05, -.54653200E+04, 0.30310500E+05, 0.41583000E+04, 0.16715300E+05, 0.88497600E+04, -.44948200E+04, -.28587300E+04, -.44256300E+04, 0.59069100E+04, 0.10188100E+05, -.43389600E+04, -.10486800E+04, -.44723400E+04, 0.10037500E+05, -.78058100E+04, 0.81527000E+03, -.43688700E+03, -.16909600E+04, -.40755700E+03, -.89418800E+03, -.97323800E+03, 0.12618700E+04, -.14722200E+03, 0.15931400E+04, -.10002500E+04, -.33582000E+03, 0.48381600E+04, -.25911000E+04, 0.11453000E+04, -.24195900E+04, 0.73268400E+04, 0.11532400E+05, -.42286700E+04, -.44612500E+03, -.47494400E+04, 0.11042100E+05, -.81352700E+04, 0.14390500E+06, -.71102500E+05, -.13420700E+05, -.71948900E+05, -.35122100E+05, -.28194000E+05, -.13909700E+05, 0.31800300E+05, -.48473900E+05, -.24262100E+05, -.59030200E+05, -.10257500E+06, 0.50587300E+05, 0.14094600E+05, 0.51278400E+05, 0.23346000E+05, 0.18892900E+05, 0.81565400E+04, -.21267100E+05, 0.31079900E+05, 0.16502600E+05, 0.42531800E+05, 0.32845400E+04, -.18928900E+04, -.11486900E+04, -.16424800E+04, -.21875200E+04, -.38632500E+04, -.12738500E+03, 0.31379600E+04, -.37202700E+04, -.32680600E+04, -.30249100E+03, -.45090200E+05, 0.21911200E+05, -.80714000E+04, 0.22550100E+05, 0.71285000E+04, 0.25648400E+04, 0.14896100E+05, -.17091400E+04, 0.27649500E+05, 0.70112000E+03, 0.20523400E+05, 0.30770300E+04, -.18272800E+04, 0.32332200E+04, -.15362100E+04, -.22204800E+04, -.67506100E+03, -.56397600E+04, 0.40703300E+03, -.95660500E+04, -.17616100E+03, 0.98957500E+03, -.75042900E+04, -.47288600E+04, 0.56966200E+04, -.41715500E+04, -.74283200E+04, 0.68632900E+04, 0.58634200E+04, 0.90995500E+03, -.48794800E+04, -.43203400E+04, 0.34238000E+04, 0.16408600E+04, 0.51702900E+04, 0.11109700E+05, -.33153900E+04, -.46965600E+04, 0.81263200E+04, -.10625100E+04, 0.83498200E+04, -.49095500E+04, -.65350100E+04, -.60238500E+04, 0.49225800E+04, -.42629200E+04, 0.22283800E+04, -.12958500E+04 },
        { -.44388400E+01, 0.88332600E-01, 0.14563200E+00, -.25087000E+00, -.46173500E+00, 0.33065600E+00, 0.69988900E+00, -.56932100E+00, -.26084800E+00, -.83208600E-01, -.24244000E-01, -.95628400E+00, 0.39516600E-01, -.95732500E-03, -.27139800E-01, 0.13616800E+00, -.81874100E+00, -.31541100E+00, -.88486000E+00, -.57175400E+04, 0.35998700E+04, -.65546000E+04, 0.19571000E+05, -.11725600E+05, -.21412300E+05, -.98057800E+04, -.32460200E+05, -.28318200E+05, 0.30751800E+05, 0.12399700E+05, 0.21774800E+05, -.32476800E+05, 0.13337000E+05, -.20271700E+05, 0.89015300E+04, 0.62672900E+04, 0.10131300E+05, 0.66154800E+03, 0.16077900E+04, 0.29299400E+04, -.37331900E+04, 0.10600000E+05, -.14246900E+04, 0.13931900E+05, -.36484000E+05, 0.16802000E+05, 0.11923100E+05, 0.18224600E+05, 0.30257800E+04, 0.36425800E+04, 0.37689200E+04, -.28069000E+04, 0.14284200E+05, -.88876800E+03, 0.25900000E+05, 0.17493800E+05, -.57705300E+04, 0.11288300E+05, -.87122900E+04, 0.21168600E+05, 0.10726500E+04, -.46966700E+04, 0.18116400E+05, -.16565300E+05, 0.46780400E+04, -.28055800E+05, -.21776100E+04, 0.12355400E+04, 0.22182600E+04, 0.10904800E+04, 0.31639000E+04, 0.25911300E+04, -.29185000E+04, -.13503000E+04, -.20365700E+04, 0.30128300E+04, -.11921900E+04, -.82612800E+04, 0.34236900E+04, -.85562700E+03, 0.41295600E+04, -.16444300E+04, -.51926300E+03, 0.20661800E+04, -.49128000E+04, 0.20613400E+04, 0.17462600E+04, -.18162300E+04, 0.11083400E+06, -.55134000E+05, -.51631000E+05, -.55444200E+05, -.24576500E+05, -.16613400E+05, -.21628100E+04, 0.27982000E+04, -.19853200E+05, -.19135800E+05, -.23329300E+05, -.47315700E+05, 0.23253500E+05, 0.25925900E+05, 0.23666800E+05, 0.11470000E+04, -.19407500E+05, 0.27774700E+05, 0.23150800E+05, 0.18395300E+05, -.14986700E+05, 0.75859200E+03, 0.91254500E+04, -.38670100E+04, -.20718000E+04, -.45607000E+04, 0.17322600E+04, -.11715500E+04, -.77884200E+02, 0.45243000E+04, -.40881700E+04, -.55730500E+03, -.61676300E+04, 0.94186000E+03, -.16912400E+04, -.13822100E+05, -.46936400E+03, -.15352300E+05, -.12509000E+03, -.51177200E+04, -.17164300E+05, -.11733300E+04, 0.25238000E+04, 0.12346300E+05, 0.47250700E+04, -.17642900E+04, 0.14507100E+04, -.23506000E+04, 0.35549100E+04, -.92751000E+03, 0.20474200E+04, 0.66441500E+04, -.19252200E+04, 0.87016200E+02, -.96423300E+04, -.39747100E+05, 0.18852800E+05, 0.32204400E+04, 0.19859100E+05, -.83738700E+04, 0.48543700E+04, 0.40013500E+04, -.97625100E+04, 0.17040900E+05, 0.21927600E+04, 0.27571600E+05, -.76064100E+05, 0.37458400E+05, 0.35306600E+05, 0.38045900E+05, 0.88559200E+04, -.85783100E+04, 0.21168900E+05, 0.12684300E+05, 0.22786800E+05, -.51074000E+04, 0.11402900E+05, 0.34576400E+05, -.18104100E+05, -.15767200E+05, -.17308200E+05, -.21181500E+05, -.20724800E+05, 0.17481500E+05, 0.14246800E+05, 0.26081100E+04, -.22187600E+05, -.35550300E+04, 0.23423500E+05, -.13700400E+05, -.23959200E+05, -.11712900E+05, -.33774200E+05, -.22722600E+05, 0.26793500E+05, 0.99716000E+04, 0.19837500E+05, -.28083400E+05, 0.15468600E+05, -.28689600E+05, 0.13387600E+05, 0.11800400E+05, 0.14342800E+05, 0.39997400E+04, 0.26393000E+04, 0.52761100E+04, 0.29731000E+04, 0.14596000E+05, -.13058700E+04, 0.15506300E+05, -.38891400E+04, 0.19757300E+04, -.19608600E+04, 0.19438600E+04, -.29346000E+04, -.26524800E+03, 0.27484300E+04, -.23386900E+03, 0.38542400E+04, -.65585700E+03, 0.41910400E+04, -.19135500E+05, 0.82965300E+04, 0.10832000E+05, 0.95667100E+04, 0.52120400E+04, 0.39178400E+04, 0.20189600E+04, 0.44326400E+04, 0.86552800E+04, -.16513600E+03, 0.14049200E+05, 0.38591600E+05, -.16290000E+05, 0.25910000E+04, -.19288000E+05, 0.20511900E+05, 0.42203200E+03, -.84210000E+04, 0.15825100E+05, -.24208500E+05, 0.52431100E+04, -.36853400E+05, -.38018800E+05, 0.16600000E+05, 0.49585800E+04, 0.18989500E+05, -.82271000E+04, 0.69787100E+04, 0.69854200E+03, -.11814600E+05, 0.13288300E+05, 0.40694900E+04, 0.27703600E+05, -.78274900E+04, 0.39766700E+04, 0.91784200E+04, 0.39186600E+04, -.78034100E+03, -.10557500E+05, 0.12864500E+05, 0.14422200E+05, 0.35948400E+04, -.74688400E+04, -.73401400E+04, 0.75748100E+03, -.24950100E+04, -.19450100E+05, -.36710400E+03, -.29498400E+05, -.16413600E+05, 0.25191800E+05, 0.72677700E+04, 0.21832200E+05, -.18872400E+05, 0.18634100E+05, -.61331900E+05, 0.30657000E+05, 0.28010200E+05, 0.30675500E+05, 0.13360000E+05, 0.87726600E+04, 0.18139800E+04, 0.69350900E+03, 0.11847600E+05, 0.96770700E+04, 0.14136000E+05, 0.33124800E+04, 0.43038800E+04, -.58930600E+04, -.59334600E+04, 0.69334700E+04, -.65943600E+04, 0.16022200E+05, -.24187500E+04, 0.62703700E+04, 0.12007600E+05, -.20541600E+05, 0.20465400E+05, -.64238900E+04, -.76395500E+04, -.78427400E+04, 0.18649300E+05, -.28374200E+03, 0.15369300E+04, -.39206800E+04, 0.16565500E+05, 0.35529800E+04, -.15101900E+05, 0.14960200E+05, 0.15381900E+05, -.21695300E+04, 0.14700400E+05 },
        { 0.55846200E+01, -.31037000E-02, -.15561000E+00, 0.23126200E+00, 0.65340200E+00, 0.64834900E+00, 0.46388900E-01, 0.55028800E-01, -.86447800E+00, 0.42810200E+00, -.10445700E+00, 0.32187200E+00, -.45333800E-01, -.21920500E-01, -.13474200E+00, -.58014800E-01, 0.42249200E+00, -.15193300E+00, 0.67118900E+00, 0.25192000E+00, -.28833200E+04, 0.76341000E+04, 0.17531100E+05, -.75382500E+04, 0.24480300E+05, -.87380800E+04, -.75663300E+04, 0.46801800E+03, -.18249500E+04, 0.50561800E+03, -.10965800E+05, 0.26630100E+04, -.24685200E+05, 0.12845000E+04, 0.21614400E+03, 0.20240400E+04, -.63581900E+03, -.31324200E+04, 0.13386900E+04, -.14546500E+04, -.18963200E+04, -.15580400E+04, 0.23927000E+04, -.41189100E+04, 0.24121300E+05, -.10941100E+05, -.12049500E+04, -.12037200E+05, -.95946800E+04, 0.43970800E+04, -.75864300E+04, -.60197600E+04, -.96926800E+04, 0.63767600E+04, -.17442400E+05, -.23738200E+05, 0.95394500E+04, -.47455900E+05, 0.11822800E+05, 0.11531900E+05, 0.69167400E+04, -.34851500E+04, -.84142100E+04, 0.13586300E+05, 0.54998300E+04, 0.31129900E+05, -.18955200E+04, 0.85920900E+03, -.22472700E+04, 0.94547100E+03, 0.70423400E+03, 0.13384700E+03, 0.15318300E+03, -.11438000E+02, 0.11140900E+04, -.12865100E+03, 0.24826900E+04, 0.63153100E+04, -.26560200E+04, 0.17415000E+04, -.31562300E+04, -.27055800E+04, -.10499100E+04, -.98423100E+03, 0.11214400E+04, -.26898600E+04, -.30378300E+04, 0.37416600E+04, -.20898500E+05, 0.10025700E+05, 0.16068200E+05, 0.10480100E+05, -.47399300E+04, -.19214200E+04, 0.96707100E+04, 0.41645200E+04, 0.40568800E+04, -.43865400E+03, -.75241400E+04, 0.46702000E+05, -.22898200E+05, -.20961200E+05, -.23359400E+05, -.13690400E+03, 0.44893000E+04, -.13259000E+05, -.25851900E+04, -.16858800E+05, 0.36294700E+04, -.79283800E+04, -.98422900E+04, 0.44260200E+04, -.75422200E+04, 0.49188700E+04, 0.35177900E+04, 0.12873200E+04, 0.77718500E+03, -.13405100E+04, 0.47344900E+04, 0.11023000E+04, 0.64839200E+04, -.39565700E+05, 0.20713300E+05, 0.29518500E+05, 0.19780800E+05, 0.96033700E+04, -.86033400E+04, 0.17243100E+05, 0.14688700E+05, 0.16166300E+05, -.11512200E+05, 0.46838200E+04, 0.11173600E+04, -.98063000E+03, -.70817700E+04, -.57467700E+03, 0.16572200E+04, -.13105600E+04, -.48427900E+03, 0.24673300E+02, 0.50832200E+03, -.93503400E+03, 0.52942500E+04, 0.22191200E+05, -.10477100E+05, 0.24340900E+05, -.11076100E+05, -.84132000E+04, -.55688200E+04, -.90345900E+02, 0.28206800E+04, -.89736200E+04, -.44421100E+04, -.17633400E+05, 0.44487800E+05, -.21757500E+05, -.20029900E+05, -.22255500E+05, 0.52325300E+02, 0.39404700E+04, -.13281500E+05, -.22274100E+04, -.14942800E+05, 0.31642700E+04, -.49471000E+04, 0.15317100E+05, -.70381300E+04, 0.29514500E+04, -.76315800E+04, -.19857300E+04, 0.36731400E+04, -.27825000E+04, -.11451800E+04, -.64663300E+04, 0.48737100E+04, -.15631800E+05, 0.16821100E+05, -.69578300E+04, 0.29328300E+05, -.84088400E+04, -.79264200E+04, -.16942800E+04, 0.36007500E+02, 0.64555800E+03, -.99910400E+04, 0.13030900E+04, -.26440600E+05, 0.17169600E+05, -.80547600E+04, -.82758600E+04, -.85822700E+04, -.64398700E+04, 0.40916300E+04, -.76884000E+04, -.66405500E+04, -.77336700E+04, 0.52302900E+04, -.60639800E+04, -.25255400E+04, 0.11820600E+04, 0.36361000E+04, 0.12632900E+04, 0.53051400E+03, 0.49431400E+02, 0.11565600E+03, -.10967600E+04, 0.45115400E+03, 0.55109600E+02, -.23550100E+03, 0.90100100E+04, -.35860300E+04, -.63881500E+04, -.45035600E+04, -.54457800E+04, 0.27000600E+04, -.51217400E+04, -.69201500E+04, -.46808700E+04, 0.42985600E+04, -.75377900E+04, -.36977500E+05, 0.16266800E+05, -.45593200E+05, 0.18478100E+05, 0.16277200E+05, 0.67541900E+04, -.96453500E+03, -.74118000E+04, 0.18524500E+05, 0.48230100E+04, 0.32859300E+05, 0.27470600E+05, -.11796300E+05, 0.27573900E+05, -.13708700E+05, -.94340700E+04, -.64556600E+04, -.54327400E+03, 0.28656000E+04, -.10877900E+05, -.50918500E+04, -.23261300E+05, 0.19684000E+05, -.96697300E+04, -.10039600E+05, -.98459500E+04, 0.78447500E+03, 0.16184400E+04, -.59410900E+04, -.16119500E+04, -.73652500E+04, 0.65414700E+03, -.17842500E+04, 0.10056400E+05, -.34319000E+04, 0.29471600E+05, -.50434600E+04, -.44228200E+04, -.48397200E+04, 0.27628000E+04, 0.28127300E+04, -.64370800E+04, -.38054800E+04, -.16758300E+05, 0.82311400E+04, -.39496700E+04, -.71619700E+04, -.41261800E+04, 0.30580900E+04, 0.17689100E+04, -.48495200E+04, -.34068600E+04, -.16396100E+04, 0.10950000E+04, 0.46510600E+04, 0.35110600E+04, 0.27302500E+04, -.14202500E+04, 0.23814100E+04, 0.15398300E+04, 0.18929700E+03, -.17046000E+04, -.58266100E+03, 0.61314500E+03, 0.85851800E+04, -.81637700E+04, 0.43108800E+03, -.67814100E+03, 0.42313400E+04, 0.14183800E+04, 0.91169700E+04, -.78156800E+03, 0.73299600E+03, -.30704100E+04, 0.13534600E+04, 0.29529300E+04, 0.22653000E+04, -.16831800E+04, 0.77998000E+04, -.18417400E+03, 0.71481100E+04 },
        { -.82979700E+01, 0.66027800E-01, 0.26741100E+00, 0.57133600E-01, -.89259700E+00, 0.66287600E+00, 0.73202700E+00, 0.14240500E+00, -.92415100E+00, 0.38490800E+00, 0.51071500E+00, -.14354500E+01, 0.19940500E-01, 0.20999300E-01, -.12119000E+00, 0.28786400E+00, -.44794400E+00, 0.75877600E-01, -.91374500E+00, 0.43009500E+00, 0.55679700E+00, 0.20061900E+05, -.32603300E+05, 0.15625800E+05, -.11742900E+05, 0.16241900E+05, -.67927900E+04, -.84489400E+04, 0.10892300E+05, 0.33426900E+04, 0.32249400E+05, -.84028500E+04, 0.42615100E+04, -.95149800E+04, 0.43720800E+04, 0.54697800E+03, 0.47436300E+04, 0.31433100E+04, 0.23726800E+04, 0.27089300E+04, 0.73527400E+02, 0.69079800E+04, 0.16048700E+04, -.43568500E+04, -.32000800E+05, 0.15489100E+05, 0.88779200E+04, 0.15949500E+05, 0.11762300E+05, 0.96402200E+04, 0.57816800E+04, 0.13804200E+04, 0.77098200E+04, 0.71690800E+04, -.75136100E+04, 0.92092500E+05, -.44795800E+05, 0.36057700E+04, -.45945300E+05, -.13099100E+04, -.93811800E+04, -.67060600E+04, 0.32064400E+05, -.29603400E+05, -.88372600E+04, -.43034800E+05, 0.30600500E+04, -.14794700E+04, 0.11454000E+04, -.15250500E+04, 0.53086900E+03, 0.45687600E+03, -.75563100E+03, -.18779200E+03, -.29029800E+04, 0.52107200E+03, -.27710800E+03, -.12946600E+05, 0.62529100E+04, -.77737500E+03, 0.64701700E+04, 0.10438000E+04, 0.12734100E+04, 0.19644800E+04, -.49787500E+04, 0.61670900E+04, 0.86690900E+03, 0.19739000E+05, -.14417600E+05, 0.71670900E+04, -.54847500E+03, 0.71388700E+04, -.17776000E+04, -.40802100E+04, 0.51287100E+04, 0.27427100E+04, 0.23720300E+05, -.35868600E+04, -.64511800E+03, 0.27892800E+05, -.13830400E+05, -.28158600E+04, -.13926300E+05, -.35036300E+04, -.61092300E+04, -.20380400E+04, 0.99940200E+04, -.14390100E+05, -.59840400E+04, -.34299900E+04, 0.28497400E+05, -.14015400E+05, -.58837100E+04, -.14243500E+05, -.21432100E+04, -.28749800E+04, -.26893500E+04, 0.92612400E+04, -.66921400E+04, -.29092200E+04, -.11917600E+05, -.21554900E+05, 0.10307700E+05, -.10739400E+05, 0.10781900E+05, -.97598700E+04, -.93749000E+04, 0.31362600E+04, -.11919300E+05, 0.11936000E+05, -.66920800E+04, 0.19538700E+05, 0.25804100E+05, -.12689800E+05, -.66437300E+04, -.12867200E+05, -.31346500E+04, 0.13015400E+03, -.62980100E+04, 0.24608200E+04, -.84954200E+04, -.37452300E+03, -.11771200E+04, -.66816300E+05, 0.33023800E+05, -.50605700E+02, 0.33365700E+05, 0.33769900E+04, 0.97340800E+04, 0.37343600E+04, -.17337700E+05, 0.17810400E+05, 0.79489200E+04, 0.33426200E+05, 0.14198300E+05, -.69806300E+04, -.48740400E+03, -.70704500E+04, -.72117100E+03, -.15816200E+04, -.21937000E+04, 0.30172600E+04, -.15340200E+05, -.19281900E+04, 0.37358000E+03, -.28987400E+04, 0.11266600E+04, -.25656200E+04, 0.13907200E+04, -.79128900E+04, -.92182300E+04, 0.48718900E+04, 0.76570800E+04, 0.12624300E+05, -.85829800E+04, -.91477600E+04, -.29159600E+05, 0.13766300E+05, -.13655000E+05, 0.14576100E+05, -.24610900E+04, 0.95726800E+03, 0.50259900E+04, 0.27131100E+04, 0.27748200E+05, -.81636800E+03, -.10913900E+04, -.31342000E+05, 0.15449300E+05, 0.13910800E+05, 0.15665400E+05, 0.11407300E+05, 0.78336300E+04, 0.64143900E+04, 0.32510400E+04, 0.85926200E+04, 0.83458900E+04, -.81691700E+04, -.27564600E+04, 0.13987600E+04, -.30997500E+04, 0.13769000E+04, -.21437100E+03, 0.65422500E+03, -.25138100E+02, -.75755600E+03, 0.26164800E+04, 0.29646300E+03, 0.18874700E+04, -.26713500E+05, 0.12961000E+05, 0.16865600E+05, 0.13353600E+05, 0.11575900E+05, 0.80913900E+04, 0.65613000E+04, 0.59606600E+04, 0.58092000E+04, 0.82342100E+04, -.12548400E+05, 0.11047300E+06, -.54017000E+05, -.15809500E+04, -.55213400E+05, -.55391700E+04, -.14331300E+05, -.56417600E+04, 0.34645800E+05, -.32595100E+05, -.12870400E+05, -.47114600E+05, -.81285100E+05, 0.39616100E+05, 0.65519200E+04, 0.40584400E+05, 0.36356200E+04, 0.10435300E+05, 0.63671800E+04, -.21671700E+05, 0.18762100E+05, 0.94853600E+04, 0.38994600E+05, 0.26107800E+05, -.13021100E+05, -.36190400E+04, -.13044000E+05, -.28678000E+04, -.42688800E+04, -.23154100E+04, 0.68529300E+04, -.10446700E+05, -.35257700E+04, -.67113600E+04, -.21124400E+05, 0.97059700E+04, -.24462500E+05, 0.10595700E+05, -.50225800E+04, 0.16803100E+04, -.46776200E+03, -.17784200E+04, 0.23056300E+05, 0.57181400E+02, 0.13637900E+05, 0.37666800E+04, -.18764300E+04, 0.16722800E+04, -.18592500E+04, 0.15087700E+04, 0.23677200E+04, -.24096700E+04, -.31739200E+03, -.11389100E+05, 0.20610900E+04, 0.31707500E+04, -.52107800E+04, -.27729000E+04, 0.17889400E+04, -.33778200E+04, -.32706700E+04, 0.23484600E+04, 0.10162500E+05, -.56612400E+03, -.70438300E+03, 0.40865900E+04, -.41891700E+04, 0.11453900E+05, 0.24244300E+04, 0.15078600E+04, -.40829700E+04, 0.40866000E+04, 0.33214400E+04, 0.37260200E+03, 0.48413000E+04, 0.10374200E+04, -.28507400E+04, -.89329100E+04, 0.99859000E+04, 0.17359100E+04, -.17593300E+04, 0.62069100E+04 },
        { -.80135900E+00, 0.99726300E-02, 0.27684600E-01, -.16265800E+00, -.22543100E-01, 0.89389100E-01, -.25568500E-01, -.51544300E-01, 0.18545700E+00, 0.11026600E+00, -.88413500E-03, -.14551400E-01, 0.61691400E-02, 0.58965500E-02, -.24172200E-01, 0.41647900E-02, 0.64644400E-02, 0.41542000E-01, 0.18322900E-01, -.85538200E-03, 0.90276700E-03, -.21397100E-01, -.15084600E+05, 0.81238500E+04, -.35636700E+04, 0.75393700E+04, 0.90075500E+04, 0.42565500E+04, 0.13356700E+04, -.20871200E+04, 0.42337000E+04, 0.39365800E+04, 0.45468100E+04, 0.47733600E+04, -.20045000E+04, -.26360200E+04, -.23873800E+04, 0.12598200E+04, 0.86715400E+03, -.90463600E+03, 0.86498700E+03, -.17624100E+04, 0.83766400E+03, -.27018200E+04, 0.44831900E+04, -.17955100E+04, -.60081300E+04, -.22440800E+04, 0.30259300E+04, 0.18603600E+04, -.12665500E+04, 0.13404800E+04, -.12125600E+04, 0.16127100E+04, -.26691900E+04, 0.28557400E+05, -.15173900E+05, 0.52646600E+04, -.14273800E+05, -.14672500E+05, -.72377600E+04, -.19192300E+04, 0.31403900E+04, -.95908300E+04, -.64965200E+04, -.96856400E+04, 0.13236600E+04, -.70610400E+03, 0.37122200E+03, -.66158900E+03, -.81254900E+03, -.40403100E+03, -.11882900E+03, 0.18058800E+03, -.36814900E+03, -.37029700E+03, -.39289900E+03, -.24774800E+03, 0.32332200E+03, -.11692200E+04, 0.12372400E+03, 0.13559700E+04, 0.82871600E+03, -.21234300E+03, 0.19444400E+03, 0.64891900E+02, 0.69247000E+03, -.37792800E+02, -.78805100E+04, 0.40566300E+04, 0.13522900E+04, 0.39372800E+04, 0.44716700E+04, 0.42661700E+04, 0.35633500E+03, -.17906800E+04, 0.61110300E+03, 0.36987900E+04, 0.82045800E+03, -.44977600E+04, 0.21604200E+04, 0.14830600E+03, 0.22496100E+04, -.10387500E+04, -.91481000E+03, 0.50127800E+03, -.86441800E+03, 0.23976300E+04, -.88438200E+03, 0.39101600E+04, 0.57125100E+04, -.30794300E+04, 0.15612000E+04, -.28560400E+04, -.28612800E+04, -.14578000E+04, -.36816800E+03, 0.46748700E+03, -.21721100E+04, -.12993900E+04, -.21333100E+04, -.92767700E+03, 0.83716700E+03, -.94780700E+03, 0.46404900E+03, 0.20827700E+04, 0.74297000E+03, 0.10177200E+03, 0.17951300E+03, 0.10577700E+02, 0.78209200E+03, -.10115900E+04, -.14341200E+04, 0.52897800E+03, 0.30356500E+04, 0.71875000E+03, -.19679800E+04, -.10546000E+04, 0.60034500E+03, -.61138000E+03, 0.42752300E+03, -.90405100E+03, 0.13117000E+04, -.12796500E+05, 0.66895000E+04, -.41275500E+04, 0.63961700E+04, 0.79138900E+04, 0.36259100E+04, 0.78181400E+03, -.12915800E+04, 0.43038900E+04, 0.33430400E+04, 0.43534000E+04, -.23995100E+03, 0.81486900E+02, -.83371100E+03, 0.12088600E+03, -.17121200E+04, -.16743000E+04, 0.11043800E+03, 0.21284300E+03, 0.15095100E+04, -.15244200E+04, 0.24088400E+04, -.74556400E+04, 0.39864700E+04, -.93355100E+03, 0.37249700E+04, 0.31791700E+04, 0.14613300E+04, 0.10562900E+04, -.94521300E+03, 0.24744400E+04, 0.12376900E+04, 0.23902600E+04, -.13526800E+05, 0.73477200E+04, -.55110500E+04, 0.67632300E+04, 0.91301000E+04, 0.40160100E+04, 0.14329000E+04, -.14617000E+04, 0.40077900E+04, 0.37575300E+04, 0.37587700E+04, 0.91329800E+04, -.43028200E+04, -.35456600E+04, -.45667500E+04, 0.60762300E+03, 0.63933900E+03, -.14842900E+04, 0.13810600E+04, -.31988200E+04, 0.59751300E+03, -.41087300E+04, 0.93315100E+03, -.48224800E+03, -.41196200E+03, -.46661000E+03, -.12285800E+02, -.43136400E+03, 0.19455000E+03, 0.31159900E+03, -.32508600E+03, -.31658400E+03, -.69546300E+03, 0.67115200E+04, -.29772200E+04, -.26450500E+04, -.33559100E+04, 0.84602300E+03, 0.99256900E+03, -.13082900E+04, 0.95319700E+03, -.23485900E+04, 0.91149300E+03, -.36239300E+04, 0.27179100E+05, -.14475000E+05, 0.74977900E+04, -.13588400E+05, -.16015700E+05, -.78623400E+04, -.15026200E+04, 0.26881100E+04, -.94418200E+04, -.71267900E+04, -.94767000E+04, -.19025300E+05, 0.10244200E+05, -.39199200E+04, 0.95098300E+04, 0.98710400E+04, 0.46305400E+04, 0.12552800E+04, -.21422200E+04, 0.66893600E+04, 0.41561700E+04, 0.67689100E+04, -.42402600E+04, 0.20064900E+04, 0.73659800E+03, 0.21204300E+04, -.57906500E+03, -.51272400E+03, 0.47264400E+03, -.88701600E+03, 0.18258400E+04, -.49214800E+03, 0.27834600E+04, -.10291900E+05, 0.57710300E+04, -.43049000E+04, 0.51475500E+04, 0.68817600E+04, 0.26038300E+04, 0.16005200E+04, -.98205000E+03, 0.30600500E+04, 0.25052200E+04, 0.27289800E+04, 0.54876600E+04, -.28299500E+04, -.11690400E+04, -.27428100E+04, -.27881400E+04, -.25690100E+04, -.18549700E+03, 0.10989900E+04, -.84028500E+03, -.22103400E+04, -.10193600E+04, -.23192200E+04, -.19841500E+04, 0.19938000E+04, -.53743900E+03, -.27770800E+04, 0.22590300E+04, -.17327900E+04, 0.78322800E+03, -.17043500E+04, -.43645300E+04, 0.51271900E+04, -.42766000E+04, 0.19287600E+04, 0.30582200E+04, 0.33302300E+03, -.50517200E+04, 0.16263000E+04, -.38804900E+03, 0.26187600E+04, -.38883800E+04, -.23095000E+04, 0.12846400E+04, -.17706100E+04, -.49085100E+04, 0.13348300E+04, -.40765600E+04 },
        { 0.27457200E+01, -.67256200E-01, -.12061100E+00, 0.21525300E+00, 0.30228400E+00, -.75402500E+00, 0.26663900E+00, 0.28272000E-02, -.19111400E+00, -.84191700E+00, 0.35331700E-01, -.35476000E+00, 0.15942700E+00, 0.78560500E-01, 0.45226600E+00, -.84779200E-01, 0.19310900E+00, 0.43823900E+00, 0.19174700E+00, -.45885100E+00, 0.13207700E+00, -.24007200E+00, 0.67109800E+01, -.30696200E+04, -.15925300E+05, -.25451100E+02, -.30576900E+05, -.26132900E+05, 0.20191400E+05, 0.11187300E+05, 0.35434700E+05, -.27729500E+05, 0.97916500E+04, -.19306500E+05, 0.76230100E+04, 0.60347100E+04, 0.96469800E+04, 0.11471300E+03, 0.12802000E+04, 0.48357400E+04, -.19071800E+04, 0.12171000E+05, -.55351200E+03, 0.95014300E+04, -.51106300E+05, 0.23085900E+05, 0.22322000E+05, 0.25531500E+05, 0.59550800E+04, 0.10263100E+05, 0.78704000E+04, -.52612900E+04, 0.13709600E+05, 0.65313200E+04, 0.20776200E+05, 0.92192300E+05, -.40863500E+05, -.18501300E+05, -.46053800E+05, 0.19339100E+05, -.43308500E+04, -.79654200E+04, 0.43468600E+05, -.26974300E+05, -.63299000E+03, -.47329100E+05, 0.24878300E+02, 0.21623000E+03, 0.15015500E+04, -.10305000E+02, 0.27187000E+04, 0.21362100E+04, -.17501500E+04, -.11061100E+04, -.32432700E+04, 0.23399000E+04, -.96984400E+03, -.14835400E+05, 0.62748000E+04, 0.15918500E+04, 0.74163900E+04, -.12863400E+04, -.49902500E+03, 0.32311500E+04, -.57732100E+04, 0.79017400E+04, -.89482000E+03, 0.48894100E+04, 0.52483900E+05, -.25784200E+05, -.32357400E+05, -.26263900E+05, -.14699200E+05, -.16822500E+05, 0.24252600E+04, 0.11315600E+05, 0.17343500E+05, -.17609400E+05, -.98252800E+04, -.20404500E+05, 0.96563600E+04, 0.14922600E+05, 0.10206200E+05, 0.10870900E+04, -.91262000E+04, 0.11696400E+05, 0.12109300E+05, -.38002600E+04, -.67251600E+04, 0.79405400E+03, 0.39223200E+05, -.18373100E+05, -.14375300E+05, -.19610000E+05, -.62899600E+03, -.46050700E+04, -.24239700E+04, 0.14678100E+05, -.69920400E+04, -.36779500E+04, -.15875200E+05, -.35599600E+05, 0.15705100E+05, -.45856700E+04, 0.17801600E+05, -.16448800E+05, -.13886200E+05, 0.71833500E+04, -.15431400E+05, 0.18041500E+05, -.11564900E+05, 0.24589300E+05, 0.35053500E+05, -.16544000E+05, -.13478000E+05, -.17512100E+05, 0.14866100E+04, 0.12527900E+03, -.66607600E+04, 0.81609600E+04, -.10637700E+05, 0.29079300E+03, -.14055500E+05, -.72767000E+05, 0.34770700E+05, 0.15410000E+05, 0.36365600E+05, -.68921700E+04, 0.87735600E+04, 0.39052300E+04, -.24517700E+05, 0.17673300E+05, 0.52574700E+04, 0.36321700E+05, -.45355900E+05, 0.21928000E+05, 0.24818400E+05, 0.22681200E+05, 0.67985800E+04, -.34615000E+02, 0.86422400E+04, -.68022400E+02, -.51034500E+04, 0.16212600E+04, 0.94849500E+04, 0.24238800E+05, -.13502300E+05, -.10834000E+05, -.12144100E+05, -.20784700E+05, -.20279000E+05, 0.10798700E+05, 0.15447400E+05, 0.12925400E+05, -.19473700E+05, -.60161500E+04, 0.20594800E+04, -.44160400E+04, -.15434300E+05, -.10314400E+04, -.26828000E+05, -.13846500E+05, 0.12957500E+05, 0.75833900E+04, 0.29012800E+05, -.17709300E+05, 0.98243900E+04, -.43675300E+05, 0.20459100E+05, 0.19406800E+05, 0.21835500E+05, 0.10167800E+05, 0.92628300E+04, 0.68741100E+04, 0.34577700E+03, 0.11262500E+05, 0.87652600E+04, 0.11865000E+05, -.22620700E+04, 0.12412200E+04, -.29077300E+04, 0.11310200E+04, -.19114400E+04, 0.38817200E+03, 0.78329600E+03, -.31196100E+03, 0.39929300E+04, -.28752600E+03, 0.27023900E+04, -.37491700E+05, 0.16655200E+05, 0.22130500E+05, 0.18744500E+05, 0.10512000E+05, 0.94514600E+04, 0.61744400E+04, 0.21655400E+04, 0.72258200E+04, 0.84389900E+04, 0.91642600E+04, 0.11979900E+06, -.54753100E+05, -.29608400E+05, -.59889500E+05, 0.16295300E+05, -.10318400E+05, -.81227400E+04, 0.48989800E+05, -.27305300E+05, -.52559000E+04, -.58119000E+05, -.93302100E+05, 0.42335200E+05, 0.26747800E+05, 0.46626700E+05, -.75726500E+04, 0.11201700E+05, 0.51845600E+04, -.32289600E+05, 0.19751600E+05, 0.77188200E+04, 0.43147300E+05, 0.85014100E+04, -.42430100E+04, 0.27600700E+04, -.42499000E+04, -.95393700E+03, -.52829800E+04, 0.40353900E+04, 0.94721800E+04, -.73322600E+04, -.32440300E+04, -.90462900E+04, -.53177700E+04, -.10059200E+04, -.21925300E+05, 0.26725400E+04, -.23438300E+05, -.97420100E+04, 0.83415100E+04, 0.32341000E+04, 0.27090400E+05, -.12963100E+05, 0.15781800E+05, -.32912300E+05, 0.16357500E+05, 0.18661700E+05, 0.16463500E+05, 0.89025900E+04, 0.95557700E+04, -.10987500E+04, -.46966000E+04, -.82073000E+04, 0.96600900E+04, 0.83423100E+04, -.22914200E+03, 0.20981200E+04, -.37616100E+04, -.48721700E+04, 0.42090400E+04, -.32567800E+04, 0.19416500E+05, -.23125700E+04, 0.35610200E+04, 0.98262400E+04, -.15355400E+05, 0.23447300E+05, -.26321400E+04, -.48928200E+04, -.58799000E+04, 0.12888100E+05, 0.99572000E+03, 0.12071700E+04, -.25038000E+03, 0.12894100E+05, 0.15654200E+04, -.15192500E+05, 0.18477500E+05, 0.12413200E+05, -.31834400E+04, 0.13373200E+05 },
        { -.89633900E+01, 0.26754900E+00, 0.43970700E+00, 0.11258000E+01, -.31559300E+00, 0.13283200E+01, 0.21348300E+00, -.24953900E+00, 0.90086300E+00, 0.80105500E+00, -.27953400E-01, 0.17920500E+01, 0.24814500E+00, -.34925400E+00, 0.50275100E+00, -.20986900E+00, 0.94556000E+00, 0.81174200E+00, 0.38246200E+00, 0.24761100E+00, -.54569700E+00, 0.21072300E+00, 0.14003300E+02, 0.10643800E+01, 0.12593800E+06, 0.18766100E+03, 0.18524800E+05, 0.45319000E+05, -.16383100E+05, -.27555600E+05, -.69317700E+05, 0.48777500E+05, -.17320900E+05, 0.20729400E+05, -.10132200E+05, 0.18941000E+04, -.10320400E+05, -.16602900E+04, 0.69318200E+04, -.11209700E+05, -.31469500E+04, -.18274200E+05, 0.84345900E+04, -.71307500E+04, 0.16187000E+06, -.80729100E+05, -.49361300E+05, -.80775000E+05, -.27343400E+05, -.10328000E+05, -.30851700E+05, 0.98207000E+04, -.45801700E+05, -.56468000E+04, -.57292400E+05, -.14587600E+06, 0.73138800E+05, -.15403000E+06, 0.72622200E+05, 0.11712800E+05, 0.27170800E+04, 0.17218500E+04, -.67473300E+05, 0.50354800E+05, -.55944000E+04, 0.81239300E+05, -.13462200E+04, 0.67767000E+03, -.11164700E+05, 0.65745600E+03, -.13120700E+04, -.30023500E+04, 0.99553000E+03, 0.21729400E+04, 0.65353700E+04, -.34976600E+04, 0.22696200E+04, 0.28272200E+05, -.14036000E+05, 0.10135800E+05, -.14126400E+05, -.38356800E+04, -.45963800E+03, -.53481700E+04, 0.99506700E+04, -.14711000E+05, 0.24830900E+03, -.80598200E+04, -.13519300E+06, 0.67998800E+05, 0.95707900E+05, 0.67800200E+05, 0.22420600E+05, 0.24341400E+05, 0.25255000E+05, -.15961600E+05, -.11842700E+05, 0.27253000E+05, 0.37312100E+05, 0.99001500E+05, -.49478900E+05, -.64251300E+05, -.49554600E+05, -.11949300E+05, 0.75157600E+03, -.24851400E+05, -.14182500E+05, -.18127700E+05, -.12288000E+04, -.37413100E+05, -.57124100E+05, 0.28599900E+05, -.15161300E+05, 0.28546900E+05, 0.76857300E+04, 0.37512800E+04, 0.45795200E+04, -.20258500E+05, 0.11654600E+05, 0.22781600E+04, 0.22887100E+05, 0.10872700E+05, -.54075800E+04, 0.51402700E+05, -.54500600E+04, 0.31123200E+05, 0.23078300E+05, 0.20683500E+04, 0.30303100E+05, -.14917300E+05, 0.17669000E+05, -.21082700E+05, -.10833300E+06, 0.54182900E+05, 0.33389000E+05, 0.54057300E+05, 0.80171000E+04, -.25512200E+04, 0.20575100E+05, -.18254700E+05, 0.31339400E+05, -.12232900E+04, 0.36358200E+05, 0.11280600E+06, -.56501800E+05, 0.82891600E+05, -.56269900E+05, -.11969100E+05, -.10541200E+05, -.38644100E+04, 0.32613300E+05, -.30997400E+05, -.32677500E+04, -.59956200E+05, 0.13682500E+06, -.68345200E+05, -.74465000E+05, -.68484400E+05, -.19629300E+05, -.10590700E+05, -.26674900E+05, 0.44354500E+04, -.13109500E+05, -.12439600E+05, -.47319500E+05, -.73298600E+04, 0.35953500E+04, 0.33934700E+05, 0.38487500E+04, 0.17001700E+05, 0.27743800E+05, -.79431200E+04, -.23672400E+05, -.32978000E+05, 0.27697300E+05, -.50051200E+04, 0.22155600E+04, -.15175500E+04, 0.12856300E+06, -.10959000E+04, 0.75621600E+04, 0.20875800E+05, -.16458200E+04, -.20454300E+05, -.59179500E+05, 0.28027200E+05, -.17336100E+05, 0.10538100E+06, -.52380400E+05, -.52577400E+05, -.52673300E+05, -.21568700E+05, -.54614400E+04, -.26294200E+05, -.75746300E+04, -.31129300E+05, -.80299300E+04, -.23605700E+05, -.35256100E+03, 0.26969300E+02, 0.11960400E+05, 0.17933800E+03, 0.35244800E+04, 0.21563600E+04, -.85625500E+03, -.14401700E+04, -.52409800E+04, 0.26509000E+04, -.17045900E+04, 0.90870400E+05, -.45081700E+05, -.56813400E+05, -.45425300E+05, -.20687500E+05, -.67167900E+04, -.23253500E+05, -.96641000E+04, -.23077500E+05, -.75009300E+04, -.17692400E+05, -.18698100E+06, 0.93730200E+05, -.14997900E+06, 0.93418000E+05, 0.22333400E+05, 0.94837200E+04, 0.19604900E+04, -.70263200E+05, 0.58236100E+05, -.48133900E+03, 0.96822000E+05, 0.15211600E+06, -.76165200E+05, 0.83834500E+05, -.75876400E+05, -.17911700E+05, -.14154400E+05, -.81094900E+04, 0.45069000E+05, -.33570900E+05, -.68248400E+04, -.72574100E+05, 0.29162700E+05, -.14781000E+05, -.32127900E+05, -.14605500E+05, -.37591400E+04, 0.12254400E+04, -.10940400E+05, -.13151600E+05, -.54887000E+04, -.79528700E+03, -.83976900E+04, -.39972200E+05, 0.19768000E+05, 0.15615300E+06, 0.19882200E+05, 0.17353000E+05, 0.18040500E+05, 0.10542700E+05, -.17968400E+05, -.40643200E+05, 0.23885900E+05, -.83989700E+04, 0.70277600E+05, -.35475200E+05, -.50416300E+05, -.35208600E+05, -.11990200E+05, -.12072800E+05, -.12697000E+05, 0.52462300E+04, 0.74479400E+04, -.13401600E+05, -.20819700E+05, 0.33029300E+04, 0.14454200E+03, 0.38324800E+04, 0.98978700E+04, -.36693900E+04, 0.49812000E+04, -.30617600E+05, 0.22817700E+03, -.52797200E+04, 0.47802100E+04, 0.92490300E+04, -.26183800E+05, -.71457600E+03, 0.19434000E+05, 0.12869700E+05, -.31557400E+04, -.41550700E+03, -.17541800E+04, -.10952200E+04, -.74362700E+04, -.65521700E+03, 0.23188700E+05, -.31832300E+05, -.39145300E+04, 0.12814900E+04, -.21419100E+03 },
        { 0.13195400E+02, -.34646300E+00, -.71507900E+00, -.49671800E+00, 0.77419800E+00, -.28707700E+01, 0.11269800E+01, -.54430100E+00, -.92700300E+00, -.26995200E+01, 0.67700200E-01, -.37118900E+01, 0.12466900E+00, 0.76868800E+00, -.39404700E+00, 0.39111200E-02, -.11790900E+01, -.97637200E+00, -.15583000E+01, -.82745500E+00, 0.25873000E+00, -.26337900E+00, -.45813100E+01, 0.13776200E+01, 0.49813200E+00, -.28466200E+03, -.38081400E+05, -.56261300E+05, 0.27684200E+05, 0.45524600E+05, 0.11086400E+06, -.66327900E+05, 0.25927100E+05, -.34019700E+05, 0.16927600E+05, 0.12849800E+05, 0.16942700E+05, -.61480600E+03, -.61205700E+04, 0.14598800E+05, 0.38133500E+04, 0.25706500E+05, -.93178300E+04, 0.13065700E+05, -.13918800E+06, 0.69715200E+05, 0.74834400E+05, 0.69351300E+05, 0.21736900E+05, 0.11835600E+05, 0.25244200E+05, -.13129400E+05, 0.20920800E+05, 0.67222200E+04, 0.43104300E+05, 0.26565500E+06, -.13329800E+06, -.14129700E+06, -.13234800E+06, -.58701800E+04, -.15105900E+05, -.11716400E+05, 0.10043100E+06, -.74119200E+05, -.32121700E+04, -.12605300E+06, -.53719500E+03, 0.26925700E+03, 0.70822400E+02, 0.29234200E+03, 0.38408700E+04, 0.47890600E+04, -.21182600E+04, -.42504300E+04, -.97918700E+04, 0.57240900E+04, -.21201000E+04, -.29595100E+05, 0.14839900E+05, 0.84120300E+04, 0.14782800E+05, -.38693300E+03, -.98801500E+03, 0.57007600E+04, -.12817500E+05, 0.15229600E+05, -.20400500E+04, 0.79618000E+04, 0.18199000E+06, -.92780200E+05, -.60730200E+05, -.91303000E+05, -.58607200E+05, -.53950900E+05, -.92047400E+04, 0.46523600E+05, 0.40042800E+05, -.58540100E+05, -.53531500E+05, -.72969800E+04, 0.49658200E+04, 0.22922500E+05, 0.37299200E+04, 0.13896600E+05, -.57185600E+04, 0.11810400E+05, 0.26436100E+05, -.14852300E+05, -.14039400E+04, -.96849500E+03, 0.86629000E+05, -.43407900E+05, -.54434900E+05, -.43291600E+05, -.70932500E+04, -.86895800E+04, -.53671300E+04, 0.30776200E+05, -.14212900E+05, -.69976200E+04, -.31776700E+05, -.20179700E+05, 0.10289700E+05, -.26198200E+05, 0.10110600E+05, -.37385600E+05, -.25709300E+05, 0.19368600E+04, -.28339200E+05, 0.26511800E+05, -.21348900E+05, 0.25858800E+05, 0.99450700E+05, -.49917600E+05, -.44627400E+05, -.49559900E+05, -.48968900E+04, 0.12272500E+04, -.17580000E+05, 0.22590800E+05, -.19840900E+05, 0.51771900E+03, -.30203500E+05, -.17517500E+06, 0.87575500E+05, 0.78151700E+05, 0.87385900E+05, 0.91805700E+04, 0.19962600E+05, 0.63098700E+04, -.46108700E+05, 0.45676700E+05, 0.10215900E+05, 0.85692000E+05, -.10473800E+06, 0.53613900E+05, 0.49794500E+05, 0.52477800E+05, 0.34714800E+05, 0.20983500E+05, 0.11706700E+05, -.12321300E+05, -.19015400E+05, 0.24859000E+05, 0.33294400E+05, 0.36983100E+05, -.18313100E+05, -.70801100E+04, -.18770300E+05, -.35283200E+05, -.45757500E+05, 0.17478700E+05, 0.42697300E+05, 0.48399600E+05, -.48100800E+05, -.35216600E+04, 0.15302100E+05, -.68890000E+04, -.57471700E+02, -.76690900E+04, -.35287800E+05, -.37158500E+05, 0.11508000E+05, 0.40332100E+05, 0.91296500E+05, -.48724400E+05, 0.15593500E+05, -.10794200E+06, 0.53782300E+05, 0.46427800E+05, 0.53944900E+05, 0.27169700E+05, 0.16041700E+05, 0.20361400E+05, 0.32725700E+04, 0.27746800E+05, 0.17295500E+05, 0.23523600E+05, -.68669700E+04, 0.35903200E+04, -.68109100E+04, 0.34288900E+04, -.42875300E+04, -.20664900E+04, 0.19403300E+04, 0.63924800E+03, 0.10330300E+05, -.32858200E+04, 0.54215300E+04, -.88577800E+05, 0.44154500E+05, 0.52659700E+05, 0.44273900E+05, 0.25227400E+05, 0.14940500E+05, 0.18002200E+05, 0.47225400E+04, 0.13001100E+05, 0.15237700E+05, 0.13121900E+05, 0.29043900E+06, -.14566700E+06, -.15230000E+06, -.14510900E+06, -.16047000E+05, -.23825900E+05, -.75492100E+04, 0.92757200E+05, -.90032200E+05, -.95483100E+04, -.13813100E+06, -.26972500E+06, 0.13522500E+06, 0.14473500E+06, 0.13458700E+06, 0.21888700E+05, 0.32138200E+05, 0.13241200E+05, -.78899900E+05, 0.46087700E+05, 0.22467200E+05, 0.11614900E+06, 0.30438800E+05, -.14293200E+05, 0.20877400E+04, -.15183000E+05, 0.31612600E+04, -.81458400E+04, 0.57890700E+04, 0.24578400E+05, -.12436700E+05, -.43396000E+04, -.18046400E+05, 0.56903500E+05, -.27926000E+05, -.46204900E+05, -.28294200E+05, -.45183300E+05, -.35301900E+05, -.40334200E+03, 0.40704500E+05, 0.75513300E+05, -.44913000E+05, 0.79694400E+04, -.88609300E+05, 0.45323400E+05, 0.27850700E+05, 0.44410200E+05, 0.29585600E+05, 0.27797500E+05, 0.30749700E+04, -.19489600E+05, -.21741800E+05, 0.29957300E+05, 0.26723500E+05, -.94743900E+02, 0.33433300E+04, -.64963900E+04, -.56401200E+04, 0.80343300E+04, -.77390100E+04, 0.50152700E+05, -.14126900E+04, 0.61345100E+04, 0.15858900E+05, -.36170400E+05, 0.39938300E+05, -.26103400E+04, -.21100900E+05, -.25370400E+05, 0.29822900E+05, 0.11946500E+04, -.85751800E+03, 0.24331800E+03, 0.15715600E+05, 0.28963600E+04, -.36320600E+05, 0.48753800E+05, 0.27352600E+05, -.23365500E+04, 0.22256000E+05 },
        { -.96825200E+01, 0.29339900E+00, 0.36010100E+00, -.27958500E+01, -.87880600E+00, 0.22325100E+01, -.79361500E+00, 0.16753300E+00, 0.73253500E+00, 0.18652100E+01, -.19523300E+00, -.13288900E+01, 0.43615300E+00, 0.48487100E-01, -.33866500E+00, 0.58516100E+00, -.54392800E+00, 0.15495500E+00, -.25555900E+00, 0.97818100E+00, -.40856700E+00, 0.21694500E+00, 0.16494300E+01, -.32528100E+00, 0.59712000E+00, -.36631800E+00, -.54012500E+05, -.24870300E+05, 0.37963600E+04, 0.10676400E+05, 0.54926900E+05, -.28667100E+05, 0.16069100E+05, -.36974700E+05, 0.18559600E+05, 0.11736000E+05, 0.18489600E+05, -.28082600E+04, 0.15799800E+04, 0.85478700E+04, -.38079600E+04, 0.20736000E+05, -.62792600E+03, 0.16770100E+05, -.57666300E+05, 0.29115700E+05, 0.41585300E+05, 0.28832500E+05, 0.19804500E+04, 0.14753200E+05, 0.81037600E+04, -.11994800E+05, 0.49854300E+04, 0.10748100E+05, 0.17657000E+05, 0.16888700E+06, -.84913800E+05, -.67311500E+05, -.84439000E+05, 0.50203300E+05, -.14018600E+05, -.27918200E+04, 0.84244000E+05, -.36829600E+05, -.97105600E+04, -.74186500E+05, 0.87472600E+03, -.43264200E+03, -.10900000E+03, -.43746500E+03, 0.47787600E+04, 0.16947800E+04, -.16284000E+02, -.72951000E+03, -.51303900E+04, 0.20968400E+04, -.18804400E+04, -.18201200E+05, 0.92303500E+04, 0.27904800E+04, 0.91002800E+04, -.50660100E+04, 0.14636600E+04, 0.18466200E+04, -.11498200E+05, 0.90334300E+04, 0.75719000E+03, 0.60697300E+04, 0.40302500E+05, -.21708200E+05, -.23962900E+05, -.20204600E+05, -.38260600E+05, -.20643700E+05, -.10219400E+05, 0.61257300E+03, 0.36385600E+05, -.20249500E+05, 0.21239600E+04, 0.11852800E+06, -.57879000E+05, -.13270400E+05, -.59232600E+05, 0.56123800E+03, -.16612600E+05, -.28739700E+04, 0.45465000E+05, -.46408300E+05, -.14723700E+05, -.53595300E+05, 0.57969800E+05, -.29057000E+05, -.33253500E+05, -.28981000E+05, 0.58119400E+04, -.61416500E+04, -.32299000E+04, 0.25546500E+05, -.60654700E+04, -.55512400E+04, -.19715500E+05, -.43114400E+05, 0.21780200E+05, -.50931000E+04, 0.21558000E+05, -.23757500E+05, -.17649900E+05, 0.64994400E+04, -.21374800E+05, 0.25179700E+05, -.13935700E+05, 0.24790700E+05, 0.39307800E+05, -.19811100E+05, -.30008500E+05, -.19649600E+05, 0.49318600E+04, 0.80505000E+02, -.77480300E+04, 0.14604700E+05, -.53777300E+04, -.78766100E+03, -.92470000E+04, -.11905000E+06, 0.59448200E+05, 0.38502500E+05, 0.59523500E+05, -.22581600E+05, 0.16678800E+05, 0.13301400E+04, -.41849700E+05, 0.24610600E+05, 0.11540000E+05, 0.54616700E+05, 0.44787400E+05, -.21059800E+05, 0.17832700E+04, -.22333100E+05, 0.13368500E+05, -.16133700E+03, 0.15195500E+04, 0.21250600E+05, -.40914400E+05, 0.49916400E+03, -.27502900E+05, 0.42645200E+05, -.21142000E+05, -.39040600E+04, -.21324400E+05, -.33825700E+05, -.22275900E+05, -.45792100E+03, 0.19479200E+05, 0.17713600E+05, -.22354000E+05, -.81252200E+04, -.27120500E+04, 0.18599700E+04, 0.79911800E+04, 0.13568700E+04, -.46022800E+05, -.44213200E+04, -.92901800E+04, 0.26669200E+04, 0.44691200E+05, -.10292300E+05, 0.14102900E+05, -.68044400E+05, 0.33986200E+05, 0.32889500E+05, 0.34020400E+05, 0.14910000E+05, 0.17126100E+05, 0.85106600E+04, -.34730400E+04, 0.13350200E+05, 0.17460600E+05, 0.18630600E+05, -.20973100E+05, 0.10524900E+05, -.83147500E+03, 0.10482800E+05, 0.22269400E+03, 0.43368900E+04, -.81459500E+02, -.46545100E+04, 0.10736100E+05, 0.29553000E+04, 0.10906100E+05, -.57795200E+05, 0.29002600E+05, 0.35766600E+05, 0.28897800E+05, 0.14174100E+05, 0.14006100E+05, 0.94095500E+04, -.13012900E+04, 0.61909100E+04, 0.14016400E+05, 0.11288500E+05, 0.18549300E+06, -.93125800E+05, -.79865400E+05, -.92746000E+05, 0.48888400E+05, -.22995700E+05, 0.32591000E+04, 0.86235400E+05, -.35426100E+05, -.16853000E+05, -.83866800E+05, -.16870700E+06, 0.84742900E+05, 0.70642900E+05, 0.84350500E+05, -.25315600E+05, 0.19658700E+05, 0.77991600E+04, -.61347300E+05, 0.26602800E+05, 0.15742900E+05, 0.66537700E+05, 0.86666400E+05, -.42503400E+05, -.95888000E+04, -.43310300E+05, -.13089100E+04, -.13592300E+05, -.12066300E+04, 0.31815200E+05, -.29184100E+05, -.11187900E+05, -.41512500E+05, -.16344600E+05, 0.85902300E+04, -.20615300E+05, 0.81765100E+04, -.39697300E+05, -.61822000E+03, -.11769000E+05, 0.39618600E+03, 0.48057000E+05, -.67596200E+04, 0.27991900E+05, -.30852100E+05, 0.16230300E+05, 0.16959800E+05, 0.15445800E+05, 0.23140000E+05, 0.13218200E+05, 0.46724900E+04, -.64876900E+02, -.16526600E+05, 0.12542800E+05, 0.42520500E+04, -.80637600E+03, 0.15628400E+04, -.35263100E+04, -.38203400E+04, 0.56713500E+04, -.29780500E+04, 0.26213800E+05, -.46816800E+04, 0.30340700E+04, 0.40478400E+05, -.47633600E+05, 0.38047500E+05, -.29679600E+04, -.36829100E+04, -.19048900E+04, 0.47951600E+05, 0.30237500E+04, 0.49820200E+04, 0.11296600E+04, 0.20878500E+05, 0.12989000E+04, -.19502900E+05, 0.23821400E+05, 0.36707600E+05, -.16718000E+05, 0.43736900E+05 },
        { -.30394000E+01, 0.46585900E-01, 0.53625000E-01, -.13623800E+01, -.15383900E+00, -.53034600E+00, 0.89236900E+00, -.37513700E+00, -.13719200E+01, -.10622900E+01, 0.15247800E-01, -.65451300E+00, 0.12846500E+00, 0.74691200E-01, 0.75130200E-01, -.29572700E-01, 0.21726400E+00, 0.44501000E+00, 0.38349800E+00, -.67934100E-02, 0.25746500E+00, -.11444400E+00, 0.41160400E+01, 0.55381500E+00, 0.79644800E-01, -.51946100E-02, 0.81722900E-01, 0.11599500E+05, -.73250600E+04, -.98374000E+04, -.14944400E+05, 0.11671100E+05, -.40401000E+04, 0.19468800E+04, -.95254300E+03, -.31831800E+04, -.97359700E+03, -.29464900E+03, 0.11988500E+04, -.16900800E+04, -.10007800E+04, -.22459700E+04, 0.12195400E+04, -.10947300E+04, 0.17233500E+05, -.86626400E+04, -.10765000E+05, -.86167300E+04, -.37473300E+04, -.26794600E+04, -.25525700E+04, 0.20946700E+04, -.42349500E+04, -.22224800E+04, -.64552300E+04, -.22863300E+05, 0.11700700E+05, 0.18632200E+05, 0.11431300E+05, 0.10187500E+05, -.58199100E+04, 0.66355200E+04, -.21283200E+04, 0.11376900E+05, -.49468100E+04, 0.95574100E+04, 0.32381200E+03, -.16363700E+03, 0.44978200E+02, -.16189900E+03, -.23420700E+02, -.10632000E+04, 0.62862500E+03, 0.97389500E+03, 0.12127300E+04, -.10809100E+04, 0.21086700E+03, 0.29581100E+04, -.14981000E+04, -.21116600E+04, -.14790400E+04, -.74051700E+03, 0.87721600E+03, -.10638600E+04, 0.72093300E+03, -.18602900E+04, 0.87379500E+03, -.87645700E+03, -.24160200E+05, 0.12463700E+05, 0.91938800E+04, 0.12083800E+05, 0.50519800E+04, 0.78994400E+04, -.14548000E+04, -.90948700E+04, -.58103400E+04, 0.84320300E+04, 0.71548400E+04, 0.16236300E+05, -.84009400E+04, 0.10588100E+03, -.81203300E+04, -.26617400E+04, -.37388500E+04, -.27358000E+03, 0.17211800E+04, -.23947100E+04, -.32731900E+04, -.81370700E+04, -.14361200E+05, 0.71987500E+04, 0.70098500E+04, 0.71803100E+04, 0.40101400E+04, 0.93043400E+03, 0.16310800E+04, -.32645000E+04, 0.35110000E+04, 0.10662000E+04, 0.49617700E+04, 0.16588100E+05, -.83652800E+04, -.53384500E+04, -.82940900E+04, 0.27386100E+04, 0.90592300E+04, -.65350300E+04, -.25282100E+03, -.94013800E+04, 0.78444400E+04, -.75906400E+04, -.21982900E+05, 0.11003400E+05, 0.81665300E+04, 0.10991100E+05, 0.20260900E+04, -.34809300E+01, 0.35994800E+04, -.36528600E+04, 0.65701300E+04, 0.54900200E+02, 0.84613700E+04, 0.15485400E+05, -.77738100E+04, -.12375700E+05, -.77426300E+04, -.62777100E+04, 0.23848400E+04, -.33671300E+04, 0.10705500E+04, -.58122900E+04, 0.22716600E+04, -.68578600E+04, 0.22360800E+05, -.11417700E+05, -.61603000E+04, -.11184700E+05, -.46226400E+04, -.57486900E+04, 0.17796000E+03, 0.56477200E+04, 0.31271000E+03, -.55804600E+04, -.89197900E+04, 0.92886800E+03, -.50030900E+03, 0.25393200E+04, -.46430700E+03, 0.16230800E+04, 0.39445300E+04, -.21685800E+04, -.40789300E+04, -.66494700E+04, 0.44215300E+04, -.40433100E+04, -.46452500E+04, 0.21332300E+04, 0.43408400E+03, 0.23225600E+04, -.82370700E+03, 0.10119000E+05, -.60607100E+04, -.10513400E+05, -.11994900E+05, 0.10455500E+05, -.13218700E+04, 0.17915300E+05, -.88931800E+04, -.73459500E+04, -.89575200E+04, -.31363700E+04, -.18789900E+04, -.31849300E+04, 0.13586100E+04, -.53942300E+04, -.24321500E+04, -.44478900E+04, -.27638400E+04, 0.13824200E+04, -.24644100E+03, 0.13821900E+04, 0.93991300E+03, 0.15746300E+04, -.46612800E+03, -.10138700E+04, 0.14788300E+03, 0.14142600E+04, 0.91800800E+03, 0.13154300E+05, -.65749200E+04, -.70263100E+04, -.65771800E+04, -.30149400E+04, -.20539700E+04, -.25977000E+04, 0.51443200E+03, -.33137200E+04, -.24955800E+04, -.18038600E+04, -.31412800E+05, 0.15944400E+05, 0.21096100E+05, 0.15706400E+05, 0.12305000E+05, -.53047100E+04, 0.78054000E+04, -.22091800E+04, 0.14780700E+05, -.49053500E+04, 0.13112200E+05, 0.24770600E+05, -.12618500E+05, -.17956300E+05, -.12385100E+05, -.97697600E+04, 0.95233200E+03, -.41134600E+04, 0.36986400E+04, -.64484100E+04, 0.23943100E+03, -.89754400E+04, 0.82020100E+04, -.43329800E+04, 0.22523300E+04, -.41026200E+04, -.97674600E+03, -.19685500E+04, -.32287900E+03, 0.26933100E+03, -.20838900E+04, -.17724600E+04, -.40063400E+04, -.18903500E+05, 0.92622900E+04, 0.34045200E+04, 0.94514300E+04, 0.19235100E+04, 0.10976500E+05, -.31835800E+04, -.11831500E+05, -.64613300E+04, 0.10823300E+05, 0.46810200E+04, 0.10940000E+05, -.56990200E+04, -.40195900E+04, -.54713900E+04, -.22661300E+04, -.39495100E+04, 0.11767700E+04, 0.42146000E+04, 0.35313400E+04, -.43455700E+04, -.29636900E+04, -.18121500E+03, -.95048800E+03, 0.12322100E+04, 0.67164100E+03, -.11763700E+04, 0.96781400E+03, -.85186400E+04, -.50658900E+03, -.11499100E+04, 0.40366500E+04, -.12112200E+04, -.39375900E+04, -.15250200E+03, 0.31196900E+04, 0.95445300E+04, 0.28031900E+04, 0.73906100E+03, 0.18518100E+04, 0.60197100E+03, 0.11360600E+04, -.92111100E+03, 0.67218200E+04, -.93855900E+04, 0.79524600E+03, -.54737500E+04, 0.30555300E+04 },
        { 0.16630200E+01, -.56098700E-01, -.56594400E-01, 0.96034500E-01, 0.13360300E+00, -.32796200E+00, -.25693000E+00, 0.41632700E+00, -.70086500E-01, -.69564000E-01, 0.12838000E-01, -.40976500E+00, -.66002000E-01, -.96157700E-02, 0.11247900E+00, -.98665500E-02, -.24551300E+00, -.11258100E+00, 0.26906600E-01, -.28920400E+00, -.38298900E+00, 0.11860300E-01, 0.14440300E+01, 0.36413200E+00, 0.19082000E+00, 0.11571100E+00, -.22299000E-01, 0.51952200E+00, -.90259700E+04, 0.13683300E+04, 0.43364000E+03, 0.16435300E+04, 0.30104600E+03, -.47576800E+04, 0.23222900E+04, 0.32947300E+04, 0.23790000E+04, -.19394700E+04, -.16325400E+04, 0.23295700E+04, 0.93716300E+01, 0.36143500E+04, -.14215100E+04, 0.28153800E+04, -.14834600E+05, 0.74395800E+04, 0.10319200E+05, 0.74172700E+04, -.25071300E+04, 0.17743500E+04, 0.38062100E+04, -.43635400E+04, 0.59803000E+04, 0.13789100E+04, 0.73211100E+04, -.30742000E+05, 0.14918200E+05, 0.14977500E+05, 0.15371300E+05, 0.10197000E+05, 0.14376100E+05, -.44598900E+04, -.70792400E+04, 0.77432300E+04, 0.10434800E+05, 0.16002000E+05, 0.41066700E+03, -.20286900E+03, -.29153500E+03, -.20534100E+03, -.21271400E+03, -.26442200E+03, 0.10258800E+04, 0.79142500E+02, -.14972900E+02, -.38395500E+03, -.18799100E+03, -.69875100E+03, 0.36724800E+03, -.11634300E+03, 0.34935500E+03, -.96839600E+03, -.89491800E+03, 0.67172800E+03, -.60976900E+03, 0.74492600E+03, -.70838900E+03, 0.20999400E+03, 0.18342700E+05, -.97199400E+04, -.83378700E+04, -.91751900E+04, 0.28883200E+03, 0.54986400E+04, -.16369600E+05, -.24699500E+04, -.57642700E+04, 0.62175900E+04, -.55835900E+04, -.20682100E+05, 0.10729300E+05, 0.95303000E+04, 0.10343300E+05, 0.46832400E+04, 0.45128300E+04, 0.94060600E+03, -.15585500E+04, 0.27559000E+04, 0.33118000E+04, 0.95887200E+04, -.33278800E+04, 0.16190300E+04, 0.21613900E+04, 0.16642200E+04, 0.16852200E+04, 0.29837200E+04, -.23138400E+04, -.23592100E+03, 0.23047500E+04, 0.20461800E+04, 0.31268200E+04, -.24399500E+05, 0.12286500E+05, 0.78197700E+04, 0.12199800E+05, -.27996800E+04, -.10342700E+05, 0.87580400E+04, 0.12758200E+04, 0.11251200E+05, -.89046800E+04, 0.86143300E+04, 0.18559500E+05, -.92623100E+04, -.94241800E+04, -.92794500E+04, 0.16044400E+04, 0.11225900E+04, -.44543900E+04, 0.36879700E+04, -.67880600E+04, 0.88300700E+03, -.71578400E+04, 0.97523100E+04, -.47869800E+04, -.49281000E+04, -.48762500E+04, -.60087200E+04, -.79172400E+04, 0.41534300E+04, 0.24515300E+04, -.40145300E+04, -.61720100E+04, -.49103300E+04, -.19728700E+05, 0.10185600E+05, 0.91398200E+04, 0.98686800E+04, 0.28899300E+04, 0.11099800E+04, 0.62066700E+04, -.67423100E+03, 0.30982700E+04, 0.21103600E+03, 0.76660700E+04, -.29663100E+04, 0.15090400E+04, 0.10579600E+04, 0.14830200E+04, 0.34193100E+04, 0.76935000E+04, -.11771700E+05, -.39103400E+04, -.15004900E+04, 0.75838200E+04, 0.33385100E+04, -.51169800E+04, 0.28482100E+04, 0.48860000E+04, 0.25585500E+04, 0.32092100E+04, 0.48697800E+04, -.11515300E+05, -.18810500E+04, -.30705200E+03, 0.58990800E+04, 0.20065400E+04, -.21497700E+05, 0.10630200E+05, 0.10877000E+05, 0.10748700E+05, 0.14744600E+02, 0.16280700E+04, 0.36453000E+04, -.36904800E+04, 0.62215000E+04, 0.22034500E+04, 0.78831300E+04, -.24131900E+04, 0.12036500E+04, 0.16282200E+04, 0.12063200E+04, 0.32188100E+03, 0.57245600E+03, -.90700000E+03, -.75941600E+03, 0.51557700E+03, 0.70843600E+03, 0.11953700E+04, -.18365200E+05, 0.91531000E+04, 0.98163500E+04, 0.91825900E+04, 0.19400600E+02, 0.94977200E+03, 0.42549900E+04, -.28789600E+04, 0.58122500E+04, 0.12973500E+04, 0.57225600E+04, -.18972400E+05, 0.90666800E+04, 0.92853700E+04, 0.94862400E+04, 0.10240100E+05, 0.12954500E+05, -.48826400E+04, -.30555900E+04, 0.81774700E+04, 0.94486600E+04, 0.10048200E+05, 0.24910900E+05, -.12058500E+05, -.12674000E+05, -.12455700E+05, -.78163000E+04, -.12165900E+05, 0.65345000E+04, 0.67073900E+04, -.72577900E+04, -.88801300E+04, -.14503500E+05, -.11800200E+05, 0.62315400E+04, 0.49455000E+04, 0.59017300E+04, 0.29184500E+04, 0.30750700E+04, -.74805200E+02, -.72607000E+03, 0.19697800E+04, 0.23145300E+04, 0.55011600E+04, 0.34855500E+04, -.14321500E+04, -.68859700E+02, -.17424800E+04, 0.16349300E+04, 0.20784100E+04, -.10776400E+05, 0.43027900E+03, -.29520200E+04, 0.31224600E+04, -.81654000E+03, -.12309800E+05, 0.64939500E+04, 0.56538500E+04, 0.61563200E+04, 0.69801700E+03, -.22647700E+04, 0.82727000E+04, 0.68759200E+03, 0.32452200E+04, -.26534000E+04, 0.39182400E+04, -.79176400E+03, -.45668300E+03, 0.25164200E+03, 0.11861000E+04, 0.33217900E+03, 0.43362500E+03, 0.13136100E+04, 0.15238600E+02, -.46897800E+03, 0.30013000E+02, -.27626700E+04, 0.41085900E+04, 0.12736600E+04, -.37325600E+03, -.27161600E+04, 0.15966600E+04, -.70489500E+03, -.18209900E+03, 0.18375600E+03, 0.15218000E+04, -.11131000E+02, -.10444800E+04, 0.31960600E+04, 0.20028000E+04, -.18132600E+03, -.24780400E+02 },
        { 0.14188900E+01, -.63165300E-01, -.48877800E-01, -.24938800E+00, 0.27121800E+00, -.30551200E+00, 0.26103700E+00, -.18474000E+00, 0.41076300E-01, -.11859200E+00, 0.67354100E-01, 0.58055900E-01, 0.32733900E-01, -.54216200E-03, -.88588500E-01, 0.11386300E-01, -.72383600E-01, -.15136500E+00, -.11237100E+00, -.70144600E-01, 0.25914000E-01, -.62947600E-01, 0.72262900E+00, -.58433900E-01, 0.78166300E-03, 0.32148100E-01, 0.16611500E+00, -.55372400E+00, -.41174400E+00, -.24977800E+04, -.75052200E+04, 0.22696600E+04, -.43406600E+04, -.11497100E+04, 0.54698800E+03, 0.13293500E+04, 0.57452800E+03, 0.18119700E+04, 0.12264400E+04, 0.32772800E+03, 0.41801300E+03, 0.70317700E+03, 0.12173000E+04, 0.49309100E+03, -.49785600E+03, 0.21955300E+03, 0.38467200E+03, 0.24901500E+03, 0.33499200E+04, 0.15465200E+04, 0.45865400E+03, -.10828000E+03, 0.37201200E+04, 0.11672200E+04, -.11213400E+04, -.41269600E+05, 0.20593600E+05, 0.20615000E+05, 0.20634100E+05, 0.95526100E+04, 0.89971400E+04, -.15089200E+04, -.11437900E+05, 0.10388900E+05, 0.64433800E+04, 0.19805100E+05, 0.80333000E+02, -.40531900E+02, -.35059500E+02, -.40151500E+02, -.80776400E+02, -.10355400E+03, 0.60274300E+02, 0.32088000E+03, 0.68263200E+03, -.27689400E+03, 0.33953200E+03, 0.72311000E+03, -.38961900E+03, 0.46929800E+02, -.36151200E+03, 0.23788600E+03, -.12981400E+03, 0.31143200E+03, 0.61639500E+03, -.18650600E+03, -.14870300E+02, -.97787300E+03, -.76839800E+04, 0.40393000E+04, 0.58335100E+04, 0.38497900E+04, 0.61515500E+04, 0.81989900E+04, -.25300600E+04, -.37999600E+04, -.47141700E+04, 0.87528600E+04, 0.24155700E+04, -.84531000E+04, 0.39956800E+04, 0.97083000E+03, 0.42219900E+04, -.20886400E+04, -.40552000E+04, 0.17969000E+04, -.22126900E+04, 0.30046800E+04, -.36722700E+04, 0.97481400E+03, -.99898400E+04, 0.49984300E+04, 0.54419500E+04, 0.49943500E+04, 0.22265200E+04, 0.26655200E+04, -.55630700E+03, -.28929800E+04, 0.19450500E+04, 0.21287700E+04, 0.46247500E+04, -.12009500E+05, 0.60050700E+04, 0.21508500E+04, 0.60046200E+04, -.11544700E+04, -.42959600E+04, 0.45368800E+04, 0.97886200E+03, 0.41408500E+04, -.36819300E+04, 0.32404700E+04, 0.39754200E+04, -.19742200E+04, -.96513400E+03, -.19884500E+04, -.82215500E+03, 0.15684900E+04, -.18490600E+04, -.28962600E+03, -.37862500E+04, 0.11693900E+04, 0.41425600E+03, 0.19300800E+05, -.96264700E+04, -.93106600E+04, -.96502200E+04, -.55335100E+04, -.50127900E+04, 0.12947100E+04, 0.40383100E+04, -.54985200E+04, -.37832900E+04, -.91604700E+04, -.21795600E+03, -.14120200E+03, -.21348200E+04, 0.10012300E+03, -.39977800E+04, -.63046000E+04, 0.23109900E+04, 0.77792300E+03, 0.33391800E+04, -.61554900E+04, -.16740700E+04, -.23582500E+04, 0.11701300E+04, 0.53080700E+03, 0.11793900E+04, 0.12212300E+04, 0.21859800E+04, -.18463600E+04, -.35939700E+04, -.38032700E+04, 0.32951700E+04, -.90173100E+03, 0.17296000E+04, -.85778400E+03, -.11924100E+04, -.86492500E+03, 0.72097400E+03, 0.15012400E+04, -.12214000E+04, -.36161700E+04, -.77383100E+04, 0.30424600E+04, -.42484200E+04, -.58287700E+04, 0.28717300E+04, 0.33161300E+04, 0.29146500E+04, 0.32347900E+04, 0.10098000E+02, 0.12013500E+04, -.10828700E+04, 0.32596700E+04, 0.23564200E+03, -.19142100E+03, 0.20870000E+03, -.10783700E+03, -.21277400E+03, -.10380300E+03, 0.18207500E+03, 0.25203700E+03, -.34969900E+03, -.47588300E+03, -.54744300E+03, 0.29269800E+03, 0.10254800E+03, -.38387300E+04, 0.18854200E+04, 0.27839500E+04, 0.19193500E+04, 0.38761500E+04, 0.92181000E+03, 0.52257400E+03, -.73279200E+03, 0.31979000E+04, 0.78518300E+03, -.13838800E+04, -.33652900E+05, 0.16790200E+05, 0.17084700E+05, 0.16826400E+05, 0.95755900E+04, 0.89969000E+04, -.28215300E+04, -.83232900E+04, 0.10216100E+05, 0.63957500E+04, 0.17508400E+05, 0.38358000E+05, -.19136800E+05, -.19138100E+05, -.19178500E+05, -.86937200E+04, -.82611800E+04, 0.90002900E+03, 0.98740500E+04, -.82862500E+04, -.65087600E+04, -.17154600E+05, -.60584300E+04, 0.29465800E+04, 0.92254700E+03, 0.30258600E+04, -.79550000E+03, -.14198000E+04, 0.54461900E+03, -.19736800E+04, 0.14260400E+04, -.12231100E+04, 0.12426200E+04, -.17375200E+03, 0.10126200E+03, 0.47442900E+03, 0.86263900E+02, 0.53391100E+03, 0.18066000E+04, -.64869900E+03, -.30845900E+04, -.74528600E+04, 0.29627400E+04, -.20243700E+04, 0.20628300E+04, -.11045800E+04, -.23542400E+04, -.10343000E+04, -.28083400E+04, -.40595000E+04, 0.15241700E+04, 0.17033000E+04, 0.30482800E+04, -.44304900E+04, -.33021100E+03, -.19141800E+03, 0.32998200E+03, -.62745300E+02, 0.21438600E+03, -.64658500E+03, 0.39202400E+03, -.17988200E+04, -.20363000E+03, -.10564800E+02, -.10875000E+04, 0.22780500E+04, 0.14822100E+04, -.10933100E+01, -.24145100E+03, 0.20500900E+03, -.19928500E+04, -.50371900E+03, -.55744400E+03, 0.42540800E+03, 0.61547200E+03, -.18741400E+03, 0.73312000E+03, -.95861900E+03, -.18435200E+04, 0.25631800E+03, -.10659900E+04 },
        { -.42822100E+01, 0.14041700E+00, 0.13906300E+00, -.31311300E+00, -.27734700E+00, 0.54574300E+00, 0.98160100E+00, -.93952600E+00, -.87001500E-01, 0.14371000E+00, -.43120600E-01, 0.97703400E-01, 0.12334900E+00, 0.19994100E-01, -.23529700E+00, -.19237900E-01, -.10110300E+00, -.14121200E+00, -.67721100E+00, 0.69098200E+00, 0.74028400E+00, -.51275700E-01, -.29055000E+00, 0.12778900E+00, -.18397300E+00, -.13742500E+00, -.11739600E+00, 0.15546900E+00, 0.12510300E+00, -.53498400E+00, 0.82608100E+04, -.13098200E+04, 0.74301900E+04, -.88970800E+02, 0.10253700E+03, -.11076900E+04, 0.44613600E+02, 0.12054300E+04, -.88420500E+03, 0.13331400E+03, 0.86678400E+03, -.13178600E+04, -.55003500E+03, -.36902500E+03, 0.20751600E+04, -.10085700E+04, -.26234500E+04, -.10376200E+04, 0.40023400E+04, -.46749300E+04, -.71425600E+03, 0.22767600E+04, -.59673900E+04, -.31633300E+04, -.29935900E+04, 0.25752600E+05, -.12609200E+05, -.15046100E+05, -.12876000E+05, -.69097400E+04, -.11197200E+05, 0.10568800E+05, 0.11262700E+05, -.51087100E+04, -.85326500E+04, -.23023100E+05, -.25262000E+03, 0.12612200E+03, 0.17558100E+03, 0.12630400E+03, 0.16331700E+03, 0.21218900E+03, -.16977800E+03, -.18206300E+03, -.81921000E+03, 0.31090800E+03, -.55376400E+03, -.40980500E+03, 0.24415600E+03, 0.78000500E+03, 0.20488500E+03, 0.91232300E+03, 0.68825900E+03, -.89755200E+03, -.93941700E+03, -.62285300E+03, 0.57867700E+03, 0.38594400E+03, -.27476900E+05, 0.13589600E+05, 0.13452900E+05, 0.13735400E+05, -.49448100E+04, -.10350000E+05, 0.15250300E+05, 0.74365800E+04, 0.20398500E+05, -.99944800E+04, 0.15029400E+05, 0.53670900E+05, -.26551900E+05, -.20647500E+05, -.26833600E+05, -.33262100E+04, 0.91739700E+02, -.10494800E+05, 0.16039500E+04, -.14155400E+05, -.95856500E+01, -.22926900E+05, 0.49905200E+04, -.24622600E+04, -.38907500E+04, -.24950300E+04, -.12159900E+04, -.21464100E+04, 0.21303400E+04, 0.14809200E+04, -.17746300E+04, -.15571300E+04, -.42653800E+04, 0.35789200E+05, -.17926200E+05, -.12456400E+05, -.17894600E+05, -.50511400E+03, 0.93587900E+04, -.11766600E+05, -.12259900E+04, -.12855300E+05, 0.85227500E+04, -.10355400E+05, -.10946200E+05, 0.54448200E+04, 0.53854100E+04, 0.54732600E+04, -.22554200E+04, 0.42717000E+03, 0.25706700E+04, -.24966500E+04, 0.56267800E+04, -.12297200E+03, 0.46594800E+04, -.72637300E+04, 0.35685800E+04, 0.36582000E+04, 0.36317900E+04, 0.50728500E+04, 0.62932500E+04, -.65037900E+04, -.16817700E+04, 0.34083000E+04, 0.48090500E+04, 0.75022500E+04, 0.41447700E+05, -.20385200E+05, -.16574900E+05, -.20720300E+05, 0.14971500E+03, 0.47960300E+04, -.12889200E+05, -.32141000E+04, -.16492400E+05, 0.44151100E+04, -.18587300E+05, 0.23338100E+04, -.11868400E+04, -.31614800E+03, -.11670100E+04, -.47316600E+04, -.86130800E+04, 0.83075500E+04, 0.54194500E+04, 0.54890500E+04, -.86879100E+04, 0.17918800E+04, 0.23780700E+04, -.13167200E+04, -.35279100E+04, -.11889900E+04, -.12962400E+04, -.37001200E+04, 0.19091900E+04, 0.32159400E+04, 0.88381500E+04, -.44160800E+04, 0.53495100E+04, 0.11935400E+04, -.44982800E+03, -.43078900E+04, -.59687400E+03, 0.31850600E+04, -.33187100E+04, 0.13241300E+04, 0.36347400E+04, 0.10950400E+04, -.27423900E+04, -.38516500E+04, 0.14907000E+04, -.73810200E+03, -.15694100E+04, -.74556700E+03, 0.35549900E+03, -.48271300E+02, 0.84742800E+02, 0.35932200E+03, -.17545100E+03, -.23394200E+03, -.40074100E+03, 0.54488900E+04, -.26488600E+04, -.52432400E+04, -.27244400E+04, 0.17705300E+04, -.32836900E+04, -.22265000E+03, 0.30015900E+04, -.22826700E+04, -.24603700E+04, -.31861000E+04, 0.14848300E+05, -.71939500E+04, -.92144700E+04, -.74241100E+04, -.97037600E+04, -.11226300E+05, 0.14355200E+05, 0.61206400E+04, -.10381300E+05, -.91001200E+04, -.15971200E+05, -.29046600E+05, 0.14282500E+05, 0.16068700E+05, 0.14523100E+05, 0.63305900E+04, 0.10160700E+05, -.66634700E+04, -.87367800E+04, 0.33918800E+04, 0.76189600E+04, 0.20111900E+05, 0.27824600E+05, -.13884100E+05, -.10737900E+05, -.13911000E+05, -.21181700E+04, -.12798200E+04, -.38546100E+04, 0.24161700E+04, -.60855700E+04, -.10945600E+04, -.12197200E+05, 0.10481500E+05, -.53885000E+04, -.57829700E+04, -.52404900E+04, -.30830900E+04, -.27708800E+04, 0.11136700E+04, 0.31178700E+04, 0.67732300E+04, -.38350100E+04, 0.13103100E+04, 0.20211600E+05, -.10101900E+05, -.96341700E+04, -.10104700E+05, 0.11046600E+04, 0.40820800E+04, -.78154200E+04, -.25761700E+04, -.10876700E+05, 0.39955800E+04, -.10066600E+05, 0.58805100E+03, 0.11806000E+03, -.20495700E+02, -.38573900E+03, 0.21488500E+03, -.91637300E+03, 0.10061300E+04, 0.96398700E+02, 0.33489200E+03, 0.23379400E+04, 0.32442200E+03, -.29356700E+04, -.63566200E+03, -.32120700E+04, 0.88719100E+03, 0.10236900E+04, 0.68970400E+03, 0.78272300E+02, -.56205200E+03, -.27481300E+04, 0.23669200E+03, -.90538200E+03, -.85025000E+03, 0.56649100E+03, -.16040600E+04, 0.24391100E+04 },
        { 0.34925400E+00, 0.55855800E-01, -.24756300E-01, 0.13607000E+01, -.35843000E+00, 0.19438400E+00, -.85390300E+00, 0.67764200E+00, -.46691800E-01, -.41707300E-01, -.82396400E-01, -.23856000E+00, 0.11198800E+00, 0.16356200E-01, 0.64512900E+00, 0.90703200E-01, 0.20136900E+00, 0.56763400E-01, 0.18794200E+00, -.77142400E-01, -.51471400E-01, 0.25469000E-01, -.16601300E+01, -.13214200E+00, -.81611200E-01, -.11114300E-01, 0.48454200E-01, 0.30972700E+00, 0.22220200E+00, 0.87578200E-01, 0.32551100E+00, -.93511700E+03, 0.26286900E+04, -.51277800E+03, 0.26448800E+03, 0.28521800E+03, 0.25640900E+03, -.11345000E+04, 0.11024500E+03, -.30496000E+03, -.10897900E+04, -.12945000E+02, -.22076300E+03, 0.14062500E+04, 0.16426100E+04, -.82281900E+03, -.35734600E+04, -.82130800E+03, -.26330800E+04, 0.74906500E+03, -.65527800E+03, -.99975300E+03, -.26918900E+03, 0.21195300E+03, 0.40793700E+04, 0.12283300E+05, -.60952600E+04, -.83304300E+04, -.61416000E+04, -.16284800E+04, -.23563700E+03, -.30931800E+04, 0.22606500E+04, -.35780300E+04, 0.49286100E+03, -.94590100E+04, 0.11345100E+02, -.56647200E+01, -.39595800E+02, -.56734800E+01, -.81437100E+01, 0.53242200E+00, 0.25924200E+01, -.24022900E+02, 0.21374600E+02, 0.68502500E+02, -.24184500E+03, -.90070800E+01, -.59286500E+00, 0.26926400E+03, 0.45016200E+01, -.27700400E+03, -.66877000E+02, 0.94044400E+02, 0.20629800E+03, 0.23722300E+03, -.20022700E+03, 0.63751800E+03, 0.21488200E+05, -.10379100E+05, -.77654100E+04, -.10744600E+05, -.20725200E+04, -.24372400E+04, -.33473700E+04, 0.18643900E+04, -.62239600E+04, -.30434600E+04, -.64946400E+04, -.26222900E+05, 0.12792400E+05, 0.53913300E+04, 0.13111700E+05, 0.40884400E+04, 0.39278400E+04, 0.30339100E+04, -.24850900E+04, 0.56423800E+04, 0.40561600E+04, 0.83004700E+04, 0.49621600E+04, -.24510900E+04, -.22264900E+04, -.24810500E+04, -.84823200E+03, -.86794800E+03, -.45510900E+03, 0.14329300E+04, -.60493400E+03, -.67756900E+03, -.30796400E+04, -.38158100E+04, 0.18868500E+04, 0.44295900E+04, 0.19079100E+04, 0.13571800E+04, 0.75701200E+03, 0.77192800E+03, 0.80134300E+02, 0.86772500E+03, 0.31712900E+03, 0.37409900E+04, 0.64219800E+03, -.30489900E+03, 0.13422700E+04, -.32116900E+03, 0.62779900E+03, -.16889300E+04, 0.74666400E+03, 0.11310300E+04, 0.52883100E+03, -.10708200E+04, -.42769600E+04, -.63696200E+04, 0.31708800E+04, 0.51094400E+04, 0.31848000E+04, 0.65227800E+03, 0.24361500E+03, 0.13759400E+04, -.17344800E+04, 0.15218100E+04, -.97806600E+02, 0.48044800E+04, -.26050600E+05, 0.12716300E+05, 0.71359600E+04, 0.13025800E+05, 0.35876400E+04, 0.35234500E+04, 0.33365000E+04, -.25108700E+04, 0.61262400E+04, 0.38076800E+04, 0.82309100E+04, -.15819800E+04, 0.79355300E+03, -.11276100E+03, 0.79097400E+03, 0.13249700E+04, 0.15741700E+04, -.13354800E+04, -.75848200E+03, 0.10452600E+03, 0.11336000E+04, 0.18976300E+04, -.24332700E+04, 0.11214600E+04, 0.34062400E+03, 0.12166400E+04, -.18942800E+03, 0.10865200E+03, 0.44627700E+03, -.11712000E+03, 0.58596100E+03, -.61586700E+03, 0.44830000E+04, 0.51752500E+04, -.25836600E+04, -.28010200E+04, -.25876400E+04, -.21009300E+04, 0.14911100E+04, -.19029500E+04, -.72317400E+03, -.29941200E+04, 0.88893400E+03, 0.70207100E+03, -.18775600E+03, 0.67687000E+02, 0.97270100E+03, 0.93845200E+02, -.44027800E+03, -.22653600E+03, 0.18153900E+03, 0.11998100E+03, 0.10620900E+03, -.19172800E+03, 0.40174500E+03, 0.42427000E+04, -.21082900E+04, -.31072000E+04, -.21213500E+04, -.22806200E+04, 0.94691000E+03, -.12538500E+04, -.62230700E+03, -.20676600E+04, 0.52358700E+03, 0.18829800E+04, 0.12853200E+05, -.63670100E+04, -.81757900E+04, -.64266200E+04, -.92599500E+03, -.27106900E+03, -.39898100E+04, 0.28140900E+04, -.11278800E+04, 0.82233600E+03, -.10020200E+05, -.96476900E+04, 0.47822600E+04, 0.63410500E+04, 0.48238200E+04, 0.15684200E+04, 0.67554300E+03, 0.15127700E+04, -.26707000E+04, 0.37294200E+04, 0.36775200E+03, 0.68293500E+04, -.11401700E+05, 0.55235500E+04, 0.17090500E+04, 0.57010400E+04, 0.20403700E+04, 0.18248400E+04, 0.12751700E+04, -.88452700E+03, 0.23516600E+04, 0.18866700E+04, 0.36175700E+04, -.48623500E+04, 0.23566900E+04, 0.46259000E+04, 0.24312100E+04, 0.75180300E+03, -.85535400E+02, 0.49195800E+03, -.30811900E+03, 0.10598700E+04, -.51187200E+03, 0.32485600E+04, -.12208800E+05, 0.59100200E+04, 0.45794000E+04, 0.61045800E+04, 0.14894300E+04, 0.18583800E+04, 0.13988900E+04, -.15175900E+04, 0.27512000E+04, 0.21519800E+04, 0.36811600E+04, -.76968000E+02, -.11980900E+03, 0.50760800E+02, -.20072400E+02, 0.37037400E+03, -.65449700E+02, 0.91975700E+03, 0.26714000E+02, -.13108000E+03, -.90615500E+03, -.15122400E+04, 0.30099000E+03, -.39187700E+00, 0.12818900E+04, -.19641700E+03, 0.60906400E+02, 0.42036800E+02, 0.12607900E+02, 0.14974000E+03, 0.13455900E+04, -.61152500E+02, 0.95195700E+01, 0.10630000E+04, 0.17916800E+04, 0.95547000E+03, -.86998000E+03 },
        { 0.14691100E+02, -.31229300E+00, -.50033200E+00, -.77796700E+00, 0.20793900E+01, -.34185000E+01, 0.11708400E+01, -.22283900E+01, 0.22701900E+01, -.23952400E+01, -.14798100E+01, 0.63053700E+01, 0.36856400E+00, 0.38619700E-01, -.17462400E+01, -.98052100E+00, 0.13068200E+01, -.48192100E+00, 0.95240000E+00, -.13266800E+01, -.24630400E+01, 0.18528700E+01, -.92512800E+01, -.34573200E+01, 0.13909800E+00, -.25773200E+00, 0.11911600E+01, -.15985600E+01, -.53211500E+01, 0.28820300E+01, -.10354700E+01, 0.67865300E+01, 0.12200700E+06, -.41407700E+05, 0.20277700E+05, 0.25978700E+05, 0.20702800E+05, 0.80790500E+03, -.71569700E+04, 0.91777700E+04, -.77123300E+04, 0.28048100E+04, -.52770200E+04, 0.34320700E+05, -.81034900E+05, 0.40534700E+05, 0.52918800E+05, 0.40517700E+05, -.10884300E+05, -.20774300E+05, 0.23267300E+05, -.32435600E+04, 0.27221700E+05, -.14498800E+05, 0.65254900E+05, -.10752900E+06, 0.51972100E+05, 0.59852000E+05, 0.53762200E+05, -.15837400E+04, 0.47554300E+04, 0.17098600E+05, -.17504800E+05, 0.21908400E+05, 0.76612600E+04, -.11177600E+06, -.52129700E+03, 0.26500200E+03, 0.11180300E+03, 0.26069600E+03, 0.24233000E+02, 0.26517300E+03, -.42608300E+03, -.56521700E+03, -.15807800E+03, 0.27967800E+03, -.10890000E+05, -.30433200E+03, 0.15249300E+03, 0.83656900E+03, 0.15229200E+03, 0.14501500E+04, -.31171200E+04, 0.26472200E+04, -.76134500E+02, -.86730400E+03, -.20373000E+04, 0.76748200E+04, 0.61907400E+04, -.77005800E+04, -.47665000E+05, -.30707500E+04, -.27190600E+04, 0.12163900E+05, -.15676400E+05, -.90758100E+03, 0.13265000E+05, 0.76281000E+04, 0.11985000E+06, 0.24494000E+05, -.89299500E+04, 0.32234700E+04, -.12260800E+05, -.11447200E+05, -.28285300E+05, 0.17752200E+05, 0.21311700E+05, 0.24366100E+05, -.25962600E+05, -.67571900E+05, -.19333200E+04, 0.72508700E+03, 0.11963800E+05, 0.96492200E+03, -.46328800E+04, -.21719800E+04, 0.19193100E+03, -.36914500E+04, -.33269800E+04, -.19032200E+03, -.22472100E+05, 0.42851700E+05, -.20963000E+05, -.14455200E+05, -.21426200E+05, -.13272900E+05, -.53111600E+04, -.60573000E+04, 0.40509600E+04, -.13606100E+05, -.56459800E+04, 0.46567500E+05, 0.18862900E+05, -.96189100E+04, -.19473900E+05, -.94327400E+04, 0.11233100E+05, 0.11061700E+05, -.92636000E+04, -.39887000E+04, -.10083400E+05, 0.93136900E+04, -.43715800E+05, 0.41896500E+05, -.20586900E+05, -.20479900E+05, -.20947700E+05, 0.66040300E+04, -.51676400E+04, 0.66194500E+03, 0.16323800E+05, -.56789200E+04, -.50439400E+04, 0.43970700E+05, 0.94907500E+04, -.18425200E+04, 0.24208800E+05, -.47727300E+04, -.44617000E+04, -.25602400E+05, 0.19215000E+05, 0.11365600E+05, 0.11695300E+05, -.22455700E+05, -.90529600E+05, 0.37009300E+04, -.16506600E+04, -.80484100E+04, -.18496400E+04, -.72478200E+04, 0.18374600E+04, 0.22201900E+04, -.17223400E+04, -.88809700E+04, 0.13718700E+04, 0.64167700E+05, -.30220100E+04, 0.34472000E+04, 0.66440100E+04, 0.15106000E+04, 0.26212400E+04, -.32335500E+04, 0.63389900E+04, 0.39890800E+04, 0.32913200E+04, -.29863200E+04, 0.12174300E+06, -.53144300E+05, 0.25945100E+05, 0.29364600E+05, 0.26572900E+05, -.82521200E+04, -.26522000E+05, 0.26726900E+05, 0.15397700E+05, 0.32251400E+05, -.25215300E+05, 0.14127000E+05, -.10086300E+04, 0.81352300E+03, 0.62215200E+04, 0.50602900E+03, 0.13904600E+04, 0.26101700E+04, -.50355000E+02, -.15291900E+04, -.47958700E+04, 0.32421400E+04, 0.97702400E+04, -.19933200E+05, 0.95184800E+04, 0.84955300E+04, 0.99665400E+04, -.14211100E+05, -.23931100E+05, 0.17059300E+05, 0.18594000E+05, 0.23422000E+05, -.23708600E+05, 0.27780600E+05, -.72629200E+05, 0.34533100E+05, 0.42465800E+05, 0.36314500E+05, -.13187400E+05, 0.34452400E+04, 0.17820500E+05, -.14219100E+05, 0.39097500E+04, 0.47267600E+04, -.10257800E+06, 0.52527600E+05, -.24758000E+05, -.35929300E+05, -.26262400E+05, 0.63951200E+04, -.22298700E+04, -.36845500E+03, 0.20818400E+05, -.12535000E+05, -.50839500E+04, 0.66155900E+05, 0.11961500E+05, -.34728300E+04, -.72361500E+04, -.59911500E+04, -.82332100E+04, -.10988900E+05, 0.85528500E+04, 0.15456500E+05, 0.18233800E+05, -.10687100E+05, -.26220800E+05, 0.41013400E+05, -.18896500E+05, -.10702100E+05, -.20508600E+05, -.12996500E+03, -.61993300E+04, 0.33404100E+04, 0.47527200E+04, -.14839800E+05, -.47701500E+04, 0.75173700E+05, 0.15545700E+05, -.50497600E+04, 0.15786500E+05, -.77820500E+04, -.33263200E+04, -.11749500E+05, 0.85859200E+04, 0.56305400E+04, -.78280200E+04, -.93550300E+04, -.71313300E+05, 0.73242800E+03, -.29489700E+03, -.15777200E+04, -.23715500E+04, 0.84403700E+04, -.40915200E+04, 0.16382200E+04, -.94404300E+02, 0.17698500E+04, -.19678800E+03, 0.77421500E+04, -.64510600E+04, 0.26299100E+04, -.17313700E+05, -.52553300E+04, -.30441900E+04, -.24032900E+04, -.15735400E+04, -.78083300E+04, 0.13061000E+04, 0.33741000E+04, -.30831800E+04, 0.19258100E+04, -.66294200E+04, 0.26927400E+04, 0.11090800E+04 },
        { -.24863300E+01, 0.83905300E-01, 0.56023100E-01, -.10738500E+01, -.19118800E+00, 0.32961500E+00, 0.46998800E+00, 0.11205200E+00, -.21912500E+01, -.32473100E+00, -.65259000E-01, -.60259800E+00, 0.16884300E-02, 0.31872400E-01, -.30178200E+00, 0.17474500E+00, -.61026000E+00, -.34635100E+00, -.45901500E-01, 0.48017600E+00, -.56172400E+00, 0.78840700E-01, -.52448400E+01, -.80069100E+00, 0.17387300E+00, 0.18738400E+00, 0.30241900E+00, 0.10442000E+01, 0.24545700E+00, -.44400100E+00, 0.39563800E-01, -.10142600E+01, -.17552100E-01, 0.32193900E+04, -.15812000E+04, 0.11387500E+04, -.16103600E+04, -.12285200E+04, -.11784300E+03, -.11375300E+04, -.62697400E+03, -.65541900E+03, -.25657300E+03, 0.42828700E+02, 0.13044800E+05, -.64018800E+04, -.63144000E+04, -.65222100E+04, -.35756800E+04, 0.69497800E+03, -.31396800E+04, -.22047700E+04, -.26617900E+04, 0.91812100E+03, 0.11288500E+04, 0.28016400E+04, -.16022800E+04, -.33870400E+04, -.14021900E+04, -.16861900E+04, 0.26195600E+04, -.52334200E+04, -.49853600E+04, -.59589200E+04, 0.20295100E+04, -.19816700E+04, -.15218500E+02, 0.10194700E+02, -.75718200E+02, 0.76394900E+01, -.12368100E+03, 0.11740900E+02, -.53493700E+02, -.41465700E+02, 0.69869500E+02, 0.15654400E+02, 0.61397600E+01, 0.17798700E+04, -.87873400E+03, 0.20752000E+04, -.88985000E+03, -.92215300E+02, -.56613100E+03, 0.17159100E+03, 0.13440200E+04, -.25814000E+03, -.51550900E+03, -.54531100E+02, 0.57319500E+04, -.25629000E+04, -.53223700E+04, -.28504100E+04, 0.31801300E+04, 0.18898900E+04, -.12901600E+04, 0.12122200E+04, -.89062600E+03, 0.58672600E+03, -.44311200E+03, -.28361100E+05, 0.13865300E+05, -.23123700E+04, 0.14171400E+05, 0.36330500E+04, 0.49680600E+04, 0.18821600E+04, -.70647500E+04, 0.11500100E+04, 0.56623700E+04, 0.86124900E+04, 0.97086700E+04, -.47940200E+04, -.90945000E+03, -.48554700E+04, -.20606900E+04, -.17410700E+04, -.80929200E+03, 0.17226100E+04, -.29461400E+04, -.15264100E+04, -.52684900E+04, -.13271200E+05, 0.67206300E+04, 0.14898900E+05, 0.66353600E+04, 0.42339100E+04, -.26231400E+04, 0.53113100E+04, 0.45893000E+04, 0.50939100E+04, -.30506600E+04, 0.45534000E+04, -.35679500E+04, 0.17607100E+04, 0.14162500E+04, 0.17825500E+04, 0.57904300E+03, -.10643700E+04, 0.14800300E+04, 0.11060600E+04, 0.15891800E+04, -.64567500E+03, -.31818700E+04, -.26006100E+04, 0.12668100E+04, 0.67978100E+04, 0.13006800E+04, 0.11696000E+04, -.11299000E+04, 0.20591700E+04, 0.31048000E+01, 0.24595400E+04, -.55348200E+03, 0.20158500E+04, -.20242600E+05, 0.97412700E+04, 0.19300700E+04, 0.10103600E+05, 0.14704100E+04, 0.26693800E+04, 0.17144100E+04, -.48995700E+04, 0.80069900E+03, 0.35862600E+04, 0.56233900E+04, -.38891700E+03, 0.26003600E+03, -.43932900E+04, 0.19498600E+03, 0.16342900E+04, 0.29759200E+04, -.19406700E+04, -.23276100E+04, -.12626300E+04, 0.27293400E+04, 0.43509300E+03, -.40060400E+04, 0.20208300E+04, 0.65255600E+03, 0.20027700E+04, 0.17248900E+04, 0.22957000E+02, 0.16419100E+04, 0.28456800E+03, 0.17879700E+04, -.18816100E+03, 0.32487800E+04, 0.64891500E+04, -.32868100E+04, -.31021300E+04, -.32440500E+04, -.30726100E+04, 0.95464900E+03, -.30339600E+04, -.28880500E+04, -.32334500E+04, 0.44231300E+03, 0.20643600E+04, 0.53715000E+03, -.33059200E+03, 0.33756100E+04, -.26747800E+03, -.45926600E+03, -.70151400E+03, 0.25239900E+03, 0.42417300E+03, 0.14029400E+03, -.57293100E+03, 0.58859600E+02, 0.61839600E+04, -.30202500E+04, -.59332600E+04, -.30920200E+04, -.29927100E+04, 0.30747100E+03, -.19715300E+04, -.22837900E+04, -.20293500E+04, 0.12970000E+03, 0.21754100E+04, 0.10805100E+05, -.55143400E+04, -.66529700E+04, -.54026100E+04, -.12203900E+04, 0.15598600E+04, -.67196400E+04, -.12823900E+04, -.39492400E+04, 0.12446600E+04, -.67578500E+04, -.47686500E+03, 0.42538000E+03, -.82579100E+03, 0.23932500E+03, 0.98007600E+03, -.16582100E+04, 0.19982000E+04, 0.12604700E+04, 0.61266200E+04, -.10282600E+04, 0.14392600E+04, -.15140500E+05, 0.74975100E+04, -.38526000E+04, 0.75635200E+04, 0.19877200E+04, 0.26175400E+04, 0.79379100E+03, -.40244800E+04, 0.61169600E+03, 0.29200000E+04, 0.49879500E+04, -.78986800E+04, 0.40091300E+04, 0.13382500E+05, 0.39481200E+04, 0.40277100E+04, -.23264200E+02, 0.22249600E+04, 0.11953500E+04, 0.24582700E+04, 0.18903300E+02, 0.16425800E+04, -.67502900E+04, 0.32464900E+04, 0.50463700E+04, 0.33693800E+04, -.67022600E+03, 0.33600400E+03, 0.31759500E+03, -.19265900E+04, 0.40281200E+03, 0.92092600E+03, 0.17595800E+04, 0.24376000E+02, 0.67553600E+02, 0.80114200E+02, 0.44040700E+02, -.17578200E+02, 0.30709400E+03, 0.10188200E+04, 0.16009600E+03, -.32899400E+03, -.25293000E+04, 0.14896400E+04, 0.12043200E+04, 0.40439000E+03, 0.17694000E+04, -.21343500E+04, -.31338000E+04, 0.23074500E+03, -.61311900E+02, -.29649700E+03, -.36815100E+02, 0.18926300E+03, -.88647800E+03, 0.14248100E+04, 0.39595000E+02, 0.19224700E+04, -.22069900E+04 },
        { 0.24540100E+00, -.16916100E-01, -.21050700E-01, 0.22716800E-01, 0.67512900E-01, -.29876500E+00, 0.20452700E+00, -.23586900E+00, 0.84050800E-01, -.28784100E+00, 0.42597000E-02, 0.96133600E-01, -.30818900E-02, 0.19345700E-02, 0.88853100E-01, -.50044100E-01, -.63740400E-01, 0.76613000E-02, 0.61749900E-01, -.52402600E-01, -.15659600E+00, 0.46190800E-01, 0.91397000E-01, -.72680700E-01, 0.19952000E-01, -.18321200E-01, 0.25231300E-01, -.17402400E-01, -.12054300E+00, -.33301400E-01, -.83326400E-01, 0.15516300E+00, 0.17979700E-01, -.10234600E+00, -.39730700E+02, 0.30319200E+03, -.15404400E+00, 0.22350200E+03, -.57633700E+02, 0.38050700E+02, 0.11263700E+03, 0.75423800E+01, -.94924200E+02, 0.52140900E+01, -.65216000E+03, 0.32516100E+03, 0.76019600E+03, 0.32612300E+03, 0.50939500E+03, -.36077700E+03, 0.29291800E+03, -.16788200E+02, 0.40120200E+03, -.27550200E+03, 0.10172500E+03, -.40016000E+04, 0.18860600E+04, 0.21464600E+04, 0.20004700E+04, 0.40231100E+03, 0.43506500E+03, 0.23830000E+03, -.14669500E+04, 0.25166900E+03, 0.57571600E+03, 0.11286300E+04, -.26295200E+02, 0.13448000E+02, 0.35197300E+01, 0.13154700E+02, -.13567300E+02, -.19967800E+01, -.61002800E+01, -.55522300E+01, 0.91920600E+01, 0.40535700E+01, 0.90502300E+01, -.77603500E+02, 0.34139600E+02, 0.34237500E+03, 0.38822900E+02, 0.74060300E+02, -.22642000E+03, 0.16749900E+03, 0.22350600E+03, 0.45993000E+02, -.17231700E+03, -.68758200E+02, 0.10533300E+04, -.77128800E+03, -.52937800E+03, -.52295700E+03, 0.67125400E+03, 0.66488400E+02, 0.35662700E+02, 0.84562700E+03, -.19569100E+02, -.59584200E+02, -.29604700E+03, -.40047400E+04, 0.21550400E+04, 0.47726400E+03, 0.20001900E+04, -.15628400E+03, -.50692200E+03, 0.75113700E+03, -.10883900E+04, 0.10745400E+04, -.15258600E+03, 0.10732300E+04, -.24116100E+03, 0.12929100E+03, 0.49969000E+03, 0.12030900E+03, -.39653600E+02, 0.21039100E+02, 0.63322200E+01, -.22295300E+03, -.16985100E+03, 0.71093400E+02, -.46418100E+02, 0.50012800E+03, -.21976800E+03, 0.18220700E+03, -.25012100E+03, -.35722600E+03, -.18955300E+03, -.12942300E+02, 0.15818000E+03, -.13073200E+03, -.22845000E+03, -.18947700E+02, -.19519300E+03, 0.81228800E+02, -.19380200E+03, 0.97350500E+02, -.10737900E+03, 0.30589600E+03, -.77466500E+02, -.95912700E+02, -.21945500E+02, 0.26753000E+03, 0.26206200E+03, 0.17880100E+04, -.87306500E+03, -.52985400E+03, -.89391400E+03, -.24392100E+03, -.22010100E+03, -.31372500E+02, 0.56858300E+03, 0.40776100E+02, -.26459800E+03, -.40840900E+03, -.34045100E+04, 0.18160800E+04, 0.84318500E+03, 0.16980400E+04, -.25648200E+03, -.46518100E+03, 0.61526100E+03, -.10286200E+04, 0.84103300E+03, -.17593900E+03, 0.96271700E+03, 0.30461000E+02, 0.27512500E+01, -.47691300E+03, -.15105300E+02, -.87248600E+01, -.25265800E+03, 0.22481900E+03, -.61990400E+02, -.23524600E+03, -.18190900E+03, -.20289600E+03, 0.10619100E+03, 0.73938800E+02, -.39639500E+02, -.53153600E+02, 0.14765500E+03, 0.35507900E+02, 0.39097200E+02, -.75308000E+02, 0.62146100E+02, -.99597200E+02, 0.15921100E+03, -.86731400E+03, 0.38686900E+03, 0.43693500E+03, 0.43378200E+03, 0.30756100E+03, -.49701100E+03, 0.40513900E+03, 0.20024800E+03, 0.73875300E+03, -.51255300E+03, -.80098200E+02, 0.49874700E+03, -.23106200E+03, 0.15125000E+03, -.24911400E+03, -.52012200E+01, 0.16737300E+03, -.13323700E+03, 0.47207100E+02, -.20251900E+03, 0.10654400E+03, -.13786400E+03, -.51492200E+03, 0.22118900E+03, 0.44246300E+02, 0.25745200E+03, 0.38879700E+03, -.37001500E+03, 0.28651500E+03, 0.20192500E+03, 0.62245000E+03, -.39550000E+03, -.12227100E+03, -.29823100E+04, 0.13787000E+04, 0.16339000E+04, 0.14911400E+04, 0.22639100E+03, 0.40363300E+03, 0.13943700E+03, -.12362100E+04, -.28474900E+03, 0.50149700E+03, 0.85883700E+03, 0.28074800E+04, -.13105600E+04, -.18383200E+04, -.14035200E+04, -.35042200E+03, -.26793700E+03, -.15033900E+03, 0.95644100E+03, -.72259100E+02, -.40230000E+03, -.64553000E+03, -.17206100E+04, 0.10084600E+04, -.13348900E+03, 0.85871000E+03, -.10448800E+03, -.10481200E+03, 0.23465400E+03, -.61215000E+03, 0.38965300E+03, 0.74934500E+02, 0.39988900E+03, 0.52624400E+03, -.16534000E+03, 0.61337100E+03, -.26341500E+03, -.31151300E+02, 0.25290900E+02, 0.18085400E+03, 0.13283300E+03, -.55490400E+02, -.62228700E+02, 0.32540200E+02, -.57956200E+03, 0.44414600E+03, 0.21494800E+03, 0.28841200E+03, -.41237900E+03, -.10202500E+03, 0.38353200E+02, -.39300600E+03, 0.11889200E+03, -.51406200E+02, 0.21464900E+03, 0.94201900E+01, 0.42932600E+02, -.28388700E+02, -.59313200E+01, -.35589300E+02, -.48514100E+02, 0.17909200E+01, 0.72033300E+01, 0.10317300E+02, -.73588600E+03, 0.83527100E+03, 0.13688300E+03, 0.98942100E+01, -.40235100E+03, -.78588300E+02, -.89031800E+03, -.47334400E+02, -.32111000E+02, -.59842200E+02, 0.38943000E+03, 0.25734700E+02, -.98777300E+02, 0.38714200E+02, -.56706900E+03, -.62174800E+02, -.70062800E+03 },
        { -.56611800E+01, -.28739600E-01, 0.62417800E+00, -.96928500E+00, 0.27361300E+00, -.34387800E+00, 0.36334000E+00, 0.31871300E+00, -.55477500E+00, -.44041200E+00, 0.85704000E-01, -.13024700E+01, -.52897600E-01, -.11598000E+00, 0.45534400E-01, 0.92006700E-01, -.86833300E+00, 0.22679900E+00, -.74696200E+00, -.21573400E+00, -.92958900E+00, 0.51789500E-01, -.98752900E-01, 0.22865000E+00, 0.35937000E+00, 0.23227100E+00, 0.28694900E+00, -.57478400E+00, -.54657400E+00, 0.32204300E+00, -.63777400E+00, -.20413200E+01, 0.18922400E-01, -.57553900E+00, -.33307700E+01, 0.55343000E+04, -.12174400E+01, -.28850100E+04, -.87452100E+03, -.26052100E+03, -.91969200E+03, 0.15855500E+04, -.10925300E+04, 0.25005000E+04, 0.63314300E+04, -.30052300E+04, -.37236400E+03, -.31653800E+04, -.62900700E+04, 0.45462200E+03, 0.28783900E+03, 0.12040800E+04, 0.32598600E+04, 0.54077200E+03, 0.83964500E+04, -.31823500E+05, 0.15440900E+05, 0.92341700E+04, 0.15909100E+05, 0.42896200E+04, 0.10453400E+05, -.40325600E+04, -.12837500E+05, -.91491500E+03, 0.10103800E+05, 0.41357900E+04, -.10369300E+03, 0.56859400E+02, -.28319900E+03, 0.51902600E+02, -.11012300E+03, 0.69987800E+02, -.90300300E+02, -.65468500E+02, 0.14400600E+03, 0.75586600E+02, 0.41855100E+02, -.48919900E+03, 0.26967900E+03, 0.42188500E+04, 0.24476600E+03, -.70987400E+03, -.20916800E+04, 0.21668700E+04, 0.31435600E+04, 0.18043900E+04, -.18493900E+04, 0.12598800E+04, 0.39541400E+05, -.19445500E+05, -.98431200E+04, -.19741600E+05, 0.13838200E+04, -.47628200E+04, -.35434500E+04, 0.77615700E+04, -.11756300E+05, -.53038900E+04, -.14627300E+05, -.79824400E+05, 0.39540400E+05, 0.48921600E+04, 0.39895000E+05, 0.10175700E+05, 0.12640800E+05, 0.59580700E+04, -.17426200E+05, 0.11450400E+05, 0.13489300E+05, 0.25964900E+05, -.17195000E+04, 0.96657300E+03, 0.39604600E+04, 0.85761500E+03, -.12655600E+03, 0.48361800E+03, -.37467500E+03, -.12697700E+04, -.62509500E+03, 0.76113000E+03, -.31061000E+04, -.21468800E+05, 0.10862100E+05, 0.65175100E+04, 0.10734000E+05, 0.32388200E+04, -.48223100E+04, 0.66259100E+04, 0.16750700E+04, 0.78424400E+04, -.49698800E+04, 0.12474300E+05, 0.43295600E+04, -.21659300E+04, 0.11033800E+04, -.21674300E+04, 0.16913500E+04, -.92362000E+03, -.70303000E+03, 0.66795600E+02, -.27589100E+04, -.44097400E+03, -.10436200E+05, 0.12618700E+05, -.63115100E+04, 0.44145600E+04, -.63086400E+04, -.29139600E+04, -.48278100E+04, 0.19719800E+04, 0.34277900E+04, 0.11797000E+04, -.45662400E+04, -.16517100E+03, -.67394800E+05, 0.33190000E+05, 0.95729300E+04, 0.33664200E+05, 0.62373600E+04, 0.89892400E+04, 0.59189900E+04, -.13701100E+05, 0.12168400E+05, 0.98758900E+04, 0.22894700E+05, 0.14142300E+03, 0.26140600E+02, -.66134800E+04, -.69726000E+02, 0.30341900E+04, 0.28410800E+04, -.16680500E+04, -.25498800E+04, -.22960500E+04, 0.29132900E+04, -.11241200E+04, -.66549000E+04, 0.34238200E+04, 0.73232000E+04, 0.33269900E+04, 0.74811300E+03, -.16670400E+03, 0.22274900E+04, -.44075400E+03, 0.25364700E+04, -.81508700E+03, 0.60016900E+04, -.23640300E+04, 0.10761600E+04, 0.53214500E+04, 0.11829900E+04, -.58109300E+04, 0.10703900E+03, -.27961600E+03, -.30594900E+03, 0.15378800E+04, -.22954600E+03, 0.86375300E+04, 0.24552500E+04, -.13369900E+04, 0.43585700E+04, -.12255800E+04, -.11727100E+04, -.47061400E+03, 0.17421100E+03, 0.90040300E+03, -.51511700E+02, -.46974400E+03, -.48315700E+03, 0.17713300E+04, -.79519400E+03, 0.94351000E+03, -.88573500E+03, -.55306200E+04, -.20362100E+03, 0.88650300E+02, 0.10096000E+04, 0.16202000E+04, -.40657400E+03, 0.83813900E+04, -.13023300E+05, 0.61811000E+04, 0.94861700E+03, 0.65115000E+04, 0.45837300E+04, 0.78184500E+04, -.62141200E+04, -.67426900E+04, 0.49869000E+03, 0.78948200E+04, -.54817100E+04, 0.31269700E+05, -.15214300E+05, -.13035400E+05, -.15633100E+05, -.45526800E+04, -.81847400E+04, 0.90145000E+03, 0.90594400E+04, 0.28377800E+04, -.78658000E+04, -.52353200E+04, -.36525500E+05, 0.18258800E+05, -.22173200E+04, 0.18250200E+05, 0.56884400E+04, 0.76879300E+04, 0.12557500E+04, -.95845300E+04, 0.36654900E+04, 0.79765800E+04, 0.11658600E+05, -.80682600E+04, 0.42138100E+04, 0.18989200E+05, 0.40318300E+04, 0.25101900E+04, -.15266500E+04, 0.31057300E+04, -.10330600E+04, 0.90089500E+03, -.15560100E+04, 0.19887700E+04, -.26685000E+05, 0.13229300E+05, 0.81442900E+04, 0.13331800E+05, 0.38661100E+03, 0.37909900E+04, 0.20325900E+04, -.55853800E+04, 0.59377200E+04, 0.39124900E+04, 0.10370600E+05, 0.11001300E+01, -.28291300E+02, -.34415100E+03, 0.77088700E+02, 0.83183100E+03, 0.43819200E+03, 0.19413000E+04, 0.14313600E+03, -.27468700E+03, -.58953100E+04, 0.11741100E+04, 0.27280500E+04, 0.43084600E+03, 0.20479900E+04, -.24637200E+04, -.53937800E+04, -.12830700E+02, -.47461700E+03, -.13110400E+04, 0.32452600E+04, 0.31455100E+03, -.15757400E+04, 0.24480200E+04, 0.21225800E+04, 0.26536100E+04, -.55648700E+04 },
        { 0.14780800E+02, -.33960400E+00, -.58927200E+00, 0.28438300E+01, 0.15243500E+01, -.28523600E+01, 0.92598200E+00, -.64380400E+00, -.11339500E-02, -.24095000E+01, 0.11902600E+00, 0.19663000E+01, -.20252700E+00, 0.17118400E-01, 0.98006700E+00, -.66029100E+00, 0.55252800E+00, 0.21362800E+00, 0.50840600E+00, -.11497300E+01, -.34944700E+00, 0.88375100E-01, 0.21900900E+01, 0.39355600E+00, -.29758100E+00, 0.41500500E+00, -.10443900E+01, 0.37797100E+00, -.53097800E+00, 0.68910200E+00, -.19238100E+00, -.21115100E+00, 0.97891700E-01, 0.92420400E-01, 0.41884300E-01, 0.14753700E+00, 0.34865000E+01, -.14106400E+04, 0.14745100E+03, -.40795100E+03, -.91360800E+03, -.40835100E+03, 0.37138900E+03, 0.84782300E+03, 0.12477800E+05, -.62618400E+04, -.15005500E+04, -.62391200E+04, -.42038900E+04, 0.28515000E+04, -.47638100E+04, -.31416000E+04, -.51838400E+04, 0.29688900E+04, -.76587000E+03, 0.23804800E+05, -.11875000E+05, -.69681500E+04, -.11900900E+05, -.44739500E+04, -.32512900E+04, -.27458500E+04, 0.42256000E+04, -.61252900E+04, -.40340200E+04, -.60647100E+04, 0.20107000E+01, -.12400900E+01, 0.55034400E+02, -.10347000E+01, -.31239300E+01, -.33831200E+02, 0.36854000E+02, 0.50599500E+02, 0.40960500E+02, -.39269800E+02, 0.12133200E+02, 0.22440600E+04, -.11242900E+04, -.76031300E+03, -.11221300E+04, -.73558800E+03, 0.63816600E+03, -.10879300E+04, -.73504100E+03, -.12048900E+04, 0.62127300E+03, -.12901100E+03, 0.83392500E+04, -.39974100E+04, -.67070800E+04, -.41854100E+04, -.25620400E+04, -.49910700E+03, -.19104900E+04, -.31212400E+04, -.52854800E+04, -.16750800E+03, -.48000900E+04, -.10395200E+04, 0.37940500E+03, 0.30412000E+04, 0.52919300E+03, 0.20870800E+04, 0.32295000E+04, -.88500800E+03, 0.24018900E+04, 0.13251900E+04, 0.18117400E+04, 0.33147200E+04, 0.61250800E+04, -.30649200E+04, -.18965900E+04, -.30613600E+04, -.13312000E+04, -.12959200E+04, -.30450200E+03, 0.17373300E+04, -.87521400E+03, -.14791900E+04, -.17811600E+04, -.13549800E+05, 0.67480200E+04, 0.10602200E+05, 0.67751200E+04, 0.26139600E+04, -.26232000E+04, 0.46405300E+04, 0.24539600E+04, 0.50072400E+04, -.21182900E+04, 0.29680900E+04, -.46151000E+04, 0.23340900E+04, -.27198200E+04, 0.23119700E+04, 0.13667300E+04, -.15943500E+04, 0.20456200E+04, 0.16927700E+04, 0.26957900E+04, -.15303200E+04, -.79982500E+03, -.98353400E+04, 0.49225500E+04, 0.22492100E+04, 0.49172800E+04, 0.19590000E+04, 0.10606800E+04, 0.84433600E+03, -.20449100E+04, 0.24022900E+04, 0.14530400E+04, 0.24662000E+04, -.31455800E+04, 0.14520100E+04, 0.28832000E+04, 0.15907700E+04, 0.22019300E+04, 0.30781700E+04, -.41180100E+03, 0.25820200E+04, 0.26826800E+04, 0.19168100E+04, 0.41882600E+04, 0.38325600E+04, -.19228600E+04, -.10723000E+04, -.19168100E+04, 0.21073500E+03, 0.29092800E+04, -.26235600E+04, -.17435400E+04, -.19721500E+04, 0.23235100E+04, -.14933700E+03, 0.92813100E+03, -.52769000E+03, -.15167800E+03, -.46383600E+03, -.35144500E+03, 0.17848100E+03, -.10870500E+03, -.35833700E+03, -.63977100E+03, 0.64087700E+03, -.91329900E+03, 0.54480300E+04, -.27271900E+04, -.23907300E+04, -.27245600E+04, -.32819400E+04, 0.17742000E+04, -.25804400E+04, -.30184700E+04, -.35738600E+04, 0.18579400E+04, 0.21264800E+04, -.10893100E+04, 0.53400100E+03, 0.22176600E+03, 0.54356100E+03, -.58520000E+02, -.22568300E+03, 0.23332100E+03, -.27414800E+03, 0.25180500E+03, -.13097100E+02, 0.21350200E+03, 0.40963800E+04, -.20523400E+04, -.24491700E+04, -.20481700E+04, -.28906900E+04, 0.12618400E+04, -.19476500E+04, -.28101300E+04, -.26504600E+04, 0.15831700E+04, 0.17079000E+04, 0.15484600E+05, -.77156100E+04, -.41041300E+04, -.77422000E+04, -.27975000E+04, -.23356900E+04, -.20908200E+04, 0.31585100E+04, -.29487800E+04, -.29256000E+04, -.45498100E+04, -.21185400E+05, 0.10564900E+05, 0.56364900E+04, 0.10591700E+05, 0.44122400E+04, 0.28348900E+04, 0.17556600E+04, -.47504500E+04, 0.57885200E+04, 0.36693600E+04, 0.54471900E+04, -.13603300E+04, 0.58151200E+03, 0.25260200E+04, 0.68694100E+03, 0.12143200E+04, 0.90465000E+03, 0.21882300E+03, 0.18103100E+04, 0.12067800E+04, 0.14865900E+03, 0.18416000E+04, -.16875300E+04, 0.79807600E+03, -.10507100E+04, 0.84504600E+03, 0.53086200E+03, -.71058900E+03, 0.46065000E+03, 0.97514900E+03, 0.93733200E+03, -.33542700E+03, -.10989400E+04, -.45255800E+04, 0.21638800E+04, 0.40790100E+04, 0.22685600E+04, 0.14772100E+04, 0.33597200E+03, 0.85850800E+03, 0.11144800E+04, 0.21504700E+04, 0.34371800E+03, 0.20550500E+04, 0.24673000E+01, -.91939900E+01, 0.25257900E+03, 0.42221000E+02, 0.13842700E+03, 0.68411500E+03, -.13958500E+03, 0.23418600E+02, -.26680800E+03, 0.14452100E+04, -.30501700E+04, -.81348000E+03, 0.13463100E+03, 0.31642700E+04, -.46369500E+03, 0.26338700E+04, 0.41513800E+03, 0.22048300E+03, -.37852800E+02, 0.40051000E+02, 0.44974100E+02, 0.64779900E+02, -.15593600E+03, 0.20062700E+04, 0.31726200E+03, 0.12770300E+04 },
        { 0.38046100E+01, -.38455500E-01, -.96036500E-01, 0.57094400E-01, 0.42024900E+00, 0.17637900E+00, 0.13529300E-01, -.16517700E+00, -.25088700E+00, -.48029100E+00, -.23845100E-01, -.26952800E+00, 0.11435400E-01, -.62777000E-02, 0.31947100E-01, -.13275200E-01, 0.22848600E+00, -.16210900E+00, 0.20346900E+00, 0.10967800E-01, 0.80616900E-01, 0.10216300E+00, 0.96305500E+00, 0.49398200E-01, 0.12278200E+00, -.63603900E-02, 0.75668500E-01, -.79904700E-01, -.68277300E-01, 0.36074000E+00, 0.90248200E-01, -.59227800E+00, -.50042600E-02, 0.26760100E+00, 0.41829100E+00, -.79478800E-01, 0.46426900E-01, -.17625800E+04, 0.43188600E+02, -.15032900E+03, -.70140300E+03, 0.29689200E+03, 0.57893000E+02, 0.70979400E+03, 0.86032000E+03, -.44463100E+03, 0.12866300E+03, -.43019100E+03, -.41118900E+04, 0.22225200E+04, -.61200700E+03, -.89322100E+03, 0.44975900E+03, 0.18805800E+04, 0.25526000E+04, 0.39408600E+04, -.19605000E+04, -.27556100E+04, -.19701600E+04, 0.46630000E+02, 0.10259500E+04, -.17796400E+04, 0.11296400E+04, -.99110500E+03, 0.84134800E+03, -.17531600E+04, -.85999900E+01, 0.42655900E+01, -.40239700E+02, 0.42939500E+01, 0.30045300E+02, -.12078200E+02, 0.31536400E+02, 0.24184800E+02, 0.27783600E+02, -.20517800E+02, 0.41480100E+01, 0.92890300E+03, -.46144300E+03, -.89593300E+03, -.46446700E+03, -.64071000E+03, 0.28134400E+03, -.26711600E+03, -.12839500E+03, -.16171000E+03, 0.19116100E+03, -.97056000E+01, 0.24062100E+05, -.11902600E+05, -.85300800E+04, -.12034200E+05, -.30405500E+04, -.55004400E+03, -.53942100E+04, -.45376900E+03, -.87641500E+04, -.18953600E+03, -.10043700E+05, -.21152700E+05, 0.10470400E+05, 0.80367000E+04, 0.10578100E+05, 0.36005700E+04, 0.27310700E+04, 0.35740300E+04, 0.10037900E+03, 0.57327000E+04, 0.21595400E+04, 0.85930500E+04, -.80881500E+03, 0.40733700E+03, -.32214100E+03, 0.40462800E+03, 0.30718200E+03, 0.22330900E+03, -.85061700E+02, 0.19218400E+03, 0.79150900E+03, 0.15393800E+03, 0.16165900E+03, -.15274200E+05, 0.76167600E+04, 0.45785700E+04, 0.76371600E+04, 0.11961700E+04, -.35598500E+04, 0.48312700E+04, 0.90853900E+03, 0.59193800E+04, -.34061300E+04, 0.57158500E+04, 0.49443500E+04, -.24516700E+04, -.17510700E+04, -.24721900E+04, 0.15043900E+04, -.72061100E+03, -.81653600E+03, 0.96482000E+03, -.18487100E+04, -.52877300E+03, -.37892500E+04, -.30703900E+04, 0.15391800E+04, 0.15763000E+04, 0.15351200E+04, -.50181800E+03, -.46873800E+03, 0.77964300E+03, -.14655100E+04, 0.31028200E+03, -.39990000E+03, 0.16648600E+04, -.21888700E+05, 0.10855000E+05, 0.75964700E+04, 0.10947800E+05, 0.32632900E+04, 0.21635800E+04, 0.40986000E+04, 0.21938900E+03, 0.67246600E+04, 0.16644800E+04, 0.90759000E+04, 0.34813800E+04, -.17424800E+04, -.10256100E+04, -.17407900E+04, 0.55877100E+03, 0.21147100E+04, -.19738800E+04, -.58525000E+03, -.13327500E+04, 0.19131500E+04, -.95142800E+03, -.47883600E+03, 0.19859800E+03, 0.16143300E+04, 0.23946900E+03, -.75634900E+03, 0.80495600E+03, -.46509100E+03, -.99927900E+03, -.43211100E+03, 0.87153200E+03, 0.49589700E+03, 0.10127200E+04, -.50879100E+03, 0.15812100E+03, -.50646200E+03, -.29574400E+04, 0.17993600E+04, -.12741600E+04, -.16491000E+04, -.15873800E+04, 0.18218500E+04, 0.21137700E+04, -.11913700E+04, 0.58525100E+03, 0.34138800E+03, 0.59546800E+03, -.43133200E+03, -.27242200E+03, 0.29379300E+03, -.22264500E+03, 0.48696300E+03, -.14657800E+03, 0.55211300E+03, 0.25852700E+03, -.13020500E+03, 0.10289100E+04, -.12925400E+03, -.28454000E+04, 0.12737700E+04, -.65045700E+03, -.11367300E+04, -.81845200E+03, 0.12938300E+04, 0.22828900E+04, 0.51622000E+04, -.25704600E+04, -.33443700E+04, -.25810900E+04, 0.72682700E+03, 0.28636800E+03, -.18475200E+04, 0.23133000E+04, 0.11232000E+04, 0.28150200E+03, -.30947900E+04, -.13087800E+04, 0.64062600E+03, 0.15408200E+04, 0.65421800E+03, -.11503500E+03, -.99546000E+03, 0.81067500E+03, -.92437900E+03, 0.10216200E+04, -.72192700E+03, 0.74358100E+03, -.10381500E+05, 0.51198800E+04, 0.46652300E+04, 0.51920500E+04, 0.20444800E+04, 0.11896300E+04, 0.17891100E+04, 0.25264900E+03, 0.27274000E+04, 0.84245400E+03, 0.43839800E+04, -.30596300E+04, 0.15023200E+04, 0.94746700E+03, 0.15300500E+04, -.13112600E+03, -.36587400E+03, 0.18736800E+03, -.87954200E+03, 0.15301000E+03, -.23907100E+03, 0.77604000E+03, -.12990500E+05, 0.64208200E+04, 0.47257700E+04, 0.64964200E+04, 0.17864300E+04, 0.48620200E+03, 0.27532000E+04, -.15227600E+01, 0.41894300E+04, 0.33352200E+03, 0.51201500E+04, -.51711500E+02, -.69862100E+02, 0.80268600E+01, 0.35008600E+02, 0.38267100E+03, 0.42298200E+03, 0.28577400E+03, -.71964500E+01, -.10180100E+03, 0.56407300E+03, -.33316000E+04, 0.18741400E+03, 0.26642100E+03, 0.19206700E+04, 0.16035600E+03, 0.23225500E+04, 0.19056700E+03, 0.18491200E+03, -.13215100E+03, 0.16083700E+04, 0.43932200E+02, 0.99028900E+02, 0.32452600E+03, 0.24224200E+04, 0.23509900E+03, 0.61478500E+03 },
        { -.69838700E+01, 0.19334100E+00, 0.25901600E+00, 0.17459200E+01, -.50305400E+00, 0.14842000E+01, 0.71875400E+00, 0.18486800E+00, -.97246000E+00, 0.12590800E+01, 0.56103400E+00, -.56384100E+00, -.13128400E+00, 0.77856300E-01, 0.25757200E+00, 0.12011900E-01, 0.45924400E+00, 0.41497400E+00, -.23625000E+00, 0.73151400E+00, 0.99964800E+00, -.39987000E+00, 0.94001000E+01, 0.13718200E+01, 0.29418800E+00, 0.32751700E-01, -.34419500E+00, 0.11674600E+01, 0.22168800E+01, -.23231900E+01, -.26337400E+00, -.23564700E+01, -.34054900E+00, 0.18185400E+01, 0.37870800E+00, -.75322400E+00, 0.22931700E-01, -.36180400E+01, 0.23452100E+04, -.61513800E+03, 0.81551800E+03, -.34301400E+02, 0.28519200E+04, -.32963400E+04, -.72065700E+04, 0.35032400E+04, 0.12654300E+05, 0.36031700E+04, 0.83673200E+03, 0.43454500E+04, 0.23011300E+04, 0.65064300E+04, 0.49307700E+04, 0.43583500E+04, -.15058400E+05, -.19720400E+05, 0.10101700E+05, 0.12155200E+05, 0.98612400E+04, 0.58251600E+04, 0.25097600E+04, 0.83044700E+04, -.74838400E+03, 0.42735200E+04, 0.43079300E+04, 0.87091200E+04, -.83494000E+02, 0.40876400E+02, 0.21127000E+01, 0.41722400E+02, 0.25075400E+03, 0.67115700E+02, 0.18827900E+02, 0.66540600E+02, 0.46279400E+01, 0.75705000E+02, 0.25589300E+02, 0.91114500E+03, -.41609700E+03, -.20796300E+04, -.45563200E+03, -.18668000E+03, 0.14112000E+04, -.55640800E+03, 0.18441800E+03, 0.24725400E+03, 0.10925400E+04, -.27565400E+04, 0.13380000E+05, -.68043700E+04, 0.62880600E+04, -.67024300E+04, -.45108800E+04, -.42833500E+04, 0.91847600E+03, 0.34570100E+04, -.79497700E+04, -.33401900E+04, -.48240600E+04, -.88848100E+04, 0.46936400E+04, 0.73545300E+04, 0.44494500E+04, 0.14909500E+04, 0.10263500E+04, 0.17830000E+04, -.63856600E+03, 0.68604100E+04, 0.63319200E+03, 0.63755800E+04, -.18697700E+05, 0.93618400E+04, 0.44425900E+04, 0.93497100E+04, 0.36630700E+04, 0.33719900E+04, 0.21065900E+04, -.44956200E+04, 0.38368200E+04, 0.33908800E+04, 0.87239500E+04, -.16172700E+05, 0.79644700E+04, -.15914100E+05, 0.80865400E+04, -.79959300E+03, -.60049200E+04, 0.31663500E+04, -.40879400E+04, 0.62612200E+04, -.51741200E+04, 0.44412900E+04, 0.19000500E+05, -.94327600E+04, -.89481600E+04, -.95006600E+04, -.14355400E+04, 0.15302800E+04, -.58155800E+04, -.27245800E+04, -.89030000E+04, 0.44226000E+03, 0.76231300E+04, 0.15887400E+05, -.79244200E+04, -.12698300E+05, -.79439700E+04, -.53375900E+04, -.12960800E+04, -.50557400E+04, 0.27930100E+04, -.17672700E+04, -.29781800E+04, -.55116200E+04, -.10546300E+05, 0.56235100E+04, 0.77521600E+02, 0.52871000E+04, 0.19602700E+04, 0.19547600E+04, 0.11108000E+04, -.77840100E+03, 0.85391700E+04, 0.13603700E+04, 0.58778400E+04, 0.43622300E+04, -.22516400E+04, 0.33621600E+04, -.21815400E+04, -.43923200E+03, -.18285000E+04, 0.20014400E+04, 0.12579900E+04, -.14833500E+04, -.13854800E+04, -.30777200E+04, 0.65510000E+04, -.34391100E+04, 0.38255400E+04, -.32752900E+04, -.48526900E+04, -.49273800E+03, -.13001600E+04, -.97836400E+02, -.23599500E+04, -.83486100E+03, -.44806200E+04, -.10387800E+05, 0.53129600E+04, 0.10089900E+05, 0.51934900E+04, 0.40115900E+03, 0.70501800E+03, 0.31034900E+04, 0.29556300E+04, 0.48850900E+04, 0.25355400E+04, -.59156200E+04, -.11119600E+04, 0.56303700E+03, -.38998600E+04, 0.55510200E+03, -.22595200E+03, 0.18994700E+03, -.12807100E+03, -.95070000E+03, 0.29062700E+03, 0.11111400E+03, 0.10987400E+03, -.69887400E+04, 0.35040200E+04, 0.14178500E+05, 0.34944100E+04, 0.16676100E+03, 0.61192800E+02, 0.22880200E+04, 0.36883500E+04, 0.36688000E+04, 0.11092500E+04, -.87476800E+04, -.27642200E+05, 0.13980900E+05, 0.14865000E+05, 0.13821100E+05, 0.69716200E+04, 0.24453900E+04, 0.10086700E+05, -.43230600E+04, 0.38616300E+04, 0.40128700E+04, 0.11333000E+05, 0.19106000E+05, -.97918900E+04, -.79889700E+04, -.95536900E+04, -.51526200E+04, -.22608100E+04, -.60355600E+04, 0.31260100E+04, -.38342600E+04, -.39652100E+04, -.84607500E+04, -.45839000E+03, 0.20761600E+03, 0.68519500E+04, 0.23450600E+03, 0.69667800E+03, -.26179200E+03, 0.56685800E+03, 0.62469100E+00, 0.17290900E+04, -.48308400E+03, 0.19198700E+04, 0.97993800E+04, -.50530500E+04, -.16411200E+05, -.48987500E+04, -.66440400E+04, -.17176700E+04, -.26120300E+04, -.37226800E+04, -.45860800E+04, -.25850100E+04, 0.30552800E+04, -.40294100E+04, 0.19872600E+04, -.50952500E+04, 0.20193600E+04, 0.14595700E+04, 0.10236800E+04, 0.13098700E+03, -.10503600E+04, 0.33307900E+04, 0.73786000E+03, 0.12427700E+04, 0.14672400E+03, 0.77601500E+02, -.35227000E+03, -.51296500E+02, -.29019000E+03, 0.14057900E+04, 0.30410400E+03, -.26884100E+03, 0.33555300E+03, 0.25198800E+04, -.36995000E+04, 0.59085600E+03, 0.25864600E+03, 0.17860800E+04, 0.24056000E+04, 0.37551300E+04, -.19230700E+03, 0.15548200E+03, -.61135900E+03, 0.22586900E+04, 0.24885200E+03, 0.16366900E+03, -.36900300E+03, 0.27177800E+04, -.14264400E+04, 0.18275900E+04 },
        { -.53583500E+01, 0.17778300E+00, 0.19580300E+00, -.53092900E-01, -.26728800E+00, 0.10691300E+01, -.12019100E+01, -.50104800E-01, -.14440000E+00, 0.64856900E+00, -.58352000E-01, 0.79452300E+00, 0.12439000E+00, -.28860500E-01, -.10768200E+00, -.63427000E-01, 0.55600300E+00, -.66139900E+00, 0.16047400E+00, -.29873000E-01, 0.29648500E+00, 0.22723000E+00, -.15413700E+01, -.73994500E+00, -.11988400E+00, -.18396500E+00, 0.82153000E-01, -.19119100E+00, -.48731100E+00, -.18875000E+01, -.55040800E+00, -.46103600E+00, 0.64135000E-01, -.35262900E+00, 0.18377700E+01, 0.12450400E+00, -.13227400E+00, -.10513500E+01, -.45692800E+00, 0.76682000E+03, 0.15183500E+04, 0.21247600E+04, -.17641400E+03, -.10242700E+03, -.13377400E+05, 0.65475100E+04, 0.68616800E+04, 0.66887200E+04, -.51420400E+03, -.63383200E+03, 0.57621000E+04, 0.46747100E+04, 0.85753900E+04, -.51886500E+03, 0.28771100E+04, -.89311400E+04, 0.50170300E+04, 0.40479900E+04, 0.44655800E+04, 0.85536100E+04, 0.27225200E+04, 0.13535100E+04, 0.33459800E+04, 0.15337200E+04, 0.43793700E+04, -.27729300E+04, 0.66985200E+02, -.37807000E+02, -.24719200E+02, -.33493100E+02, 0.14862500E+03, -.83467500E+02, 0.11018700E+03, 0.10680100E+03, 0.16224900E+02, -.78871000E+02, -.80945000E+02, 0.38569000E+03, -.27427600E+03, -.88714900E+03, -.19284500E+03, -.13773900E+03, 0.10866100E+04, 0.15892500E+02, -.48600700E+03, 0.76042400E+03, 0.77156400E+03, -.15641400E+04, 0.42501200E+05, -.19689800E+05, -.55578400E+04, -.21250800E+05, -.61675300E+03, 0.63483300E+04, -.12814300E+05, -.13909200E+04, -.14495100E+05, 0.51103600E+04, -.12945600E+05, -.51248500E+05, 0.24238600E+05, 0.15772800E+05, 0.25624300E+05, 0.44092600E+04, -.29107700E+04, 0.11857500E+05, -.58503000E+03, 0.13946700E+05, -.91318600E+03, 0.13361100E+05, -.16079300E+04, 0.89235200E+03, -.82261500E+03, 0.80397500E+03, 0.17098300E+04, 0.82122300E+03, -.18867600E+03, 0.42620000E+03, 0.86217000E+03, 0.12198500E+04, -.20026100E+03, -.17594800E+04, 0.71495600E+03, -.11822900E+05, 0.87974300E+03, -.20598000E+03, -.24624900E+04, 0.90485100E+03, 0.23249500E+03, 0.17836900E+04, -.29076300E+04, 0.16515700E+04, 0.10347000E+05, -.51214100E+04, -.22153800E+04, -.51744000E+04, 0.18842100E+03, 0.23586000E+04, -.52019900E+04, -.37839100E+04, -.70899900E+04, 0.18820200E+04, -.47080800E+03, 0.33935100E+04, -.17498300E+04, -.37636500E+04, -.16967600E+04, -.45742500E+04, 0.21873000E+03, -.99076600E+03, -.12260100E+04, -.21858500E+04, -.11634100E+04, 0.21978300E+04, -.50274600E+05, 0.23853000E+05, 0.11939300E+05, 0.25137500E+05, 0.31915500E+04, -.35552200E+04, 0.12311200E+05, -.70114300E+03, 0.14848000E+05, -.18820100E+04, 0.13640600E+05, -.50270300E+02, -.39744000E+02, 0.26346200E+04, 0.25128200E+02, -.43217000E+03, 0.68639700E+03, -.10849900E+04, -.32352000E+03, 0.54403000E+03, 0.14774000E+04, -.89506900E+03, -.12196200E+04, 0.14960400E+03, 0.78344400E+03, 0.60981500E+03, -.33791400E+04, 0.10597000E+04, -.12173900E+04, -.14831100E+04, -.78903700E+03, 0.89620400E+03, 0.24545900E+04, -.85241800E+04, 0.43247400E+04, 0.55886400E+04, 0.42620900E+04, 0.24192500E+04, -.36034100E+03, 0.37512500E+04, 0.51793000E+04, 0.34528500E+04, 0.32202800E+03, -.86773800E+03, -.27886600E+04, 0.13688900E+04, -.20388100E+04, 0.13943200E+04, -.92373600E+03, -.47513100E+03, 0.43635900E+03, -.71847200E+03, 0.12692600E+04, -.41503300E+03, 0.21161400E+04, -.69022700E+04, 0.34038100E+04, 0.86763600E+04, 0.34511400E+04, 0.19822200E+04, -.43706500E+03, 0.30687200E+04, 0.46769300E+04, 0.30933300E+04, -.22177600E+03, -.76360700E+03, -.61538700E+03, 0.81863900E+03, 0.19572100E+03, 0.30769100E+03, 0.76977700E+04, 0.12025800E+04, 0.82653000E+03, 0.56255300E+04, 0.45677300E+04, 0.30463500E+04, -.52090100E+04, 0.72575300E+04, -.41153900E+04, -.18528600E+04, -.36287700E+04, -.67467300E+04, -.13177300E+04, -.69890800E+03, -.33504300E+02, -.49869600E+03, -.29886800E+04, 0.19824700E+04, -.23276400E+05, 0.10795000E+05, 0.93680500E+04, 0.11638300E+05, 0.21583300E+04, -.27610300E+04, 0.62013000E+04, 0.90504700E+03, 0.61083200E+04, -.15695100E+04, 0.59102900E+04, -.82496000E+03, -.40372700E+02, -.59939100E+04, 0.41249200E+03, -.23150100E+04, 0.26636000E+04, -.44306400E+04, -.58473900E+04, -.41338100E+04, 0.19548700E+04, 0.49548900E+04, -.21256100E+05, 0.97976400E+04, 0.23077200E+04, 0.10628200E+05, 0.68477100E+03, -.26576500E+04, 0.60231800E+04, 0.70608800E+03, 0.62868200E+04, -.21255500E+04, 0.63965400E+04, -.23110400E+03, -.37134900E+03, -.11340700E+03, -.53596300E+02, -.13989700E+03, 0.44026200E+03, 0.11861800E+04, -.22054300E+03, -.80192400E+02, 0.36942100E+03, -.42170200E+04, 0.27856700E+04, 0.67707700E+03, -.41325200E+03, 0.22640600E+04, 0.23612700E+04, 0.26416000E+03, 0.21095100E+03, 0.16990500E+03, 0.39153400E+04, -.29296500E+03, -.54278200E+02, 0.96130300E+03, 0.29639400E+04, -.13117300E+04, 0.13881800E+04 },
        { 0.53676700E+01, -.74293700E-01, -.20200900E+00, 0.20653900E+00, 0.60920600E+00, -.17237700E+00, -.14490300E+01, 0.13539600E+01, -.13834800E+00, 0.20480300E+00, 0.46702300E-01, 0.40341500E+00, -.21434100E-01, 0.14246800E-01, -.14897100E+00, -.12316000E-01, 0.61401700E+00, -.52429800E-01, 0.39178500E+00, -.66500400E+00, 0.65265900E+00, 0.65266000E-01, -.11389200E+01, 0.19556000E+00, -.13640200E+00, -.32013100E-02, -.45708100E-01, -.37273000E-01, 0.44739500E-01, 0.23816100E+00, -.67903900E-01, 0.13147100E+00, 0.97315800E-02, 0.70034200E+00, -.80570200E+00, -.38630700E+00, 0.95535700E-01, -.65048100E+00, -.14903000E+00, -.73653200E+00, 0.13702500E+04, 0.10332100E+04, 0.57624500E+03, -.12670200E+04, -.12936200E+05, 0.63685600E+04, 0.11085200E+05, 0.64680300E+04, 0.81498500E+03, -.27889700E+04, 0.67251700E+04, 0.10068100E+05, 0.83377100E+04, -.14755700E+04, -.29569200E+04, -.29483700E+05, 0.15163900E+05, 0.11541400E+05, 0.14742700E+05, 0.87307600E+04, 0.30121000E+04, 0.99958000E+04, -.10576200E+03, 0.51119100E+04, 0.50766700E+04, 0.40685800E+04, -.79571400E+02, 0.37262200E+02, -.63157000E+02, 0.39765600E+02, 0.25498700E+03, 0.91877900E+02, 0.28271100E+02, 0.21757800E+02, -.35279400E+01, 0.10104100E+03, 0.90494800E+01, -.33570000E+03, 0.16216800E+03, -.96721600E+03, 0.16780300E+03, 0.91292400E+01, 0.83075100E+03, 0.33512900E+02, 0.59222300E+01, 0.93154300E+03, 0.66757000E+03, -.15577700E+04, 0.31608800E+05, -.15259100E+05, 0.55411300E+04, -.15814500E+05, -.39917300E+04, -.72710300E+04, 0.30839200E+03, 0.70520800E+04, -.99271400E+04, -.62872700E+04, -.13546400E+05, -.34816800E+05, 0.16994600E+05, 0.83832300E+04, 0.17414100E+05, 0.22262700E+04, -.12024600E+04, 0.86175400E+04, -.68287200E+03, 0.14285400E+05, -.29864500E+03, 0.94190800E+04, -.14417700E+05, 0.72761500E+04, 0.24085900E+04, 0.72095700E+04, 0.33495500E+04, 0.24760000E+04, 0.20138900E+04, -.30417900E+04, 0.24387400E+04, 0.27697500E+04, 0.46896100E+04, 0.98887300E+04, -.50795800E+04, -.26493400E+05, -.49442000E+04, -.22253200E+04, -.16764300E+03, -.46409800E+04, -.36865800E+04, -.29143800E+04, 0.12102700E+02, -.42097900E+03, 0.98925400E+04, -.49150800E+04, -.13863300E+04, -.49471000E+04, -.42023600E+03, 0.38671300E+04, -.60556000E+04, -.71959500E+04, -.78923000E+04, 0.24026200E+04, 0.25877300E+04, 0.16436900E+05, -.82605800E+04, -.98054200E+04, -.82186700E+04, -.55322700E+04, 0.18256800E+03, -.61647800E+04, 0.20398600E+04, -.23668400E+04, -.18020900E+04, -.21861900E+04, -.39016800E+05, 0.19189300E+05, 0.43331700E+04, 0.19519700E+05, 0.30619500E+04, 0.17319900E+04, 0.61343000E+04, -.34062300E+04, 0.14789100E+05, 0.18837100E+04, 0.12912700E+05, -.99444400E+03, 0.45156000E+03, 0.46540900E+04, 0.49688100E+03, -.15502300E+02, -.28150600E+04, 0.28616600E+04, 0.18364600E+04, 0.48549100E+03, -.16907700E+04, -.24709300E+04, 0.10327600E+04, -.79174900E+03, 0.37102700E+04, -.51620400E+03, -.49213000E+04, -.12436400E+04, -.39170100E+03, 0.43744900E+03, -.59846100E+03, -.16655400E+04, 0.21734600E+03, -.17316500E+05, 0.87638900E+04, 0.96320500E+04, 0.86579000E+04, 0.18269300E+04, -.30806800E+04, 0.68018500E+04, 0.75311600E+04, 0.87860000E+04, -.12205200E+04, 0.66558300E+03, -.40620400E+03, 0.20786100E+03, -.37323000E+04, 0.20238900E+03, -.79101500E+03, 0.14538300E+03, -.21113000E+03, -.60842500E+03, 0.22359100E+03, -.27010300E+02, 0.76737400E+03, -.99769000E+04, 0.49729000E+04, 0.12748900E+05, 0.49884800E+04, 0.12975500E+04, -.31033900E+04, 0.50847500E+04, 0.81848500E+04, 0.57653400E+04, -.17634700E+04, -.83134700E+03, -.28923000E+05, 0.14818600E+05, 0.11655800E+05, 0.14461500E+05, 0.86386600E+04, 0.32904500E+04, 0.10195700E+05, -.15605800E+04, 0.47097900E+04, 0.51889100E+04, 0.59662200E+04, 0.20190600E+05, -.10493900E+05, -.56352300E+04, -.10095800E+05, -.68745800E+04, -.57062500E+03, -.72725500E+04, 0.29291700E+04, -.25457500E+04, -.30595900E+04, -.11950900E+04, -.88538000E+04, 0.40871100E+04, 0.47641300E+04, 0.44312000E+04, 0.79934000E+03, -.10857100E+04, 0.31798500E+04, 0.59236600E+00, 0.35559700E+04, -.32505300E+03, 0.10241000E+04, 0.68024200E+04, -.37036300E+04, -.10456400E+05, -.34004500E+04, -.49775900E+04, 0.16351800E+04, -.65195700E+04, -.77686600E+04, -.61606200E+04, 0.52447600E+03, 0.22044600E+04, -.14135500E+05, 0.67234600E+04, -.47704800E+04, 0.70715400E+04, 0.15341100E+04, 0.29484200E+04, 0.19545900E+03, -.21500500E+04, 0.52065400E+04, 0.23947200E+04, 0.60910000E+04, 0.65112300E+02, -.25279900E+03, -.47807000E+03, -.57534200E+02, 0.25258200E+03, 0.39602600E+03, 0.81613100E+03, -.29099900E+03, 0.42473500E+03, -.53664300E+02, -.23870400E+04, 0.10327000E+04, 0.17649200E+03, -.16448400E+04, 0.29215400E+04, 0.13117800E+04, -.48279300E+03, -.21051500E+03, -.12446100E+04, 0.42055300E+04, 0.20499700E+03, -.34549300E+03, -.56422100E+03, 0.21881300E+04, -.15069100E+04, 0.22079100E+02 },
        { -.11602800E+01, 0.52944900E-01, 0.12927600E-01, -.13619500E+00, -.16946000E+00, 0.31015700E+00, -.10123100E+00, 0.34620300E+00, -.13182400E+01, 0.65248600E-01, 0.17036900E-01, -.19010200E+00, 0.70328500E-01, -.24913700E-01, 0.55616000E-01, -.16681800E-01, -.36015100E-01, -.66351200E-01, -.10135900E+00, 0.71014500E-01, 0.18047400E+00, 0.12167200E-01, -.18124700E+01, -.62236200E-01, 0.27654400E-01, 0.56170300E-01, -.87694300E-01, 0.21004600E+00, 0.49632900E+00, 0.36186900E+00, 0.51520600E+00, 0.53230600E-01, -.65229200E-01, -.30402600E+00, 0.19640600E+00, 0.52094000E-01, -.24835300E-01, 0.60035000E+00, -.14352800E+00, 0.21602600E-01, -.18470800E+00, 0.59836700E+03, -.67996500E+02, -.44416600E+03, -.44786100E+04, 0.22302700E+04, 0.41755500E+04, 0.22393000E+04, -.14368700E+03, 0.25705000E+02, 0.17280200E+04, 0.15994200E+04, 0.27333200E+04, -.16746700E+03, -.73180500E+03, 0.89498500E+04, -.44865200E+04, -.32139500E+04, -.44748900E+04, -.12412900E+04, -.23257200E+04, 0.82349900E+03, 0.70149500E+04, 0.51387700E+04, -.20122600E+04, -.27639600E+04, 0.43608300E+02, -.21892100E+02, -.15215900E+02, -.21804700E+02, 0.29867300E+02, -.17754400E+01, 0.16662300E+02, 0.77189500E+00, -.17382900E+02, 0.40612400E+01, -.40571400E+02, -.70792900E+03, 0.34653900E+03, -.20456400E+03, 0.35396300E+03, -.51931400E+02, -.62190800E+02, 0.32487300E+03, 0.73943400E+02, 0.57231800E+03, -.49731200E+02, -.22389200E+03, -.17095900E+04, 0.99331000E+03, 0.14245200E+04, 0.85447400E+03, 0.21683000E+04, 0.13586900E+04, -.11324500E+04, -.89455300E+03, 0.16289600E+03, 0.73896700E+03, 0.22304600E+04, -.94325000E+04, 0.45771700E+04, 0.49649800E+04, 0.47164100E+04, -.78605000E+03, -.19216800E+04, 0.37679100E+04, 0.16000500E+04, 0.35578500E+04, -.11327900E+04, 0.21982900E+04, -.43233800E+03, 0.20508500E+03, -.58553100E+03, 0.21619000E+03, 0.32215500E+03, -.80952900E+02, 0.23760000E+03, 0.11495100E+04, 0.23835000E+04, -.61641200E+02, 0.52643800E+03, 0.13112100E+03, -.75627000E+02, -.49032500E+04, -.65556400E+02, -.45954200E+03, -.12862200E+03, -.70361700E+03, -.18441300E+04, -.33876300E+03, -.66691000E+02, 0.16453100E+04, 0.40202200E+04, -.19943700E+04, -.25117200E+04, -.20100800E+04, 0.19178600E+03, 0.18794400E+03, -.12236000E+04, -.27115600E+03, -.17860200E+04, 0.24254100E+03, -.39597000E+03, -.41748600E+03, 0.21482700E+03, -.10282700E+04, 0.20873600E+03, 0.10361400E+03, 0.97976500E+03, -.92451000E+03, -.23714600E+04, -.40478700E+04, 0.10362000E+04, -.35709500E+03, -.68342100E+04, 0.32772000E+04, 0.28076200E+04, 0.34174200E+04, -.12273400E+04, -.21041100E+04, 0.33369900E+04, 0.14906000E+04, 0.27426800E+04, -.13364400E+04, 0.93752800E+03, -.27921400E+04, 0.13937300E+04, 0.25441100E+04, 0.13960600E+04, -.32251700E+02, -.59826500E+03, 0.95100800E+03, 0.51410800E+03, 0.28571900E+04, -.56111600E+03, 0.41998700E+03, 0.55605500E+03, -.30740300E+03, 0.11154600E+04, -.27802300E+03, -.66037900E+03, -.41124400E+02, -.39196900E+03, 0.15040400E+03, -.78364300E+03, -.90503900E+02, -.80459900E+02, 0.63313900E+02, -.46743100E+02, 0.15732200E+04, -.31667200E+02, -.27583600E+03, 0.98263400E+02, 0.17121000E+03, 0.17147800E+04, -.59409900E+03, 0.89748500E+02, -.37621400E+03, -.46581900E+03, 0.22311400E+03, -.64052200E+03, 0.23288900E+03, -.89299100E+02, 0.15102200E+02, -.20876100E+02, -.65932300E+02, 0.34671400E+03, -.12702900E+02, 0.27747300E+03, -.10691000E+04, 0.53078500E+03, 0.30617300E+04, 0.53455000E+03, -.58255200E+02, 0.14213500E+03, 0.42313200E+03, 0.15231200E+04, -.16239200E+03, -.26713000E+02, -.55748600E+02, 0.69330100E+04, -.34700500E+04, -.26386100E+04, -.34665000E+04, -.11872100E+04, -.25248400E+04, 0.10947300E+04, 0.62379200E+04, 0.79908300E+04, -.25794200E+04, -.13563600E+04, -.18155700E+04, 0.91971700E+03, 0.53711300E+03, 0.90776700E+03, 0.19776000E+02, 0.84155200E+03, -.81889300E+03, -.37625700E+04, -.42865100E+04, 0.56345000E+03, 0.19919800E+03, -.17954100E+04, 0.82962500E+03, 0.22294200E+04, 0.89782700E+03, -.64096800E+03, -.41804500E+03, 0.81147000E+03, 0.28950100E+03, 0.74910000E+03, -.42886900E+02, 0.16451900E+03, -.14120000E+03, 0.57844600E+02, -.29085900E+04, 0.70624900E+02, 0.59158300E+02, 0.61912900E+03, -.13467400E+04, -.14287700E+04, -.17336400E+04, 0.66793400E+03, 0.11744900E+04, 0.31679500E+03, -.22496400E+03, -.63565200E+03, -.15827700E+03, -.10101000E+04, -.79821100E+03, 0.86311700E+03, 0.95148900E+03, -.43279100E+03, -.50365500E+03, -.81210600E+03, -.42164200E+02, -.78219000E+02, -.12230400E+03, -.13706400E+02, -.18184300E+02, 0.68398000E+02, -.55309800E+03, -.42787000E+02, 0.69636500E+02, -.75291800E+03, 0.13922000E+04, -.16019400E+04, 0.19788100E+02, 0.97902000E+01, 0.16166100E+04, -.13985900E+04, 0.27317900E+03, 0.21024100E+02, -.31851800E+02, 0.31678400E+03, -.61943700E+02, 0.12776800E+04, -.99183400E+03, -.11647200E+04, -.86472900E+02, -.43963400E+03 },
        { -.39776700E+01, 0.65180600E-01, 0.10496800E+00, -.48293600E+00, -.58415600E+00, 0.32118100E+00, 0.50950600E+00, 0.13086700E+00, -.27277000E+01, -.16390700E+00, -.46411200E-01, -.90511900E+00, -.12731000E+00, -.33044600E-01, -.28109600E+00, 0.58921000E-01, -.87431900E+00, -.75661000E+00, -.45815500E+00, 0.10210800E+01, -.71794100E-01, 0.17183200E+00, -.79407100E+01, -.11570800E+01, -.14272200E+00, 0.24856200E-01, 0.93154900E-01, 0.33185700E+00, 0.39392400E+00, 0.36502500E+00, 0.48013900E+00, 0.11749000E+01, -.62330800E-01, -.73420200E-01, 0.56542000E+00, 0.17186900E+00, -.29495800E-01, 0.89926700E-01, -.16525700E+00, 0.48802300E+00, -.10077000E-01, 0.30601100E-01, 0.47342300E+03, -.15116600E+04, 0.63292100E+04, -.30885600E+04, 0.95940000E+01, -.31646100E+04, 0.83099100E+03, 0.76788000E+03, -.24992500E+04, -.18799600E+04, -.39434100E+04, 0.13170100E+04, -.68160300E+04, 0.66061300E+04, -.36452600E+04, -.17707400E+04, -.33030700E+04, -.50548000E+04, -.24649600E+04, 0.40415300E+03, 0.67877600E+03, -.11332300E+04, -.28709700E+04, 0.59448000E+04, -.58267800E+02, 0.30897900E+02, -.73187100E+01, 0.29134200E+02, -.40095700E+02, 0.28876600E+02, -.75721800E+01, 0.16781300E+02, 0.25587200E+02, 0.35685500E+02, 0.68060000E+02, 0.10376100E+04, -.47212500E+03, -.44087100E+03, -.51880700E+03, 0.53362700E+02, -.26289400E+03, -.42178000E+03, -.18386000E+03, -.93441700E+03, -.44935100E+02, -.67703500E+03, -.14989800E+05, 0.62598900E+04, 0.61171900E+04, 0.74950300E+04, -.31445600E+04, -.20909600E+04, 0.60501900E+04, 0.77676000E+03, -.77332600E+03, -.64094300E+03, 0.25303100E+04, 0.40821800E+05, -.19320000E+05, -.12003300E+05, -.20410900E+05, -.32570100E+04, -.15872500E+04, -.78420100E+04, 0.28930600E+04, -.90442400E+04, -.30237800E+04, -.87897300E+04, -.95901500E+03, 0.36151600E+03, -.22429800E+03, 0.47950500E+03, -.34969700E+03, -.24172000E+03, 0.44719800E+03, -.14100700E+02, 0.35849400E+03, -.44418300E+03, 0.27069300E+04, -.44348900E+04, 0.23179300E+04, 0.40471200E+04, 0.22174400E+04, -.90286200E+03, -.15915500E+04, 0.16726600E+04, 0.60897500E+03, 0.26667100E+04, -.11272400E+04, -.46869800E+03, -.40283700E+04, 0.19720300E+04, -.63821300E+03, 0.20149000E+04, -.10137000E+03, 0.61692700E+02, 0.12747800E+04, 0.82486900E+03, 0.17906600E+04, -.19974500E+03, 0.41498100E+04, -.47933000E+04, 0.24290600E+04, 0.16375800E+04, 0.23966500E+04, 0.24106700E+04, 0.11026300E+04, -.23775100E+03, -.12593300E+04, 0.11966000E+04, 0.14111700E+04, -.15223400E+04, 0.36102400E+05, -.17010100E+05, -.12368300E+05, -.18051300E+05, -.16325700E+04, -.69361300E+03, -.77587600E+04, 0.26747700E+04, -.62838600E+04, -.20938800E+04, -.80913200E+04, 0.51791700E+04, -.25347400E+04, -.22046600E+04, -.25895800E+04, 0.86176600E+03, -.54679800E+01, -.57850100E+03, 0.60238600E+03, -.18071300E+04, -.24193300E+03, -.31662800E+04, 0.20119900E+04, -.66488100E+03, 0.97173400E+03, -.10060000E+04, 0.11695800E+04, -.17791900E+03, -.12614800E+03, 0.41671300E+02, -.24258000E+00, -.27210500E+03, -.30489000E+04, 0.13875600E+04, -.76262900E+03, -.12634700E+04, -.69378000E+03, -.18214900E+04, -.11594700E+03, -.13535900E+04, -.28912500E+04, -.20385400E+03, 0.18391100E+03, 0.62369100E+03, -.49123300E+03, 0.29769900E+03, 0.73261700E+03, 0.24562400E+03, 0.53132800E+03, 0.31981700E+03, -.20237000E+03, -.42825300E+03, 0.16967300E+03, 0.25324400E+03, -.65884000E+03, 0.12210300E+03, -.67230100E+02, -.13039900E+04, -.61052900E+02, -.99253700E+03, -.86785100E+02, -.86168100E+03, -.24028000E+04, -.47587700E+03, 0.22675200E+03, -.80782500E+03, -.27538800E+04, 0.10527200E+04, 0.22282300E+04, 0.13769500E+04, -.33718900E+04, -.10891900E+04, 0.13794300E+04, -.11722900E+04, -.15528800E+04, -.17818600E+04, 0.74893700E+04, -.11348400E+05, 0.59712400E+04, 0.36045600E+04, 0.56741900E+04, 0.48477700E+04, 0.27079400E+04, -.63283700E+02, -.26767000E+04, 0.11919100E+04, 0.29947200E+04, -.20743000E+04, 0.19051100E+05, -.88991000E+04, -.56057400E+04, -.95255700E+04, -.15875100E+04, -.67163300E+03, -.36847700E+04, 0.87327900E+03, -.42396600E+04, -.14815000E+04, -.39123800E+04, 0.13927300E+04, -.38527000E+03, 0.58879800E+03, -.69636800E+03, -.34617000E+02, -.67432300E+03, 0.50972300E+03, 0.11243200E+04, 0.18295700E+04, -.60081300E+03, -.17019400E+04, 0.51731400E+04, -.19341300E+04, -.16707400E+04, -.25866200E+04, 0.16553400E+04, 0.11112600E+04, -.27134900E+04, -.70556200E+03, 0.16838400E+04, 0.42958600E+03, -.34554600E+03, 0.17486000E+03, 0.23213100E+03, 0.11085000E+03, 0.71469200E+02, -.27439700E+03, 0.20306600E+03, -.86995200E+03, 0.71458200E+02, -.33483400E+02, 0.22725600E+04, -.10863300E+04, -.19222900E+04, -.20288600E+03, 0.45398400E+03, 0.27242500E+02, 0.26412700E+04, -.21145300E+03, -.16578100E+03, -.40315000E+03, -.14440600E+04, 0.24543800E+03, 0.21571800E+03, -.11776500E+04, 0.19249200E+03, -.15370500E+03, 0.92654400E+03 },
        { -.87337600E+00, 0.53274300E-01, 0.47190400E-01, -.99468200E-01, -.78794600E-01, 0.70537900E+00, -.29909400E+00, 0.29001200E+00, 0.10323900E+00, 0.38748300E+00, -.45292200E-02, -.20692100E+00, -.16699200E-01, 0.21928900E-01, -.25412400E+00, 0.65646600E-01, 0.30529100E+00, 0.17240400E+00, 0.10698300E+00, -.92830500E-01, 0.17878100E+00, -.87399800E-01, -.12213000E+01, 0.17634000E+00, -.93064400E-01, -.29073600E-01, -.14130800E+00, 0.92210700E-01, 0.37858800E+00, -.64331700E+00, 0.18269000E+00, -.36127700E+00, -.72805800E-01, -.94015700E-02, -.94732700E+00, -.18509500E-01, -.54244600E-01, 0.60909900E+00, -.98212000E-01, 0.22009500E+00, -.87245400E-02, -.28367200E+00, -.40524400E+00, -.10624700E+04, 0.21243500E+04, -.10080400E+04, -.76621300E+02, -.10621300E+04, 0.11743000E+04, -.12551400E+03, -.91996600E+03, -.11666900E+04, -.15649800E+04, -.22321300E+03, -.44418100E+04, -.76464200E+03, 0.19777300E+03, 0.17833400E+04, 0.38196500E+03, -.17081900E+04, -.18536000E+03, -.40322900E+03, -.13249600E+04, 0.52875700E+03, -.20037000E+03, 0.40527900E+04, 0.17744000E+01, 0.12104400E+01, -.99520900E+01, -.87901300E+00, -.73658000E+02, 0.34130000E+02, -.47985100E+02, -.35561000E+02, -.13365600E+02, 0.39568800E+02, 0.11640500E+02, -.85877000E+03, 0.47098200E+03, 0.29050100E+03, 0.42940600E+03, 0.84077500E+02, -.80247700E+03, 0.42340200E+03, 0.30677500E+03, 0.97482200E+02, -.64397900E+03, 0.11400900E+03, -.20732700E+05, 0.98366100E+04, 0.37610800E+04, 0.10370500E+05, 0.35857200E+03, -.48806900E+04, 0.68747000E+04, 0.26679900E+04, 0.63078100E+04, -.39472300E+04, 0.70325300E+04, 0.18708800E+05, -.88559100E+04, -.35967300E+04, -.93567800E+04, -.82974800E+03, 0.36821500E+04, -.58764900E+04, -.24743600E+04, -.74058100E+04, 0.29616100E+04, -.31834200E+04, -.58201500E+03, 0.29466900E+03, 0.71455500E+03, 0.29071000E+03, -.63944700E+02, 0.10574100E+03, -.78250800E+02, -.16037500E+03, 0.48977300E+03, 0.73977800E+02, 0.12298600E+04, 0.21039400E+04, -.10000800E+04, 0.11437700E+04, -.10520300E+04, -.93130600E+03, 0.50079100E+03, -.89750700E+03, -.11290700E+04, -.85233700E+03, 0.63468700E+03, -.62462100E+03, -.26684700E+04, 0.13252300E+04, -.52223400E+03, 0.13345600E+04, -.55236300E+03, -.30054800E+02, 0.10426000E+04, 0.88867900E+03, 0.15504500E+04, 0.28948300E+02, 0.32150800E+04, -.13073300E+04, 0.67143300E+03, 0.60505500E+03, 0.65376200E+03, 0.10245700E+04, 0.15650800E+03, 0.54565700E+03, -.18161700E+03, 0.11106700E+03, 0.26622500E+03, -.10048100E+04, 0.20199200E+05, -.96328600E+04, -.38946600E+04, -.10104300E+05, -.96602100E+03, 0.32360800E+04, -.56780100E+04, -.15789000E+04, -.66721600E+04, 0.24609800E+04, -.47696800E+04, 0.55806600E+03, -.26038300E+03, -.63090900E+03, -.27889200E+03, 0.68313600E+03, -.10870200E+04, 0.78723400E+03, 0.52497200E+03, 0.35197800E+02, -.10709600E+04, -.11294300E+04, 0.12953600E+04, -.51779000E+03, 0.53441300E+03, -.64775100E+03, 0.14278300E+04, -.33261300E+03, 0.33307900E+03, 0.70872600E+03, 0.15173500E+03, -.53393700E+03, -.17517800E+04, 0.12739100E+04, -.63372300E+03, -.18728000E+02, -.63681500E+03, -.15572300E+03, -.14813900E+03, -.61959600E+03, -.10616100E+04, -.36750700E+03, -.44675600E+03, -.15647300E+04, 0.14484100E+04, -.72829500E+03, 0.49763100E+03, -.72391300E+03, 0.49085800E+03, 0.43550100E+03, -.42106500E+03, 0.15552300E+03, -.43451000E+03, 0.28523200E+03, -.11611700E+04, 0.22020800E+03, -.71751900E+02, -.10568000E+04, -.11011700E+03, 0.44382300E+02, -.22460600E+03, -.37896900E+03, -.10215700E+04, -.14515000E+03, -.49849800E+03, -.15485800E+04, -.77489100E+03, 0.21623500E+03, 0.12513500E+04, 0.38743000E+03, -.17785300E+04, -.51638000E+03, -.12766700E+02, -.87722500E+03, -.30396400E+02, -.64432400E+03, 0.33171800E+04, -.21049700E+03, 0.26268500E+03, -.16679300E+04, 0.10548000E+03, 0.13261600E+04, -.82299900E+02, 0.67670700E+03, 0.38004400E+03, -.55779800E+03, -.28399400E+02, -.29424700E+04, 0.10158200E+05, -.47893900E+04, -.26419400E+04, -.50808700E+04, -.33821700E+03, 0.30214600E+04, -.38948200E+04, -.24081700E+04, -.44042800E+04, 0.26450900E+04, -.19825300E+04, 0.20353900E+04, -.88020800E+03, 0.49821600E+03, -.10180100E+04, 0.22757000E+03, -.58289900E+03, 0.11156800E+04, 0.14405600E+04, 0.73552000E+03, -.53840400E+03, -.92424900E+03, 0.93916900E+04, -.44293100E+04, -.12928900E+04, -.46974000E+04, -.35323100E+03, 0.21559300E+04, -.30801200E+04, -.13353900E+04, -.27150100E+04, 0.16698700E+04, -.28886900E+04, 0.85068700E+02, 0.16481700E+03, -.21718900E+02, 0.28591500E+02, -.96994900E+02, -.23170200E+03, -.40950600E+03, 0.94454300E+02, 0.48538900E+02, -.51915700E+03, 0.22942700E+04, -.49174800E+03, -.28126300E+03, -.53283700E+03, -.11952200E+03, -.16157000E+04, -.17784800E+03, -.14622700E+03, -.70866700E+02, -.17116100E+04, 0.17873200E+03, 0.23330500E+03, -.18625300E+03, -.12225000E+04, -.35700200E+02, -.12994600E+04 },
        { 0.46863000E+01, -.10328300E-02, -.14464200E+00, 0.54769800E+00, 0.64239700E+00, 0.13908000E+00, -.82136700E-01, -.47884700E-01, 0.17434500E+00, -.64544500E+00, 0.36767000E-01, -.51859600E+00, -.11340300E-01, 0.46502500E-01, 0.46216100E-01, -.75541200E-03, 0.51727700E+00, 0.12398700E+00, 0.32927100E-01, -.11026300E+00, -.10420800E+00, 0.28155800E-01, 0.25993500E+01, 0.14543600E+00, 0.10351100E+00, -.20323100E-02, 0.64444700E-01, 0.15685000E+00, 0.97520300E-01, 0.38770700E+00, 0.92144100E-02, -.11074200E+01, 0.83491700E-02, 0.65425800E+00, -.53883400E+00, -.38993900E+00, -.18500400E-01, 0.10329100E+01, 0.25919200E-02, -.63730700E+00, 0.40062000E+00, 0.78800100E+00, -.43241000E+00, -.59946600E+00, 0.10280700E+05, -.51214800E+04, -.78071200E+04, -.51402300E+04, 0.48834900E+03, 0.11856100E+02, -.26759000E+04, -.69577200E+03, -.42574000E+04, -.15163000E+03, -.15626900E+04, 0.55638300E+04, -.27815600E+04, -.42617800E+04, -.27828900E+04, -.53791100E+03, 0.16771100E+04, -.36807400E+04, -.31582200E+04, -.75863500E+04, 0.10912400E+04, -.60197400E+03, -.25173700E+02, 0.12854900E+02, -.32521600E+02, 0.12608900E+02, -.74237800E+02, -.13147400E+01, -.21765600E+02, -.67420100E+01, 0.41944600E+02, -.97385500E+01, 0.26376500E+02, -.14356500E+04, 0.70739300E+03, 0.10349100E+04, 0.71788500E+03, -.13393300E+02, -.81602600E+03, 0.59879800E+03, 0.40354400E+03, 0.49296100E+03, -.65731800E+03, 0.90935400E+03, 0.61005700E+04, -.28386600E+04, -.23705800E+04, -.30390200E+04, -.18370100E+04, -.41948100E+04, 0.17912800E+04, 0.35960800E+04, -.35625400E+04, -.30634000E+04, -.41752100E+04, -.41676100E+04, 0.19002400E+04, -.17709000E+04, 0.20772600E+04, 0.29402600E+04, 0.54893800E+04, -.42678600E+04, -.65105600E+04, -.34090300E+04, 0.45625000E+04, 0.43228900E+04, 0.51192800E+04, -.25165500E+04, -.17292000E+04, -.25604500E+04, -.86755600E+03, -.50696000E+03, -.82566800E+03, 0.54991000E+03, -.21644800E+04, -.58309600E+03, -.16292100E+04, 0.34560200E+04, -.17202000E+04, 0.36690800E+04, -.17281800E+04, 0.50147700E+03, 0.30316900E+04, -.16446800E+04, -.66058700E+03, -.18952200E+04, 0.31893300E+04, -.15541600E+04, -.70171000E+04, 0.35031300E+04, 0.41210600E+04, 0.35086400E+04, -.77520500E+03, -.15693100E+04, 0.25835500E+04, 0.92231800E+03, 0.36540700E+04, -.14716700E+04, 0.10593700E+04, -.63285600E+04, 0.31475900E+04, 0.52974800E+04, 0.31645500E+04, 0.57489800E+03, -.11332200E+03, 0.19555700E+04, -.88928300E+02, 0.43718500E+04, -.18642700E+03, 0.24666200E+04, -.38465100E+04, 0.17166500E+04, -.53208500E+03, 0.19104600E+04, 0.23216000E+04, 0.46012800E+04, -.32112500E+04, -.49919700E+04, -.71722200E+03, 0.36293000E+04, 0.42014300E+04, 0.32503400E+03, -.14724700E+03, -.15878600E+04, -.16213500E+03, 0.15578500E+04, 0.98882900E+02, -.68409500E+03, -.38650700E+03, -.16669900E+04, 0.21468000E+03, -.92443300E+03, -.13421000E+04, 0.63241100E+03, -.87084300E+02, 0.67086700E+03, 0.78314400E+03, -.56170800E+03, 0.84021400E+03, 0.13213400E+03, 0.13653900E+04, -.49706500E+03, 0.74318100E+03, 0.30518200E+04, -.15371500E+04, -.23822900E+04, -.15255300E+04, 0.13452200E+03, 0.91780000E+03, -.11990900E+04, -.15096000E+04, -.14871900E+04, 0.70455400E+03, 0.64627500E+02, 0.13714300E+04, -.70360800E+03, 0.11411000E+04, -.68492200E+03, 0.49998100E+02, 0.26528100E+03, -.21514700E+03, 0.30298300E+03, -.28502000E+03, 0.15858200E+03, -.81953900E+03, 0.26675000E+04, -.13245200E+04, -.40716700E+04, -.13337800E+04, 0.81446500E+02, 0.58706200E+03, -.92391900E+03, -.16028000E+04, -.12398500E+04, 0.62970000E+03, 0.20209500E+02, 0.57687100E+04, -.28618900E+04, -.41462900E+04, -.28844000E+04, -.19167600E+03, 0.13588500E+04, -.36605100E+04, -.21312100E+04, -.73908500E+04, 0.13982500E+04, -.27849300E+04, -.97545300E+04, 0.48799900E+04, 0.51083500E+04, 0.48779000E+04, 0.14893300E+04, -.60536100E+02, 0.27643700E+04, 0.14467300E+03, 0.67044900E+04, 0.37361900E+03, 0.21776800E+04, -.24293200E+04, 0.11353200E+04, -.15918100E+04, 0.12098100E+04, 0.17487800E+04, 0.29105600E+04, -.20591500E+04, -.32971200E+04, -.18979700E+04, 0.24408500E+04, 0.18649100E+04, -.18105400E+04, 0.87405500E+03, 0.50859900E+04, 0.90439700E+03, -.26346200E+03, -.10622300E+04, 0.19055500E+04, 0.14389700E+04, 0.29468400E+04, -.10058100E+04, 0.97163100E+02, -.57840700E+04, 0.27881500E+04, 0.25974400E+04, 0.28878400E+04, 0.12373500E+04, 0.27618600E+04, -.10058300E+04, -.29416800E+04, 0.21131300E+04, 0.21845000E+04, 0.33480400E+04, 0.97009300E+01, -.53948300E+01, 0.15334600E+03, 0.35744800E+02, -.21531800E+03, -.11061400E+03, 0.91771900E+03, 0.77838300E+02, -.15231700E+03, -.96549800E+03, -.42796300E+03, 0.16574000E+04, -.47857700E+03, 0.10228700E+04, -.15547600E+04, -.32792900E+03, -.32114400E+03, -.18242900E+03, 0.33778200E+03, 0.70723600E+02, -.72719200E+02, -.11375000E+04, 0.14616000E+04, 0.97301700E+03, 0.45660500E+03, -.16813000E+04 },
        { -.61620300E+01, 0.13727400E+00, 0.15145700E+00, -.33257600E+00, -.69428200E+00, 0.58433200E+00, 0.81840700E+00, 0.43177500E+00, -.45756600E+01, -.21046600E+00, -.54403300E-01, -.12057000E+01, -.38066900E-01, 0.27776700E-01, 0.37295200E+00, 0.53239300E-01, -.94954400E+00, -.31303900E+00, -.48458500E+00, 0.76072200E+00, -.25549300E+00, 0.21919000E-01, -.21758600E+00, -.60029900E+00, -.20211900E+00, -.50914100E-01, 0.47094100E-01, -.41451600E-01, 0.31884500E+00, 0.13646700E+00, 0.79983800E+00, 0.10124700E+01, -.96904400E-01, -.79409000E+00, 0.38114400E+01, 0.19292600E+00, -.13092000E+00, 0.19351700E+01, -.23708200E+00, 0.52131700E+00, -.67559300E+00, 0.89874800E+00, 0.80363800E+00, 0.11512800E+00, -.73393200E+00, -.19009300E+03, -.35238100E+04, 0.99604300E-01, 0.66051700E+03, -.72223100E+03, 0.23095800E+03, 0.56821200E+03, 0.16056600E+02, -.43608400E+03, 0.10741900E+04, -.28979900E+05, 0.14963900E+05, 0.10397500E+05, 0.14489000E+05, 0.38811000E+04, 0.54692700E+04, 0.65884700E+03, -.94071400E+04, -.55126600E+03, 0.51373200E+04, 0.12034800E+05, -.15175700E+02, 0.16918400E+01, -.16247900E+02, 0.76120400E+01, -.52824000E+01, -.15920100E+00, 0.41362900E+01, 0.24552700E+02, 0.45875000E+01, 0.92550200E+01, -.94929600E+01, -.66667900E+03, 0.19935400E+03, 0.73594800E+03, 0.33339300E+03, 0.16870800E+02, -.79114100E+03, 0.69262500E+03, 0.52132600E+03, 0.34529600E+03, -.68378200E+03, -.25020500E+03, 0.27130700E+05, -.11788800E+05, -.75101500E+04, -.13553200E+05, 0.51512700E+04, 0.98497000E+03, -.34643400E+04, 0.49410700E+04, -.11080500E+05, 0.23308300E+03, -.10457100E+05, -.73598700E+05, 0.35176300E+05, 0.14810200E+05, 0.36792600E+05, 0.41278200E+04, 0.33754600E+04, 0.86858500E+04, -.88879700E+04, 0.29296300E+05, 0.27843900E+04, 0.28996600E+05, -.50353200E+04, 0.24834800E+04, 0.48563300E+04, 0.25168200E+04, -.76458400E+03, 0.10430300E+04, -.13758800E+03, -.30003800E+04, -.21119100E+04, 0.10704500E+04, 0.18390100E+04, 0.38057400E+04, -.20991700E+04, -.44037000E+04, -.19030600E+04, -.72415100E+03, 0.10564200E+04, -.14572500E+04, -.94306900E+03, -.87864300E+03, 0.11369400E+04, 0.91640200E+01, -.28548300E+04, 0.15275000E+04, 0.48001400E+04, 0.14269500E+04, -.27451600E+03, 0.32064500E+03, 0.25526100E+03, -.14519200E+04, 0.50050000E+02, -.47609700E+02, 0.64922500E+03, 0.11804600E+05, -.59313100E+04, -.35289100E+04, -.59020200E+04, -.31327900E+04, -.25280100E+04, -.34555300E+02, 0.34976700E+04, 0.26753400E+04, -.29801200E+04, -.29245400E+04, -.62222400E+05, 0.29562500E+05, 0.14711300E+05, 0.31097700E+05, 0.20605200E+04, 0.18638800E+04, 0.75342000E+04, -.77684900E+04, 0.24946900E+05, 0.17065700E+04, 0.24624100E+05, 0.43901000E+04, -.22601600E+04, -.17011200E+04, -.21946400E+04, 0.98267200E+03, -.63693500E+03, -.42198000E+03, 0.80884600E+03, -.35029400E+04, -.14130900E+03, -.42050600E+04, -.45282400E+04, 0.17602000E+04, 0.17134100E+02, 0.22639100E+04, -.71207100E+03, 0.24665300E+03, 0.56443000E+03, -.93903300E+03, 0.23761500E+04, -.55996700E+02, 0.36345600E+04, -.62750200E+04, 0.30830000E+04, 0.15837800E+03, 0.31379000E+04, 0.46610400E+03, -.12546600E+04, 0.19142000E+04, 0.10025200E+04, 0.49790100E+04, -.10685300E+04, 0.30177600E+04, 0.22539300E+04, -.11513500E+04, -.68297600E+03, -.11261100E+04, -.96318100E+03, -.61400400E+03, -.73724800E+02, 0.13147500E+03, -.74255200E+03, -.45904500E+03, -.59808700E+03, -.36967800E+04, 0.17367500E+04, -.26389700E+03, 0.18483500E+04, 0.67346300E+03, -.83735900E+03, 0.13825800E+04, 0.11271300E+04, 0.32858900E+04, -.74181300E+03, 0.19250300E+04, -.29309300E+05, 0.15116600E+05, 0.11900300E+05, 0.14654600E+05, 0.47363900E+04, 0.65763300E+04, 0.43537600E+03, -.96720000E+04, -.41855000E+04, 0.66002300E+04, 0.10465800E+05, 0.16625700E+05, -.87090000E+04, -.69982500E+04, -.83122300E+04, -.27557800E+04, -.27327900E+04, -.19891100E+03, 0.58367000E+04, 0.13728800E+04, -.28415800E+04, -.62214600E+04, -.31647600E+05, 0.14867800E+05, 0.56932100E+04, 0.15818600E+05, 0.19590900E+04, 0.21010400E+04, 0.30587200E+04, -.46831900E+04, 0.11978200E+05, 0.18848500E+04, 0.12154100E+05, -.99925300E+03, 0.48560700E+02, 0.22497100E+04, 0.49872700E+03, -.14943100E+04, 0.19867500E+02, -.80802600E+02, -.24734300E+04, 0.12453400E+04, -.40909000E+03, 0.21554800E+04, -.11033700E+05, 0.46096200E+04, 0.20539500E+04, 0.55122700E+04, -.35689500E+04, -.14587900E+04, 0.22869500E+04, -.11971000E+04, 0.60249500E+04, -.10319000E+04, 0.40138600E+04, -.10608100E+03, -.14260000E+03, -.47627300E+02, -.12499500E+02, 0.86817600E+02, -.17667600E+03, 0.47703000E+03, -.23341300E+02, -.25652800E+02, -.52950400E+04, 0.26576500E+04, 0.12229000E+04, -.15290600E+03, -.37660300E+03, -.53377000E+03, -.49214200E+04, -.63851900E+03, -.98659800E+02, -.45720400E+03, 0.25980200E+04, 0.27687500E+02, -.15560600E+04, 0.45056800E+03, -.11111900E+04, -.50840100E+03, -.51086700E+04 },
        { -.83387000E+01, 0.19871900E+00, 0.51710200E+00, -.94969500E+00, -.29362500E+00, 0.12574700E+01, -.84505900E+00, 0.50149400E+00, 0.62888200E+00, 0.83053400E+00, -.14868400E-01, 0.25264600E+00, 0.22402000E+00, -.46359400E+00, 0.57323000E-01, -.52355000E-01, 0.21415600E+00, 0.52670100E+00, 0.35018600E+00, -.46618600E+00, -.82093700E+00, 0.14492900E+00, 0.37516600E+01, 0.79700300E+00, 0.75732800E+00, 0.17191100E+00, -.31086700E-02, -.12243900E+00, -.63689900E+00, -.10300800E+01, -.76879600E+00, -.26214200E+01, -.57760300E-01, -.67734900E+00, 0.34105000E+00, 0.10111700E+00, -.21273300E+00, 0.31724900E+01, -.52114800E-02, 0.10239500E+01, -.99181900E+00, -.45477600E+00, -.13501600E+01, 0.10552000E+01, 0.93772300E+00, 0.10738200E+00, 0.10531700E+05, -.53220600E-03, -.10505600E+04, 0.14048600E+03, -.20374900E+03, -.11841600E+04, 0.39790900E+03, 0.47926500E+03, -.18475900E+04, -.16113700E+05, 0.79620600E+04, 0.16556700E+05, 0.80569600E+04, 0.13837500E+04, -.49526200E+03, 0.43321000E+04, -.20606500E+04, 0.45991400E+04, 0.85612200E+02, 0.47670100E+04, -.24066200E+03, 0.12083300E+03, 0.10046700E+03, 0.12032700E+03, -.54885800E+02, -.26448200E+02, 0.50627300E+02, 0.70356600E+00, 0.76705600E+02, 0.35018500E+01, 0.10286500E+03, -.58249200E+03, 0.28891400E+03, -.86522400E+03, 0.29124300E+03, -.43114900E+03, -.11114500E+04, 0.32670300E+03, -.20463100E+03, 0.18118800E+03, -.70997000E+03, -.78952100E+03, 0.21346400E+05, -.10201800E+05, -.24904400E+05, -.10675300E+05, 0.13025900E+04, 0.33779000E+03, 0.48129400E+03, 0.81092000E+04, -.58847200E+04, 0.86507300E+03, -.75427300E+04, -.30012500E+05, 0.14548600E+05, 0.37592500E+05, 0.15007100E+05, -.20922800E+04, -.72272800E+04, 0.73037600E+04, -.48401500E+04, 0.11912000E+05, -.64438900E+04, 0.66460700E+04, -.85421600E+04, 0.42588500E+04, 0.41623100E+04, 0.42712000E+04, 0.13410500E+04, 0.12119400E+04, 0.99836400E+03, -.17812900E+04, 0.23337700E+04, 0.11310500E+04, 0.33793000E+04, -.36144900E+04, 0.17983300E+04, -.24789500E+04, 0.18072800E+04, -.40636700E+04, -.24518600E+04, 0.10030400E+04, -.83361400E+03, 0.15679000E+04, -.23549800E+04, 0.49730000E+04, -.26508200E+04, 0.13622200E+04, -.65655500E+04, 0.13255300E+04, 0.15761200E+04, 0.16347600E+04, -.62196800E+02, -.75069500E+02, -.76915400E+02, 0.13678400E+04, 0.11689700E+04, 0.75832400E+04, -.37838100E+04, -.75001300E+04, -.37916600E+04, -.17646900E+04, 0.13773900E+03, -.23000400E+04, 0.55150800E+03, -.18312300E+04, 0.11205400E+03, -.13880300E+04, -.30532500E+05, 0.14838600E+05, 0.34305500E+05, 0.15268400E+05, -.92047100E+03, -.44982700E+04, 0.44076100E+04, -.66499000E+04, 0.10662200E+05, -.42258100E+04, 0.80587500E+04, 0.29820100E+04, -.14726600E+04, 0.60291600E+03, -.14910700E+04, 0.10083400E+04, -.35572100E+03, 0.50690200E+03, 0.56748800E+03, -.71911500E+03, -.20854100E+03, -.31052400E+04, 0.56676400E+04, -.28821100E+04, 0.39710600E+04, -.28337800E+04, 0.39907700E+01, 0.66325100E+03, -.15654100E+04, -.12111800E+04, -.30782700E+04, 0.36252300E+02, -.16679700E+04, -.42194500E+04, 0.20556600E+04, 0.52019100E+04, 0.21096700E+04, -.32953800E+03, -.19957000E+04, 0.10927300E+04, 0.10675900E+03, 0.29426600E+04, -.19639700E+04, 0.82985900E+03, 0.27185000E+04, -.13985100E+04, -.16786200E+04, -.13594000E+04, -.40128300E+03, 0.51863100E+03, -.68835400E+03, -.17381300E+03, -.97595100E+03, 0.32594300E+03, -.59816000E+03, -.18616200E+04, 0.93073600E+03, 0.36020500E+04, 0.93082200E+03, 0.48588300E+02, -.13207300E+04, 0.60888800E+03, 0.42704500E+03, 0.16907700E+04, -.14454400E+04, 0.56848200E+01, -.12285700E+05, 0.60832300E+04, 0.12332600E+05, 0.61428600E+04, 0.10404400E+04, -.37313800E+03, 0.41837000E+04, -.97198100E+03, 0.42124600E+04, -.34362200E+03, 0.41060800E+04, 0.15247200E+05, -.75438300E+04, -.15385300E+05, -.76236700E+04, -.21944800E+04, -.49438400E+03, -.33081500E+04, 0.28306600E+04, -.31629200E+04, -.11450600E+04, -.39752200E+04, -.13098100E+05, 0.63160600E+04, 0.19780200E+05, 0.65498400E+04, -.13717500E+04, -.29787700E+04, 0.30889400E+04, -.29377500E+04, 0.51311800E+04, -.25458100E+04, 0.26785100E+04, 0.11478200E+04, -.58231900E+03, -.12914300E+04, -.57378400E+03, -.93638700E+03, 0.14859500E+04, -.14675500E+04, -.27050800E+04, -.28831500E+04, 0.12331200E+04, 0.82509300E+03, -.88899900E+04, 0.42127500E+04, 0.11029100E+05, 0.44458200E+04, -.14971400E+04, -.12314200E+04, 0.36458100E+03, -.26787700E+04, 0.28783400E+04, -.14946000E+04, 0.29723500E+04, 0.14915700E+03, 0.20909900E+03, -.52476600E+02, 0.87649700E+02, -.61929500E+02, 0.36226600E+03, -.11891800E+04, 0.59212200E+02, 0.22513800E+02, -.33519300E+04, 0.27230300E+04, -.11816600E+04, -.14371800E+03, -.22371800E+03, 0.17506300E+04, -.23862000E+04, -.61398500E+01, -.19491400E+03, -.48571900E+03, 0.33041400E+04, 0.64097800E+02, 0.72852100E+03, -.17281700E+04, -.31558300E+04, -.11570400E+04, -.35604600E+04 },
        { -.19509200E+02, 0.34441200E+00, 0.65956000E+00, -.17563700E+01, -.20670200E+01, 0.21980600E+01, 0.41925600E+00, 0.66989900E+00, -.16278200E+01, 0.16187200E+01, 0.38988300E-01, -.34520300E+01, -.25704800E-01, 0.11684400E+00, -.80121700E+00, 0.46753500E+00, -.12545400E+01, -.76250200E-02, -.98929500E+00, 0.18597900E+01, 0.87070900E+00, -.31352700E+00, 0.21249100E+00, 0.33534600E+00, 0.10785100E+00, -.65366800E-01, 0.43986800E+00, 0.14523600E+01, 0.26207500E+01, 0.24339900E+00, 0.95468900E+00, 0.30320000E+01, -.80212000E-01, 0.34007600E+00, -.32654000E+01, -.28764000E+00, 0.11408100E+01, -.50789300E+01, 0.39658200E+00, -.11001800E+01, 0.92659600E+00, -.25859400E+00, -.47735500E-01, 0.36762200E-01, -.10181700E+01, -.36322000E+00, -.91733500E+00, 0.42250500E+01, -.46586500E+03, -.22026500E+03, 0.17735300E+04, 0.36623600E+04, 0.83289700E+03, -.60377200E+03, 0.20811500E+04, -.10269100E+05, 0.51390100E+04, 0.47977700E+04, 0.51260100E+04, 0.23111200E+04, 0.20513000E+04, 0.22260800E+04, -.13592900E+04, 0.87715500E+03, 0.24677800E+04, -.81045300E+03, -.10744100E+03, 0.53597200E+02, -.60908500E+02, 0.53815400E+02, -.23398600E+02, 0.31332500E+02, -.22828800E+02, -.49745700E+02, 0.53841000E+02, 0.26405400E+02, 0.36299500E+02, -.27542700E+04, 0.13494900E+04, 0.29349700E+03, 0.13765400E+04, 0.25210300E+03, -.10840800E+04, 0.14270500E+04, 0.14923200E+04, 0.15775200E+04, -.77021700E+03, 0.47251600E+03, 0.22927200E+05, -.10769700E+05, -.18897300E+05, -.11394600E+05, 0.61324700E+03, -.21879100E+04, 0.79210300E+03, 0.11542200E+05, -.72488200E+04, -.17558500E+03, -.97235900E+04, -.34385600E+05, 0.16562400E+05, 0.29139700E+05, 0.17160700E+05, 0.21458900E+04, 0.90960400E+03, 0.18536200E+04, -.13411300E+05, 0.53366100E+04, 0.55561800E+03, 0.10585700E+05, -.56804100E+04, 0.28850900E+04, 0.14567800E+04, 0.28357600E+04, 0.12647600E+04, 0.10072800E+04, 0.79626300E+03, -.13501600E+04, 0.12222800E+04, 0.99347500E+03, 0.95679200E+03, 0.37717300E+04, -.19098700E+04, -.79032500E+04, -.18851200E+04, -.22633900E+04, 0.31001300E+04, -.30155000E+04, -.35396500E+04, -.23615200E+04, 0.25496000E+04, 0.37760200E+04, 0.35229000E+04, -.17346700E+04, 0.45237400E+01, -.17677000E+04, 0.10457500E+03, -.69904400E+03, -.71257300E+03, -.62648700E+03, -.59501100E+03, -.59133000E+03, -.49510600E+04, 0.20412800E+04, -.10406100E+04, 0.13366100E+04, -.10196300E+04, -.17587500E+04, 0.43457900E+03, -.12699500E+04, -.12246000E+04, 0.37087700E+03, 0.14417300E+03, 0.26907400E+04, -.30479400E+05, 0.14612800E+05, 0.26496100E+05, 0.15172200E+05, 0.15873000E+04, 0.11725000E+04, 0.57137200E+03, -.13123800E+05, 0.60180500E+04, 0.36034700E+03, 0.10265900E+05, -.11474800E+04, 0.59957700E+03, 0.79565800E+03, 0.57371300E+03, 0.25930900E+04, -.14118800E+04, 0.10878300E+04, 0.13561600E+04, -.30166800E+03, -.73339900E+03, -.33062000E+04, 0.16704600E+04, -.96738400E+03, 0.46176200E+04, -.83124900E+03, -.73535000E+03, -.57786300E+03, -.48328800E+02, -.43742500E+03, -.44045800E+03, -.11292300E+04, 0.11272800E+04, -.14696500E+03, 0.20442000E+02, 0.40634800E+04, 0.77818300E+02, -.12060500E+03, 0.14221000E+03, 0.39404700E+03, 0.16667500E+04, 0.13759700E+03, 0.26283800E+03, 0.12768100E+04, 0.27505400E+04, -.14178900E+04, -.27158900E+03, -.13696800E+04, -.70570600E+03, 0.64616400E+02, -.28134500E+03, 0.43854800E+03, -.34574700E+03, -.29354300E+03, -.72918500E+03, 0.17460200E+04, -.87758200E+03, 0.23266400E+04, -.86799400E+03, -.58743500E+03, 0.30857900E+03, 0.35043800E+03, 0.21783500E+04, -.44498500E+03, 0.30126100E+03, 0.17028800E+04, -.28943100E+04, 0.14969200E+04, 0.80524800E+03, 0.14407100E+04, 0.19603200E+04, 0.63212000E+03, 0.88923800E+03, 0.48270000E+03, 0.87098800E+03, 0.94550700E+03, -.41533600E+04, 0.13082700E+05, -.65442200E+04, -.50398900E+04, -.65338300E+04, -.31990000E+04, -.17781900E+04, -.28950600E+04, 0.17158300E+04, -.46392900E+03, -.25233900E+04, -.34481700E+03, -.17505400E+05, 0.84243300E+04, 0.15360300E+05, 0.87256700E+04, 0.11615000E+04, 0.79260500E+03, 0.87976200E+03, -.71868900E+04, 0.24269400E+04, 0.61937900E+03, 0.51932200E+04, -.47046000E+04, 0.22556700E+04, 0.50521900E+04, 0.23548000E+04, -.98716700E+03, 0.39660100E+02, 0.54250500E+03, -.28624800E+04, 0.14980500E+04, -.31277400E+03, 0.22347700E+04, -.12593100E+05, 0.59474500E+04, 0.92801200E+04, 0.62669900E+04, -.56185100E+03, 0.14993000E+04, -.25858300E+03, -.58352100E+04, 0.33669700E+04, 0.36964500E+03, 0.57356400E+04, 0.32692800E+02, -.86173500E+02, -.14689000E+03, 0.36241200E+02, 0.10914200E+02, 0.56282800E+02, 0.37358900E+03, 0.23447700E+02, 0.12849000E+03, -.35541800E+04, 0.16176200E+04, 0.30040100E+03, -.48038300E+03, 0.46801200E+03, 0.94788200E+03, -.23198200E+04, -.60221300E+03, -.39481300E+03, 0.69440900E+02, 0.28239600E+04, -.24619700E+03, -.15264800E+03, -.15760200E+03, -.12302000E+04, 0.19744400E+03, -.42467300E+04 },
        { 0.36116600E+01, -.18383800E+00, -.10159700E+00, -.23052500E+01, 0.59790600E+00, -.92470800E+00, 0.27014400E+00, -.25963800E+00, -.10953700E+00, -.87591800E+00, 0.55941900E-01, -.34837700E-01, 0.60696700E-02, -.69173400E-02, -.39218500E+00, 0.75562000E-01, -.19487500E+00, -.15379600E+00, 0.10385300E+00, -.11429000E-02, 0.19437700E+00, -.89634700E-01, -.74231300E+00, -.57787200E+00, -.15597700E+00, 0.10442500E+00, 0.21192100E+00, -.18103300E+00, -.56432700E+00, 0.13050600E+01, -.33435700E+00, 0.11252400E+00, 0.33869600E-01, 0.54307900E+00, 0.17270300E+01, -.62558800E-01, 0.13283700E+00, -.76460900E+00, 0.44797900E-01, -.31014800E+00, 0.38227500E+00, 0.47706100E+00, 0.83819000E+00, -.98588500E+00, -.16106200E+00, 0.14793900E+00, -.38531500E+00, -.60243900E-02, 0.11854100E+04, -.18364500E+03, -.34937200E+02, 0.22379200E+03, -.94839700E+02, -.27279300E+03, -.65699200E+03, -.34350700E+04, 0.17570700E+04, 0.12090100E+04, 0.17177600E+04, 0.27082400E+03, 0.10113200E+04, -.14409900E+03, -.17701800E+04, 0.67661300E+03, 0.10340200E+04, 0.65743400E+03, -.22785300E+02, 0.12502900E+02, -.90304000E+01, 0.11386400E+02, -.38963000E+02, 0.22832200E+02, -.19602900E+02, -.29688100E+02, -.10687800E+01, 0.15066000E+02, 0.13120900E+02, -.11623900E+04, 0.60790300E+03, -.21802900E+03, 0.58117700E+03, 0.64119100E+02, -.42352300E+03, 0.26401100E+03, -.13956300E+03, 0.38765800E+03, -.37080300E+03, 0.69074100E+03, -.91133200E+04, 0.47741600E+04, -.48618300E+04, 0.45536800E+04, -.37335400E+03, -.26849000E+04, 0.22197200E+04, -.39400900E+03, 0.41627400E+04, -.21676900E+04, 0.33721600E+04, 0.78492800E+04, -.40624500E+04, 0.71445900E+04, -.39229700E+04, 0.80428600E+03, 0.39246700E+04, -.32704800E+04, -.13897600E+04, -.48949100E+04, 0.32626000E+04, -.25328400E+04, -.45190600E+03, 0.29746500E+03, 0.24260600E+03, 0.22615900E+03, 0.18213000E+03, 0.29653100E+03, -.10162900E+03, -.90919700E+02, 0.45156700E+03, 0.31554200E+03, -.12112000E+03, 0.30755800E+04, -.15586300E+04, -.10819300E+04, -.15377300E+04, -.49731900E+03, 0.92275700E+03, -.11383100E+04, -.66211800E+03, -.13218700E+04, 0.91991000E+03, -.61146200E+03, -.85884000E+03, 0.45180500E+03, 0.46803900E+03, 0.42984300E+03, -.46338000E+03, -.25301600E+02, 0.43392100E+03, 0.20617200E+03, 0.21382700E+03, 0.78966900E+02, 0.23024600E+03, 0.23063700E+03, -.11561100E+03, 0.68657800E+03, -.11539000E+03, 0.27967900E+03, -.44897600E+03, 0.34041600E+03, 0.67935100E+03, -.37022100E+03, -.34755400E+03, -.26683000E+03, 0.89522200E+04, -.45762100E+04, 0.69149300E+04, -.44727500E+04, 0.47840800E+03, 0.33406700E+04, -.28522100E+04, -.59109700E+03, -.48775100E+04, 0.27206600E+04, -.31178600E+04, -.19089000E+04, 0.93531700E+03, -.84178300E+01, 0.95433700E+03, 0.19048700E+03, -.53908800E+03, 0.80281500E+03, 0.28058200E+03, 0.93332600E+03, -.58940600E+03, 0.12279800E+04, 0.11432800E+04, -.65287000E+03, 0.69459500E+03, -.57155700E+03, 0.85078100E+03, -.39684700E+03, 0.14048900E+03, 0.70911400E+03, -.26411900E+03, -.30759500E+03, -.82220100E+03, 0.87546800E+03, -.37633400E+03, 0.41450800E+03, -.43781600E+03, 0.27416600E+03, 0.14831000E+03, -.47906700E+03, -.38976900E+03, -.37783100E+03, 0.26542500E+02, -.49485200E+03, 0.10720500E+04, -.57074500E+03, 0.23813300E+03, -.53623000E+03, 0.25341100E+03, 0.10497200E+03, -.85466100E+02, 0.28153200E+03, -.43809000E+03, 0.80364700E+02, -.60854500E+03, 0.12630900E+04, -.58571000E+03, -.39627500E+03, -.63150200E+03, 0.19945100E+03, 0.15767200E+03, -.57402700E+03, -.36376500E+03, -.57013600E+03, 0.73807100E+02, -.36463500E+03, -.98276600E+01, 0.34730000E+02, -.38801000E+03, 0.48800700E+01, -.79506800E+03, 0.36280300E+03, 0.51263700E+01, -.91343200E+03, 0.10121100E+03, 0.35297000E+03, -.27892400E+02, 0.36895800E+04, -.18885500E+04, -.88499000E+03, -.18449200E+04, -.53734500E+03, -.12061000E+04, 0.34852400E+03, 0.16942100E+04, -.12154500E+04, -.11322200E+04, -.10173500E+04, 0.23195600E+04, -.12715300E+04, 0.34438200E+04, -.11585100E+04, 0.53123400E+03, 0.21760100E+04, -.13991800E+04, -.73812200E+03, -.17423800E+04, 0.18121400E+04, -.54582900E+03, 0.21576100E+04, -.11382500E+04, 0.85581000E+03, -.10785400E+04, 0.87064000E+02, -.64632700E+03, 0.59752000E+03, 0.12574400E+04, -.60406700E+03, -.41221200E+03, -.14462100E+04, 0.57634100E+04, -.30247100E+04, 0.19343800E+04, -.28806000E+04, 0.72145200E+02, 0.13207800E+04, -.13758400E+04, 0.42585400E+02, -.26962700E+04, 0.10557000E+04, -.20833700E+04, 0.63210400E+02, 0.79286700E+02, -.22213200E+02, 0.29510000E+02, -.26942200E+02, -.88710000E+02, 0.93035500E+02, 0.57319600E+02, 0.88112400E+02, -.13501700E+02, 0.57997000E+03, 0.14349400E+03, -.13823500E+03, -.40483000E+03, -.53168900E+03, -.34601700E+03, -.50552700E+02, -.14385300E+03, 0.46570500E+02, -.11574100E+04, -.14339000E+02, 0.20346900E+02, 0.46348000E+03, -.23150400E+03, 0.29481500E+03, -.22533500E+03 },
        { 0.24018000E+02, -.65810300E+00, -.84984300E+00, 0.30194900E+01, 0.30785300E+01, -.50266000E+01, 0.35203300E+01, -.22941300E+01, 0.31223900E+00, -.34890600E+01, 0.41213000E+00, 0.54702600E+01, -.56957100E+00, 0.80512700E-01, 0.26199200E+01, -.15622900E+01, 0.25993700E+01, 0.25144900E+01, 0.22548800E+01, -.16397300E+01, 0.13151000E+01, -.31830300E+00, 0.33758000E+02, 0.25150800E+01, 0.34322200E+00, 0.34828700E+00, -.16890300E+01, 0.20502400E+00, 0.15950900E+00, 0.49882400E+00, -.14214100E+01, -.32795600E+01, -.17591200E-01, 0.32128100E+01, -.41431100E+01, -.18506800E+01, -.17335400E+00, -.36300900E+01, -.35242600E+00, -.17217800E+01, 0.18613600E+01, 0.49719400E+01, -.36189000E+00, -.29925600E+01, 0.24797200E+01, 0.22199500E+00, 0.13896900E+01, -.89602200E-01, -.15383600E+01, 0.67698600E+04, -.34589800E+04, -.14029400E+04, -.21569800E+04, 0.48096100E+04, 0.36201900E+04, -.17684900E+05, 0.87764500E+04, 0.15528000E+05, 0.88433000E+04, 0.36173300E+04, 0.60403100E+04, -.14578200E+04, -.18476000E+05, -.96717000E+04, 0.66329200E+04, 0.38260400E+04, 0.71357000E+03, -.35170600E+03, -.22154200E+02, -.35679100E+03, -.32608400E+02, 0.51681700E+02, -.24392200E+03, 0.79074200E+02, -.22064800E+03, 0.57876100E+01, -.31205200E+03, 0.22605800E+04, -.91774500E+03, -.18796500E+04, -.11305300E+04, -.20360500E+03, 0.21238000E+04, -.11845000E+04, 0.14096300E+04, -.12616100E+04, 0.13353800E+04, 0.32733100E+04, -.17633400E+06, 0.85389200E+05, 0.54648800E+05, 0.88164900E+05, 0.16538500E+05, -.14601200E+04, 0.18629900E+05, -.32114500E+05, 0.46476800E+05, -.15137400E+04, 0.68962300E+05, 0.10670900E+06, -.50467100E+05, -.34783000E+05, -.53348400E+05, 0.21261200E+04, 0.39910100E+05, -.37065000E+05, -.77921000E+04, -.58363600E+05, 0.34078100E+05, -.25451100E+05, -.60874000E+04, 0.31098200E+04, 0.79195700E+04, 0.30444200E+04, 0.29828000E+03, 0.10292000E+04, -.15940100E+03, -.59682800E+04, -.50516200E+04, 0.14755100E+04, -.10158500E+04, -.19001500E+05, 0.94893700E+04, 0.67126300E+04, 0.95009300E+04, 0.61253900E+04, -.50849100E+04, 0.50133800E+04, -.26571700E+04, 0.67447700E+04, -.36965800E+04, 0.30915900E+04, 0.15462200E+05, -.76917200E+04, -.75788000E+04, -.77256600E+04, -.19972000E+04, -.28176000E+04, -.93022900E+02, 0.47992500E+04, -.11123200E+04, -.23141600E+04, -.80424700E+04, 0.24823200E+04, -.11349100E+04, -.60700600E+04, -.12414300E+04, -.10499000E+04, -.41602300E+04, 0.35063800E+04, 0.77930300E+04, 0.78187400E+04, -.46192200E+04, -.20700000E+04, 0.15065900E+06, -.72381900E+05, -.51004900E+05, -.75321400E+05, -.86080500E+04, 0.23765200E+05, -.30271600E+05, 0.12636900E+05, -.54995000E+05, 0.19933900E+05, -.46194500E+05, 0.87430900E+04, -.44891700E+04, -.52371400E+04, -.43719400E+04, -.29313000E+04, -.18261700E+04, 0.10632400E+04, -.98316500E+03, -.69882200E+04, -.26607900E+04, 0.17358900E+04, 0.62428300E+04, -.28880600E+04, -.49739400E+04, -.31210000E+04, -.12026000E+03, -.25905100E+04, 0.29358700E+04, 0.53647400E+04, 0.39538200E+04, -.13205900E+04, -.68294300E+04, 0.97121500E+04, -.45318500E+04, 0.27894000E+04, -.48561600E+04, -.44354100E+04, 0.34704200E+04, -.25034600E+04, -.42390000E+04, -.29629200E+04, 0.34491500E+04, 0.95775400E+03, 0.28507000E+04, -.13619600E+04, -.12945600E+04, -.14255600E+04, 0.30043300E+04, -.29526200E+03, 0.41330000E+03, 0.20956400E+04, 0.18350200E+03, 0.31231900E+02, -.35746100E+04, 0.10568600E+05, -.51265300E+04, 0.38303000E+03, -.52838900E+04, -.49410500E+04, 0.28114400E+04, -.30005500E+04, -.19827000E+04, -.87175000E+03, 0.26200700E+04, 0.15512800E+04, -.21240200E+05, 0.10388700E+05, 0.16079100E+05, 0.10619800E+05, 0.50274900E+04, 0.34488800E+04, 0.17492400E+04, -.19758700E+05, -.18135400E+05, 0.45195900E+04, 0.27677000E+04, 0.14133300E+05, -.70541100E+04, -.69594300E+04, -.70670900E+04, -.22820800E+04, -.68982600E+04, 0.36456100E+04, 0.12352300E+05, 0.33169100E+04, -.62151100E+04, -.55237600E+04, 0.44040500E+05, -.20730100E+05, -.15320800E+05, -.22017500E+05, 0.21315100E+04, 0.20582500E+05, -.17876800E+05, -.47434900E+04, -.26058800E+05, 0.17428900E+05, -.94098600E+04, 0.20608000E+05, -.10073200E+05, -.22515900E+05, -.10302400E+05, -.23735400E+04, -.10308000E+05, 0.96276600E+04, 0.13682800E+05, 0.70861000E+04, -.94209500E+04, -.13397000E+05, 0.85964300E+05, -.41745400E+05, -.24743900E+05, -.42981400E+05, -.81086500E+04, 0.53541900E+03, -.85656700E+04, 0.12501200E+05, -.24871400E+05, 0.91713500E+03, -.34161900E+05, -.32727300E+03, 0.22489100E+03, -.26764100E+03, -.24636300E+03, 0.24897400E+03, 0.25370100E+03, 0.13308800E+04, -.43392600E+02, 0.56696700E+03, 0.35019000E+04, 0.98756200E+04, 0.54111900E+04, 0.29021700E+03, 0.10439000E+04, -.45734800E+04, -.77702100E+04, -.52052100E+03, 0.52952800E+03, -.12722400E+03, -.16068500E+05, 0.28352900E+03, -.24381000E+04, 0.41845400E+04, -.34037000E+04, 0.65224900E+03, 0.27676900E+04 },
        { -.21516100E+01, 0.64735500E-01, 0.82096400E-01, -.14928200E+00, -.10239000E+00, 0.22457900E+00, 0.55434700E+00, -.28896500E+00, -.27946100E+00, -.23858700E+00, -.21364600E-01, -.23755200E+00, 0.99461800E-02, 0.98946900E-02, -.39822200E-01, 0.69080700E-01, -.16523000E+00, 0.75086800E-03, -.25692300E+00, 0.57985600E+00, -.62821800E-01, -.15953300E-01, 0.83048100E+00, -.60087100E-01, 0.11775000E+00, 0.27452100E-01, 0.27581200E-01, 0.26068400E+00, 0.19172500E+00, 0.20815400E+00, 0.24540100E+00, -.43146600E-01, -.32383400E-01, 0.37600500E+00, -.49599000E+00, -.12394200E+00, -.31478400E-02, -.71913300E-01, 0.12869900E+00, -.30935500E+00, 0.11337900E+00, 0.48530100E+00, -.97665200E-01, -.34277600E+00, 0.61234300E+00, -.10390100E+00, 0.17438000E+00, -.48546800E-02, 0.10837000E+00, 0.58205500E-01, -.76076000E+03, -.16794300E+04, -.34484500E+03, 0.21495100E+03, -.28485700E+03, 0.59142000E+04, -.30049100E+04, -.29267800E+04, -.29571000E+04, -.13892700E+04, -.14642800E+04, -.10305300E+04, 0.18706100E+04, -.37886600E+03, -.14847100E+04, -.67001000E+03, 0.63302200E+02, -.31454700E+02, 0.10036500E+01, -.31651500E+02, -.18275200E+02, -.18074800E+02, 0.16014100E+02, 0.18913600E+02, -.19674000E+02, -.10901500E+02, -.18238200E+02, 0.11196100E+04, -.55010500E+03, 0.22978700E+01, -.55980400E+03, 0.44340900E+02, 0.40312200E+03, -.50333500E+03, -.41275300E+03, -.57229200E+03, 0.31788400E+03, -.46624800E+03, -.11387000E+05, 0.53919800E+04, 0.59986200E+04, 0.56932200E+04, 0.21569000E+03, 0.88243100E+03, 0.22944900E+04, -.37937100E+03, 0.47842900E+04, 0.65256200E+03, 0.43679800E+04, 0.16843400E+05, -.81430300E+04, -.97947600E+04, -.84216700E+04, -.12710700E+04, -.46256300E+03, -.34334700E+04, 0.21986200E+04, -.34251900E+04, -.73377200E+03, -.50120200E+04, 0.33753500E+04, -.17209000E+04, -.10937000E+04, -.16876700E+04, -.74024200E+03, -.69186200E+03, -.37657400E+03, 0.95812900E+03, -.60986200E+03, -.66876100E+03, -.82575100E+03, -.50575200E+03, 0.26390400E+03, 0.22000500E+04, 0.25287700E+03, 0.70645600E+03, -.86760300E+03, 0.91932400E+03, 0.17149400E+04, 0.82079000E+03, -.10404100E+04, -.12422200E+04, -.12444100E+04, 0.62283900E+03, 0.76626700E+02, 0.62182100E+03, 0.61212600E+02, 0.30491500E+03, 0.38690400E+03, 0.26185800E+03, 0.25770400E+03, 0.38730500E+03, 0.86666400E+03, -.24680800E+04, 0.12505400E+04, 0.83279900E+03, 0.12340400E+04, 0.10748800E+04, 0.45537000E+03, 0.73464000E+03, -.55300200E+03, -.42655500E+02, 0.62075700E+03, -.15718200E+03, 0.14572800E+05, -.70146600E+04, -.83406600E+04, -.72862500E+04, -.68597000E+03, -.42715300E+02, -.33264700E+04, 0.11221400E+04, -.42744000E+04, -.19760900E+03, -.46490000E+04, 0.40000000E+03, -.20544900E+03, 0.49062500E+02, -.20000100E+03, -.44286800E+03, 0.74023700E+03, -.10604000E+04, -.53753100E+03, 0.16106700E+03, 0.54311200E+03, 0.50551100E+03, -.78552000E+03, 0.45035000E+03, -.94732200E+03, 0.39275800E+03, 0.73176000E+03, 0.44676600E+03, -.15568500E+03, -.94650700E+02, 0.76985400E+01, 0.40062800E+03, -.22127700E+03, 0.10600800E+04, -.53029900E+03, -.19873800E+04, -.53004300E+03, 0.13513400E+03, -.31061700E+03, -.33340000E+03, -.29456300E+03, -.43781800E+03, -.33194800E+03, -.68681000E+03, -.74211300E+03, 0.38516600E+03, 0.93336600E+02, 0.37104400E+03, 0.18113700E+03, -.18606400E+03, 0.48851800E+02, -.26204200E+03, 0.82572700E+02, -.13054700E+03, 0.19874100E+03, 0.13774600E+03, -.70667000E+02, -.13413900E+04, -.68878200E+02, 0.22426000E+03, -.18272700E+03, -.26614500E+03, -.48761200E+03, -.50806000E+02, -.21549100E+03, -.53608300E+03, 0.43254900E+04, -.22196500E+04, -.20176500E+04, -.21627400E+04, -.10979900E+04, -.81009800E+03, -.13471000E+04, 0.16500000E+04, 0.11319800E+03, -.10025100E+04, 0.26704100E+03, -.58733700E+04, 0.29801100E+04, 0.21260000E+04, 0.29366800E+04, 0.14684700E+04, 0.12818100E+04, 0.98823100E+03, -.16261400E+04, 0.45310100E+03, 0.13894000E+04, 0.91403600E+03, 0.75996000E+04, -.36556200E+04, -.48558500E+04, -.37997500E+04, -.68080200E+03, -.59916800E+03, -.13837700E+04, 0.12226300E+04, -.12498800E+04, -.66909700E+03, -.22317600E+04, -.10762600E+04, 0.59499000E+03, 0.26779900E+03, 0.53812100E+03, 0.14297400E+04, 0.92992100E+03, -.51975900E+03, -.23400000E+01, -.14781500E+03, 0.94248800E+03, -.21465200E+03, 0.65551200E+04, -.31240300E+04, -.31232700E+04, -.32775100E+04, -.11170800E+03, -.44387100E+03, -.13811900E+04, 0.35350200E+03, -.24173600E+04, -.31012700E+03, -.26042100E+04, -.23560700E+02, 0.22790000E+01, 0.11538900E+03, 0.17101000E+02, -.78182400E+02, 0.49846600E+02, -.21798600E+03, 0.17158600E+02, -.11965200E+03, 0.11479000E+04, -.38379200E+03, -.41583400E+03, 0.22775300E+03, -.31554600E+03, 0.41734400E+01, 0.72551500E+03, 0.18446100E+03, 0.44761500E+02, -.45946700E+01, -.11881700E+04, 0.21926900E+02, 0.16087200E+03, -.27637500E+03, 0.41521500E+03, -.14287900E+02, 0.12126000E+04 },
        { 0.79248100E+00, -.14185400E-01, -.24138800E-01, 0.27430500E-01, 0.42737000E-01, -.39649000E-01, -.19352100E+00, 0.15186800E+00, 0.29781800E-01, -.31931300E-02, -.63220000E-02, -.68491200E-01, 0.68500100E-02, -.13049800E-03, 0.15471000E-01, -.19620700E-01, -.40645300E-01, -.41434900E-01, 0.66175400E-02, -.72808000E-01, -.39784900E-01, 0.46955500E-03, -.24150800E+00, -.40186500E-01, -.22761400E-01, -.66986200E-02, 0.19294900E-01, -.38121700E-01, 0.10386100E-02, -.50500800E-01, 0.28078900E-01, 0.11314300E+00, -.35709900E-02, -.53084300E-01, 0.69616500E-01, 0.32747800E-01, -.24291500E-01, 0.89554600E-01, -.57337500E-01, 0.12807900E+00, -.46330400E-01, -.13310500E+00, 0.12227400E+00, 0.47285700E-01, -.16419000E+00, 0.48927400E-01, 0.12000500E-01, 0.48788500E-02, -.70953200E-01, -.17781200E-01, -.45316000E-01, 0.23346600E+03, 0.13725400E+03, -.64119400E+02, -.80216000E+02, -.99639500E+03, 0.51485800E+03, 0.27942900E+03, 0.49811000E+03, 0.42935200E+03, 0.28208100E+03, 0.27585900E+03, -.41308900E+03, 0.20638500E+03, 0.33423600E+03, -.36188500E+03, 0.92702400E+01, -.45249700E+01, -.30056600E+01, -.46327200E+01, 0.22954700E+01, 0.90306700E+01, -.12287900E+02, -.83966900E+01, -.80465800E+01, 0.72384200E+01, -.50933800E+01, -.29637300E+03, 0.14952700E+03, 0.23118400E+02, 0.14819500E+03, -.11021400E+02, -.34506300E+02, 0.65875800E+02, 0.45213900E+02, 0.14367400E+03, -.48177000E+02, 0.24590100E+03, -.40695600E+04, 0.20643400E+04, 0.56487800E+03, 0.20359700E+04, 0.32230500E+03, -.33093100E+03, 0.42287900E+03, -.53636200E+03, 0.16931600E+04, -.44855200E+03, 0.17606400E+04, 0.21308500E+04, -.10833000E+04, 0.61677500E+02, -.10660900E+04, 0.83050900E+02, 0.79938300E+03, -.50332500E+03, -.20477000E+03, -.16931600E+04, 0.84580300E+03, -.90579800E+03, -.43423400E+03, 0.23321600E+03, 0.17906500E+03, 0.21703500E+03, 0.16873000E+03, 0.10247800E+03, 0.68379600E+02, -.16675800E+03, 0.92855700E+02, 0.13434200E+03, -.97601100E+02, 0.30319500E+03, -.15367600E+03, -.33972300E+03, -.15162100E+03, 0.78437800E+02, 0.17556600E+03, -.25115800E+03, -.38861500E+03, -.30200100E+03, 0.25113900E+03, 0.88109100E+02, 0.28410900E+03, -.14153000E+03, -.23806800E+02, -.14193800E+03, -.50277000E+02, -.68640100E+02, 0.40774000E+02, 0.87519100E+02, -.78579900E+02, -.55381800E+02, -.98171200E+02, 0.45747700E+03, -.22960200E+03, -.13758200E+03, -.22871000E+03, -.10142000E+03, -.16073900E+03, -.81238400E+02, 0.26821500E+03, -.15239400E+03, -.18499600E+03, 0.81683300E+00, 0.30243000E+04, -.15313900E+04, -.18965200E+03, -.15134700E+04, -.14411900E+03, 0.49926800E+03, -.40352100E+03, 0.18142800E+03, -.16723200E+04, 0.57444700E+03, -.12613700E+04, -.54631700E+03, 0.26744700E+03, 0.18793800E+03, 0.27320400E+03, -.15370300E+03, -.22533700E+03, 0.36959100E+03, 0.69284300E+02, 0.30754400E+03, -.24549100E+03, 0.29806700E+03, 0.23442100E+03, -.13177000E+03, -.16766200E+02, -.11724400E+03, -.10583000E+02, -.20116200E+03, 0.15028000E+03, 0.25507700E+03, 0.11161800E+02, -.15185600E+03, -.16846200E+03, 0.10658900E+03, -.39867200E+02, 0.10289300E+03, -.53262800E+02, 0.20567900E+02, 0.68073700E+02, 0.31269700E+02, 0.63330500E+02, -.13379300E+03, 0.54159900E+02, -.11079100E+03, 0.87063100E+02, -.48151900E+02, -.34265000E+01, -.43452500E+02, 0.76557100E+02, 0.88577500E+01, 0.59324300E+02, 0.10602900E+03, -.81277100E+01, 0.19300400E+02, -.83346300E+02, 0.27471400E+03, -.12983000E+03, 0.41965000E+02, -.13737500E+03, -.11176900E+03, 0.26974000E+02, -.43707100E+02, 0.89265000E+02, -.10402800E+03, 0.83414900E+01, 0.44530700E+00, -.18026400E+03, 0.10400100E+03, -.87574600E+02, 0.90146300E+02, 0.17849100E+03, 0.24027400E+02, 0.38493500E+03, -.24559600E+03, 0.87289500E+02, 0.10759800E+03, -.55182500E+03, 0.17112900E+04, -.86994500E+03, -.42421200E+03, -.85559400E+03, -.44849900E+03, -.45848000E+03, -.15281700E+03, 0.58693200E+03, -.39530700E+03, -.46331600E+03, -.19659900E+03, 0.10197700E+04, -.52102300E+03, -.83852100E+02, -.51038400E+03, 0.54650200E+02, 0.55617700E+03, -.36333500E+03, -.19639600E+03, -.82223400E+03, 0.54666100E+03, -.38513000E+03, 0.55315700E+03, -.28900400E+03, -.40442600E+03, -.27668600E+03, -.26404600E+02, -.29480700E+03, 0.30528900E+03, 0.37462100E+03, -.86369500E+02, -.24093800E+03, -.24565200E+03, 0.19834000E+04, -.10101500E+04, -.21802000E+03, -.99211700E+03, -.15530700E+03, 0.13559000E+03, -.15052700E+03, 0.23330400E+03, -.95832300E+03, 0.20633200E+03, -.87172700E+03, 0.86991500E+01, 0.98452100E+01, -.36936900E+02, -.68502300E+01, 0.32099100E+02, -.28470700E+02, 0.73821700E+02, -.11372600E+01, 0.48297000E+02, 0.78450800E+01, 0.35928000E+03, 0.16986000E+03, -.36286600E+02, -.18696400E+02, -.10693100E+03, -.29351800E+03, 0.92745400E+01, -.53498800E+01, 0.67049300E+00, -.45998100E+03, 0.17266800E+02, 0.26931800E+01, 0.16123900E+03, -.17183400E+03, 0.10172500E+03, 0.24280000E+02 },
        { 0.28266200E+01, -.13489300E+00, -.21449100E-03, 0.10564900E+01, 0.49484100E+00, -.93344100E+00, 0.24492000E+00, -.11255800E+01, 0.48108300E+01, -.15197700E+00, -.23428200E-01, 0.74567500E+00, -.75935400E-01, 0.90158700E-01, 0.36583600E+00, -.30135100E-01, 0.45276700E+00, 0.54542100E+00, 0.37852300E-01, -.27106200E+00, -.25902300E+00, -.57623000E-01, 0.13879200E+02, 0.10365900E+01, 0.11013200E-01, -.28924700E+00, 0.15632500E+00, -.60111000E+00, -.95398800E+00, -.64796500E+00, -.63906300E+00, 0.16935500E+01, 0.14121400E+00, 0.23871700E+00, 0.25337700E+01, -.35066400E+00, 0.37892900E-01, -.59608600E+00, 0.44855400E+00, -.24904800E+00, 0.73379700E+00, -.11403000E+01, 0.38399200E+00, -.97108500E+00, 0.13485300E+01, -.92985300E-01, 0.41396500E+00, -.77387300E-02, -.39266300E+00, -.57352100E-01, 0.13533300E+01, -.82126000E+01, 0.26242600E+04, -.47946600E+03, -.15247100E+04, -.36752500E+05, 0.18575300E+05, 0.19983000E+05, 0.18375700E+05, 0.86184000E+04, 0.75897800E+04, 0.23667100E+04, -.16904800E+05, -.18330800E+04, 0.83962300E+04, 0.67592800E+04, 0.18171100E+03, -.89265200E+02, 0.28359000E+02, -.90838500E+02, -.30062300E+02, 0.59369600E+02, -.15140300E+03, -.30329700E+02, -.72254700E+02, 0.44681800E+02, -.81824000E+02, -.18662200E+04, 0.96041200E+03, -.54393500E+01, 0.93313000E+03, -.69014100E+03, -.51806200E+03, 0.61882500E+03, 0.81723900E+03, 0.12984000E+04, -.61170300E+03, 0.29452000E+04, -.65923300E+05, 0.33057900E+05, 0.79144400E+04, 0.32970300E+05, 0.46121100E+04, -.24147100E+04, 0.57585500E+04, -.10570600E+05, 0.23170600E+05, -.35353800E+04, 0.26896700E+05, 0.41382900E+05, -.20663600E+05, 0.36692800E+04, -.20695400E+05, 0.96982400E+03, 0.13907200E+05, -.11044700E+05, -.50932200E+04, -.29426500E+05, 0.13224500E+05, -.13503900E+05, -.16642800E+05, 0.85063600E+04, 0.79284800E+04, 0.83209100E+04, 0.40756600E+04, 0.34538400E+04, 0.76840300E+03, -.60280600E+04, 0.12390000E+04, 0.36523800E+04, 0.33678600E+04, -.29375300E+04, 0.14595200E+04, 0.15581500E+04, 0.14686200E+04, 0.76393000E+03, -.11058600E+04, 0.62868800E+02, -.30093300E+04, -.88592700E+03, -.20454000E+03, 0.53719900E+03, 0.22769000E+04, -.11422600E+04, -.20291600E+04, -.11367500E+04, -.28785300E+03, 0.40776900E+03, 0.23934500E+03, 0.21709700E+04, -.30186100E+03, 0.23400100E+03, 0.24389800E+03, 0.95035800E+04, -.47499900E+04, -.56226900E+04, -.47516200E+04, -.24219900E+04, -.36776700E+04, 0.10208700E+04, 0.66948700E+04, 0.30859400E+04, -.40537300E+04, -.18613700E+04, 0.57604900E+05, -.28770100E+05, -.21561900E+04, -.28811000E+05, -.29370100E+04, 0.77846300E+04, -.83488900E+04, 0.34031100E+04, -.27299000E+05, 0.77460200E+04, -.20829900E+05, -.12542000E+04, 0.53085400E+03, -.21073100E+03, 0.62737500E+03, -.23458300E+04, -.13740400E+04, 0.20595700E+04, -.15119600E+04, -.16615300E+04, -.14767400E+04, 0.29139500E+04, 0.42683800E+04, -.22618100E+04, -.16908200E+04, -.21343800E+04, 0.56827500E+03, -.14849700E+04, 0.18351100E+04, 0.26475300E+04, 0.13858800E+03, -.10032100E+04, -.36141700E+04, -.14963900E+04, 0.94872200E+03, 0.34532400E+04, 0.74841600E+03, -.48788900E+02, 0.89016200E+02, 0.10217000E+04, -.17633400E+04, 0.66705900E+02, -.22427700E+03, 0.41183600E+03, 0.18030100E+04, -.93995100E+03, -.37197400E+03, -.90094200E+03, 0.13320600E+04, 0.69987000E+02, 0.45103000E+03, 0.13697900E+04, -.35746000E+03, 0.35160800E+03, -.17065400E+04, 0.12722400E+04, -.53180800E+03, 0.17994200E+03, -.63619000E+03, -.14518900E+04, -.47850500E+03, 0.83588000E+02, -.70773300E+03, 0.11203900E+04, -.92418600E+03, 0.79731700E+03, -.18044800E+05, 0.91632100E+04, 0.10226100E+05, 0.90224700E+04, 0.60136500E+04, 0.42541400E+04, 0.20610200E+04, -.12277400E+05, -.62216200E+04, 0.55181100E+04, -.21252600E+03, 0.41241100E+05, -.20783700E+05, -.19375400E+05, -.20620200E+05, -.80057100E+04, -.94615200E+04, -.90074300E+03, 0.16105300E+05, -.12645200E+04, -.93932500E+04, -.11527300E+05, 0.16459200E+05, -.82605400E+04, 0.10179200E+04, -.82329100E+04, 0.10421800E+04, 0.89098300E+04, -.64209400E+04, -.41988300E+04, -.13879700E+05, 0.81783800E+04, -.43264300E+04, 0.74469200E+04, -.38339400E+04, -.52924200E+04, -.37240100E+04, -.29958200E+02, -.29102400E+04, 0.47812700E+04, 0.56017400E+04, 0.11439800E+03, -.25350700E+04, -.45557300E+04, 0.32819600E+05, -.16504200E+05, -.29524100E+04, -.16412900E+05, -.24076700E+04, 0.66540200E+03, -.22044200E+04, 0.43671300E+04, -.13106600E+05, 0.13590000E+04, -.13551200E+05, -.34181800E+02, 0.23165200E+03, -.39801100E+03, -.10390000E+03, 0.22476000E+03, -.30943200E+03, 0.10718600E+04, 0.21550000E+02, 0.39761800E+03, 0.13386000E+04, 0.44534400E+04, 0.50920900E+04, -.21244400E+03, -.93585200E+03, -.26675900E+04, -.28923400E+04, -.21593500E+02, 0.59390800E+02, -.12894200E+03, -.68443500E+04, 0.41571100E+03, -.13544200E+04, 0.26550000E+04, -.21583300E+04, 0.34361200E+03, 0.11290700E+04 },
        { 0.65585500E+00, -.11916600E+00, 0.10188500E-02, -.11171900E+01, 0.15356600E+00, -.14526200E+01, 0.42676500E+00, -.16873800E+00, -.72817500E+00, -.83634800E+00, -.34810200E-02, 0.60000700E+00, 0.16329300E+00, -.28325500E-01, 0.15581700E+00, -.59358600E-01, -.52532300E+00, -.23536800E+00, 0.26399800E+00, -.31475800E+00, -.56275200E+00, 0.16865800E-01, -.17577900E+01, -.10338200E+00, -.34475400E-01, 0.36171600E-02, 0.12315100E-02, 0.74284100E-01, -.38730000E-01, -.38803000E+00, -.16354200E+00, 0.43751600E-02, 0.24382000E-01, -.10198400E-01, 0.58425100E+00, 0.24880300E+00, 0.54924600E-01, -.66564500E+00, 0.52100100E-01, 0.22892000E+00, 0.38395300E-01, 0.14458400E-01, 0.71267400E+00, -.11148000E+01, 0.18582200E+00, -.10023200E+00, 0.14312000E+00, -.38246000E-02, 0.74028400E+00, 0.10711300E+00, 0.94995100E+00, -.38352700E+01, 0.30355300E+00, 0.64999400E+03, 0.28784000E+03, -.80014700E+04, 0.40327700E+04, 0.19005000E+04, 0.40003500E+04, 0.86871100E+03, -.17676500E+03, 0.24116600E+04, 0.23606300E+03, 0.54421200E+04, 0.85185000E+02, 0.22209300E+04, -.13304500E+03, 0.65209500E+02, 0.62960400E+01, 0.66531400E+02, 0.28282100E+02, 0.30531100E+01, 0.65163900E+01, -.21763600E+02, 0.91449200E+01, 0.23505900E+02, 0.36670100E+02, -.11436900E+04, 0.52207400E+03, 0.22316500E+03, 0.57189500E+03, 0.67160100E+02, -.50373300E+03, 0.48590900E+03, 0.24151700E+03, 0.46425300E+03, -.29252100E+03, -.15295800E+03, 0.31155200E+05, -.15033400E+05, -.88802100E+04, -.15573400E+05, -.78551300E+03, 0.13668100E+04, -.64693100E+04, 0.27259700E+04, -.93923700E+04, 0.26211400E+03, -.98202200E+04, -.33851100E+05, 0.16349600E+05, 0.70287900E+04, 0.16922700E+05, 0.62434600E+03, -.63270500E+04, 0.11518400E+05, 0.24557100E+04, 0.15189500E+05, -.43197400E+04, 0.84732500E+04, -.26133600E+04, 0.13004200E+04, 0.10417900E+04, 0.13063300E+04, 0.26645100E+03, 0.18838100E+03, 0.65889800E+03, -.36775000E+03, 0.11493700E+04, 0.30564500E+03, 0.73353800E+03, -.35463900E+02, 0.19999300E+02, -.16428400E+04, 0.17632900E+02, -.14593900E+04, -.97325800E+02, -.21390400E+03, -.42203100E+03, -.51996900E+02, 0.58226800E+01, 0.14904800E+04, 0.39816600E+03, -.21179100E+03, 0.10305300E+04, -.19942400E+03, 0.21204100E+03, 0.46186400E+03, -.15975600E+03, 0.48082800E+02, -.46732400E+03, -.16617200E+03, 0.12046300E+03, 0.66254000E+04, -.33395400E+04, -.26652000E+04, -.33125800E+04, -.10870600E+04, -.19481800E+03, -.16594600E+04, 0.13299000E+03, -.24825500E+04, -.34881700E+03, -.13082300E+04, -.36636600E+05, 0.17710300E+05, 0.89935300E+04, 0.18313000E+05, 0.12635600E+04, -.47818900E+04, 0.10363200E+05, 0.18736200E+03, 0.13921300E+05, -.30633800E+04, 0.10240300E+05, 0.78251000E+03, -.36044600E+03, 0.16402300E+03, -.39106100E+03, -.49989500E+02, -.62096900E+03, 0.11621500E+04, 0.86497500E+03, 0.47395100E+03, -.30622000E+03, -.20162400E+04, 0.36979700E+03, -.23652500E+03, 0.21673500E+02, -.18505500E+03, -.23834500E+03, 0.58416900E+03, -.82430500E+03, -.13445200E+04, -.54358600E+03, 0.18757600E+03, 0.10683200E+04, -.32255200E+04, 0.15403200E+04, 0.83245800E+02, 0.16128800E+04, 0.63579600E+03, -.12252200E+04, 0.10474800E+04, 0.85825800E+03, 0.18013700E+04, -.91680400E+03, 0.79536700E+03, -.93974900E+03, 0.46117600E+03, 0.51297400E+03, 0.47016800E+03, -.53433100E+03, 0.15551100E+03, 0.77230100E+02, -.34254600E+03, 0.28486100E+03, 0.10984800E+03, 0.84096500E+03, -.19750800E+04, 0.94802600E+03, 0.46263300E+03, 0.98743600E+03, 0.67282000E+03, -.83901700E+03, 0.70956200E+03, 0.79685500E+03, 0.71906700E+03, -.60663400E+03, 0.53657400E+03, -.10578400E+05, 0.53591000E+04, 0.38810100E+04, 0.52892600E+04, 0.56074300E+03, 0.18980500E+03, 0.29481000E+04, -.58181700E+03, 0.50587200E+04, 0.24226200E+03, 0.30555400E+04, 0.75369500E+04, -.37889800E+04, -.24956500E+04, -.37682600E+04, -.12941200E+04, 0.89548600E+02, -.21910000E+04, -.41314600E+02, -.40567900E+04, -.42307700E+03, -.14726300E+04, -.12792600E+05, 0.61544900E+04, 0.21810700E+04, 0.63943100E+04, 0.78874800E+02, -.24481000E+04, 0.44987300E+04, 0.82915300E+03, 0.59435900E+04, -.14844000E+04, 0.28188900E+04, -.23598800E+04, 0.11237400E+04, 0.13500500E+04, 0.11794200E+04, -.81134000E+03, 0.73165000E+03, -.78823000E+00, -.14146800E+04, 0.59788400E+02, 0.21673500E+03, 0.26733400E+04, -.16046700E+05, 0.77853100E+04, 0.42653100E+04, 0.80218400E+04, 0.18999200E+03, -.12123900E+04, 0.38743500E+04, -.36890900E+03, 0.56012300E+04, -.72902100E+03, 0.50814000E+04, 0.84900300E+02, 0.50804600E+02, -.12330100E+03, -.55724200E+01, 0.10961700E+03, 0.29678400E+02, -.59968200E+03, -.12167700E+02, 0.13459500E+03, -.16502600E+04, -.19678700E+03, -.12409100E+04, -.19396300E+03, -.88217000E+02, 0.12222300E+04, -.36759100E+03, 0.31495200E+01, 0.53435300E+01, -.29312400E+03, 0.28378300E+04, 0.66319000E+02, 0.61225500E+03, -.10005300E+04, -.38847400E+03, -.50163100E+03, -.13422000E+04 },
        { 0.15049400E+01, -.52912400E-01, -.46408200E-01, 0.11322400E+00, 0.93040200E-01, -.26809100E+00, -.26434100E+00, 0.35718900E+00, 0.96041600E-01, -.19123000E+00, 0.91623100E-02, -.40433500E+00, -.89304700E-01, -.62787900E-02, 0.10105600E+00, 0.42077100E-02, -.13296300E+00, -.34323200E-01, -.76476700E-02, -.18774800E+00, -.21218300E+00, 0.24715400E-01, 0.97031000E+00, 0.23221900E+00, 0.10847300E+00, 0.72168000E-01, -.22672000E-01, 0.23861400E+00, 0.48891200E+00, 0.12837500E+00, -.18951300E+00, 0.93464300E-01, 0.81833200E-02, -.17925600E+00, -.22891500E+00, -.76419000E-02, -.21975100E-01, 0.93661100E-01, -.61813300E-01, -.34355500E-01, 0.13861700E+00, -.10523800E+00, -.13571200E+00, 0.20845100E+00, 0.18676600E+00, -.63869700E-01, -.81100800E-02, -.26321200E-03, -.12006200E+00, 0.15761900E-01, 0.40254500E+00, -.46314800E+00, -.62580300E-02, 0.18324100E-01, -.35899700E+03, -.41603000E+04, 0.20799500E+04, 0.26764300E+04, 0.20801200E+04, 0.20780200E+03, 0.57147300E+03, 0.63201300E+03, -.14017400E+04, 0.11732000E+04, 0.27541700E+03, 0.66170200E+03, 0.11568300E+01, -.41103400E+00, 0.15018700E+02, -.57749300E+00, -.74237000E+01, 0.38438500E+01, -.11693500E+02, -.58636000E+01, -.18619300E+01, 0.18895600E+01, -.31605400E+01, -.11800800E+03, 0.56867200E+02, -.13463900E+00, 0.59006700E+02, 0.39406600E+01, -.70370300E+02, 0.61459400E+02, 0.61540200E+02, -.24954600E+01, -.68568200E+02, 0.16331100E+03, -.16066200E+04, 0.92758100E+03, -.24037800E+04, 0.80378500E+03, 0.89351600E+03, 0.92570300E+03, -.31187400E+03, -.42974600E+03, 0.31528400E+03, 0.58929000E+03, 0.10023300E+04, -.30441400E+04, 0.14086700E+04, 0.40755200E+04, 0.15218100E+04, -.51136300E+01, 0.88202800E+02, 0.27102100E+03, -.12593900E+04, 0.32481100E+03, 0.18487700E+03, 0.62778200E+03, -.20727700E+04, 0.10473900E+04, 0.11503300E+04, 0.10363500E+04, 0.21857800E+03, 0.33225100E+03, 0.21566100E+03, -.65318400E+03, 0.45803900E+03, 0.26074600E+03, 0.40483900E+03, -.37629400E+03, 0.18581900E+03, 0.48163300E+03, 0.18813800E+03, -.40541700E+02, 0.57028300E+02, -.47082900E+02, -.32823200E+03, 0.59649900E+02, 0.69036700E+02, 0.73128400E+03, -.17141300E+02, 0.14317200E+02, -.19880600E+03, 0.87513400E+01, 0.66772000E+02, -.11356000E+03, 0.87229800E+02, 0.93705200E+02, 0.76294400E+02, -.35277900E+02, -.48906600E+02, -.15654300E+04, 0.78367000E+03, 0.70377400E+03, 0.78272500E+03, 0.62095200E+02, -.16769700E+03, 0.34270100E+03, -.20515700E+03, 0.32341000E+03, 0.11285900E+03, 0.84798600E+03, -.10060300E+04, 0.39283300E+03, 0.35319900E+04, 0.50250600E+03, -.34570700E+03, -.34270900E+03, 0.22354800E+03, -.61980400E+03, -.31301700E+02, -.13774800E+03, -.88297900E+02, -.88624700E+02, 0.39616200E+02, -.18815100E+03, 0.44329300E+02, 0.36196300E+02, 0.80728000E+01, 0.13963800E+03, 0.17104900E+02, -.30616800E+03, -.34366400E+02, 0.16025500E+03, -.23247600E+03, 0.93370700E+02, 0.22945100E+03, 0.11622500E+03, 0.54544000E+02, -.18479600E+03, 0.33929600E+03, 0.24705100E+03, 0.25745700E+03, -.88891300E+02, 0.11207800E+03, 0.35227700E+03, -.17312600E+03, 0.32277700E+03, -.17612600E+03, -.29177300E+03, 0.25637300E+03, -.24852700E+03, -.28672100E+03, -.64026500E+02, -.28696300E+02, 0.27557700E+03, 0.19071500E+03, -.10638500E+03, 0.10338400E+03, -.95327400E+02, -.48234800E+01, -.48364600E+02, 0.85296500E+02, 0.10143700E+03, -.66107800E+02, -.78989100E+01, -.93055900E+02, 0.69879100E+03, -.34239900E+03, -.33738800E+03, -.34940200E+03, -.31157500E+03, 0.20572100E+03, -.32939300E+03, -.23795600E+03, -.24867600E+03, -.17133800E+02, 0.19671200E+03, -.15886400E+04, 0.79735500E+03, 0.12416100E+04, 0.79432400E+03, -.49373700E+02, 0.43237100E+03, 0.25080700E+03, -.97806900E+03, 0.21385800E+03, 0.40001100E+02, -.10761500E+03, 0.50299300E+04, -.25120200E+04, -.26731100E+04, -.25149500E+04, -.48346600E+03, -.92313300E+03, -.47322500E+03, 0.15465600E+04, -.12548100E+04, -.64275300E+03, -.12872400E+04, -.20661200E+04, 0.97398900E+03, 0.20692000E+04, 0.10328700E+04, 0.21117000E+02, 0.15722400E+03, 0.17346200E+03, -.62581000E+03, 0.43181600E+03, 0.12561700E+03, 0.70132200E+03, -.62094100E+03, 0.29746300E+03, 0.44942000E+03, 0.31043100E+03, 0.17539500E+03, -.26155100E+03, 0.48706100E+03, 0.17315200E+03, 0.52313800E+03, -.77046600E+02, 0.28190700E+03, 0.10772700E+04, -.60124000E+03, 0.10776100E+04, -.53878900E+03, -.49187800E+03, -.48549000E+03, 0.14294200E+03, 0.19030200E+03, -.31642900E+03, -.31252100E+03, -.61840400E+03, 0.47700800E+00, 0.11824400E+01, -.93576400E+01, -.87054900E+01, 0.30088700E+01, -.35112200E+01, -.99335700E+02, 0.91503000E+01, 0.19497500E+02, -.31362900E+03, 0.55990700E+03, -.13057100E+03, -.17819500E+02, 0.72849500E+02, -.34173300E+03, -.51293700E+03, -.48841200E+02, -.89298500E+01, 0.52048300E+02, -.21652800E+03, -.28393800E+02, -.41698400E+02, -.26435700E+02, -.42732600E+03, 0.15949900E+03, -.32451100E+03 },
        { 0.73824000E+01, -.79755900E-01, -.26289600E+00, 0.11213500E+00, 0.76487900E+00, -.25502000E+00, -.16921600E+01, 0.10556800E+01, -.36576600E-01, 0.13392300E+00, -.30607800E-01, 0.69892900E+00, 0.52284600E-01, 0.24981800E-02, 0.19856200E-02, -.44341300E-01, 0.57717000E+00, -.63899800E-01, 0.68101800E+00, -.82194600E+00, 0.80358700E-01, -.88280400E-04, -.14031000E+01, -.19347500E+00, -.11418800E+00, -.27723600E-01, 0.13204300E+00, -.38760900E+00, -.63141100E+00, 0.25077600E-02, 0.36822300E-01, -.68452400E+00, 0.20633700E-01, 0.25641900E+00, 0.12119500E+01, 0.25856000E-01, 0.78807800E-01, 0.94071300E+00, -.30885300E+00, 0.10607400E+00, 0.10361100E+00, 0.14116300E+01, -.99790900E-01, -.32489900E-01, -.14556000E+00, 0.98645300E-01, -.18053300E+00, -.76415100E-02, 0.19881100E+00, 0.12101500E-01, 0.67288800E+00, -.14486400E+01, 0.22851400E+00, -.41380500E-01, -.27651600E+01, -.42968600E+05, 0.21479800E+05, 0.19961400E+05, 0.21484400E+05, 0.53946600E+04, 0.82197000E+04, 0.34363900E+04, -.16371300E+05, 0.19524300E+04, 0.74510600E+04, 0.15343500E+05, -.31222100E+03, 0.15474400E+03, 0.88409700E+02, 0.15610600E+03, 0.31304400E+02, 0.27033900E+02, -.21699200E+02, -.32443100E+02, 0.78351300E+02, 0.24369100E+02, 0.13349600E+03, -.16416800E+04, 0.76367100E+03, 0.37109900E+03, 0.82083700E+03, -.60566300E+02, -.11473100E+04, 0.71587100E+03, 0.36142000E+03, 0.55973800E+03, -.94668700E+03, 0.36273500E+03, 0.53752400E+05, -.26093500E+05, -.26866700E+05, -.26878000E+05, -.22219200E+04, 0.39809200E+04, -.11658200E+05, 0.14111000E+04, -.21847300E+05, 0.36243400E+04, -.20356800E+05, -.52732400E+05, 0.25562000E+05, 0.29689400E+05, 0.26367100E+05, 0.18897900E+04, -.66125600E+04, 0.13160300E+05, -.39410200E+04, 0.18884600E+05, -.54032600E+04, 0.16101900E+05, -.14174900E+05, 0.70681000E+04, 0.64863200E+04, 0.70875700E+04, 0.18210800E+04, 0.29539200E+04, 0.10836100E+04, -.52793400E+04, 0.48046500E+03, 0.27237400E+04, 0.48439800E+04, -.58261900E+04, 0.29143600E+04, 0.33410000E+04, 0.29131300E+04, -.32362200E+04, -.10533700E+04, 0.12422400E+04, -.12072000E+04, 0.24366200E+04, -.79097800E+03, 0.38783100E+04, -.54824100E+03, 0.26454200E+03, 0.12067300E+04, 0.27455400E+03, 0.88623500E+03, 0.21819800E+03, 0.15601000E+03, 0.76733800E+02, -.78931800E+03, 0.10169600E+03, 0.19512900E+03, 0.50914200E+04, -.25727900E+04, -.10233300E+04, -.25457500E+04, -.34448200E+04, -.33153200E+04, 0.39266400E+02, 0.29187400E+04, 0.33634300E+04, -.32078000E+04, 0.60789800E+03, -.51295400E+05, 0.24846200E+05, 0.28401800E+05, 0.25649700E+05, 0.19206800E+04, -.65389300E+04, 0.12509300E+05, -.25503100E+04, 0.20171400E+05, -.54393800E+04, 0.16680700E+05, 0.39744100E+04, -.19511900E+04, -.35670800E+04, -.19872700E+04, 0.90579900E+03, -.87691600E+03, 0.17861700E+04, 0.18295800E+04, -.31561100E+04, -.54387300E+03, -.30933800E+04, 0.41106800E+03, -.25471800E+03, 0.10069000E+04, -.20549200E+03, -.93741800E+03, 0.69873900E+02, 0.14850100E+03, -.12297200E+04, 0.50434200E+03, -.89196100E+02, 0.12956800E+04, -.67478100E+04, 0.32737300E+04, 0.25615900E+04, 0.33738500E+04, -.78103300E+03, 0.29433500E+03, 0.40177200E+03, -.28449200E+04, 0.39592100E+04, -.24527900E+03, 0.39780300E+04, 0.10058200E+04, -.52123700E+03, 0.59488000E+03, -.50304300E+03, -.77407300E+03, 0.30209600E+03, 0.13751000E+03, 0.21241000E+03, -.33688200E+03, 0.29808100E+03, -.50297600E+02, -.22781200E+04, 0.10912200E+04, -.24199800E+03, 0.11390800E+04, -.61042000E+03, 0.40884200E+03, -.28915700E+03, -.19966300E+04, 0.14241700E+04, 0.35204600E+02, 0.15769600E+04, -.27112700E+05, 0.13600000E+05, 0.12442500E+05, 0.13556300E+05, 0.42165200E+04, 0.67731000E+04, 0.29180100E+04, -.12208000E+05, -.45950500E+04, 0.64599100E+04, 0.71694000E+04, 0.34396600E+05, -.17179800E+05, -.15542100E+05, -.17198400E+05, -.49463500E+04, -.67376900E+04, -.27752000E+04, 0.12574100E+05, -.23324100E+04, -.62330100E+04, -.11693400E+05, -.28522000E+05, 0.13889400E+05, 0.15525400E+05, 0.14261800E+05, 0.11539800E+04, -.29760500E+04, 0.71162900E+04, -.16386500E+04, 0.97735600E+04, -.26827100E+04, 0.95238000E+04, -.29954700E+02, -.33003500E+02, 0.44312100E+04, 0.15095500E+02, -.33266100E+04, -.20473100E+04, 0.25399900E+04, 0.31544900E+03, 0.17226800E+04, -.19944000E+04, 0.16368500E+04, -.26832900E+05, 0.13066700E+05, 0.12817700E+05, 0.13417200E+05, 0.70529700E+03, -.22289200E+04, 0.61999000E+04, -.77998400E+03, 0.11682800E+05, -.21102800E+04, 0.10054400E+05, 0.13707500E+03, 0.20021600E+03, -.17058400E+03, -.29309000E+02, 0.13157900E+03, -.83545200E+02, 0.49334200E+03, -.59038000E+01, 0.20613100E+03, -.25569200E+04, -.11153400E+04, 0.17395300E+04, -.35064400E+03, 0.20572100E+03, -.17481700E+04, 0.54829200E+03, -.62735900E+03, -.11956000E+01, -.19791700E+03, 0.47119300E+04, 0.47214000E+02, -.14441600E+04, 0.11518300E+04, -.66793600E+03, -.19265300E+03, -.28019700E+04 },
        { -.18479300E+02, 0.82680300E+00, 0.39378500E+00, -.19075500E+01, -.13161100E+01, 0.32802300E+01, -.17048100E+01, 0.12191200E+01, -.39594900E+00, 0.25278700E+01, -.16019400E+00, -.36738600E+01, 0.20259700E+01, 0.20209500E+00, -.86295300E+00, 0.68812200E+00, -.11135800E+01, -.32092300E+00, -.14323900E+01, -.14227400E+00, -.94365600E+00, -.37624500E+00, 0.78875300E+00, 0.40641900E+00, -.37534900E+00, 0.30403600E-01, 0.73463700E+00, 0.16954700E+00, -.58491900E+00, -.13411300E+00, 0.80083300E-01, 0.17366300E+00, -.63724500E-02, -.27321100E+00, 0.55876400E+01, 0.15554400E+00, 0.64912800E-01, 0.51225200E+01, -.79464000E+00, 0.18518200E+01, -.37765900E-01, -.20590500E+01, 0.12747000E+00, 0.32044800E+01, 0.16287500E+00, -.64486400E+00, -.79071000E+00, -.12159500E-01, -.48353500E+00, -.21785900E+00, 0.24827200E+01, 0.10929400E+02, 0.78616400E-01, -.31203100E+00, 0.72575100E+00, 0.11810000E+01, -.12746800E+04, -.24814300E+04, 0.15435200E+01, -.35548700E+04, -.29985300E+04, 0.77102300E+03, 0.59537800E+04, 0.52788500E+04, -.33088300E+04, 0.35340500E+04, -.22498800E+03, 0.11725100E+03, -.20369100E+02, 0.11245600E+03, -.12868200E+03, -.33377700E+02, 0.97956600E+02, -.20378600E+02, 0.76161000E+02, -.39638600E+01, 0.10389900E+03, -.46704100E+03, 0.47372300E+03, 0.25580000E+02, 0.23334500E+03, 0.22754300E+01, -.14662000E+04, 0.77394400E+03, 0.22346400E+03, 0.70835400E+03, -.98867800E+03, -.14660300E+04, 0.27800000E+05, -.19493000E+05, -.13775500E+05, -.13918600E+05, 0.13443200E+05, 0.30817900E+04, 0.38756900E+04, 0.17193400E+05, -.76058200E+04, 0.41239000E+04, -.11927600E+05, -.11980000E+06, 0.65119200E+05, 0.35396400E+05, 0.59911800E+05, 0.24788100E+04, 0.21730300E+04, 0.88505300E+04, -.23811400E+05, 0.45822400E+05, -.89367200E+03, 0.49367400E+05, 0.33514400E+03, -.10780300E+04, 0.35408700E+04, -.16615100E+03, -.32458000E+04, -.89616900E+03, -.16590600E+03, -.31779600E+03, -.54331200E+03, -.11455700E+04, 0.73696000E+03, 0.37432000E+04, -.17577200E+04, -.89724500E+04, -.18712000E+04, -.30402400E+04, 0.21875500E+04, -.18410600E+04, -.11462600E+04, -.16713900E+04, 0.15798000E+04, 0.15087400E+04, -.28408200E+04, 0.15304600E+04, 0.34448000E+04, 0.14192700E+04, 0.70299500E+03, -.99278900E+03, 0.90048000E+03, -.98498900E+03, 0.85041100E+03, -.71431700E+03, -.94355300E+03, 0.20692400E+05, -.10036900E+05, -.72796000E+04, -.10346700E+05, -.22446400E+04, -.59376400E+03, -.30989900E+04, 0.22958200E+04, -.44281300E+04, -.42409800E+03, -.83915600E+04, -.99878200E+05, 0.55144900E+05, 0.34471700E+05, 0.49961200E+05, -.38340200E+03, 0.13885000E+04, 0.50331600E+04, -.23987600E+05, 0.35245400E+05, -.10206600E+04, 0.40923100E+05, 0.20275800E+04, -.10059000E+04, 0.91330800E+03, -.10145800E+04, 0.31316800E+04, 0.33923700E+03, -.15875800E+04, 0.32110800E+03, -.19584000E+03, 0.25174200E+03, -.33867800E+04, -.33206000E+04, 0.27751700E+04, 0.41206700E+04, 0.16609200E+04, 0.14146000E+03, 0.14352500E+04, -.14848700E+04, -.28026600E+04, -.24088700E+03, 0.40175100E+03, 0.37560000E+04, -.38754700E+04, 0.17372900E+04, 0.60383900E+03, 0.19372300E+04, -.63865200E+03, -.25885600E+04, 0.10629900E+04, 0.21989100E+04, 0.41438300E+04, -.19144900E+04, 0.13451100E+04, 0.87390900E+04, -.41338200E+04, -.32239900E+04, -.43708100E+04, -.16100400E+04, -.87187500E+03, -.15497500E+04, 0.44801900E+03, -.28154700E+04, -.85140800E+03, -.30173900E+04, -.35723100E+04, 0.17106200E+04, 0.17969100E+04, 0.17865400E+04, 0.59276300E+03, -.15296700E+04, 0.14701800E+04, 0.18222600E+04, 0.31080800E+04, -.10982000E+04, 0.39984500E+03, -.19137900E+05, 0.82087600E+04, 0.79798000E+04, 0.95686500E+04, 0.23244200E+03, 0.88677600E+03, 0.10800500E+04, -.11409000E+03, 0.80291500E+04, 0.32784400E+02, 0.11006200E+05, -.13281600E+04, 0.17596800E+04, -.91885900E+03, 0.66319100E+03, 0.20363700E+04, 0.32221600E+04, -.12843300E+04, -.46707700E+04, -.17883600E+04, 0.30115600E+04, -.10061000E+04, -.50817900E+05, 0.27997900E+05, 0.16134100E+05, 0.25417200E+05, 0.58241500E+03, 0.10939500E+04, 0.32865000E+04, -.11064800E+05, 0.19770500E+05, -.17529800E+03, 0.20072500E+05, -.43972200E+04, 0.33477800E+04, 0.52377700E+04, 0.22006300E+04, -.10589800E+03, 0.12836600E+04, -.22872600E+04, -.55872800E+04, -.15696000E+04, 0.73437100E+03, 0.30582100E+04, -.74711500E+04, 0.65464300E+04, 0.22453200E+04, 0.37422500E+04, -.82672100E+04, -.27585500E+04, -.22947100E+04, -.69179100E+04, 0.19703900E+04, -.30823800E+04, 0.40655500E+04, 0.54630300E+02, -.10244300E+03, 0.14729900E+03, 0.15426400E+03, -.19137800E+03, 0.16204000E+03, -.14040300E+04, 0.10085000E+03, -.31586700E+03, -.11366900E+05, 0.78242700E+04, -.42900200E+04, -.37337100E+03, 0.79801000E+03, 0.24773800E+04, -.11585400E+05, -.14301800E+03, -.42330900E+03, -.79486300E+03, 0.52682200E+04, -.60527300E+02, 0.79117800E+03, -.30391800E+04, -.51492200E+04, -.13428300E+03, -.10373200E+05 },
        { 0.36303600E+01, -.16764700E+00, -.68949400E-01, 0.21035800E+00, 0.16628700E+00, -.62604100E+00, 0.31837900E+00, -.40237200E+00, 0.33643700E+00, -.53316200E+00, -.18976000E-01, 0.50701300E+00, -.55596500E+00, -.45461600E-01, -.11426600E+00, -.62476000E-01, 0.25562800E-01, -.12382600E+00, 0.29945600E+00, 0.22767000E+00, -.69164900E-01, 0.24166900E+00, -.45285700E+01, -.49626300E+00, 0.40532200E-01, -.38776900E-01, -.13460600E+00, 0.33274500E-01, 0.14630000E+00, -.89117400E-01, 0.23274100E+00, 0.28334200E+00, -.18187500E-01, -.33602400E+00, 0.26790500E+01, 0.21320300E-01, 0.10192600E+00, 0.20113500E+00, 0.19503700E+00, -.16977400E-01, -.36203400E+00, 0.58831100E+00, 0.17454900E+00, -.71758200E+00, 0.39993700E-01, -.99340200E-01, -.11583000E+00, -.95390300E-02, 0.52903700E+00, -.93481200E-01, -.23549900E+00, -.13099800E+01, -.67553000E-01, 0.60427200E-02, -.16824700E+01, 0.37879100E+00, -.68055400E-01, 0.31032000E+04, 0.73797700E-01, 0.75879800E+03, -.52504800E+03, 0.11374700E+03, 0.43191900E+03, -.16783800E+03, -.63856300E+03, -.19563800E+04, 0.28006600E+03, -.13864800E+03, -.25226900E+02, -.14003200E+03, -.18635300E+02, 0.12591700E+01, -.37006100E+02, 0.31981400E+02, -.77940000E+02, -.19794800E+01, -.12978900E+03, 0.10614600E+04, -.48607500E+03, -.28417400E+03, -.53076300E+03, -.26343800E+02, 0.69017400E+03, -.28238300E+03, 0.26600500E+03, -.38388700E+03, 0.49488500E+03, 0.24542800E+03, -.42865200E+05, 0.20959600E+05, 0.14307100E+05, 0.21433100E+05, 0.46103900E+04, -.15152700E+03, 0.70072800E+04, -.28185900E+04, 0.14514300E+05, -.99005300E+03, 0.17465000E+05, 0.21872000E+05, -.10430500E+05, -.81403000E+04, -.10935400E+05, -.43417700E+03, 0.61325000E+04, -.72550500E+04, -.15832100E+04, -.10644500E+05, 0.54759900E+04, -.67659400E+04, -.99330000E+03, 0.54355000E+03, 0.13886400E+04, 0.49670800E+03, 0.30882600E+03, -.33629000E+02, -.23179200E+02, -.34463500E+03, -.12600900E+03, 0.40876100E+01, -.49437900E+03, 0.33608200E+04, -.16862600E+04, -.32050900E+04, -.16803900E+04, 0.15639800E+04, 0.50235700E+03, -.12848900E+04, -.93211400E+03, -.14944600E+04, 0.67728400E+03, -.49807200E+03, -.36295000E+01, 0.20001700E+02, -.10366000E+04, 0.22906900E+01, -.40697300E+03, 0.43214000E+02, 0.41402200E+02, 0.12583100E+03, 0.72904400E+03, -.17640900E+02, -.53368900E+03, -.14138100E+04, 0.72973500E+03, -.11963700E+04, 0.70688200E+03, 0.47595100E+03, 0.41465700E+03, 0.67598100E+03, -.55879800E+02, 0.68595800E+03, 0.61541000E+03, 0.38719100E+03, 0.29508800E+05, -.14235500E+05, -.10467600E+05, -.14754000E+05, -.21345200E+04, 0.39765900E+04, -.69093300E+04, 0.59472600E+03, -.11708700E+05, 0.37309800E+04, -.10347700E+05, 0.38482500E+03, -.22766500E+03, 0.93664100E+03, -.19244400E+03, -.55735100E+03, 0.81649600E+02, -.76451800E+03, -.88307300E+03, -.99310200E+03, 0.11391300E+01, 0.50378200E+03, -.38781000E+03, 0.19874900E+03, -.54219400E+03, 0.19394800E+03, 0.48297500E+03, -.63417800E+03, 0.89547600E+03, 0.15464600E+04, 0.91534500E+03, -.30259200E+03, -.77890400E+03, 0.22019900E+04, -.10158700E+04, 0.10602200E+04, -.11009900E+04, 0.10054600E+02, -.63509200E+02, 0.20190200E+03, 0.11467500E+04, -.64435300E+03, -.26913400E+03, -.43588700E+03, -.76772900E+03, 0.42031300E+03, -.53285300E+03, 0.38389000E+03, 0.45483700E+03, -.57245100E+03, 0.30711900E+03, -.58346600E+00, 0.36408900E+03, -.36984000E+03, 0.46753200E+02, 0.19592000E+04, -.92996800E+03, 0.57741700E+03, -.97954500E+03, -.40016600E+03, -.20921000E+03, 0.93501100E+02, 0.12457500E+04, -.86253100E+01, -.45723000E+03, 0.48806700E+03, -.72354400E+03, 0.32874400E+03, 0.27262600E+04, 0.36173800E+03, 0.99405800E+03, -.27336700E+03, -.41324500E+03, -.23686700E+03, -.67911400E+03, -.60844300E+03, -.76566300E+03, 0.20557100E+04, -.10357100E+04, -.29571400E+04, -.10278900E+04, -.68064000E+03, -.26666300E+03, 0.30937500E+03, 0.42897200E+03, -.20837000E+03, -.86776800E+02, 0.25221000E+03, 0.12590100E+05, -.60843400E+04, -.48904100E+04, -.62949800E+04, -.25203000E+03, 0.35704600E+04, -.46265000E+04, -.16697100E+04, -.60389400E+04, 0.33099100E+04, -.40794300E+04, 0.46465200E+03, -.21331600E+03, -.42569400E+04, -.23214700E+03, 0.16671800E+04, 0.40097200E+03, -.13110900E+03, 0.22777800E+03, 0.88907300E+03, 0.60116000E+03, -.11730900E+04, 0.21594400E+05, -.10598900E+05, -.67275500E+04, -.10797400E+05, -.22743900E+04, -.15344500E+03, -.32362800E+04, 0.16800700E+04, -.75210600E+04, 0.27746500E+03, -.88886600E+04, -.14741400E+03, -.14048600E+03, 0.32589400E+01, -.30682700E+02, 0.25467800E+02, -.36087700E+02, -.17744100E+03, -.83979500E+00, -.19186100E+02, 0.10575900E+04, 0.21955400E+04, 0.51322200E+03, 0.89019900E+02, -.37302900E+03, -.12203500E+03, -.17648400E+04, -.18565900E+02, -.10402000E+02, 0.32192000E+02, -.42306300E+04, -.10083800E+02, -.14012300E+03, -.19905800E+03, -.40506000E+03, -.54908000E+02, 0.10106900E+04 },
        { -.22751600E+01, 0.12020800E+00, 0.10962800E+00, -.26793700E+00, -.33683800E+00, 0.14865800E+01, -.10845400E+01, 0.95095500E+00, 0.44727600E+00, 0.74144100E+00, -.49184300E-01, -.50216900E+00, 0.18895800E+00, 0.49974100E-01, -.43211700E+00, 0.27374500E+00, 0.53510100E+00, 0.11043600E+00, -.89736400E-01, -.35924500E+00, 0.22335000E+00, -.83620300E-01, -.37842200E+01, -.11786900E+00, -.32009300E+00, -.84514700E-01, 0.78051300E-01, -.45719100E-01, -.34304600E-01, -.13346700E+01, 0.85206600E-01, 0.33152000E+00, -.60817800E-01, 0.31072700E-01, -.19033600E+01, -.44837700E-01, -.27405200E+00, 0.67441800E+00, -.66136500E-01, 0.26625600E+00, -.38314500E-02, -.93132500E+00, -.48902900E+00, 0.76538800E+00, -.25991100E+00, -.13538400E+00, -.10800400E+00, 0.52278100E-01, 0.88288000E+00, -.64911000E-01, 0.71919100E+00, -.40958900E+01, 0.13509900E+00, 0.37206500E+00, 0.22298400E+01, 0.90297200E-01, -.44863700E-01, -.47508400E+00, -.14866800E+01, 0.20089700E+04, 0.52795800E+03, -.14239500E+04, -.34204100E+03, -.26631300E+04, 0.12979200E+04, -.59295500E+03, 0.14124800E+03, -.69814800E+02, -.45058100E+02, -.70581700E+02, -.23531000E+02, -.25690900E+01, -.28034700E+02, 0.11452500E+02, -.44707700E+02, 0.87289500E+01, -.67133800E+02, -.27056400E+03, 0.17092300E+03, 0.69037400E+03, 0.13540500E+03, -.17426000E+03, -.22518800E+03, 0.33353600E+03, 0.36373100E+03, 0.13370700E+03, -.22814300E+03, 0.54190600E+02, -.18440300E+05, 0.85947900E+04, 0.13460700E+05, 0.92405500E+04, 0.16707700E+04, -.78350100E+04, 0.77545500E+04, 0.36578500E+04, 0.88737300E+04, -.71753100E+04, 0.63135500E+04, 0.26019500E+04, -.62783200E+03, -.12777100E+05, -.13123600E+04, 0.23513300E+04, 0.96284200E+04, -.57019600E+04, -.42717800E+04, -.44738300E+04, 0.89559200E+04, 0.14297500E+04, 0.27458600E+04, -.13591400E+04, -.21489800E+03, -.13743300E+04, -.26182500E+03, -.33394900E+03, -.65862600E+03, 0.33551500E+03, -.13932900E+04, -.10617800E+03, -.94332700E+03, 0.15714100E+04, -.78913500E+03, -.23187000E+04, -.78610500E+03, 0.11149000E+04, -.58059100E+03, -.22429400E+03, -.34558600E+03, -.51829500E+03, -.37866300E+03, -.12475600E+04, -.32732300E+03, 0.17123100E+03, -.42254700E+03, 0.16397800E+03, -.65012000E+03, 0.59858900E+03, -.29901800E+03, -.43285200E+03, 0.25151700E+03, 0.22927700E+03, 0.12815500E+04, 0.85694000E+04, -.42700000E+04, -.44207200E+04, -.42842200E+04, -.13702300E+04, -.55733900E+03, -.45319100E+03, 0.22304200E+04, -.12448000E+03, -.14100400E+04, -.28680200E+04, 0.41670600E+04, -.14442100E+04, -.12025700E+05, -.21062400E+04, 0.17034700E+04, 0.98986000E+04, -.62012500E+04, -.47123600E+04, -.51851300E+04, 0.90949300E+04, 0.61088900E+03, 0.10100400E+04, -.52521000E+03, 0.50316900E+03, -.50424700E+03, -.22295300E+03, -.94091900E+03, 0.17870600E+03, -.12317900E+03, -.53017600E+03, -.73153300E+03, -.10339700E+04, -.41746200E+03, 0.23882000E+03, -.83757700E+03, 0.20815900E+03, -.75620600E+02, -.25921500E+02, 0.32024300E+03, 0.54037200E+03, 0.76697000E+03, -.34121700E+03, 0.45289100E+02, -.25985700E+04, 0.13588100E+04, 0.43746200E+03, 0.12998400E+04, 0.66584900E+03, -.11376600E+04, 0.15543100E+04, 0.12561900E+04, 0.16701900E+04, -.46339200E+03, -.11485300E+04, 0.16962700E+04, -.81870000E+03, -.72526500E+03, -.84675200E+03, 0.20282200E+03, 0.16876100E+03, -.34269100E+03, 0.35952900E+03, -.27534200E+03, 0.66600100E+01, -.80212000E+03, -.26517800E+04, 0.13543800E+04, 0.71063000E+03, 0.13255900E+04, 0.45485200E+03, -.11679800E+04, 0.15050800E+04, 0.13085800E+04, 0.22173800E+04, -.71392000E+03, -.35919100E+03, -.76964400E+04, 0.38206500E+04, 0.37515000E+04, 0.38484500E+04, 0.28400000E+04, 0.92273900E+03, -.11922200E+03, -.17433500E+04, -.15335300E+04, 0.19503900E+04, 0.29042600E+04, -.56450100E+04, 0.28126500E+04, 0.93349500E+03, 0.28233800E+04, -.76476900E+03, 0.74743000E+03, 0.17258400E+04, -.12533900E+04, 0.29763600E+04, 0.52363200E+02, 0.27198800E+04, 0.61156500E+04, -.27378700E+04, -.76528800E+04, -.30664300E+04, 0.80981000E+03, 0.45403900E+04, -.38299900E+04, -.22816200E+04, -.39446900E+04, 0.44283400E+04, -.17354000E+04, 0.41244200E+04, -.20314100E+04, -.30936800E+04, -.20640000E+04, -.30539700E+03, 0.64595100E+02, -.38300400E+03, 0.33040700E+03, -.57419100E+03, -.56666500E+03, -.10331400E+04, 0.83505900E+04, -.38934200E+04, -.63721100E+04, -.41826400E+04, -.11326400E+04, 0.33733100E+04, -.32208000E+04, -.14680000E+04, -.39550300E+04, 0.31390000E+04, -.30695100E+04, -.13111400E+03, -.53558700E+02, -.71499800E+02, -.28754700E+02, 0.98262600E+02, -.10548200E+03, 0.41163700E+03, -.93839100E+01, -.46173500E+01, -.16676400E+04, 0.25526500E+04, 0.15510500E+04, 0.17001200E+03, -.63635500E+03, 0.47830200E+03, -.34918600E+04, -.81210900E+02, 0.48205300E+02, -.37695700E+03, -.12269900E+04, 0.23147100E+03, -.40891100E+03, 0.59659500E+03, -.21402200E+03, -.49664400E+03, -.16899400E+04 },
        { 0.30252600E+02, -.63750000E+00, -.12455500E+01, 0.55687100E+01, 0.30289400E+01, -.54429500E+01, 0.12865600E+01, -.46698900E+00, -.47428800E+00, -.45455700E+01, 0.36736600E+00, 0.33111700E+01, -.53518000E+00, -.15342500E+00, 0.18544800E+01, -.12974600E+01, 0.12487900E+01, 0.87962000E+00, 0.13008000E+01, -.28184500E+01, -.32351300E+00, -.38235800E+00, 0.58990900E+01, 0.16938300E+01, -.68944500E+00, 0.70364000E+00, -.20855700E+01, -.37456000E+00, -.10785400E+01, -.88945200E+00, -.84784700E+00, -.11892500E+01, -.19271000E-01, -.79474800E+00, 0.10175600E+01, 0.56818000E+00, 0.14823300E+00, 0.82411900E+00, -.28900700E+00, 0.18586300E+01, -.12884300E+01, -.20368900E+01, 0.28499700E+00, 0.21573700E+01, -.21177300E+01, 0.22725500E+00, 0.33990900E+00, 0.64255100E+00, 0.43510500E+00, -.48117900E-01, 0.51536700E+00, 0.34157300E+01, -.64030300E+00, -.93233700E+00, 0.43359700E+01, 0.30419800E+00, -.77237000E-01, -.45004500E+00, -.43324900E+01, 0.12101200E+05, 0.18125400E+04, -.66483500E+04, -.13553700E+04, -.14200700E+05, 0.60395000E+04, -.10080100E+04, 0.87472400E+03, -.43430600E+03, -.23293500E+03, -.43725600E+03, 0.25108300E+02, -.13943300E+02, -.14455500E+03, 0.11553700E+03, -.30091100E+03, 0.46979900E+02, -.42688600E+03, 0.24204300E+03, 0.76008900E+02, 0.36322800E+04, -.12018900E+03, -.15883200E+04, -.11546100E+03, 0.10875300E+04, 0.17632200E+04, 0.17728100E+03, -.37583700E+03, 0.70791900E+03, -.10825700E+06, 0.49691200E+05, 0.98798000E+05, 0.54164200E+05, 0.75183100E+04, -.40356500E+05, 0.36825300E+05, 0.72639900E+04, 0.47167600E+05, -.38963600E+05, 0.38951200E+05, 0.28834100E+05, -.99017400E+04, -.98062700E+05, -.14439700E+05, 0.10744300E+05, 0.47577200E+05, -.24640200E+05, -.78582500E+04, -.23433900E+05, 0.45218300E+05, 0.16592600E+04, 0.80970800E+04, -.40924400E+04, 0.55242300E+03, -.40510000E+04, 0.23153500E+03, -.79821200E+03, -.31216200E+04, 0.21202000E+03, -.67659700E+04, 0.35148100E+03, -.20282500E+04, 0.84044700E+04, -.41771000E+04, -.13957000E+05, -.42043000E+04, 0.69650600E+04, -.41299800E+04, -.12559400E+04, -.30677100E+04, -.36951900E+04, -.14662000E+04, -.99094800E+04, -.36367700E+04, 0.17926300E+04, -.12520600E+04, 0.18292500E+04, -.34757000E+04, 0.37389800E+04, -.16477000E+04, -.20074800E+04, 0.20443100E+04, 0.95710600E+03, 0.96940100E+04, 0.59949800E+05, -.29884800E+05, -.33862500E+05, -.29973700E+05, -.89623000E+04, -.43773900E+04, -.47364000E+04, 0.16348200E+05, -.21525400E+04, -.95014600E+04, -.21942100E+05, 0.36144700E+05, -.13772400E+05, -.95152700E+05, -.18116800E+05, 0.68213200E+04, 0.47617600E+05, -.25596700E+05, -.85504500E+04, -.25422000E+05, 0.44812100E+05, -.26831600E+04, 0.72989700E+04, -.37678500E+04, 0.35776400E+04, -.36464300E+04, -.40088200E+04, -.52373100E+04, 0.13207600E+04, -.13779600E+04, -.29352200E+04, -.43449400E+04, -.39043300E+04, -.12905000E+04, 0.10434100E+04, -.89450400E+04, 0.64034500E+03, -.22100200E+04, -.19317900E+03, 0.11704200E+04, 0.28890900E+04, 0.37437100E+04, -.12657300E+04, -.99420700E+03, -.17509200E+05, 0.90882800E+04, 0.24894500E+04, 0.87539100E+04, 0.40705800E+04, -.67193400E+04, 0.10221300E+05, 0.76090400E+04, 0.10587500E+05, -.25021100E+04, -.52661800E+04, 0.53400200E+04, -.24156700E+04, -.48524600E+04, -.26682100E+04, 0.15313100E+04, 0.10341200E+04, -.16116800E+04, 0.14138600E+04, -.53113100E+03, 0.59488000E+03, -.29339100E+04, -.18507500E+05, 0.93637200E+04, 0.68197600E+04, 0.92492800E+04, 0.30807500E+04, -.71272700E+04, 0.99406600E+04, 0.78367100E+04, 0.13871200E+05, -.41653300E+04, -.14902400E+04, -.57292100E+05, 0.28449100E+05, 0.28043800E+05, 0.28651300E+05, 0.18241400E+05, 0.59533500E+04, 0.26532200E+04, -.14102100E+05, -.81180000E+04, 0.12079600E+05, 0.22946100E+05, -.31424600E+05, 0.15664000E+05, 0.59590900E+04, 0.15710600E+05, -.42363500E+04, 0.46361000E+04, 0.89596300E+04, -.70619300E+04, 0.15722900E+05, 0.97011500E+03, 0.12674000E+05, 0.47225600E+05, -.21388400E+05, -.57834700E+05, -.23628800E+05, 0.34703500E+04, 0.23773200E+05, -.20129600E+05, -.57684400E+04, -.24311700E+05, 0.23839900E+05, -.15071400E+05, 0.28686900E+05, -.14022800E+05, -.27053300E+05, -.14351900E+05, -.37759700E+04, -.44516100E+02, -.30984500E+04, 0.32033500E+04, -.48917600E+04, -.34458400E+04, -.78004200E+04, 0.47222400E+05, -.21523100E+05, -.46084100E+05, -.23621000E+05, -.48172200E+04, 0.16619100E+05, -.13912600E+05, -.13204800E+04, -.19643900E+05, 0.16485400E+05, -.18251100E+05, -.79621600E+03, -.32314100E+03, -.56874800E+03, -.26759800E+03, 0.82055100E+03, -.82643900E+03, 0.18170200E+04, -.21911000E+03, 0.10002700E+03, -.53123800E+04, 0.11477700E+05, 0.89740000E+04, 0.75583200E+03, -.35992900E+04, 0.29884000E+04, -.16007000E+05, -.64392300E+02, 0.68734000E+03, -.23244500E+04, -.75354200E+04, 0.15398700E+04, -.21775900E+04, 0.26938900E+04, 0.55995600E+03, -.37724400E+04, -.47308400E+04 },
        { 0.52829000E+01, -.12260400E+00, -.21104500E+00, -.43718200E+00, 0.82727500E+00, -.17645000E+01, 0.56762500E+00, -.76554500E+00, 0.93114700E+00, -.18801500E+01, -.51121000E-02, 0.95190900E-01, 0.39534600E+00, 0.12131600E+00, 0.23450900E+00, -.12033800E+00, 0.47910500E-01, -.32937400E-01, 0.32446200E+00, -.11150300E+01, -.82923300E+00, -.66805500E-01, 0.44371200E+01, 0.57149500E+00, -.14457700E+00, -.12214700E+00, 0.21534700E+00, -.33678200E+00, -.18638500E+01, -.15597900E+01, -.10084200E+01, -.80325600E+00, 0.12215200E+00, -.69156000E+00, 0.21846400E+01, 0.52432800E+00, 0.55673400E-01, 0.52371300E+00, -.12115400E+00, 0.11115600E+01, -.41055900E+00, -.16837700E+01, 0.23165800E+00, 0.65492800E+00, -.46710000E+00, 0.59189100E-01, -.94163000E-01, -.16078000E-01, 0.10742400E+01, -.66694800E-01, 0.15027000E+01, -.63399400E+01, -.51575400E-02, 0.24697700E+00, 0.27243300E+01, 0.77875800E-01, -.77452100E-01, -.82385400E+00, -.33514500E-01, 0.66926500E-01, -.34298700E+04, 0.30331300E+04, 0.23342200E+04, 0.46671300E+04, -.30351300E+04, -.57696400E+04, 0.10546000E+03, -.52039800E+02, -.26935100E+02, -.52731200E+02, 0.18828100E+02, 0.20094200E+02, -.31522000E+02, 0.10960000E+02, -.42101700E+02, 0.23571900E+02, -.52432300E+02, 0.90795800E+03, -.42163100E+03, -.11137500E+03, -.45408600E+03, -.32679000E+03, 0.33898300E+03, -.22021600E+03, 0.40016300E+03, -.43041500E+03, 0.26680000E+03, 0.37931700E+03, -.21906300E+05, 0.10325200E+05, 0.12147400E+05, 0.10953800E+05, 0.20522800E+04, -.57941200E+03, 0.32203700E+04, -.10865500E+04, 0.77247300E+04, -.20548100E+04, 0.92221800E+04, 0.71714700E+04, -.29737300E+04, -.63367500E+04, -.35842700E+04, -.26869400E+03, 0.21260200E+04, -.14132800E+04, -.10844900E+04, -.55751200E+04, 0.28530300E+04, -.46676600E+04, -.78942600E+04, 0.39479200E+04, 0.31243800E+04, 0.39472700E+04, 0.16267700E+04, 0.51439800E+03, 0.96150200E+03, -.19921300E+04, 0.18704900E+04, 0.47119300E+03, 0.11306900E+04, 0.50798300E+03, -.24434900E+03, -.22243700E+04, -.25386300E+03, 0.74850500E+03, -.41963900E+03, -.35634700E+03, -.88733800E+03, -.10792000E+04, 0.16339200E+03, 0.41025500E+03, 0.15135000E+04, -.76146700E+03, -.83395300E+03, -.75671600E+03, -.57539000E+03, 0.22779200E+03, -.24875700E+03, 0.47529500E+03, 0.51800300E+03, -.13643000E+03, -.38048600E+03, 0.11847200E+05, -.59014500E+04, -.61621700E+04, -.59236700E+04, -.64911200E+03, 0.18275900E+03, -.22115800E+04, 0.26340300E+04, -.27977400E+04, 0.25533700E+03, -.25451100E+04, 0.13462500E+05, -.61268100E+04, -.89268300E+04, -.67297300E+04, -.16184100E+04, 0.68743200E+03, -.13421100E+04, 0.85481300E+03, -.59413100E+04, 0.16409800E+04, -.64132600E+04, 0.13076300E+04, -.68696300E+03, 0.64721900E+03, -.65400400E+03, -.76824500E+03, -.53770500E+03, 0.15262700E+03, -.71624400E+03, -.44024400E+03, -.72297200E+03, -.83269800E+03, 0.87020700E+03, -.36844800E+03, -.66662200E+03, -.43474700E+03, -.14484400E+03, -.48737800E+03, 0.47374800E+03, 0.87051100E+03, 0.25441400E+03, -.26166600E+03, -.49788300E+03, -.52036500E+03, 0.32959000E+03, 0.42055500E+03, 0.26030300E+03, 0.17644700E+02, -.10548300E+04, 0.11693300E+04, 0.97498700E+03, 0.92900800E+03, -.68128700E+03, -.85871000E+02, -.69022400E+03, 0.39352300E+03, -.48207500E+03, 0.34517300E+03, 0.26590300E+03, -.24916500E+03, 0.21118200E+03, 0.16962600E+02, 0.36325000E+03, -.23704500E+02, 0.25042100E+03, 0.23988400E+03, -.92837200E+02, 0.39757200E+03, -.11956500E+03, -.30469000E+03, -.94879400E+03, 0.70644600E+03, 0.11033600E+04, 0.94069000E+03, -.76173200E+03, 0.64609600E+03, -.15970100E+05, 0.79472500E+04, 0.77613400E+04, 0.79846600E+04, 0.18565900E+04, -.10272300E+04, 0.38118800E+04, -.34007100E+04, 0.39737300E+04, -.11802300E+04, 0.11144400E+04, 0.22364800E+04, -.11208100E+04, -.14405500E+04, -.11181100E+04, -.49387800E+03, 0.19441000E+04, -.19831900E+04, -.12607900E+04, -.36282500E+04, 0.16216800E+04, 0.36762400E+04, 0.78381900E+04, -.36258300E+04, -.48651100E+04, -.39187100E+04, -.21131900E+03, 0.18539600E+04, -.23459300E+04, -.12817800E+04, -.43996900E+04, 0.22237700E+04, -.39896800E+04, 0.42816400E+04, -.20830500E+04, -.37347400E+04, -.21400800E+04, -.12570300E+03, -.25350300E+03, -.16253000E+03, 0.50074500E+03, -.72773800E+03, -.20181300E+03, -.16064200E+04, 0.93217400E+04, -.43639000E+04, -.50731800E+04, -.46613100E+04, -.84140100E+03, 0.11424400E+02, -.90740200E+03, 0.72531900E+03, -.34394700E+04, 0.80926900E+03, -.40995500E+04, -.34237500E+02, 0.84216000E+01, -.12501400E+03, -.25664100E+02, 0.14062000E+03, -.13649700E+03, -.11309600E+04, -.23523400E+02, 0.10530700E+03, 0.76041600E+03, 0.13474700E+04, -.80046900E+03, -.35762500E+02, -.61280400E+03, 0.10252600E+04, -.11096100E+04, 0.92416500E+02, 0.13087400E+02, -.31586600E+03, -.20579900E+04, 0.18647000E+03, 0.67363700E+03, -.16144100E+04, 0.49635700E+02, -.36029400E+03, 0.69466500E+03 },
        { -.10024300E+02, 0.43469100E-01, 0.39656600E+00, -.87279400E+00, -.12889100E+01, 0.49976700E+00, 0.66542000E+00, -.10560300E+00, -.13571100E+01, 0.48724100E+00, -.80906700E-01, 0.10909200E+01, 0.20790800E-01, -.55875400E-01, -.13875300E+00, 0.55276700E-01, -.42090300E+00, -.15634700E+00, 0.19107100E+00, 0.51023800E+00, -.27025800E+00, 0.12902200E+00, -.27556300E+01, -.59458600E+00, 0.15699000E+00, 0.31037600E-01, 0.16718500E+00, 0.35394900E+00, 0.15015000E-01, -.54232500E+00, 0.28459100E+00, 0.50238100E+00, -.51215400E-01, 0.35132300E-01, 0.14599800E+01, 0.28452600E+00, -.17554300E-01, -.16570800E+00, -.24601400E+00, 0.94694400E+00, -.30170500E+00, 0.30709600E+00, 0.60598400E+00, 0.60195800E+00, -.58380800E+00, -.14199600E+00, -.33130500E-01, 0.12257200E-03, -.50741400E+00, 0.51589900E-01, 0.57357300E+00, 0.32220000E+01, 0.24461100E+00, 0.10833900E+00, -.98440000E+00, 0.46699600E+00, 0.12974500E+00, 0.20860300E+00, -.13188900E+00, -.18133300E+00, -.23819200E+00, -.23827700E+04, 0.20761400E+03, -.30552100E+04, 0.37084100E+03, 0.26456800E+04, 0.18132700E+03, -.89899900E+02, -.63824100E+02, -.90646600E+02, -.40413200E+02, -.31854100E+02, 0.79943000E+01, 0.33119000E+02, -.41715200E+02, -.14953400E+02, -.63038600E+02, 0.10263400E+04, -.48158200E+03, 0.56145900E+02, -.51302800E+03, -.24483600E+03, -.63729100E+02, -.44403000E+02, 0.46916800E+02, -.34396600E+03, -.14246300E+03, -.30039500E+03, -.24205100E+05, 0.11671200E+05, 0.19511600E+05, 0.12108100E+05, 0.26575400E+03, -.84534700E+04, 0.10619700E+05, 0.45721400E+04, 0.11393600E+05, -.78617400E+04, 0.71017700E+04, 0.21717700E+05, -.10381100E+05, -.24259800E+05, -.10862500E+05, 0.19371600E+03, 0.71266000E+04, -.84503500E+04, -.84037100E+02, -.57068400E+04, 0.64206400E+04, -.41349900E+04, 0.28175000E+04, -.13732600E+04, -.41915600E+03, -.14091600E+04, -.80123500E+03, -.57545600E+03, -.91722100E+03, 0.46239000E+03, -.18344700E+04, -.48679700E+03, 0.18065300E+03, 0.17475900E+04, -.87877100E+03, -.17254600E+04, -.87413700E+03, 0.20817500E+04, -.75254100E+03, 0.16460700E+03, 0.76415000E+03, 0.37876300E+02, -.49989100E+03, -.34213800E+04, -.68845400E+03, 0.35714700E+03, -.68139800E+02, 0.34566200E+03, -.54603300E+03, 0.71937400E+03, -.69141600E+03, -.13946700E+04, -.48198400E+03, 0.41967000E+03, 0.19739200E+04, 0.12984500E+05, -.64813000E+04, -.70353200E+04, -.64920700E+04, -.55309700E+03, -.11425000E+04, -.25356800E+03, 0.39833600E+04, 0.18870900E+03, -.17939900E+04, -.64224700E+04, 0.18005600E+05, -.85516400E+04, -.21419900E+05, -.90100100E+04, 0.90405600E+03, 0.87287100E+04, -.89895800E+04, -.24856300E+04, -.70181800E+04, 0.78812300E+04, -.31087300E+04, 0.29606300E+04, -.14913900E+04, -.34445500E+01, -.14798100E+04, -.39859600E+03, 0.17655200E+03, -.16014500E+04, -.34558900E+03, -.17365900E+04, 0.12473200E+03, -.62757600E+03, -.24777800E+04, 0.12460100E+04, -.56060600E+03, 0.12380800E+04, 0.37159500E+03, 0.22215300E+03, 0.41824500E+03, 0.58212700E+03, 0.11679900E+04, -.98752000E+01, 0.11683300E+03, -.37245500E+04, 0.19085000E+04, 0.19574600E+03, 0.18621500E+04, 0.54264500E+03, -.17960200E+04, 0.21262300E+04, 0.17806900E+04, 0.34816600E+04, -.10744600E+04, -.13481600E+04, 0.12502500E+04, -.60637400E+03, -.85625700E+03, -.62483900E+03, 0.41594300E+03, 0.31538000E+03, -.64109100E+03, -.50589000E+02, -.50445500E+03, 0.17057700E+03, -.72982200E+03, -.40191900E+04, 0.20352900E+04, 0.11145400E+04, 0.20088500E+04, 0.71207900E+03, -.16482500E+04, 0.21122400E+04, 0.16096300E+04, 0.36313900E+04, -.10969800E+04, -.10134700E+04, -.16042400E+05, 0.80044300E+04, 0.81812900E+04, 0.80220600E+04, 0.20686600E+04, 0.23736000E+04, -.10162900E+04, -.41672200E+04, -.26999800E+04, 0.29317700E+04, 0.96231300E+04, -.10922300E+05, 0.54481900E+04, 0.33701700E+04, 0.54608800E+04, 0.16889800E+04, 0.21326200E+04, 0.28190000E+04, -.26425300E+04, 0.35846800E+04, 0.17592700E+04, 0.21175800E+04, 0.15969000E+05, -.77545300E+04, -.13318600E+05, -.79871100E+04, -.27748400E+03, 0.31770900E+04, -.51912400E+04, -.20042000E+03, -.47472800E+04, 0.31544800E+04, -.48499100E+04, 0.41943400E+04, -.20839500E+04, -.38746700E+04, -.20985800E+04, 0.51605800E+03, 0.63949200E+03, -.18145200E+04, -.67058500E+03, -.13634700E+04, 0.61465500E+02, -.17158700E+04, 0.12138300E+05, -.58821600E+04, -.98639200E+04, -.60707000E+04, -.55947200E+03, 0.34648800E+04, -.48471900E+04, -.16143200E+04, -.45324300E+04, 0.32880900E+04, -.38669100E+04, -.18464600E+03, -.14862100E+03, 0.48248400E+02, 0.30765700E+01, 0.12170500E+02, -.43453600E+02, 0.69536700E+02, -.97907600E+00, -.14860700E+03, -.41545800E+03, 0.18520100E+04, 0.84317400E+03, 0.30894100E+03, -.32990500E+03, 0.21032100E+03, -.22441600E+04, -.14530200E+03, 0.25841200E+02, -.53752500E+03, -.14611400E+04, 0.24320700E+03, -.68129900E+03, -.17558500E+02, 0.37292900E+03, -.41997800E+03, -.60876400E+03 },
        { -.79916800E+01, 0.82832900E-01, 0.29943000E+00, -.12846300E+00, -.86120300E+00, 0.25051800E+00, 0.53952700E+00, -.34310900E+00, 0.41942400E-01, 0.13829600E+00, 0.12828700E-01, 0.14707300E+01, 0.16303100E-01, 0.53795000E-01, -.14089000E+00, -.17470200E-01, 0.12688200E+01, 0.57273000E+00, -.38419000E-01, 0.39972000E+00, 0.48239000E+00, 0.42301700E-01, 0.40213400E+01, -.21444100E+00, -.36427800E-01, -.10242800E+00, 0.15784800E-01, -.13041900E+00, -.81942300E+00, -.61654200E+00, -.60388200E+00, -.13064000E+01, 0.33423200E-01, 0.20379800E+00, -.15264900E+01, -.27005900E+00, -.19444800E+00, -.42349200E-03, 0.40265700E-01, -.38824500E+00, -.18364700E-01, 0.11210400E+01, -.65390000E+00, -.74586500E+00, 0.10581000E+01, -.50697900E-01, -.11512000E+00, 0.12606500E-01, 0.49159800E+00, -.10854300E+00, 0.78450900E-01, -.63740400E+00, -.15271500E+00, 0.88782700E-01, -.48090700E+00, 0.21034700E+00, -.45639200E-01, 0.11754200E+01, 0.34500500E+00, 0.17871800E-01, -.36193800E+00, 0.92569500E-01, -.21379800E+04, -.13155700E+04, 0.23413700E+03, -.31844400E+04, -.10983300E+03, 0.54902000E+02, 0.45961800E+02, 0.54911200E+02, -.64516300E+01, 0.92833100E+01, -.12149000E+02, -.23136800E+02, 0.37636400E+02, 0.59580900E+01, 0.68789000E+02, 0.51852400E+03, -.25493600E+03, 0.24497000E+03, -.25931700E+03, 0.35255800E+02, 0.47454000E+02, -.25203500E+03, -.19210900E+03, -.31487800E+03, -.10643100E+02, -.24094200E+03, 0.84878700E+04, -.43013000E+04, -.24463100E+04, -.42454800E+04, -.16351500E+04, -.15944700E+04, 0.11662000E+04, 0.36128800E+04, -.23787200E+04, -.96052700E+03, -.51713400E+04, -.31233200E+04, 0.16069000E+04, 0.25722400E+04, 0.15629400E+04, 0.55070000E+03, 0.60453500E+03, -.21229100E+04, -.54665000E+04, -.24614200E+04, 0.63413300E+03, 0.35223200E+03, -.41254900E+03, 0.17851500E+03, 0.14835300E+02, 0.20641100E+03, 0.15990100E+03, 0.10385700E+03, -.18254700E+02, -.67465700E+03, -.18261800E+03, 0.23954100E+02, -.64776500E+03, -.24543200E+04, 0.12280400E+04, 0.44574400E+04, 0.12272800E+04, 0.22415700E+03, -.52574500E+03, 0.94480600E+03, 0.85791500E+03, 0.74379800E+03, -.83786200E+03, 0.26736700E+03, 0.15903900E+04, -.80127100E+03, -.88914700E+03, -.79554300E+03, -.21124400E+03, -.88306400E+02, -.56283000E+03, -.44306100E+03, -.55284200E+03, 0.69082700E+02, -.17402000E+03, -.81134700E+03, 0.40617100E+03, 0.94908100E+03, 0.40560500E+03, -.61850100E+03, -.16095800E+03, 0.86025100E+02, 0.79644200E+03, 0.93638300E+03, -.25198500E+03, 0.23789600E+04, -.29735300E+04, 0.15360100E+04, 0.19530600E+04, 0.14890900E+04, 0.41204600E+03, 0.49296100E+03, -.18733400E+04, -.46224900E+04, -.10287800E+04, 0.35869100E+03, 0.14589700E+04, -.84859100E+03, 0.42127600E+03, -.89818500E+03, 0.42412200E+03, 0.58908400E+03, -.20793000E+03, 0.71456600E+03, -.16140700E+03, -.16101700E+03, -.25469400E+03, -.89326500E+02, -.48575100E+03, 0.26519500E+03, -.23697200E+03, 0.24316100E+03, -.42960300E+03, -.62456900E+02, 0.60519000E+03, 0.38892500E+03, 0.39841700E+03, -.17481700E+03, 0.54661700E+03, -.73521000E+03, 0.37395200E+03, -.30363900E+03, 0.36765600E+03, -.32194000E+03, 0.36552600E+02, -.20808600E+03, -.13126100E+04, 0.13546900E+03, -.87383000E+01, -.35406300E+03, 0.17373100E+04, -.90585400E+03, -.18716500E+03, -.86873400E+03, -.45269700E+02, 0.33843100E+03, -.32371300E+03, 0.21952000E+03, -.57555300E+03, 0.22962900E+03, -.67585900E+03, 0.59812400E+02, -.30704400E+02, -.12424200E+04, -.29637900E+02, -.24365600E+03, -.37855700E+02, -.35714000E+03, -.11724300E+04, -.18307900E+03, 0.44392400E+02, -.48984800E+03, 0.11314100E+03, -.64494000E+02, -.12439600E+03, -.56876800E+02, 0.29016500E+03, -.88746200E+02, 0.34055200E+03, -.21697600E+04, -.18836800E+04, 0.16170700E+03, -.39427600E+04, -.18964700E+04, 0.94895200E+03, 0.87900300E+03, 0.94833400E+03, 0.83992000E+02, 0.31796800E+03, 0.14639500E+03, 0.11107900E+04, 0.14143400E+04, 0.25167400E+03, 0.31166000E+04, -.33379100E+04, 0.16977600E+04, 0.18594700E+04, 0.16697700E+04, 0.51748800E+03, -.92442100E+02, -.26918000E+03, -.20230500E+04, -.47837400E+03, -.79512800E+02, 0.68407200E+03, 0.35000700E+04, -.17358400E+04, 0.68923300E+03, -.17495200E+04, -.12795800E+04, -.11685300E+04, 0.32537600E+03, 0.75864600E+03, -.95702000E+03, -.12075700E+04, -.11023300E+04, -.48458300E+04, 0.24544200E+04, 0.12138800E+04, 0.24233300E+04, 0.97965600E+03, 0.13128100E+04, -.10094300E+04, -.28137700E+04, 0.79919600E+03, 0.10112700E+04, 0.28939500E+04, 0.31289500E+02, 0.99301800E+02, 0.10786000E+02, -.14645900E+02, -.22008200E+02, 0.14418800E+00, 0.22495500E+03, 0.96197700E+01, -.96218000E+01, -.45328300E+03, -.35161800E+03, 0.54326700E+03, 0.10475400E+03, 0.10087000E+03, -.55424800E+03, 0.74138000E+02, -.15979500E+02, 0.78180600E+02, -.29217500E+02, 0.13555300E+04, 0.84172600E+02, -.19016200E+03, 0.59677800E+03, 0.61273800E+03, 0.19148500E+03, -.70463200E+03 },
        { 0.13022300E+02, -.33513200E+00, -.73146200E+00, 0.12674600E+01, 0.19067600E+00, -.96524500E+00, -.16931700E+00, -.14929900E+00, 0.87069700E+00, 0.30873800E+00, 0.64605900E-01, -.17344500E+01, -.26155900E+00, 0.57888200E+00, -.30635900E+00, 0.20595100E+00, -.12203800E+01, -.94575600E+00, -.65711300E+00, 0.19999500E+00, 0.39159000E+00, -.39692300E+00, -.12773000E+02, -.68504100E+00, -.14568700E+01, -.32166300E+00, -.42464500E+00, 0.29036400E+00, 0.13707600E+01, -.25505800E+00, 0.81902200E+00, -.24980300E+00, -.14598700E-01, 0.14412700E+00, -.11023500E-02, 0.15003500E+00, 0.25321200E+00, -.43668400E+00, 0.18484400E+00, 0.15158200E+00, 0.17387800E+00, -.24339700E+01, 0.90640600E+00, -.22343900E+00, -.22292400E+00, 0.59242800E-01, -.35328300E+00, -.34464600E-01, -.96737700E-01, -.24612000E-01, -.25173000E+01, 0.39392800E+01, -.36719900E+00, -.35965000E+00, 0.36333500E+00, -.12481000E+01, 0.10984800E+00, 0.11779400E+01, -.56141100E+00, -.17960400E+00, 0.76366500E-02, 0.48641800E+00, -.45027800E+00, 0.44572500E+04, -.10839300E+04, 0.16414800E+04, -.29229200E+03, 0.14395800E+03, 0.88130800E+02, 0.14615200E+03, 0.46771200E+02, -.12867400E+02, 0.25226500E+02, -.66898400E+02, 0.45258200E+02, -.13351800E+02, 0.10523800E+03, -.31153900E+04, 0.14867100E+04, 0.77531100E+03, 0.15577800E+04, 0.80544600E+02, -.72272000E+03, 0.98021200E+03, -.70798000E+02, 0.94612600E+03, -.46914200E+03, 0.95082200E+02, 0.55919800E+05, -.27405800E+05, -.22677900E+05, -.27958400E+05, -.55926200E+04, -.26188800E+04, -.10051900E+05, 0.35977000E+04, -.16391800E+05, -.25518200E+04, -.18925900E+05, -.38892500E+05, 0.18833000E+05, 0.20094200E+05, 0.19444500E+05, 0.98471100E+03, -.71810500E+04, 0.14080600E+05, 0.29492300E+04, 0.15064600E+05, -.55097800E+04, 0.76384700E+04, -.58570400E+04, 0.28468700E+04, 0.49766400E+03, 0.29283400E+04, 0.14767800E+04, 0.15778000E+04, 0.21498700E+03, -.11659100E+04, 0.27579600E+04, 0.94248400E+03, 0.36847100E+04, -.18918100E+04, 0.96605200E+03, 0.13276100E+04, 0.94575800E+03, -.32109100E+04, -.94759500E+02, -.10853800E+03, -.21864600E+04, -.38384100E+03, 0.49640600E+03, 0.10109000E+04, -.26529600E+04, 0.12913200E+04, 0.16375900E+04, 0.13274400E+04, 0.69153900E+03, 0.26356500E+03, 0.57514900E+03, 0.56728500E+03, 0.76347900E+03, -.28335600E+03, 0.23491300E+04, 0.17653800E+04, -.91338400E+03, -.40963100E+03, -.88260000E+03, -.19601900E+04, -.82373200E+03, -.48940800E+03, -.46824500E+03, -.24438100E+04, -.65272600E+03, 0.97458600E+03, -.47898600E+05, 0.23281500E+05, 0.22398400E+05, 0.23946500E+05, 0.32729800E+04, -.36189000E+04, 0.12892600E+05, -.32974800E+03, 0.15596300E+05, -.23900100E+04, 0.12224600E+05, -.52076500E+04, 0.26464200E+04, 0.98767800E+03, 0.26040400E+04, 0.10246300E+03, -.15677200E+04, 0.30689500E+04, 0.13188400E+04, 0.32703700E+04, -.11388300E+04, 0.53250000E+03, 0.20503500E+04, -.10083400E+04, 0.35931800E+03, -.10255500E+04, -.11415100E+04, 0.11375000E+04, -.14728500E+04, -.16631400E+04, -.20410500E+04, 0.86168400E+03, 0.10380800E+04, -.95139800E+04, 0.46366900E+04, 0.65767900E+04, 0.47569100E+04, 0.10400700E+04, -.28506500E+03, 0.17030100E+04, -.16419800E+04, 0.20428400E+04, -.30133700E+03, 0.17800700E+04, 0.11684300E+04, -.62336600E+03, 0.51784500E+02, -.58415200E+03, -.57118400E+03, 0.98278900E+03, -.32346900E+03, 0.51293200E+03, -.31280700E+03, 0.77517100E+03, 0.10643000E+03, -.69734700E+04, 0.34117300E+04, 0.47121500E+04, 0.34863700E+04, 0.13713600E+04, 0.29751600E+03, 0.10082300E+04, -.18292000E+04, 0.61622000E+03, 0.39269700E+03, 0.97030500E+02, -.24687100E+04, 0.12785300E+04, 0.96033100E+03, 0.12347600E+04, 0.76675400E+03, 0.91376500E+03, 0.69610600E+03, 0.95310500E+02, 0.57127300E+04, 0.21722200E+03, 0.12670000E+04, 0.32451500E+04, -.16042400E+04, 0.34523000E+03, -.16227100E+04, -.72950000E+03, -.54511200E+03, -.47658700E+03, 0.48571900E+03, -.34360000E+04, 0.27935700E+03, -.22622300E+04, -.18091900E+05, 0.88264800E+04, 0.97338700E+04, 0.90450000E+04, 0.12031900E+03, -.38513500E+04, 0.70267200E+04, 0.20881900E+04, 0.73519500E+04, -.31203900E+04, 0.35084700E+04, -.14523300E+04, 0.71839500E+03, 0.17381200E+04, 0.72546900E+03, -.25013700E+04, 0.55401600E+03, 0.23416700E+03, 0.21483000E+03, -.78728300E+03, 0.51480400E+02, 0.37574800E+04, -.28576800E+05, 0.14077200E+05, 0.10844100E+05, 0.14288100E+05, 0.26182900E+04, 0.11734700E+04, 0.52648700E+04, -.14795000E+04, 0.87683700E+04, 0.10371400E+04, 0.97210300E+04, 0.41365400E+02, 0.14952700E+03, -.99730400E+02, -.44708200E+02, 0.85134900E+02, -.29995000E+02, -.55387500E+03, -.32832000E+02, 0.15443700E+03, -.23061600E+04, -.11372300E+04, -.37703800E+03, -.31473700E+03, 0.26230200E+03, 0.36399300E+03, 0.53848100E+03, 0.15992800E+03, 0.26449500E+03, 0.27521000E+03, 0.55848400E+04, -.34615000E+02, 0.68550200E+03, -.34635200E+03, -.50171200E+03, -.68661400E+03, -.20726800E+04 },
        { 0.47782500E+01, -.86794900E-01, -.12651700E+00, 0.13539300E+01, 0.29179600E+00, 0.57597500E-01, -.84416100E+00, 0.29719500E+00, 0.14679800E+01, 0.19607400E+00, -.10156800E-04, 0.38275300E+00, -.14134300E+00, -.54012600E-01, 0.70067200E-01, 0.81576300E-01, -.10628400E+00, -.29944300E+00, -.31276700E+00, -.21009100E+00, -.11176300E+00, -.21896700E-01, -.43051600E+01, -.30128300E+00, -.20217700E+00, -.25206400E-01, -.58569500E-01, -.10366500E+01, -.24298900E+00, -.20474300E+00, -.14138600E+00, 0.75798300E+00, 0.34278500E-02, -.47184400E-01, -.10616900E+00, -.54094900E-01, 0.39982300E-02, -.63839600E+00, -.13610700E+00, 0.53224300E+00, 0.62549100E-01, -.70501500E-01, 0.27482400E+00, 0.11587300E+00, -.32271800E-01, -.19745200E+00, -.39046500E-02, -.26082000E-02, 0.18051600E+00, 0.40058300E-01, 0.47328700E+00, -.78775700E+00, 0.10358600E+00, -.24757000E+00, 0.54721700E-01, 0.63280800E+00, 0.55808600E-01, -.90290800E-01, 0.18526500E+00, 0.35689900E-01, 0.14604200E+00, -.13781000E+00, -.46790100E+00, 0.10510100E+00, 0.80308700E+03, -.14055300E+04, 0.19037500E+02, -.93590600E+01, -.11321900E+02, -.95236600E+01, -.15515600E+02, 0.11082300E+02, -.17544000E+02, -.15746700E+02, -.12768100E+02, 0.14778000E+02, 0.10699100E+02, 0.16732400E+03, -.86478300E+02, 0.19354600E+03, -.83685100E+02, 0.13444700E+03, 0.88081100E+02, -.20801600E+02, 0.14913600E+03, 0.39081400E+02, 0.52084600E+02, 0.13636400E+02, -.13721400E+05, 0.69322600E+04, 0.70394400E+04, 0.68587600E+04, 0.94163300E+03, -.18026500E+04, 0.48902100E+04, 0.20891600E+04, 0.59083200E+04, -.10827300E+04, 0.43722400E+04, 0.12453500E+05, -.63103900E+04, -.80343600E+04, -.62258100E+04, -.15448300E+04, 0.56219600E+03, -.38492000E+04, -.10087900E+04, -.34086300E+04, 0.19690000E+03, -.34754900E+04, 0.42208400E+03, -.19940700E+03, -.28295900E+02, -.21094200E+03, -.13665900E+03, -.66712400E+02, -.59923400E+02, 0.68699300E+02, -.69850900E+02, 0.13286000E+03, -.46287800E+03, 0.93163200E+03, -.46476800E+03, -.13784800E+03, -.46573600E+03, 0.51191100E+03, 0.14657500E+03, -.30888500E+03, 0.10434200E+03, -.25164700E+03, -.11966600E+03, -.73167500E+03, 0.10156100E+04, -.50468200E+03, -.33669500E+03, -.50888100E+03, -.16590600E+03, 0.23414700E+03, -.33993700E+03, -.17325900E+03, -.56467800E+03, 0.23469100E+03, -.29230600E+03, 0.23399000E+04, -.11666000E+04, -.11948600E+04, -.11700000E+04, 0.46822800E+00, -.62668000E+02, -.32918500E+03, 0.75675800E+03, -.42333200E+03, -.47812600E+03, -.43422400E+03, 0.12906700E+05, -.65455000E+04, -.75771700E+04, -.64514000E+04, -.14807800E+04, 0.60233100E+03, -.39412900E+04, -.11394200E+04, -.41146100E+04, 0.10729500E+03, -.36992700E+04, -.12129600E+03, 0.50976100E+02, 0.18111700E+03, 0.60530400E+02, -.55081500E+02, -.20251800E+03, 0.11681400E+03, 0.64290800E+02, 0.47469900E+03, -.16560600E+03, 0.36945100E+02, 0.10536700E+03, -.66232300E+02, -.15396100E+03, -.52503000E+02, 0.16813300E+03, -.27470700E+01, 0.70111300E+02, 0.23260000E+03, -.96324000E+02, -.24445000E+03, -.41870300E+03, 0.13680500E+04, -.67614900E+03, -.82987900E+03, -.68401000E+03, 0.14251600E+03, -.40912400E+03, -.10326900E+03, 0.43142500E+03, -.48546200E+03, -.20158500E+03, -.13351200E+04, 0.92620700E+03, -.49113400E+03, -.26666700E+03, -.46320100E+03, 0.16843700E+03, 0.11564200E+03, -.24934800E+03, 0.25293600E+02, -.36322300E+03, 0.13129600E+02, -.54060200E+03, 0.95022900E+03, -.46716900E+03, -.63274500E+03, -.47495800E+03, -.15646100E+02, -.42996800E+03, -.34031400E+02, 0.46240200E+03, -.17430200E+03, -.31286100E+03, -.67279400E+03, -.21408600E+03, 0.10665400E+03, 0.11646500E+03, 0.10685300E+03, -.28144700E+03, -.52412600E+03, 0.33299600E+03, -.41073300E+02, 0.38992500E+03, 0.23518000E+03, -.94837500E+03, 0.83310100E+03, -.41148200E+03, -.51388900E+03, -.41649100E+03, -.90998500E+02, -.17723500E+03, -.45847600E+01, 0.19106100E+03, -.29033000E+03, -.76492700E+03, 0.67557300E+03, 0.65828600E+04, -.33166700E+04, -.41330300E+04, -.32906900E+04, -.66717600E+03, 0.73560800E+03, -.23305500E+04, -.98769900E+03, -.21298900E+04, 0.61971000E+03, -.21616100E+04, 0.22749100E+02, -.16100900E+02, -.18101600E+03, -.11081200E+02, 0.38600700E+03, 0.24032400E+03, 0.97960900E+01, -.17502200E+03, -.56685200E+03, 0.27981500E+02, -.57466600E+03, 0.73752900E+04, -.37181800E+04, -.38919000E+04, -.36871400E+04, -.60912500E+03, 0.72505700E+03, -.24390100E+04, -.89692300E+03, -.29861700E+04, 0.37763600E+03, -.23009700E+04, 0.14283400E+02, 0.15116100E+02, -.24836000E+02, 0.21966300E+01, 0.22761200E+02, -.49649800E+02, 0.11866500E+03, 0.16823700E+02, 0.15804700E+02, -.12909900E+03, 0.13369100E+04, -.60305400E+02, 0.21937700E+02, -.27072700E+03, 0.30521000E+03, -.10168300E+04, 0.41241500E+02, -.11785800E+02, -.12532900E+03, -.62865300E+03, 0.77000400E+02, 0.21370600E+03, 0.25748800E+03, -.45821200E+03, 0.39663700E+02, -.16632100E+03 },
        { -.33141700E+01, 0.75406700E-01, 0.13024800E+00, -.19381300E+00, -.42640500E+00, 0.10240000E+01, -.18790900E+00, 0.37062600E+00, -.85284800E+00, 0.10828100E+01, 0.21178100E+00, -.56322100E+00, -.39980400E+00, -.12279600E+00, -.51607100E+00, 0.20252900E-01, -.24482600E+00, -.31063300E+00, 0.15034500E+00, 0.79256300E+00, 0.68268700E+00, -.34636000E+00, -.72105300E+01, -.32772200E+00, 0.63428200E-01, 0.17198400E+00, -.30200200E+00, 0.76532000E+00, 0.15532100E+01, -.49815600E-01, 0.40285700E+00, -.12845600E+01, -.22160600E+00, 0.33193400E+00, -.86096700E+00, -.18225700E+00, 0.61904800E-01, -.75351200E+00, 0.29519200E+00, -.84063800E+00, 0.24417000E+00, 0.29287100E+00, -.63630200E+00, 0.12656100E+00, 0.31076300E-01, -.93203900E-01, -.10486000E+00, -.73434900E-03, -.42162400E+00, 0.59640600E-01, -.70996700E+00, -.97442600E+00, -.18515000E+00, 0.13518800E-01, -.25878000E+00, -.34002600E+00, 0.34539600E-01, -.25369500E+00, 0.83482000E-01, -.97740000E-01, -.51815000E+00, 0.11323500E+00, -.44499300E+00, -.53703500E-01, -.83474900E-01, 0.81388100E+04, 0.37377200E+02, -.18157700E+02, -.27286500E+01, -.18683900E+02, 0.25654700E+02, 0.19253000E+02, -.28816000E+02, -.71197500E+01, -.23383800E+02, 0.16865800E+02, -.45077500E+02, -.40617500E+03, 0.21153000E+03, 0.18888200E+03, 0.20308100E+03, -.32585100E+03, -.17579500E+03, 0.26501500E+03, 0.19044600E+03, 0.21664200E+03, -.18625000E+03, 0.33487800E+03, -.12563600E+05, 0.61036000E+04, 0.34087400E+04, 0.62839800E+04, 0.46386200E+03, 0.36555800E+02, 0.39701200E+03, -.22748200E+04, 0.29827900E+04, -.10160300E+04, 0.74232300E+04, 0.67384400E+04, -.31854000E+04, 0.16752100E+04, -.33697100E+04, -.17602200E+03, 0.15826900E+04, -.10145200E+04, -.48213400E+03, -.51282700E+04, 0.21801500E+04, -.25863000E+04, -.50041200E+04, 0.25123700E+04, 0.10877800E+04, 0.25020000E+04, 0.12241400E+04, 0.99445300E+03, 0.95885100E+02, -.98743600E+03, 0.16208300E+04, 0.81758100E+03, 0.52836100E+04, -.52833000E+02, 0.34965600E+02, -.22925900E+03, 0.26371600E+02, 0.32413000E+03, -.24669500E+03, -.10897500E+03, -.10703800E+04, -.33888400E+03, 0.21358600E+03, -.79264600E+03, -.36276000E+03, 0.18281000E+03, -.20901800E+03, 0.18254900E+03, -.34381500E+03, -.60537300E+02, 0.21965600E+03, 0.42485000E+03, 0.55873900E+03, -.21260100E+03, 0.61643100E+03, 0.12950700E+04, -.63132000E+03, -.57515000E+03, -.64751000E+03, 0.34891600E+02, -.32129400E+03, 0.13852500E+03, 0.48515500E+03, -.16221200E+03, -.28788900E+03, -.56351300E+04, 0.11455300E+05, -.55569700E+04, -.84901900E+03, -.57292100E+04, -.10224400E+04, 0.12480600E+03, -.38859200E+03, 0.15897800E+04, -.45223700E+04, 0.90079400E+03, -.58224700E+04, 0.65385300E+03, -.35783000E+03, -.92806300E+02, -.32686100E+03, -.68441300E+03, -.56143900E+03, 0.42210300E+03, 0.77532200E+02, -.42720200E+03, -.64440200E+03, 0.13650200E+04, 0.82514900E+03, -.40082000E+03, -.20793700E+03, -.41265800E+03, -.34935200E+03, -.60192100E+03, 0.68746700E+03, 0.10419900E+04, 0.42714000E+03, -.36217400E+03, -.63887500E+03, -.84157600E+03, 0.46374300E+03, 0.85862100E+03, 0.42080700E+03, -.17477900E+03, -.87636600E+02, 0.49742700E+03, -.88627400E+02, 0.30317800E+03, -.10489100E+03, 0.87025400E+03, -.64058500E+03, 0.32306500E+03, 0.81168700E+01, 0.32041000E+03, 0.26863900E+03, -.12051100E+02, 0.26419600E+03, 0.14670100E+03, 0.22675800E+03, 0.15426000E+03, 0.15669500E+03, -.20058900E+04, 0.10267200E+04, 0.11797100E+04, 0.10028900E+04, -.21815000E+03, -.64077400E+02, 0.51591500E+03, -.33521700E+03, 0.77713300E+03, -.83458200E+02, 0.29838900E+03, -.39676100E+04, 0.19669500E+04, 0.16875000E+04, 0.19838900E+04, 0.34303100E+03, 0.24246900E+03, 0.81094100E+03, -.12682800E+04, -.22732700E+03, 0.20039400E+03, 0.10490500E+05, 0.51642300E+03, -.24978800E+03, 0.16149100E+03, -.25823300E+03, -.17398300E+02, -.53751100E+03, 0.57551100E+03, -.20126800E+02, -.10813300E+04, -.37863800E+03, -.75714600E+04, 0.43195000E+04, -.20675600E+04, -.66924100E+02, -.21603800E+04, -.28774500E+02, 0.14086400E+04, -.13891800E+04, -.93589200E+03, -.28623600E+04, 0.16303500E+04, -.14095000E+04, 0.38597100E+04, -.19081900E+04, -.19719300E+04, -.19299400E+04, -.82240100E+03, -.10324600E+04, 0.71306100E+03, 0.14026600E+04, -.71138600E+02, -.86569000E+03, -.15255300E+04, 0.51919100E+04, -.25102700E+04, -.95577200E+03, -.25966300E+04, -.15969500E+03, -.19959000E+03, 0.33776900E+03, 0.13203400E+04, -.13609200E+04, 0.33486700E+03, -.32619500E+04, -.94897200E+01, 0.36536000E+02, -.14436500E+03, -.32527600E+02, 0.16618500E+03, -.16588800E+03, -.97876900E+02, -.21522000E+02, 0.96463900E+02, 0.92875900E+03, 0.53969300E+03, 0.75215200E+03, -.86460500E+02, -.22512100E+03, -.10563000E+03, -.96012500E+02, -.95428900E+02, 0.61475000E+02, -.13731800E+03, -.12723300E+04, 0.18546900E+03, -.11147900E+03, -.32408300E+02, 0.99043400E+02, -.15915700E+03, 0.67569000E+03 },
        { -.12930500E+01, -.42222500E-02, 0.57459300E-01, -.27104300E+00, -.70134800E-01, -.64847900E+00, 0.33663600E+00, -.35905500E+00, 0.52728500E+00, -.59880600E+00, 0.23811400E-01, 0.69015200E+00, -.25224300E-01, 0.45224400E-01, 0.92842100E-02, 0.42900600E-01, 0.44784900E+00, 0.18299200E+00, -.66967800E-01, 0.10124400E+00, 0.65945300E-01, 0.52721900E-01, 0.16149700E+01, -.22893100E-01, 0.28111400E-01, -.39570000E-01, 0.49489700E-01, -.11240500E+00, -.21333800E+00, 0.13963700E+00, -.42956300E-01, -.26066300E+00, -.22376800E-01, 0.16792700E+00, -.19554200E+00, -.21633500E+00, -.51670400E-01, 0.57718300E+00, -.13823200E+00, 0.26429100E+00, -.92582500E-01, -.29249700E+00, -.23980000E+00, 0.79016300E+00, -.43555900E+00, 0.38678900E-01, -.93399300E-02, 0.10341100E-01, -.22966300E+00, -.39148100E-01, -.69522800E+00, 0.24785900E+01, -.15912800E+00, -.40657200E+00, 0.19400300E+00, 0.73729200E-01, 0.25221300E-01, -.12608300E+00, 0.14622400E+00, -.37598300E-01, -.93672900E-01, 0.30034400E+00, -.23371000E-01, 0.88192100E-01, -.17459600E+00, -.11879000E+00, 0.65245500E+02, -.32226300E+02, -.30048200E+02, -.32625300E+02, -.81962900E+01, 0.10777000E+02, -.13741500E+02, 0.96996800E+01, -.15495900E+02, 0.11042300E+02, -.26751800E+02, -.23573600E+02, 0.21456300E+02, 0.96370700E+02, 0.11755100E+02, -.17555600E+03, 0.17167900E+02, 0.60139500E+02, 0.18635500E+03, 0.53257300E+02, -.22347100E+02, 0.49095600E+03, -.18389700E+05, 0.90131600E+04, 0.89470600E+04, 0.91941200E+04, 0.15750100E+04, -.27849500E+03, 0.36136100E+04, -.46941700E+03, 0.57375300E+04, -.54667900E+03, 0.73577900E+04, 0.11910900E+05, -.57771700E+04, -.74183600E+04, -.59547200E+04, -.65086400E+03, 0.19898700E+04, -.41056100E+04, -.14500800E+04, -.53521700E+04, 0.17535000E+04, -.34699900E+04, -.91622400E+03, 0.46830300E+03, 0.27864000E+03, 0.45818600E+03, 0.20804700E+03, 0.96606300E+02, 0.40749600E+02, -.14461300E+03, 0.32395300E+03, 0.10132700E+03, 0.32567200E+03, 0.28689200E+03, -.14246300E+03, -.15891300E+04, -.14338400E+03, 0.66061700E+03, -.58714900E+02, -.33168100E+03, -.70249600E+03, -.30175900E+03, 0.12319300E+03, 0.46769100E+02, 0.60731800E+03, -.30091200E+03, -.17046600E+03, -.30403600E+03, -.20922600E+03, 0.26592800E+01, 0.66051900E+01, 0.28377800E+03, 0.11675300E+03, 0.16831500E+02, -.54283300E+03, -.19821600E+04, 0.10008500E+04, 0.86348200E+03, 0.99104300E+03, 0.43682100E+03, 0.11836700E+03, 0.38989800E+03, -.48568200E+03, 0.34309800E+03, 0.26043900E+03, -.34427300E+02, 0.15234700E+05, -.74459200E+04, -.85278600E+04, -.76161300E+04, -.14457300E+04, 0.71756800E+03, -.35472600E+04, -.92025700E+02, -.52543200E+04, 0.65061700E+03, -.51517200E+04, 0.19487800E+03, -.11463300E+03, 0.49118600E+03, -.97530100E+02, -.19297400E+03, -.48813400E+02, -.13665200E+03, -.39212700E+03, -.45013800E+03, -.98159800E+02, 0.61998600E+03, 0.20511900E+03, -.95010400E+02, 0.23036600E+03, -.10240700E+03, 0.20083700E+03, -.37767800E+03, 0.33188100E+03, 0.62508000E+03, 0.29217400E+03, -.27719300E+03, -.61744300E+03, 0.19213300E+04, -.93158800E+03, -.45593700E+03, -.96063400E+03, -.21247600E+03, 0.26919400E+03, -.47448300E+03, 0.92505400E+02, -.82443000E+03, -.11891600E+02, -.15188900E+03, -.46156300E+02, 0.28069900E+02, -.11516800E+03, 0.23045100E+02, 0.25795500E+03, -.86729800E+02, 0.11974000E+02, -.36622500E+02, -.26653100E+02, -.28061500E+01, -.20333500E+03, 0.12279200E+04, -.59819400E+03, -.10885100E+03, -.61381400E+03, -.30325400E+03, 0.18938400E+03, -.31871600E+03, 0.14428000E+03, -.45318100E+03, -.38013900E+02, 0.19023800E+03, 0.11933800E+04, -.60931700E+03, -.81048700E+03, -.59685600E+03, -.15456400E+03, -.26242100E+03, -.18031100E+03, 0.11059300E+03, -.30238300E+03, -.32546500E+03, -.52482100E+02, 0.13053000E+04, -.64982900E+03, -.61061500E+03, -.65259500E+03, -.15591000E+02, -.37206400E+03, 0.58005800E+02, 0.21410800E+03, -.29611200E+03, -.27609200E+03, -.96063300E+03, 0.68275900E+04, -.33270400E+04, -.40081100E+04, -.34133800E+04, -.18620200E+03, 0.15979400E+04, -.26985200E+04, -.12339000E+04, -.32055800E+04, 0.14578900E+04, -.20754400E+04, 0.88057100E+03, -.42747400E+03, -.13846800E+04, -.44000600E+03, 0.48019700E+03, -.26794700E+03, 0.18482200E+03, 0.37235900E+03, 0.23331100E+03, -.78672600E+02, -.10717200E+04, 0.86542500E+04, -.42423300E+04, -.40706000E+04, -.43269700E+04, -.69327600E+03, 0.13186900E+03, -.16572500E+04, 0.20104100E+03, -.29284600E+04, 0.26857700E+03, -.34350900E+04, 0.92978200E+00, -.16480900E+00, -.37091200E+02, 0.69782800E+01, 0.26635400E+02, -.42450200E+02, -.28251800E+02, 0.44181000E+01, 0.15029500E+02, 0.44491600E+03, 0.10037500E+04, 0.45352400E+02, -.16320100E+02, -.25147800E+03, -.12486900E+03, -.77071400E+03, -.19323600E+02, -.58999400E+02, 0.46346000E+02, -.15902700E+04, -.45029300E+01, 0.84238700E+01, -.31763600E+02, -.60236300E+02, 0.10005000E+03, 0.33072100E+03 },
        { -.36969800E+01, 0.18121200E+00, 0.59766500E-01, 0.89769600E-01, -.21551800E+00, 0.53301400E+00, -.23433800E+00, 0.37559800E+00, -.44215100E+00, 0.37586400E+00, 0.79048800E-02, -.43321900E+00, 0.33305800E+00, 0.28126100E-01, 0.91267600E-01, 0.55958000E-01, -.23650300E-01, 0.43270800E-01, -.25635500E+00, -.40952200E-01, 0.55751800E-01, -.12108900E+00, 0.17161100E+01, 0.33023800E+00, -.27546500E-01, 0.12863400E-01, 0.27014200E-01, 0.12835700E+00, 0.20974000E+00, -.20043300E+00, -.54493000E-02, 0.41344000E-01, -.44494500E-02, 0.23472400E+00, -.11611800E+01, -.59377900E-01, -.30460200E-01, -.61281500E+00, 0.28815700E-01, -.31135400E-01, 0.98979400E-01, -.56414000E-01, -.12343700E-01, -.10581900E+00, 0.63339900E-01, -.76692500E-01, -.20032000E-01, 0.52725500E-02, -.29302800E-01, 0.38250700E-01, 0.89224000E-01, -.47805700E+00, 0.44699000E-01, 0.80125000E-01, -.12009600E+00, -.15337000E-02, 0.44018300E-01, -.11567700E+00, 0.14788800E+00, -.34462100E-01, -.38306000E-01, -.90561300E-01, 0.25716800E-01, -.72328800E-02, 0.65904700E-01, -.65943700E-02, 0.31447400E+00, 0.33808700E+02, 0.14564600E+01, 0.56214600E-02, 0.97740400E+00, -.21236400E+01, -.14003600E+01, -.81703500E+00, -.27264500E+01, -.57358500E+00, -.37051700E+01, -.36675600E+02, 0.12550500E+02, 0.35875000E+02, 0.18396100E+02, 0.30902400E+02, -.53915200E+02, 0.17513000E+02, -.38510200E+02, -.55133400E+02, -.47782700E+02, -.97649100E+02, 0.23702800E+04, -.11942800E+04, -.52977500E+03, -.11833800E+04, -.44995200E+03, -.10407000E+04, -.14162800E+03, 0.20235700E+03, -.41887900E+03, -.10597500E+04, -.10608900E+04, -.12430000E+04, 0.62101100E+03, -.57220100E+03, 0.62011900E+03, 0.25522000E+03, 0.15751400E+03, 0.85157000E+03, 0.10088200E+04, 0.10053800E+04, 0.36816500E+03, 0.25151800E+03, 0.46786100E+03, -.24833900E+03, -.69634400E+02, -.23407800E+03, -.76028100E+02, -.59586400E+02, -.44578300E+02, 0.38795100E+02, -.19751200E+03, -.43825600E+02, -.16475200E+03, -.33610700E+03, 0.16811200E+03, 0.33480100E+03, 0.16792900E+03, 0.18933000E+03, -.31186900E+03, 0.30969000E+03, 0.32596600E+03, 0.27617800E+03, -.28068500E+03, 0.49649000E+02, -.24490100E+03, 0.11811000E+03, -.61962700E+02, 0.12302200E+03, -.89717200E+02, 0.14251600E+03, -.10200200E+03, -.23157100E+03, -.70600300E+02, 0.96293900E+02, 0.40015900E+03, 0.13685800E+04, -.68721100E+03, -.65298800E+03, -.68421500E+03, -.14053800E+03, -.10059300E+03, -.16718800E+03, 0.36392700E+03, -.16131400E+03, -.20143100E+03, -.20879600E+03, -.24109100E+04, 0.11980300E+04, 0.36132400E+02, 0.12029500E+04, 0.52380600E+03, 0.71090700E+03, 0.55900600E+03, 0.35071800E+03, 0.83959600E+03, 0.84235600E+03, 0.90180800E+03, 0.10034900E+03, -.44969700E+02, -.93142200E+02, -.49990100E+02, -.66652600E+02, -.80396600E+02, 0.74890400E+02, 0.75461500E+02, 0.11552500E+03, -.63853400E+02, -.30794100E+03, -.22016000E+03, 0.11761600E+03, -.13714800E+03, 0.10977600E+03, -.11553700E+02, 0.29663700E+02, 0.51931000E+02, 0.69706500E+01, 0.83293800E+02, 0.11365500E+02, 0.20678200E+03, -.80348400E+03, 0.39023100E+03, 0.13001500E+03, 0.40168800E+03, 0.14657600E+03, -.13850800E+03, 0.32505700E+03, 0.13853500E+03, 0.40733600E+03, -.91833600E+01, -.53953600E+02, -.12058100E+03, 0.73139800E+02, 0.13772200E+03, 0.60374000E+02, -.61289600E+01, 0.10729000E+03, -.10463900E+01, -.96330200E+01, 0.37901300E+02, 0.60505300E+02, 0.11344700E+03, -.56302500E+03, 0.27290600E+03, -.15921300E+02, 0.28122700E+03, 0.15064000E+03, -.13319300E+03, 0.22263100E+03, 0.91982700E+02, 0.33047800E+03, -.34048900E+02, -.88407300E+02, -.15426900E+04, 0.77488300E+03, 0.79900400E+03, 0.77166900E+03, 0.15922400E+03, 0.23157500E+03, 0.19086200E+03, -.33005500E+03, 0.60844800E+02, 0.25508500E+03, 0.45923900E+03, -.10251200E+04, 0.51294200E+03, 0.21168900E+03, 0.51245400E+03, 0.78881400E+02, 0.22532400E+03, 0.10070200E+03, -.18994900E+03, 0.22785900E+03, 0.18263300E+03, 0.53302200E+03, -.36072200E+02, 0.26046500E+02, -.41932800E+03, 0.17157600E+02, 0.41155600E+02, -.24253200E+02, 0.36117900E+03, 0.55919200E+03, 0.32565100E+03, 0.10829300E+03, -.18006200E+03, 0.56934700E+03, -.28180400E+03, -.24255700E+02, -.28521800E+03, -.71275500E+02, 0.49929200E+02, -.15930800E+03, -.16387700E+02, -.23801500E+03, -.24737700E+02, 0.14145100E+03, -.12789100E+04, 0.64918200E+03, 0.23997800E+03, 0.63902000E+03, 0.16514800E+03, 0.40420700E+03, 0.18132900E+03, 0.32945200E+02, 0.44110600E+03, 0.42281500E+03, 0.47325300E+03, -.69731100E+01, -.22786400E+01, 0.15924300E+01, -.58781700E+01, 0.39965000E+01, 0.23085800E+01, 0.14344900E+01, -.21943200E+01, 0.32205100E+01, -.14191600E+03, 0.15866500E+00, 0.44452900E+02, 0.67861500E+02, -.40813700E+02, 0.38517600E+02, -.71693200E+02, 0.13753200E+02, 0.22002100E+02, -.35291400E+02, 0.21006000E+03, 0.23247300E+02, -.16615300E+02, 0.18402300E+02, 0.99864500E+01, -.46958600E+02, -.13836900E+03 },
        { -.27127300E+01, 0.47866400E-01, 0.94485900E-01, -.13758000E+00, -.31164100E+00, 0.20499800E+00, 0.40176800E+00, -.26385600E+00, -.15224300E+00, -.36444600E-01, 0.25785500E-02, -.44941300E+00, 0.32366900E-01, 0.96694300E-02, -.15902800E-01, 0.43349300E-01, -.35591200E+00, -.13467400E+00, -.48966200E+00, 0.48617000E+00, 0.13690600E-01, -.64138400E-01, 0.41879200E+00, 0.31059000E-02, -.36840000E-01, -.19284400E-01, 0.86118700E-02, 0.25737500E-01, -.66557100E-02, -.97370000E-01, 0.92842300E-01, -.11286400E+00, -.23280900E-02, 0.12616300E+00, -.66224000E+00, -.26088200E-01, -.44884000E-01, -.56506200E-01, 0.39679100E-01, 0.11377700E-01, 0.50004500E-01, -.66334600E-01, -.28750300E+00, -.52331100E-01, 0.26408700E+00, -.14550500E+00, 0.62967800E-01, 0.58013600E-02, 0.21441900E-01, 0.67780100E-01, 0.37963200E+00, -.20086800E+01, -.23305900E-01, 0.47482400E-02, 0.27616000E+00, 0.23389100E-01, -.85010100E-02, -.41014600E+00, 0.26443700E+00, -.56638200E-01, 0.47193800E-01, -.11575900E-02, -.19845300E+00, 0.47807000E-01, 0.19568700E-02, -.72259500E-02, 0.83554800E+00, -.18085400E-02, 0.22565600E+02, 0.69664100E-02, 0.22929900E+01, -.41726200E+01, -.39616500E+01, -.11689200E+02, -.75454000E+01, -.31645500E+01, -.50752500E+01, 0.47476600E+02, -.22010500E+02, -.17751400E+02, -.23674600E+02, 0.10738900E+03, -.34568200E+02, -.66846600E+02, -.18743400E+03, -.39439100E+02, -.35721500E+02, -.30440600E+03, 0.42156700E+04, -.21558700E+04, -.36613000E+04, -.21055600E+04, -.70565700E+02, -.10391000E+03, -.11606900E+04, -.12850300E+03, -.99306100E+03, -.10865700E+03, -.18931300E+04, -.49162300E+04, 0.25122600E+04, 0.28852500E+04, 0.24565100E+04, 0.43039200E+03, 0.20352000E+03, 0.14877100E+04, 0.13047900E+03, 0.17073800E+04, 0.34369600E+03, 0.16028900E+04, 0.29522600E+03, -.15365400E+03, 0.23358100E+03, -.14778500E+03, -.82970100E+02, -.17948400E+02, -.53438300E+02, -.76533400E+02, -.21865500E+03, -.17536700E+02, -.88991800E+02, -.18970400E+03, 0.96047400E+02, 0.14066300E+04, 0.94706600E+02, -.49107800E+02, -.11463700E+03, 0.28888200E+03, 0.37245100E+03, 0.17816800E+03, -.15914700E+03, -.16535300E+03, -.55622400E+03, 0.27589700E+03, -.94248300E+02, 0.27924700E+03, 0.71787400E+02, 0.36870400E+02, -.66978100E+02, -.25956400E+03, 0.29351100E+02, -.51143400E+01, 0.62087100E+03, 0.19445600E+04, -.97336600E+03, -.10737200E+04, -.97219700E+03, -.23906800E+03, -.11082500E+03, -.29940800E+03, 0.64919100E+03, -.23567200E+03, -.26372200E+03, -.10862800E+03, -.47128400E+04, 0.24143900E+04, 0.33324500E+04, 0.23534100E+04, 0.55433600E+03, 0.59204800E+03, 0.10061600E+04, -.25913600E+03, 0.12034200E+04, 0.68857100E+03, 0.16999500E+04, -.58828100E+03, 0.29517800E+03, -.21578400E+02, 0.29435500E+03, -.43695600E+02, -.76087400E+02, 0.21812300E+03, 0.24061500E+03, 0.44680300E+03, -.10025700E+03, -.14089600E+03, -.54044000E+03, 0.27870800E+03, -.52025700E+03, 0.26987000E+03, -.65650800E+02, 0.12556800E+03, 0.10403400E+03, -.11589600E+02, 0.10720600E+03, 0.79714800E+02, 0.46887100E+03, -.14248900E+04, 0.71264300E+03, 0.10638200E+03, 0.71239000E+03, 0.91436600E+02, -.22441600E+03, 0.42255700E+03, -.12236800E+03, 0.56660700E+03, 0.41924000E+02, -.19598600E+03, 0.14647900E+03, -.63029800E+02, -.19516700E+02, -.73128600E+02, -.81571000E+02, -.33156400E+02, 0.58455200E+02, 0.14578100E+03, 0.29701900E+02, -.73219300E+02, 0.78591600E+02, -.10397200E+04, 0.51807400E+03, -.11736800E+03, 0.51953400E+03, 0.80935500E+02, -.25443800E+03, 0.29937000E+03, -.19322100E+03, 0.44372300E+03, -.23470100E+02, -.30320300E+03, -.18167800E+04, 0.90717000E+03, 0.10954700E+04, 0.90876500E+03, 0.31231400E+03, 0.27040100E+03, 0.27684100E+03, -.41609700E+03, 0.20703200E+03, 0.32694500E+03, 0.35338500E+03, -.10170100E+04, 0.50672300E+03, 0.31306400E+03, 0.50838400E+03, 0.62875300E+02, 0.19688100E+03, 0.13327900E+03, -.54178300E+02, 0.18421700E+03, 0.16874700E+03, 0.55505100E+03, -.35909800E+04, 0.18150500E+04, 0.17191500E+04, 0.17944200E+04, 0.14679400E+03, -.29476000E+03, 0.13373100E+04, 0.45511000E+03, 0.14440800E+04, -.21134900E+03, 0.12182900E+04, -.11187800E+03, 0.60099700E+02, 0.20858800E+03, 0.55321500E+02, -.32315500E+02, 0.11342100E+03, -.54514100E+02, 0.83080300E+02, -.79076000E+02, -.59075900E+02, 0.70513400E+03, -.14988500E+04, 0.77111700E+03, 0.15686700E+04, 0.74883300E+03, -.73399300E+02, -.13996500E+02, 0.46108500E+03, 0.86576300E+02, 0.36104300E+03, 0.19304500E+02, 0.55870300E+03, -.21988400E+02, -.10981500E+02, 0.18632800E+02, -.17698800E+02, -.98154800E+00, 0.81077500E+01, 0.31308300E+02, -.20397800E+01, -.72804300E+01, -.30639800E+03, 0.39365100E+02, 0.10043700E+03, 0.72174700E+02, 0.13904900E+03, 0.27316200E+02, -.11580100E+03, 0.19560000E+02, 0.76070100E+02, -.80400600E+02, 0.25641100E+03, 0.59684900E+02, -.33154900E+02, 0.71030000E+02, -.22569700E+03, -.27540600E+01, -.25037800E+03 },
        { -.36943500E+01, 0.89432900E-01, 0.13020300E+00, -.66923800E+00, -.43129300E+00, 0.73875600E+00, -.39730500E+00, 0.36760400E+00, -.23462600E+00, 0.59524900E+00, -.31436100E-01, -.62392500E+00, 0.32444300E-01, -.12672500E-01, -.16811000E+00, 0.18380900E+00, -.20079200E+00, -.72511600E-01, -.20186000E+00, 0.32064100E+00, 0.18585100E+00, -.24566800E-01, -.15702300E+01, -.11814400E+00, 0.29675900E-01, -.63905400E-01, 0.18899100E+00, 0.25308900E-01, 0.28600100E+00, 0.26093600E-01, 0.15005400E+00, 0.35722600E+00, -.15247800E-01, -.31798300E-01, -.60104900E+00, -.35662000E-01, -.25352300E-01, -.49532300E+00, 0.26096200E-01, -.84778400E-01, 0.40483000E-01, 0.10172200E+00, 0.18085500E-01, -.11918600E+00, -.55338700E-01, -.35360400E-01, -.10078300E+00, 0.65872600E-02, -.16294700E-01, 0.17287300E-01, -.24925700E+00, -.57196400E+00, 0.33516300E-01, 0.63754100E-02, -.27484200E+00, -.20232600E-01, -.38851700E-03, -.10809100E+00, 0.13034900E+00, -.30938400E-01, -.30712100E-03, -.19202900E-01, -.12839500E+00, 0.81504800E-02, 0.19425400E-02, -.67560400E-01, 0.14927100E+00, 0.39404500E-02, -.92461000E-01, 0.28707600E+01, -.84837400E+01, 0.11881900E+01, -.30586800E+01, -.41729600E+01, -.14359900E+00, 0.21579800E+01, -.98900900E+00, -.14088700E+03, 0.73605200E+02, 0.70656000E+02, 0.70480700E+02, 0.57776800E+02, -.77857200E+02, 0.76668200E+02, 0.41882000E+02, 0.53823100E+02, -.67138400E+02, -.53368100E+02, -.44040600E+03, 0.21535600E+03, -.11908800E+04, 0.22129700E+03, 0.56729000E+03, -.43211400E+03, 0.50736800E+03, 0.73318300E+03, 0.47609500E+03, -.41020800E+03, 0.23579200E+03, -.38107500E+04, 0.19164600E+04, 0.23988100E+04, 0.19045000E+04, 0.75921400E+02, 0.37400500E+03, 0.30391300E+03, -.11543200E+04, 0.65104100E+03, 0.42438500E+03, 0.12704700E+04, 0.10568400E+03, -.49024100E+02, 0.79847800E+02, -.52934400E+02, -.28339900E+02, -.82940600E+01, -.26744800E+02, -.41643700E+02, -.55331000E+02, -.14992600E+02, -.25757200E+01, -.25825800E+03, 0.12678000E+03, 0.72381200E+02, 0.12905100E+03, -.44826400E+02, -.94771000E+02, 0.74856700E+02, -.81979000E+02, 0.10025700E+03, -.11353400E+03, 0.39992400E+03, 0.46133800E+02, -.19920100E+02, -.94700300E+02, -.23291300E+02, -.51435600E+02, 0.26587300E+02, -.18143400E+02, -.16242200E+02, 0.27687900E+02, 0.25629500E+02, 0.15663900E+02, 0.28915500E+02, -.13777600E+02, 0.20380700E+03, -.14411600E+02, -.84886700E+02, 0.24992900E+02, 0.23946600E+02, -.16883100E+02, 0.31063300E+02, 0.12759900E+02, 0.14981800E+03, -.26263700E+04, 0.13240600E+04, 0.22725400E+04, 0.13116300E+04, -.56146700E+02, 0.41330700E+03, 0.94882500E+01, -.10808500E+04, 0.31184200E+03, 0.44760500E+03, 0.87857100E+03, -.27426600E+03, 0.13514300E+03, 0.13923800E+01, 0.13724800E+03, 0.16548700E+03, -.96214500E+02, 0.74192500E+02, 0.29803500E+02, 0.10078400E+03, -.85569900E+02, -.14016500E+03, -.19959200E+03, 0.93150600E+02, 0.18341200E+03, 0.99605000E+02, 0.38174700E+02, -.17825500E+02, 0.10161300E+03, 0.55043300E+02, 0.85863300E+02, -.65899800E+02, 0.19101200E+03, -.29174600E+03, 0.15129800E+03, 0.14113100E+03, 0.14583800E+03, 0.21520600E+02, -.57994900E+02, 0.86441300E+02, -.29696700E+01, 0.81760500E+02, -.12076000E+02, -.34144800E+02, 0.36683600E+03, -.18629800E+03, -.16485800E+01, -.18336800E+03, -.29621500E+02, 0.24681700E+02, -.24374400E+02, 0.84110200E+02, -.87448400E+02, -.55832900E+01, -.11433900E+03, -.15187600E+03, 0.80586500E+02, -.66865000E+02, 0.75758000E+02, 0.16811900E+01, -.40631100E+02, 0.31596500E+02, -.26055700E+02, 0.68846600E+02, -.58739700E+01, -.22568500E+02, -.37590900E+02, 0.17917300E+02, 0.82092200E+01, 0.19000600E+02, 0.10917400E+03, 0.37362300E+02, -.51287800E+02, 0.87128100E+01, 0.59513300E+02, 0.76285300E+01, -.69667000E+02, 0.17905300E+02, -.99050000E+01, -.14094300E+03, -.90191300E+01, -.55581400E+02, 0.15912900E+02, 0.24089100E+02, 0.34427000E+02, 0.97494500E+02, 0.23014200E+01, -.28227000E+01, -.15973300E+04, 0.80152400E+03, 0.10437000E+04, 0.79812100E+03, -.33481300E+01, 0.24358800E+03, 0.60206800E+02, -.60537600E+03, 0.23846000E+03, 0.27283400E+03, 0.46152800E+03, -.97108500E+02, 0.44902100E+02, 0.54976300E+03, 0.48209900E+02, 0.64648800E+02, 0.59333700E+02, -.76379500E+01, -.95254700E+02, -.25821800E+01, 0.20636200E+02, 0.26500400E+03, 0.16024500E+03, -.81076600E+02, 0.52765200E+03, -.80379200E+02, -.31554800E+03, 0.18800400E+03, -.22105700E+03, -.33900100E+03, -.25852600E+03, 0.17895300E+03, -.99323100E+02, -.49789200E+01, -.74956000E+00, 0.19864900E+01, 0.12798200E+01, -.76240900E+01, 0.89666000E+01, 0.10096900E+02, 0.69983800E+01, -.29207500E+01, -.50665100E+03, 0.59519000E+03, 0.54090200E+02, 0.22150300E+02, -.34754100E+02, 0.93882000E+01, -.68131700E+03, -.15026900E+02, -.14920200E+02, -.13412100E+02, 0.77998300E+02, 0.57934300E+01, -.96366600E+01, 0.11830900E+02, -.35508700E+03, 0.27105300E+02, -.50724000E+03 },
        { -.17017600E+02, 0.25171500E+00, 0.12450700E+01, 0.18203700E+01, -.32978000E+00, 0.13184000E+01, -.62651200E+00, 0.49534200E+00, 0.29285800E+00, 0.89423100E+00, 0.46657100E-01, 0.21504800E+01, -.13710100E-01, -.32482500E-01, 0.34544100E-02, 0.19924000E-01, 0.17696800E+01, 0.36453900E+00, 0.34411000E+00, -.49206500E-01, -.59994200E+00, 0.31267400E+00, 0.10612700E+01, -.18514500E+01, -.42169100E+00, -.26170100E+00, 0.26024900E+00, -.31795800E+00, -.89339000E+00, -.12313800E+01, -.43573900E+00, -.28609200E+01, 0.14886400E-01, 0.10434900E+01, 0.16376200E+01, -.90483000E+00, -.49007700E+00, 0.25419400E+01, -.97552200E+00, 0.46427000E+00, 0.64793300E+00, 0.30961700E+01, -.12433700E+00, -.16315700E+01, 0.12879500E+01, 0.11984200E+00, -.62106700E+00, 0.66059400E-01, -.12448100E+01, 0.11755100E-01, 0.96714200E+00, 0.10883100E+01, 0.11590900E+01, 0.48196400E+00, -.53979800E+01, 0.66895800E+00, 0.16535500E-01, -.16002700E+01, 0.46994700E+00, -.50879000E+00, -.12051900E+00, 0.20071100E+01, -.73106900E+00, -.10133600E+00, -.18373200E+01, -.11490800E+01, 0.34281100E+01, 0.11598800E+00, -.54377100E+01, 0.19949200E-01, -.18744400E+03, 0.35993200E+02, -.89005300E+02, -.10048100E+03, -.39555500E+02, 0.53014100E+02, -.37100000E+02, -.33510600E+04, 0.18016700E+04, -.10838400E+01, 0.16760300E+04, 0.11000900E+04, -.20358100E+04, 0.15225400E+04, 0.37081300E+03, 0.12612700E+04, -.17372600E+04, -.12121700E+04, -.26438900E+05, 0.12493900E+05, -.22027600E+05, 0.13238500E+05, 0.12560900E+05, -.11453900E+05, 0.14553900E+05, 0.14100800E+05, 0.16159300E+05, -.10142300E+05, 0.11686600E+05, -.63464600E+05, 0.32659200E+05, 0.44617100E+05, 0.31719200E+05, 0.42181500E+04, 0.17879400E+05, -.22399500E+04, -.28373400E+05, 0.44933000E+04, 0.17252400E+05, 0.21467900E+05, 0.45502800E+04, -.22181800E+04, 0.17033000E+04, -.22765400E+04, -.15268100E+04, -.63099000E+03, -.68108500E+03, -.24014100E+03, -.14094800E+04, -.75179100E+03, -.88262500E+03, -.60662100E+03, 0.24690600E+03, -.52874000E+04, 0.30213900E+03, -.60474800E+03, -.92441800E+03, 0.26566800E+03, -.20446800E+04, 0.13814000E+03, -.13190500E+04, 0.55610200E+04, -.64891100E+04, 0.33118000E+04, 0.13544600E+04, 0.32547600E+04, -.75612900E+03, -.14812700E+03, 0.92993600E+03, -.15251100E+04, 0.25820200E+04, -.14832800E+03, 0.34308900E+04, 0.13092100E+05, -.65233700E+04, -.42500500E+04, -.65453400E+04, -.28389000E+04, -.72453000E+03, -.14202900E+04, 0.33880100E+04, -.56594300E+03, -.14517600E+04, -.15598900E+04, -.36794600E+05, 0.19406300E+05, 0.41885900E+05, 0.18372600E+05, 0.52404100E+03, 0.17483400E+05, -.78726400E+04, -.25609600E+05, -.28480100E+04, 0.16644700E+05, 0.11966400E+05, -.44822900E+04, 0.21835400E+04, -.35614600E+02, 0.22428700E+04, 0.28261600E+04, -.26253100E+04, 0.25624100E+04, 0.13609800E+04, 0.17004600E+04, -.25172900E+04, -.22160100E+04, -.33799200E+04, 0.16145000E+04, 0.43617900E+04, 0.16871500E+04, 0.59851100E+03, -.44382600E+03, 0.21021400E+04, 0.13359000E+04, 0.23213800E+04, -.14333400E+04, 0.38519100E+04, -.75549000E+04, 0.39660300E+04, 0.52158800E+04, 0.37770100E+04, -.21444000E+03, -.28169600E+04, 0.27461600E+04, 0.36835500E+03, 0.41951300E+04, -.13385500E+04, -.24358700E+04, 0.10511700E+05, -.52699800E+04, -.15772700E+04, -.52549300E+04, -.30898600E+03, 0.22135200E+03, -.99429100E+03, 0.23362000E+04, -.23470000E+04, -.41852200E+03, -.35112700E+04, -.53961300E+04, 0.28259700E+04, 0.13856400E+04, 0.26954700E+04, -.35286800E+03, -.24771200E+04, 0.19769400E+04, -.14937100E+03, 0.39894100E+04, -.12001900E+04, -.17786700E+04, -.16061300E+05, 0.79720600E+04, 0.79795400E+04, 0.80336600E+04, 0.28084100E+04, 0.17024700E+04, 0.26807200E+04, -.35471800E+04, 0.22211700E+04, 0.12805900E+04, 0.55829900E+04, -.68608400E+04, 0.33884300E+04, 0.17417900E+04, 0.34294600E+04, -.53906900E+03, 0.10015200E+04, 0.15827700E+04, -.10253400E+04, 0.16823800E+04, 0.79218200E+03, 0.25580400E+04, -.31760000E+05, 0.16181500E+05, 0.21621000E+05, 0.15871200E+05, 0.14047300E+04, 0.82865700E+04, -.31755600E+02, -.13043700E+05, 0.36908600E+04, 0.82474400E+04, 0.93367500E+04, 0.20206300E+04, -.10455600E+04, 0.52851300E+04, -.10152400E+04, -.38104600E+03, -.10619100E+04, 0.13901400E+04, -.15056500E+03, 0.62834000E+03, -.22800900E+04, 0.47972800E+04, 0.15256500E+05, -.73914100E+04, 0.83967600E+04, -.76331300E+04, -.74339600E+04, 0.49209800E+04, -.73208700E+04, -.73059100E+04, -.10037300E+05, 0.44448600E+04, -.66708100E+04, -.57346000E+02, 0.78782000E+02, 0.14525900E+02, 0.15139800E+02, -.62291700E+02, 0.82725300E+02, 0.13814000E+03, 0.15617400E+03, 0.51606900E+02, -.10697100E+05, 0.13235700E+05, 0.56673300E+03, 0.30801900E+03, -.23661600E+02, 0.38146200E+03, -.15288400E+05, -.39291100E+03, -.27450800E+03, -.10078400E+04, -.19990800E+03, 0.49739600E+03, -.35899100E+03, 0.40743200E+03, -.72764000E+04, 0.53409000E+03, -.10832300E+05 },
        { 0.90896500E+01, -.31440700E+00, -.32189500E+00, 0.91734800E+00, 0.84672200E+00, -.21780600E+01, 0.21682600E+01, -.58979800E+00, -.17883800E+01, -.22289800E+01, 0.11188800E+00, -.87490600E-01, -.27358000E+00, 0.27463400E-01, 0.12972100E+01, -.54154200E+00, 0.71659600E-01, 0.88168300E+00, 0.10145300E+01, 0.53057700E+00, 0.99361800E+00, -.34276800E+00, 0.13416700E+02, 0.86721300E+00, 0.13853300E+00, 0.22385500E-01, -.15695100E+00, -.63397100E-01, 0.81684700E+00, 0.70418100E+00, -.19638500E+00, 0.10664900E+01, 0.26737600E-01, 0.69408200E+00, -.35872600E+01, -.49797600E+00, -.32176700E+00, -.31256500E+01, 0.32264700E+00, -.19645800E+01, 0.66090000E+00, 0.16811700E+01, 0.29731200E+00, -.24453800E+01, -.35089600E+00, 0.40576900E+00, 0.18490400E+00, 0.72514200E-01, 0.66740700E-01, 0.79248400E-01, -.18300300E+01, -.13163600E+01, -.17631300E+00, 0.54998100E+00, -.14816100E+01, -.22291200E+00, -.85282800E-01, 0.16162700E+01, 0.14651700E+01, -.20836100E+00, -.34735400E+00, -.36100500E+00, 0.15965800E+01, -.26723700E+00, 0.17531300E+00, 0.70337500E+00, 0.24918000E+00, -.73050600E-01, -.24848500E+00, 0.10241700E-01, -.52026600E+00, -.26009800E+02, -.80335100E+01, -.15114100E+02, -.27341500E+02, -.16687900E+02, -.35699500E+02, -.25584400E+04, 0.12993700E+04, 0.33841800E+02, 0.12798900E+04, 0.51198400E+03, -.99616400E+03, 0.93435500E+03, 0.22942600E+03, 0.68562800E+03, -.72713100E+03, -.26894000E+03, 0.92694700E+04, -.54315800E+04, -.12634200E+05, -.46171000E+04, -.21140200E+04, -.10273300E+05, -.11626400E+04, -.45316400E+04, -.15514600E+04, -.82079300E+04, -.26382400E+04, -.18940500E+04, 0.17694300E+04, 0.49729200E+04, 0.93186700E+03, 0.21435900E+04, 0.74442300E+04, 0.37978700E+04, 0.10648000E+05, 0.40195300E+04, 0.68595400E+04, -.11461700E+04, 0.35923700E+04, -.18707100E+04, -.79286100E+02, -.17977900E+04, -.91686400E+03, -.40352200E+03, -.27561300E+03, 0.39887200E+03, -.12994700E+04, -.36767400E+03, -.13107800E+04, -.71321700E+02, 0.31915300E+02, -.25130600E+04, 0.34287000E+02, -.43762100E+03, -.12110200E+04, 0.93333900E+03, 0.59716400E+03, 0.84900200E+03, -.10610800E+04, -.61914200E+03, -.72887900E+04, 0.36269400E+04, 0.22469400E+04, 0.36523800E+04, -.11996000E+03, 0.73023500E+03, 0.10220400E+04, -.93653400E+03, 0.16247600E+04, 0.30797100E+03, 0.56539200E+04, 0.13488900E+05, -.67566900E+04, -.68588800E+04, -.67436600E+04, -.17170000E+04, -.10642800E+04, -.17646800E+04, 0.33997800E+04, -.11397300E+04, -.19561400E+04, -.19191200E+04, -.72945600E+04, 0.44552400E+04, 0.89854600E+04, 0.36204200E+04, 0.38780200E+04, 0.11037700E+05, 0.14200100E+04, 0.67489400E+04, 0.21512800E+04, 0.98585400E+04, 0.16127400E+04, -.16979000E+04, 0.87520500E+03, -.14050000E+03, 0.85097400E+03, -.25308200E+03, -.12409500E+04, 0.13436600E+04, 0.12160300E+04, 0.19708600E+04, -.91600700E+03, -.10311100E+04, 0.80120000E+03, -.31549900E+03, -.50511400E+03, -.40396800E+03, -.41257300E+03, 0.58704100E+03, -.88782800E+03, -.12716700E+04, -.63746500E+03, 0.17490700E+03, 0.60681900E+03, -.70580600E+04, 0.35196300E+04, 0.31168900E+04, 0.35284000E+04, 0.70755200E+03, -.16968900E+04, 0.27752600E+04, 0.10767800E+04, 0.37382700E+04, -.28746100E+03, -.13741200E+04, 0.22258200E+04, -.10380700E+04, 0.15341700E+03, -.11120800E+04, 0.12958900E+03, 0.97016000E+03, -.28170100E+03, 0.10023400E+04, -.36844400E+03, 0.39845800E+03, -.58283900E+03, -.59875800E+04, 0.29674600E+04, 0.22057700E+04, 0.29906000E+04, 0.91872100E+03, -.14745500E+04, 0.22746500E+04, 0.66992900E+03, 0.35348200E+04, -.32305900E+03, -.12817300E+04, -.15046900E+05, 0.75110600E+04, 0.77065500E+04, 0.75270900E+04, 0.16529600E+04, 0.21971700E+04, 0.19905200E+04, -.29280700E+04, 0.15655400E+04, 0.23658100E+04, 0.43768300E+04, -.64863600E+04, 0.32223800E+04, 0.24055600E+04, 0.32420100E+04, 0.40278700E+03, 0.13692800E+04, 0.59819000E+03, -.14450100E+04, 0.13843500E+04, 0.10492000E+04, 0.36346900E+04, -.34853700E+04, 0.21120100E+04, 0.35431900E+04, 0.17333500E+04, 0.50588400E+03, 0.21161900E+04, 0.35489000E+04, 0.60818500E+04, 0.35253800E+04, 0.20697200E+04, -.22354600E+03, -.85812400E+03, 0.47079800E+03, 0.15497700E+04, 0.42296600E+03, -.10380200E+04, 0.73220900E+03, 0.44975400E+03, 0.56499500E+03, 0.38660200E+03, -.22419400E+03, 0.41843700E+04, -.45962600E+04, 0.26711000E+04, 0.57234700E+04, 0.22938500E+04, 0.49631700E+03, 0.42910000E+04, 0.10507700E+04, 0.26189000E+04, 0.16080000E+04, 0.33839800E+04, 0.59160700E+03, -.95489800E+02, -.11509000E+02, 0.96056200E+01, -.50811400E+02, -.17914400E+02, 0.10644500E+03, 0.32812100E+02, -.29650500E+02, 0.11062000E+03, -.25962100E+04, 0.22567600E+04, -.59412400E+02, 0.28465200E+03, 0.18468700E+02, 0.51511600E+03, -.27305400E+04, 0.36452400E+02, 0.12783000E+03, -.50720700E+03, 0.12378900E+04, 0.23841100E+03, -.13209100E+03, 0.12271400E+03, -.20530000E+04, -.49624700E+03, -.22890000E+04 },
        { 0.10674600E+02, -.24623500E+00, -.38479700E+00, 0.15836200E+00, 0.76650000E+00, -.17767100E+01, -.10949300E+01, -.50912400E+00, 0.29028400E+01, -.10515500E+01, -.91605700E+00, 0.12735600E+01, -.69200100E-01, -.73246000E-01, 0.33569400E+00, -.41104700E+00, -.11173600E+00, -.28637700E+00, 0.41643400E+00, -.50225700E+00, -.72085700E+00, -.24366500E+00, -.27109300E+01, 0.79636700E-01, -.11882100E+00, -.11661500E+00, -.36905800E+00, -.61781500E+00, 0.10630800E+00, 0.73784000E+00, 0.92429900E+00, 0.14121200E+01, 0.20462200E+00, -.13926400E+01, -.11032000E+01, 0.40860900E+00, 0.46490900E-03, 0.13571500E+01, -.10195800E+01, -.90125900E+00, 0.12030400E+01, 0.26453700E+01, 0.10666500E+01, -.24364400E+01, 0.26623800E+01, 0.12646500E-01, 0.29104300E+00, -.40078600E-01, -.11675500E+00, 0.22229800E+00, 0.10725700E+01, -.94906400E+01, 0.87198700E+00, -.26336200E-01, 0.17963100E+01, -.25714500E+00, -.54245600E-01, 0.54724000E+00, -.40613300E+00, 0.26063400E+00, 0.46668100E+00, -.49479400E+00, -.14857000E+00, 0.60640300E+00, 0.53275400E+00, 0.25431000E+00, -.36714200E+01, 0.34584800E-01, 0.25384100E+00, -.13151200E-01, 0.69010700E-02, 0.98372300E+00, 0.68790300E+02, 0.62573300E+02, 0.65891000E+02, -.13861300E+02, 0.54768400E+02, 0.35559100E+04, -.17894500E+04, 0.28897800E+03, -.17788500E+04, -.20885500E+03, 0.19074200E+04, -.16212700E+04, -.34606100E+03, -.85336300E+03, 0.15223500E+04, 0.49403100E+03, -.15642600E+04, 0.23529900E+04, 0.95000000E+04, 0.75117300E+03, 0.30497200E+04, 0.19808400E+05, -.21690500E+04, 0.59371500E+04, 0.69885200E+03, 0.16443500E+05, 0.20427300E+04, -.12579700E+04, -.91581600E+03, -.54802500E+04, 0.65135000E+03, -.32879500E+04, -.15107400E+05, -.31576500E+04, -.10981700E+05, 0.13291900E+04, -.14033800E+05, 0.17505200E+03, 0.50223900E+04, -.23336300E+04, -.25371800E+04, -.25088000E+04, -.10781000E+04, -.12849600E+04, 0.14280400E+03, 0.18410400E+04, -.62826500E+03, -.94642800E+03, -.36674600E+04, 0.25023800E+04, -.12817000E+04, 0.29896700E+04, -.12491700E+04, 0.15389600E+04, 0.32146600E+04, -.17932900E+04, 0.14722400E+04, -.17172900E+04, 0.17277900E+04, 0.20326100E+04, 0.95342700E+04, -.47036400E+04, -.32209500E+04, -.47808900E+04, 0.50941500E+03, -.13625700E+04, -.11921800E+04, 0.53711600E+03, -.26380900E+04, -.11410100E+03, -.91691000E+04, -.26904000E+05, 0.13463900E+05, 0.13521600E+05, 0.13450800E+05, 0.36911400E+04, 0.22163900E+04, 0.32041000E+04, -.71961300E+04, 0.27108300E+04, 0.39346800E+04, 0.60309000E+04, 0.16554200E+04, -.23076400E+04, -.79856700E+04, -.78586000E+03, -.50186500E+04, -.19652800E+05, 0.36045800E+03, -.77685600E+04, 0.18650100E+04, -.17737000E+05, -.12046100E+04, 0.66438500E+03, -.35309900E+03, 0.13026400E+04, -.33517500E+03, 0.54913600E+03, 0.32252300E+04, -.31264400E+04, -.21819700E+04, -.18849000E+04, 0.28810500E+04, 0.14910600E+04, -.16105800E+04, 0.57527300E+03, 0.39524800E+03, 0.81015800E+03, 0.11390400E+04, -.39988300E+03, 0.26579400E+03, 0.34501500E+03, -.57290100E+03, 0.27971300E+02, 0.32476800E+03, 0.16982900E+05, -.84762100E+04, -.86436600E+04, -.84906500E+04, -.25453500E+03, 0.39965800E+04, -.66589300E+04, -.14413900E+04, -.86789600E+04, 0.10543900E+04, 0.58288200E+04, -.44045800E+04, 0.20597400E+04, 0.13798800E+03, 0.22007700E+04, -.45259300E+03, -.17573000E+04, 0.58879500E+03, -.20930600E+04, 0.33904600E+03, -.90491700E+03, 0.12380300E+04, 0.14776700E+05, -.73265600E+04, -.61955800E+04, -.73838200E+04, -.44834800E+03, 0.41546300E+04, -.58145000E+04, -.15275300E+04, -.91301500E+04, 0.16260000E+04, 0.43928000E+04, 0.36080100E+05, -.18002100E+05, -.18069500E+05, -.18045200E+05, -.47986400E+04, -.43173800E+04, -.53392200E+04, 0.75450600E+04, -.35400800E+04, -.47468400E+04, -.14620800E+05, 0.13126700E+05, -.65504400E+04, -.63545500E+04, -.65616700E+04, -.10562800E+04, -.20813000E+04, -.20750400E+04, 0.28543900E+04, -.16003800E+04, -.17687300E+04, -.60798800E+04, -.17870500E+04, 0.13980100E+03, -.19868900E+04, 0.90837300E+03, -.41802600E+03, -.55273900E+04, -.25546200E+04, -.61452500E+04, -.18669200E+03, -.55383100E+04, 0.18152800E+04, -.68908800E+04, 0.33106900E+04, 0.16419000E+04, 0.34540400E+04, 0.39949400E+04, 0.70905500E+03, -.12897100E+04, -.31418100E+04, -.66601600E+03, 0.23898300E+04, -.29948800E+04, 0.43416800E+04, -.29503700E+04, -.54173300E+04, -.21627800E+04, -.79987400E+03, -.83352300E+04, -.76189000E+03, -.36152100E+04, -.26449500E+04, -.68481400E+04, -.97726200E+03, 0.15893400E+03, -.69638000E+02, 0.23382900E+03, 0.12401900E+03, -.27873300E+03, 0.15354700E+03, 0.10989000E+03, 0.32579000E+02, -.31783800E+03, 0.42921500E+04, -.50851500E+04, -.89986700E+03, -.19897800E+03, 0.41581100E+03, -.97240300E+03, 0.56307300E+04, 0.19080200E+03, -.34895000E+03, 0.15930500E+04, -.12509900E+04, -.10603000E+04, 0.26838400E+03, -.24351600E+03, 0.36940100E+04, 0.14273300E+04, 0.44175300E+04 },
        { 0.18258200E+02, -.28061600E+00, -.13377900E+01, -.61974300E+00, 0.56689300E+00, -.21845800E+01, 0.13913300E+01, -.16243100E+01, -.11006500E+01, -.10287200E+01, -.11934000E+00, 0.12504500E+01, 0.21689200E+00, 0.52101500E+00, -.16181500E+00, -.34512500E+00, -.32418600E-01, -.65568100E+00, 0.18111100E+01, -.25291600E+00, 0.30652300E+00, 0.19458000E+00, -.11530900E+02, -.20000200E+01, -.67153700E+00, 0.36648800E-01, -.34463000E+00, -.18929300E+00, -.10979500E+01, -.53595200E+00, -.34514400E+00, 0.15256200E+01, 0.10670000E-01, 0.12383200E+00, 0.48005900E+01, -.11079600E+01, -.33964400E+00, 0.69224400E+00, -.17304400E+00, -.66291800E+00, -.34750600E-01, 0.40934000E+01, -.82260400E+00, -.15671700E+01, 0.21744700E+01, -.56960800E+00, -.16916800E+00, 0.25546700E-01, -.49042000E+00, -.10032800E+00, 0.34915500E+01, -.10846700E+02, 0.10702000E+01, 0.90395400E+00, -.45243800E+01, 0.14942200E+01, -.43936500E-01, 0.29314200E+01, 0.73898600E+00, -.10357900E+00, -.51287800E+00, -.52994900E+00, 0.13221400E+01, -.20625200E+00, 0.14179500E+01, 0.32213300E+00, -.42621200E+01, 0.30128200E-01, 0.24175400E-01, 0.52756400E-02, 0.10727700E+00, -.95473900E+00, -.79570900E+00, 0.70889600E+02, 0.38021100E+02, 0.46024800E+01, -.41138900E+01, -.65937300E+03, 0.33742200E+03, 0.25079200E+04, 0.32971700E+03, -.64083600E+03, -.95963400E+02, 0.20088000E+03, 0.27414400E+03, 0.10236100E+03, -.15692400E+03, 0.14512900E+04, -.58061800E+04, 0.36221200E+04, 0.10526700E+05, 0.28981100E+04, 0.19155900E+04, 0.35677400E+04, 0.28985300E+04, 0.11899100E+04, 0.26637900E+04, 0.17523200E+04, 0.54234100E+04, -.23656400E+04, 0.56651000E+03, -.18090500E+05, 0.11839100E+04, 0.23721000E+04, 0.22845500E+04, -.54115000E+04, -.18000000E+04, 0.37032700E+04, 0.23542000E+04, -.40438100E+03, 0.15839800E+05, -.78083300E+04, -.39660200E+04, -.79197900E+04, -.36751800E+04, -.32883500E+04, -.31950300E+03, 0.39944700E+04, -.34078600E+04, -.25731600E+04, -.80489400E+04, 0.11629700E+04, -.62549200E+03, -.35329100E+04, -.58139100E+03, 0.24709800E+04, 0.29720600E+03, 0.14738200E+02, 0.20411000E+04, -.29974300E+03, 0.92788200E+02, 0.13551500E+04, -.11919100E+04, 0.65802800E+03, 0.50278800E+03, 0.59449200E+03, 0.91875700E+02, -.30172800E+03, 0.19854800E+03, -.14631800E+04, -.87023100E+03, 0.46372600E+03, -.15401000E+04, -.50279100E+04, 0.25157000E+04, 0.27370300E+04, 0.25139000E+04, 0.17007600E+04, 0.12024400E+03, -.12669100E+03, -.24552700E+04, -.43198200E+03, 0.82595400E+03, -.32681000E+03, -.29574300E+04, 0.87198600E+03, -.15486200E+05, 0.14823600E+04, 0.93133700E+03, -.13236400E+02, -.38349800E+04, -.18540500E+04, 0.28365800E+04, 0.48298300E+03, 0.20921200E+03, 0.45729000E+03, -.22702400E+03, 0.36140300E+04, -.22878100E+03, -.25282600E+03, 0.78777400E+03, 0.27044400E+03, -.83027300E+03, -.30386200E+03, 0.60472200E+03, 0.67699400E+03, -.57362900E+03, 0.94832700E+02, -.40520000E+03, 0.28697100E+03, 0.94370000E+03, -.72106400E+03, 0.15102800E+03, -.40968800E+03, -.25152600E+03, -.56180400E+03, 0.70021200E+03, 0.94559800E+04, -.47165100E+04, -.67089200E+04, -.47280600E+04, -.72832200E+03, 0.19836900E+04, -.40229500E+04, 0.22584400E+03, -.29814600E+04, 0.25463900E+03, 0.46067700E+04, -.89244600E+03, 0.36407000E+03, 0.10619200E+03, 0.44593100E+03, -.27310200E+02, -.64292600E+03, 0.20794100E+03, -.88700200E+03, -.43243200E+03, -.27833300E+03, -.10306100E+03, 0.75503500E+04, -.37267400E+04, -.50647800E+04, -.37750900E+04, -.15876800E+03, 0.25603200E+04, -.33701000E+04, -.71270700E+03, -.42126400E+04, 0.11291800E+04, 0.31778200E+04, 0.12152800E+05, -.60421100E+04, -.61897900E+04, -.60765400E+04, -.35298100E+04, -.17711700E+04, -.12463900E+03, 0.26947000E+04, -.20011600E+04, -.16393900E+04, -.63130300E+04, -.41273200E+04, 0.20541800E+04, -.26507500E+04, 0.20637000E+04, 0.81998400E+03, 0.11684000E+04, -.68643300E+03, -.16785400E+04, 0.15852500E+04, 0.11035400E+04, 0.10592200E+04, 0.10727000E+03, -.38475900E+03, -.82025500E+04, -.52127700E+02, 0.17580100E+04, 0.13932800E+04, -.28122400E+04, -.39381200E+03, 0.93284600E+03, 0.11808700E+04, -.25649500E+03, 0.34355700E+04, -.18359200E+04, -.32039700E+04, -.17176600E+04, 0.13799800E+04, -.19271600E+04, 0.10616100E+03, -.28211900E+03, -.25157500E+04, -.76857500E+03, -.26039000E+04, 0.47903800E+04, -.27865000E+04, -.54193500E+04, -.23935600E+04, -.81300900E+03, -.13108600E+04, -.21895600E+04, -.11429100E+04, -.26428900E+04, -.30593500E+03, -.32647600E+04, 0.16163200E+03, -.12571700E+02, 0.13719000E+03, 0.38468900E+02, -.16693100E+03, 0.15834800E+03, 0.11428200E+03, -.73227300E+01, -.25366700E+03, 0.29373500E+03, -.13038500E+04, -.15345900E+04, 0.27343100E+03, 0.24025500E+03, -.38094200E+03, -.32283600E+02, 0.33085000E+03, -.32897500E+03, 0.59096200E+03, -.16271500E+04, -.66553300E+03, 0.92312700E+02, -.12828400E+03, 0.24580900E+04, 0.13073100E+04, 0.69716200E+03 },
        { 0.37695000E+01, -.31515900E-01, -.10398600E+00, 0.16274700E+01, 0.18942300E+00, 0.25860400E+00, -.10616800E+01, 0.36492200E+00, 0.17958500E+01, 0.50057100E+00, 0.35560100E-01, 0.21562300E+00, 0.16611200E-02, -.86683100E-01, 0.37760000E+00, 0.11168300E+00, -.15132100E+00, -.21954900E+00, -.10570900E+00, -.20526800E+00, -.23376000E+00, -.57359200E-01, -.33227000E+01, 0.14088000E+00, -.30635000E-01, 0.52144600E-02, -.11595200E+00, -.37559400E+00, 0.16621200E+00, -.25259700E+00, -.31338000E+00, 0.73938100E-01, -.10618100E-01, 0.29845800E+00, -.68642100E+00, -.11577800E+00, 0.11144700E+00, -.11598400E+01, 0.87977300E-01, 0.10653100E+00, 0.15617900E+00, -.28215400E+00, 0.51286800E-01, -.26569500E+00, 0.26718300E-01, -.14217800E+00, 0.42342100E-01, -.13415900E-01, -.14201300E-01, 0.50314600E-01, 0.11698700E+00, -.13682800E+01, 0.20231500E+00, -.14569600E+00, -.28567500E+00, 0.30675200E+00, 0.39229600E-01, -.16984800E+00, -.11079000E+00, 0.11169700E+00, -.51452100E-01, -.21829000E+00, -.26932800E+00, 0.40297100E-01, 0.41963600E+00, -.10038700E-01, -.20245800E+00, 0.63762800E-02, -.71600100E+00, -.12908800E-02, 0.92555300E-01, 0.18467400E+00, 0.78533800E-01, -.62555900E-01, 0.73906500E+01, -.21023600E+01, 0.45772800E+01, 0.38773400E+03, -.20542700E+03, -.78028400E+02, -.19399800E+03, -.53410600E+02, 0.12706400E+03, -.14515300E+03, -.20530100E+02, -.16050000E+03, 0.88129700E+02, 0.54989400E+02, 0.74773600E+03, -.15148100E+03, -.94730600E+03, -.37795400E+03, -.61781800E+03, 0.20983900E+04, -.73863000E+03, -.29731000E+03, -.14117800E+04, 0.18920300E+04, -.70481800E+01, 0.48370400E+04, -.26497600E+04, -.82539800E+03, -.24153600E+04, -.51507200E+03, -.20482100E+04, -.41020100E+03, 0.54883200E+03, -.11326200E+04, -.18878400E+04, -.17162300E+04, -.14539600E+03, 0.83387200E+02, -.26580600E+03, 0.73035400E+02, 0.27768000E+03, -.42091900E+02, 0.61060900E+02, 0.15828700E+03, 0.27226900E+03, -.21900300E+02, 0.50117900E+02, 0.43031800E+02, -.19119800E+02, 0.13770500E+04, -.21230200E+02, 0.15822400E+03, 0.22592700E+03, -.10088600E+02, 0.39211300E+03, 0.86706300E+02, 0.15430300E+03, -.75109200E+02, 0.15413400E+04, -.76826900E+03, -.51322500E+03, -.77232900E+03, 0.13924600E+02, -.13316200E+03, -.24420800E+03, 0.98225300E+02, -.53820300E+03, -.15053500E+02, -.11242800E+04, -.34074800E+04, 0.17034300E+04, 0.19056600E+04, 0.17035700E+04, 0.50257000E+03, 0.35645400E+03, 0.37146900E+03, -.10073800E+04, 0.17599200E+03, 0.55502800E+03, 0.75250300E+03, 0.43933900E+04, -.24205600E+04, -.70232200E+03, -.21909200E+04, -.49295600E+03, -.24733700E+04, 0.91219200E+01, 0.84947100E+03, -.36802400E+03, -.22728000E+04, -.19271300E+04, 0.10293700E+04, -.51281900E+03, -.29292300E+03, -.51510800E+03, 0.98512800E+02, 0.38546700E+03, -.38207600E+03, -.55830900E+02, -.66208100E+03, 0.34395300E+03, -.47047500E+02, -.11117000E+02, -.16078900E+02, 0.64342500E+02, 0.62513900E+01, 0.19262000E+03, -.11946900E+03, 0.17644800E+03, 0.26008000E+03, 0.19225400E+03, -.31206500E+02, -.29970200E+03, 0.15820100E+04, -.80412300E+03, -.73647700E+03, -.79088600E+03, -.24071300E+03, 0.41747500E+03, -.57268100E+03, -.15379400E+03, -.60556900E+03, 0.10797900E+03, 0.84191900E+02, -.10320500E+04, 0.50925400E+03, 0.39769600E+03, 0.51583000E+03, -.47801500E+01, -.16159500E+03, 0.19926300E+03, -.25978600E+03, 0.24711000E+03, -.82823500E+02, 0.35311300E+03, 0.13227000E+04, -.66418800E+03, -.65725300E+03, -.66070300E+03, -.27334800E+03, 0.32376000E+03, -.46907700E+03, -.12075800E+03, -.63891200E+03, 0.67829000E+02, 0.36239100E+02, 0.32164400E+04, -.15987800E+04, -.15196000E+04, -.16089600E+04, -.48554100E+03, -.48584700E+03, -.37002300E+03, 0.82077700E+03, -.48207000E+03, -.53815100E+03, -.86138100E+03, 0.36741600E+03, -.17930500E+03, 0.14548900E+03, -.18346900E+03, -.52790200E+02, -.35961100E+02, -.15927500E+03, -.75137300E+02, -.34920100E+03, -.10600000E+02, -.21052500E+03, 0.19721400E+04, -.10959600E+04, -.43956500E+03, -.98404000E+03, -.15198600E+03, -.87521900E+03, -.22496000E+03, 0.17422700E+03, -.49697100E+03, -.84720100E+03, -.44165000E+03, 0.13847800E+03, -.82812800E+02, -.14486200E+03, -.68001800E+02, 0.25526600E+03, -.19887800E+03, -.10517900E+01, 0.54679300E+02, 0.15690700E+03, 0.31876500E+02, -.82200700E+03, -.82770500E+03, 0.31073700E+03, 0.85544900E+03, 0.41488500E+03, 0.49593800E+03, -.80262300E+03, 0.30256200E+03, 0.87665700E+01, 0.78095300E+03, -.73430300E+03, 0.22128200E+03, 0.24630300E+02, -.97606300E+01, 0.98965300E+01, 0.12564200E+02, 0.41823700E+00, -.10766900E+02, 0.45565400E+01, 0.13102700E+02, -.14011000E+02, 0.10239600E+04, -.11259800E+04, 0.97669000E+02, -.21860000E+02, 0.47006400E+02, -.97643900E+02, 0.14072700E+04, -.48220200E+02, -.61993800E+01, 0.10248800E+03, -.26901500E+03, -.48308100E+02, -.40594800E+00, -.22487700E+02, 0.64968000E+03, 0.10683400E+03, 0.84091900E+03 },
        { 0.53748700E+01, -.16825100E+00, -.21386100E+00, -.13956600E+01, 0.41380900E+00, -.11815400E+01, 0.43992100E+00, 0.59086000E-01, -.74562500E+00, -.13671700E+01, 0.32176900E-02, -.16789000E+01, -.17139800E+00, -.22065400E-01, -.17388300E+00, 0.13908200E+00, -.82967300E+00, -.14056500E+00, 0.23361400E-01, 0.25389500E+00, 0.12986800E+00, -.30607400E+00, -.40153400E+01, 0.15338000E+00, -.33745900E-01, 0.25453800E+00, -.20400000E-01, 0.48457500E+00, 0.84301400E+00, 0.13461800E+01, 0.52392100E+00, 0.85255600E+00, -.33754500E-01, 0.35178300E+00, -.94507600E+00, -.87384700E-01, 0.13834500E+00, -.98660800E-02, 0.23648400E+00, -.43671300E+00, 0.67277400E-01, -.26985200E+00, 0.36249100E+00, -.15674600E+00, -.25081800E+00, -.58457500E-01, -.87448300E-01, -.39235100E-02, 0.85920500E-01, -.12518700E-01, -.96490300E-02, -.45323200E-01, 0.19094900E+00, -.18680900E+00, -.86298100E-01, -.39157200E-01, 0.22359600E-01, -.62902400E+00, -.96542600E-01, -.88898400E-02, 0.36633100E+00, -.21500700E+00, -.69561000E+00, -.98212800E-01, 0.29988000E+00, -.50874600E-01, 0.95758500E-01, 0.11834500E-01, -.96847900E+00, 0.41539200E-02, 0.64407000E-01, 0.30624600E-01, -.14000600E+00, -.12509700E+00, 0.10470800E+01, 0.66998300E+01, 0.12595200E+01, -.52266700E+03, 0.28165100E+03, 0.79234500E+03, 0.26140300E+03, 0.53842200E+02, -.51154400E+02, 0.23132100E+03, 0.22449000E+03, 0.30232600E+03, -.34243500E+02, 0.13991900E+03, -.10719600E+04, 0.49405700E+03, 0.47591500E+04, 0.53743700E+03, 0.17014000E+04, -.20788600E+04, 0.29117300E+04, 0.31793200E+04, 0.24739400E+04, -.20578000E+04, 0.42752800E+03, -.10936800E+05, 0.55537800E+04, -.35215400E+04, 0.54669100E+04, 0.92386800E+03, 0.26005300E+04, -.10741700E+04, -.35896900E+04, 0.37776600E+04, 0.23408200E+04, 0.41186400E+04, 0.37800900E+04, -.18643400E+04, -.65581000E+03, -.18902000E+04, -.12619400E+04, -.71320200E+03, -.14403800E+03, 0.67045000E+03, -.11962400E+04, -.59946900E+03, -.18628000E+04, 0.85544300E+03, -.44313500E+03, -.21763400E+04, -.42785400E+03, 0.12237900E+03, 0.37362400E+03, -.63310000E+03, -.76580900E+03, -.60544900E+03, 0.33053600E+03, 0.19510400E+03, -.11090300E+03, 0.71547600E+02, 0.18366500E+03, 0.55989900E+02, -.13756300E+02, 0.63815300E+02, 0.75666000E+02, 0.75140100E+02, -.88641000E+01, 0.55606200E+02, 0.99642400E+02, 0.11196900E+04, -.55752100E+03, -.56298400E+03, -.55976800E+03, -.25767200E+03, -.20637000E+03, -.26640100E+03, 0.13237700E+03, -.48648800E+02, -.17656500E+03, -.34876400E+03, -.10218900E+05, 0.51917400E+04, -.30062200E+04, 0.51069700E+04, 0.61986300E+03, 0.28906300E+04, -.15547400E+04, -.41458400E+04, 0.22904900E+04, 0.26385000E+04, 0.44127500E+04, -.20117300E+04, 0.10030300E+04, 0.13743400E+04, 0.10060600E+04, 0.17994300E+03, -.35804500E+03, 0.67086300E+03, 0.53079200E+02, 0.10256300E+04, -.27726800E+03, 0.29371600E+03, -.25102600E+03, 0.96626700E+02, -.26229600E+03, 0.12518400E+03, -.18510200E+03, 0.62237900E+02, -.30189800E+03, -.40181500E+03, -.37550500E+03, -.12801700E+03, 0.64463800E+03, -.54724100E+02, 0.51456600E+02, -.41376000E+03, 0.27294200E+02, 0.26277900E+03, -.88283800E+02, -.13014300E+03, 0.46938700E+03, 0.49862500E+02, -.17324100E+03, 0.10436100E+04, 0.15487400E+04, -.80032000E+03, -.64671400E+03, -.77430600E+03, -.10173400E+03, 0.92078000E+02, -.32840500E+03, 0.10076500E+03, -.59805300E+03, 0.31772500E+02, -.65734700E+03, 0.92594800E+01, 0.15822400E+02, -.13244800E+02, -.49456900E+01, 0.42379200E+03, 0.16616200E+03, -.12176400E+03, 0.23919400E+03, -.28110000E+03, 0.78532000E+02, 0.70064800E+03, 0.13873200E+04, -.69884600E+03, -.76751100E+03, -.69330600E+03, -.20992300E+03, -.12439400E+02, -.23239500E+03, 0.14636500E+03, 0.13944900E+02, -.83151500E+01, -.13278200E+04, -.11482900E+02, -.31831800E+01, -.10841100E+04, 0.56253900E+01, 0.10585700E+03, 0.24938800E+03, -.34001400E+03, -.62812400E+02, 0.69381400E+03, 0.14721200E+03, 0.66824300E+02, -.40316900E+04, 0.20476500E+04, -.15459100E+04, 0.20150000E+04, 0.44937700E+03, 0.11867000E+04, -.60818900E+03, -.15366700E+04, 0.13360300E+04, 0.11026200E+04, 0.12387000E+04, -.95481400E+03, 0.46057000E+03, -.64361900E+02, 0.47680000E+03, 0.24939300E+03, 0.38985900E+03, -.33872400E+03, -.59539900E+03, -.59662000E+03, 0.30103300E+03, 0.80759900E+03, 0.18143900E+04, -.90616100E+03, -.31653300E+04, -.90750600E+03, -.11187400E+04, 0.87347700E+03, -.16524100E+04, -.14733200E+04, -.16833200E+04, 0.89893700E+03, -.61346500E+03, -.11590200E+02, -.12987100E+02, 0.67141200E+01, -.11883900E+02, -.37657600E+02, 0.35561000E+02, 0.50723700E+02, -.20900300E+02, -.38460400E+02, -.17464600E+04, 0.15145100E+04, -.50810700E+03, -.11833600E+02, -.69366000E+02, 0.10172800E+02, -.23316300E+04, 0.89909300E+02, -.38523200E+02, 0.49376900E+02, 0.45276200E+03, -.12379400E+03, 0.62232200E+01, -.40220000E+02, -.39004600E+03, 0.93617400E+02, -.14446600E+04 },
        { -.27504900E+01, 0.54437800E-01, 0.94848100E-01, 0.33941700E+00, -.31171400E+00, 0.54855900E+00, 0.17009500E-01, 0.31914600E+00, -.61615500E+00, 0.42063400E+00, 0.18932300E+00, -.51969000E+00, -.98801000E-01, -.63303900E-02, -.33481600E-01, 0.50472300E-01, -.17672500E-01, 0.10064700E-02, -.15087600E+00, 0.20376900E+00, 0.39804000E+00, -.17302700E+00, 0.42658200E-03, 0.24587300E+00, -.17432900E-01, 0.48497600E-01, -.10725400E+00, 0.28492800E+00, 0.63411100E+00, -.33213300E+00, 0.81482300E-01, -.73026800E+00, -.10978600E+00, 0.17656700E+00, -.46015600E+00, -.73160200E-01, 0.96921300E-02, -.54846900E+00, 0.37121000E-01, -.12193700E+00, 0.67887100E-01, 0.11732900E+00, -.77620400E-01, -.18741300E+00, 0.59377500E-01, -.77459900E-01, -.42557500E-01, -.61771500E-03, -.20098500E-01, 0.27327200E-01, -.11293000E+00, -.49056800E-02, -.40192400E-02, 0.41258400E-01, -.46843900E+00, -.73365900E-02, 0.14002600E-01, 0.24739200E-01, 0.20890600E-01, -.37960600E-01, -.55055600E-01, 0.35244400E-01, -.74131700E-01, 0.27445400E-01, 0.10806100E+00, -.45416400E-01, 0.33981100E+00, 0.40440100E-02, 0.23232800E+00, 0.77263900E-03, 0.31457800E-01, -.44546000E-01, -.35735300E-01, 0.20999900E-01, 0.19854500E-02, 0.93010700E-02, 0.17223900E+02, -.53248600E+02, 0.27623900E+02, 0.64088400E+02, 0.26622700E+02, 0.62697200E+02, -.19130000E+02, 0.39950200E+02, 0.78606300E+02, -.10101400E+01, -.20519500E+02, -.11163900E+03, 0.27926600E+04, -.13780600E+04, -.15353400E+04, -.13963800E+04, 0.12850000E+03, 0.24137000E+03, -.66321500E+03, 0.54444300E+03, -.86961600E+03, 0.18496200E+01, 0.17512700E+03, -.49733900E+04, 0.24705000E+04, 0.22053000E+04, 0.24867200E+04, 0.25789900E+03, -.37335000E+03, 0.12427300E+04, -.27493800E+03, 0.17793200E+04, -.16765600E+03, 0.70915500E+03, 0.22658600E+03, -.10940600E+03, -.38694500E+02, -.11329000E+03, -.47128600E+02, -.40938300E+02, -.12875600E+02, 0.18898600E+02, -.56861600E+02, -.30143600E+02, -.85355900E+02, -.61300100E+02, 0.28965400E+02, 0.23993500E+03, 0.30653700E+02, -.78641400E+02, 0.35715800E+02, 0.26132400E+01, -.50627600E+01, 0.36947700E+02, -.35926000E+01, 0.39671900E+03, 0.20033300E+03, -.98307900E+02, -.15447900E+03, -.10040400E+03, -.26165300E+02, -.30968400E+02, -.30976300E+02, -.15611000E+02, -.31697300E+02, -.13673900E+02, -.16593500E+03, -.68651500E+03, 0.34286600E+03, 0.43768000E+03, 0.34325500E+03, -.99237900E+01, 0.10741100E+03, 0.91923500E+02, -.30912100E+03, 0.75795400E+02, 0.12343900E+03, 0.29310700E+03, -.47366700E+04, 0.23516100E+04, 0.22297400E+04, 0.23684000E+04, 0.22229300E+03, -.34663800E+03, 0.11728600E+04, -.37751600E+03, 0.16059800E+04, -.12024800E+03, 0.48601200E+03, 0.14452400E+03, -.70770900E+02, -.13605200E+03, -.72267600E+02, 0.13903400E+03, -.81066100E+02, 0.43031200E+02, 0.97624700E+02, -.62346400E+02, -.51793200E+02, -.28786400E+03, -.19645900E+03, 0.93449000E+02, 0.56580300E+02, 0.98238500E+02, -.29572700E+02, -.12492400E+02, 0.73703200E+02, 0.17462200E+02, 0.12332800E+03, -.22257700E+02, 0.27332900E+03, 0.85128200E+02, -.42980100E+02, -.10527200E+03, -.42562400E+02, -.30315200E+01, 0.66235100E+02, -.26113100E+02, 0.32599600E+02, -.14328500E+02, 0.15072800E+02, 0.22591400E+03, -.90181400E+02, 0.43387300E+02, 0.90468100E+02, 0.45088000E+02, -.56835100E+02, -.35698900E+01, 0.16262900E+02, -.41644600E+02, 0.21707900E+02, 0.14601800E+01, 0.62627500E+02, 0.18955800E+03, -.94009100E+02, -.17667600E+03, -.94770800E+02, -.20020600E+02, 0.80026700E+02, -.77255300E+02, -.19752600E+02, -.82068800E+02, 0.13672900E+02, 0.15567100E+03, 0.39660300E+03, -.19715000E+03, -.19997900E+03, -.19831100E+03, -.48420100E+02, -.59704000E+02, -.74935200E+02, 0.16541400E+03, -.46139800E+02, -.81687400E+02, -.16399700E+03, -.10416500E+03, 0.50829300E+02, -.48091400E+02, 0.52085400E+02, -.75500200E+02, 0.45898500E+02, -.27055600E+01, -.91454500E+02, 0.40970600E+02, 0.20116300E+02, 0.10507600E+03, -.16828900E+04, 0.83424500E+03, 0.78106800E+03, 0.84146400E+03, 0.60629100E+02, -.10270300E+03, 0.34554000E+03, -.22361500E+03, 0.58930600E+03, -.18777000E+02, 0.17166500E+03, -.77609100E+02, 0.35402300E+02, 0.29104200E+03, 0.38820100E+02, -.53770500E+02, -.11877600E+02, -.19122400E+02, -.17437900E+03, 0.84857000E+02, 0.47286500E+01, 0.18780100E+03, -.14836300E+04, 0.73162500E+03, 0.76360300E+03, 0.74184000E+03, -.95874200E+02, -.16370600E+03, 0.41325800E+03, -.17611500E+03, 0.54212300E+03, -.54625300E+02, -.91245700E+01, -.80693500E+01, -.50227000E+01, 0.62642900E+00, -.15810700E+01, 0.75610800E+00, 0.20170000E+01, 0.72744800E+01, -.32816400E+00, 0.36184300E+01, -.25982600E+03, 0.12461500E+03, 0.22954400E+02, -.33946900E+00, 0.73325500E+01, 0.32374600E+02, -.21114800E+03, -.30806400E+02, 0.75596900E+00, 0.25691500E+02, 0.22547300E+03, -.17552400E+02, -.11666500E+02, 0.24369100E+00, -.70275400E+02, -.11602900E+02, -.27711900E+03 },
        { 0.31676800E+00, -.17305500E-01, -.16161700E-01, -.52460600E-01, 0.68962700E-01, -.17887400E+00, 0.18430600E+00, -.14530800E+00, -.27582900E-01, -.14809200E+00, 0.35254300E-02, 0.15287400E+00, -.22657100E-01, 0.62107800E-03, -.42323600E-01, -.47026400E-01, 0.18329500E-01, 0.42874600E-02, 0.46935200E-01, -.42043300E-01, -.57349600E-01, 0.27182000E-01, -.16738900E+00, -.70892800E-01, 0.14019000E-01, -.14945800E-01, 0.24672400E-01, -.54350800E-01, -.87944900E-01, -.40398500E-01, -.60413000E-01, 0.43589000E-01, 0.83662800E-02, -.69627300E-01, 0.17411700E+00, 0.24316200E-01, -.18612400E-01, -.10102700E+00, 0.13028200E-01, 0.32048100E-01, -.46784800E-01, -.34108700E-01, 0.25930500E-01, -.16302100E-01, -.41343300E-01, -.94763000E-02, -.18407300E-03, 0.36161000E-02, 0.68214000E-01, -.59474900E-02, -.27888000E-01, -.98531900E-01, 0.18239200E-01, 0.27142400E-01, -.12746000E+00, -.14846300E-01, 0.24373100E-02, 0.54254200E-01, 0.63970000E-01, -.12943700E-01, -.81638600E-02, -.14215600E-01, 0.20728600E-01, -.78419600E-02, -.39856500E-01, -.26292000E-02, -.15760900E-01, -.32496200E-02, 0.39664400E-01, 0.31357400E-03, -.14294600E-01, 0.70058800E-02, -.11118800E-01, 0.13830300E-01, -.15286800E+00, 0.10927700E+00, 0.27919800E-01, 0.19241600E+03, -.10105900E+03, -.89642400E+02, -.96230400E+02, 0.51160900E+01, 0.42680400E+02, -.60453200E+02, -.10698200E+02, -.88741800E+02, 0.27589700E+02, -.81446400E+02, 0.11396700E+04, -.52273800E+03, -.22998600E+03, -.57049700E+03, -.96605100E+02, 0.65227500E+03, -.49739100E+03, 0.51655300E+02, -.75419400E+03, 0.48040600E+03, -.37539000E+03, -.48491700E+03, 0.18202700E+03, 0.16283400E+03, 0.24298800E+03, -.23000400E+03, -.10522900E+04, 0.65020900E+03, 0.14493600E+03, 0.34196300E+03, -.83429300E+03, -.23292200E+02, -.50982300E+03, 0.25194000E+03, 0.64602300E+02, 0.25496800E+03, 0.16695900E+03, 0.81566300E+02, 0.22149100E+02, -.10029900E+03, 0.15151500E+03, 0.69092100E+02, 0.28132500E+03, -.28380000E+03, 0.14493100E+03, 0.48203800E+03, 0.14194800E+03, -.16364100E+02, -.55457600E+02, 0.79019300E+02, 0.13329300E+02, 0.12753000E+03, -.29527200E+02, 0.21765800E+03, 0.39026900E+03, -.19841300E+03, -.13907500E+03, -.19545900E+03, 0.13154700E+01, -.14498700E+02, -.93251400E+02, 0.10011400E+02, -.11196100E+03, -.14158400E+02, -.21728400E+03, -.70840900E+03, 0.35353100E+03, 0.32300700E+03, 0.35417600E+03, 0.38540600E+02, 0.81254500E+02, 0.98012900E+02, -.20246000E+03, 0.90516900E+02, 0.93128400E+02, 0.22472100E+03, -.38284400E+03, 0.13215700E+03, 0.49829900E+02, 0.19238500E+03, -.22352400E+03, -.11162000E+04, 0.68819100E+03, 0.25376300E+03, 0.53470800E+03, -.89496600E+03, -.11243300E+03, 0.52670100E+03, -.26209100E+03, -.24405200E+03, -.26342100E+03, 0.35719100E+02, 0.54063300E+02, -.12310400E+03, 0.10412800E+02, -.29336000E+03, 0.46971500E+02, -.22536400E+03, -.14897900E+03, 0.79026100E+02, 0.32723600E+02, 0.74606200E+02, -.46556400E+01, -.11853800E+02, 0.94862000E+02, 0.77099800E+02, 0.16102500E+03, 0.23798300E+01, 0.21648800E+02, 0.95777500E+02, -.54271200E+02, -.45150400E+02, -.47868200E+02, -.64231100E+02, 0.53979200E+02, -.17357300E+02, -.68774600E+02, -.31441000E+02, 0.11923600E+02, -.92713600E+02, -.29341600E+03, 0.14744600E+03, 0.88911400E+02, 0.14667600E+03, -.17861700E+01, -.91579000E+01, 0.39833100E+02, -.70516800E+02, 0.89060100E+02, 0.85022800E+01, 0.13750600E+03, 0.82876400E+02, -.46088300E+02, -.48763900E+02, -.41328800E+02, -.73575800E+02, 0.42642600E+01, -.16648300E+02, -.37618800E+02, -.10468800E+02, -.27679200E+02, -.50263600E+02, 0.56633100E+02, -.26511500E+02, -.13169500E+02, -.28441500E+02, 0.20744500E+02, -.53953200E+02, -.25632500E+01, 0.27852500E+02, -.88504600E+02, -.56237700E+02, 0.13449200E+03, -.71576200E+02, 0.37738100E+02, 0.19146600E+03, 0.35828400E+02, -.85137600E+01, -.91997000E+01, 0.29714100E+02, -.37500600E+02, -.10165000E+03, 0.11724100E+01, 0.21092600E+00, 0.38120900E+02, -.42571200E+02, -.75797200E+02, -.18722400E+02, -.12262600E+03, -.39906400E+03, 0.16414500E+03, -.27535200E+02, 0.25179500E+02, -.30228300E+03, -.64754700E+02, 0.11163600E+03, -.53443000E+02, -.12858900E+03, -.55609400E+02, -.41936900E+02, -.56555300E+02, -.86041200E+01, -.39055200E+02, 0.12584400E+03, -.32126700E+02, -.94361200E+02, -.82613900E+03, 0.39558800E+03, 0.24072700E+03, 0.41324000E+03, 0.93970700E+02, -.30069600E+03, 0.29931200E+03, -.14808500E+02, 0.49909800E+03, -.22996200E+03, 0.29567300E+03, 0.45379500E+00, -.45121700E+00, -.11296000E+01, 0.11438300E+01, 0.85657800E+01, -.10708500E+02, -.88488000E+01, 0.26189600E+01, 0.20029000E+01, 0.17466600E+03, -.18048900E+03, 0.73624300E+02, -.11548600E+02, 0.97043700E+01, 0.97865400E+01, 0.27484200E+03, -.29073300E+02, 0.99371000E+01, 0.86211400E+01, 0.25026000E+02, 0.99509200E+01, -.47188000E+01, -.15480800E+01, 0.54988300E+02, -.28826900E+02, 0.11637600E+03 },
        { -.19252000E+01, 0.74585700E-01, 0.58514600E-01, 0.14544400E+01, -.26138900E+00, 0.40922800E+00, 0.24226100E-01, 0.80159200E-01, -.64407400E-01, 0.34850000E+00, -.87834400E-02, 0.23022100E+00, -.25010800E-01, 0.10280400E-01, 0.16523100E+00, -.97792900E-01, 0.18862400E+00, 0.65068800E-01, -.16851000E-01, -.39386700E-01, -.26006800E+00, 0.74808900E-01, 0.50318900E+00, 0.17873400E+00, 0.89604000E-01, -.11173700E+00, -.21596500E-01, -.13917100E+00, 0.13527300E+00, -.68383300E+00, 0.22187700E+00, 0.47801100E-01, -.28710800E-01, -.56452600E+00, 0.99174500E+00, 0.10582800E+00, -.10699400E+00, 0.77646800E+00, -.18295900E+00, 0.38111300E+00, -.26167500E+00, -.13859100E-01, -.18131500E+00, 0.49535700E+00, -.66293700E-01, -.75653600E-01, 0.13155600E+00, 0.75634500E-02, -.41971300E+00, 0.88931500E-02, 0.37916800E-01, -.95181900E-01, 0.99390000E-02, -.15283400E+00, 0.17787400E-01, 0.16845000E+00, 0.20258700E-02, 0.19159500E+00, 0.19550000E+00, 0.24784000E-02, 0.43105400E-01, 0.61185300E-01, -.17473400E+00, 0.71432300E-01, -.47286100E-01, -.11109400E+00, -.34216800E+00, -.43553700E-02, 0.54422400E+00, -.27169000E-02, 0.18413600E-01, -.35029000E-01, 0.14652800E+00, 0.24523900E-01, -.46733300E+00, -.45168900E-01, 0.26199000E+00, -.11964500E+01, -.24277000E+02, -.19169000E+03, -.12760200E-02, 0.51245200E+01, -.52579200E+01, 0.19960700E+01, 0.11588400E+01, -.18739200E+01, -.47544200E+02, 0.21201700E+02, 0.84529800E+02, 0.83947700E+02, -.57068800E+03, -.42685200E+02, -.87650100E+03, 0.55922200E+03, -.10794800E+03, 0.23575100E+03, -.46263800E+03, 0.50738500E+03, 0.26714100E+03, 0.71637500E+04, -.37559100E+04, -.11255800E+04, -.35817300E+04, -.97659400E+03, -.22390500E+04, -.39258900E+02, 0.13085500E+04, -.21001400E+04, -.19046800E+04, -.30330300E+04, -.16696300E+04, 0.80638300E+03, 0.13803800E+03, 0.83482900E+03, 0.57844900E+03, 0.29333700E+03, 0.81897900E+02, -.26183800E+03, 0.58342800E+03, 0.23430100E+03, 0.10172700E+04, -.68534000E+03, 0.35369500E+03, 0.37882000E+03, 0.34268100E+03, -.14960800E+03, -.10038500E+03, 0.35672100E+02, -.42139300E+03, 0.20801000E+03, 0.11724300E+03, -.78745700E+02, 0.28556300E+03, -.15653100E+03, 0.15239900E+03, -.14309800E+03, 0.25507000E+03, 0.55772400E+01, -.39665000E+02, 0.18088900E+03, -.16327500E+03, -.23944400E+02, -.87107000E+02, -.91401400E+03, 0.45219100E+03, 0.25403800E+03, 0.45700100E+03, 0.14282800E+03, 0.41170400E+02, 0.16270400E+03, -.89147600E+02, 0.22578800E+03, 0.59862600E+02, 0.79877700E+02, 0.56630700E+04, -.30119500E+04, -.78935000E+03, -.28312200E+04, -.62799900E+03, -.21797300E+04, 0.20596200E+03, 0.12001000E+04, -.12541900E+04, -.19048100E+04, -.27838000E+04, 0.59109800E+03, -.28903400E+03, -.24247000E+03, -.29556400E+03, -.54506100E+02, 0.63658300E+02, -.16405900E+03, 0.60167900E+02, -.37936900E+03, 0.11961500E+02, 0.22705800E+03, -.24719000E+03, 0.13879300E+03, 0.24826100E+03, 0.12361700E+03, -.19823300E+02, -.70910200E+02, 0.20965000E+03, 0.17368500E+03, 0.24025500E+03, -.44373700E+02, -.26765600E+03, -.50403700E+03, 0.22000700E+03, 0.49559400E+03, 0.25201800E+03, -.17546500E+03, -.62737400E+02, 0.15029400E+03, -.19012900E+03, 0.28698500E+03, -.77956100E+02, -.86970300E+03, -.40356100E+03, 0.19538800E+03, 0.89543800E+02, 0.20176200E+03, 0.84574100E+02, 0.72066200E+02, 0.24929900E+02, -.79255000E+02, 0.10034700E+03, 0.74212700E+02, 0.14268300E+03, -.51208500E+03, 0.23377000E+03, 0.48338100E+03, 0.25606000E+03, -.19854600E+03, -.14743800E+03, 0.16999500E+03, -.96420800E+02, 0.33627900E+03, -.12166200E+03, -.70393700E+03, -.89355900E+03, 0.45664900E+03, 0.49108700E+03, 0.44675700E+03, 0.83767800E+02, 0.84068500E+02, 0.12488900E+03, -.24668200E+03, -.17053900E+03, 0.10190900E+03, 0.10198600E+04, -.40222700E+03, 0.21070900E+03, 0.89990600E+03, 0.20112000E+03, 0.82436600E+02, -.36722300E+02, 0.11832400E+03, -.10523700E+03, -.32477900E+03, 0.31092400E+02, -.96557300E+02, 0.36729400E+04, -.18992600E+04, -.90273500E+03, -.18363500E+04, -.46314400E+03, -.76419900E+03, -.31968600E+03, 0.29877800E+03, -.11685100E+04, -.59740100E+03, -.14664300E+04, -.13363000E+03, 0.73663200E+02, -.44604700E+03, 0.66846400E+02, 0.91384400E+02, -.77443500E+02, 0.22836500E+02, -.67763700E+01, 0.24503500E+03, -.26228000E+02, -.20114500E+03, -.82072500E+03, 0.37115600E+03, 0.65080900E+03, 0.41045200E+03, 0.55970400E+03, -.20878100E+03, 0.15284100E+03, -.14908700E+03, 0.54264600E+03, -.21203400E+03, 0.17341500E+03, -.25386100E+01, 0.73885100E+00, -.10010800E+02, 0.16062800E+01, 0.12722100E+02, -.16292400E+02, -.25676100E+02, 0.29554300E+01, 0.19329000E+02, 0.63378000E+03, -.42190000E+03, 0.20682300E+03, -.62992900E+02, 0.75506900E+02, -.35338500E+02, 0.83196100E+03, -.46248700E+02, 0.72771800E+01, -.46534000E+02, -.94731200E+02, 0.66811800E+02, -.91165900E+01, 0.40759000E+01, 0.13763500E+03, 0.13473900E+02, 0.44444200E+03 },
        { -.39935600E+01, 0.10118500E+00, 0.21671500E+00, -.47207900E+00, -.23694600E+00, 0.86069500E+00, -.41136800E+00, 0.10185600E+00, 0.21622800E+00, 0.77322800E+00, -.41211200E-01, 0.92229300E+00, -.17904300E+00, -.25593800E+00, -.44609100E+00, 0.69437800E-01, 0.21734000E+00, -.56552100E-01, 0.82551800E+00, 0.47507300E+00, -.10811500E+00, 0.14496800E+00, -.54802900E+01, -.10581800E+01, -.20328800E+00, -.22195400E+00, -.63265300E-02, 0.46810400E+00, 0.72835200E-01, -.23924900E+00, -.87801800E-01, -.16958900E+00, 0.22627300E-01, 0.16263000E+00, -.40266400E+00, 0.26675200E+00, 0.15447100E+00, -.63459900E+00, 0.13181900E+00, 0.17028300E+00, -.12861800E+00, -.12599900E+01, 0.28856200E+00, 0.26320000E+00, -.74184400E+00, 0.17514600E+00, -.13294000E+00, -.17073300E-01, 0.68346200E+00, -.20983400E-01, -.99238200E+00, 0.26294900E+01, -.45120700E+00, -.79458800E-01, 0.11149800E+01, -.45757100E+00, 0.26170500E-01, -.66834200E-01, -.25271700E+00, -.35653300E-01, 0.19629800E+00, 0.88939300E-01, -.43364800E-01, 0.79312700E-01, 0.20486200E+00, 0.16659200E+00, 0.19928400E+00, -.22281300E-01, 0.13084600E+01, -.16600000E-02, -.13323500E+00, 0.14304900E+00, 0.97933600E-01, 0.92217300E-01, -.10995200E+01, 0.13152600E+00, 0.16329400E+00, 0.10112900E+01, 0.54000900E+00, -.38113900E+03, -.13021100E+00, -.11269800E+03, -.88185400E+02, 0.10772300E+03, 0.22364200E+03, -.23088500E+02, -.11202000E+02, 0.18232300E+03, 0.34343700E+04, -.18927600E+04, -.53607800E+04, -.17189200E+04, -.11330200E+04, -.15467600E+04, -.10098300E+04, -.97533900E+03, -.28540200E+04, -.86501100E+03, -.24375700E+04, -.61278900E+03, 0.48080200E+03, 0.19730300E+04, 0.30881200E+03, 0.47149100E+03, 0.12914300E+04, 0.21834400E+03, -.21797800E+03, -.84446100E+03, 0.76196700E+03, 0.21756900E+04, -.47025600E+04, 0.23440100E+04, 0.28747600E+04, 0.23515300E+04, 0.11018200E+04, 0.87840300E+03, 0.17180600E+03, -.97548700E+03, 0.12110000E+04, 0.69833000E+03, 0.21731900E+04, -.36027900E+03, 0.18989800E+03, 0.19156600E+03, 0.18036200E+03, -.64607800E+03, -.12289200E+03, -.13347500E+02, -.48883100E+03, 0.11190900E+03, 0.65965200E+01, -.59465100E+03, 0.83368500E+03, -.42621500E+03, -.23341200E+03, -.41754600E+03, -.18443600E+03, 0.29833000E+02, 0.88047100E+02, 0.68567300E+03, 0.30594800E+03, -.13033700E+03, -.10106800E+03, -.13384600E+04, 0.67406000E+03, 0.88382800E+03, 0.66909800E+03, -.79355200E+02, 0.25174300E+03, 0.37217200E+03, -.53877700E+03, 0.28450700E+03, 0.23457700E+03, 0.40344200E+03, 0.12525500E+02, 0.15620500E+03, 0.24093400E+04, -.24583800E+01, 0.39574600E+03, 0.11286000E+04, 0.49116100E+03, 0.68600700E+03, 0.21923500E+03, 0.59399200E+03, 0.14306100E+04, 0.95263800E+03, -.48312600E+03, -.90742800E+03, -.47664700E+03, 0.76937800E+02, -.14499300E+03, -.23533000E+03, -.12190100E+03, -.90670300E+03, -.11608200E+02, -.17072000E+03, 0.13393000E+04, -.63594100E+03, -.33825900E+03, -.66908600E+03, -.37416400E+03, 0.47236800E+02, -.26710100E+03, -.88602600E+02, -.99246800E+02, 0.62848300E+02, -.94168600E+03, -.74922700E+03, 0.38175100E+03, 0.78178500E+03, 0.37474700E+03, 0.51595100E+02, 0.25982200E+02, 0.46140300E+03, -.32494100E+02, 0.15671200E+03, 0.73264100E+02, -.45469000E+03, -.56531000E+02, 0.55468700E+02, 0.30835100E+03, 0.28199600E+02, -.20263900E+02, 0.13233100E+03, 0.13971500E+02, 0.13868300E+03, 0.15123500E+03, 0.11645400E+03, -.77528900E+02, -.93061200E+03, 0.46245700E+03, 0.79237700E+03, 0.46586100E+03, -.62955400E+02, -.12330700E+03, 0.50517100E+03, 0.24220000E+03, 0.60345200E+03, -.94296100E+02, -.72221200E+02, -.18665900E+04, 0.92326400E+03, 0.10166100E+04, 0.93268400E+03, 0.66679300E+03, 0.18418200E+03, -.16530100E+03, -.29213600E+03, 0.23993200E+03, 0.15675100E+03, 0.13780600E+04, 0.66084100E+03, -.32602800E+03, 0.19451500E+03, -.33021800E+03, -.11103200E+03, -.18880700E+03, 0.85583200E+02, -.83724100E+02, -.26935700E+03, -.16826300E+03, -.11917900E+03, 0.26775600E+03, -.42784800E+02, 0.40910700E+03, -.13262600E+03, 0.22014600E+03, 0.77908900E+03, -.22925500E+03, -.32653200E+03, -.62934500E+03, 0.49159800E+03, 0.91487200E+03, 0.19791600E+03, -.73307800E+02, -.20158600E+03, -.97887900E+02, -.84404300E+03, 0.16809100E+02, 0.41124800E+03, 0.51059900E+03, 0.10003600E+04, -.90711600E+02, -.41762500E+03, -.32122100E+04, 0.16972700E+04, 0.33545900E+04, 0.16064200E+04, 0.58021400E+03, 0.70290000E+03, 0.95552300E+03, 0.54605900E+03, 0.20402700E+04, 0.34205700E+03, 0.17577200E+04, -.36396300E+02, 0.48269600E+01, -.61685000E+02, -.96441800E+00, 0.52612100E+02, -.54219900E+02, -.56434500E+02, 0.22086100E+01, 0.73015700E+02, 0.17717300E+02, -.31687300E+03, 0.39918800E+03, -.10851700E+03, -.22820600E+03, 0.15632600E+03, 0.38865400E+03, -.14378400E+03, 0.31385800E+02, 0.13745000E+02, 0.39423200E+03, 0.68341800E+02, -.75845000E+01, -.67447600E+02, 0.54028100E+00, -.43562000E+03, -.30035200E+03 },
        { -.10640200E+02, 0.15287200E+00, 0.35517500E+00, -.54430800E+00, -.10540300E+01, 0.64260700E+00, 0.75642900E+00, 0.10284100E+00, -.85280500E+00, 0.53689100E+00, 0.14218200E-01, -.11998200E+01, 0.35533100E-01, -.19331200E-01, -.12973200E+00, 0.85388200E-01, -.95034400E+00, -.12638000E+00, -.11448400E+01, 0.80235000E+00, 0.64146200E-01, -.57725900E-01, 0.23633400E+01, 0.58252100E+00, 0.14820600E+00, 0.47905600E-01, 0.45763800E-01, 0.56343600E+00, 0.10570700E+01, -.40808800E+00, 0.15139900E+00, 0.13056100E+01, -.14541900E-01, -.18669900E+00, -.28923200E+01, 0.10162200E+00, -.20469900E+00, -.22169200E+01, 0.94345600E-01, -.40147500E+00, 0.44221700E+00, -.83218100E+00, 0.20735800E+00, -.75436600E-01, 0.86307400E-01, -.15456900E+00, 0.18149400E+00, 0.33779700E-01, -.43104100E+00, 0.78318600E-01, -.16985200E+00, 0.23311300E+00, -.51463700E-01, 0.32147800E+00, 0.29860400E+01, -.66973100E+00, -.18498300E-02, -.22683500E+00, 0.39169100E+00, 0.35179800E-02, -.13126000E+00, -.29649800E+00, 0.95273600E-02, 0.10023700E+00, 0.64178700E+00, 0.12901800E-01, -.19435700E+00, 0.44277200E-02, 0.69326000E+00, -.24443300E-03, -.79766900E-01, -.29831600E-01, -.15508700E-01, -.44839400E-01, 0.76847400E+00, 0.26571000E-01, -.41224200E+00, -.29286000E+01, -.28914200E+00, 0.22375800E+00, 0.29804400E+01, -.94071000E+02, 0.56885100E+01, -.11120900E+03, -.28729500E+03, -.14358200E+02, -.63043700E+02, -.15076700E+03, 0.42537000E+03, -.12976100E+03, 0.69739600E+03, -.21015000E+03, -.59980100E+03, 0.17822200E+04, -.28232100E+03, 0.10462100E+04, 0.22186800E+03, 0.85907800E+03, 0.15310500E+04, 0.20377400E+04, -.11077900E+04, -.12656700E+03, -.10212200E+04, 0.48004700E+03, -.98745100E+03, -.30576000E+03, -.43007700E+03, -.13813700E+04, -.27127100E+03, -.31740500E+04, 0.50062800E+02, -.16406500E+02, -.31934700E+03, -.25280300E+02, 0.20790500E+03, -.14915700E+01, -.34567900E+02, -.30948500E+02, -.31492500E+02, 0.12560100E+02, -.31862400E+02, -.22710100E+03, 0.11289800E+03, 0.15650400E+04, 0.11333500E+03, 0.14073500E+04, -.39722800E+03, 0.64873600E+03, 0.14831900E+04, 0.23171000E+03, -.55150700E+03, -.11714100E+02, 0.51944200E+03, -.25629400E+03, -.77285300E+03, -.25925400E+03, -.27888400E+03, -.12328300E+02, -.48138000E+03, -.79524400E+03, -.42558200E+03, 0.12562300E+03, -.29108400E+03, 0.22208600E+04, -.11110400E+04, -.10291000E+04, -.11103000E+04, -.13729000E+03, -.25876700E+03, -.35783600E+03, 0.67398300E+03, -.57044400E+03, -.29181200E+03, -.76131200E+03, 0.16846700E+04, -.91678100E+03, -.47281600E+03, -.84633400E+03, 0.31936800E+03, -.13905000E+04, 0.36608700E+02, -.41468000E+03, -.91983000E+03, -.61388600E+03, -.30083000E+04, -.12218700E+03, 0.63078200E+02, 0.14159300E+03, 0.61411900E+02, -.19098400E+03, 0.21527900E+03, 0.15435900E+03, -.18288400E+03, 0.42590000E+03, 0.53630200E+02, 0.67515000E+02, -.86840300E+03, 0.42393400E+03, -.61987000E+02, 0.43366500E+03, 0.21931600E+03, -.22099600E+03, 0.56873400E+03, 0.69646600E+03, 0.44394600E+03, -.14731000E+03, 0.62923700E+03, 0.41700100E+02, -.22374500E+02, -.56361300E+03, -.20960900E+02, 0.12764800E+02, -.79959400E+01, -.62234400E+02, -.73529600E+01, -.10441300E+03, -.13784300E+02, 0.23447900E+03, -.93601000E+03, 0.47981100E+03, 0.13897400E+03, 0.46811000E+03, 0.26912000E+02, -.24036800E+03, 0.12890000E+03, -.29618000E+03, 0.25599800E+03, -.15378600E+03, 0.50474700E+03, 0.72651000E+03, -.36185600E+03, -.86478600E+03, -.36377000E+03, 0.17383300E+01, -.11276100E+02, -.24789600E+03, -.11359300E+03, -.40639100E+03, -.40377000E+02, -.21679700E+03, -.82317200E+02, 0.45820200E+02, 0.99286300E+02, 0.41736400E+02, 0.11555100E+03, 0.69940600E+02, 0.20975000E+03, -.15016300E+03, -.85134300E+02, 0.82701800E+02, -.36669700E+03, -.96678600E+02, 0.47017400E+02, -.34023400E+03, 0.48150800E+02, -.17950400E+03, 0.58147800E+02, 0.35109400E+02, 0.29418000E+02, 0.69039400E+02, 0.87316000E+02, -.62987900E+02, 0.10113700E+04, -.55814000E+03, -.78980700E+02, -.50704600E+03, 0.30530000E+03, -.61486300E+03, -.14248900E+03, -.15431500E+03, -.68885700E+03, -.24825600E+03, -.14562100E+04, 0.33218700E+04, -.16682800E+04, -.86596700E+03, -.16619200E+04, 0.29911900E+03, -.49852200E+03, -.70090800E+03, 0.42808800E+02, -.14581300E+04, -.38808000E+03, -.12706500E+04, 0.99615100E+02, -.92664800E+02, -.35841500E+03, -.50353500E+02, 0.37962000E+03, -.73166500E+03, -.76899800E+02, -.75110400E+03, -.44061700E+03, -.26701800E+03, -.75587800E+03, 0.27958100E+02, 0.14367900E+02, 0.74861100E+01, 0.85629500E+01, 0.53963900E+01, -.19175600E+02, 0.12718800E+02, 0.10707700E+02, -.18502600E+02, 0.10422000E+04, -.11508300E+04, 0.26620000E+03, 0.20566200E+03, 0.18568000E+02, -.70531600E+02, 0.11869300E+04, 0.15049800E+03, 0.14470000E+02, -.29841300E+02, -.47827300E+03, 0.34446300E+02, 0.38635700E+01, 0.18760600E+02, 0.11377100E+04, 0.27026700E+03, 0.92471400E+03 },
        { 0.24286100E+00, 0.40735700E-01, 0.22289000E-01, 0.45406000E+00, -.20240400E+00, 0.30600500E+00, -.77717200E-01, 0.14348400E+00, -.19396000E+00, 0.22401200E+00, 0.94185600E-02, -.94290600E-01, -.35489200E-01, 0.34134600E-02, 0.39600700E-01, -.91323400E-02, 0.14554800E+00, 0.83666300E-01, 0.11880600E+00, 0.12244700E+00, 0.19536700E+00, 0.16328100E-02, -.39208700E+00, 0.19936800E+00, 0.59995600E-01, 0.37603600E-01, -.12035000E+00, 0.32116900E+00, 0.37682300E+00, -.22102900E+00, 0.13236200E+00, 0.81615900E-01, -.31551300E-01, 0.64269600E-01, -.64763300E+00, -.95151600E-01, -.12166600E-01, -.29281800E+00, 0.11574100E+00, -.19483000E+00, -.71528300E-01, 0.22220400E+00, -.16343500E+00, -.27093400E+00, 0.16784500E+00, -.75888300E-01, 0.11106900E+00, 0.28143300E-02, -.43505600E-01, 0.18667400E-02, -.19958200E+00, -.12884400E+01, 0.84517100E-01, 0.92525300E-01, 0.23270500E+00, -.62645000E-01, 0.73555800E-02, -.83035500E-01, 0.61406900E-01, 0.35709900E-01, -.14801600E+00, -.50008200E-01, -.73924100E-01, -.52863000E-01, -.14088400E+00, -.61189000E-01, -.13543200E+00, 0.38697100E-02, -.50031300E+00, -.25409900E-03, 0.15474000E-01, 0.57171200E-01, 0.36691500E-01, 0.41994000E-01, -.66061900E-01, -.18782500E+00, 0.15012400E+00, 0.14419100E+01, -.37499100E+00, -.13024600E+00, -.26744900E-02, -.23805500E+03, -.16909600E+02, -.12217200E+02, -.10311300E+03, -.70883700E+01, -.28817100E+02, 0.16415100E+03, -.48558400E+04, 0.23226300E+04, 0.22094600E+04, 0.24284200E+04, -.61306500E+03, -.14524100E+04, 0.16438300E+04, 0.34256800E+02, 0.18197400E+04, -.11457600E+04, 0.97851600E+03, 0.82241000E+04, -.40095500E+04, -.31693400E+04, -.41120500E+04, -.11660900E+03, 0.14069500E+04, -.22063000E+04, 0.10513800E+03, -.33314800E+04, 0.10966700E+04, -.22438400E+04, -.15842500E+04, 0.78703800E+03, 0.56027300E+03, 0.79211900E+03, 0.39680700E+03, 0.28825900E+03, 0.38441400E+02, -.35615600E+03, 0.35536200E+03, 0.21815400E+03, 0.79589700E+03, 0.21242200E+03, -.10243800E+03, -.16607400E+03, -.10621400E+03, 0.21003200E+03, -.55169200E+02, -.42331700E+02, -.33295900E+02, -.15254000E+03, 0.45461700E+02, -.10454700E+04, 0.35370300E+03, -.17959300E+03, -.16422800E+03, -.17649300E+03, -.70611300E+02, 0.64448300E+02, -.94584700E+02, 0.11696000E+03, -.65787500E+02, -.20427000E+01, 0.27064200E+03, 0.13402700E+04, -.66732400E+03, -.81462300E+03, -.67013400E+03, -.79931900E+02, -.17693700E+03, -.68137800E+02, 0.59501400E+03, -.11206000E+03, -.22154700E+03, -.47669900E+03, 0.78397600E+04, -.38285400E+04, -.32127500E+04, -.39201300E+04, -.81796600E+02, 0.13030900E+04, -.20417100E+04, 0.23784500E+03, -.29018700E+04, 0.97931900E+03, -.20627100E+04, -.35402500E+03, 0.17193700E+03, 0.38153800E+03, 0.17701700E+03, -.29580600E+03, -.52399100E+02, 0.64858800E+02, -.20054600E+03, 0.11564900E+03, -.87244600E+02, 0.43933600E+03, 0.32457500E+03, -.15093000E+03, -.47321600E+02, -.16228700E+03, 0.30906400E+02, -.34379600E+02, 0.25260400E+02, 0.21856700E+03, -.87369300E+02, 0.11519200E+02, -.43964600E+03, -.99377200E+03, 0.50251600E+03, 0.64985800E+03, 0.49689700E+03, 0.14404600E+03, -.21508400E+03, 0.42871700E+03, 0.70507000E+02, 0.34284400E+03, -.79861100E+02, -.53186500E+03, 0.12882800E+03, -.66709700E+02, -.13549900E+03, -.64383200E+02, 0.12793800E+03, 0.92430000E+02, -.47035400E+02, 0.45441300E+02, -.72416900E+02, 0.78653800E+02, -.96000300E+02, -.86391900E+03, 0.43284500E+03, 0.54930300E+03, 0.43196800E+03, 0.11590100E+03, -.25153600E+03, 0.37810300E+03, 0.15629100E+03, 0.43673600E+03, -.11386600E+03, -.43478000E+03, -.17323400E+04, 0.86177300E+03, 0.82290500E+03, 0.86616800E+03, 0.36747700E+03, 0.29273900E+03, 0.98423500E+02, -.58299600E+03, 0.31447500E+02, 0.30041900E+03, 0.70481600E+03, -.80231000E+02, 0.42493900E+02, 0.15969500E+03, 0.40118300E+02, 0.14565800E+03, -.11153700E+02, 0.90728400E+02, 0.54349800E+02, -.57998400E+02, 0.32566100E+02, -.99391100E+02, 0.37784800E+04, -.18331700E+04, -.15735700E+04, -.18893600E+04, 0.39904700E+02, 0.70779100E+03, -.10718900E+04, -.35406900E+02, -.15688900E+04, 0.59820300E+03, -.11227900E+04, 0.10117800E+04, -.49584800E+03, -.98026100E+03, -.50586900E+03, 0.11967500E+02, 0.56254400E+01, -.18398600E+03, 0.25458300E+03, -.34172900E+03, -.32173400E+02, -.50307200E+03, 0.22740100E+04, -.10833800E+04, -.88390200E+03, -.11372000E+04, 0.30694900E+03, 0.72612000E+03, -.77014300E+03, -.10381100E+01, -.86716500E+03, 0.58158400E+03, -.54050300E+03, 0.15331400E+01, 0.12775900E+02, -.26917900E+02, 0.19387800E+01, 0.22009800E+02, -.28881700E+02, -.23008900E+02, -.11536400E+01, 0.35705500E+01, 0.40885700E+03, -.78933300E+02, 0.15644400E+03, -.38743000E+01, -.75415700E+02, -.53983400E+02, 0.21230700E+03, 0.41439200E+02, 0.40058100E+01, -.57926100E+02, -.33029600E+03, 0.71241300E+02, -.38872400E+01, -.74786000E+01, 0.28054700E+03, -.39370100E+02, 0.30777600E+03 },
        { 0.40881900E+01, -.27465900E-01, -.91112800E-01, 0.27025500E+00, 0.39072100E+00, 0.65538300E+00, -.33762500E-01, -.57772100E-01, -.45640800E+00, -.29324300E+00, -.42075500E-01, -.36008400E+00, -.54501400E-01, 0.47740400E-02, -.61570900E-01, -.28420400E-01, 0.59902400E+00, -.17740400E-02, 0.55483400E+00, 0.23033800E+00, 0.57947000E+00, 0.62429300E-01, 0.14962300E+01, 0.15335800E-01, 0.12488600E+00, 0.13608500E-01, 0.64005300E-01, 0.27737900E-02, 0.38821400E-01, 0.33811500E+00, 0.75110600E-01, -.52911500E+00, -.29143200E-01, 0.39648100E+00, 0.50234900E-01, -.19028500E+00, -.31583600E-02, 0.74411600E+00, 0.58614400E-01, -.15738800E+00, -.22981700E-01, 0.57376500E-01, -.65889300E-01, -.59400200E-01, -.55511800E-01, 0.56698600E-01, -.11383900E-01, 0.83488500E-02, -.55276900E-01, -.23845200E-01, -.61864600E+00, 0.11244000E+01, -.46639500E-02, -.40866100E-01, -.22484900E+00, -.13825900E+00, 0.19093200E-01, -.57659400E-01, 0.76977700E-01, -.28520100E-01, -.19227800E+00, 0.10156700E+00, -.49436500E-02, 0.37449000E-01, 0.57064000E-01, -.83219100E-01, 0.55184100E+00, -.50169500E-03, 0.13052500E+00, 0.53458000E-03, 0.17286300E-01, 0.82156600E-02, -.14295800E-01, 0.18684400E-01, 0.14743400E+00, -.88017200E-01, -.95562900E-01, -.53037700E+00, 0.91634000E-01, -.23867300E+00, -.15368400E-01, 0.18753300E+00, -.82512200E+02, 0.55259200E+02, 0.86195000E+02, -.24202500E+02, -.68733600E+02, -.92716900E+02, 0.40454900E+04, -.20390400E+04, -.19113000E+04, -.20229400E+04, -.84315200E+02, 0.87678800E+02, -.10328300E+04, 0.32332000E+03, -.17845200E+04, -.12539500E+02, -.13099100E+04, -.60338700E+04, 0.30342700E+04, 0.20584900E+04, 0.30176200E+04, 0.44757800E+03, -.16083100E+03, 0.13545300E+04, -.81110600E+03, 0.14359600E+04, 0.29198200E+01, 0.19554200E+04, -.12061600E+04, 0.60727900E+03, 0.78322600E+03, 0.60314900E+03, 0.25375000E+03, 0.22351900E+03, 0.19065800E+02, -.35958600E+03, 0.18224900E+03, 0.16790400E+03, 0.54480800E+03, -.12932100E+03, 0.66640300E+02, 0.64112000E+03, 0.64724400E+02, -.65593400E+01, 0.12465200E+02, 0.10644000E+03, 0.14818500E+03, 0.54647400E+02, -.77624100E+02, 0.13865300E+03, 0.63634000E+03, -.31975300E+03, -.46909900E+03, -.31843100E+03, -.19788100E+03, -.76312800E+02, -.93722100E+02, 0.63635000E+02, 0.27926800E+02, -.70128100E+02, -.21332600E+03, -.57587900E+03, 0.28887800E+03, 0.45566300E+03, 0.28790100E+03, -.16702200E+03, 0.10036000E+03, 0.20631000E+03, -.27767100E+03, 0.13333000E+03, 0.84098800E+02, 0.36575500E+03, -.52874900E+04, 0.26586400E+04, 0.18689300E+04, 0.26447100E+04, 0.29670900E+03, -.22133200E+03, 0.13465900E+04, -.47880600E+03, 0.16282500E+04, -.48966500E+02, 0.16516900E+04, 0.31804700E+03, -.15870800E+03, -.31917800E+03, -.15911800E+03, 0.17881700E+03, -.70738000E+02, -.51180100E+02, -.14482900E+02, -.26726100E+03, -.30592200E+02, -.37709300E+03, -.88435200E+02, 0.50463900E+02, -.10117500E+03, 0.44385400E+02, -.13028800E+03, -.15318700E+02, 0.10475600E+03, 0.68052600E+02, 0.22533200E+03, -.24984200E+02, 0.20790000E+03, -.56423400E+02, 0.28051200E+02, -.13576500E+03, 0.28257400E+02, 0.47404800E+02, 0.11054400E+03, 0.13443100E+03, 0.93452400E+02, -.49619700E+02, 0.11054100E+03, 0.12666800E+03, -.18196500E+03, 0.10375300E+03, 0.15645000E+03, 0.90979900E+02, -.78439300E+02, -.84947300E+01, 0.27951800E+02, -.16654600E+02, 0.11613300E+03, -.78481600E+01, 0.11890000E+03, -.38516400E+01, 0.57266500E+00, -.23131100E+03, 0.20949000E+01, -.58865600E+01, 0.50748100E+02, 0.81109200E+02, 0.86253000E+02, 0.66244900E+02, 0.19450500E+02, 0.14903600E+03, -.37091900E+03, 0.18448700E+03, 0.20030500E+03, 0.18527700E+03, 0.33940000E+03, 0.74081700E+02, -.16471300E+03, -.62093800E+02, -.14697000E+00, 0.51993800E+02, 0.22535000E+02, 0.17099800E+03, -.85400100E+02, -.22625500E+03, -.85437700E+02, -.96756500E+02, -.13993900E+01, 0.43314500E+02, -.36411800E+02, 0.83689600E+02, -.11587700E+02, 0.21388300E+02, -.22196600E+04, 0.11199800E+04, 0.71171000E+03, 0.11101300E+04, 0.17001400E+03, -.62801700E+00, 0.38917900E+03, -.49913500E+03, 0.42762600E+03, 0.57212600E+02, 0.72208100E+03, 0.49657100E+03, -.24362000E+03, 0.14665400E+03, -.24795700E+03, -.33072600E+03, -.74538800E+02, -.13842100E+02, -.77859100E+02, 0.14267400E+03, -.10952700E+03, -.29476100E+02, -.25648100E+04, 0.12914200E+04, 0.11855100E+04, 0.12824100E+04, 0.52272800E+02, -.74066100E+02, 0.69127600E+03, -.13321600E+03, 0.11253500E+04, -.37874300E+02, 0.86973200E+03, -.15173100E+02, -.68625100E+01, -.14350400E+02, -.10453200E+01, 0.18104000E+02, -.17581000E+02, -.23635800E+01, 0.11824000E+01, 0.10182700E+02, -.21905800E+03, -.72989500E+02, 0.18307900E+03, 0.67036200E+01, -.40522300E+02, 0.73961900E+02, -.49360200E+02, -.51329800E+02, 0.16693500E+02, 0.32368700E+02, 0.33248300E+03, 0.98099800E+01, -.18353500E+02, -.13831100E+02, 0.23765300E+02, -.11317100E+03, -.29425700E+03 },
        { 0.27848900E+01, -.66005900E-01, -.17481400E+00, 0.25602200E+00, 0.54245400E-01, -.45816200E+00, 0.35588300E+00, -.31215000E+00, -.45871400E-01, -.36327800E+00, -.38624900E-01, 0.10430800E+00, 0.23294200E-02, 0.13107500E+00, 0.39291200E-01, -.51521800E-01, 0.88566700E-01, -.68737000E-01, -.20625600E-01, 0.18084100E-01, 0.11360800E+00, -.25781300E-01, -.13401300E+00, -.27216100E+00, -.17561500E+00, -.62673500E-01, 0.86509000E-01, -.87622000E-01, -.29135900E+00, -.50802800E-01, -.16277000E+00, 0.37968000E+00, 0.33922900E-01, 0.70892400E-01, -.57831500E+00, 0.10303800E+00, -.37831600E-01, -.40233700E+00, 0.51558000E-02, 0.71496500E-01, -.33386600E-01, -.77036300E+00, 0.98850700E-01, 0.49237200E+00, -.51938600E+00, 0.11732600E+00, -.12567500E+00, 0.90423900E-02, 0.22979000E+00, 0.47294600E-02, -.34698000E+00, 0.11672600E+01, -.17293600E+00, 0.90213600E-01, 0.93730600E+00, -.26197400E+00, 0.60585300E-02, -.37795600E+00, 0.84754800E-01, -.27042800E-01, -.62750100E-01, -.19404200E-01, -.87389400E-02, 0.12250500E+00, 0.21772300E+00, -.10770700E+00, 0.96562000E+00, -.61696700E-02, 0.10965700E+01, -.24035400E-03, -.47782300E-02, -.23574000E+00, -.11173800E+00, 0.20240900E-01, 0.10987600E+00, -.53515100E+00, -.30985800E+00, 0.31352200E+00, -.51697400E+00, -.56134300E+00, 0.45940400E-02, -.16781100E-02, -.44981400E+00, 0.16781000E+03, 0.35682400E+03, -.35008900E+02, 0.43082400E+02, -.15940900E+02, 0.97122300E+04, -.49874300E+04, -.62045900E+04, -.48549900E+04, -.10092300E+04, -.17592600E+04, -.12392700E+04, 0.94333500E+03, -.33747300E+04, -.16759000E+04, -.39479400E+04, -.94783300E+04, 0.48766200E+04, 0.21339700E+04, 0.47388900E+04, 0.10775200E+04, 0.62017200E+03, 0.20617400E+04, -.13198900E+03, 0.29387500E+04, 0.74027900E+03, 0.34267200E+04, -.23040000E+04, 0.11522400E+04, 0.18986800E+04, 0.11519700E+04, 0.46744000E+03, 0.44219400E+03, 0.34057500E+02, -.59188500E+03, 0.40335400E+03, 0.33906800E+03, 0.10614200E+04, 0.22959800E+03, -.11134600E+03, -.21431600E+03, -.11481900E+03, -.24179700E+03, 0.48463300E+02, -.50844500E+02, -.61553200E+01, -.14641500E+03, 0.82349400E+02, -.26580400E+03, 0.67840700E+03, -.34372300E+03, -.44274800E+03, -.33915900E+03, -.28318600E+03, -.18790300E+02, 0.16503600E+02, 0.36490800E+03, 0.16370500E+03, -.11310500E+03, 0.47985000E+02, 0.96852600E+03, -.48294900E+03, -.18643700E+03, -.48425200E+03, -.33230800E+03, -.34554800E+02, 0.12332100E+03, 0.12365600E+03, -.41429100E+01, -.10500300E+03, -.23005200E+03, -.10147500E+05, 0.51892200E+04, 0.34949700E+04, 0.50729300E+04, 0.11869000E+04, 0.11478500E+04, 0.19346800E+04, -.25464800E+03, 0.31780100E+04, 0.11888700E+04, 0.38514200E+04, 0.57332900E+03, -.28450600E+03, -.62957900E+03, -.28663400E+03, 0.24908600E+02, -.13469600E+03, -.61022100E+02, -.21038600E+03, -.41416800E+03, -.30019600E+02, -.68648100E+03, 0.66857000E+03, -.31587600E+03, -.35167900E+03, -.33432000E+03, -.29776900E+03, 0.15483700E+02, -.17986900E+03, -.13565300E+03, -.80812500E+02, 0.35031000E+02, 0.44235900E+02, -.82518600E+03, 0.41072900E+03, 0.42531200E+03, 0.41260600E+03, 0.29248800E+03, -.60008100E+02, 0.65244000E+03, 0.69811600E+03, 0.41788800E+03, 0.31316100E+02, 0.38763300E+03, -.21310800E+03, 0.13248500E+03, 0.68773900E+03, 0.10661700E+03, -.17614500E+03, 0.11485500E+03, -.27243200E+02, -.41189500E+02, 0.73567500E+02, 0.10169800E+03, 0.14099000E+03, -.86721800E+03, 0.42842000E+03, 0.43716800E+03, 0.43359000E+03, 0.28488600E+03, -.10407000E+03, 0.59364400E+03, 0.73043800E+03, 0.64739300E+03, -.81615700E+02, 0.46820800E+03, -.26428200E+04, 0.13179900E+04, 0.12921900E+04, 0.13214500E+04, 0.63825200E+03, 0.41351700E+03, -.95250400E+02, -.66358700E+03, 0.16755400E+03, 0.41415600E+03, 0.86707200E+03, 0.14180300E+03, -.70860700E+02, -.14282700E+03, -.70909900E+02, -.46788300E+02, 0.87113400E+02, 0.66714900E+01, -.20934900E+03, 0.17846900E+03, 0.44503400E+02, 0.14749400E+03, -.25830000E+04, 0.13687500E+04, 0.24633700E+03, 0.12911600E+04, 0.43438000E+03, 0.41255300E+03, 0.28168700E+03, -.40919100E+03, 0.65294400E+03, 0.47012400E+03, 0.88181600E+03, 0.83666100E+03, -.40514500E+03, -.44175000E+03, -.41836000E+03, -.65710100E+03, 0.14658200E+02, -.25783400E+02, 0.74126900E+02, 0.10784100E+03, -.44769500E+02, 0.21458700E+02, -.62657000E+04, 0.31998600E+04, 0.35987000E+04, 0.31325200E+04, 0.41358700E+03, 0.61947200E+03, 0.12020900E+04, -.23644700E+03, 0.24416400E+04, 0.58493400E+03, 0.25208500E+04, -.47741400E+02, -.20938100E+02, -.55585100E+02, -.81892600E+01, 0.48660300E+02, -.37041800E+02, -.24933200E+02, -.20854200E+01, 0.45580300E+02, -.63065300E+03, -.20458800E+03, 0.26359200E+03, -.43572200E+02, -.15267400E+03, 0.11312500E+03, -.16434200E+03, -.37741700E+02, -.55591400E+01, 0.14552100E+02, 0.99182900E+03, 0.60854700E+01, -.29483600E+02, -.68776200E+02, 0.19459300E+03, -.26608900E+03, -.77298800E+03 },
        { 0.43511100E+01, -.96205200E-01, -.12836500E+00, 0.14441300E+00, 0.35562200E+00, -.29646800E+00, -.22806600E+01, 0.14026200E+01, 0.24883300E+00, 0.69039200E-02, 0.14269300E-01, -.17171900E+00, -.11982800E-01, -.92335900E-02, 0.87574900E-01, -.39571800E-04, 0.46250400E+00, -.18096700E+00, 0.36510000E+00, -.51931300E+00, 0.41200700E+00, 0.50993800E-01, -.28743800E+00, 0.11310700E+00, -.11192700E+00, -.14420100E-01, -.24762100E-01, -.35874500E+00, -.26774400E+00, -.18533300E-02, -.58368600E+00, -.51341100E+00, 0.70440500E-01, 0.35322900E+00, -.68913600E+00, -.24446400E+00, 0.49770700E-01, -.18810900E-02, -.41852000E+00, -.27495200E+00, 0.98105000E+00, 0.41310700E+00, -.65133800E-01, -.26596800E-01, 0.72863100E+00, 0.74271400E-01, -.27553500E-01, -.16591600E-01, -.17146600E+00, 0.54996900E-01, 0.47804800E+00, -.72308100E+00, -.84591300E-01, -.22937800E+00, 0.10206800E+01, 0.20156900E+00, -.23773500E-01, -.73910800E-02, -.21815000E+00, 0.84943000E-01, 0.47148500E+00, -.37698900E+00, -.19152400E+00, -.24938500E-01, 0.38035700E+00, 0.25017700E+00, -.15502100E+01, 0.48485000E-02, 0.14344000E+00, -.24791000E-02, -.90776100E-02, -.92112700E-01, 0.17652200E+00, 0.13152300E+00, -.87081500E+00, -.35537800E+00, 0.14209200E+00, -.24152300E+01, 0.54217600E+00, 0.46750700E+00, 0.38644600E-01, -.33007300E+00, 0.18792500E+01, -.33340100E+00, -.13892600E+03, 0.12659100E+02, -.23656000E+02, -.97550700E+02, -.78819000E+04, 0.38239600E+04, 0.50862300E+04, 0.39432800E+04, -.15929000E+04, -.32074600E+04, 0.25220000E+04, -.12120700E+04, 0.37385100E+04, -.22924400E+04, 0.22347000E+04, 0.21767000E+05, -.10763500E+05, -.88828300E+04, -.10887000E+05, -.54404800E+03, 0.21663400E+04, -.45366600E+04, 0.36154400E+04, -.56426300E+04, 0.16270000E+04, -.74009100E+04, 0.13726100E+04, -.70717600E+03, -.17134600E+04, -.68666400E+03, -.19372800E+03, -.14743200E+03, -.71673600E+02, 0.51691100E+03, -.80729200E+02, -.11171100E+03, -.41900700E+03, 0.10737700E+03, -.50959300E+02, -.94128600E+03, -.54004400E+02, 0.28456100E+03, -.24999500E+03, -.14102900E+03, -.47730600E+03, 0.15749800E+02, 0.35501400E+02, -.17312200E+04, -.11412700E+04, 0.56541700E+03, 0.72974800E+03, 0.57205700E+03, 0.24889100E+03, 0.31261400E+03, -.55365100E+02, -.31495400E+03, -.25900500E+03, 0.17310800E+03, 0.14366000E+04, 0.44250100E+04, -.22129500E+04, -.25318100E+04, -.22123200E+04, -.57204600E+02, -.58706700E+03, -.63139200E+03, 0.16217500E+04, -.56001200E+03, -.71602600E+03, -.14389300E+04, 0.17051600E+05, -.84143800E+04, -.75300500E+04, -.85311600E+04, 0.38345200E+03, 0.31442600E+04, -.43246200E+04, 0.22195200E+04, -.55043000E+04, 0.24080500E+04, -.55514300E+04, -.50521000E+03, 0.25216100E+03, 0.27011600E+03, 0.25307000E+03, -.52432100E+03, -.97859400E+02, 0.12789300E+03, 0.86659100E+02, 0.54240100E+03, -.13348300E+03, 0.70059200E+03, -.58695800E+03, 0.31031900E+03, 0.48042900E+03, 0.29267500E+03, 0.22552500E+02, -.44956500E+02, 0.17468100E+03, 0.19831300E+03, -.51479000E+02, -.41908200E+02, -.13329700E+03, -.18102700E+04, 0.90498600E+03, 0.13124400E+04, 0.90494600E+03, 0.67187200E+02, -.60779700E+03, 0.62612800E+03, 0.16737100E+03, 0.11247600E+04, -.29201200E+03, -.13212900E+04, 0.71565000E+03, -.37239800E+03, -.10112500E+03, -.35773700E+03, 0.37974700E+03, 0.49478800E+03, -.23992900E+03, 0.17326900E+03, -.34985800E+03, 0.30983200E+03, -.35744100E+03, -.18275500E+04, 0.90987800E+03, 0.12034500E+04, 0.91298400E+03, 0.16625000E+03, -.57529400E+03, 0.57407800E+03, 0.81172500E+02, 0.10002100E+04, -.22721900E+03, -.11994200E+04, -.35245400E+04, 0.17582900E+04, 0.15702600E+04, 0.17631400E+04, -.13771400E+03, 0.44043100E+03, 0.70199100E+03, -.93257200E+03, 0.26675400E+03, 0.50746800E+03, 0.15142000E+04, -.11301100E+04, 0.56567000E+03, 0.10561600E+04, 0.56476800E+03, 0.29931900E+03, 0.97916600E+02, 0.16104200E+03, -.51236200E+02, -.26731600E+03, 0.11107000E+03, 0.44733500E+03, 0.80134300E+04, -.39442000E+04, -.31299100E+04, -.40084800E+04, -.21453900E+03, 0.40553500E+03, -.11436900E+04, 0.22111400E+04, -.16211700E+04, 0.27109200E+03, -.28931100E+04, -.45466500E+02, 0.33313000E+02, -.67903600E+03, 0.21208400E+02, 0.42951900E+03, 0.21731900E+03, -.29802200E+03, 0.11454200E+03, -.57229400E+03, 0.10030500E+03, 0.15371800E+03, 0.47765600E+04, -.23293300E+04, -.29573100E+04, -.23886900E+04, 0.72967300E+03, 0.16136500E+04, -.15964400E+04, 0.42579000E+03, -.21264000E+04, 0.12105300E+04, -.15999800E+04, 0.56960300E+01, 0.38743700E+01, -.79039200E+00, -.10494900E+02, -.32033000E+01, 0.17982300E+01, -.50006900E+01, -.12697700E+02, -.12100900E+02, 0.57000700E+03, -.20428500E+02, -.23319400E+03, 0.19977900E+02, 0.62562300E+02, -.14191900E+03, 0.30883900E+03, 0.75992200E+02, -.56791300E+01, -.22490300E+03, -.48819800E+03, 0.12255500E+03, -.13192400E+02, 0.74335900E+02, 0.16692800E+03, 0.14166300E+03, 0.62321300E+03 },
        { -.97186400E+00, 0.14354700E-01, 0.34859300E-01, -.28364400E-01, -.92127100E-01, 0.31497400E-01, 0.23177400E+00, -.14567900E+00, -.32962500E-02, 0.13808100E-02, 0.23627600E-02, 0.72200600E-01, -.11466200E-02, 0.47490400E-02, -.15027800E-01, 0.47364000E-02, 0.40970100E-01, 0.51931700E-01, -.43836800E-01, 0.73872600E-01, 0.59640700E-02, 0.47745200E-02, 0.25644300E+00, -.27381700E-01, 0.35237700E-02, -.57343300E-02, -.26576600E-03, 0.25006900E-01, -.17239400E-01, -.35481000E-01, 0.15779600E-01, -.65758100E-01, -.29709000E-02, -.51293000E-02, -.53221400E-01, -.63981100E-02, -.14489000E-01, 0.83162700E-02, 0.29954900E-01, -.12530100E-01, -.64531000E-01, 0.89303300E-01, -.46154100E-01, -.59021200E-01, 0.39913200E-01, -.86373200E-02, -.12679400E-01, 0.14122600E-02, 0.41633700E-01, -.97443100E-02, -.18067000E-01, -.67895400E-01, 0.24997200E-02, 0.69830500E-02, -.14708200E+00, 0.10190600E-01, -.18360100E-02, 0.75770300E-01, 0.34181400E-01, -.50854400E-02, -.53747800E-01, 0.35540400E-01, 0.73585200E-01, -.56878700E-02, -.43746900E-01, -.24563300E-01, 0.82624500E-01, 0.82531600E-04, -.32529300E-01, 0.17601500E-03, 0.91605000E-02, 0.39900900E-02, 0.10521900E-01, -.14879600E-01, -.44611100E-01, 0.31366700E-01, -.35527700E-01, -.64150300E-01, 0.88176400E-01, -.48704600E-01, -.36240000E-02, 0.44696300E-01, 0.12504700E+00, 0.20227800E-01, -.43247700E-01, -.13079500E+02, 0.35356500E+01, 0.72832400E+01, -.15238700E+03, 0.74363500E+02, -.53511400E+02, 0.76159400E+02, -.19154100E+02, -.42220600E+02, -.35182200E+02, -.24385500E+03, -.62721100E+02, -.36555400E+02, 0.70455400E+02, 0.38213100E+03, -.18927900E+03, -.15110200E+03, -.19110500E+03, -.32778200E+02, 0.87616900E+01, 0.55570500E+02, 0.36067100E+03, 0.90874100E+02, 0.15155700E+01, -.11884500E+03, 0.21584300E+03, -.10833800E+03, -.11581900E+03, -.10792500E+03, -.33690800E+02, -.44484700E+02, 0.37942300E-01, 0.69604200E+02, -.23812400E+02, -.31033000E+02, -.88927400E+02, -.67118400E+02, 0.33522900E+02, -.31811200E+01, 0.33555400E+02, -.45695300E+02, -.53706300E+02, 0.28168000E+02, -.61410900E+01, 0.59013300E+02, -.21372000E+02, 0.82940000E+02, -.10073500E+03, 0.50451400E+02, 0.76471500E+02, 0.50402600E+02, 0.17602000E+02, 0.26811400E+02, 0.93614100E+01, -.21982300E+02, -.15577900E+02, 0.18449300E+02, 0.29014600E+02, -.47323400E+02, 0.23579000E+02, 0.36996000E+02, 0.23664000E+02, 0.41953200E+02, 0.16086100E+02, -.25271800E+02, -.39997400E+02, -.29714200E+02, 0.18054600E+02, -.15553300E+01, 0.33727700E+03, -.16685300E+03, -.79232400E+02, -.16867300E+03, -.71281500E+01, 0.33391200E+02, 0.22839900E+02, 0.30784500E+03, 0.69372000E+02, 0.24159600E+02, -.12407800E+03, 0.10847300E+03, -.54046200E+02, -.19469900E+02, -.54231100E+02, -.10737700E+02, -.93594800E+01, 0.83574400E+01, 0.32422200E+02, -.34677100E+02, -.37760400E+01, -.48999600E+02, 0.35824200E+02, -.18163300E+02, 0.14286100E+02, -.17922800E+02, 0.26037200E+02, 0.36198000E+01, -.71159900E+01, -.12432500E+02, -.42279900E+01, 0.91963600E+01, -.43350000E+02, -.69002700E+01, 0.32475400E+01, 0.24566500E+02, 0.34461200E+01, -.30018600E+02, -.24833300E+01, -.10527400E+02, -.18188900E+02, 0.33895100E+02, -.10835400E+02, 0.11318300E+01, -.36380200E+02, 0.18335700E+02, 0.36917500E+02, 0.18187200E+02, 0.80831500E+01, 0.68774900E+01, 0.18860100E+02, 0.48660400E+01, 0.10119600E+02, 0.78877900E+01, 0.10253900E+02, -.93761400E+01, 0.46011800E+01, 0.10924900E+02, 0.46764500E+01, -.21800600E+02, 0.31284700E+01, -.98662300E+01, -.19398200E+02, 0.10776100E+02, -.29791600E+01, 0.33843700E+01, 0.34114100E+02, -.16950200E+02, -.12042400E+02, -.17045200E+02, -.69971300E+02, -.27186400E+02, 0.47202700E+02, 0.45533300E+02, -.96354000E+01, -.22771600E+02, 0.52191500E+02, -.20053000E+03, 0.10009600E+03, 0.11203900E+03, 0.10026100E+03, 0.26438700E+02, 0.38462000E+02, -.15316700E+01, -.60707300E+02, -.82509500E+01, 0.31278000E+02, 0.87000900E+02, 0.16944300E+03, -.83955700E+02, -.72294400E+02, -.84728200E+02, -.25058700E+02, -.77186700E+01, 0.46572300E+02, 0.19193200E+03, 0.54497800E+02, -.11048400E+02, -.40263200E+02, -.12903700E+02, 0.62010400E+01, -.21694800E+02, 0.64289400E+01, -.11623600E+01, -.20636700E+02, 0.48776200E+02, 0.47774900E+02, 0.43915200E+02, -.97479900E+01, 0.67777700E+01, 0.41860500E+02, -.20166800E+02, 0.44512100E+02, -.20912700E+02, 0.14943000E+02, 0.19329600E+02, 0.30389500E+02, 0.13234300E+03, 0.56433400E+02, 0.17710900E+02, -.44302100E+02, 0.25667600E+01, 0.72049900E+00, 0.14153200E+01, -.35857900E+00, 0.22775200E+00, 0.16408900E+01, -.51181700E+00, 0.56018100E+00, 0.43328200E+00, 0.15474800E+02, 0.78657700E+01, -.23494100E+02, 0.10570000E+01, -.30263300E+01, 0.16193200E+01, 0.81916000E+01, -.55325600E+01, 0.49895900E+00, -.27985600E+01, -.38884400E+02, -.19135800E+01, 0.48816500E+00, 0.10066100E+01, -.26246300E+02, -.13250300E+01, 0.16409900E+02 },
        { -.10108700E+02, 0.61082400E+00, -.32248000E-01, -.82302000E+00, -.23782000E-02, -.11432200E+00, 0.38301100E+00, 0.30185200E+00, -.65767600E+00, -.52075200E-01, 0.53179100E-01, -.19957300E+01, -.17378100E+00, -.32634000E-01, -.12313500E+00, 0.15321400E+00, -.12367600E+01, -.16977900E+00, -.10260200E+01, 0.33222900E+00, -.28797400E+00, -.58761800E-01, -.22167200E+01, 0.48359000E+00, 0.41231300E-01, 0.14458800E+00, -.84495300E-01, 0.39619200E+00, 0.88336400E+00, -.32789900E+00, 0.98358400E-01, 0.50883900E-01, -.13268100E-01, 0.79568200E-02, -.45769400E+01, 0.20207000E+00, -.89084100E-01, -.15605300E+01, 0.44488700E-01, -.21191300E+00, 0.30432400E+00, -.71673900E+00, -.88199300E-02, 0.13257000E+00, 0.39344600E-01, -.43593800E+00, -.71362800E-03, 0.20339500E-01, 0.11274800E+00, 0.48389500E-01, 0.95078500E-01, -.17587300E+01, -.11041400E+00, 0.26543200E+00, 0.26545300E+01, 0.47924400E-02, 0.14336600E-01, -.39478900E+00, 0.45357600E+00, 0.22044300E-01, 0.98752500E-01, -.16513300E+00, -.25608900E+00, -.48122600E-01, 0.67742600E+00, 0.36099200E-01, -.21587400E+00, 0.24050200E-01, 0.30156300E-01, 0.64380100E-03, -.10127400E+00, 0.14609900E+00, -.74893800E-01, -.44237100E-01, 0.12196900E+01, 0.40777700E+00, -.71672800E+00, -.19922400E+01, -.26909000E+01, 0.14095600E+01, 0.55269600E-01, 0.65333700E-01, -.11262200E+01, -.67445500E+00, 0.56753900E+00, 0.36213200E+00, -.15826900E+03, -.46322000E+03, 0.11564300E+05, -.52616700E+04, -.44329800E+04, -.57812800E+04, 0.53600600E+03, 0.68986400E+04, -.39323400E+04, 0.37852600E+04, -.46623300E+04, 0.43242800E+04, 0.30128100E+03, -.18070600E+05, 0.84110900E+04, 0.92794600E+04, 0.90350700E+04, -.91907900E+03, -.89177100E+04, 0.68301600E+04, -.24856500E+04, 0.45655200E+04, -.63162000E+04, 0.10769700E+02, -.45862600E+04, 0.22894400E+04, 0.57859700E+03, 0.22931000E+04, 0.14385800E+04, 0.78119300E+03, 0.11915500E+03, -.12222800E+04, 0.10854300E+04, 0.62050600E+03, 0.23939700E+04, -.13609700E+04, 0.67247600E+03, 0.33397100E+04, 0.68046200E+03, 0.11182600E+04, -.22591700E+03, 0.73013800E+03, 0.10453200E+04, 0.34606400E+03, -.28554800E+03, 0.20989000E+04, 0.19668500E+04, -.99203200E+03, -.12190300E+04, -.98450500E+03, -.85898700E+02, -.42313600E+03, -.61454800E+03, -.52965200E+03, -.50138500E+03, -.13227300E+03, -.16544400E+04, -.17714100E+04, 0.87994000E+03, 0.87641700E+03, 0.88572200E+03, -.36182700E+03, 0.76048300E+02, 0.48663400E+03, -.43470400E+03, 0.36048100E+03, 0.10916500E+03, 0.75486400E+03, -.14281900E+05, 0.65293000E+04, 0.73744900E+04, 0.71402200E+04, -.16874000E+04, -.10274900E+05, 0.72434300E+04, -.11270500E+04, 0.54927800E+04, -.75326800E+04, -.15308300E+04, 0.12777600E+04, -.62972900E+03, -.44128700E+03, -.63884100E+03, 0.20739500E+03, 0.30909500E+03, -.27499100E+03, -.35495700E+03, -.53472100E+03, 0.52675800E+02, -.10106200E+04, -.21602300E+04, 0.10656400E+04, 0.48456500E+03, 0.10800600E+04, 0.38882100E+02, -.32223000E+03, 0.12796100E+04, 0.10541700E+04, 0.13661600E+04, -.21288800E+03, 0.16846100E+04, 0.73409000E+03, -.41061200E+03, -.70119400E+03, -.36704000E+03, -.35023300E+03, 0.38128500E+03, -.11472800E+03, -.70840700E+02, -.68279900E+03, 0.16957300E+03, 0.11116500E+03, -.23140200E+04, 0.11271800E+04, 0.63006000E+03, 0.11570600E+04, -.25817400E+03, -.47353400E+03, 0.34638900E+03, -.67546000E+03, 0.66348500E+03, -.21771300E+03, 0.13237500E+04, 0.14019900E+04, -.72298200E+03, -.11639600E+04, -.70103000E+03, -.43586700E+03, 0.19362700E+03, -.37051500E+03, -.16572900E+03, -.67171700E+03, -.51607200E+02, -.22914900E+03, 0.26495500E+03, -.10930500E+03, -.10586700E+03, -.13242500E+03, 0.73243200E+03, 0.13176900E+03, -.26060700E+03, -.27007700E+03, -.45901700E+03, 0.99843500E+02, -.37375500E+03, 0.18625900E+04, -.91872300E+03, -.20962000E+03, -.93130900E+03, -.49523900E+03, -.34763200E+03, 0.68959200E+02, 0.28946000E+03, -.30873000E+03, -.16887600E+03, -.14153200E+04, -.47405600E+04, 0.21057200E+04, 0.24035500E+04, 0.23699900E+04, -.41898000E+03, -.28839100E+04, 0.11070400E+04, -.26288200E+04, 0.22460900E+03, -.17103500E+04, -.11908200E+04, 0.29743900E+04, -.15001300E+04, -.12145100E+04, -.14872600E+04, 0.22841600E+03, -.75507900E+03, -.70216900E+03, -.80816600E+03, -.88445700E+03, -.42821700E+03, -.64169200E+03, -.78898100E+04, 0.37244900E+04, 0.31578600E+04, 0.39445700E+04, 0.93985300E+02, -.32930200E+04, 0.23904600E+04, -.19173700E+04, 0.28116800E+04, -.20880800E+04, 0.10769500E+04, -.44636700E+01, -.11108500E+02, -.22595100E+02, 0.97064000E+01, 0.49611900E+02, -.59849100E+02, -.25365300E+02, 0.21215300E+02, -.20876100E+00, 0.86780000E+03, -.10679500E+04, 0.88503300E+03, 0.92794300E+02, 0.21727700E+03, 0.12422600E+01, 0.13475100E+04, 0.59662900E+02, 0.38772800E+02, 0.62014800E+02, 0.41235400E+03, 0.60909200E+02, 0.13364500E+01, -.56157500E+02, 0.90655700E+03, 0.25433400E+03, 0.53057700E+03 },
        { -.12828600E+02, 0.31458300E+00, 0.41495900E+00, -.74278800E+00, -.14781300E+01, 0.29492200E+01, -.65117400E+00, 0.13925200E+01, -.14270000E+01, 0.24784500E+01, 0.10412700E+01, -.48588600E+01, -.10611100E+00, 0.41967800E-01, -.13529900E+01, 0.76219300E+00, -.11301900E+01, -.41638700E+00, -.11387200E+01, 0.62573900E+00, 0.93792900E+00, -.11601100E+01, -.69033400E+01, 0.19835400E+01, -.24035400E+00, 0.29330600E+00, -.57006500E+00, 0.19855400E+01, 0.36328300E+01, -.27071400E+01, 0.43172200E+00, -.45113200E+01, -.56490100E+00, 0.41751600E+00, 0.48780300E+01, -.13794100E+00, 0.57983100E+00, 0.19335300E+01, 0.43096100E+00, 0.72277200E+00, -.13406200E+00, -.17348800E+01, -.27500800E+00, 0.30403200E+01, -.29033900E+00, 0.64073700E+00, -.91092800E+00, -.10052400E+00, -.74776500E+00, -.18068600E+00, 0.89460000E+00, 0.51298200E+01, 0.12918100E+00, -.78584500E+00, -.52542000E+00, -.20881800E-02, 0.31948400E-01, -.15453000E+01, -.24761400E+01, 0.23242600E+00, 0.42823500E+00, -.63000000E-01, -.21036100E+01, 0.31946600E+00, 0.16997200E+00, 0.99007900E-01, -.20872000E+01, 0.15876200E+00, -.33320000E+01, -.29935700E-02, 0.82835800E+00, -.33745600E+00, 0.19840900E+00, -.77336100E-01, 0.28899600E+01, 0.83976500E+00, 0.17859500E+01, 0.73269400E+01, -.37844800E+01, 0.16738900E+01, 0.15619100E+00, 0.92548700E+00, 0.21563500E+00, -.18033700E+01, 0.21695100E+01, -.41445300E+01, -.30228200E+00, 0.13409500E+04, 0.20361500E+04, -.81275000E+03, -.23549900E+03, -.10097700E+04, -.18161000E+03, 0.12699200E+04, 0.18567800E+04, 0.21170600E+04, 0.44361100E+03, 0.13505400E+04, -.74532300E+04, -.29483100E+04, 0.12742100E+04, -.21398800E+04, 0.14706800E+04, 0.74260700E+02, -.26508100E+03, -.10516000E+04, -.10073500E+04, -.28901100E+04, -.26551200E+03, 0.14580300E+05, -.21826600E+04, 0.10846500E+04, 0.22313200E+04, 0.10909400E+04, 0.38635400E+03, 0.29402600E+03, 0.13087600E+02, -.79881100E+03, 0.21561000E+03, 0.13485600E+03, 0.70983100E+03, -.91260900E+02, 0.36314600E+02, 0.13008200E+04, 0.45321000E+02, 0.10444400E+04, -.32876300E+02, 0.11436800E+04, 0.28949000E+04, 0.15333600E+03, -.34318000E+03, -.45137800E+04, -.20966200E+04, 0.10515600E+04, 0.54430700E+03, 0.10490600E+04, 0.10887900E+03, -.37070200E+03, 0.67688200E+03, -.18118100E+03, 0.69271500E+03, 0.55703400E+02, 0.73180200E+03, 0.35321200E+04, -.17709500E+04, -.11837300E+04, -.17658800E+04, 0.20145300E+03, -.63330500E+03, 0.10295700E+03, 0.18367600E+04, -.10113200E+03, -.55391100E+03, -.27822500E+04, -.31860400E+04, 0.13967200E+04, -.87140700E+03, 0.15848700E+04, 0.46541900E+02, -.29154600E+03, -.12742900E+04, -.15435400E+04, -.24888100E+04, -.34535300E+03, 0.13209900E+05, -.48278200E+03, 0.24842700E+03, -.15475900E+03, 0.24184700E+03, -.48976200E+03, 0.11334700E+04, -.79752100E+03, -.11698400E+04, 0.14249100E+03, 0.69250900E+03, 0.30589500E+04, 0.10115700E+04, -.52986300E+03, -.14122100E+04, -.50646400E+03, 0.42474600E+03, -.97258500E+02, -.28512500E+03, -.40308600E+03, -.54493500E+03, -.22236800E+02, -.21442500E+04, 0.92037300E+02, -.63219800E+02, -.17491500E+04, -.46038700E+02, 0.86737500E+02, 0.32515900E+03, -.72614000E+02, 0.21421200E+03, 0.39444900E+02, 0.41088300E+03, -.10407100E+03, -.69567200E+03, 0.35056900E+03, 0.54373600E+03, 0.34829700E+03, -.52263900E+03, -.97746100E+03, 0.30499100E+03, -.10588500E+03, 0.37447300E+03, -.75865600E+03, -.33652000E+03, 0.17645100E+03, -.93228800E+02, -.15127600E+04, -.88786800E+02, -.27354600E+02, 0.33520700E+03, 0.21095200E+03, 0.53229600E+03, 0.31102100E+03, 0.45584500E+03, -.40406500E+03, -.29490900E+04, 0.14886600E+04, 0.17789900E+04, 0.14752500E+04, 0.84960400E+03, 0.10130200E+04, -.27211800E+03, -.11657900E+04, 0.15814400E+03, 0.10777900E+04, 0.15606500E+04, -.88936000E+03, 0.44556900E+03, -.82683700E+03, 0.44446600E+03, 0.36681600E+03, 0.16147300E+03, 0.14384600E+03, 0.13302300E+03, 0.11566200E+04, 0.39625800E+03, 0.59526900E+02, 0.29164500E+04, -.15666800E+04, -.29365400E+04, -.14613400E+04, -.11285700E+03, 0.11628100E+03, -.19057400E+04, -.11960400E+04, -.28670300E+04, 0.13089600E+03, 0.45605800E+04, 0.23588400E+04, -.11980400E+04, 0.10489300E+04, -.11804500E+04, 0.20620500E+03, -.82459900E+03, 0.41503300E+03, 0.11058900E+04, -.12802600E+04, -.53155300E+03, -.39498400E+04, -.43334200E+04, 0.20679200E+04, 0.12385400E+04, 0.21641700E+04, 0.45809500E+03, -.75588100E+03, -.25236700E+03, -.12344100E+04, 0.56358900E+03, -.67550100E+03, 0.49116600E+04, 0.21207100E+01, -.31673700E+02, 0.19374200E+02, 0.97826200E+01, -.48747200E+02, 0.69396800E+02, 0.44642900E+02, 0.21211400E+02, 0.44691800E+01, 0.65862100E+03, -.20086300E+04, 0.35679700E+03, 0.20535100E+03, 0.24350000E+03, -.36714500E+03, 0.14553800E+04, 0.27018400E+03, -.71256500E+02, 0.49534900E+02, 0.14353000E+03, -.31620800E+02, -.23604100E+01, 0.21399900E+01, 0.10402800E+04, 0.47981700E+03, 0.80473700E+03 },
        { 0.75712400E+01, -.14511800E+00, -.29949200E+00, 0.49919500E+00, 0.65059800E+00, -.36708600E+00, -.13414000E+01, 0.48109300E+00, 0.38728100E+00, 0.13483400E+00, -.56869600E-02, -.61843000E+00, -.45306100E-01, -.58811600E-01, 0.22875400E+00, -.17328700E+00, -.34964900E+00, -.34433800E+00, 0.50629600E+00, -.10267200E+01, -.40253600E+00, 0.13193200E+00, -.27464100E+01, 0.28805200E+00, -.34088000E-01, -.35619700E-02, -.12179200E+00, -.23424700E+00, 0.29465000E+00, -.46135600E+00, -.82257500E-01, -.64621300E-01, 0.17644100E-01, -.45427600E+00, 0.23501600E+01, 0.28654800E+00, 0.12537400E+00, 0.40155900E+00, 0.11548500E+00, 0.56454200E-01, -.11311100E+00, -.72009300E+00, 0.10769800E+00, 0.70833400E-01, -.30233600E+00, 0.17580800E+00, -.96086000E-01, -.13514600E-01, -.28291600E+00, -.10030400E+00, -.32317800E+00, -.15043400E+01, 0.18090800E+00, 0.14717000E+00, -.20954800E+00, -.12817600E+00, -.16040300E-01, -.12269300E+00, -.41344200E+00, 0.82304900E-01, 0.28874300E+00, -.51391500E+00, -.41637400E+00, -.98094100E-01, 0.87050900E-02, 0.19770100E+00, -.11991900E+01, -.35415500E-02, -.92307600E+00, 0.12790100E-02, -.33711600E-01, 0.19968200E+00, -.51441700E-01, -.63907100E-01, -.52998700E-01, -.25128400E+00, 0.16429900E+00, 0.44736500E+01, -.11095200E+01, -.42757200E+00, -.28635700E-01, 0.39156300E+00, -.49392500E+00, 0.84280600E-01, -.10496000E+01, -.47611800E+01, 0.57800200E-01, 0.11758300E+00, -.11771600E+05, 0.58357100E+04, 0.48886500E+04, 0.58851900E+04, -.11562800E+04, -.39327100E+04, 0.39747700E+04, -.11365200E+04, 0.47645200E+04, -.23485800E+04, 0.33137700E+04, 0.26070800E+05, -.12952100E+05, -.10148800E+05, -.13036700E+05, -.52195300E+03, 0.41299100E+04, -.73698000E+04, 0.18789500E+04, -.71951400E+04, 0.27700400E+04, -.85781200E+04, 0.33221300E+04, -.16721600E+04, -.18847100E+04, -.16612000E+04, -.70388900E+03, -.56268000E+03, -.11115900E+03, 0.10923700E+04, -.37621000E+03, -.46566200E+03, -.11518700E+04, 0.57707300E+03, -.29042800E+03, -.19909900E+04, -.28866600E+03, -.30883500E+03, 0.24170200E+03, -.73758100E+03, -.14265500E+04, -.21860600E+03, 0.61279000E+03, -.78575300E+03, -.15902800E+04, 0.79925800E+03, 0.12754300E+04, 0.79633800E+03, 0.58696000E+03, 0.18283900E+03, 0.29001100E+03, 0.23314000E+02, -.22525400E+03, 0.83279900E+02, 0.84545200E+03, 0.27143600E+04, -.13571700E+04, -.18647500E+04, -.13571000E+04, 0.16365700E+03, -.40203100E+03, -.60065900E+03, 0.91542300E+03, -.39340900E+03, -.42830400E+03, -.13190800E+04, 0.21880400E+05, -.10860800E+05, -.85410000E+04, -.10941700E+05, 0.22990700E+03, 0.47200100E+04, -.69623900E+04, 0.90354600E+03, -.70737200E+04, 0.31970300E+04, -.70105500E+04, -.25584400E+03, 0.12541400E+03, 0.42479200E+03, 0.12811300E+03, -.36773900E+03, -.27609400E+03, 0.27684000E+03, 0.41469300E+03, 0.61493200E+02, -.22537300E+03, 0.78133400E+03, -.18794400E+03, 0.83100500E+02, 0.50775200E+03, 0.93616000E+02, -.17318500E+03, -.62642100E+02, -.28575200E+02, -.12986600E+03, -.15072300E+03, -.12840100E+03, -.27354300E+03, -.12910000E+04, 0.65095400E+03, 0.12069500E+04, 0.64538100E+03, -.21523900E+03, -.54154200E+03, 0.36096500E+03, 0.14269000E+03, 0.13829900E+04, -.52625300E+03, -.12576000E+04, 0.18129800E+04, -.94977300E+03, -.54813400E+03, -.90654300E+03, 0.44323900E+03, 0.60212700E+03, -.41182800E+03, 0.35787100E+03, -.72241900E+03, 0.37994000E+03, -.86109900E+03, -.19368500E+04, 0.97383700E+03, 0.16427900E+04, 0.96805000E+03, 0.46757700E+02, -.51470900E+03, 0.61669900E+03, 0.10350600E+03, 0.12191500E+04, -.37094000E+03, -.99127100E+03, -.28664400E+04, 0.14314600E+04, 0.13154300E+04, 0.14336100E+04, -.61439300E+03, 0.10001300E+03, 0.98360900E+03, -.60282300E+03, -.13085800E+02, 0.19880700E+03, 0.20723400E+04, -.30443900E+04, 0.15216900E+04, 0.19042200E+04, 0.15220600E+04, 0.58427300E+03, 0.39118500E+03, 0.20189700E+03, -.67353200E+03, -.26417300E+03, 0.37544700E+03, 0.11062900E+04, 0.79768200E+04, -.39543600E+04, -.29450200E+04, -.39887900E+04, -.58213500E+02, 0.11249600E+04, -.17039900E+04, 0.17840400E+04, -.15046100E+04, 0.58335000E+03, -.25631600E+04, -.92402000E+03, 0.45588300E+03, -.11384300E+04, 0.46127500E+03, 0.85059500E+02, -.11532400E+03, 0.28797300E+03, 0.29584200E+03, 0.10855500E+03, -.17876200E+03, 0.29952400E+03, 0.75399900E+04, -.37531300E+04, -.31674300E+04, -.37696600E+04, 0.39439200E+03, 0.20703800E+04, -.25781000E+04, 0.22464200E+03, -.29802400E+04, 0.13337100E+04, -.25021900E+04, -.15299800E+01, -.64141300E+00, 0.12173700E+02, -.16855900E+02, -.13186200E+02, 0.85762000E+01, 0.98086500E+01, -.21670700E+02, -.68085500E+01, 0.15672400E+03, 0.58694900E+03, -.50845000E+03, -.12048900E+03, 0.19275600E+03, -.10837600E+03, -.29716500E+03, -.54389900E+02, -.28235000E+02, -.19060400E+03, -.57017500E+03, 0.66125100E+02, -.45823100E+02, 0.92958800E+02, -.17307800E+03, 0.15290100E+03, 0.15381000E+03 },
        { -.31877000E+01, 0.44388000E-01, 0.62923100E-01, -.12285300E+01, -.17762400E+00, -.39620900E+00, 0.84526900E+00, -.28873800E+00, -.16993300E+01, -.80878300E+00, 0.13949000E-01, -.20101000E+00, 0.76435900E-01, 0.50526300E-01, 0.28021700E-01, -.43322500E-01, 0.26233400E-01, 0.12561000E+00, -.14984300E+00, -.46316900E-01, -.11474800E+00, 0.89122300E-02, 0.22062400E+01, 0.14538300E+00, 0.87272600E-01, 0.33207200E-01, 0.27600800E-01, 0.59361700E+00, -.70496200E-01, -.13079300E+00, -.11220400E+00, -.44355300E+00, -.12642200E-01, -.10995300E+00, -.32237200E+00, 0.12332300E+00, -.53798900E-01, 0.28889500E+00, -.10727100E+00, 0.28101600E+00, -.21279300E+00, 0.11593300E+00, 0.58592700E-01, 0.21179500E+00, -.14362000E+00, 0.26862900E-01, 0.48595400E-01, 0.37279100E-02, 0.10672600E-01, 0.57780700E-02, 0.31613400E+00, 0.14892300E+01, -.27591700E-01, 0.11121400E+00, 0.32433500E-02, -.71228500E-01, -.23262900E-01, -.59899600E-01, -.68248700E-01, -.44339700E-02, -.38889000E-01, -.11112000E+00, 0.10070300E+00, -.42250000E-02, 0.46733100E-01, -.39120800E-01, -.11422500E+00, 0.81916300E-02, -.11846800E+00, 0.14648600E-02, 0.20604900E-01, -.94039300E-01, -.34950800E-01, 0.39294000E-01, -.52530700E+00, 0.45379700E-01, 0.44860100E-01, 0.21623000E+01, -.73336700E+00, 0.25478000E+00, 0.16845000E-01, 0.31699800E+00, 0.23936800E+00, -.37176300E+00, 0.52360600E+00, 0.18886500E+01, 0.26716700E+00, 0.14052900E+00, -.15585800E+00, -.23953200E+03, 0.55885400E+03, -.11191300E+01, -.30895400E+03, -.22250300E+04, 0.15689400E+04, 0.77179700E+03, 0.64621800E+03, -.17354600E+04, -.11784800E+03, 0.13604400E+04, -.41529800E+03, -.34830300E+04, -.67934600E+03, 0.67692100E+03, 0.22709700E+04, -.16174100E+04, -.25733300E+03, 0.45012500E+03, 0.17161000E+04, -.10224100E+04, 0.20188300E+04, -.10105200E+04, -.13038300E+02, -.10093200E+04, -.55514500E+03, -.36389000E+03, -.82676700E+02, 0.45649700E+03, -.62107300E+03, -.28532000E+03, -.87758800E+03, 0.45859300E+03, -.22705900E+03, -.99716300E+03, -.22921700E+03, -.79317100E+02, 0.80331400E+02, -.26461600E+03, -.32319000E+03, -.17481300E+03, 0.13503700E+03, 0.14006900E+03, 0.37106700E+03, -.18312400E+03, -.81185400E+02, -.18552400E+03, -.20680000E+02, 0.18076800E+03, -.11121800E+03, 0.96565900E+02, -.18872800E+03, 0.59469100E+02, -.87534700E+02, 0.61725800E+03, -.30744400E+03, -.32585500E+03, -.30867600E+03, 0.33797400E+02, -.62842100E+01, -.23498000E+03, 0.78975600E+02, -.19999400E+03, -.26515200E+02, -.41590300E+03, -.52098100E+03, 0.52080500E+03, -.21839800E+04, 0.26205900E+03, 0.94450100E+03, 0.29149300E+04, -.18977800E+04, -.10349700E+04, 0.55956100E+02, 0.23047100E+04, 0.18786900E+02, -.24641900E+03, 0.12345200E+03, 0.20369600E+03, 0.12309200E+03, 0.82310900E+02, -.10128200E+03, 0.20750200E+03, 0.13410600E+03, 0.12444500E+03, -.41830300E+02, 0.54120200E+02, 0.23471800E+03, -.10916800E+03, -.22523100E+03, -.11716500E+03, -.65636900E+02, 0.36760100E+02, -.26071400E+03, -.10797400E+03, -.17535400E+03, 0.19352500E+02, 0.56591700E+02, -.37903900E+03, 0.20041700E+03, 0.87987800E+02, 0.18955500E+03, 0.14846200E+03, -.12835900E+03, 0.72202300E+02, 0.16667800E+03, 0.35883400E+03, -.13662800E+03, 0.27857300E+03, 0.55054000E+03, -.24925300E+03, -.17649300E+03, -.27532000E+03, -.24323500E+02, 0.81379200E+02, -.15862300E+03, 0.28903300E+02, -.19067700E+03, 0.33352300E+02, -.18967400E+03, -.43146900E+03, 0.21979500E+03, 0.37694200E+03, 0.21591700E+03, 0.23756500E+03, -.91038300E+02, 0.14829200E+03, 0.18091600E+03, 0.21876000E+03, -.10237400E+03, 0.17759700E+03, -.28946000E+03, 0.13740100E+03, 0.24281500E+03, 0.14452200E+03, -.17796600E+03, -.24828200E+02, 0.15559600E+03, -.50817500E+02, 0.97208800E+01, 0.13978400E+02, 0.23501300E+03, -.15200200E+04, 0.75441000E+03, 0.27397600E+03, 0.76007600E+03, 0.19642600E+03, 0.35916500E+03, -.36034500E+02, -.36213500E+03, 0.38002400E+03, 0.26518200E+03, 0.64902800E+03, 0.50512800E+03, -.13947500E+03, -.13461200E+04, -.25201600E+03, 0.31180100E+03, 0.68282200E+03, -.33459100E+03, 0.31151600E+03, 0.41460400E+03, 0.46086300E+03, -.38071300E+03, 0.31023400E+03, -.14975800E+03, -.57881200E+03, -.15476800E+03, -.13111700E+03, 0.13747400E+03, -.24601400E+03, 0.44655200E+02, -.22419500E+03, 0.63548000E+02, 0.10652700E+03, 0.70011200E+03, -.24478600E+03, -.61812600E+03, -.34978900E+03, -.35215300E+02, 0.97040300E+03, -.82454000E+03, -.23438100E+03, -.30380400E+03, 0.74308500E+03, -.33127400E+03, -.94757000E+00, -.31329200E+01, 0.29288400E+01, -.81579200E+00, -.28995800E+01, -.10897900E+01, -.53857900E+01, -.49534100E+01, -.29357200E+01, -.46797900E+03, 0.24459500E+03, -.20854500E+03, -.18261500E+02, -.11718300E+03, 0.44527700E+02, -.53835800E+03, -.10306100E+02, 0.11908500E+01, -.22041200E+02, 0.17679100E+03, -.22227700E+02, 0.33786700E+01, -.15269100E+02, 0.81814800E+02, -.89689500E+02, -.43142200E+03 },
        { -.28066600E+01, 0.57109800E-01, 0.18625600E+00, 0.55006400E-01, -.91083600E-01, 0.36066500E+00, -.22461700E+00, 0.27660000E+00, -.36580200E-01, 0.19300700E+00, 0.80630200E-02, 0.15755200E+00, -.24755200E-02, -.11453900E+00, 0.28065100E-01, 0.24637400E-01, 0.12615900E+00, 0.11489000E+00, 0.50745800E-01, 0.68171700E-03, -.75172100E-01, -.23098400E-02, 0.83988800E+00, 0.34763300E-01, 0.38266800E-01, -.36061900E-01, 0.49398500E-01, -.20506000E-01, -.58500900E-02, -.12986700E+00, -.59784500E-01, -.19924800E+00, 0.54603700E-03, 0.34119200E-01, -.35802300E+00, 0.48626200E-01, -.13240400E-03, -.12626000E+00, -.11856400E-02, 0.82948200E-01, 0.15405900E-02, -.10426600E+00, 0.27157000E-01, -.30422600E-01, -.58491300E-01, 0.14887800E-01, -.35233200E-01, 0.10598300E-02, 0.64191200E-01, 0.21138300E-02, -.11497400E+00, 0.22264300E+00, -.90592900E-02, -.76486400E-02, -.17706000E+00, -.23627500E-01, -.12052400E-02, -.27184000E+00, -.13736900E-02, -.22354500E-01, 0.67433500E-01, 0.72828100E-01, -.97182900E-01, 0.10836500E-01, -.97849700E-01, -.62595200E-01, 0.60010600E+00, 0.24821800E-02, 0.96783000E+00, -.14700700E-02, 0.48863800E-01, -.58185900E-01, 0.11052700E+00, 0.53029800E-01, -.52121000E+00, -.10247100E+00, 0.12788300E-01, -.16977300E+01, 0.55006200E+00, 0.61993900E+00, 0.17536400E-01, -.41912000E+00, -.12960100E+00, 0.24753900E+00, 0.17674500E+00, 0.40338600E+01, 0.15657300E+00, -.14186500E-01, 0.40324000E+00, 0.12218200E+00, 0.36930200E+04, 0.58986400E+00, 0.91979500E+03, 0.10801500E+04, -.27679800E+03, 0.53022700E+03, -.12985200E+02, 0.61424600E+03, 0.88678400E+02, -.70156300E+04, 0.34917700E+04, 0.24894200E+04, 0.35082400E+04, -.27964400E+03, -.14511300E+04, 0.22670000E+04, -.35892300E+03, 0.18253500E+04, -.99515200E+03, 0.26242600E+04, -.83669300E+03, 0.42340600E+03, -.30881000E+03, 0.41838800E+03, 0.92266200E+02, 0.13861200E+03, 0.10599900E+02, -.42620500E+03, -.11714200E+03, 0.93863500E+02, 0.20528400E+03, 0.22783000E+03, -.11338500E+03, 0.16939700E+03, -.11387300E+03, 0.31770900E+03, 0.58802000E+02, 0.16339200E+03, 0.65979200E+03, -.51140700E+02, -.26066400E+03, 0.10499300E+03, 0.89221200E+03, -.44723700E+03, -.66164900E+03, -.44669300E+03, -.43496900E+03, -.73991400E+02, -.12872300E+03, 0.40641600E+02, 0.99846600E+02, -.14158300E+02, -.35891000E+03, -.11145600E+04, 0.55592700E+03, 0.76815700E+03, 0.55725200E+03, -.22021200E+03, 0.12194800E+03, 0.34954900E+03, -.33743200E+03, 0.29202300E+03, 0.13197000E+03, 0.64920800E+03, -.56572100E+04, 0.28175100E+04, 0.63939100E+03, 0.28289100E+04, -.48450000E+03, -.14876600E+04, 0.19631800E+04, -.20098600E+03, 0.16469600E+04, -.99947100E+03, 0.22755300E+04, -.39222700E+02, 0.24143100E+02, -.19363400E+01, 0.19549800E+02, 0.24756100E+03, 0.10126100E+03, -.16622300E+03, -.14051900E+03, 0.14103100E+03, 0.10269700E+03, -.32326100E+03, 0.21921400E+03, -.10292500E+03, 0.17436900E+03, -.10948600E+03, 0.17802500E+03, 0.62516200E+02, -.14464300E+03, -.42282600E+00, -.16589400E+02, 0.43052100E+02, -.37471800E+02, 0.71492300E+03, -.35972800E+03, -.33303500E+03, -.35741400E+03, 0.21564100E+03, 0.12942800E+03, -.91974200E+02, 0.15596900E+03, -.63243000E+03, 0.18205500E+03, 0.33858900E+03, -.53465100E+03, 0.28186800E+03, -.85571500E+02, 0.26736500E+03, -.93589500E+02, -.15470900E+03, 0.58418000E+02, -.15509500E+03, 0.24150000E+03, -.12429700E+03, 0.23987800E+03, 0.10241400E+04, -.51491500E+03, -.57593200E+03, -.51193800E+03, 0.95900800E+02, 0.13334300E+03, -.21615100E+03, 0.19868700E+03, -.49258100E+03, 0.11344100E+03, 0.35249600E+03, 0.14574900E+04, -.72864000E+03, -.86460000E+03, -.72888100E+03, 0.36929800E+03, 0.14819600E+01, -.59701300E+03, 0.28814900E+03, -.12601700E+02, -.11241300E+03, -.10843500E+04, 0.16780900E+04, -.84208900E+03, -.98951800E+03, -.83900000E+03, -.29111900E+03, -.20891900E+03, -.11154200E+03, 0.42973600E+03, 0.16437300E+03, -.22423900E+03, -.53008700E+03, -.90685600E+03, 0.44803300E+03, 0.47796000E+03, 0.45346900E+03, -.28559100E+03, -.32841300E+03, 0.16565200E+03, -.65321200E+03, -.16842200E+03, -.10187900E+03, 0.19916700E+03, 0.84031900E+02, -.39829100E+02, 0.11338300E+04, -.41752700E+02, 0.59488400E+02, 0.28140200E+03, -.31182500E+03, -.37279500E+03, -.10305400E+03, 0.25187700E+03, -.13813500E+03, -.50195300E+03, 0.25196100E+03, -.16848300E+04, 0.25075000E+03, -.36549700E+03, -.58953900E+03, 0.35010600E+03, -.62984100E+02, 0.26351900E+03, -.40888200E+03, 0.25748800E+03, 0.15111400E+02, 0.85961200E+01, -.29311700E+01, 0.15947200E+02, -.19330700E+01, 0.20185300E+01, -.41399000E+01, 0.64100500E+01, -.31515600E+01, -.64182000E+02, 0.18365500E+03, 0.11118400E+03, 0.51312500E+02, -.16227100E+03, 0.50797500E+02, -.23679400E+03, 0.21318300E+02, -.60964300E+01, 0.62984400E+02, 0.76025400E+02, -.24949000E+02, 0.12804500E+02, -.42370900E+02, -.15707200E+03, -.11662000E+03, 0.43194900E+02 },
        { -.23001300E+02, 0.46881000E+00, 0.84206200E+00, -.51413000E+01, -.23422000E+01, 0.31809600E+01, -.26068600E+01, 0.70198400E+00, 0.18586700E+01, 0.29618700E+01, -.29616700E+00, -.15083400E+01, 0.51260800E+00, -.10994800E+00, 0.27380400E+00, 0.93131400E+00, -.18923000E+00, 0.20390900E+00, -.82152300E-01, 0.10652600E+01, 0.27113300E+00, 0.12538000E+00, 0.40447700E+01, -.64374900E+00, 0.50339700E+00, -.11318800E+01, 0.15279800E+01, -.25233700E+01, -.19405000E+00, -.12041100E+01, 0.17612700E+00, 0.15867900E+01, -.28771200E-01, -.20050700E+01, 0.59546800E+00, -.10277600E-01, -.60214100E+00, -.18951800E+01, -.47613900E+00, 0.69869800E+00, -.44417300E+00, 0.26091100E+01, -.67049900E-01, -.11582000E+01, -.33287600E-01, -.12107000E-01, -.29418500E+00, -.24649800E+00, 0.68043400E+00, 0.28527800E+00, -.80104400E+00, -.14939400E+02, 0.42031300E+00, -.18815400E+00, -.16308100E+01, 0.99744600E+00, -.17644000E+00, -.48216000E+00, 0.16211200E+00, 0.30800200E+00, 0.58919100E+00, -.80209800E+00, -.10687600E+01, 0.66753500E-01, 0.45726500E+00, -.90862100E+00, -.63261100E+00, 0.28538000E-01, -.17450000E+01, 0.20148000E-01, 0.61471900E+00, 0.66090200E+00, 0.60198900E+00, -.12504700E+00, 0.32807700E+01, 0.66228900E+00, 0.46838500E+00, -.19819900E+01, 0.29211900E+01, -.11047600E+01, -.18958800E-01, 0.19204900E+01, 0.25639600E+01, 0.94483800E+00, -.59798400E-01, -.10231900E+02, -.10269800E+01, -.28010300E+00, -.91654900E+00, -.11464800E+01, 0.70189600E+00, 0.42636800E+02, -.73469000E+03, -.26721600E+03, 0.11741700E+03, -.11073000E+04, -.64196500E+03, -.14819500E+03, -.81131600E+03, 0.86026000E+04, -.43239300E+04, 0.35631900E+03, -.43306500E+04, -.39249200E+03, 0.10600800E+03, -.16369900E+04, 0.14014900E+04, -.31630900E+04, 0.38570400E+02, -.35442000E+04, 0.12713100E+04, -.68141800E+03, -.17426000E+04, -.63910000E+03, -.15788400E+03, -.23537700E+03, 0.86626900E+02, 0.62378600E+03, 0.20302700E+03, -.75751900E+02, 0.20541600E+03, -.39672500E+04, 0.19742300E+04, 0.11744600E+04, 0.19816900E+04, -.12271300E+04, -.17823000E+04, 0.94844500E+03, -.14644900E+04, 0.16498300E+04, -.68512100E+03, 0.31132400E+04, -.17807400E+04, 0.88181800E+03, 0.14705800E+04, 0.88534900E+03, 0.93434700E+03, 0.80182100E+03, 0.10278600E+03, -.97066600E+02, -.15382000E+03, 0.46623500E+03, 0.35471300E+03, 0.65663300E+03, -.33628100E+03, -.33265800E+03, -.32873300E+03, 0.63599700E+03, 0.56341100E+02, -.87733500E+03, -.12908800E+03, -.63072000E+03, -.85574100E+01, -.14882200E+04, 0.67303800E+04, -.34297600E+04, 0.25762500E+03, -.34205100E+04, 0.24080400E+03, 0.66135400E+03, -.19645900E+04, 0.46475900E+03, -.26267900E+04, 0.56390500E+03, -.28914100E+04, 0.77343600E+03, -.38326500E+03, -.25412400E+03, -.38590200E+03, -.12971300E+03, -.18643900E+03, 0.23616900E+03, 0.38080600E+03, -.46677700E+03, -.31831600E+03, 0.31385500E+03, -.75074800E+02, 0.34926200E+02, 0.18785300E+03, 0.37296200E+02, 0.18269700E+03, 0.52312100E+02, 0.14419200E+03, -.12653800E+03, 0.71189000E+02, 0.90588800E+02, -.36940800E+03, -.25528200E+04, 0.12475600E+04, 0.13888200E+04, 0.12777300E+04, -.11682300E+04, -.28607400E+03, -.15655200E+03, -.18391300E+04, 0.10008100E+04, -.29262500E+03, -.87425800E+03, 0.34697600E+03, -.22874800E+03, -.74987000E+01, -.17030300E+03, 0.52682600E+02, -.22660200E+02, 0.22755900E+03, 0.40878700E+03, 0.18581100E+03, 0.10422900E+02, -.23618400E+02, -.22338200E+04, 0.10996600E+04, 0.11041300E+04, 0.11168500E+04, -.84222400E+03, -.30601500E+03, 0.11884300E+03, -.12452500E+04, 0.79224900E+03, -.17372900E+03, -.82344100E+03, -.10566900E+04, 0.53926900E+03, 0.51824500E+03, 0.52835000E+03, -.82851500E+03, -.36658200E+03, 0.13017100E+04, 0.38017500E+03, 0.55015900E+03, -.10199600E+03, 0.28429000E+04, -.31845900E+04, 0.16015400E+04, 0.18863700E+04, 0.15925600E+04, 0.54856800E+03, 0.30386600E+03, 0.16616300E+03, -.62390900E+03, 0.20788300E+03, 0.31335500E+03, 0.46440400E+03, 0.21892400E+04, -.10784700E+04, 0.63639800E+03, -.11152900E+04, -.33285500E+03, -.65794700E+03, 0.32313400E+03, 0.13963500E+04, -.31658500E+03, -.69006800E+03, -.68563300E+03, 0.23032800E+03, -.12022000E+03, -.26629200E+03, -.11754900E+03, -.96774700E+01, -.48702800E+03, 0.93271400E+03, 0.13224700E+04, 0.58629900E+03, -.35562500E+03, 0.13004300E+03, -.80618200E+03, 0.42133200E+03, 0.36949800E+03, 0.38745300E+03, 0.51995200E+03, 0.38029600E+03, -.11970400E+03, 0.34831400E+03, 0.11092100E+03, 0.39167700E+03, 0.28319600E+03, -.51683200E+00, 0.23591600E+02, 0.27532900E+02, -.27811800E+02, -.16829000E+02, 0.33484200E+02, -.51938900E+02, -.27363500E+01, -.20213500E+02, 0.86343900E+02, -.66767400E+02, -.35938800E+03, 0.16032700E+02, -.94808600E+02, 0.10145300E+03, 0.21676800E+03, -.61080000E+02, 0.42967100E+02, -.21955200E+03, -.48219700E+03, 0.11257200E+03, 0.12175300E+03, 0.17006900E+02, -.21871200E+03, 0.71432500E+02, 0.96261000E+02 },
        { -.11699700E+01, 0.43160900E-01, 0.30416000E-01, -.54484500E-01, -.20448600E+00, 0.35368200E+00, -.18997900E+00, 0.13614300E+00, -.27171900E+00, 0.28694700E+00, -.75501700E-02, -.15823200E+00, -.49564100E-01, -.36895900E-01, -.58996200E-01, 0.60523600E-01, -.10328400E+00, -.74706500E-01, 0.78006700E-01, 0.23134800E+00, 0.42010900E-01, 0.10627300E+00, -.37306600E+01, -.26983800E+00, 0.67795600E-01, 0.63976900E-01, -.29913600E-01, 0.37738400E+00, 0.26355400E+00, 0.38153700E+00, 0.22009200E+00, 0.98196500E-01, -.24299900E-01, 0.97072000E-01, -.21230100E+00, -.30961400E-01, 0.38031900E-01, 0.56935400E-01, 0.67576100E-01, -.22566100E+00, -.25369400E-01, 0.34117600E+00, -.40669600E-01, -.22978000E+00, 0.39551900E-01, -.45960100E-01, 0.83943900E-02, -.11451700E-02, -.12928700E+00, -.24182300E-01, -.33581900E+00, 0.58824500E+00, 0.38417000E-01, -.78599600E-01, -.48175000E+00, -.18744100E-02, -.52027100E-02, 0.14077000E+00, -.74377300E-01, 0.42610100E-01, -.16502100E+00, -.15258300E-01, -.27838000E-01, -.45364800E-02, -.16539800E+00, -.93926400E-01, -.23369000E+00, 0.45033500E-02, -.37579200E+00, -.11240800E-02, 0.33298500E-01, -.10308900E-01, -.52998700E-02, -.22951600E-01, 0.57635400E+00, -.33571900E-01, -.54596100E-01, -.57353300E+00, -.13750900E-01, 0.13055900E+00, 0.10231100E-01, -.70491100E-01, -.19831100E+00, 0.76109200E-02, 0.74929300E-01, -.12331200E+00, 0.48570300E-01, 0.79424100E-02, 0.16794900E+00, -.56483200E-01, -.24716200E+00, 0.10046600E-01, 0.95048600E+03, 0.11932700E+04, -.69929200E+03, 0.66137400E+02, -.37978200E+02, 0.73072000E+03, 0.32961300E+03, -.69988200E+04, 0.34892300E+04, 0.34087200E+04, 0.34999400E+04, -.21011100E+03, -.11430600E+04, 0.20441900E+04, -.65028300E+03, 0.18358900E+04, -.75898100E+03, 0.20806200E+04, -.79726000E+03, 0.40461900E+03, 0.21153200E+03, 0.39868700E+03, 0.18662900E+03, 0.14988900E+03, 0.68789700E+01, -.30205800E+03, 0.17667400E+02, 0.11537600E+03, 0.20750400E+03, 0.95273000E+02, -.47480800E+02, 0.34439000E+03, -.47595100E+02, 0.22548500E+03, 0.64547800E+02, 0.11635800E+03, 0.41582100E+03, -.59782500E+02, -.13886800E+03, 0.26498600E+03, 0.40687600E+03, -.20233000E+03, -.42994700E+03, -.20346700E+03, -.26083600E+03, -.11468400E+03, -.46507100E+02, -.14969000E+02, 0.11788800E+03, -.43974800E+02, -.18644300E+03, -.99820200E+03, 0.49989000E+03, 0.64424700E+03, 0.49909100E+03, -.67006100E+02, 0.11361300E+03, 0.26761300E+03, -.27711000E+03, 0.20399300E+03, 0.13292500E+03, 0.59252500E+03, -.46501100E+04, 0.23224400E+04, 0.23523200E+04, 0.23257400E+04, -.59347200E+03, -.14803700E+04, 0.18692900E+04, -.13513900E+03, 0.14529400E+04, -.10318800E+04, 0.13611000E+04, -.24950600E+02, 0.11744500E+02, -.64898600E+02, 0.12434700E+02, 0.90881800E+02, 0.76036600E+02, -.11297500E+03, -.12950800E+03, 0.32086900E+02, 0.65519300E+02, -.29884200E+03, -.92159900E+01, 0.45191000E+01, 0.30477300E+02, 0.46761300E+01, 0.38987200E+02, -.36887600E+01, 0.20629600E+02, 0.38964200E+02, 0.28888000E+02, 0.15524200E+01, 0.17146100E+03, 0.73262900E+03, -.36265900E+03, -.44594700E+03, -.36630000E+03, 0.12714100E+03, 0.15654100E+03, -.12327900E+03, 0.10524300E+03, -.51637500E+03, 0.13278400E+03, 0.44715400E+03, -.30823000E+03, 0.16124600E+03, 0.46701200E+01, 0.15411000E+03, -.74756200E+02, -.10991800E+03, 0.60294000E+02, -.72810100E+02, 0.11525000E+03, -.66598400E+02, 0.16415200E+03, 0.77841300E+03, -.38704900E+03, -.53465400E+03, -.38913200E+03, 0.52448700E+02, 0.16059000E+03, -.20077800E+03, 0.50192000E+02, -.42671700E+03, 0.10091500E+03, 0.42539900E+03, 0.10426200E+04, -.52236800E+03, -.55474000E+03, -.52138400E+03, 0.21054300E+03, -.52696100E+02, -.33916300E+03, 0.19325200E+03, -.55433200E+02, -.11165800E+03, -.94631200E+03, 0.10948000E+04, -.54854800E+03, -.64956400E+03, -.54737600E+03, -.18090000E+03, -.17616500E+03, -.17043600E+02, 0.28502700E+03, 0.53234200E+02, -.16372500E+03, -.40291200E+03, -.21887100E+04, 0.10851400E+04, 0.11550900E+04, 0.10945700E+04, -.14317900E+03, -.19275000E+03, 0.40304200E+03, -.65542200E+03, 0.30897100E+03, -.42549900E+02, 0.54196200E+03, 0.60169900E+02, -.30292600E+02, 0.59479900E+03, -.29914500E+02, -.25452400E+02, 0.65448300E+02, -.84864200E+02, -.19875100E+03, -.58314800E+02, 0.75832600E+02, 0.13413000E+03, -.27702100E+03, 0.13731900E+03, 0.92645900E+02, 0.13850600E+03, -.42437800E+03, -.64360000E+03, 0.50012000E+03, 0.90873600E+02, 0.14084600E+03, -.43366200E+03, -.55994300E+01, 0.30969800E+01, 0.11580500E+01, -.18133600E+01, 0.67441900E+01, 0.23254600E+01, -.10678500E+01, -.19041900E+01, 0.36506100E+01, -.98652300E+00, -.13766400E+03, 0.32200300E+03, 0.15227500E+03, 0.36739200E+02, -.47362400E+02, 0.15835300E+02, -.31600200E+03, 0.17041500E+02, -.32699900E+01, 0.74898200E+02, 0.88494900E+02, -.34303600E+02, 0.71225600E+01, -.17534400E+02, -.25625200E+03, -.25742600E+02, -.82988900E+02 },
        { 0.15649200E+02, -.71181700E+00, -.35487700E+00, 0.12032600E+01, 0.56011000E+00, -.16084000E+01, -.50953100E+00, -.37155700E+00, 0.25193200E+01, -.51121400E+00, 0.89627400E-01, -.39846200E-02, -.67511400E+00, -.13249300E+00, 0.15880100E+00, -.29470000E+00, -.50813200E+00, -.52958200E+00, 0.11240600E+00, -.54787700E+00, -.48664000E-01, 0.14597100E+00, -.72562500E+01, -.92176700E+00, -.33534500E+00, -.64184300E-01, -.11104200E-01, -.18167800E+01, -.82755500E+00, 0.15593800E+01, 0.22889700E+00, -.10024100E+01, 0.55509100E-01, -.77299500E+00, 0.72463900E+00, 0.95451300E-01, -.10217500E+00, 0.36296500E+01, -.62903600E+00, -.57067000E+00, 0.79876800E+00, 0.33847200E+00, -.65213300E+00, 0.11381100E+01, 0.10710400E+01, 0.43726900E+00, -.50397600E-01, -.41235600E-02, -.76958700E+00, 0.69453200E-02, 0.65713300E+00, 0.18340400E+00, 0.14516500E+00, -.37534700E+00, 0.37763900E+01, -.56661300E+00, -.90577400E-02, -.12852300E+01, -.43298400E+00, 0.17698200E+00, 0.39325600E+00, 0.99417500E-01, -.75631400E+00, 0.18713000E+00, -.29793400E+00, -.96248900E-01, -.23057600E+01, 0.29568600E-01, -.12492900E+00, -.10180600E-01, 0.98854700E-01, -.42739900E+00, 0.62260300E-01, -.17520900E+00, 0.80552900E+00, -.18525800E+00, -.13099800E-01, -.63702300E+01, 0.99987400E-01, -.41679200E+00, -.15431600E-01, -.10736300E+01, -.83739900E+00, 0.79922900E+00, -.17945700E+01, -.81534300E+01, 0.22539200E+00, -.11916800E+00, 0.20887000E+01, 0.92418500E+00, -.13286700E+00, 0.62272900E-01, 0.19928700E+01, 0.56686700E+04, -.45767300E+04, -.45079600E+04, -.34111300E+04, 0.46710200E+04, 0.17551200E+03, 0.55681700E+04, -.28996600E+04, 0.28437400E+04, -.27854400E+04, -.27447100E+04, -.70541700E+04, 0.46252600E+04, 0.56215400E+04, -.25280900E+04, -.55251600E+04, 0.26808500E+03, -.50305700E+04, 0.25004300E+04, 0.37016900E+03, 0.25151600E+04, 0.14150200E+04, 0.80640200E+03, 0.33760100E+03, -.10213000E+04, 0.16079500E+04, 0.65415300E+03, 0.24057600E+04, -.29120200E+04, 0.14776800E+04, 0.30619400E+04, 0.14558600E+04, -.11751600E+04, -.93242000E+03, 0.10510000E+04, 0.25881000E+03, 0.11733200E+04, -.65205600E+03, -.10138600E+04, -.12251900E+04, 0.58633900E+03, 0.45904700E+03, 0.61310500E+03, 0.43025800E+03, -.80872800E+02, 0.27346200E+03, 0.31923100E+02, 0.59580100E+03, -.12303100E+03, 0.14991400E+04, -.21491200E+04, 0.10744900E+04, 0.72947700E+03, 0.10747200E+04, 0.54214100E+02, 0.18413500E+03, 0.29160600E+03, -.51224000E+03, 0.48430700E+03, 0.14317800E+03, 0.13037300E+04, 0.87028100E+04, -.44413000E+04, 0.15822900E+03, -.43530000E+04, -.29100500E+04, -.83870700E+04, 0.51211700E+04, 0.71717100E+04, -.60930300E+03, -.68231300E+04, -.23626000E+04, 0.85921400E+03, -.42760100E+03, -.41236900E+03, -.42929400E+03, -.20028400E+02, 0.92176800E+02, -.24419800E+03, -.31584700E+02, -.48613800E+03, 0.31192700E+01, 0.30029800E+03, 0.12247200E+03, 0.71923400E+01, -.36250200E+02, -.61830700E+02, 0.48973300E+03, 0.18984400E+03, 0.19792200E+03, -.40449900E+02, 0.22905000E+03, 0.18266800E+03, -.12908300E+04, -.20472300E+04, 0.10402300E+04, 0.90988200E+03, 0.10234100E+04, -.65429900E+03, 0.17950200E+03, 0.12816700E+03, -.16607800E+04, -.78344100E+02, 0.42560400E+03, -.12930700E+04, -.19074900E+04, 0.10052600E+04, 0.51325100E+03, 0.95366300E+03, 0.12553500E+03, -.27354300E+03, 0.55892200E+03, -.25488400E+02, 0.77673800E+03, -.15021200E+03, 0.57691700E+03, -.80161900E+03, 0.37604400E+03, -.19111400E+03, 0.40021300E+03, -.86984800E+03, 0.13049500E+03, -.25349000E+03, -.13761000E+04, -.69046000E+02, 0.38627500E+03, -.13111300E+04, 0.25948300E+03, -.13432000E+03, -.21991300E+03, -.12908500E+03, 0.53770900E+03, 0.60516800E+02, -.79585900E+02, 0.38795500E+03, 0.25290900E+03, 0.63398900E+02, 0.10858300E+03, 0.23873800E+04, -.11857800E+04, 0.44609800E+02, -.11939200E+04, -.13303200E+03, -.56036400E+03, -.46457200E+02, 0.52208700E+03, -.82078400E+03, -.38168600E+03, -.10478100E+04, 0.25609900E+04, -.13144800E+04, 0.56517300E+03, -.12808900E+04, -.13768800E+04, -.23633200E+04, 0.12568000E+04, 0.14264000E+04, -.15660100E+04, -.17289800E+04, 0.18366500E+03, -.18032300E+04, 0.94253600E+03, 0.10837100E+04, 0.90056000E+03, 0.37392700E+03, -.89953300E+02, 0.82249300E+03, 0.39191200E+03, 0.15039000E+04, -.92458400E+02, 0.12261000E+03, -.34717600E+04, 0.17656200E+04, 0.18307900E+04, 0.17363300E+04, 0.78168300E+03, -.23169900E+04, 0.25810600E+04, 0.16992000E+04, 0.21638200E+04, -.18809300E+04, 0.13149200E+04, 0.20086900E+02, 0.39118700E+02, 0.22627100E+01, 0.57736400E+01, -.25925900E+01, 0.23931600E+02, 0.16958400E+01, 0.18920900E+02, 0.13576000E+01, 0.15293700E+04, -.82253300E+03, 0.46080100E+03, 0.10934400E+01, 0.26643600E+03, 0.19080100E+02, 0.18107200E+04, -.38867600E+02, 0.42152500E+02, -.38045500E+02, -.84688800E+03, 0.14029700E+03, 0.22600800E+02, 0.71310800E+01, -.47282200E+03, 0.36003500E+02, 0.14398100E+04 },
        { 0.10321100E+02, -.32159400E+00, -.54573600E+00, 0.33652200E+00, 0.31575100E+00, -.19880100E+01, 0.11217800E+01, -.83232500E+00, 0.45880600E+00, -.18014600E+01, 0.79783300E-02, -.31197400E+01, -.44960900E+00, 0.78112000E+00, -.37263000E+00, 0.13585600E+00, -.59659300E+00, -.39856600E+00, -.11956000E+01, -.16078400E+00, 0.43892000E+00, -.10835100E+00, -.39493000E+01, 0.44328500E+00, 0.19339600E+00, 0.75788900E+00, 0.23481700E-01, 0.22150800E+00, -.77523900E+00, 0.14465500E+01, -.11507700E+00, -.12528300E+01, 0.14282600E-01, -.42389500E-01, -.15213200E+01, 0.18277800E+00, 0.58929800E-01, 0.22570100E+01, -.26646800E+00, -.57771400E+00, 0.49073700E+00, -.48598100E-01, -.12305800E+01, 0.20979100E+01, 0.74142200E+00, -.19729200E+00, -.53896600E-01, -.27231100E-01, -.13112000E+01, -.14293100E-01, 0.51742300E+00, 0.41841100E+01, -.42433600E+00, -.64031600E+00, 0.39507600E+01, -.16010100E-01, 0.13198200E+00, 0.32622500E+00, -.52583400E+00, 0.11568600E+00, -.88834600E+00, 0.16666700E+00, 0.36622200E+00, -.21927100E-01, 0.20508700E+00, 0.27806500E+00, -.62626900E+00, -.98511300E-02, 0.78699100E+00, -.72399300E-02, -.20038200E+00, -.49601000E+00, -.59574600E-01, -.20368600E+00, 0.38261900E+00, -.13226300E+01, -.13672800E+01, -.10405300E+02, 0.59336200E-01, -.68777100E+00, -.19148200E-01, 0.66777700E-01, -.10673300E+00, 0.33748600E+00, -.30431800E+00, 0.56824900E+01, 0.69672500E+00, 0.58640800E-01, 0.34842000E+00, 0.68307700E+00, -.53528300E+00, -.51081700E-02, 0.21776700E+01, -.34327300E+00, -.25099800E+04, -.46883100E+04, -.34220600E+04, -.38271900E+03, 0.39239300E+03, -.10372700E+04, 0.50406800E+03, -.26030700E+04, 0.51775600E+03, 0.21759400E+03, 0.57199800E+03, 0.24474900E+04, 0.40796000E+04, 0.14143900E+04, 0.10630200E+04, 0.15080400E+04, -.85318100E+03, 0.44943700E+03, 0.13149600E+04, 0.42650300E+03, 0.21744900E+03, 0.16535400E+03, 0.92242300E+02, -.15387700E+03, 0.49724600E+03, 0.27000400E+03, 0.81614200E+02, -.23135600E+03, 0.13379000E+03, -.52171500E+03, 0.11561500E+03, -.72571200E+03, -.16162700E+03, -.17263900E+03, -.74126300E+03, 0.12141500E+03, 0.15665600E+03, -.93559600E+03, -.61919200E+03, 0.29573800E+03, 0.29232700E+03, 0.31022300E+03, -.15901600E+03, 0.49525700E+01, 0.22723500E+03, 0.34154900E+03, 0.45058800E+03, -.24803800E+03, 0.13529400E+04, -.73154200E+04, 0.36586500E+04, 0.44795200E+04, 0.36577300E+04, 0.35952700E+03, 0.12407200E+04, -.15433200E+03, -.29802700E+04, -.12809900E+03, 0.98643900E+03, 0.38902800E+04, 0.18276000E+04, -.91216100E+03, -.34657100E+04, -.91475300E+03, -.92771900E+02, 0.24229300E+02, 0.23483000E+04, 0.51782500E+04, 0.22858600E+04, 0.55262900E+03, -.28483200E+03, 0.46192100E+03, -.24176600E+03, 0.14037500E+03, -.23089300E+03, 0.16457700E+03, -.46914700E+03, 0.60941100E+03, 0.66684600E+03, -.40739000E+03, -.15842400E+03, -.38909700E+03, 0.11138800E+04, -.51152600E+03, -.22763500E+03, -.55706000E+03, -.19140800E+03, -.88365500E+02, -.32558400E+03, -.26171800E+01, 0.32334600E+02, -.65071700E+02, -.82641500E+03, -.92777600E+03, 0.49138700E+03, 0.12589900E+04, 0.46385200E+03, -.41772400E+03, 0.23644300E+03, -.12158000E+03, -.58508800E+03, 0.40587900E+02, 0.35181900E+01, -.12278500E+03, -.30843900E+03, 0.18746700E+03, 0.17659100E+03, 0.15420300E+03, 0.25078000E+03, 0.16470500E+03, 0.23863800E+03, 0.23638400E+03, 0.26676600E+03, 0.15845300E+03, -.34323900E+02, -.55665600E+03, 0.27927300E+03, 0.10994500E+04, 0.27819200E+03, -.37631100E+03, 0.14183600E+03, -.18405000E+03, -.52203200E+03, -.28294000E+03, 0.25383700E+02, -.47956400E+02, 0.75716000E+04, -.37968200E+04, -.37506800E+04, -.37856700E+04, -.68914300E+03, -.19868800E+04, 0.79477000E+03, 0.33435200E+04, 0.17573600E+03, -.16015200E+04, -.37647400E+04, 0.98266900E+03, -.48935500E+03, -.84180100E+03, -.49138000E+03, -.36508700E+03, -.29356100E+03, 0.16922200E+02, 0.27236900E+03, -.63599600E+03, -.39119500E+03, 0.17261600E+03, -.11884300E+04, 0.60121400E+03, -.58537700E+03, 0.59395100E+03, -.14540500E+02, 0.21631500E+03, 0.12905800E+04, 0.17688500E+04, 0.76234400E+03, 0.44172600E+03, 0.11825000E+04, 0.57650400E+03, -.25839300E+03, -.79808400E+03, -.28855200E+03, -.65498000E+03, -.51578200E+03, 0.52922100E+03, 0.10381000E+04, 0.12292600E+04, -.56485200E+03, -.40137800E+02, -.11291000E+04, 0.57314600E+03, 0.64980200E+03, 0.56474400E+03, 0.15653500E+03, 0.12537000E+03, 0.13768900E+04, 0.21818700E+04, 0.17543700E+04, 0.23900200E+03, 0.47605300E+02, 0.33168300E+02, 0.22996000E+02, -.56341600E+00, 0.41722000E+01, 0.32117600E+02, -.14355600E+02, -.23163900E+02, -.35977500E+01, 0.21036500E+01, -.14508800E+03, 0.45153800E+03, 0.10772300E+02, -.87191400E+02, 0.58204500E+02, 0.51558400E+03, -.33673500E+03, -.17216500E+03, 0.37283700E+02, 0.47423900E+02, -.78763300E+03, -.18402100E+02, 0.17027800E+03, 0.52508500E+02, -.62128700E+03, -.22175700E+03, -.22138300E+03 },
        { 0.35690700E+01, -.13789400E+00, -.93097400E-01, -.84842100E+00, 0.67604400E+00, -.12057300E+01, 0.10513300E+01, -.12927800E+01, 0.13047600E+01, -.70618100E+00, -.39205500E-01, 0.12910200E+01, 0.11933900E+00, 0.56258300E-01, 0.29239800E+00, -.18696200E+00, 0.63961000E+00, 0.76011600E+00, 0.80155200E+00, -.67556500E+00, -.61408000E+00, 0.47169200E-01, 0.11057700E+02, 0.13369200E+00, 0.15444900E+00, -.27094000E+00, 0.27845700E+00, -.11837700E+01, -.15557400E+01, 0.21333400E+00, -.62783600E+00, -.75941900E+00, 0.54595300E-01, -.90351200E+00, 0.30936500E+01, 0.28197900E+00, -.51781400E-01, 0.24689600E+01, -.49716200E+00, 0.91337100E+00, -.37314900E+00, -.41704100E+00, 0.21546600E+00, 0.10886400E+01, -.47586200E+00, 0.13191900E+00, 0.21534400E-01, -.30147900E-02, 0.12326900E-01, -.20404800E-01, 0.47888800E+00, 0.27503700E+01, -.12576300E+00, -.15855900E+00, 0.22210300E+01, 0.18930400E+00, 0.79410800E-02, -.44971700E+00, -.14358400E+00, 0.12052600E+00, 0.28180300E+00, 0.29800900E+00, -.22194600E+00, 0.20007500E-01, -.12547400E+00, -.26467000E+00, 0.61417700E-01, -.60605100E-02, 0.59838800E+00, -.67172400E-02, 0.40494100E-01, 0.12426700E+00, 0.32842800E+00, -.11677000E+00, -.32432900E+00, -.27020400E+00, 0.26023500E+00, -.40134000E+01, 0.15261800E+01, -.44471400E+00, -.56434900E-01, 0.10914200E+01, -.83062600E+00, 0.73605800E+00, -.46734600E+00, -.67219600E+01, -.21462000E+00, -.24151300E+00, -.49612400E+00, -.11959800E+01, 0.67693100E+00, -.86854300E-01, -.17051700E+01, 0.10565300E+00, -.21525100E+00, -.22609800E+04, -.14865600E+04, 0.23972300E+01, 0.48240800E+03, 0.23171800E+04, -.11448600E+04, -.30646200E+04, -.11589100E+04, 0.44219800E+03, 0.10943000E+04, -.85176900E+03, 0.20119900E+04, 0.11315200E+04, 0.87444000E+03, -.16384700E+04, 0.30549000E+04, -.15279800E+04, -.11468700E+04, -.15275000E+04, -.54535000E+03, -.59654900E+03, -.56929000E+02, 0.93394700E+03, -.45673100E+03, -.40451600E+03, -.12036800E+04, -.27112800E+03, 0.13723600E+03, -.11669800E+04, 0.13559500E+03, -.73604300E+03, -.19308300E+03, -.31111700E+03, -.10712400E+04, 0.15181000E+03, 0.32336900E+03, 0.11797700E+04, -.65942600E+03, 0.33197700E+03, 0.99778800E+03, 0.32909400E+03, 0.32671600E+03, 0.21506600E+03, 0.63472300E+02, -.23783200E+02, -.22838200E+03, 0.33618900E+02, -.61804500E+01, -.74902400E+03, 0.37326900E+03, 0.39380300E+03, 0.37437500E+03, 0.40668600E+03, 0.25343200E+03, -.67446200E+03, -.64784400E+03, -.53397700E+03, 0.23848600E+03, -.29976100E+03, 0.16273000E+04, -.76025100E+03, -.21117700E+04, -.81403700E+03, 0.57923400E+03, 0.14028700E+04, -.12432800E+04, 0.16461400E+04, 0.95385900E+03, 0.11983600E+04, -.14767800E+04, 0.10488100E+04, -.52602800E+03, 0.47249000E+02, -.52460600E+03, 0.10590100E+03, -.14945000E+03, 0.31830400E+03, 0.52307700E+03, -.48628200E+03, -.14176100E+03, -.14362000E+03, 0.17075800E+03, -.87260300E+02, 0.14170000E+03, -.84974100E+02, 0.71660700E+02, -.36441100E+02, -.13734000E+03, -.94456000E+02, 0.10995500E+03, -.17803500E+01, -.69803900E+02, -.43777700E+03, 0.22675300E+03, 0.49175400E+03, 0.21904900E+03, -.70337200E+03, -.16034400E+03, -.24861700E+03, -.33376400E+03, 0.77437000E+03, -.37215600E+03, 0.41119200E+03, 0.26380400E+03, -.12266400E+03, -.93839500E+02, -.13181800E+03, 0.61724700E+02, -.33273400E+02, 0.69714800E+02, 0.16207900E+03, 0.38200800E+02, -.65462600E+01, -.62237000E+02, -.73377400E+03, 0.37248500E+03, 0.84266200E+03, 0.36726800E+03, -.35195300E+03, -.10583800E+03, -.38390700E+00, -.34381700E+03, 0.35117400E+03, -.22833200E+03, 0.12636900E+03, 0.24781100E+03, -.12792200E+03, 0.43173100E+02, -.12435600E+03, -.81280000E+03, -.65019100E+03, 0.11471000E+04, 0.57171200E+03, 0.23589300E+03, -.45669000E+03, 0.89956900E+03, -.27655900E+04, 0.13783700E+04, 0.14175300E+04, 0.13829600E+04, 0.24901400E+03, 0.39538300E+03, 0.32248200E+02, -.74668900E+03, 0.27856300E+02, 0.30167900E+03, 0.10088500E+04, -.40977100E+03, 0.17624200E+03, -.61641200E+03, 0.20469500E+03, 0.81111100E+02, -.31783500E+03, 0.73694900E+03, 0.18132900E+04, 0.14331700E+04, -.40475200E+03, 0.81152900E+02, 0.15227600E+03, -.80593300E+02, -.12495200E+04, -.75592500E+02, -.15235300E+03, -.43368700E+03, 0.37449200E+03, 0.66589400E+03, 0.47978800E+03, -.33007100E+03, 0.15236500E+03, 0.38581700E+03, -.20446600E+03, -.16998100E+03, -.19321800E+03, 0.25886300E+02, 0.61840900E+02, -.16157500E+03, 0.95617900E+03, 0.58335600E+03, 0.97145100E+02, -.72063600E+03, 0.24776000E+02, -.98572100E+00, 0.19645700E+02, -.74599700E+01, 0.65275200E+01, 0.43216000E+01, -.41679100E+02, 0.10677200E+00, -.17977800E+02, -.12128800E+03, -.66055900E+02, -.32729600E+03, -.86694900E+02, 0.65910700E+02, 0.15193900E+03, -.13811800E+03, -.83599800E+02, 0.58467200E+01, -.12290400E+03, -.46589300E+03, -.11217800E+02, 0.66380900E+02, -.42488400E+01, -.45716700E+01, 0.19041900E+02, -.49833300E+02 },
        { -.13728700E+01, 0.10651300E+00, 0.77412800E-01, -.38963400E+00, -.14092500E+00, 0.13968800E+01, -.72687400E+00, 0.84426400E+00, 0.80864200E-01, 0.13977800E+01, -.70193800E-01, 0.16495600E+00, 0.93320300E-01, 0.37798600E-01, -.88469700E+00, 0.13461800E+00, 0.65036800E+00, 0.38956700E-01, 0.21124500E+00, -.41043400E+00, 0.18230100E+00, -.12144500E-01, -.60427100E+01, -.14592100E+00, -.29187900E+00, -.98660200E-01, -.48640700E-01, 0.10717800E+00, 0.23648000E+00, -.12458000E+01, 0.34927000E+00, -.67443400E+00, -.54602400E-01, -.32542700E-01, -.12106900E+01, -.12821100E-01, -.77261600E-01, 0.22749200E+01, -.94980800E-01, 0.28869900E+00, -.11534900E+00, -.59688900E+00, -.63337800E+00, 0.11437100E+01, 0.20967600E+00, -.28042600E-01, -.32884100E+00, 0.11423300E-01, 0.87778500E+00, -.14577600E+00, 0.80979600E+00, -.33902100E+01, 0.11656700E+00, 0.61251800E-01, 0.13367500E+01, 0.10014400E+00, -.68543800E-01, -.21997300E+00, 0.20912400E+00, 0.12878300E+00, 0.12598500E+00, -.19919100E+00, -.18652400E+00, 0.22012000E-01, 0.22181800E-01, -.12109200E+00, -.13209500E+01, 0.45691900E-01, -.14720700E+01, -.56661100E-03, 0.15161600E+00, 0.42175800E-01, 0.55498300E-01, -.50993800E-01, 0.10292700E+01, -.51868600E-01, -.58313800E-01, -.19732500E+01, -.10879300E+01, 0.13120800E+00, 0.30100300E-02, 0.49244300E+00, 0.92713100E+00, -.32686600E+00, -.18752300E+00, -.68488300E+01, 0.18237200E+00, -.29849900E-01, 0.76836500E+00, 0.38165800E+00, 0.11942100E+00, 0.46835100E-01, 0.13638100E+01, 0.14715000E+00, 0.15554500E+00, 0.15125800E+00, -.95462600E+03, 0.66822300E+03, -.33369400E+03, -.79397800E+03, 0.40031000E+03, -.93397700E+03, 0.39679200E+03, 0.21150500E+03, 0.83102800E+03, 0.26589000E+02, 0.52155800E+03, 0.41623000E+03, -.63550900E+02, 0.95518100E+03, -.55395900E+03, 0.26325400E+03, 0.13893400E+03, 0.27696800E+03, 0.83683100E+02, 0.34949900E+02, 0.70552600E+02, -.13760700E+03, 0.23381500E+03, 0.16569400E+02, 0.46133500E+03, 0.16928500E+03, -.87896400E+02, -.17487900E+02, -.84696600E+02, -.32686500E+03, 0.32917600E+02, -.50453000E+02, -.15302100E+03, 0.32729000E+02, 0.19550300E+03, -.48478300E+03, -.74658600E+03, 0.37393400E+03, 0.73456500E+03, 0.37340800E+03, 0.32111100E+03, -.26619200E+02, 0.13186400E+03, -.11826500E+03, 0.11260300E+02, 0.42778100E+01, 0.24838900E+02, 0.64000700E+03, -.31911400E+03, -.59064800E+03, -.31990900E+03, 0.13898700E+03, -.77164700E+02, -.16490600E+02, 0.35944400E+03, 0.90569300E+02, -.67585800E+02, -.65862900E+03, 0.51747800E+03, -.27538900E+03, -.97213100E+03, -.25902200E+03, -.87918300E+02, 0.23549200E+03, 0.12206000E+03, 0.58779300E+03, 0.62250200E+03, -.62505600E+03, 0.72381300E+02, 0.25675800E+03, -.12904000E+03, 0.54535700E+02, -.12821700E+03, -.23944700E+02, 0.58753900E+02, -.15239400E+03, -.89088200E+02, -.29812400E+03, 0.15350400E+02, 0.29579700E+03, -.10968800E+03, 0.50236000E+02, 0.36496400E+02, 0.54530000E+02, 0.14621300E+03, 0.58002600E+02, 0.11120300E+03, -.36882700E+02, 0.72348700E+02, 0.55111200E+02, -.32377600E+03, -.77518400E+02, 0.29592300E+02, 0.15438300E+03, 0.38644900E+02, -.16732000E+03, -.67193500E+02, -.18799500E+02, -.21653900E+03, 0.21376600E+03, -.91970500E+02, -.90601800E+03, -.31237800E+02, -.75244200E+01, 0.25606500E+03, 0.15571000E+02, -.32053600E+02, -.66260900E+02, 0.68836000E+02, 0.31080000E+02, 0.58398100E+02, -.45498400E+02, 0.15871700E+02, -.35429500E+03, 0.17670500E+03, 0.20019500E+03, 0.17684400E+03, -.21603300E+03, -.10093700E+03, 0.79307100E+02, -.16691500E+03, 0.34530200E+03, -.83667300E+02, -.65767400E+03, -.15509700E+04, 0.77760800E+03, 0.79918100E+03, 0.77583000E+03, 0.21821900E+02, 0.29186400E+03, 0.92739400E+02, -.49865200E+03, -.76668600E+02, 0.32211900E+03, 0.14131000E+04, -.90741900E+03, 0.45542500E+03, 0.92441100E+03, 0.45358700E+03, 0.22227100E+03, 0.14154000E+03, 0.17150300E+01, -.24197400E+03, -.24603600E+02, 0.19645700E+03, 0.22725200E+02, 0.26341900E+02, 0.26593400E+01, -.74546900E+03, -.13213500E+02, 0.86820100E+02, 0.39557100E+03, -.19928600E+03, -.30663100E+02, -.32069100E+02, 0.31682400E+02, 0.34678400E+03, -.34672600E+03, 0.17247600E+03, -.57331000E+03, 0.17287600E+03, -.50235700E+02, -.19295700E+03, 0.43150000E+03, 0.16003300E+03, 0.33212200E+03, -.15375400E+03, -.75270300E+02, -.97605800E+03, 0.49136600E+03, 0.48551700E+03, 0.48820100E+03, 0.13908500E+03, 0.13842800E+03, 0.13685100E+03, 0.74437800E+01, 0.66666100E+03, -.19203300E+03, 0.47418300E+03, 0.28455700E+01, -.65445800E+00, 0.17694900E+02, -.61269200E+01, -.15227400E+02, 0.96786400E+01, 0.72182300E+01, 0.39961800E+01, -.12526100E+02, 0.90402400E+02, -.28529800E+03, -.21243700E+02, -.43585400E+02, 0.13586200E+03, -.76896200E+02, 0.26234800E+03, -.26110600E+02, 0.11019300E+02, -.38481100E+02, -.75559800E+02, 0.39038800E+02, -.27521900E+02, 0.50519700E+01, 0.64877900E+02, 0.19725400E+02, 0.42766900E+01 },
        { 0.21473800E+01, -.18759200E+00, -.80839400E-01, 0.21189200E-01, 0.30248300E+00, -.20552600E+01, 0.17377300E+01, -.18448900E+01, 0.39436400E+00, -.16631800E+01, 0.11081600E+00, 0.86593900E+00, -.13909700E+00, 0.86183700E-03, -.67334500E-01, -.37629700E+00, 0.11097900E+00, 0.11535300E+00, 0.32658300E+00, -.12772900E+00, -.81390800E+00, 0.13193200E+00, 0.44332000E+01, -.15067200E+00, 0.42730100E+00, 0.13550700E+00, 0.81749700E-01, -.26438800E-01, -.84548800E+00, 0.11657000E+01, -.49937800E+00, -.11818800E+01, 0.39985100E-01, -.23631800E+00, 0.44729300E+01, 0.20500300E+00, 0.35742000E+00, 0.45566000E+00, -.67808300E-01, 0.77528500E+00, -.71930700E+00, 0.11034800E+01, 0.51040600E+00, -.61251300E+00, 0.99799200E-01, 0.81053800E-01, 0.34510500E-01, -.73066600E-01, -.24183300E+00, 0.94338900E-01, -.64625400E-01, 0.46791200E+01, -.65481400E-01, -.37561900E+00, -.20989500E+01, 0.45384900E+00, 0.12654100E+00, 0.40479100E+00, -.12338400E+01, 0.80597300E-01, -.10630400E+00, 0.14459900E+00, -.42107200E+00, -.25496400E-02, -.17703100E+00, -.21415700E+00, 0.18134700E+00, 0.61003800E-03, 0.14369700E+00, -.45523200E-02, 0.12651300E+00, -.23130800E+00, -.10487900E+00, -.12897200E-01, -.29983300E-01, 0.49263100E+00, 0.56836500E+00, 0.66332100E+01, -.49948600E-01, -.86796000E+00, -.47105400E-01, 0.10510400E+01, -.10444400E+01, 0.36632100E+00, -.14172600E+01, -.54603200E+01, -.40342900E+00, -.18515000E-01, 0.70641800E+00, -.68981400E+00, -.29719500E+00, -.30296700E-01, -.17855000E+01, 0.29795800E+00, -.41329500E+00, -.56154400E-01, -.50657900E+00, -.72997400E+03, 0.15638400E+04, -.29317900E+04, 0.14821100E+04, 0.39096000E+02, 0.14660400E+04, 0.12820500E+04, 0.18683800E+04, 0.11884900E+04, 0.20520300E+04, 0.10678700E+04, 0.22201800E+04, 0.77951900E+02, -.73665200E+03, 0.37743400E+03, 0.58694900E+03, 0.36834100E+03, 0.28578500E+03, 0.19091200E+03, -.17414900E+02, -.32447200E+03, 0.33753900E+02, 0.20869500E+03, -.27430300E+02, 0.62250100E+03, -.31147800E+03, 0.21294600E+03, -.31121600E+03, 0.52163000E+03, -.23217600E+03, 0.33122500E+03, 0.12280700E+04, -.85824200E+02, -.45141800E+03, -.12148200E+04, 0.81288700E+03, -.40948800E+03, -.78960400E+03, -.40769500E+03, -.62830700E+03, 0.11511500E+03, -.34188100E+03, -.31025800E+03, 0.49449300E+02, 0.40673200E+02, 0.42149100E+03, -.15181500E+03, 0.74051400E+02, 0.88538000E+03, 0.75865500E+02, -.23203700E+02, 0.25354200E+03, -.21864600E+03, -.38510800E+03, -.33506900E+03, 0.14016800E+03, 0.35732400E+03, -.26934300E+04, 0.13668400E+04, 0.28047300E+03, 0.13468700E+04, 0.11299400E+04, 0.20186500E+04, 0.62057300E+03, 0.11599900E+04, 0.46309300E+03, 0.24484700E+04, -.96132400E+02, 0.27022400E+03, -.13369500E+03, -.34089800E+01, -.13519100E+03, 0.54811000E+02, 0.69986200E+02, -.29845300E+01, -.11560800E+03, 0.16090900E+03, 0.89373200E+02, -.26440700E+03, 0.85708300E+03, -.41833800E+03, -.96882800E+02, -.42838900E+03, 0.27488000E+03, -.92773900E+01, -.20324300E+03, 0.31331300E+03, -.10493700E+03, 0.33066100E+02, -.25378900E+03, 0.18004700E+03, -.99013200E+02, 0.10591100E+03, -.89967100E+02, 0.24734600E+03, 0.67106800E+02, -.57219800E+02, -.69782100E+02, -.44692700E+03, 0.15962100E+03, 0.90570700E+03, -.83669200E+03, 0.43871400E+03, 0.44467500E+03, 0.41837300E+03, -.64228300E+02, -.22171200E+03, 0.14381200E+03, -.15483900E+03, 0.41963800E+03, -.18625100E+03, 0.34221900E+03, 0.76071700E+03, -.38240400E+03, -.28956900E+03, -.38020600E+03, 0.16838900E+03, 0.13156100E+03, -.25489300E+03, -.10632800E+02, -.52360600E+03, 0.13649200E+03, 0.57322200E+03, 0.14613600E+04, -.73008700E+03, -.74572500E+03, -.73084900E+03, 0.12562500E+03, -.22921800E+03, -.17003600E+03, 0.61615800E+03, 0.28473900E+03, -.21201500E+03, -.13881400E+04, 0.14935000E+04, -.74865100E+03, -.13731400E+04, -.74669300E+03, -.53463100E+03, -.12957200E+03, -.20862100E+03, 0.28226600E+03, 0.14989200E+03, -.20794400E+03, -.18531200E+03, 0.10713700E+04, -.53335600E+03, -.64195300E+03, -.53566700E+03, 0.31119100E+03, 0.39793900E+03, -.78366100E+02, 0.58037200E+03, -.38780700E+03, 0.64735000E+03, -.71943100E+03, 0.20069500E+04, -.99818500E+03, 0.17241200E+03, -.10032100E+04, 0.37540400E+02, 0.34972100E+02, -.44300400E+03, 0.37679400E+03, -.38300000E+03, -.19045100E+02, -.67556700E+03, -.99536000E+03, 0.49633900E+03, 0.46717500E+03, 0.49760200E+03, 0.60391900E+02, -.11351000E+03, 0.44384900E+03, 0.40450200E+03, 0.57512500E+03, 0.22606200E+03, -.50621300E+03, 0.35888100E+02, 0.29878200E+02, -.73548400E+01, 0.16011300E+02, 0.48675800E+01, 0.99293600E+00, -.23855900E+02, 0.10884000E+02, -.98851400E+00, 0.23412500E+03, -.33530500E+03, 0.24705600E+03, 0.13600800E+03, -.23279500E+03, 0.16889100E+03, 0.58341400E+02, 0.54407900E+02, 0.12722700E+02, 0.36131500E+02, -.24238000E+03, -.19148000E+02, 0.64284900E+02, -.67133400E+02, 0.49611600E+03, -.12851600E+03, 0.21053900E+03 },
        { 0.30628200E+01, -.75842700E-01, -.10213000E+00, 0.39634000E-01, 0.25293700E+00, -.62340000E+00, 0.97476600E-01, -.35542400E+00, 0.50129600E+00, -.53208700E+00, -.13567300E+00, 0.53263100E+00, 0.72639800E-01, 0.65967800E-02, 0.10641900E+00, -.65963200E-01, 0.13983000E-01, -.40256100E-01, 0.10551900E+00, -.12537100E+00, -.38946800E+00, 0.36487700E+00, -.11106100E+01, -.66095000E+00, -.16871100E-01, -.85748600E-01, 0.22802000E+00, -.55873800E+00, -.93613200E+00, 0.49757100E+00, -.77237300E-01, 0.78165900E+00, 0.95543000E-01, -.24245100E+00, 0.16602500E+01, 0.41769000E-01, -.57827000E-01, 0.10160200E+01, -.87085500E-01, 0.21081900E+00, -.24208700E+00, 0.11939300E+00, -.23685900E-01, 0.18441900E+00, -.25431700E+00, 0.84997600E-01, -.19266600E-01, 0.12977600E-01, 0.20315000E+00, -.71362100E-01, 0.10438000E+00, 0.76817500E+00, -.59753100E-01, -.20547400E-01, -.68142200E+00, 0.22590100E+00, -.12664500E-01, 0.34826000E+00, 0.21312800E+00, -.29009300E-01, -.25643200E-01, 0.61186300E-01, 0.20017300E+00, -.11978700E+00, -.29193100E+00, 0.19114900E-01, -.93438400E-01, -.18840800E-01, -.22511600E+00, 0.11413200E-02, -.34487300E-01, -.15791700E+00, -.15014000E+00, -.24168600E-01, -.17911100E+00, 0.15548200E+00, -.71775900E-01, 0.68414700E+00, 0.63417400E+00, -.38766500E+00, -.12179200E-01, 0.10659000E+00, -.41535900E-01, 0.42553200E-01, -.51606600E+00, -.16978500E+01, -.27433300E+00, -.96218700E-01, -.36331200E-02, -.34130100E+00, 0.10000500E-01, 0.96963500E-02, -.28959100E+00, 0.20015000E-01, -.81071000E-01, -.10257600E-01, 0.27442700E-01, 0.14624100E-01, -.87219400E+03, 0.12772000E+04, -.64026800E+03, -.21409500E+04, -.63920900E+03, -.73996500E+02, -.29099400E+02, -.35923000E+03, 0.17753500E+03, -.34295400E+03, 0.91746600E+02, -.26662800E+03, 0.21458100E+03, -.10932900E+03, 0.14262700E+03, -.10735000E+03, 0.11274100E+02, -.21159800E+02, -.23991800E+02, 0.60054800E+02, -.36069100E+02, -.55141800E+01, -.18377900E+03, 0.23469500E+03, -.11890100E+03, -.17021200E+03, -.11741000E+03, 0.11775800E+03, 0.53913500E+02, -.16127300E+02, 0.14312900E+03, -.91002200E+02, 0.55575900E+02, -.72282000E+02, -.44900100E+03, 0.22248000E+03, 0.14203100E+03, 0.22487500E+03, -.12004300E+02, -.47413400E+02, 0.45478900E+02, -.16925800E+03, 0.73014400E+02, -.29798600E+02, 0.17599800E+03, 0.15092000E+03, -.76814600E+02, -.52912300E+02, -.75407900E+02, -.31042100E+02, 0.10162400E+01, -.10032800E+03, -.58378000E+01, -.83261100E+02, -.70971800E+02, 0.20243700E+03, 0.14432800E+04, -.73495700E+03, -.17736800E+04, -.72239400E+03, -.13058400E+03, -.50838600E+02, -.30247200E+03, 0.20106400E+03, -.35969300E+03, 0.22658800E+02, 0.29368900E+02, 0.77234600E+02, -.37341400E+02, 0.28174600E+02, -.38506200E+02, -.78069500E+02, 0.45448500E+02, -.29420600E+02, -.82063400E+02, -.37431200E+02, 0.54535700E+02, -.95854100E+02, -.24634900E+02, 0.13560700E+02, -.53562100E+02, 0.12110600E+02, -.26404400E+02, -.28225000E+02, 0.15836400E+02, 0.45191200E+01, -.79730400E+00, -.28455600E+02, 0.27717400E+03, 0.12968500E+03, -.70250200E+02, -.87860300E+02, -.64910000E+02, 0.70987300E+00, 0.60880400E+02, -.69858000E+01, 0.11636400E+03, -.48120200E+02, 0.26527200E+02, 0.31602700E+03, -.10385400E+03, 0.50872000E+02, 0.17225300E+03, 0.51905300E+02, -.67127400E+01, 0.26353400E+02, -.26293100E+02, -.50824800E+02, 0.79968900E+01, 0.17116300E+02, 0.17744600E+03, -.85810300E+02, 0.39040800E+02, 0.58126700E+02, 0.42695900E+02, 0.63206000E+02, 0.65273700E+02, 0.43712700E+02, 0.64991900E+02, -.37243200E+01, 0.40131700E+02, 0.20865500E+03, 0.17815300E+03, -.86755600E+02, -.85075000E+02, -.88848900E+02, -.12754800E+02, -.84035400E+02, 0.16247700E+03, 0.14285500E+03, 0.70527000E+02, -.10567300E+02, -.46155400E+03, 0.16650000E+03, -.81470600E+02, -.16915200E+03, -.83328400E+02, -.67619100E+01, -.15686300E+02, 0.10002300E+02, 0.63094500E+02, 0.36776900E+02, -.13099900E+02, 0.46190300E+01, -.65312400E+02, 0.40330200E+02, -.68871500E+03, 0.32449700E+02, 0.44733800E+02, -.60192200E+02, -.11348900E+02, 0.47750400E+02, 0.13545700E+02, 0.10732500E+02, -.62107600E+01, 0.28498600E+03, -.14189300E+03, -.44082100E+03, -.14287800E+03, -.55980900E+02, -.14725200E+03, 0.27678300E+02, 0.84631400E+02, -.80988400E+02, -.14317600E+03, 0.18163400E+03, -.31652800E+03, 0.16232700E+03, 0.12235900E+03, 0.15839100E+03, 0.19433900E+02, -.32057400E+01, 0.53416900E+02, -.54760100E+02, 0.42905700E+02, 0.86285400E+01, 0.52435500E+03, 0.45925600E+01, -.33432800E+01, 0.13213900E+01, -.87631100E+00, 0.33602400E+01, -.81932700E+00, -.31749500E+01, -.16403700E+00, -.38232100E+01, -.15314600E+02, 0.17506100E+02, 0.28069000E+02, 0.10802900E+02, 0.70187800E+02, 0.48625600E+02, -.32649300E+02, 0.18671300E+02, -.41301300E+01, 0.26120800E+02, 0.85775000E+02, -.21391500E+02, 0.27857600E+02, -.25992500E+01, 0.55545900E+02, 0.50632700E+02, -.17374900E+02 },
        { -.10487500E+02, 0.29516100E+00, 0.40765900E+00, 0.11602800E+01, -.12540800E+01, 0.30937500E+01, -.25684300E+01, 0.16172400E+01, -.48017400E+00, 0.26141200E+01, -.42233800E-02, 0.15566200E+01, -.12354200E+00, -.41405500E-01, -.74653900E+00, 0.29744700E+00, 0.77496800E+00, -.40137900E+00, -.16889400E+01, 0.59748700E+00, 0.71282200E+00, 0.13048300E+00, -.52161300E+01, -.10354200E+01, -.18387500E+00, 0.48936900E-01, 0.12180900E+00, -.22059500E+00, 0.29509500E+00, -.18241300E+01, -.84527500E+00, -.45715500E+00, -.19373000E-01, 0.11744000E+01, -.31168000E+01, -.50564800E+00, -.29477600E+00, -.24832300E+01, -.14395400E+00, -.25293300E+00, 0.66411100E+00, 0.80451300E+00, -.42361600E+00, -.43851400E+00, 0.45861000E+00, -.14848800E-01, -.42956100E-01, 0.35563500E-01, -.20255600E+00, 0.24210600E-01, 0.25397300E+00, 0.36445100E+01, -.17023700E+00, 0.10811800E+00, -.19301500E+01, 0.43699500E+00, -.10790300E-01, 0.88142100E+00, 0.53983900E+00, -.18163800E+00, 0.90393200E-01, -.39349800E-01, 0.60424800E+00, -.21075100E-01, 0.87880100E+00, 0.32546100E+00, -.78027500E+00, 0.99670500E-02, -.17917100E-01, 0.70573700E-02, 0.44406900E-01, -.34672900E+00, -.20824800E+00, 0.62458900E-01, -.18679200E+00, 0.36988800E-01, -.58085100E+00, -.76112800E+00, -.29215500E+00, 0.60019900E-01, 0.73898200E-01, -.12595400E-01, 0.27106600E+01, -.98660100E+00, 0.62711000E+00, 0.10604100E+02, 0.13301800E+00, 0.27839500E+00, -.32575800E+00, 0.13909800E+01, 0.54354200E+00, 0.63218900E-01, -.17672600E+01, -.26623600E-01, 0.20969300E+00, -.12986100E+01, -.85276400E-01, -.80091300E-01, -.17811600E+01, 0.53058900E+04, -.26403600E+04, -.79146600E+04, -.26561500E+04, 0.66705600E+03, 0.13350300E+04, -.27799100E+04, -.20039400E+03, 0.49857200E+02, 0.12743000E+04, -.45017500E+04, 0.26066800E+04, -.13115700E+04, -.63249000E+03, -.13036600E+04, -.16401200E+03, -.24749300E+03, -.17166400E+03, 0.11719800E+04, 0.93815500E+02, -.10805600E+03, -.14767100E+04, 0.38939600E+03, -.19705100E+03, -.13754600E+04, -.19499200E+03, 0.60937300E+03, 0.10509500E+03, -.56473000E+03, -.10786100E+04, -.35376900E+03, 0.30921700E+03, 0.14030300E+04, -.12903200E+04, 0.64457000E+03, 0.80001100E+03, 0.64584100E+03, 0.22425400E+03, 0.13314700E+03, 0.66295900E+02, -.40857000E+03, -.10044500E+03, 0.11758200E+03, 0.31361000E+02, -.29323200E+04, 0.14682900E+04, 0.12392200E+04, 0.14663400E+04, 0.59262500E+03, 0.39460900E+03, -.28170200E+03, -.14020600E+04, -.38349200E+03, 0.34316200E+03, 0.12025800E+04, 0.42496500E+04, -.20959400E+04, -.59621200E+04, -.21288700E+04, 0.45612500E+03, 0.11566600E+04, -.21023100E+04, -.32520700E+03, -.32670100E+03, 0.10585500E+04, -.30560800E+04, 0.67197800E+03, -.34582700E+03, -.11092100E+03, -.33554900E+03, -.43807400E+03, 0.43950100E+01, 0.43494500E+02, 0.17330200E+03, -.47955200E+03, 0.86025800E+02, -.31516500E+03, -.52620500E+03, 0.26035000E+03, 0.75222900E+02, 0.26230200E+03, -.45372000E+03, -.24987500E+03, 0.24739300E+03, 0.27827800E+03, 0.18392500E+03, -.24317100E+03, 0.13103500E+04, 0.20761800E+04, -.10328600E+04, -.63072400E+03, -.10383300E+04, -.25327000E+03, 0.35262100E+03, -.87423300E+03, 0.69760700E+02, -.54283500E+03, -.24013100E+03, 0.16094800E+04, 0.56870900E+03, -.29689500E+03, 0.19241300E+03, -.28440400E+03, 0.15699200E+03, 0.35324400E+03, -.34244600E+03, -.49932800E+02, -.34614600E+03, 0.28689500E+03, 0.44954800E+02, 0.44711300E+03, -.21800200E+03, 0.42766800E+03, -.22437800E+03, 0.20477700E+03, 0.40720700E+03, -.41597500E+03, -.20743700E+03, -.55452900E+03, -.55208300E+02, 0.13314800E+04, 0.35682200E+04, -.17891500E+04, -.18182100E+04, -.17832300E+04, -.12159000E+04, -.12031800E+04, 0.85307400E+03, 0.15760900E+04, 0.45616000E+03, -.91584200E+03, -.19241800E+04, 0.64598900E+03, -.31824000E+03, -.22001400E+03, -.32329300E+03, -.20534300E+03, -.37723500E+03, 0.39884900E+02, -.76853800E+02, -.54148700E+03, -.32467800E+03, -.11401500E+03, -.99941300E+03, 0.48293900E+03, -.19548500E+04, 0.49853500E+03, 0.55634800E+03, 0.43317700E+02, -.99462200E+02, 0.40640900E+03, 0.12625800E+04, -.21981500E+02, -.62897200E+03, -.25044900E+03, 0.12451000E+03, -.18640100E+04, 0.12362900E+03, 0.10869800E+03, -.49015900E+03, 0.33022100E+03, 0.40050100E+03, 0.25236900E+03, -.38036200E+03, 0.99016900E+03, 0.10011600E+04, -.50344800E+03, -.47412900E+03, -.50018400E+03, -.18272900E+03, -.62912400E+02, -.20210500E+03, -.17772100E+03, -.44985600E+03, 0.13131700E+02, -.56416400E+03, 0.22458800E+01, -.92720000E+00, -.13367100E+02, -.19691900E+02, 0.24497900E+02, -.40407700E+02, -.57848300E+02, -.15021600E+02, 0.78467700E+01, -.34943400E+03, 0.22432600E+03, -.27136800E+03, -.32428900E+02, 0.47623100E+02, 0.24836400E+03, -.42246400E+03, -.35033700E+02, 0.12035400E+02, 0.12393900E+03, 0.17214000E+03, -.14285300E+03, 0.18187300E+03, -.40182800E+02, 0.23439900E+03, 0.23244900E+03, -.35000700E+03 },
        { 0.23864700E+02, -.11014800E+01, -.49861200E+00, 0.10567200E+01, 0.20356400E+01, -.41661600E+01, 0.31999300E+01, -.23973500E+01, 0.76557900E+00, -.26606900E+01, 0.29909800E+00, 0.51295200E+01, -.18083600E+01, -.79851400E-01, -.18855900E+01, -.11437700E+01, 0.16212700E+01, -.18184200E+00, 0.14878100E+01, -.82281200E+00, 0.67279500E-01, 0.63209600E+00, -.10733000E+02, -.12176600E+01, 0.21132600E+00, -.15485900E-01, -.36947100E+00, -.46984700E+00, -.12318300E+01, -.48195600E+00, -.12121900E+01, -.23632800E+01, 0.36706400E-01, -.32352200E-01, -.33526600E+01, 0.17267700E+00, 0.32219800E+00, -.21449800E+01, 0.32273200E+00, -.47752900E+00, -.39068300E+00, 0.23323400E+00, -.86339300E+00, 0.22986400E+00, -.10525500E+01, 0.12359600E+01, 0.35559400E+00, -.66864800E-01, 0.51576200E+00, -.71399000E-02, -.15806800E+01, -.25877600E+01, 0.44174000E-01, 0.21413600E-01, -.26591900E+01, -.10817800E+01, -.90707900E+00, -.58232800E+00, -.21654900E+01, 0.15553000E+00, 0.25604400E+00, 0.51789900E+00, -.54187200E+00, 0.50341700E-01, -.49725300E+00, -.60779000E+00, -.17474300E+01, 0.11798900E+00, -.20606200E+01, -.38443600E-02, 0.54298700E+00, -.87635000E+00, -.55049900E+00, 0.89376200E-01, 0.21951100E+01, 0.17679100E+01, -.56636500E+00, 0.95292400E+01, -.33643200E+01, 0.94317400E+00, 0.32719400E-01, -.12775800E+01, -.73692100E+00, -.28366900E+00, -.11401400E+01, -.59928000E+01, 0.48542500E+00, 0.23572700E+00, 0.20974500E+01, 0.11351100E+01, -.22153000E+00, 0.69475400E-01, 0.30492100E+01, 0.41793400E+00, -.94486400E-01, -.13994300E+01, 0.39456100E+00, -.76657700E-01, -.60439200E-01, 0.70387300E+00, 0.21436200E+03, 0.35598100E+04, 0.59768700E+00, 0.87455400E+03, 0.22734700E+04, -.10566800E+04, -.47503700E+02, -.11524000E+04, 0.18919900E+04, 0.21011800E+04, -.27097200E+03, 0.14263100E+03, -.10862900E+04, 0.13552100E+03, -.73963500E+02, -.95110700E+02, 0.13208800E+03, -.95845300E+02, 0.49006600E+03, -.66597400E+01, 0.58682600E+03, -.87765900E+03, 0.45224600E+03, -.43967300E+03, 0.43897600E+03, -.21630300E+04, -.13940900E+03, -.21099900E+03, -.13905900E+04, 0.22511700E+03, 0.52623000E+03, -.10622200E+04, -.99083500E+03, 0.49800200E+03, 0.12067300E+04, 0.49273000E+03, 0.79912500E+03, 0.69899900E+02, 0.33567600E+03, 0.46213800E+03, 0.39602200E+03, -.20725400E+03, 0.89411900E+03, -.93543000E+03, 0.46735800E+03, 0.52196100E+03, 0.46746300E+03, 0.42606200E+03, 0.29609200E+03, -.26323800E+03, -.20142000E+03, 0.76622700E+02, 0.27321600E+03, -.64820000E+03, -.29250500E+03, 0.31676600E+03, 0.30799000E+04, 0.14695100E+03, 0.11821200E+04, 0.27832200E+04, -.16862400E+04, -.13263600E+04, -.17579200E+04, 0.24661400E+04, 0.10735800E+04, 0.51352900E+03, -.26352300E+03, 0.23343100E+03, -.25719600E+03, 0.13270400E+03, -.35229200E+03, 0.10071600E+03, 0.40497800E+03, -.40572500E+03, -.44846500E+03, 0.60841600E+03, 0.46284100E+03, -.23087800E+03, 0.64955300E+03, -.23057800E+03, 0.46968200E+03, 0.19202400E+03, -.13207500E+03, -.20829800E+03, 0.55177800E+02, 0.23016000E+03, -.10538000E+04, -.30817000E+04, 0.15502300E+04, 0.22065400E+04, 0.15411600E+04, -.81690100E+03, -.56177800E+03, 0.45789800E+03, -.11942700E+04, 0.14696700E+04, -.28414300E+03, -.13568400E+04, 0.28121800E+03, -.13550000E+03, -.27536700E+03, -.14046300E+03, -.88835500E+02, -.30533400E+03, 0.29679200E+03, 0.31963700E+03, 0.19971700E+03, -.25561000E+03, -.24524500E+03, -.23201200E+04, 0.11725000E+04, 0.15334700E+04, 0.11608800E+04, -.79263200E+03, -.47493200E+03, 0.39784300E+03, -.79573900E+03, 0.12065500E+04, -.16760400E+03, -.12570500E+04, -.17440200E+04, 0.86525800E+03, 0.86853700E+03, 0.87107500E+03, -.46568700E+03, -.71272300E+02, 0.65430700E+03, -.47891800E-01, 0.50652400E+03, -.20032000E+02, 0.30076500E+04, -.15303000E+04, 0.76123900E+03, 0.14408700E+04, 0.76548000E+03, 0.11872800E+03, 0.45196500E+02, 0.19996100E+03, -.17293500E+03, -.24297100E+03, 0.16269900E+02, 0.38623300E+03, -.29567500E+03, 0.20658700E+03, 0.16798500E+04, 0.14791000E+03, 0.34578900E+02, 0.22277000E+02, 0.25426400E+03, 0.61136400E+03, 0.27465700E+03, -.10015000E+03, 0.15268200E+04, -.20199200E+04, 0.10116200E+04, 0.66347700E+03, 0.10112900E+04, 0.35734900E+03, 0.41097000E+02, 0.72277700E+03, 0.55180200E+03, 0.15494300E+04, 0.66460300E+02, 0.23552900E+03, -.59705800E+03, 0.29505600E+03, 0.28263700E+03, 0.29794300E+03, 0.84463800E+02, 0.86598100E+02, 0.65522300E+02, 0.11691600E+03, 0.81885000E+02, 0.15479500E+03, -.17154300E+03, 0.37217600E+01, 0.19576300E+02, 0.21651400E+02, -.95216800E+01, -.29002100E+02, 0.51531500E+02, -.97012000E+01, 0.82026800E+00, -.16291500E+02, -.13680200E+03, -.19394200E+03, -.19386800E+03, -.19305800E+03, 0.28049800E+03, -.33990000E+02, -.34148400E+02, -.13652300E+03, -.88429700E+01, -.27267900E+03, -.51687200E+03, 0.14579300E+03, -.16271000E+02, 0.91826000E+02, -.12371600E+03, -.41279100E+02, -.12231100E+03 },
        { -.73602500E+01, 0.75790400E-01, 0.25445000E+00, -.26920500E+00, -.82857600E+00, 0.36057300E+00, 0.86745300E+00, 0.14872300E+00, -.10980700E+01, 0.43386100E+00, 0.89626500E-02, -.68552400E+00, 0.26336400E-01, -.24950800E-01, -.29493500E-02, 0.53254200E-01, -.81113100E+00, -.17622000E+00, -.98152700E+00, 0.35066300E+00, -.25797600E+00, -.33279600E-01, 0.14341600E+01, 0.51613000E+00, 0.12715300E+00, 0.88497800E-01, 0.48988400E-01, 0.41483600E+00, 0.42579800E+00, -.42895400E+00, 0.11493300E-01, 0.52928600E+00, -.11304700E-01, -.24396400E+00, -.24602200E+01, 0.32832200E+00, -.12507800E+00, -.11888300E+01, -.11099100E-02, 0.36793200E-01, 0.14522600E+00, -.51116200E-03, 0.24638400E+00, -.18461100E-01, 0.36238200E+00, -.26952000E+00, 0.87787300E-01, 0.11891800E-01, -.43940300E+00, 0.54613000E-02, 0.11396400E+01, 0.88966000E+00, 0.28623000E+00, 0.50257900E+00, 0.10735600E+01, 0.75026900E-01, 0.73959400E-01, 0.19114400E+00, -.27957600E-01, -.67397600E-01, -.16298200E+00, 0.27437100E+00, 0.27588200E+00, -.56051800E-01, 0.45707600E+00, 0.11353800E+00, -.77489700E+00, 0.72550400E-02, -.40184900E+00, 0.20518400E-02, -.35691200E-01, -.16035600E-01, -.11670700E+00, -.13520800E+00, 0.90664900E+00, 0.11283400E+00, -.55279100E+00, 0.12551800E+00, -.11617200E+01, -.21813800E+00, 0.16541000E-01, 0.80501500E+00, -.10854400E+00, -.41582200E+00, -.37352700E+00, -.65318000E+01, 0.28821400E-01, -.31333500E-01, -.10679600E+00, 0.39488100E+00, -.14509900E+00, 0.67297200E-01, -.12021800E+01, 0.15389800E+00, 0.13889700E+00, 0.27001300E-01, -.39686500E+00, 0.25208500E+00, -.99244600E+00, -.20607300E+00, -.73502200E-02, -.53750400E+04, -.16482500E+01, 0.43276100E+03, 0.47485000E+03, -.50087100E+03, 0.91498000E+03, 0.13462600E+04, 0.40739700E+03, -.12335000E+04, 0.19172700E+04, -.96906300E+03, -.43581800E+03, -.95877500E+03, -.20497000E+03, -.27279200E+03, -.12068400E+03, 0.57047600E+03, -.39621000E+03, -.19904000E+03, -.10656200E+04, 0.84692700E+03, -.43191200E+03, 0.18097200E+03, -.42369800E+03, 0.14910000E+04, -.87945500E+02, 0.32078800E+03, 0.13960800E+04, -.12323500E+03, -.24436900E+03, 0.44191900E+03, -.16138300E+04, 0.81106700E+03, 0.47076500E+03, 0.80879800E+03, -.15142300E+03, -.87451000E+02, -.24968100E+02, -.11141400E+04, -.93794800E+02, 0.19027400E+03, -.76235400E+02, 0.28146000E+04, -.14088000E+04, -.15412100E+04, -.14070000E+04, 0.41675400E+02, -.38910700E+03, -.38644800E+03, 0.80093200E+03, -.51222500E+03, -.42619800E+03, -.98346200E+03, 0.64108000E+03, -.33386100E+03, -.39086900E+04, -.32265500E+03, 0.58467800E+02, 0.12133800E+03, -.15125200E+03, 0.84432800E+03, 0.92488200E+03, 0.16818900E+02, -.85970300E+03, 0.77879300E+03, -.38559800E+03, -.27080600E+03, -.38883700E+03, -.40941500E+03, 0.45415900E+03, -.22744200E+03, -.39452000E+03, -.69266700E+02, 0.32774400E+03, -.34807000E+03, -.67543400E+03, 0.32222200E+03, -.92874400E+02, 0.33664900E+03, -.36142300E+02, -.17434900E+03, 0.39860300E+03, 0.28507300E+03, 0.17617700E+03, -.10939600E+03, 0.10391400E+04, 0.27391900E+04, -.13838600E+04, -.16406800E+04, -.13699700E+04, -.67149700E+02, 0.31702200E+03, -.60260500E+03, 0.74746700E+03, -.67111800E+03, 0.47775900E+02, 0.88046700E+03, -.42092500E+03, 0.19796700E+03, 0.77350300E+03, 0.21032000E+03, -.57202900E+01, 0.68573100E+02, -.91214000E+02, -.27089800E+03, -.39014200E+02, 0.82872300E+02, 0.39686100E+03, 0.16198200E+04, -.81107400E+03, -.10913300E+04, -.81096200E+03, 0.11135700E+03, 0.27779500E+03, -.35228100E+03, 0.38821200E+03, -.53973200E+03, 0.43382400E+02, 0.65971200E+03, -.92833300E+03, 0.46970500E+03, 0.47849700E+03, 0.46534600E+03, -.27112300E+03, 0.93537300E+02, 0.45280200E+03, -.40170500E+03, -.75727900E+02, 0.20281000E+03, -.37313500E+03, -.52164700E+03, 0.26065800E+03, 0.64104100E+02, 0.26040900E+03, 0.49263800E+02, 0.10428000E+03, 0.26152800E+02, -.25508600E+03, 0.17480100E+03, 0.17322700E+03, 0.11211400E+03, -.17234300E+03, 0.88590900E+02, -.23334400E+04, 0.85661400E+02, 0.38983300E+03, 0.21352000E+03, -.23986100E+03, 0.39668300E+03, 0.48796200E+03, 0.19627100E+03, -.72387800E+03, 0.19892900E+04, -.10048900E+04, -.15361900E+04, -.99642000E+03, -.75251500E+02, -.70066300E+03, 0.22676300E+02, 0.17551600E+03, -.10320600E+04, -.49510100E+03, -.23178500E+03, -.42417900E+03, 0.21171000E+03, 0.34281200E+02, 0.21273500E+03, -.28838400E+01, -.91640900E+02, 0.13584600E+03, -.93255000E+02, 0.63008500E+02, -.22832900E+02, 0.22928700E+03, 0.21102000E+02, -.13780200E+02, 0.72873000E+01, -.61208300E+01, 0.11361000E+02, -.12469700E+02, -.57132200E+01, 0.50249300E+01, -.13005700E+02, 0.14349900E+03, -.30204700E+03, -.32040600E+02, 0.16618600E+03, 0.11555400E+03, -.58547600E+02, 0.10812500E+03, 0.15469100E+03, 0.88038200E+01, 0.54400000E+02, 0.18555100E+03, -.75445200E+02, 0.37411000E+02, -.33595800E+02, 0.56570400E+03, 0.29421000E+03, 0.14728700E+03 },
        { -.65012700E+01, 0.17628100E+00, 0.24911400E+00, 0.60650500E+00, -.10644500E+01, 0.23845100E+01, -.92224700E+00, 0.12247300E+01, -.17726300E+01, 0.15472500E+01, 0.44324800E-01, -.72849200E+00, -.30990300E+00, -.10527600E+00, -.38174100E+00, 0.23238200E+00, 0.12611400E+00, -.23984000E-01, -.67123800E-01, 0.14333900E+01, 0.16722200E+01, -.23718600E+00, -.97006400E+01, -.12231500E+01, -.38003000E+00, 0.91281500E-01, -.25700000E+00, 0.12586500E-01, 0.15346300E+01, 0.60869500E+00, 0.19058400E+00, 0.40312600E+01, -.13879500E+00, 0.12630400E+01, -.36925000E+01, -.97149300E+00, -.22401100E+00, -.52846300E+01, 0.14251300E+00, -.47655800E+00, 0.10755200E+01, 0.16599500E+00, 0.13587900E+01, -.19481900E+01, 0.19455000E+00, -.32694400E+00, 0.21577700E+00, 0.49812300E-01, -.57869000E+00, 0.33727900E+00, -.21421300E+01, 0.35055800E+01, 0.27153500E-01, -.65255500E-01, -.16400800E+01, -.62611800E-01, 0.95951600E-01, 0.32198500E+00, 0.10142500E+01, -.20107200E+00, -.64735900E+00, 0.24564900E+00, -.13079600E+01, 0.90889300E+00, 0.13157100E+01, -.41568000E+00, 0.30909500E+01, 0.22653200E-01, 0.38331000E+01, -.59685800E-02, 0.47870100E-02, -.61953000E+00, -.11293400E+00, 0.50542800E+00, -.17662700E+00, -.10801700E+01, -.93519900E-01, -.23390000E+01, -.85147000E+00, 0.76113400E+00, 0.96900200E-01, -.30384700E+01, -.37197700E+00, 0.71135800E+00, 0.11876900E+01, 0.63958900E+01, 0.19014400E+00, -.67737700E-01, 0.35771200E+00, -.22938100E+00, -.74376000E+00, 0.63950600E-01, 0.27142600E+01, -.41782400E+00, -.32092600E+00, -.18417300E+00, 0.29897200E-01, -.94301200E+00, 0.15306300E+01, -.42630500E+00, -.12752000E+00, -.16561900E+01, -.31503600E+01, 0.11396500E+04, 0.16688400E+04, 0.66816900E+03, 0.38618600E+04, -.13676600E+03, 0.17287200E+04, 0.61302000E+03, -.73488200E+03, 0.33995500E+03, 0.66865900E+03, 0.36717400E+03, 0.43786000E+03, 0.24503600E+03, -.13114000E+03, -.18881000E+03, 0.38250900E+03, 0.13171200E+03, 0.14079800E+03, -.58719800E+02, 0.27589000E+02, 0.33356100E+03, 0.28954500E+02, 0.14835700E+04, -.47148700E+03, 0.79950500E+03, 0.18952100E+04, 0.14485800E+03, -.79872100E+03, -.14005500E+04, -.16334400E+04, 0.81286300E+03, -.15188300E+03, 0.81791300E+03, -.38172900E+03, 0.14917100E+00, 0.16915000E+03, -.61484100E+03, 0.62849200E+03, 0.13783200E+03, 0.13140700E+04, 0.42148000E+04, -.21117300E+04, -.16957800E+04, -.21068900E+04, -.42983000E+03, -.62048700E+03, -.27858100E+03, 0.15390800E+04, -.97969900E+01, -.79299400E+03, -.12164300E+04, -.54470900E+03, 0.28915100E+03, 0.12356900E+03, 0.26828900E+03, 0.66851800E+03, 0.11569500E+04, 0.10149800E+04, 0.29726600E+04, 0.12767700E+03, 0.11085400E+04, 0.96981900E+03, 0.50438600E+03, -.24872400E+03, -.36297200E+03, -.25125000E+03, -.41262400E+03, 0.56227400E+03, -.30528600E+03, -.76277100E+03, -.11077600E+03, 0.39621300E+03, 0.27421100E+03, 0.58809600E+03, -.27957100E+03, -.51937900E+03, -.29584100E+03, -.93739700E+02, -.24240100E+03, 0.41968800E+02, 0.27841300E+03, -.79421800E+02, -.22250200E+03, -.29102400E+01, 0.10332000E+04, -.52223200E+03, -.11689700E+04, -.51721500E+03, 0.17949900E+03, -.27778900E+02, -.19971800E+03, 0.33706100E+03, -.20629600E+03, 0.33939300E+03, -.56013600E+02, -.45893500E+03, 0.22510800E+03, 0.52488200E+03, 0.22924500E+03, 0.66446200E+02, 0.12646000E+03, -.17798900E+03, -.23255000E+03, 0.11990800E+03, 0.25812800E+02, 0.26112500E+03, 0.61152500E+03, -.30856400E+03, -.11041900E+04, -.30752500E+03, 0.25379000E+03, -.98444100E+02, -.66736500E+02, 0.30535300E+03, 0.74241200E+02, 0.24986000E+03, -.76597200E+02, -.57048200E+04, 0.28515300E+04, 0.26802500E+04, 0.28543900E+04, 0.98223900E+03, 0.11923400E+04, 0.32092200E+03, -.18488600E+04, 0.44081200E+03, 0.11747900E+04, 0.15260300E+04, -.13973400E+03, 0.66540000E+02, -.10127600E+04, 0.69171300E+02, -.15272400E+03, 0.61088300E+02, 0.13495300E+03, -.18043600E+03, 0.34466600E+03, 0.18524900E+03, 0.30796300E+03, 0.28639200E+04, -.14485600E+04, -.88974400E+03, -.14330000E+04, 0.36629600E+03, 0.77325800E+03, -.94422300E+03, 0.71261200E+03, -.14010300E+04, 0.98246700E+03, -.11879700E+04, 0.25068400E+04, -.12489400E+04, 0.69122600E+03, -.12564200E+04, 0.99909200E+02, -.53723500E+03, -.24082600E+02, 0.77551400E+03, -.72400500E+03, -.54798400E+03, -.88736300E+03, -.18113500E+04, 0.90627400E+03, 0.71001100E+03, 0.90679200E+03, 0.15404000E+03, -.11224800E+03, 0.58684200E+03, 0.23952300E+03, 0.51400100E+03, -.73700300E+02, 0.67328400E+03, 0.12000500E+02, 0.32582000E+02, -.29217900E+02, -.61712100E+01, 0.35610800E+01, 0.57393600E+01, 0.58355200E+02, 0.14472900E+00, 0.18826200E+02, 0.13006400E+03, -.47065200E+03, 0.42606900E+03, 0.23191600E+03, -.60917800E+02, -.13147500E+03, 0.19008300E+03, 0.20662400E+03, 0.49084700E+01, -.19665800E+03, 0.17555100E+03, 0.92322100E+02, -.77479900E+02, 0.17016100E+02, 0.46163500E+03, 0.20972800E+03, 0.17088100E+03 },
        { -.67909000E+01, 0.20375300E+00, 0.26752000E+00, 0.10339900E+01, -.52433100E+00, 0.15603300E+01, -.10736300E+01, 0.12488200E+00, 0.75649500E+00, 0.14850500E+01, 0.20895200E-01, 0.88253800E+00, -.31724600E-01, -.30585800E-01, 0.32801100E-01, 0.40831000E-01, 0.46222300E+00, -.23882100E+00, -.34771000E+00, -.53902800E-01, -.15232400E+00, -.82631100E-01, 0.11293400E+01, -.33164600E+00, -.65681900E-02, -.51140500E-01, 0.35172100E-01, -.20285600E+00, -.39864000E+00, -.60531900E+00, -.99899200E-01, -.11275700E+01, -.63008700E-01, 0.10270000E+00, 0.10146800E+01, -.74165500E-01, -.22027800E-01, 0.59264500E+00, -.32937000E+00, 0.89692500E+00, -.15866000E+00, 0.37389900E-01, -.78312000E-01, 0.50809100E+00, 0.24340300E+00, -.24631500E+00, -.34893400E-01, -.10263900E-01, -.33729000E+00, 0.15344800E+00, 0.40663900E+00, 0.57919800E+00, 0.55511900E-01, 0.74186100E-01, 0.13843200E+01, 0.67171300E-01, 0.13590000E+00, -.94797900E+00, -.15136800E+00, -.60719700E-01, -.52359700E-01, 0.63526500E+00, -.77728000E+00, 0.23155500E+00, 0.14051600E+00, -.32274700E+00, 0.12620300E+01, 0.79381800E-02, 0.61456500E+00, -.30286900E-02, 0.10561200E+00, -.46643900E+00, -.11080800E+00, 0.34170000E-01, -.21343700E+00, -.56730000E+00, -.26478000E+00, -.34300200E+01, 0.53591800E+00, -.80872400E+00, -.38938700E-01, -.10619700E+00, 0.36212100E+00, 0.41424000E+00, -.44367100E+00, 0.25989600E+01, -.12571900E+00, -.54761700E-01, -.20234000E+00, -.51840900E+00, -.31155900E+00, -.47569000E-01, -.71513500E+00, -.14386700E+00, 0.30550000E-01, 0.22572600E+00, -.29363100E-01, 0.28421100E+00, -.10703700E+00, -.60619000E-01, -.17965800E+00, -.59907400E+00, 0.40436800E+00, -.12742100E+04, -.23434900E+04, 0.78042900E+03, 0.16684700E+03, 0.87078400E+03, -.20890700E+04, -.17835100E+04, -.25018400E+03, 0.13162600E+03, -.32084600E+03, 0.12507900E+03, 0.14670200E+03, 0.59884400E+02, -.56606500E+01, -.85800600E+02, -.58499200E+02, 0.54526700E+02, 0.15588700E+03, -.68389600E+02, 0.32419800E+02, 0.91453900E+03, 0.34213000E+02, 0.28400900E+03, 0.16105900E+03, -.43475900E+02, 0.10241300E+02, -.96667500E+02, 0.99514700E+02, 0.97128500E+03, 0.39466600E+03, -.19526600E+03, -.23381200E+03, -.19744800E+03, -.90344800E+02, -.23899800E+03, -.94432300E+02, -.13860500E+03, -.19232300E+03, -.65477300E+02, -.52023200E+03, 0.50450600E+03, -.25317100E+03, -.64613100E+03, -.25231800E+03, -.12410600E+03, -.11818700E+03, 0.47073200E+02, 0.27176000E+03, -.10928100E+03, -.61087200E+02, 0.65087300E+02, 0.12261500E+04, -.63238900E+03, -.22476900E+03, -.61298300E+03, -.11301800E+04, -.21380400E+04, 0.55803700E+03, 0.51496200E+03, 0.62907800E+03, -.19225600E+04, -.16709000E+04, 0.43697000E+03, -.21314000E+03, -.50070700E+03, -.21858300E+03, -.17838600E+02, -.19971300E+02, -.92193400E+02, -.18541700E+02, 0.74489600E+02, -.77504700E+02, -.47185200E+03, -.98800200E+03, 0.48567300E+03, 0.31138300E+03, 0.49419200E+03, -.19167300E+02, -.50718900E+01, 0.36279600E+03, 0.15074900E+03, 0.24484500E+03, -.13230700E+02, 0.71558600E+03, 0.84681900E+03, -.42915700E+03, -.48700900E+03, -.42334100E+03, -.14129700E+03, 0.13619400E+03, -.60385200E+02, 0.23839600E+03, -.29234900E+03, -.38988500E+02, 0.26507000E+03, -.11983000E+03, 0.61620900E+02, 0.98139600E+02, 0.59938100E+02, 0.73688100E+01, 0.11632400E+03, 0.18478900E+02, -.80569100E+02, -.82537900E+02, 0.13565200E+03, 0.19645100E+03, 0.30854400E+03, -.15811600E+03, -.32049400E+03, -.15409500E+03, -.74581200E+02, 0.63229500E+02, -.35846700E+02, 0.18488500E+02, -.18321400E+03, -.81205300E+02, 0.16966100E+03, 0.73762600E+03, -.36503800E+03, -.43222600E+03, -.36902400E+03, -.53147500E+02, -.19335400E+03, -.25555900E+02, 0.11495600E+03, -.13822500E+03, -.21640500E+03, -.85397400E+03, 0.72763300E+03, -.36344900E+03, 0.14507000E+03, -.36373900E+03, -.68599100E+02, -.22589600E+03, 0.79123000E+02, 0.29626300E+03, -.86068400E+02, -.18221100E+03, -.63327600E+03, -.77643000E+03, 0.39783600E+03, 0.11973400E+03, 0.38823200E+03, -.45086100E+03, -.69459800E+03, 0.41684100E+03, 0.20929300E+02, 0.48934400E+03, -.63746100E+03, -.65149000E+03, 0.30308400E+02, -.20667200E+02, -.16394500E+03, -.14900700E+02, -.11345100E+03, 0.32179100E+01, -.23428600E+03, -.53832500E+03, -.46594800E+03, 0.11069800E+03, 0.57951500E+03, -.37517000E+03, 0.19224100E+03, 0.79245300E+01, 0.18747400E+03, 0.68420000E+02, 0.21201400E+02, 0.47002500E+02, -.96714800E+02, 0.12749800E+03, 0.24087700E+02, 0.16459200E+03, -.20165100E+02, -.18529700E+02, -.39173700E+01, -.28633900E+00, 0.19898700E+02, -.21650400E+02, -.42899900E+02, 0.75077100E+00, 0.59046800E+01, 0.30778300E+02, 0.33631200E+03, 0.67853700E+02, -.65228800E+01, 0.12689400E+03, -.41683100E+02, -.10117400E+03, 0.37996300E+02, 0.29407800E+01, 0.65855900E+02, 0.25086200E+03, -.18607700E+02, 0.34590200E+02, -.15979000E+02, -.20771600E+03, 0.64729300E+02, 0.20832800E+02 },
        { 0.19157000E+02, -.30896400E+00, -.67896300E+00, -.26427700E+01, 0.22139900E+01, -.33897600E+01, -.23381000E+00, -.16275700E+01, 0.19965000E+01, -.24935400E+01, -.12911300E+01, 0.40889200E+01, 0.75429800E+00, -.39675300E-01, 0.97809800E-01, -.44651400E+00, 0.38340600E+00, -.10448200E+00, 0.23961600E+01, -.16173100E+01, -.27320000E+01, 0.59186700E+00, -.61214100E+01, -.24062900E+01, 0.67963500E-02, -.10604600E+00, 0.62158900E+00, -.17548400E+01, -.43794700E+01, 0.15374800E+01, -.15024100E+01, 0.35494600E+01, 0.70646500E+00, -.91954900E+00, 0.45007700E+00, 0.86808400E+00, -.30298600E-01, 0.13231700E+01, 0.29115100E-01, 0.28707400E+00, -.38931700E+00, -.12283700E+01, -.65105700E+00, 0.23322800E+00, -.15995000E+00, 0.19966400E+00, 0.48532100E+00, -.71413200E-03, 0.76561400E+00, -.62965200E-01, 0.88473000E+00, -.21644200E-01, -.44427200E+00, -.37050300E+00, 0.43480000E+01, -.72889000E+00, -.11924700E+00, -.13450800E+01, 0.45192500E-01, 0.24028200E+00, 0.86823800E-01, -.11202800E+01, 0.35655800E+00, -.31610300E+00, -.71147200E-01, 0.12755900E+01, -.13504500E+01, -.80715500E-01, -.31955100E+00, -.98200300E-03, -.50829800E+00, -.23919100E+00, -.23889200E+00, -.17114100E+00, -.14540600E+01, 0.35496000E+00, 0.14023100E+01, 0.38306400E+01, 0.14036900E+00, 0.15364600E+01, 0.74298700E-01, -.46947900E+00, -.16813900E+01, -.18635200E+01, 0.19069700E+01, 0.36372200E+01, -.72044700E-01, 0.10790400E+01, -.99196500E+00, 0.10460500E+01, -.81353000E-01, -.16748400E+00, 0.15925300E+01, -.52783200E+00, 0.19156600E-01, 0.38570100E+00, 0.23626100E+01, 0.13804600E+01, 0.22345400E+01, 0.14220800E+01, -.33174000E+00, -.26781600E+01, -.13453800E+00, 0.11513600E+01, -.17316800E+04, -.20867400E+03, -.17394300E+04, 0.74847200E+03, -.94350100E+03, -.10132200E+04, 0.78551900E+04, -.39091900E+04, -.28093000E+04, -.39275800E+04, -.20165500E+04, -.16944800E+04, -.12791400E+03, 0.18037700E+04, -.23897400E+04, -.14604900E+04, -.33914600E+04, -.38257100E+03, 0.18876500E+03, 0.80362500E+03, 0.19120900E+03, 0.13504400E+04, -.69819600E+03, 0.98981700E+03, 0.22188000E+04, 0.90962400E+03, -.10445900E+04, 0.18386500E+04, -.12050200E+04, 0.61548600E+03, -.58863900E+03, 0.60746500E+03, -.11713500E+03, 0.18675900E+03, -.17857300E+03, -.11445900E+04, -.35883100E+03, 0.34344300E+03, 0.49287700E+03, 0.49728700E+04, -.24963000E+04, -.36887000E+04, -.24862700E+04, -.56929500E+03, -.89133900E+03, -.41447800E+03, 0.14180000E+04, -.18469900E+03, -.85531400E+03, -.17026100E+04, -.15456300E+04, 0.76741700E+03, -.22410100E+03, 0.77281300E+03, -.96278100E+02, -.19656800E+04, 0.35542000E+03, -.97143100E+03, 0.21610700E+04, -.14545100E+04, 0.33251200E+03, -.10336600E+04, 0.54787900E+03, 0.10232700E+04, 0.51709800E+03, 0.41454500E+02, 0.53862200E+03, 0.57867200E+03, 0.60112200E+02, 0.22862400E+03, 0.48474000E+03, 0.89552100E+03, -.49909100E+03, 0.21392500E+03, -.62156700E+03, 0.24901600E+03, 0.43137300E+03, -.33649200E+02, 0.15103100E+03, -.11227900E+03, 0.20272300E+03, -.87155200E+02, 0.37901600E+03, -.88807800E+02, 0.34675100E+02, -.11769900E+04, 0.44201200E+02, 0.92819600E+02, -.10029400E+03, 0.19178800E+02, 0.33029900E+03, 0.52782500E+03, 0.12876700E+03, -.42418800E+03, -.93102500E+03, 0.53936400E+03, 0.21308900E+03, 0.46541300E+03, 0.23309100E+02, -.15829700E+02, 0.90280400E+02, -.40075100E+03, 0.25190100E+01, -.58843800E+02, 0.53440900E+03, 0.86339400E+03, -.44428700E+03, -.14665100E+04, -.43220800E+03, 0.14157100E+03, -.12489000E+03, -.15748100E+03, 0.25898200E+03, -.95822200E+02, 0.76793400E+02, -.56976300E+03, -.47515500E+04, 0.23937600E+04, 0.25644800E+04, 0.23763600E+04, 0.24443500E+03, 0.11391100E+04, 0.36747200E+03, -.22385200E+04, -.13559100E+04, 0.97157100E+03, 0.14349600E+04, -.67997600E+04, 0.33865500E+04, 0.26289500E+04, 0.33996700E+04, 0.12002700E+04, 0.16293100E+04, 0.13201300E+03, -.18405600E+04, 0.98684000E+03, 0.15159300E+04, 0.24183400E+04, -.13664900E+04, 0.66927600E+03, 0.29194600E+03, 0.68334000E+03, 0.57719500E+03, 0.20503900E+03, 0.38098200E+03, -.28901400E+01, 0.68480300E+03, 0.40342900E+03, -.23731000E+03, 0.17822900E+04, -.92318900E+03, -.22428100E+04, -.89194400E+03, 0.99652000E+02, -.43528800E+03, -.18712100E+03, -.62929900E+02, -.76161600E+03, -.53075300E+03, 0.31074700E+03, 0.28362400E+04, -.14255300E+04, -.91833500E+03, -.14178100E+04, -.35567300E+03, -.63287700E+02, -.72345700E+03, -.34417600E+03, -.11363100E+04, -.26304000E+02, -.87566100E+03, 0.73085500E+02, 0.15279000E+02, 0.36681400E+02, 0.80194800E+01, -.26387100E+02, 0.20696400E+02, 0.16416900E+03, 0.85626400E+01, -.33857400E+02, 0.34678000E+03, -.37537300E+03, -.57093100E+03, 0.27309500E+03, -.14169000E+02, -.26552000E+03, 0.52678800E+03, 0.65737100E+02, -.73781200E+01, -.14650200E+03, -.40282800E+03, 0.51730000E+02, -.28836200E+03, 0.10360300E+03, 0.47507300E+03, 0.22446300E+03, 0.33256600E+03 },
        { 0.53953000E+01, -.10962400E+00, -.17242700E+00, 0.10895000E+01, 0.53335200E+00, -.43324600E+00, -.69648600E+00, -.32922300E+00, 0.31749100E+01, 0.81980800E-01, 0.56556300E-01, 0.47298200E+00, -.10216600E+00, -.44763800E-02, 0.18495300E+00, -.11211500E+00, 0.50589100E+00, 0.34790400E+00, 0.35063000E+00, -.34113600E+00, 0.29030000E+00, -.14206600E+00, 0.25485300E+01, 0.35261200E+00, -.88477100E-01, -.63439100E-01, -.20783000E+00, -.54896900E+00, -.18330500E+00, 0.61578500E+00, -.17917700E-01, 0.40477500E+00, 0.22928200E-01, -.72549800E+00, 0.10796200E+01, 0.16859300E-01, 0.10118500E+00, 0.36059300E+00, -.11284800E+00, -.53291200E-01, 0.19356700E+00, 0.13776700E+00, 0.59835200E-02, -.11632400E+00, 0.83831500E+00, -.11427100E-01, 0.13428600E+00, -.34642600E-01, -.53322500E-01, 0.10533300E+00, 0.63715000E-01, -.76691700E+00, -.15992700E+00, -.27173200E+00, 0.18559100E+01, -.31037200E+00, 0.23706600E-01, -.30556500E+00, -.43971500E+00, 0.94855100E-01, 0.27772400E+00, -.18316300E+00, -.34651100E+00, 0.25699700E+00, 0.48028400E+00, 0.37735500E-01, 0.38552500E+00, 0.22593100E-02, 0.13511700E+01, -.53588200E-02, -.19987500E-01, -.36772400E-01, 0.17000700E+00, -.29934800E-01, -.52656500E+00, -.25165100E+00, 0.33385800E+00, -.23955900E+01, 0.33963400E+00, -.43721600E-01, -.18336400E-01, -.59489700E+00, -.36078400E+00, 0.35616700E+00, -.34758000E-01, 0.78852100E+00, 0.27496400E-01, 0.62372700E-01, 0.19279700E+00, -.24656700E+00, -.13609400E+00, -.66390100E-01, -.21826500E+00, -.35292400E-01, 0.12146300E+00, 0.23220800E+00, -.62644700E+00, -.38127800E+00, -.12429600E+01, -.16985900E+00, -.25319900E-01, 0.40787600E+00, -.63675600E-02, 0.80452400E-02, -.28098500E-01, 0.13269000E+04, 0.23412700E+04, 0.87177600E+03, -.17172200E+03, -.34024900E+03, -.81880200E+03, 0.41042300E+03, 0.43291200E+03, 0.40938700E+03, 0.22624900E+03, 0.14309600E+03, 0.14052400E+02, -.35581600E+03, -.14955000E+02, 0.13121700E+03, 0.23713500E+03, -.77227800E+02, 0.38148600E+02, 0.39729100E+03, 0.38656200E+02, -.10932100E+03, -.17299800E+03, 0.26041800E+03, 0.48825600E+03, 0.89620700E+02, -.23194200E+03, -.10862000E+04, 0.73780500E+03, -.37517000E+03, -.54216400E+03, -.37073100E+03, -.20299200E+03, 0.88050200E+02, -.18209700E+03, 0.90609000E+02, 0.30862500E+02, -.37744400E+01, 0.45647800E+03, 0.34183800E+03, -.17205100E+03, 0.13030300E+03, -.17102600E+03, -.61402100E+02, 0.59956200E+02, -.35682400E+01, 0.73251100E+02, -.93653700E+02, -.14690900E+02, 0.11614800E+03, -.28057500E+03, 0.12204200E+03, 0.98747200E+02, 0.14034900E+03, 0.13944000E+03, 0.21839500E+03, 0.87308200E+03, 0.16015300E+04, 0.56619100E+03, 0.67877900E+02, -.14394000E+03, 0.94337600E+01, -.12248300E+01, 0.69233100E+02, -.48876900E+01, -.86265300E+01, 0.32261100E+02, -.94728500E+02, -.42007000E+02, 0.20157100E+03, 0.26335000E+02, 0.57422100E+02, 0.56863600E+03, -.27070200E+03, -.16216200E+03, -.28398300E+03, 0.33783300E+03, 0.98851800E+02, -.21599300E+03, 0.25594800E+02, -.20420100E+03, 0.10250600E+03, -.49582100E+03, -.37643500E+03, 0.17440800E+03, 0.20233200E+03, 0.18834300E+03, 0.23723200E+03, -.35907000E+02, 0.13796300E+03, -.24906300E+03, -.16313800E+03, 0.14054700E+03, -.26331100E+03, -.54961200E+03, 0.28378800E+03, 0.17460000E+03, 0.27486000E+03, -.52799300E+02, -.15020900E+03, 0.12310200E+03, -.99105500E+02, 0.19786000E+03, -.13026900E+03, 0.30201000E+03, -.19059800E+03, 0.86681600E+02, 0.32061100E+02, 0.95616800E+02, 0.10162500E+03, -.19598200E+02, 0.13909300E+02, -.18842700E+03, -.46544900E+02, 0.11557700E+03, -.26136200E+03, 0.13712200E+02, -.50673600E+01, 0.30761500E+02, -.72275200E+01, 0.26611200E+03, 0.10938100E+03, -.31547600E+03, -.39701800E+02, 0.35210800E+02, 0.12402500E+03, -.43672300E+03, 0.72618200E+03, -.36175900E+03, -.51894400E+03, -.36295800E+03, -.19164300E+03, -.54199800E+02, -.11793300E+03, 0.20012500E+03, 0.11232900E+03, -.73742700E+02, -.22473300E+03, 0.13239600E+04, -.64578100E+03, -.56349200E+03, -.66200400E+03, -.18288900E+03, -.30946900E+02, 0.81557400E+02, 0.54010800E+03, -.19869800E+03, -.48663700E+02, -.57650900E+03, 0.29013400E+03, -.13660900E+03, 0.34303300E+03, -.14458500E+03, 0.22091400E+03, 0.34051600E+03, -.25810200E+03, 0.45036000E+02, -.86762600E+02, 0.24769500E+03, 0.86127100E+02, -.67319200E+03, 0.34513300E+03, 0.42917700E+03, 0.33640000E+03, 0.46978700E+02, -.10080200E+03, 0.35425100E+03, 0.41969000E+03, 0.48668100E+03, -.12174900E+03, 0.10726500E+03, 0.19387800E+02, 0.23687900E+02, -.48222000E+01, 0.11428200E+02, -.35250500E+01, 0.28664400E+01, -.31877800E+02, 0.71307400E+01, 0.37698400E+01, 0.12861400E+03, -.10076900E+03, 0.17889300E+03, 0.32541900E+02, -.11620300E+03, 0.69855000E+02, 0.15423400E+03, 0.22254800E+02, 0.62914800E+01, 0.89362300E+01, -.14500900E+03, 0.37125400E+02, 0.31751400E+02, -.56090400E+02, -.78310200E+02, -.13099900E+03, 0.13638100E+03 },
        { -.18813000E+02, 0.53646600E+00, 0.63918600E+00, -.18064300E+01, -.20033600E+01, 0.38077600E+01, -.15197000E+01, 0.10950500E+01, -.47951000E+00, 0.29964400E+01, -.18760800E+00, -.33188900E+01, 0.44674100E+00, 0.48431800E-01, -.23125000E+01, 0.82791900E+00, -.12484900E+01, -.10965500E+01, -.10808500E+01, 0.93412400E+00, -.90234100E+00, 0.88573300E-01, -.17360200E+02, -.76752500E+00, -.23872100E+00, 0.97683500E-01, 0.34813300E+00, 0.14553700E+01, 0.72798100E+00, -.48865400E+00, 0.98713700E+00, 0.92195900E+00, -.93186900E-01, -.93719400E+00, 0.50108100E+01, 0.63375000E+00, 0.60267200E+00, 0.37208400E+01, 0.10158100E+00, 0.13388800E+01, -.93336000E+00, -.23441500E+01, -.12780200E-01, 0.23483900E+01, -.44941900E+00, 0.31136600E+00, -.60906100E+00, -.10759800E+00, 0.12529200E+00, -.39814100E+00, 0.45404200E+00, 0.50014000E+01, 0.72332100E-01, -.44151200E+00, -.25450000E-01, -.16567100E+00, 0.60746900E-01, -.64923400E+00, -.24684000E+01, 0.31302100E+00, 0.14221800E+00, 0.18953400E+00, -.10856100E+01, 0.27892300E+00, 0.53597900E-01, -.45398200E+00, -.14517500E+01, 0.11379300E+00, -.18730300E+01, -.66065100E-02, 0.58242200E+00, -.47903700E+00, -.21827800E-02, 0.45985900E-01, 0.23546400E+01, 0.83919200E-01, -.54996400E-01, 0.26369300E+00, -.21823800E+01, 0.66121000E+00, 0.33058200E-02, 0.91749900E-01, 0.65043400E+00, -.59246300E+00, 0.21717600E+00, -.59348400E+01, 0.46617300E-01, 0.14884200E+00, 0.31197100E+00, -.56819200E-01, 0.69262600E-02, 0.75196600E-01, -.27387000E+00, 0.28383200E-01, 0.10967800E+00, -.38397400E+00, 0.11561100E+00, -.40375100E+00, -.42171900E+00, -.52371400E-01, 0.14222600E+00, 0.73065200E-01, -.15050500E+01, -.20715000E+01, 0.48784500E+00, 0.19272400E+01, 0.37777700E+04, -.54912700E+03, 0.28484500E+03, -.22429600E+04, -.39838600E+04, 0.19565900E+04, 0.73646500E+03, 0.19917100E+04, 0.16576400E+04, 0.10845400E+04, -.19608600E+03, -.75144500E+03, 0.16557900E+04, 0.82951300E+03, 0.16939400E+04, 0.41683100E+03, -.21436700E+03, 0.80514400E+03, -.20892100E+03, 0.23331700E+04, 0.35514600E+03, 0.79169200E+02, 0.95451800E+03, -.73289000E+03, 0.12838000E+02, 0.64873800E+03, -.26592400E+04, 0.13340900E+04, 0.68680000E+03, 0.13319300E+04, -.36906700E+03, -.78285800E+03, 0.55470600E+03, -.83986800E+03, 0.80837400E+03, -.12865300E+03, 0.12890200E+03, 0.43604900E+04, -.21828800E+04, -.22154800E+04, -.21794800E+04, -.32982200E+03, -.78454400E+03, -.17927900E+03, 0.21002400E+04, -.43592600E+02, -.83918300E+03, -.13167800E+04, 0.29119300E+04, -.14115400E+04, -.24827000E+03, -.14597400E+04, -.74662000E+03, -.59182200E+03, 0.44712500E+03, 0.34657400E+04, -.10312200E+04, -.41672300E+03, -.22495200E+04, 0.24613000E+04, -.12349300E+04, -.22802800E+04, -.12293000E+04, -.76353300E+03, 0.48234800E+03, -.83920700E+03, -.12025400E+04, -.55947000E+03, 0.10839000E+03, -.11086200E+04, -.17123400E+04, 0.85554000E+03, 0.64403100E+03, 0.85357300E+03, -.87348000E+03, -.57800700E+03, 0.10887400E+04, 0.76101400E+03, 0.63575200E+03, -.54811000E+03, 0.22056700E+04, 0.40265900E+04, -.20019300E+04, -.24983500E+04, -.20142200E+04, -.54146000E+03, 0.27020000E+03, -.68792200E+03, 0.12923900E+04, -.73771700E+03, 0.23251600E+02, 0.13698700E+04, 0.48557600E+03, -.30313000E+03, 0.74008500E+03, -.24316300E+03, 0.22498800E+03, 0.68511000E+03, -.50175400E+03, -.11426900E+03, -.22097100E+03, 0.54181700E+03, 0.85846000E+02, 0.12940700E+04, -.63495400E+03, -.15496900E+04, -.64956500E+03, 0.15994700E+02, 0.36289800E+02, -.57434800E+02, 0.74267300E+03, 0.41273500E+02, -.86159600E+02, 0.11982200E+04, -.50759000E+04, 0.25304300E+04, 0.19237100E+04, 0.25408300E+04, 0.79101100E+03, 0.59745300E+03, 0.99056100E+03, -.12969600E+04, 0.12147700E+04, 0.62121700E+03, 0.88905300E+03, 0.33066100E+04, -.16567600E+04, -.16736000E+04, -.16543200E+04, -.69127700E+03, -.11358200E+04, 0.57730800E+03, 0.92631500E+03, -.25615500E+03, -.76629700E+03, -.15797100E+04, 0.12017000E+04, -.64213700E+03, -.18720400E+03, -.60165300E+03, -.65363600E+02, -.10158200E+03, -.92201700E+03, 0.63544200E+03, -.11275800E+04, 0.19214700E+03, -.21232600E+04, 0.25009500E+04, -.12552500E+04, 0.14027800E+04, -.12546500E+04, -.46969700E+03, -.13330600E+04, 0.22110300E+03, 0.29170000E+03, -.13581800E+04, -.91137200E+03, -.27910500E+03, -.43696300E+04, 0.21748900E+04, 0.10684600E+04, 0.21863900E+04, 0.52091100E+03, 0.81942500E+02, 0.89782700E+03, -.33444900E+03, 0.93869400E+03, 0.18681900E+03, 0.15984200E+04, -.85853700E+02, -.26622300E+02, -.60145000E+02, -.37309900E+02, 0.58210900E+02, -.42853600E+02, -.33895900E+02, -.17296100E+02, 0.46344900E+02, -.13137200E+03, 0.76363500E+02, 0.83900800E+03, 0.14648000E+03, 0.42061200E+03, -.27470300E+03, -.39637700E+03, 0.33529500E+03, -.14713100E+02, -.12828500E+03, 0.10868800E+04, 0.10389700E+01, 0.60159500E+02, 0.48826200E+02, 0.35871700E+03, 0.63695900E+03, -.88641700E+02 },
        { -.64140100E+00, 0.21846800E-01, 0.22523300E-01, -.71236000E-01, -.53843000E-01, 0.11803300E+00, 0.38681200E-01, -.11664400E+00, 0.46929700E-01, 0.13779800E-01, -.52455900E-02, 0.96658400E-01, 0.19029700E-01, 0.83728500E-03, -.69099200E-01, 0.13672300E-01, 0.77329800E-01, 0.49217300E-03, -.34547900E-01, 0.10584900E+00, 0.12747000E+00, 0.10164700E-02, -.73138000E+00, -.12294400E+00, -.52061800E-01, -.28090300E-01, 0.81062700E-02, -.96288600E-01, -.27473200E+00, -.67760700E-02, 0.18597700E-01, 0.63097200E-01, 0.10286500E-02, 0.26986300E-02, 0.58120500E-01, -.99184500E-03, 0.11128600E-01, 0.23978800E-01, -.19448300E-01, 0.50925400E-01, 0.54251900E-02, -.11993100E+00, 0.89974100E-01, 0.36687200E-01, -.73768800E-01, -.99776800E-02, -.77513700E-02, -.33331800E-03, 0.18751400E-01, -.22455000E-02, -.81624000E-01, 0.24557400E+00, -.10362300E-01, -.37754300E-02, 0.36927600E+00, -.27934200E-01, 0.61212800E-02, -.70696500E-01, -.20837100E-01, 0.50285100E-02, 0.30953900E-01, 0.41441300E-01, -.64079400E-01, -.31924800E-02, 0.29753100E-01, 0.47327600E-02, -.88317300E-01, -.12106200E-02, 0.32009600E-02, -.48880500E-03, -.85605400E-02, -.24978100E-01, 0.15054000E-02, 0.15272900E-01, -.10695700E+00, 0.32090200E-01, 0.80522600E-02, -.23303800E+00, 0.12247500E+00, 0.11824800E+00, 0.58680500E-03, -.63949700E-01, -.20511600E-02, -.66097200E-01, 0.75173700E-01, 0.48767500E+00, 0.19875100E-01, -.58584100E-02, -.60898200E-02, 0.35763100E-01, -.73433200E-01, -.11598400E-02, 0.23179100E+00, -.45000400E-02, 0.11656600E-01, -.44012100E-01, 0.30242000E-01, 0.18001400E-01, 0.14282400E+00, -.28519700E-01, 0.28364700E-02, -.50789000E-01, 0.21981300E-02, -.33814000E-01, 0.42499200E-02, -.10375300E+00, 0.29587400E-01, 0.18582500E+03, -.47414300E+02, -.11293500E+03, 0.13677700E+03, -.68056900E+02, -.68112600E+02, -.68385300E+02, -.68505400E+02, -.53646800E+02, 0.47983700E+02, 0.25898400E+02, -.81470000E+02, -.34208800E+02, -.79929700E+02, 0.71678200E+02, -.36385000E+02, -.10734400E+03, -.35816300E+02, -.31384200E+02, 0.10856700E+02, -.17608300E+02, 0.33983500E+01, -.11851800E+02, 0.90276200E+01, -.41622900E+01, 0.10321300E+03, -.51928600E+02, -.22965300E+02, -.51990100E+02, -.18614700E+02, 0.98639000E+01, -.18692400E+02, 0.15128400E+02, -.19387400E+02, 0.90323400E-01, -.33784200E+02, -.69938300E+02, 0.34329100E+02, 0.88298100E+01, 0.34925800E+02, 0.29288600E+02, 0.33677800E+02, -.46979100E+01, -.37622100E+02, 0.75011400E+01, 0.34155900E+02, 0.36414400E+02, -.66534900E+02, 0.32837200E+02, 0.10052600E+02, 0.33385300E+02, 0.33016800E+02, 0.46912900E+02, -.36620900E+02, -.32176000E+02, 0.13333800E+03, 0.69995000E+01, -.65610400E+02, -.68708500E+02, 0.36237200E+02, 0.52511300E+02, 0.34281500E+02, 0.26533000E+02, -.54869400E+01, 0.57843400E+01, 0.13855400E+02, 0.32730900E+02, -.26014000E+01, 0.31065800E+02, 0.54879500E+02, -.27106500E+02, 0.19349600E+02, -.27298200E+02, 0.62700700E+02, 0.18021400E+02, -.40122900E+02, -.19023100E+02, -.20962000E+02, 0.20342700E+02, -.36874400E+02, -.34310200E+02, 0.14075600E+02, 0.76728000E+02, 0.17207000E+02, 0.28325900E+02, -.19337200E+02, 0.16707400E+02, 0.59247300E+01, 0.19111300E+02, -.20773100E+02, -.19711600E+02, -.40613600E+02, 0.24569200E+02, 0.14729200E+01, 0.20329100E+02, -.77919000E+01, -.24134700E+02, 0.13283100E+02, -.16125500E+02, 0.75285700E+01, -.15123600E+02, 0.31423500E+02, -.15405000E+02, 0.59255300E+01, 0.52604000E+02, 0.78388900E+01, 0.17281600E+02, -.81585700E+01, 0.24601500E+01, -.24856000E+01, 0.12111900E+01, -.12024300E+02, -.32650500E+02, 0.77470900E+02, -.37853300E+02, -.31240100E+02, -.38892200E+02, -.32992200E+02, -.17354800E+02, -.22866000E+02, -.45028000E+01, -.38791500E+02, -.18655700E+02, -.25960500E+02, -.13918100E+03, 0.69205000E+02, 0.97993500E+02, 0.69646300E+02, 0.35913000E+02, 0.46556800E+02, -.31712600E+02, -.42500100E+02, 0.40163300E+02, 0.30083400E+02, 0.66632900E+02, -.94191500E+02, 0.47133500E+02, 0.42396500E+02, 0.47112100E+02, 0.10488900E+01, -.21615800E+02, 0.51690100E+02, 0.43093400E+02, 0.13371100E+03, -.45856000E+02, 0.83532900E+01, -.92785200E+02, 0.46031400E+02, -.14191300E+02, 0.46608900E+02, 0.35332000E+02, 0.70774300E+02, -.43956900E+02, -.52371900E+02, 0.23309300E+02, 0.63367200E+02, 0.58418700E+02, 0.13761500E+03, -.68634000E+02, -.44883600E+02, -.68898400E+02, -.17930900E+02, -.61639700E+01, -.29207200E+02, 0.98441400E+01, -.15940300E+02, -.67993500E+01, -.64644000E+02, 0.32515600E+01, 0.13745000E+01, 0.18777200E+01, 0.13070000E+01, -.30535800E+01, 0.17389200E+01, -.65838500E+00, 0.81335500E+00, -.16654000E+01, 0.14278700E+02, -.16668300E+02, -.50262300E+02, -.36139700E+01, -.16068400E+02, 0.33347100E+01, 0.23932500E+02, -.49751900E+01, -.35663700E+01, 0.32520100E+01, -.32371200E+02, -.18072300E+01, -.28158800E+01, -.70040800E+01, 0.27670500E+01, -.20910100E+02, 0.11361800E+02 },
        { -.10221500E+02, 0.25268400E+00, 0.61880600E+00, -.58861700E+00, -.60927400E+00, 0.16845600E+01, -.16809200E+01, 0.10409000E+01, 0.97846200E+00, 0.89874200E+00, -.17833300E+00, -.72403200E+00, 0.39849900E+00, -.41593200E+00, 0.95002200E+00, 0.36364000E+00, 0.88391000E-01, 0.63309300E+00, 0.38110600E+00, 0.31793300E-01, -.36420900E+00, -.12736300E+00, 0.80095400E+01, 0.95374200E+00, 0.45773500E+00, 0.78264700E-01, 0.20557700E+00, 0.39743000E+00, -.32735300E+00, -.39511400E+00, -.11324300E+01, -.67781000E+00, 0.90501000E-01, 0.41163500E+00, -.60612300E+01, 0.58182700E+00, -.59756400E-01, -.12797200E+01, 0.27722000E+00, 0.52733700E+00, -.32786300E+00, -.34553900E+01, 0.31638300E+00, 0.71955000E+00, -.10631600E+01, 0.43968600E+00, 0.65824800E+00, 0.96650500E-02, 0.16471500E+00, 0.12043600E+00, -.24498300E+01, 0.69351300E+01, -.47400000E+00, 0.43538600E+00, 0.42180500E+01, -.16779500E+01, 0.57249500E-01, -.17855400E+01, -.32646900E+00, 0.18448700E-01, -.24856600E+00, 0.55228600E-01, -.85567600E-02, 0.37033300E+00, 0.46156100E+00, -.32232400E+00, 0.30062600E+01, -.37436500E-02, 0.46699300E+01, -.82953700E-02, 0.11788300E-01, 0.35261300E+00, 0.63635100E+00, 0.32474600E+00, -.78839500E+00, -.24246600E+01, -.15865100E+00, -.74490400E+01, -.33838000E+00, 0.20526800E+01, 0.61209500E-01, -.15981800E-01, -.11156000E+01, 0.22804500E+01, 0.21847700E+01, 0.83429000E+01, 0.78705000E+00, 0.14856400E-01, -.21778600E+00, 0.49238800E+00, 0.20650600E+00, -.34550100E-01, 0.29127700E+01, -.37096200E+00, -.14525500E+00, 0.10798700E+01, 0.87120600E+00, 0.50589900E+00, 0.25319700E+01, 0.36559700E-01, -.23828000E+00, -.17284200E+01, -.97454700E-01, 0.77544600E+00, 0.42033700E+00, 0.24660300E+00, 0.29154800E+00, -.68326900E+00, -.43943600E+03, 0.44172900E+04, -.47562300E+03, 0.22003100E+03, -.67005300E+03, 0.23792400E+03, -.40590700E+03, -.43545800E+02, 0.17750600E+03, -.89815200E+02, 0.17097600E+03, -.97789000E+02, 0.67771200E+03, -.71415400E+03, 0.36850000E+03, -.14511600E+04, 0.35712400E+03, -.76412500E+03, -.12912600E+03, -.19876500E+03, -.12375400E+04, 0.20272500E+03, 0.15081800E+03, -.15879100E+03, 0.92533400E+01, -.14981700E+02, 0.61663500E+03, -.54457700E+01, 0.44921200E+03, 0.31450200E+03, 0.23562800E+03, 0.81457100E+03, 0.76067200E+02, 0.10885300E+03, -.34178400E+03, -.41273100E+03, 0.20674300E+03, -.60779500E+02, 0.20643300E+03, -.20311200E+03, -.18098400E+03, 0.29146200E+03, -.39803900E+01, 0.52472400E+03, -.91875800E+02, -.95008800E+03, -.28488400E+04, 0.14314200E+04, 0.13956700E+04, 0.14254600E+04, 0.31847400E+03, -.11087300E+02, 0.60656500E+03, -.37646900E+03, 0.29327500E+03, -.24161400E+03, 0.37308300E+04, 0.11941100E+03, -.59211600E+02, 0.73154100E+03, -.59647300E+02, 0.27065800E+03, -.18384100E+03, 0.12778700E+03, 0.36610800E+03, 0.70442600E+02, -.10166700E+03, 0.74644200E+02, 0.69835700E+03, -.30964700E+03, -.12804300E+03, -.34931100E+03, -.41065100E+03, 0.17916800E+03, -.58846000E+03, -.68665400E+03, -.24456400E+03, 0.19959800E+03, -.13378100E+04, -.38583200E+03, 0.20126600E+03, 0.74139400E+03, 0.19285100E+03, -.63072900E+02, -.14297900E+03, -.32694100E+02, -.20445900E+02, 0.23088000E+03, 0.79187900E+02, -.18386700E+04, 0.94792900E+03, -.48271700E+03, -.10224100E+04, -.47400500E+03, 0.86830900E+02, 0.52834600E+02, -.19577700E+03, 0.19921500E+03, -.21968300E+03, 0.43838200E+02, -.93953600E+03, 0.24144900E+03, -.12363900E+03, 0.41980400E+03, -.12082700E+03, -.27095100E+03, -.24548800E+03, 0.27040600E+02, 0.39120200E+03, 0.28913200E+03, -.31567700E+02, -.10622900E+04, -.58673400E+03, 0.28180600E+03, 0.27745700E+03, 0.29351600E+03, -.90654400E+02, 0.29873600E+03, -.30657300E+03, -.33486600E+03, -.19305900E+03, 0.21480300E+03, 0.24757500E+04, -.44260700E+03, 0.21758000E+03, 0.56395700E+03, 0.22124300E+03, 0.33213800E+03, 0.19494900E+03, -.21794200E+03, -.24608400E+03, -.13325600E+03, 0.14474300E+03, 0.36518700E+03, 0.33060900E+04, -.16365900E+04, -.15689000E+04, -.16527100E+04, -.33074300E+03, 0.27572000E+03, -.90050900E+03, -.50334600E+02, -.79303000E+03, 0.14006100E+03, 0.84552500E+03, -.18581600E+04, 0.95295200E+03, -.24497200E+03, 0.92903900E+03, -.16757500E+03, 0.46299900E+03, 0.19510200E+03, -.30524900E+03, 0.71988600E+03, 0.41832800E+03, -.12881000E+04, 0.43437800E+03, -.21201500E+03, 0.25214400E+03, -.21703900E+03, -.88536800E+01, 0.76917400E+02, -.23414000E+03, -.35416900E+02, -.19873800E+03, -.36699500E+01, 0.16670900E+03, -.49262600E+01, -.14001900E+02, -.79544800E+01, -.44805300E+01, -.77660900E+01, 0.92433800E+01, 0.28630300E+02, -.60352200E+01, 0.94986700E+01, -.31794600E+03, 0.51258700E+02, -.48727700E+03, -.14353800E+03, -.19955300E+03, -.49338700E+02, -.68702800E+02, -.61352900E+02, 0.35547300E+02, -.16716400E+03, -.11657100E+03, 0.77970300E+02, -.62716300E+02, -.43365500E+01, -.48335000E+03, -.35212100E+03, -.31909100E+03 },
        { 0.30049700E+02, -.15792400E+01, -.50763000E+00, -.30181900E+00, 0.82727000E+00, -.34477200E+01, 0.17704400E+00, -.63902600E+00, 0.11037700E+01, -.25024800E+01, 0.33159600E-01, 0.21528900E+01, -.29143600E+01, -.48208300E+00, -.96572300E+00, -.30622400E+00, -.14146400E+00, -.47895900E+00, 0.14088300E+01, 0.33893500E+00, 0.75261200E+00, 0.49172200E+00, -.24404400E+02, -.31412500E+01, -.35564800E+00, 0.83378000E-01, -.16546500E+00, -.15674000E+01, -.15662800E+01, 0.15946900E+01, 0.42688500E-01, 0.19740400E+01, -.42887200E-01, -.30948000E+01, 0.60438400E+01, 0.86925200E+00, -.72328700E-01, 0.29676700E+01, -.70008600E+00, 0.15428300E+01, -.14869900E+01, -.18920900E+01, 0.37923000E+00, 0.37752200E+01, -.36945600E+01, 0.46531400E+00, -.57897200E+00, 0.29266500E-01, -.37518800E+00, -.42461200E+00, -.35025500E+01, 0.11144900E+02, -.83955200E+00, -.14935900E+01, 0.32534200E+00, 0.34883700E+00, -.32047900E+00, 0.37146900E+00, -.17820300E+00, 0.32423200E-01, 0.46997200E+00, 0.13499300E+01, -.10100000E+01, 0.81289200E-01, -.84925500E+00, -.31478400E+00, -.18984700E+01, 0.38972600E-01, -.19715100E+00, -.11835900E-01, 0.21204000E+00, -.90908800E+00, -.39777000E-01, -.14317900E+00, 0.60466000E+00, 0.76515900E+00, -.77794000E+00, -.12675100E+02, 0.19566600E+01, -.44921000E+00, -.59730300E-01, -.65166900E+00, 0.71124300E+00, 0.16833700E+01, -.19273700E+01, -.18880800E+02, -.51264800E+00, -.21033100E+00, 0.23603000E+01, -.37531800E+00, -.16731700E+00, -.46792900E-01, 0.79078400E+01, 0.11411700E+01, -.27455400E+00, 0.19879900E+01, 0.22757900E+01, 0.61318300E+00, -.16399200E+01, 0.17617500E+01, -.34016200E+00, -.19001400E+01, 0.45415100E+00, 0.20758600E+01, -.60375800E+00, -.19681500E+01, 0.29431500E+00, 0.14696800E+02, -.11833000E+01, 0.13105500E+05, 0.16666700E+04, -.91519300E+03, -.66206700E+03, -.83319300E+03, -.16914900E+04, -.53325600E+03, -.36039200E+03, -.17265200E+03, -.51052300E+03, -.68514300E+03, 0.10271600E+03, -.41540300E+04, 0.20875000E+04, 0.22390000E+04, 0.20768800E+04, -.45707000E+03, -.23666700E+04, 0.25904300E+04, 0.22273800E+04, 0.25847700E+04, -.18143000E+04, -.20271600E+04, -.29892400E+04, 0.14919900E+04, 0.89243700E+03, 0.14989300E+04, 0.12025000E+04, 0.11010300E+04, 0.25302500E+03, -.15634400E+03, 0.26751400E+03, 0.70702600E+03, 0.14739100E+04, 0.97526200E+04, -.48636500E+04, -.41943300E+04, -.48758100E+04, -.18608600E+04, -.19632900E+04, -.29889600E+03, 0.31223500E+04, -.13010100E+03, -.20613300E+04, -.46898900E+04, -.65981300E+04, 0.31542600E+04, 0.29358400E+04, 0.32995200E+04, 0.65064800E+03, -.76120200E+03, 0.17671200E+04, -.77799400E+03, 0.17684100E+04, -.60179900E+03, 0.10796600E+05, -.61659300E+03, 0.29757100E+03, 0.21204200E+04, 0.30905000E+03, -.33105700E+02, 0.44830800E+03, 0.52643600E+03, 0.13313200E+03, 0.10220300E+04, 0.42570300E+03, 0.15010000E+04, 0.17730100E+04, -.84310300E+03, -.18832700E+04, -.88799600E+03, -.44171000E+03, 0.44528300E+03, -.91363800E+03, -.12259900E+04, -.66750000E+03, 0.55333700E+03, -.34066400E+04, -.23848900E+04, 0.11293500E+04, 0.20674100E+01, 0.11918800E+04, -.22071000E+03, -.16817300E+03, 0.35418500E+03, -.67197200E+03, 0.31651400E+03, 0.13809300E+04, -.58453300E+04, 0.39784700E+03, -.27061500E+03, -.10380500E+04, -.19917100E+03, -.99419900E+02, -.42521600E+03, 0.14126000E+03, 0.12311400E+03, -.25197800E+03, -.40995600E+03, -.13298100E+04, 0.78706900E+03, -.44423000E+03, -.13570200E+04, -.39492900E+03, -.99358300E+03, -.60665800E+03, 0.93045700E+02, 0.68447900E+03, 0.53006500E+03, 0.74134800E+03, -.41065500E+04, -.76511400E+04, 0.38214000E+04, 0.42180300E+04, 0.38272300E+04, 0.10301400E+04, 0.28146300E+04, -.94405200E+03, -.31267500E+04, -.10528900E+04, 0.26212600E+04, 0.62728800E+04, -.29292700E+04, 0.14796400E+04, 0.18128800E+03, 0.14640400E+04, 0.72026600E+03, 0.13264700E+04, -.38914100E+03, -.91174600E+03, 0.26743000E+03, 0.13076900E+04, 0.15904300E+04, 0.83468700E+04, -.40407700E+04, -.42681200E+04, -.41731100E+04, -.18225000E+03, 0.18328100E+04, -.26815200E+04, -.33945600E+03, -.26766100E+04, 0.19330400E+04, 0.24374600E+04, 0.18647300E+04, -.89121300E+03, -.12393900E+04, -.93438700E+03, 0.48997800E+02, -.49888300E+02, 0.23139800E+03, 0.66074600E+03, -.61791800E+03, -.16171100E+03, -.48094300E+04, 0.23365000E+04, -.11137400E+04, -.20815600E+03, -.11673400E+04, -.50015900E+03, -.35021800E+03, -.35100900E+03, 0.49182800E+03, -.11012900E+04, -.39970000E+03, 0.34836500E+03, 0.74174800E+02, -.35857000E+00, 0.39294800E+01, 0.10979400E+02, -.20236400E+02, 0.67434600E+02, 0.24589800E+03, 0.13932200E+02, 0.14328600E+01, -.31297000E+03, -.23985300E+03, -.61590000E+03, 0.20970800E+03, -.26056200E+03, -.36311400E+03, 0.32907800E+03, 0.18817300E+03, 0.17215700E+03, -.59726000E+03, -.60449100E+03, 0.42201600E+03, -.32284100E+03, 0.14128600E+03, -.44252200E+03, -.37561800E+03, -.22334000E+03 },
        { -.60450700E+00, -.40397500E-01, 0.29057600E-01, -.15023200E+01, 0.32874600E+00, 0.16028500E-02, 0.69846300E+00, -.56972200E+00, -.75821300E-01, 0.45375300E-01, -.48597100E-02, 0.36209500E+00, -.11778500E+00, 0.18681900E-01, -.95289000E+00, -.85766900E-01, 0.24010500E-03, -.84234900E-01, -.10025900E+00, -.31976400E-01, -.40975200E-01, 0.57459800E-01, -.36477300E+00, -.12952000E+00, 0.28059800E-01, -.30696100E-01, 0.13511800E-01, -.34692400E+00, -.33825800E+00, -.12733200E+00, -.22431600E+00, -.48212000E+00, 0.93063200E-02, -.95255400E-01, 0.12150800E+00, 0.32690400E-01, 0.29585800E-01, -.92079400E-01, -.40751700E-01, 0.12435700E+00, -.71602700E-01, 0.10864100E+00, -.61444500E-01, 0.10186500E+00, -.10208300E+00, -.11863200E-01, -.39959400E-01, -.52927900E-02, 0.13124900E+00, -.48610000E-02, 0.11106500E-01, -.57023700E+00, -.91223200E-02, -.88836900E-02, -.64023000E+00, 0.18719200E+00, -.12378600E-01, 0.11583000E+00, -.35082600E-01, -.14238300E-01, 0.44153000E-01, 0.62156500E-01, 0.51765700E-02, 0.67970200E-02, 0.10701300E+00, -.64363800E-01, 0.34955800E+00, -.45250200E-02, 0.25003600E+00, 0.19386500E-03, 0.16766400E-01, -.39256400E-01, -.53675400E-01, 0.16824600E-02, 0.10335300E+00, 0.48902500E-01, -.15841600E+00, 0.12121500E+00, 0.25195700E+00, -.23846500E+00, -.14689300E-01, -.37443500E-01, -.58603100E-01, 0.19934300E+00, -.32531100E+00, 0.10775800E+01, -.70013500E-01, -.61890200E-01, 0.39445300E-01, -.82386800E-01, 0.57829600E-01, 0.46150300E-02, -.25401000E+00, 0.14309900E-01, -.18071400E-01, -.24427500E+00, -.23428000E-01, 0.19831600E+00, 0.24871100E+00, 0.92955900E-01, -.57399700E-02, -.21407600E+00, -.21362600E-01, 0.51028000E-01, -.51173800E-01, -.22503300E+00, 0.49691200E-01, 0.16460100E+01, -.11697300E+00, 0.54567400E-01, 0.51159900E+03, -.25628000E+03, -.31878100E+03, -.25578800E+03, -.67609300E+02, -.71078900E+02, -.48001500E+02, 0.16378400E+03, -.82743400E+02, -.65589400E+02, -.12061100E+03, -.10389700E+03, 0.52449600E+02, 0.50010800E+02, 0.51938600E+02, -.91894400E+01, -.26379300E+02, -.13585700E+01, -.96451900E+02, 0.47666700E+02, 0.79924700E+01, 0.21290700E+03, -.21443500E+03, 0.10768600E+03, 0.13990700E+03, 0.10739500E+03, 0.90316700E+02, 0.22701600E+02, 0.21112700E+02, -.60474300E+02, -.43306500E+02, 0.39229200E+02, -.33158100E+02, 0.19734100E+03, -.98818700E+02, -.19901600E+03, -.98637500E+02, 0.66867300E+02, -.59297400E+02, -.20282600E+02, 0.82821900E+02, -.33079800E+02, -.29361800E+02, -.35558000E+03, -.10636600E+02, 0.12584700E+02, 0.33033900E+02, 0.54347100E+01, -.45324200E+01, -.17209100E+01, 0.14414900E+02, -.22980400E+02, -.28509000E+01, -.14960500E+00, 0.46045100E+01, 0.14037900E+03, -.70373500E+02, -.21229600E+02, -.70139300E+02, -.23134800E+02, 0.22395000E+02, 0.59388400E+01, 0.51567000E+02, -.72386800E+02, -.31152600E+01, -.48459400E+01, -.18022300E+03, 0.88051700E+02, -.36733200E+01, 0.90009900E+02, -.35729100E+02, -.95882100E+01, 0.63751800E+02, -.18859500E+02, 0.46765700E+02, -.63173900E+01, 0.68463700E+02, 0.15907700E+03, -.73352000E+02, -.17480800E+03, -.79579900E+02, -.99552700E+02, 0.21031800E+01, -.87546300E+02, -.21622500E+02, 0.55481500E+02, -.38495100E+02, 0.31601600E+02, 0.87786800E+02, -.46244900E+02, -.50284000E+02, -.43917800E+02, 0.95136200E+01, 0.14731400E+02, -.16811900E+02, 0.30039500E+02, -.16155400E+02, 0.14562800E+02, -.52406200E+02, 0.64348200E+02, -.28104600E+02, -.10582800E+03, -.32271700E+02, -.69446500E+02, 0.91596800E+01, -.43085800E+02, -.46122700E+02, 0.18241800E+02, -.16695900E+02, 0.35896500E+02, -.41711500E+03, 0.20762700E+03, 0.23693300E+03, 0.20867100E+03, -.82406400E+02, 0.30866100E+02, 0.12155500E+03, -.12551700E+03, -.22051300E+02, 0.39214400E+02, 0.47177500E+03, -.62854100E+03, 0.31279000E+03, 0.34920200E+03, 0.31423000E+03, 0.91871000E+02, 0.64653800E+02, 0.69406700E+02, -.16033100E+03, 0.28840300E+02, 0.80775200E+02, 0.15473500E+03, 0.20459100E+02, -.17096000E+02, -.60911000E+02, -.10169700E+02, -.21700500E+02, -.54018100E+02, 0.27576500E+02, 0.37353700E+02, 0.38772000E+02, -.58176300E+02, -.20346800E+02, -.98489800E+02, 0.47317500E+02, -.13096300E+03, 0.49099000E+02, -.35823700E+02, -.94797200E+02, 0.12118800E+03, 0.35222800E+02, 0.14189800E+02, -.67427400E+02, 0.53257300E+01, 0.25155100E+02, -.15478700E+02, 0.20040800E+02, -.12492500E+02, 0.73099700E+01, 0.24036600E+02, -.14357100E+02, -.17151000E+02, -.22845800E+02, 0.30651900E+02, -.13399400E+02, -.24165900E+01, -.36578400E+01, 0.44898900E+01, -.38844400E+01, 0.12094800E+00, 0.19039200E+00, -.53123200E+01, -.70927800E+00, -.34061500E+01, -.19736400E+02, 0.21933000E+02, -.30224900E+02, -.20310300E+00, 0.21012800E+02, -.19714700E+02, -.20599900E+02, -.35497300E+01, 0.45167200E+01, -.15239100E+02, -.49857000E+01, -.26061900E+01, -.21029300E+00, 0.34683600E+01, -.26766700E+02, 0.35759900E+02, -.22507200E+02 },
        { 0.14774200E+02, -.74266600E+00, -.27874200E+00, -.28894600E+00, 0.57396500E+00, -.19452200E+01, 0.26475800E+00, -.69409300E+00, 0.86818000E+00, -.14341600E+01, -.48835700E-01, 0.11729200E+01, -.16271500E+01, -.17328700E+00, -.72992400E+00, -.11216800E+00, -.28386700E+00, -.64149800E+00, 0.55758700E+00, 0.49025700E+00, 0.13236600E+00, 0.58990200E+00, -.17030900E+02, -.26347600E+01, -.18411600E+00, -.26814700E-01, 0.20703300E+00, -.90060200E+00, -.11533100E+01, 0.19903500E+01, 0.30664600E+00, 0.14360600E+01, 0.76853300E-01, -.15562500E+01, 0.89473200E+00, 0.56126600E+00, -.14709000E+00, 0.19538000E+01, -.34631800E+00, -.66637300E-01, -.24316800E+00, -.90900100E-01, 0.98068300E-01, 0.83233200E+00, -.47015300E+00, 0.56821900E+00, 0.17112200E+00, 0.12144800E-01, -.38300700E+00, -.84895100E-01, -.93986600E+00, 0.12727100E+01, -.64624900E-02, -.38727300E+00, 0.21051700E+01, -.98883800E+00, -.12957400E+00, -.75326600E+00, -.19235400E+00, 0.10395500E+00, -.38309100E-01, 0.58805800E-01, -.14198900E+00, 0.11878400E-01, -.76698900E+00, -.41213100E-01, -.82174600E+00, 0.20645100E-01, 0.96776800E+00, -.82886300E-02, -.42492400E-01, -.39909000E+00, 0.40517300E-01, -.87504300E-01, -.29996400E+00, 0.42575300E+00, 0.17812400E+00, -.29851000E+01, 0.56095600E+00, 0.81213300E+00, 0.23578900E-01, -.19393700E+01, -.13969300E+01, 0.61629600E+00, -.75765100E-01, -.28940100E+01, 0.41181000E+00, 0.51766600E-01, 0.12872900E+01, 0.32654600E+00, -.34129500E+00, -.11911000E-01, 0.40062400E+01, 0.23141300E+00, 0.17947900E+00, 0.46870500E+00, -.18971600E+00, -.81120300E+00, -.46072500E+00, 0.39386600E-01, -.56121600E-02, -.54990100E-01, 0.14053100E-01, -.38834600E+00, -.14330900E+00, 0.79966200E+00, -.30209800E-01, -.18372100E+01, -.26781800E+00, 0.10299900E+00, 0.31216500E+01, 0.13200000E+03, -.92233900E+02, -.15264300E-01, -.30733700E+03, -.23002800E+03, 0.35802200E+03, -.17322800E+02, -.16933700E+03, -.14079400E+03, -.32683400E+03, 0.42118800E+03, -.19925000E+03, -.15320100E+03, -.21052700E+03, 0.76562100E+02, -.50740200E+02, 0.89892900E+02, 0.56475800E+03, -.46993800E+02, -.17080900E+03, -.25378300E+03, 0.54382500E+03, -.28484400E+03, -.32097300E+03, -.27296000E+03, -.28574700E+03, 0.14117000E+02, -.15981200E+03, -.74749900E+02, -.30695300E+01, -.35516100E+02, 0.63049300E+02, -.17092300E+02, 0.47479300E+00, -.25159800E+03, 0.83950000E+01, -.18545900E+03, 0.92286900E+02, -.31998800E+02, -.11087200E+03, 0.12647400E+03, 0.31277000E+02, 0.84844500E+03, -.35730500E+02, -.42964600E+02, -.10251800E+03, 0.17802900E+02, 0.14585600E+02, -.54722000E+01, -.93109600E+02, 0.19224900E+02, 0.12193500E+03, -.34476600E+02, 0.45429400E+02, -.26942800E+03, 0.15978100E+03, 0.17701100E+03, 0.13446900E+03, 0.19173400E+03, 0.26653500E+02, 0.25177000E+02, -.11066300E+03, 0.17538400E+03, 0.96945600E+02, -.44034100E+02, 0.52693200E+03, -.24743900E+03, 0.13262100E+03, -.26298000E+03, 0.41639400E+03, 0.12139900E+03, -.26154800E+03, 0.11355200E+02, -.83370700E+02, 0.11693200E+03, -.31327600E+03, -.20621000E+03, 0.67789500E+02, 0.70184100E+03, 0.10329400E+03, 0.24233100E+03, 0.16170400E+02, 0.92876700E+02, -.69768900E+02, -.23778600E+03, 0.13811800E+03, -.19404200E+03, -.64651300E+03, 0.36436100E+03, 0.27703100E+03, 0.32335700E+03, -.87234400E+02, -.10724600E+03, 0.10517800E+03, -.24575700E+03, 0.14975900E+03, -.92061500E+02, 0.33561400E+03, 0.29859800E+03, -.17272100E+03, 0.16476800E+03, -.14882900E+03, 0.13388100E+03, -.14451400E+02, -.66925300E+02, 0.66156600E+02, -.25351600E+03, 0.63609900E+02, -.27795400E+03, 0.99324900E+03, -.48885700E+03, -.57390600E+03, -.49716500E+03, 0.68683400E+02, -.18640100E+02, -.33448600E+03, 0.15237300E+03, -.14610700E+03, -.92214500E+02, -.13486100E+04, 0.94415400E+03, -.48689600E+03, -.20430500E+03, -.47188400E+03, 0.53085100E+02, 0.12261900E+03, -.37482300E+03, 0.14240300E+03, 0.36496200E+02, 0.17259300E+02, -.19972800E+03, -.19733100E+03, 0.15476400E+03, 0.10264200E+03, 0.98547400E+02, 0.13133600E+03, 0.23290100E+03, -.44970400E+01, 0.64401400E+01, -.19251000E+02, 0.23272700E+03, 0.10966900E+03, 0.68849900E+02, -.44447400E+02, -.27768500E+03, -.33692000E+02, 0.16946600E+03, 0.41287300E+03, -.46774000E+03, -.27696900E+03, 0.99860600E+02, 0.31189700E+03, 0.21659600E+03, -.18151400E+03, 0.99172400E+02, 0.13075100E+03, 0.90374600E+02, 0.10871300E+02, -.78087700E+01, -.39157400E+02, -.43436400E+02, 0.19333700E+02, -.34347500E+02, 0.92459800E+02, 0.27697100E+02, 0.15088500E+02, -.60444700E+01, 0.15547300E+02, -.10343000E+02, 0.72704800E+01, 0.43706200E+02, 0.93237200E+01, 0.24220200E+01, 0.15465500E+03, -.17386900E+03, -.27198900E+03, 0.27141000E+02, -.97393800E+02, 0.10872600E+01, 0.16908000E+03, 0.84120500E+01, -.12379900E+02, 0.17694700E+02, 0.25234400E+02, 0.15160700E+02, -.44710700E+02, -.25549700E+02, 0.17624600E+03, -.16166000E+03, 0.16318500E+03 },
        { 0.84101800E+01, -.22709500E+00, -.27559200E+00, 0.95510300E+00, 0.64579900E+00, -.74027700E+00, -.10201500E+01, -.42132800E+00, 0.34880100E+01, -.14337900E+00, 0.72943900E-01, -.18024900E+00, -.75223800E-01, -.50621400E-01, 0.18974700E+00, -.23966800E+00, 0.12277400E+00, -.18017000E+00, 0.29198700E+00, -.38566100E+00, 0.40233200E+00, 0.11144600E+00, -.17998700E+01, 0.68178700E-01, -.28431000E+00, -.17433900E+00, -.43098700E+00, -.11919500E+01, 0.16616900E+00, 0.32005500E+00, 0.28842700E+00, -.17972500E+00, 0.59073300E-01, -.41047600E+00, 0.18618800E+01, -.28659500E+00, 0.99835700E-01, 0.68521200E+00, -.45964000E-01, -.80004100E+00, 0.73289800E+00, 0.16724600E+00, -.58342800E+00, -.61267700E+00, 0.11290000E+01, 0.19845900E-01, 0.64675100E-02, -.20839300E-01, 0.44620600E+00, 0.70269000E-01, -.26367300E+00, -.60686500E+01, -.22391000E+00, -.39442700E+00, 0.26501400E+01, -.29801600E+00, -.44453800E-01, -.49588100E+00, 0.13298300E+00, 0.19635100E+00, 0.46509700E+00, -.39140300E+00, -.68399300E+00, 0.13421700E+00, -.23765800E+00, 0.81225700E-02, -.51419800E+00, -.23395900E-01, 0.11241100E+01, -.94557800E-02, -.70948800E-01, -.29200900E-01, 0.17802300E+00, -.19136100E-01, 0.59450600E+00, -.45486800E+00, 0.27472300E+00, -.65771100E+01, 0.22209700E+01, -.31772700E+00, -.22521000E-01, -.13406000E+01, -.80957800E+00, 0.76102900E+00, -.62964800E+00, 0.88089400E+00, -.25539900E+00, -.27569300E+00, 0.56357100E+00, -.15801900E+01, 0.76427200E-01, -.13221700E-01, 0.14908900E+01, -.17309900E+00, -.15220200E+00, 0.20743500E+00, 0.60035900E+00, 0.24743600E+00, 0.17523300E+01, -.12728600E+00, -.56793500E-01, -.56788300E+00, 0.37467500E-01, -.58728000E-02, 0.24187900E-01, -.53992400E+00, -.19219100E-01, -.33849900E+01, 0.33332200E+00, -.43181200E-01, 0.14469500E+01, 0.82705500E-01, 0.10227400E+04, -.44848200E-01, -.11230900E+03, -.11358400E+03, 0.15978000E+03, -.94457700E+02, -.22237900E+03, -.75259100E+02, -.18517000E+03, -.55561400E+03, 0.27349600E+03, 0.20121100E+03, 0.27788300E+03, -.17516500E+03, -.31061600E+03, 0.29361300E+03, 0.33932400E+03, 0.25917700E+03, -.40151900E+03, -.89721900E+03, 0.80647100E+03, -.40346500E+03, -.88726900E+03, -.40417900E+03, -.22859700E+03, 0.98804500E+02, -.11643700E+03, 0.27864700E+03, 0.16627900E+03, -.51427100E+02, 0.79761100E+03, 0.30805500E+03, -.15549000E+03, -.21853500E+03, -.15424900E+03, -.12958200E+03, 0.15386200E+03, -.18978300E+03, -.13543800E+03, -.14028900E+03, 0.93952300E+02, 0.52896900E+03, 0.41037500E+03, -.21907400E+03, -.61260000E+03, -.20526400E+03, 0.26587700E+02, -.57428800E+02, -.11506600E+03, 0.21398400E+03, 0.21571100E+03, -.70802500E+02, -.19133900E+03, -.10430600E+04, 0.52964500E+03, 0.21731300E+03, 0.52118500E+03, 0.73483800E+02, -.17118500E+03, 0.35513900E+03, 0.20177700E+02, 0.30959000E+03, -.11402700E+03, 0.60391000E+03, 0.62872500E+03, -.31175400E+03, -.54604400E+03, -.31368100E+03, 0.33376700E+03, 0.10926400E+03, -.26643500E+03, 0.44641500E+02, -.21612600E+03, 0.53714000E+02, -.52333800E+03, -.26767600E+04, 0.13187100E+04, 0.96807300E+03, 0.13386400E+04, 0.38464300E+03, -.24516000E+03, 0.63855900E+03, -.49137100E+03, 0.79111800E+03, -.29225600E+02, -.92425700E+02, -.24782600E+03, 0.15495700E+03, -.18353300E+02, 0.12403000E+03, -.36478800E+02, -.18276800E+03, 0.13637900E+03, -.53412100E+02, 0.19356600E+02, -.15667900E+03, 0.13371300E+03, -.15665200E+04, 0.76798400E+03, 0.58161300E+03, 0.78390600E+03, 0.30881900E+03, -.14167300E+03, 0.28768300E+03, -.38472000E+03, 0.43414400E+03, 0.34862900E+02, -.46204000E+03, -.49517900E+03, 0.25328500E+03, 0.25908900E+03, 0.24683400E+03, 0.40930500E+03, 0.98905300E+02, -.13647300E+03, -.15023900E+02, 0.19501100E+03, 0.47316000E+02, -.51454900E+03, -.61667000E+03, 0.31093800E+03, -.20767700E+03, 0.30860700E+03, 0.73094800E+02, 0.24332900E+03, -.15067300E+03, -.18144800E+03, 0.37889900E+03, 0.16026600E+03, 0.41015600E+03, -.11489300E+04, 0.58076600E+03, 0.47698800E+03, 0.57434500E+03, 0.13137000E+03, 0.17819700E+03, 0.22086400E+03, -.42430600E+02, 0.25767800E+03, 0.14277000E+03, 0.51299400E+03, 0.39585800E+03, -.19596600E+03, 0.12378000E+03, -.19697000E+03, 0.27679500E+03, 0.40323600E+03, -.44004200E+03, 0.70063500E+02, 0.55199400E+02, 0.18900200E+03, 0.23400000E+03, 0.28996300E+03, -.13772400E+03, -.80012200E+02, -.14541200E+03, -.44780900E+02, -.27029700E+02, -.86986200E+02, -.64646300E+02, -.95021800E+02, -.20956300E+02, -.24160100E+03, 0.69572700E+01, 0.39712100E+02, -.10065200E+02, 0.10814600E+02, -.17712200E+02, 0.95044100E+01, 0.15143000E+02, -.14666000E+00, 0.13356000E+02, 0.45578500E+02, -.56710800E+02, 0.20881200E+02, 0.45822600E+02, -.15404600E+03, 0.81388900E+02, 0.66828800E+02, -.18530000E+02, -.91023600E+01, -.12930300E+02, -.26285900E+03, 0.51804300E+02, -.35057200E+02, -.24093500E+02, 0.44463600E+02, -.10712300E+03, 0.39927600E+02 },
        { -.46820100E+01, 0.12612200E+00, 0.18144500E+00, -.52050900E+00, -.57896100E+00, 0.13082400E+01, -.44027800E+00, 0.26996300E+00, -.55293100E+00, 0.12157400E+01, -.39358400E-01, -.43918100E-02, -.23629200E+00, -.11565600E+00, -.83190100E+00, 0.10632400E+00, -.10655900E+00, -.39600300E+00, 0.29072600E+00, 0.86415500E+00, 0.31019900E+00, 0.28931000E+00, -.11373700E+02, -.14095500E+01, 0.84760200E-02, 0.57229000E-01, -.25920000E-01, 0.46613200E+00, 0.48081200E+00, 0.55549800E+00, 0.54835400E+00, 0.56155800E+00, -.46816200E-01, -.90681900E-01, 0.37814900E-01, 0.18805200E-01, 0.61988400E-01, -.19736300E-01, 0.11898800E+00, -.38320500E+00, -.66184800E-01, 0.46714400E+00, -.61160000E-01, -.18640600E+00, -.10074200E+00, -.26566300E-01, -.75595300E-01, -.24954000E-02, 0.55047400E-01, -.60184900E-01, -.90077100E+00, 0.24773700E+00, -.94055200E-01, -.16006900E+00, -.79950300E+00, -.79129800E-01, 0.21011200E-01, 0.35579600E+00, 0.30747900E-01, -.21078800E-01, -.15956200E+00, 0.16354700E+00, -.55379800E-01, 0.35945800E-01, -.27066000E+00, 0.15033700E-01, 0.13183400E+00, -.13051000E-01, 0.46064600E+00, -.20763600E-02, -.71771600E-01, -.30940200E-01, -.12827400E-01, 0.22616600E-01, 0.27510100E+00, -.33083900E-01, -.10503100E+00, -.14522900E+01, 0.63085000E+00, 0.61351000E-01, 0.14923600E-02, -.50430700E+00, -.34293600E+00, 0.40036700E+00, -.78458600E-01, -.12541200E+01, -.13585900E+00, -.79414000E-01, 0.24979700E+00, -.73108900E+00, -.20148600E+00, 0.98103200E-02, 0.14015500E+01, -.91909200E-01, 0.53411800E-01, -.61107500E-01, -.39807100E-01, -.18064400E+00, -.18734800E-01, 0.78016500E-01, 0.36803400E-02, -.15982200E+00, -.33181200E-01, -.16335700E+00, -.18572700E-01, 0.16962000E+00, 0.33885000E-01, 0.56621100E-01, -.87027600E-01, 0.38231200E-01, 0.86558100E+00, -.97054200E-02, -.68752600E-01, 0.28707900E+01, -.11332000E+03, -.71956200E+02, 0.10821200E+03, 0.23402900E+02, -.30693000E+02, -.44177500E+02, -.10942400E+02, -.11554500E+03, 0.56558900E+02, 0.17049800E+03, 0.57792100E+02, -.33495900E+02, -.86636400E+02, 0.90710900E+02, 0.12935100E+03, 0.80497700E+02, -.99261300E+02, 0.16198000E+03, 0.24506900E+02, -.13525900E+02, -.57801800E+02, -.12318900E+02, -.29364700E+02, 0.21034200E+01, -.23443700E+02, -.41268600E+02, 0.19314300E+02, 0.24838500E+01, 0.60011300E+01, -.79813700E+02, 0.38066500E+02, -.51851600E+02, 0.39871300E+02, 0.49459900E+02, 0.27326600E+02, 0.13872400E+02, 0.56297000E+01, 0.82947400E+02, 0.41863400E+02, 0.11030200E+03, 0.71299400E+02, -.47225700E+02, -.73095700E+02, -.35568300E+02, 0.12438000E+02, 0.22541100E+02, -.75861400E+02, -.63733000E+01, -.63734800E+01, 0.85365000E+01, -.13709500E+02, -.72367200E+02, 0.40992700E+02, -.13670300E+02, 0.36123400E+02, 0.42529300E+02, 0.98692700E+01, -.79638500E+01, -.34969500E+02, -.14665600E+02, 0.12603100E+02, 0.70673600E+02, 0.53843500E+02, -.25652500E+02, 0.26670500E+02, -.26804000E+02, 0.14155300E+03, 0.33052900E+02, -.26489500E+01, 0.16751200E+02, 0.42936400E+01, 0.32172400E+02, -.66305600E+02, -.24050500E+03, 0.11160900E+03, 0.18104800E+03, 0.12029700E+03, 0.14795200E+02, 0.87435300E+01, 0.30845700E+02, -.14486000E+03, 0.50391300E+01, 0.24058300E+02, -.49815500E+02, -.17640700E+03, 0.94536200E+02, 0.12017100E+03, 0.88224300E+02, -.20841200E+02, -.34995000E+02, 0.59365600E+02, -.39280900E+02, 0.48285900E+02, -.25110100E+02, 0.96482600E+02, -.32296300E+02, 0.98191100E+01, -.33152300E+01, 0.16262500E+02, -.94602900E+01, 0.58975400E+01, -.31878700E+02, -.10034800E+03, -.31362300E+02, 0.14122200E+02, -.10904900E+03, 0.11378300E+03, -.53644400E+02, -.78417000E+02, -.57022200E+02, -.31577500E+02, 0.28378200E+02, -.82489200E+02, -.26742400E+02, -.59897100E+02, -.11687500E+02, -.90001300E+02, -.76342700E+02, 0.38656900E+02, 0.10309600E+03, 0.38217700E+02, 0.10752600E+03, 0.71394600E+02, -.69248900E+02, -.29816400E+02, 0.41914000E+02, 0.51672100E+02, -.19681600E+02, -.18188300E+03, 0.10100500E+03, 0.66539800E+02, 0.90946200E+02, 0.35090800E+02, 0.43714500E+02, 0.37403000E+02, 0.30406400E+01, 0.47366800E+02, 0.36546900E+02, 0.80579900E+02, -.12958200E+03, 0.64847600E+02, 0.56249800E+02, 0.64974700E+02, 0.74796800E+02, 0.68580100E+02, -.64856300E+01, -.27663300E+01, 0.11688200E+03, 0.56164100E+02, 0.15409400E+03, -.10977000E+03, 0.58346300E+02, 0.53049600E+02, 0.54799200E+02, 0.83058200E+01, -.36830700E+01, 0.12903400E+02, -.12548100E+02, 0.28517200E+02, -.70722000E+00, -.15325000E+02, 0.54323700E+01, 0.69890900E+01, 0.34301400E+01, 0.16225600E+01, -.71716700E+01, 0.83588000E+01, 0.19190000E+02, 0.18682000E+01, -.37354200E+01, 0.35920500E+02, -.44414600E+02, -.10091300E+03, 0.15842300E+02, -.58684200E+01, -.44105200E+02, 0.40395900E+02, -.53892100E+01, -.10584500E+01, 0.10291200E+02, -.36080100E+02, 0.37674500E+01, -.25474000E+02, 0.39004600E+01, 0.40236900E+02, -.82027400E+01, 0.38192100E+02 },
        { -.82270700E+01, 0.86850400E-01, 0.30031500E+00, -.25244500E+00, -.92654000E+00, 0.34169300E+00, 0.12980700E+01, -.24541000E+00, -.30168600E+00, 0.15954400E+00, 0.64797600E-01, -.11643300E+01, -.17156100E-01, 0.28395100E-01, -.11998200E+00, 0.13819800E+00, -.88316100E+00, -.25614200E+00, -.13348900E+01, 0.98825800E+00, 0.22819600E+00, -.40265500E-01, 0.66149800E+00, 0.27597000E+00, -.47608900E-01, 0.36390100E-01, -.12224500E+00, 0.52559500E+00, 0.99153100E+00, 0.20793300E-01, 0.52305200E+00, 0.81166400E+00, -.29036600E-01, 0.21104700E+00, -.19899400E+01, -.19262600E+00, -.90207400E-01, -.11450100E+01, -.69267500E-01, -.97928400E-01, 0.32616800E+00, -.61445600E+00, 0.45845500E+00, 0.73404700E-01, -.16303700E+00, -.70954000E-01, 0.91414000E-01, 0.16560600E-01, -.22814200E+00, -.15740800E-01, -.59917200E+00, 0.36999000E+01, -.13331000E+00, 0.27109900E-01, 0.17621600E+01, -.56895000E+00, 0.39717300E-01, 0.11997400E+00, 0.64564400E-01, 0.10151400E-01, -.32997900E+00, 0.20367500E+00, 0.31989400E+00, 0.74987300E-01, -.21520200E+00, -.12243100E+00, 0.49162400E+00, 0.11643700E-01, 0.47176700E+00, -.25807700E-02, -.47794900E-01, -.12698500E+00, 0.19124300E-01, -.77231000E-01, 0.54660200E+00, 0.11359300E+00, -.62526600E+00, -.34444200E+01, -.21480300E+00, -.28487000E+00, 0.16415800E-02, 0.60063300E-01, 0.86940500E+00, 0.39837600E-01, 0.16316100E-02, -.20937800E+01, 0.23991600E-01, -.19162700E+00, 0.22569200E+00, -.14205300E+00, -.58797600E+00, 0.48369000E-01, 0.12499100E+00, 0.20490500E+00, -.52672000E-01, -.54090200E-01, 0.34391100E+00, 0.56136700E+00, 0.33593100E+00, -.33706300E+00, -.45555300E-01, -.31390700E-01, 0.31725900E-01, 0.30997500E-01, 0.16336800E+00, -.46966600E+00, 0.10668100E+00, 0.21909900E+01, 0.51319800E-01, 0.25768900E-01, -.30628300E+01, 0.59236900E-01, 0.10137800E-01, 0.13160500E-01, 0.33601700E+03, 0.21619000E+03, -.24068000E+03, 0.12911600E+03, 0.11448500E+03, 0.17364900E+03, 0.20760900E+03, -.28166900E+03, 0.14452100E+03, -.56616500E+03, 0.14082100E+03, -.69882700E+02, -.25159100E+02, -.88957700E+02, -.58948800E+03, 0.57507200E+02, 0.61814100E+02, 0.91380300E+03, -.34473000E+03, 0.17386600E+03, 0.41456300E+03, 0.17224800E+03, 0.19250700E+03, 0.13250500E+03, 0.90501100E+02, 0.82569300E+02, 0.46666800E+01, 0.12374600E+03, -.43998700E+03, -.13413500E+04, 0.67522000E+03, 0.81571000E+03, 0.67074500E+03, 0.30570200E+03, 0.12568400E+03, 0.13838600E+03, -.52746100E+03, -.13692600E+03, 0.20723600E+03, -.35532700E+03, -.14676600E+03, 0.11932900E+03, 0.11555400E+03, 0.73824100E+02, 0.19212000E+02, 0.14101400E+03, 0.40245700E+02, -.46868500E+02, -.17105600E+03, 0.16230500E+03, 0.14361600E+02, 0.17009700E+03, -.97789900E+02, 0.44413200E+01, -.84945300E+02, -.39841400E+02, -.55221800E+01, -.11555300E+03, 0.22763100E+03, -.46187700E+02, -.40451400E+02, 0.83779000E+02, -.48884200E+02, 0.22090600E+02, 0.12404200E+00, 0.24228900E+02, -.25402500E+03, -.43227000E+02, 0.19120400E+02, -.61943600E+02, -.57494100E+02, -.53610600E+02, 0.16329600E+03, 0.10072700E+04, -.47008400E+03, -.63914200E+03, -.50372800E+03, -.16226100E+03, 0.12023900E+03, -.43333600E+03, -.99104800E+02, -.35628600E+03, -.61493700E+02, 0.46927300E+03, 0.35017100E+03, -.17935500E+03, -.26480800E+03, -.17514500E+03, 0.28910700E+02, 0.50826500E+02, -.12761900E+03, 0.11376400E+03, -.42173800E+02, 0.41156900E+02, -.16461100E+03, 0.28465800E+03, -.11871100E+03, -.85598900E+02, -.14253300E+03, -.61256000E+02, 0.17612300E+03, -.19102500E+03, -.18563000E+03, -.18677700E+03, 0.18146000E+02, 0.53762300E+03, 0.10966200E+04, -.55927000E+03, -.41452000E+03, -.54807400E+03, -.26584100E+03, -.26403700E+03, -.16710800E+02, 0.48267000E+03, 0.23672000E+03, -.20326600E+03, 0.57255500E+03, 0.32625900E+03, -.16495100E+03, -.22840700E+03, -.16321600E+03, -.23226200E+03, -.28465200E+03, 0.12612700E+03, 0.35041800E+02, -.10922000E+03, -.21270400E+03, -.18626200E+03, 0.21983600E+03, -.14888200E+03, 0.75796500E+01, -.10972300E+03, -.13261900E+03, -.29142800E+03, 0.54924600E+02, 0.52296100E+02, 0.51024200E+02, -.28911600E+03, -.11036300E+03, -.67647700E+03, 0.33850800E+03, 0.35545500E+03, 0.33794600E+03, 0.71680300E+01, -.93675500E+02, 0.34036400E+03, 0.14293100E+03, 0.15279100E+03, -.21290000E+02, -.52367400E+02, 0.12685200E+03, -.75879000E+02, -.97915500E+02, -.63208900E+02, 0.17457400E+02, 0.25279000E+02, 0.16380400E+02, 0.16882200E+02, 0.46360700E+02, 0.24364200E+02, -.32170800E+02, -.11827800E+02, -.33519500E+01, 0.10410500E+02, -.71586200E+01, -.52282600E+01, 0.45325000E+01, -.65664300E+02, -.32654300E+01, -.86546000E+01, -.59635800E+02, 0.68118700E+02, 0.19488700E+03, -.18378500E+02, -.67368100E+02, 0.10929500E+03, -.83645100E+02, -.38944700E+02, 0.10844500E+02, 0.48534900E+02, 0.57122400E+02, -.57400300E+02, 0.10194500E+03, -.49076000E+02, -.94879200E+02, 0.61107200E+02, -.73090700E+02 },
        { 0.40208900E+01, 0.42462900E-01, -.73727700E-01, 0.13500600E+01, 0.52985700E+00, 0.99644400E+00, 0.88334200E-01, 0.11968900E+00, -.33583100E+00, 0.83591200E+00, -.43461500E-01, 0.73567300E+00, 0.14375300E-01, -.54369700E-01, -.61485000E-01, -.15377100E-01, -.31805700E+00, -.12582600E+00, -.67620900E-01, 0.17485700E+00, -.79807200E-01, 0.67022300E-01, -.14442400E+01, -.18528800E+00, 0.27467700E-01, 0.34439500E-01, 0.95599700E-02, -.11460000E+00, -.24250300E-01, -.44965300E-01, -.56806400E-02, 0.61555100E+00, -.18201600E-01, -.34684100E+00, 0.30175700E+00, 0.32969300E+00, -.25981400E-02, -.26999400E+00, 0.76452400E-01, 0.33809400E+00, -.35182100E+00, -.87549900E+00, 0.38586600E+00, 0.47464900E+00, -.93281100E+00, 0.11498400E+00, 0.78604800E-01, 0.86315600E-02, -.29494700E+00, 0.49781300E-02, -.15298700E+00, 0.18451300E+01, 0.39499700E-01, 0.19068900E+00, 0.26932400E+00, -.39220900E+00, -.35563700E-02, -.29566800E+00, -.10538800E+00, -.23947800E-01, -.13628600E+00, 0.46752500E-01, -.53784600E-01, -.55986200E-01, -.21628800E+00, -.63311000E-01, 0.34331700E-01, 0.55411400E-02, -.19192000E+00, 0.90805300E-03, 0.31042300E-01, -.16836600E+00, -.12020000E+00, 0.36092700E-01, 0.68572900E-01, 0.34448300E+00, 0.59129900E-01, 0.15937500E+01, -.34371700E+00, 0.77000000E+00, 0.38252800E-01, -.25132800E+00, -.65085800E-01, -.66375100E+00, 0.62923900E+00, 0.39833200E+01, 0.34712100E+00, 0.13685000E+00, -.21691200E+00, 0.99348500E+00, -.35022200E+00, 0.26079900E-01, 0.31078000E+00, 0.22154900E-01, -.55223000E-01, -.28706400E+00, -.39181800E+00, -.80341400E-01, 0.23172900E+00, -.10438600E+00, 0.11443500E+00, -.19818600E+00, 0.18505500E+00, -.25023400E+00, -.76606900E-01, -.32615000E+00, -.39490000E-01, 0.19563300E+01, -.25118700E-01, -.12795500E+00, 0.15794500E+01, -.14220700E-01, 0.12548100E-01, -.51507600E-02, -.47950800E+00, 0.10349100E+03, -.23478800E+03, -.13160300E+03, -.62682400E+02, 0.53258200E+02, -.79958800E+02, 0.13360200E+03, -.67402100E+02, 0.18473100E+03, -.66873100E+02, 0.60014700E+03, -.30284900E+02, 0.20831800E+03, 0.52624400E+03, -.19168200E+02, -.10048900E+03, 0.12758900E+03, -.44509100E+03, 0.22691900E+03, -.73577700E+02, 0.22391200E+03, -.14101600E+03, -.79154400E+02, 0.15676300E+02, -.26049500E+03, 0.93892100E+02, -.36819800E+01, -.38017500E+02, 0.76123100E+03, -.37617900E+03, -.20554700E+03, -.38046100E+03, -.35236800E+03, -.17228900E+03, 0.19699700E+02, 0.89315000E+02, -.25370000E+03, -.22725200E+03, -.26266100E+02, 0.60455000E+02, -.40436300E+02, -.34507400E+02, -.30422300E+02, -.88722800E+02, -.25284400E+03, 0.26447000E+03, 0.24591700E+03, 0.17015500E+03, -.23395400E+03, 0.31797700E+02, -.61900500E+02, 0.24853100E+02, 0.96990000E+02, 0.31202700E+02, -.10915000E+03, 0.65059200E+02, 0.62234800E+00, 0.15710600E+02, 0.24487100E+03, 0.71396300E+02, -.15061100E+03, -.23434900E+03, 0.11343200E+03, -.29390400E+02, 0.11667900E+03, -.20202500E+03, -.73758800E+02, 0.11842400E+03, 0.11633300E+02, 0.27515000E+02, -.73143600E+02, 0.33266000E+03, 0.94695800E+03, -.47515100E+03, -.66815500E+03, -.47366500E+03, 0.77586100E+02, 0.15246800E+03, -.65968400E+02, 0.45639600E+03, -.43771200E+03, 0.10455000E+03, 0.11019600E+03, 0.13921700E+03, -.83447600E+02, -.35226100E+02, -.69695200E+02, 0.23849400E+02, 0.41337800E+02, -.74157900E+02, -.25356400E+02, -.11810700E+03, 0.30120900E+02, -.58661000E+02, 0.61397400E+03, -.30496100E+03, -.40097200E+03, -.30746400E+03, 0.79637900E+02, 0.10581100E+03, -.14591500E+02, 0.34656300E+03, -.21916300E+03, 0.43580600E+02, 0.26767600E+03, 0.85338100E+03, -.42951900E+03, -.42034900E+03, -.42614100E+03, 0.93997100E+02, -.38634100E+02, -.13950500E+03, 0.25565600E+03, -.74532500E+02, 0.10011300E+02, -.83980200E+03, 0.11809100E+04, -.58922600E+03, -.74387100E+03, -.59065400E+03, -.29541400E+03, -.19389200E+03, 0.56329300E+01, 0.30604700E+03, -.12279300E+03, -.16161700E+03, -.41330300E+03, 0.14887700E+03, -.62877000E+02, -.49274600E+02, -.74419000E+02, 0.56802700E+02, 0.18338800E+03, -.18604600E+03, -.16435800E+03, -.18827400E+03, 0.20098300E+03, -.15008700E+03, 0.11519900E+04, -.57445200E+03, -.34297400E+03, -.57674200E+03, -.20514300E+03, -.28411600E+03, -.52593100E+02, -.48312100E+02, -.59234700E+03, -.23091000E+03, -.50321700E+03, 0.29306800E+03, -.14580700E+03, -.80719600E+02, -.14619200E+03, -.54685300E+02, -.31784600E+02, -.13394200E+02, -.12118800E+02, -.17435400E+03, -.41946500E+02, 0.51104500E+02, 0.23455400E+01, -.12760600E+02, -.18127200E+01, 0.23960100E+01, 0.13986000E+02, -.11446700E+02, -.78432400E+00, -.86775900E+00, 0.11558400E+01, -.30808000E+02, 0.44710700E+02, 0.11505100E+03, 0.63200000E+02, 0.36830500E+02, 0.74499500E+02, -.21986800E+02, 0.39081100E+02, 0.58243600E+01, 0.63440400E+02, 0.61389400E+02, -.30486000E+02, 0.30255600E+02, 0.28832400E+01, 0.16434200E+02, 0.54040500E+02, -.24279400E+02 },
        { -.20283600E+02, 0.56149300E+00, 0.67705800E+00, 0.17993600E+01, -.23147900E+01, 0.56675300E+01, -.10712600E+00, 0.28234300E+01, -.77873700E+01, 0.52769600E+01, 0.13034500E+01, -.30203900E+01, -.81280300E+00, -.25536600E+00, -.52937000E+00, -.38724700E-01, -.23839000E+00, -.28610500E+00, -.60587200E+00, 0.32318200E+01, 0.50690800E+01, -.22967900E+01, -.60845600E+01, 0.13944600E+01, -.90638500E-01, 0.69113700E+00, -.15987300E+01, 0.34765900E+01, 0.79160500E+01, -.20731100E+01, 0.31071400E+00, -.60514600E+01, -.11371800E+01, 0.31018500E+01, -.61115800E+01, -.18062600E+01, -.75559000E-01, -.88797700E+01, 0.10327700E+01, -.44255800E+01, 0.22171500E+01, 0.21380200E+00, -.14737000E+01, -.27907900E+01, -.43485700E+00, -.64847600E-01, -.36286900E+00, 0.68655200E-01, -.11969400E+01, 0.66354800E+00, -.44685700E+01, 0.16121600E+01, -.10003800E+01, 0.12993500E+01, 0.29199600E+01, -.29066100E+01, -.51897700E-01, -.19147300E+01, 0.97202700E+00, -.25501600E+00, -.20508400E+01, 0.17616600E+00, -.16648500E+01, 0.44707200E-01, -.14046600E-01, 0.25119100E+01, 0.16709000E+01, 0.34345100E-01, 0.18207700E+01, -.58709700E-02, 0.29399700E+00, -.79049000E+00, -.24569200E+00, 0.53046300E+00, -.15504800E+01, -.17161500E+01, -.21291200E+01, -.25724300E+00, -.94781400E+00, 0.32542700E+00, -.76967400E-03, -.54232600E+01, -.69863200E+00, -.28598600E-01, -.14003000E+01, 0.31520700E+02, 0.11587800E+01, -.40359100E+00, 0.39248700E+00, 0.26281000E+01, -.25973100E+00, 0.13938100E+00, -.43261100E+01, 0.10131800E+00, -.14101500E+01, -.22195200E+01, 0.16903800E+01, 0.18013500E+01, 0.38400400E+01, -.57494400E+00, 0.68174300E-01, -.27785100E+01, 0.11490700E+01, -.74701000E-01, 0.53841400E+00, -.40431100E+01, 0.42404600E+00, 0.89386500E+01, 0.38672800E+00, 0.51193700E-01, -.10276000E+01, 0.53169700E+00, 0.14477200E+01, 0.12464300E-01, 0.40080800E+01, -.25353600E+01, -.61710400E+03, -.98527000E+03, -.43626100E+03, -.62622600E+02, -.22016700E+04, 0.53446500E+04, -.26841100E+04, -.10813600E+04, -.26724200E+04, 0.13678900E+04, 0.28427100E+04, -.20360000E+04, 0.48315400E+03, -.26456100E+04, 0.21891100E+04, -.60258100E+04, 0.29199200E+04, -.14422700E+04, -.19368900E+04, -.14572700E+04, -.13236400E+04, -.15901700E+04, -.10651900E+03, 0.51609400E+03, -.15105400E+03, -.12422300E+04, 0.86679600E+03, -.18549800E+04, 0.93432800E+03, 0.20387800E+04, 0.92755200E+03, -.13558800E+04, 0.33651700E+03, 0.26358900E+03, -.58964600E+03, 0.84570400E+01, 0.78950100E+02, 0.38580900E+04, 0.19471200E+04, -.10421300E+04, -.90465600E+03, -.97499600E+03, -.45718800E+03, -.12120600E+04, 0.52453000E+03, 0.11928500E+04, 0.68093600E+03, -.11180700E+04, -.28403100E+03, -.58315700E+03, 0.28877000E+03, 0.32362700E+03, 0.29172500E+03, -.11585600E+02, -.31647400E+03, 0.28821000E+03, -.13825100E+03, 0.67050500E+03, 0.77052700E+02, -.10666900E+04, -.14364300E+04, 0.71052200E+03, 0.11174300E+04, 0.71794500E+03, -.40174500E+03, -.57047300E+03, 0.36282900E+03, 0.39623200E+03, 0.56184400E+03, -.51784400E+03, 0.11155900E+04, 0.75466400E+03, -.42133600E+03, 0.69281200E+03, -.37741200E+03, 0.95929500E+03, 0.12464800E+03, 0.13841500E+04, 0.33575000E+04, 0.36600100E+03, -.20926800E+03, 0.88439300E+02, 0.51945600E+03, -.34845100E+03, -.34660100E+03, -.25974400E+03, 0.22369800E+03, 0.35297200E+03, -.13295600E+03, -.20986700E+03, -.73870900E+03, 0.22913600E+03, -.21514200E+03, 0.70840200E+03, -.38095600E+03, 0.91667100E+03, -.35447400E+03, 0.83201100E+03, -.38640000E+02, 0.87655900E+03, 0.25006600E+04, 0.13159400E+03, -.33986500E+03, 0.36743100E+03, 0.57031000E+04, -.28456000E+04, -.33920300E+04, -.28512500E+04, 0.42631200E+03, -.10387100E+04, -.36697200E+03, 0.19475700E+04, -.74030500E+03, -.10813200E+04, -.67777100E+04, 0.47140900E+04, -.23518600E+04, -.23171100E+04, -.23571500E+04, -.13134200E+04, -.51741100E+03, 0.84414100E+02, 0.18510500E+04, -.32923300E+03, -.80077000E+03, 0.29443800E+03, -.25163300E+04, 0.13452800E+04, 0.11700000E+04, 0.12577400E+04, 0.38728200E+03, 0.83882200E+03, 0.38317500E+01, -.67147300E+03, -.15336700E+01, 0.89867600E+03, 0.92289400E+03, 0.29404300E+04, -.14617200E+04, -.14378700E+04, -.14707300E+04, -.59639700E+03, -.17525100E+03, -.19709400E+04, -.17305600E+04, -.19336100E+04, -.10039300E+03, -.40273200E+03, 0.12489700E+04, -.61659200E+03, -.26022400E+03, -.62427300E+03, -.25418700E+03, -.13953200E+03, -.16337100E+03, 0.11643900E+03, -.42354300E+03, -.28039500E+03, -.19912400E+03, -.57542100E+01, -.12008400E+03, -.52027100E+02, 0.39506400E+02, 0.76860800E+02, -.89341500E+02, 0.32643000E+01, -.17950300E+02, 0.44193000E+02, -.23127700E+03, 0.33588700E+03, 0.52844200E+03, -.20881400E+03, 0.78257800E+03, 0.17405200E+03, -.18605300E+03, 0.61290200E+02, -.17295800E+03, 0.28071600E+03, 0.12362500E+03, -.13862800E+03, -.29863300E+02, 0.15755600E+03, -.17740300E+03, 0.72468800E+02, -.21659300E+03 },
        { -.17570600E+00, 0.14152000E-01, 0.13646500E-01, 0.10755600E+00, -.52859000E-01, 0.26813800E+00, -.16944900E+00, 0.16579500E+00, -.10302400E+00, 0.97205100E-01, 0.33220300E-04, -.22347000E+00, -.15936200E-01, -.63271700E-02, -.44174100E-01, 0.37846700E-01, -.35371900E-01, -.65903100E-01, -.73456200E-01, 0.91772600E-01, 0.13582900E+00, -.32924200E-01, -.73724200E+00, -.21014400E-02, -.25697300E-01, 0.77677200E-02, 0.29280700E-02, -.57181000E-02, 0.12364700E+00, 0.10618600E-01, 0.57787400E-01, 0.22868700E+00, -.11403800E-01, 0.71781700E-01, -.35011500E+00, -.38954200E-01, -.34567700E-02, -.29643800E+00, -.40147900E-02, -.10709600E-02, 0.67996800E-01, -.98485200E-01, 0.93676700E-01, 0.43950500E-02, -.70473900E-01, -.19627400E-01, -.53478300E-02, 0.24356800E-02, -.43303700E-01, 0.12317600E-01, -.13362000E+00, 0.20638300E+00, 0.18334200E-02, -.60222400E-02, 0.53847300E-01, -.28611900E-01, 0.11230600E-01, -.29546000E-01, 0.38612000E-01, -.16500100E-01, 0.89121600E-04, 0.21701200E-01, -.82547400E-01, 0.44070500E-01, 0.93184200E-01, -.61177600E-02, 0.10504500E+00, 0.16306900E-02, 0.12492700E+00, 0.46424700E-04, -.33804300E-02, -.25467900E-01, -.89045900E-02, 0.20462000E-01, 0.19522100E-01, 0.28538900E-01, -.79421100E-01, -.18291100E+00, -.14303200E-01, 0.45133800E-01, 0.54580500E-02, -.10034400E+00, 0.18067300E+00, -.39522300E-01, 0.10887700E+00, 0.43101700E+00, -.77518100E-03, -.11786900E-01, -.51907900E-01, -.23308000E-01, -.10446600E+00, 0.77651800E-02, 0.99129900E-01, -.83581600E-02, 0.10637400E-01, -.42812300E-01, -.35290500E-01, -.94459900E-01, -.73825400E-01, -.30937900E-01, 0.12944500E-01, 0.59963500E-02, 0.30423500E-01, -.81325800E-01, -.12600400E-01, 0.19771000E-01, 0.48357600E-02, 0.74343100E-01, -.40484500E-01, -.29606000E-02, -.41846200E-01, 0.84232000E-02, -.24871000E-01, 0.17527900E-02, -.86057100E-02, 0.10437000E+00, -.10938500E-01, -.22882000E+02, -.38542400E+02, 0.22816500E+01, -.26307600E+02, 0.90664100E+02, -.45741500E+02, -.51788700E+02, -.45322500E+02, 0.11485000E+02, 0.50874300E+02, -.30653800E+02, 0.20851300E+02, -.38425400E+02, 0.18542000E+02, -.15833300E+02, 0.14399000E+03, -.71914000E+02, -.84632200E+02, -.72160200E+02, -.34643300E+02, -.13352200E+02, -.81193900E+01, 0.42558700E+02, -.99211700E+01, -.10730700E+02, -.49170100E+02, -.63523200E+02, 0.31239300E+02, 0.28856200E+02, 0.31747200E+02, -.24042100E+02, 0.15245300E+02, 0.16587700E+02, -.19518500E+02, -.37595500E+01, 0.13294800E+02, 0.41983500E+02, 0.17287600E+01, -.98678400E-01, -.63638100E+01, -.79500800E+00, 0.32464700E+01, 0.12180400E+02, -.99559600E+01, 0.38159300E+01, -.61375100E+01, 0.15836700E+02, 0.64413100E+01, 0.89140900E+01, -.34433800E+01, -.56904400E+01, -.44825600E+01, 0.21937200E+02, -.60828300E+01, -.17474800E+01, 0.51058300E+01, 0.31654200E+02, -.34287800E+01, -.89690800E+01, 0.47571400E+02, -.23991000E+02, 0.37539600E+01, -.23736600E+02, 0.44551200E+01, 0.36625400E+01, -.34806400E+02, -.13334500E+02, -.12387800E+02, 0.19532600E+01, -.50698100E+01, 0.30712500E+02, -.15858800E+02, 0.66954800E+01, -.15338800E+02, 0.22953000E+02, 0.34620800E+01, 0.41575100E+01, 0.34232300E+02, -.19232900E+02, 0.12089200E+02, -.11399100E+02, -.15647100E+02, 0.10020100E+02, -.47599900E+01, 0.78303800E+01, -.63374100E+00, 0.23805200E+01, -.53038100E+01, -.11074800E+02, 0.66010400E+01, -.12127200E+01, 0.10977300E+02, 0.24913800E+02, -.13079500E+02, 0.37978500E+00, -.12409200E+02, 0.20555800E+02, -.68397200E+01, 0.76429500E+01, 0.41521400E+02, -.41960200E+01, -.12575500E+01, 0.44131000E+01, 0.18398400E+03, -.91460400E+02, -.10670100E+03, -.92046400E+02, 0.13134800E+02, -.37403300E+02, -.28753700E+02, 0.56622600E+02, 0.11910500E+02, -.40193900E+02, -.11081200E+03, 0.12128800E+03, -.60856700E+02, -.87286800E+02, -.60625000E+02, -.29593200E+02, -.22882700E+02, 0.39439500E+01, 0.49571200E+02, 0.25066700E+02, -.30032000E+02, -.13063200E+02, 0.33984100E+01, -.22766800E+01, 0.93424400E+01, -.16843200E+01, 0.68605500E+00, -.21832900E+01, -.73760200E+00, -.25053900E+01, -.15594700E+01, -.24493700E+01, -.51997700E+01, -.67367000E+01, 0.29997900E+01, 0.34042700E+02, 0.34467800E+01, -.82084200E+01, 0.37858400E+02, -.45596400E+02, -.35218400E+02, -.11572300E+02, 0.31198800E+02, 0.29330800E+01, -.11495100E+02, 0.54800500E+01, 0.12735200E+02, 0.57210100E+01, -.10087900E+01, -.38553200E+00, 0.30012000E+01, 0.37348400E+01, 0.18437800E+02, -.60960200E+01, 0.63372500E+01, 0.11379400E+00, -.24767300E+00, -.68585700E+00, 0.10466700E+01, 0.11455700E+00, -.65679700E+00, -.43472200E+01, 0.14376000E+00, 0.14548000E+00, 0.37023800E+01, -.31830100E+01, 0.94495900E+01, -.36784100E+01, -.10407800E+02, 0.99286600E+01, 0.19543500E+01, 0.24730200E+01, -.24332000E+01, -.80282000E+00, 0.15256100E+02, 0.32603900E+00, 0.58364000E+01, -.23751100E+01, 0.19805600E+01, -.16317300E+02, 0.26814000E+01 },
        { -.66218100E+01, 0.25229400E+00, 0.17358000E+00, 0.17689000E+01, -.11915600E+01, 0.19467100E+01, -.90203500E+00, 0.11879700E+01, -.22988000E+01, 0.13404400E+01, 0.40509900E-01, -.84749200E+00, -.25185500E+00, -.17617200E+00, 0.15577500E+00, 0.18098400E+00, -.49538000E+00, -.50989200E+00, 0.31421300E-02, 0.12777900E+01, 0.69597500E+00, 0.13189800E+00, -.16152300E+02, -.88098100E+00, 0.10448800E+00, 0.25897400E+00, -.24780000E+00, 0.18441000E+01, 0.21274700E+01, 0.47074000E+00, 0.27683100E+00, 0.15463700E+01, -.12485100E+00, 0.15077200E+01, -.23443300E+01, -.71994500E+00, 0.41137900E-01, -.39154600E+01, 0.36119500E+00, -.93677100E+00, 0.69287200E+00, 0.31097800E+00, 0.42055600E+00, -.17588100E+01, 0.35364500E+00, -.73551000E-01, 0.19446200E+00, 0.56639500E-02, -.86965800E+00, 0.22798300E+00, -.21107200E+01, 0.64006500E+01, -.11422600E+00, -.20299200E-01, -.25579900E+01, -.68093000E+00, 0.90837400E-01, 0.52017300E+00, -.13150800E+00, 0.14883900E-01, -.67211500E+00, -.27112800E+00, -.44644000E+00, 0.57596700E+00, -.96734600E-01, -.62189600E+00, 0.16344700E+01, 0.16654000E-01, 0.15778400E+01, -.53581600E-02, 0.24783400E+00, -.15458600E+00, 0.41648100E-01, 0.19299700E+00, 0.16756600E+01, -.59599000E+00, 0.65255300E+00, 0.88855200E+00, -.14121900E+00, 0.10966300E+00, 0.67278900E-01, -.16540700E+01, 0.19004000E+00, 0.49379100E+00, 0.35005900E+00, -.25484300E+01, -.37051800E+00, 0.70366900E-01, 0.59032100E+00, -.64072500E+00, -.12575500E+00, 0.52739400E-01, 0.62901200E+00, -.25862200E+00, 0.14539000E+00, -.12237100E+00, -.74972900E+00, -.89851100E+00, -.88502600E+00, -.10072100E+00, -.16728700E+00, -.57663900E+00, 0.62881000E+00, 0.14124300E+00, -.21732100E+00, 0.84611100E+00, -.15601500E-01, -.60119400E+00, 0.58296500E-01, -.66640000E-01, 0.33223800E+01, -.26001900E-01, 0.16215300E+00, -.36880700E-02, -.15366800E+01, 0.74879900E+00, -.54415300E-01, -.24424300E+00, -.23776400E+03, -.36713000E+02, 0.32575700E+03, 0.30644800E+03, -.15661800E+03, -.35087000E+03, -.15324500E+03, -.14899100E+03, -.18566300E+02, 0.10991100E+03, 0.34677700E+03, 0.11133900E+03, -.25766200E+02, 0.85431800E+03, -.53159700E+03, 0.26542300E+03, 0.57058600E+03, 0.26677200E+03, 0.14850900E+03, 0.11627900E+03, -.14584200E+02, -.34320700E+03, -.13561000E+03, 0.15016500E+03, -.55690000E+03, 0.82598900E+03, -.41402200E+03, -.28804900E+03, -.41290000E+03, 0.21585800E+03, -.11611900E+03, 0.46442000E+02, 0.39417100E+03, 0.16513000E+03, -.48731500E+02, -.12623900E+04, -.42836400E+03, 0.22207700E+03, 0.28003500E+03, 0.21445300E+03, 0.54580400E+02, 0.18792500E+03, -.17396600E+01, -.14913400E+03, -.75736900E+02, 0.17596700E+03, 0.13277800E+03, -.11324800E+03, 0.56680900E+02, 0.32732600E+03, 0.56762800E+02, 0.15139700E+03, 0.27259500E+03, -.24545300E+03, -.19892000E+03, -.16519500E+03, 0.18385600E+03, 0.33594300E+03, 0.10003400E+03, -.58041200E+02, -.46685600E+02, -.50294100E+02, 0.11769600E+03, 0.65675100E+02, -.39964900E+02, -.14724000E+03, -.89839200E+02, 0.67375500E+02, 0.50674800E+02, 0.35373500E+03, -.17908100E+03, -.47405700E+03, -.17697600E+03, -.61170700E+02, 0.17263800E+02, -.16337700E+03, -.41535200E+02, -.42861700E+02, 0.25595500E+02, 0.52609600E+03, -.20452800E+03, 0.11190900E+03, 0.70669800E+02, 0.10221300E+03, -.10209100E+03, -.16841500E+03, -.21443500E+01, -.36317300E+01, 0.17690300E+03, -.13037600E+03, 0.14109600E+03, 0.34404600E+03, -.16867000E+03, -.32822400E+03, -.17228100E+03, -.58564000E+02, 0.95788000E+02, -.83373000E+02, -.25311700E+02, -.98236800E+01, 0.54436100E+02, 0.37530900E+03, -.22809200E+04, 0.11434800E+04, 0.13430700E+04, 0.11407700E+04, 0.32668100E+03, 0.65496200E+03, -.13092500E+03, -.89689000E+03, -.84822600E+02, 0.57127800E+03, 0.20233700E+04, -.18603500E+04, 0.93148200E+03, 0.75298200E+03, 0.93006600E+03, 0.41753100E+03, 0.44502500E+03, -.92772500E+01, -.50591100E+03, 0.54148700E+03, 0.44325400E+03, 0.55135700E+03, 0.81860000E+03, -.42775500E+03, -.32266600E+03, -.40917700E+03, -.69944400E+02, -.13062500E+03, -.50290900E+02, 0.16519000E+03, -.14575400E+03, -.12606500E+03, -.36642100E+03, -.22959000E+03, 0.10931700E+03, 0.95106900E+02, 0.11443100E+03, -.21875600E+02, -.10866900E+03, 0.25836400E+03, 0.93693100E+02, 0.11096300E+01, -.74137800E+02, -.75947000E+02, -.69307100E+02, 0.34092900E+02, -.79267600E+01, 0.34804700E+02, -.12890300E+01, -.55072100E+02, 0.58607100E+02, 0.49170400E+02, 0.14226600E+03, -.30827000E+02, 0.12735600E+02, 0.14233900E+02, -.95229800E+01, 0.39387500E+02, -.12825100E+01, -.31871900E+02, 0.36520700E+02, 0.14814400E+02, 0.91292900E+01, -.40551600E+02, 0.11348400E+03, -.12745100E+03, 0.55843300E+02, 0.40248700E+02, -.63123800E+00, -.90641100E+02, 0.10169000E+03, 0.84691700E+01, 0.58595600E+01, 0.12619600E+02, 0.36646700E+02, -.42689700E+02, -.46977200E+02, -.34702500E+02, 0.10463000E+03, 0.55210000E+02, 0.10713800E+03 },
        { -.12251600E+01, 0.25148200E-01, 0.52297300E-01, -.75914900E-01, -.19635000E+00, 0.41473500E+00, -.10982900E+00, 0.10521100E+00, -.17917700E+00, 0.34443400E+00, -.47610200E-02, -.84688300E-02, -.16873900E+00, -.38327400E-01, -.22695200E+00, 0.40372500E-01, -.49600400E-02, -.21190900E-01, 0.92833600E-01, 0.34238500E+00, 0.23751200E+00, 0.54213400E-01, -.34326900E+01, -.40243900E+00, -.18787500E-01, 0.23310300E-01, -.64827700E-01, 0.10744100E+00, 0.32113300E+00, 0.23036300E+00, 0.24158700E+00, 0.55510200E+00, -.32470400E-01, 0.28135200E-01, -.56465500E+00, -.49240900E-01, -.15185900E-01, -.48980200E+00, 0.64190800E-01, -.12817100E+00, 0.25179500E-01, 0.40315700E+00, 0.40619800E-01, -.24834200E+00, 0.85535400E-01, -.80280800E-01, 0.52449000E-01, 0.38509300E-02, 0.96416600E-02, 0.12788900E-01, -.23737100E+00, -.20955900E+00, 0.18898900E-01, -.14358300E+00, -.71244100E+00, 0.17832400E+00, 0.16356200E-01, 0.27540000E+00, 0.19180000E+00, -.53876600E-02, -.13530200E+00, -.97328300E-01, -.13965400E+00, 0.35862700E-01, 0.23658300E+00, 0.60531200E-01, -.11671400E+00, -.69269500E-02, 0.21136700E+00, -.44618600E-03, -.48542700E-01, -.33582100E-02, 0.11320500E-01, 0.15067300E-01, -.12517900E+00, 0.47975500E-01, 0.25897000E-01, 0.49298900E+00, 0.89517700E-01, 0.19959700E+00, 0.16661300E-01, -.13033100E+00, -.97278000E-01, 0.41339300E-02, 0.23194500E+00, 0.56017000E+00, 0.51553200E-01, 0.37849000E-01, 0.77217300E-01, 0.11457500E+00, -.11636100E+00, 0.90954600E-02, 0.75968400E+00, -.36188300E-01, 0.42545900E-01, -.11331100E+00, -.69610500E-01, -.92906000E-01, -.57897500E-01, 0.30144500E-01, 0.13518000E-01, -.21976700E-01, 0.21238900E-01, -.92877700E-01, -.10259500E-01, 0.26003300E-02, -.15846800E-01, 0.15420600E+00, -.22005300E-01, -.52215000E-02, 0.54712300E+00, -.14373600E-01, -.63847800E-01, -.41244700E-02, -.13595500E+00, 0.74722200E-01, -.35681300E-01, 0.30717100E+00, -.76406100E-01, 0.14161400E+02, -.43346700E+02, -.11941600E+02, 0.52271300E+01, 0.43591500E+02, 0.59696500E+01, -.44213600E+02, -.18417600E+01, 0.49386200E+01, -.43466600E+00, 0.16506500E+02, 0.18121800E+02, 0.69241100E+02, 0.48552700E+02, -.24431100E+02, 0.12832000E+02, -.24147000E+02, -.24808500E+01, -.19593500E+02, -.19745500E+02, -.14022100E+02, -.95796400E+01, -.19957800E+02, -.32487400E+02, -.28330300E+03, 0.14211600E+03, 0.18452500E+03, 0.14164200E+03, 0.71850500E+02, 0.53175300E+02, 0.12076900E+02, -.92723900E+02, 0.32283300E+02, 0.67878800E+02, 0.57489000E+02, 0.59994200E+02, -.37621800E+02, -.17460700E+02, -.30089500E+02, -.51455700E+01, -.23671500E+02, -.16598200E+02, -.73016300E+01, -.93036800E+01, -.25417000E+02, -.19885700E+02, -.31799300E+02, 0.15674800E+02, 0.47070600E+02, 0.15887900E+02, 0.14799500E+02, 0.84029900E+01, -.26869200E+02, 0.54982100E+01, -.16097900E+02, 0.10799600E+02, 0.48391100E+02, -.23763000E+02, 0.12128600E+02, 0.51957100E+02, 0.11906400E+02, 0.55644400E+02, -.10554800E+01, 0.16826800E+02, 0.25033300E+02, 0.15126800E+02, 0.54176700E+01, -.11975000E+02, -.16233200E+01, -.32109400E+01, 0.51286200E+02, 0.82277600E+00, -.20542300E+02, 0.29447900E+02, -.84861000E+01, -.54487600E+02, -.32826000E+02, 0.12100200E+02, 0.31179500E+02, -.53773900E+02, 0.23002100E+02, 0.25728500E+02, 0.26894200E+02, -.11707400E+02, -.23643000E+02, 0.28870500E+02, -.63822600E+01, 0.51518700E+01, -.16709700E+02, 0.34755800E+02, 0.46526500E+02, -.25369200E+02, 0.19216300E+02, -.23240500E+02, -.28353500E+02, 0.33330900E+02, -.32386800E+02, -.52075600E+02, -.42256700E+02, 0.11769300E+02, 0.12386900E+02, 0.28998000E+03, -.14438500E+03, -.13943600E+03, -.14501800E+03, -.76028000E+02, -.20070900E+02, -.60588600E+02, 0.93065600E+02, -.25188800E+02, -.46911900E+02, -.56479000E+02, 0.91032300E+02, -.44359600E+02, 0.12529500E+02, -.45505700E+02, -.25137500E+02, -.28932200E+01, -.27205400E+02, 0.38747100E+02, 0.10882300E+02, -.19277900E+02, -.28246200E+02, -.92362900E+02, 0.52834600E+02, 0.30687800E+02, 0.46146900E+02, 0.14349400E+02, 0.26071100E+02, 0.18732200E+02, 0.27053300E-01, 0.13287700E+02, 0.21426900E+02, 0.52684400E+02, -.32659400E+02, 0.17364000E+02, -.29000500E+02, 0.16357100E+02, 0.59409600E+02, 0.34005100E+01, -.14209900E+02, 0.95563300E+01, 0.39554100E+02, 0.17791100E+02, 0.44916700E+02, -.67380100E+00, 0.26791700E+01, -.41140200E+00, 0.31148000E+00, -.58911800E+00, -.74815900E+01, 0.82391500E+01, 0.25907300E+02, 0.10634000E+02, -.74176800E+01, -.30038600E+02, 0.39632400E+01, -.55271100E+00, 0.49615600E+01, 0.16581900E+01, -.57694400E+01, 0.63437700E+01, -.53994400E+00, 0.86890100E+00, -.46878000E+01, 0.74626000E+01, -.88693400E+01, -.38830100E+01, 0.60173400E+00, 0.23829900E+02, -.84201600E+01, 0.11340100E+02, -.93206400E+01, -.20744700E+01, 0.19254900E+02, -.30461300E+02, -.85717100E+01, -.18021900E+01, -.10731400E+01, 0.59136000E+01, 0.14320000E+02, 0.94618100E+01 },
        { 0.12409100E+02, -.25425500E+00, -.74902000E+00, -.36156800E+00, 0.52433200E+00, -.16533900E+01, 0.23817400E+00, -.33931200E+00, -.47612800E+00, -.11288400E+01, -.33384000E-01, -.10422900E+01, -.56303000E-01, 0.49915300E+00, -.39517700E+00, 0.16439500E+00, -.83951000E+00, -.82370100E+00, -.45395500E+00, 0.17827900E-01, 0.77077200E-01, -.35460000E-01, -.12265700E+02, -.10798700E+01, -.97036100E+00, -.20705300E+00, -.57272400E-01, 0.19986400E-02, 0.31822700E+00, 0.62742800E+00, 0.88525900E+00, 0.15311900E+01, 0.48006600E-01, -.34334000E+00, 0.17931600E+01, 0.31053300E+00, 0.16140000E+00, 0.86479600E-01, -.50599400E-01, 0.19259200E+00, 0.39904500E-01, -.50431100E+00, 0.10054800E+01, -.38051400E+00, -.22276100E+00, 0.23680500E+00, -.18324200E+00, -.28416800E-01, -.15449500E+00, -.30390400E-01, 0.53002600E+00, 0.25479100E+01, 0.97075900E-01, -.21102800E+00, -.91313000E+00, -.49428400E+00, -.51096500E-01, -.30335200E+00, -.72850000E+00, -.12265000E-01, 0.95768200E-01, 0.82538600E-01, -.19800000E+00, 0.25298000E+00, -.39642000E+00, -.29688800E-01, 0.10118400E+01, 0.19104800E-01, 0.17679300E+01, -.38039900E-02, 0.55788900E-01, 0.61056000E-01, 0.20898100E+00, -.27933400E-01, -.44634900E+00, 0.14518000E+00, 0.36541800E-01, 0.21742700E+00, -.73972300E+00, 0.10972100E+01, 0.18139100E-01, -.10813300E+01, -.86002700E+00, 0.24102800E+00, 0.57499300E+00, 0.45852300E+00, 0.63647000E+00, 0.65295300E-01, 0.76872000E+00, 0.10051900E+01, -.15656600E+00, 0.86990600E-03, 0.16304100E+01, 0.10501500E+00, 0.35197100E-01, 0.40169200E+00, 0.35363000E+00, -.14825900E+00, 0.37028400E+00, -.42108200E+00, 0.22901200E-01, -.10917000E+01, 0.37654000E+00, -.20598000E+00, 0.28369900E+00, -.40501900E-01, 0.17934000E+00, 0.65080900E+01, -.25138100E+00, 0.56378300E-01, -.75162200E+00, -.62457400E-01, -.78725900E+00, 0.49245000E-02, 0.80937100E+00, 0.30909900E+00, -.23253300E+00, -.11821400E+00, -.41023100E+00, 0.12669300E+01, -.91445400E+03, 0.25933000E+04, -.13081100E+04, 0.11581200E+03, -.12966400E+04, 0.88957300E+03, 0.95320300E+03, -.69706600E+03, 0.72680500E+03, -.99635300E+03, 0.45969300E+03, -.23484800E+04, 0.10377400E+04, -.51837700E+03, -.53255100E+03, -.51804300E+03, -.62117200E+03, -.31497300E+03, -.30616500E+03, -.35899300E+03, -.28875600E+03, -.19054600E+03, 0.95063600E+02, -.21332100E+04, 0.10646000E+04, 0.10325100E+04, 0.10665600E+04, -.25834300E+03, 0.35037800E+03, 0.62664000E+02, -.98466600E+03, -.74888000E+02, 0.28805000E+03, 0.20451800E+04, -.65444200E+02, -.17897700E+02, -.23945900E+03, 0.32476300E+02, -.87279000E+02, -.18260800E+03, 0.20425900E+03, 0.27754300E+03, 0.19572500E+03, -.15538600E+03, 0.35984100E+03, 0.33230900E+03, -.15717500E+03, -.32474200E+02, -.16621600E+03, 0.14062500E+03, 0.95314900E+02, -.22021700E+02, -.84691300E+02, -.73113400E+02, 0.28837400E+03, -.77748700E+03, -.31063500E+03, 0.15474600E+03, 0.18503800E+01, 0.15544400E+03, -.58949900E+02, -.78392600E+02, 0.19212800E+02, 0.23104000E+03, 0.16499100E+03, -.75596600E+02, 0.34362000E+03, 0.14915100E+04, -.78483800E+03, -.30015200E+03, -.74570200E+03, 0.43867600E+03, 0.42481100E+03, -.20496500E+03, 0.71301500E+03, -.72498900E+03, 0.13808500E+03, 0.96225200E+03, -.33565300E+03, 0.14912200E+03, 0.11074500E+03, 0.16786300E+03, -.44751100E+02, -.91450400E+01, -.35331700E+02, -.24164300E+03, -.14613700E+02, -.19880800E+02, 0.12762900E+03, 0.16650600E+04, -.85349000E+03, -.34936300E+03, -.83240500E+03, 0.32727800E+03, 0.39413100E+03, -.34845700E+03, 0.52834400E+03, -.91452600E+03, 0.96761500E+02, 0.70447800E+03, 0.45065800E+04, -.22448600E+04, -.23302400E+04, -.22534300E+04, -.11462400E+03, -.78389300E+03, -.31771700E+03, 0.15869100E+04, 0.75547500E+02, -.79582700E+03, -.40535100E+04, 0.26705400E+04, -.13318100E+04, -.11261800E+04, -.13352200E+04, -.43869700E+03, -.25446200E+03, -.34578500E+03, 0.61321800E+03, -.14929400E+03, -.34651100E+03, -.36465900E+03, -.10807600E+03, 0.10001500E+03, 0.13936000E+03, 0.53920800E+02, 0.13536900E+03, 0.35121300E+03, -.26885300E+03, -.35287800E+03, -.31549800E+03, 0.32459100E+03, -.13211200E+02, 0.84288200E+03, -.42029600E+03, -.12189100E+04, -.42124600E+03, -.34391500E+03, 0.88715000E+02, -.74008700E+03, -.60253500E+03, -.42148900E+03, 0.26538100E+02, -.11416200E+03, -.58441900E+02, 0.40101400E+02, 0.15889800E+03, 0.29137600E+02, -.15708300E+02, -.55886800E+02, 0.30382400E+02, 0.55660800E+01, 0.95839300E+01, -.11538900E+03, 0.23620500E+03, 0.14784600E+02, -.41720400E+02, -.13137000E+02, 0.18213900E+02, 0.26773400E+02, -.41296700E+02, -.98532000E+01, 0.61269200E+01, 0.63486200E+01, 0.75005300E+02, -.64677900E+02, -.78492300E+02, 0.59765300E+01, 0.64126100E+02, 0.19429600E+03, 0.76221400E+02, 0.11332600E+02, -.11010900E+02, 0.20530800E+03, 0.23115800E+03, -.11550400E+03, 0.71243800E+02, -.55234100E+02, 0.12473800E+03, -.10615300E+03, 0.82296900E+02 },
        { -.17735500E+02, 0.47239600E+00, 0.62392100E+00, 0.17679100E+01, -.22014500E+01, 0.53016100E+01, -.43346400E+00, 0.23716500E+01, -.50074900E+01, 0.50636500E+01, 0.11365400E+01, -.32440900E+01, -.83647400E+00, -.19092800E+00, 0.26751800E+00, 0.36580500E-01, 0.34979700E+00, 0.67960100E+00, -.15755600E+00, 0.34211400E+01, 0.56017100E+01, -.27075800E+01, 0.60816500E+01, 0.27284500E+01, 0.12383400E+00, 0.30222900E+00, -.16148300E+01, 0.22814900E+01, 0.86255300E+01, -.21728900E+01, 0.10571000E+01, -.66113400E+01, -.12232700E+01, 0.25110300E+01, -.69249300E+01, -.18652500E+01, -.12606500E+00, -.84034300E+01, 0.39919700E+00, -.35921100E+01, 0.24832200E+01, 0.30500900E+01, -.13365500E+01, -.14407600E+01, 0.76414800E+00, -.57546400E-01, -.31773400E+00, 0.30843000E-01, -.32894000E+01, 0.83189500E+00, -.39340100E+01, -.43397300E+00, -.20731500E-01, 0.52780100E+00, -.74125600E+01, -.89995700E+00, 0.78505500E-01, 0.50230800E+00, 0.57710900E+00, -.47612900E+00, -.23651200E+01, 0.49989000E+00, -.12542700E+01, 0.64356200E+00, -.12205600E+00, 0.19677800E+01, 0.20659300E+01, 0.10573500E+00, 0.27363700E+01, -.57926800E-02, 0.60435700E+00, 0.31545800E-01, 0.52620500E+00, 0.21139100E+00, 0.16566100E+01, -.12439100E+01, -.18241600E+01, -.95224600E+01, -.63939000E+00, -.13249000E+01, 0.29545300E-01, -.24377000E+01, 0.84287100E+00, 0.13363900E+01, -.57201700E+00, 0.18936000E+02, 0.10095500E+01, -.75466500E-01, 0.12910000E+00, 0.25935300E+01, 0.10244800E+01, 0.37679800E-01, -.40941700E+01, 0.56002400E-01, 0.52215300E+00, -.18171200E+01, -.15468800E+01, -.17600500E+01, -.45576300E+01, 0.57626500E-01, 0.12369600E+00, 0.56012800E+00, 0.10823400E+01, -.56042300E+00, -.23617100E+00, 0.22096400E+00, -.32130500E+00, -.98816900E+01, 0.89174800E+00, -.62323900E+00, 0.17687000E+01, -.44133700E+00, 0.12354800E+00, -.40697100E-01, -.81153500E+00, -.28114900E+01, 0.59898100E+00, 0.33837300E+01, -.88703100E-01, 0.49999300E+01, 0.35415900E+00, -.45766500E+04, 0.22942400E+04, 0.14790800E+04, 0.22882600E+04, -.42651700E+03, -.28282500E+04, 0.27637300E+04, 0.15524400E+04, 0.26009600E+04, -.20812100E+04, 0.47020600E+04, -.36642600E+04, 0.18308200E+04, 0.16440900E+04, 0.18293500E+04, 0.82776800E+03, 0.12500400E+04, 0.10212700E+03, -.11050000E+04, 0.41504600E+03, 0.90312300E+03, -.46787500E+03, 0.64590800E+04, -.32203500E+04, -.34022400E+04, -.32294000E+04, -.58571300E+03, -.83800000E+03, -.61024800E+03, 0.14384300E+04, -.11249300E+04, -.10379400E+04, -.22267400E+04, -.20849700E+04, 0.10080800E+04, 0.13311200E+04, 0.10428100E+04, 0.40695800E+03, 0.64556600E+03, 0.40816900E+02, -.10273300E+04, -.21200900E+03, 0.67870700E+03, 0.15025800E+03, -.41735600E+02, 0.11410800E+02, 0.45590600E+03, 0.21094500E+02, -.91531800E+02, 0.38637000E+03, -.25161400E+03, 0.20576300E+03, 0.79670800E+03, -.64469400E+01, 0.14000500E+04, 0.12687600E+04, -.62959900E+03, -.93142800E+03, -.63483300E+03, 0.37213300E+02, 0.46025000E+03, -.39433400E+03, -.72392000E+03, -.66930300E+03, 0.46235800E+03, -.24360700E+03, 0.10096300E+04, -.53626500E+03, -.18056200E+04, -.50499500E+03, -.84656400E+03, -.89275900E+02, -.74516200E+03, -.14350700E+04, -.12795300E+04, 0.73124000E+03, -.16083900E+04, -.44560600E+03, 0.20649200E+03, 0.22064500E+03, 0.22269900E+03, -.19252100E+03, -.31894600E+03, 0.40001800E+02, 0.33612100E+02, 0.42733100E+03, -.24541300E+03, 0.52112900E+03, 0.37331900E+03, -.18829500E+03, -.15067100E+04, -.18710100E+03, -.89518900E+03, -.20567800E+03, -.23726500E+03, -.77102600E+03, -.16800000E+03, 0.44845600E+03, -.78274100E+03, -.39281500E+04, 0.19548400E+04, 0.26071700E+04, 0.19645800E+04, 0.29918700E+03, 0.10622700E+04, -.15654200E+03, -.12971600E+04, 0.67184300E+03, 0.13145600E+04, 0.23444400E+04, -.20282900E+03, 0.97580500E+02, -.52635100E+03, 0.10123500E+03, -.10899700E+03, 0.17868300E+03, -.31279600E+03, -.27929100E+03, 0.17150900E+03, 0.37310300E+03, -.41175000E+02, 0.32439000E+04, -.16103000E+04, -.15574900E+04, -.16217400E+04, -.24077000E+03, -.35874200E+03, -.44126900E+03, 0.50880000E+03, -.66602400E+03, -.30099300E+03, -.13560300E+04, 0.12349300E+04, -.61866000E+03, 0.62491600E+03, -.61815100E+03, -.65782200E+02, -.30391400E+03, 0.10846500E+04, 0.11046900E+04, -.20345300E+03, -.25172500E+03, -.11462000E+04, -.10016600E+02, 0.15923500E+02, -.19731300E+03, 0.53387300E+01, -.12490900E+02, 0.14685600E+02, 0.41798500E+02, 0.10740400E+03, -.14348400E+03, 0.51056000E+02, 0.62412700E+03, 0.37288800E+02, 0.59267400E+02, 0.47318100E+02, -.14144900E+02, -.32083600E+02, 0.68573700E+02, 0.14877000E+02, 0.23292600E+02, -.38756900E+02, 0.22967100E+03, -.29081400E+03, 0.29255800E+01, 0.31322200E+03, -.46359900E+03, 0.16504500E+03, 0.22949700E+03, 0.94510300E+02, 0.14778300E+03, -.30764100E+03, -.31148300E+02, 0.20681600E+03, 0.10050600E+03, -.84428900E+02, 0.24740500E+03, -.12064800E+03, 0.24920700E+03 },
        { -.23129200E+02, 0.12315900E+01, 0.26365900E+00, 0.19462500E+01, -.55175600E+00, 0.14989000E+01, -.10215000E+01, 0.73111100E+00, -.81354600E-01, 0.11927400E+01, 0.41286500E-01, 0.39685400E+00, 0.13655900E+01, 0.87391200E-01, 0.75171300E+00, -.99367500E-01, 0.12067500E+01, 0.26761800E+00, -.33221600E+00, -.11070800E+01, -.76892700E+00, -.22141100E+00, 0.10981000E+02, 0.73166100E+00, -.11884700E+00, -.13150700E-01, 0.16232800E-01, -.16399000E-01, -.75092900E+00, -.18511300E+01, -.85644500E+00, -.10930700E+01, 0.76284600E-01, 0.92110500E+00, -.13323500E+01, -.34099300E+00, -.21814200E+00, -.12021800E+01, -.21064700E+00, 0.18213000E+00, 0.25555300E+00, 0.82282500E+00, -.70623100E+00, -.41872000E+00, 0.77219000E+00, 0.17769100E-01, -.24327900E-01, 0.10240800E-01, 0.16942000E+00, 0.14853400E+00, 0.15258700E+01, -.45847500E+01, 0.60906800E-01, 0.84381700E-01, 0.38780800E+00, 0.45589100E+00, -.43591400E-01, -.56954900E+00, 0.46815400E+00, 0.49560400E-01, -.32426700E-02, -.61036500E+00, 0.15551000E-01, -.54148200E-01, 0.61153400E+00, -.28290800E-01, -.23375500E+00, -.26077500E-01, -.37364700E+00, 0.35038600E-02, 0.12577600E+00, 0.13453600E-02, -.33088700E-01, 0.92816700E-01, -.17427400E+00, -.64929400E+00, 0.35754100E+00, 0.29322900E+01, -.67425200E+00, -.44051300E+00, 0.76389000E-02, 0.12805300E+01, -.24261700E+00, -.32431400E+00, 0.70438600E-01, 0.38291200E+01, 0.61061500E-01, 0.18310300E+00, -.44636200E+00, 0.28796400E+01, 0.15770900E+00, 0.56998500E-01, -.14683700E+01, 0.63456900E+00, 0.94607000E-01, -.11809300E+01, -.19763500E+00, 0.38269200E+00, 0.19321500E+00, -.34717700E+00, 0.83019700E-01, 0.46070700E+00, 0.60229900E-01, -.36379200E+00, 0.34598300E+00, -.96110000E+00, 0.25659800E-02, 0.51288800E+01, 0.39075000E+00, -.33205800E+00, -.31852000E+01, -.11111000E+01, -.85773800E+00, -.27759600E-01, 0.30626500E+00, -.15299700E+00, 0.15800000E+00, -.73600700E+01, -.50407200E+00, 0.80629500E+00, -.11878900E+00, -.16282100E+00, -.86990900E+02, 0.25856300E+03, 0.12379200E+00, 0.22059200E+03, -.39383500E+03, 0.40517600E+03, 0.74213100E+03, 0.33885700E+03, -.47148300E+03, 0.51907200E+03, 0.48156200E+03, -.24210000E+03, -.12884100E+03, -.24352000E+03, -.15396600E+03, 0.35200900E+03, -.26761800E+03, -.25337800E+03, -.31778700E+03, 0.25332200E+03, -.30886500E+03, 0.22020400E+04, -.11169100E+04, -.11266500E+04, -.11013000E+04, -.37576700E+03, -.23103600E+03, -.30643200E+03, 0.32141800E+03, -.61076900E+03, -.27203600E+03, -.75817600E+03, -.67466700E+03, 0.26295600E+03, 0.28119600E+03, 0.33763800E+03, 0.13230700E+03, 0.17821200E+03, -.16254000E+02, -.32208500E+03, 0.10189300E+02, 0.21835000E+03, 0.19783500E+03, 0.67869200E+03, -.29867200E+03, -.11421200E+03, -.33980300E+03, 0.79759200E+02, 0.14973500E+03, -.64954200E+02, 0.50800600E+02, -.13451200E+02, 0.98152100E+02, 0.61878800E+02, 0.80390400E+03, -.40189900E+03, -.35824300E+03, -.40105400E+03, 0.17529400E+03, 0.13583300E+03, -.25727600E+03, -.32673900E+02, -.21934000E+03, 0.14722800E+03, -.33478600E+03, 0.53671300E+03, -.40620200E+03, -.20933400E+00, -.26801900E+03, -.75913900E+02, 0.10051700E+03, -.37383800E+03, -.65797900E+03, -.56049500E+03, 0.38087100E+03, -.47831000E+03, -.56772900E+03, 0.29571300E+03, 0.12136200E+03, 0.28402100E+03, -.12136800E+03, -.17406200E+03, 0.10607900E+03, -.14164600E+03, 0.22308000E+03, -.15085200E+03, 0.36620900E+03, 0.44301800E+03, -.28653800E+03, -.13205600E+03, -.22064800E+03, -.17701200E+03, -.73444500E+02, -.19156900E+03, -.28328800E+03, -.26757100E+03, 0.17017800E+03, -.31440000E+03, -.59800000E+03, 0.33340100E+03, 0.35819400E+03, 0.29800400E+03, 0.20099700E+03, 0.68846900E+02, -.83671900E+02, -.89731600E+02, 0.41516400E+03, 0.53187600E+02, -.83205700E+02, 0.60621400E+03, -.28566400E+03, -.39285800E+03, -.30275000E+03, -.17181400E+03, -.35601900E+02, -.17630100E+03, 0.69947400E+02, 0.67959100E+02, -.34497600E+02, -.41737000E+03, 0.99733400E+03, -.44052800E+03, -.40537700E+03, -.49871300E+03, 0.89584400E+01, 0.83861800E+02, -.24483400E+03, 0.23808300E+02, -.29806600E+03, 0.65687700E+02, -.45290400E+03, 0.11019800E+04, -.57115900E+03, -.55869400E+03, -.54966100E+03, -.85902900E+02, 0.12837900E+03, -.70776300E+02, 0.29972600E+03, -.20133000E+03, 0.61150800E+02, -.29930500E+03, -.19508600E+03, 0.12466000E+03, 0.12325300E+03, 0.96912000E+02, -.10801900E+02, -.60715200E+02, 0.11612600E+03, 0.16417000E+03, 0.41407200E+02, -.72997400E+02, 0.17731700E+03, 0.27075900E+02, 0.18623400E+02, 0.11241700E+01, 0.66414900E+01, 0.31140600E+01, -.43765200E+01, -.34464900E+02, 0.14465400E+02, -.74914700E+00, 0.16384000E+03, -.17899100E+03, -.29051800E+02, 0.78959300E+02, -.27582300E+03, 0.12182700E+03, 0.16608300E+03, 0.25209100E+02, 0.50213000E+02, -.11659300E+03, 0.33926100E+02, 0.10075100E+03, 0.55942000E+02, -.75714100E+02, 0.18059500E+03, -.21873000E+03, 0.18270600E+03 },
        { -.58930400E+01, 0.12241000E+00, 0.15463400E+00, -.49414200E+00, -.65091200E+00, 0.43659400E+00, 0.87543500E+00, 0.24203700E+00, -.42993200E+01, -.30662600E+00, -.54917600E-01, -.10756900E+01, -.12702800E+00, -.28039500E-01, 0.15007900E-01, -.92489800E-02, -.11052300E+01, -.59629500E+00, -.48948100E+00, 0.11048800E+01, -.19516800E+00, 0.19290100E+00, -.46780500E+01, -.99138700E+00, -.18266500E+00, -.75081300E-01, -.13092800E-01, -.51534300E-01, 0.56194700E+00, -.13772600E+00, 0.93736900E+00, 0.18384400E+01, -.10944800E+00, -.97849800E+00, 0.48657100E+01, 0.28205600E+00, 0.92351900E-02, 0.10204400E+01, -.13119500E+00, 0.80042800E+00, -.63567300E+00, 0.13222300E+01, 0.12027400E+01, -.38657900E+00, -.45433800E-01, 0.67359200E+00, 0.13977700E+00, -.30417800E-01, 0.17659000E+00, -.72357100E-01, 0.22955700E+00, -.26000500E+01, 0.24543500E+00, -.25437100E+00, -.14743100E+01, 0.26246600E+00, -.24375100E-01, 0.54447700E+00, -.34497200E+00, 0.13920500E+00, 0.85036400E-01, -.30985200E+00, 0.14511400E+00, 0.69035700E-01, -.48602500E-01, -.65393100E-01, -.84314400E-01, -.13481700E-01, 0.89379700E-01, -.30075200E-02, 0.62387400E-01, 0.22793300E+00, 0.30531800E+00, -.11908900E+00, 0.23195400E+00, 0.66233800E-01, 0.39662900E+00, 0.18425100E+00, 0.11239800E+01, -.47189000E+00, -.56917900E-02, 0.31943400E+00, 0.60538200E+00, -.49538500E-01, 0.25672400E-03, 0.74009100E+00, -.37604700E+00, -.10183300E+00, -.61229000E+00, -.12616700E+00, 0.82200900E+00, 0.41520500E-01, -.19885800E+01, -.25671800E+00, 0.31970300E+00, 0.91122700E-01, 0.25812500E+00, -.33019000E+00, 0.86738000E-01, 0.60956600E-01, -.10783700E+00, -.45048700E+00, 0.40402500E-01, -.56469800E+00, 0.21725300E+00, 0.18483200E+00, 0.19656200E+00, 0.12280900E+01, 0.10350600E+00, 0.23229900E-01, -.10005800E+00, -.45840900E-01, 0.30704700E-01, 0.13961200E-01, 0.36121000E+00, 0.57898400E-01, -.72493600E-01, 0.45947900E+01, 0.49857200E+00, 0.15608900E+01, 0.28896800E+00, 0.20439100E+00, 0.38613400E-01, 0.13301600E+04, -.19838000E-01, 0.23592300E+03, 0.13586800E+03, -.53083600E+02, 0.18178800E+03, -.17114300E+03, 0.97387500E+02, -.18359300E+04, -.18198600E+03, 0.91533800E+02, -.25040800E+03, 0.92611000E+02, 0.24322100E+02, -.33664800E+03, 0.23416500E+02, -.17925500E+03, -.82061800E+02, -.15852500E+03, 0.92480400E+03, 0.19659700E+04, -.98546800E+03, -.13341700E+04, -.98295600E+03, -.32331900E+02, -.28907600E+03, -.19255900E+03, 0.89838300E+03, -.19317800E+03, -.33340100E+03, -.10420900E+03, 0.49435400E+03, -.27838700E+03, -.47934900E+03, -.24730800E+03, -.11652800E+03, -.27862400E+03, 0.76485500E+02, 0.40684100E+03, 0.73954900E+03, -.33439800E+03, -.55261800E+02, -.24615300E+02, 0.16838200E+02, -.61175300E+03, 0.12360400E+02, -.44825700E+03, -.12222900E+03, 0.13544400E+03, -.15415300E+03, 0.15407800E+03, -.15052300E+03, -.35195100E+03, -.10607900E+04, 0.51925200E+03, 0.13372000E+03, 0.53029400E+03, 0.83977500E+02, -.52246100E+02, 0.46319300E+03, 0.32240600E+03, 0.28334000E+03, -.51089700E+02, 0.27365200E+03, -.10216100E+04, 0.50931200E+03, 0.28469000E+03, 0.51077000E+03, 0.78043600E+02, -.11316900E+03, 0.52786100E+03, 0.27926100E+03, 0.62560000E+03, -.22554900E+03, 0.15608100E+03, 0.10293800E+03, -.69099900E+02, 0.21083000E+03, -.51480400E+02, 0.59226200E+02, 0.84845700E+02, 0.58542900E+02, 0.18604800E+02, -.20060900E+03, 0.96371800E+02, -.14918500E+03, -.75723700E+03, 0.37314100E+03, 0.80985800E+02, 0.37852200E+03, 0.11307100E+03, -.53016300E+02, 0.27878800E+03, -.91105900E+01, 0.31592100E+03, -.10817200E+03, -.23038300E+03, -.12327800E+04, 0.62383700E+03, 0.49086800E+03, 0.61649900E+03, 0.10237600E+03, 0.18731800E+02, 0.46461600E+03, -.35053900E+03, -.19179500E+03, 0.90144000E+02, -.63367300E+03, -.17940000E+03, 0.91534600E+02, 0.53712000E+03, 0.89661600E+02, 0.18834200E+03, -.10843100E+03, 0.24430800E+03, 0.82049500E+02, -.26719000E+03, -.37730100E+02, -.17919700E+03, -.12897000E+04, 0.66229200E+03, 0.19433100E+03, 0.64482000E+03, 0.88083200E+02, 0.62644400E+02, 0.22608000E+03, -.12450500E+03, 0.24989800E+03, 0.44957200E+02, 0.43748100E+03, 0.25044500E+03, -.13208700E+03, -.42265700E+03, -.12538100E+03, 0.14028100E+03, -.11688100E+03, -.23921500E+03, -.26523000E+03, -.50624200E+03, -.10885600E+03, 0.38663600E+03, 0.33578800E+03, -.16270600E+03, -.97119800E+02, -.16787600E+03, -.62815100E+02, -.13788700E+01, -.12372500E+03, -.17754500E+03, -.44752300E+03, 0.62649300E+02, -.22333900E+03, -.23556900E+02, 0.27026800E+00, -.31021200E+02, -.42064200E+01, 0.32339100E+02, -.37402700E+02, -.74756900E+01, -.80284300E+01, 0.33661200E+02, -.28113000E+02, 0.53176100E+02, 0.58680900E+00, -.47058100E+01, 0.27923700E+03, -.12873500E+03, -.35511400E+01, 0.73162900E+02, -.16432900E+02, 0.35953400E+02, -.47264700E+02, 0.17573900E+02, -.19021300E+02, 0.53056900E+02, -.30616700E+02, 0.20521300E+03, -.78458400E+01 },
        { -.16750200E+02, 0.21870800E+00, 0.63681100E+00, -.22039300E+01, -.18062000E+01, 0.14169300E+01, -.14867300E+00, -.23102500E+00, 0.46447600E+00, 0.12405700E+01, -.15710000E+00, 0.21237300E+00, 0.28717400E+00, -.20563500E-01, 0.19912200E+00, 0.26183100E+00, -.12056400E+00, 0.21581900E+00, -.52365800E-01, 0.10545600E+01, 0.67455300E+00, 0.35400100E-01, 0.68609300E+01, 0.46941800E+00, 0.40053000E+00, -.42563000E+00, 0.38331500E+00, -.23249100E+00, 0.75287900E+00, -.17271200E+00, 0.36132600E+00, 0.20566700E+01, -.34102200E-01, -.94295500E+00, -.21659500E+00, 0.73242900E-01, -.95416400E-01, -.20892000E+01, 0.18983100E+00, -.12437700E+00, -.14837800E+00, 0.25072500E+00, 0.44642000E+00, -.87436300E+00, -.27269300E+00, 0.78400800E-01, 0.21807500E+00, 0.14331100E-01, -.26054500E+00, 0.13652300E+00, -.92915800E+00, -.38459500E+01, 0.31636800E+00, 0.31474800E+00, -.34381700E+00, -.67614200E+00, -.70915500E-01, 0.11132100E+00, 0.25773600E+00, 0.34882500E-02, -.16604500E+00, -.33455600E+00, 0.14665800E+00, 0.67804200E-01, -.36086100E+00, -.18588200E+00, -.29449900E+00, -.24065000E-03, 0.25684100E-01, -.17563500E-03, 0.60556500E-01, 0.27590900E+00, 0.30664200E+00, 0.37121000E-01, -.59246500E-01, 0.32328800E+00, 0.47162300E+00, 0.17803100E+01, 0.47892800E+00, 0.73891600E+00, 0.70314700E-01, -.12509900E+00, 0.10918700E+01, -.41356800E+00, 0.14219900E+01, 0.32848100E+01, 0.30731900E+00, 0.19273700E+00, -.42414600E+00, 0.11995800E+01, -.23064100E+00, 0.37501300E-01, 0.16330000E+01, -.14933300E+00, -.53672700E-01, 0.17096600E+00, 0.16352700E+00, -.16615700E+00, 0.10802300E+01, 0.57144400E-01, 0.32164900E-01, -.10732000E+01, 0.59116000E+00, 0.18526700E+00, -.95788100E-01, -.66206900E+00, -.18959200E+00, 0.32421800E+01, 0.83917100E-01, -.55668300E-01, 0.20553900E+01, -.86013900E-02, 0.11927100E+00, -.23698400E-01, -.26408200E+00, 0.59152000E+00, 0.54366900E-01, 0.73985300E+00, 0.21730400E-01, 0.27588700E+01, -.30378600E+00, 0.13212300E+00, 0.62290400E-01, 0.45491500E+00, 0.27370700E+01, 0.26158500E+03, -.30635900E+02, 0.61994100E+02, 0.14637300E+03, 0.12900000E+02, -.12634300E+03, 0.50279200E+03, 0.23761800E+03, -.11893900E+03, -.23177900E+03, -.11923200E+03, -.11117200E+03, 0.12267200E+03, -.53309400E+02, 0.48446100E+02, -.41534300E+02, 0.10542800E+03, -.36200800E+03, -.12469400E+04, 0.62160000E+03, 0.65812700E+03, 0.62370200E+03, -.37694900E+02, 0.16318200E+03, 0.36272700E+02, -.55425200E+03, -.58302700E+02, 0.16296200E+03, 0.55488200E+03, -.46219300E+02, 0.24570300E+02, 0.75762600E+02, 0.22209500E+02, 0.46336500E+02, 0.13975200E+03, -.86015500E+02, -.12612100E+03, -.30589100E+03, 0.15686800E+03, 0.44352600E+01, 0.42436700E+03, -.21235400E+03, -.72225600E+02, -.21179100E+03, 0.75906100E+02, 0.31898800E+02, 0.26057000E+02, 0.69698800E+02, -.80660400E+02, 0.81773100E+02, -.46513000E+03, 0.39616000E+03, -.20170200E+03, -.11905300E+03, -.19884000E+03, -.70038400E+02, -.22346200E+02, -.12684900E+03, -.76022600E+01, -.87975500E+02, -.25466600E+02, -.63221300E+02, 0.71494200E+03, -.35301900E+03, -.30739600E+03, -.35774500E+03, 0.63287200E+02, 0.14112800E+03, -.29988800E+03, 0.53945200E+02, -.35376600E+03, 0.43629400E+02, 0.15571300E+03, -.18140800E+03, 0.94534900E+02, 0.15688900E+03, 0.90592400E+02, -.18451300E+02, 0.20382800E+02, 0.14700800E+01, -.64638200E+02, 0.11277400E+03, 0.39400500E+01, 0.75712500E+02, 0.64782900E+03, -.32067800E+03, -.27934700E+03, -.32464800E+03, 0.86506900E+02, 0.10259600E+03, -.20309500E+03, 0.16781200E+03, -.33001800E+03, 0.16582300E+02, 0.25368900E+03, 0.21128100E+04, -.10552900E+04, -.11313300E+04, -.10555600E+04, -.10946200E+03, -.40628000E+03, -.80224800E+02, 0.70846400E+03, 0.20119200E+01, -.36589900E+03, -.95088200E+03, 0.69340500E+03, -.34640300E+03, -.67284500E+03, -.34700200E+03, -.13323500E+03, -.99414300E+02, -.10404400E+03, 0.10444600E+03, -.60979200E+02, -.10937900E+03, -.20188000E+03, 0.40227600E+03, -.20008200E+03, 0.13494000E+02, -.20131700E+03, -.15072200E+02, 0.13879300E+02, -.90946900E+02, -.55861800E+01, -.11308800E+03, 0.13298800E+02, -.11355000E+03, 0.40164900E+03, -.20232700E+03, -.52781300E+01, -.20200100E+03, -.16299700E+03, -.16098800E+02, -.61685500E+01, 0.95834700E+02, -.42455800E+02, -.15184800E+02, -.30322000E+03, -.40402800E+03, 0.19940500E+03, 0.10908400E+03, 0.20251100E+03, 0.20708000E+02, -.33015400E+02, 0.12017700E+03, 0.58821800E+02, 0.26149100E+03, -.61198400E+02, 0.20877500E+03, 0.65926100E+01, 0.88804600E+00, -.51846100E+01, 0.24379000E+01, 0.57381100E+01, -.73410200E+01, -.24798100E+01, 0.21005300E+01, 0.11799000E+01, 0.28923200E+02, -.30943700E+02, -.88245000E+01, 0.17887800E+02, -.15118500E+03, 0.89147500E+02, 0.13950200E+02, 0.30223100E+01, 0.47692000E+01, 0.32957400E+02, 0.10219400E+03, -.37241100E+02, 0.41086200E+02, -.19436400E+02, 0.22280300E+02, -.78855300E+02, 0.24343100E+02 },
        { 0.21290000E+01, -.93063900E-01, -.74777600E-01, -.11562500E+01, 0.30173900E+00, -.50808800E+00, 0.18718800E+00, -.25671900E+00, -.57268500E-01, -.41202300E+00, -.71066400E-03, 0.19977700E-01, 0.12099600E-01, -.75121500E-02, -.22154300E+00, 0.14206700E-01, -.19814000E+00, -.16462400E+00, -.41687700E-01, 0.62907600E-01, 0.24358400E-01, 0.89167300E-01, -.89732600E+00, -.43950600E+00, 0.10845100E-01, 0.42249700E-01, 0.20435900E+00, -.28587100E+00, -.58658500E+00, 0.85582700E+00, -.30743100E+00, 0.17671900E+00, 0.58057400E-01, 0.14312500E+00, 0.10603800E+01, -.87707000E-01, -.12764000E-01, 0.30972000E-01, -.27500700E-01, -.25793100E+00, 0.21096100E+00, 0.47105800E+00, 0.24692300E+00, -.54583600E+00, 0.20400600E+00, 0.65154500E-01, -.73394100E-01, 0.31642200E-02, -.17854700E-01, -.92798000E-02, 0.20450600E+00, 0.66860200E+00, 0.37451600E-01, 0.19558100E-01, -.49418100E-02, 0.34206800E-01, -.15780400E-01, 0.53754800E-01, -.14083900E-02, 0.29270700E-02, -.60327400E-01, -.63817800E-02, 0.15475600E+00, -.43342000E-01, 0.31563000E-01, 0.45000800E-01, -.77048900E-01, 0.11766600E-01, -.17976800E+00, 0.66277500E-03, 0.38620100E-01, -.68501900E-01, 0.10025100E-01, -.17973000E-01, -.10220400E+00, -.33310400E+00, 0.26561800E-01, -.13746700E+01, -.38300500E+00, 0.15897000E-01, 0.95592500E-02, 0.61390600E-01, -.16622100E+00, -.26377600E-01, -.45125400E-01, 0.12612600E+01, 0.14467700E+00, 0.38930500E-01, 0.74400100E-01, 0.16516900E+00, 0.14006100E+00, 0.28357900E-02, -.62326200E+00, -.50693700E-01, 0.12543200E+00, 0.42570000E-01, -.19661800E+00, -.19175800E+00, -.30741900E+00, -.18853500E+00, 0.18102500E-01, 0.39740800E+00, 0.42795100E-01, -.16271900E+00, -.52156400E-02, 0.10666900E+00, -.19663500E-01, 0.17610000E+00, -.15893000E-01, -.16402300E-02, -.47707100E+00, 0.17020400E-01, -.62990600E-01, -.22026600E-02, 0.16702500E+00, -.58271000E-01, -.19067900E-01, -.79914100E+00, 0.83056400E-02, -.24733100E+00, 0.15484900E+00, 0.42413600E-01, -.16216900E-01, -.10617900E+00, 0.21472700E-02, -.29343200E+03, 0.18075800E+03, -.24562700E+03, -.42568600E+03, -.13999000E+03, 0.18006700E+03, -.59825500E+03, 0.58481300E+03, -.29219700E+03, -.27642000E+03, -.29258100E+03, 0.18344000E+02, -.82431400E+02, -.10376300E+02, 0.29189600E+03, -.44646700E+02, -.11612900E+03, 0.26262800E+03, -.20256300E+03, 0.10099900E+03, -.62180500E+02, 0.10124800E+03, 0.21166800E+02, 0.16116700E+02, 0.63772900E+02, 0.24961300E+02, 0.76631000E+02, 0.44321700E+02, 0.10199300E+03, 0.25153200E+03, -.12038700E+03, -.15015100E+03, -.12586400E+03, -.51573000E+02, -.12120800E+03, -.34486100E+01, 0.13264000E+03, 0.12215500E+03, -.11571400E+03, -.48601300E+02, -.14712300E+03, 0.75914800E+02, -.68025500E+02, 0.73512900E+02, 0.92506500E+01, -.12637900E+03, 0.79438200E+02, 0.32728100E+02, 0.11952000E+02, -.95854000E+02, 0.28896700E+02, -.11090100E+03, 0.57549500E+02, 0.59693400E+02, 0.55548100E+02, 0.21304100E+02, 0.27741800E+02, -.39151000E+02, -.40034000E+01, 0.10643400E+02, 0.94318400E+01, -.80821900E+02, -.76903300E+03, 0.38748400E+03, 0.43738200E+03, 0.38455500E+03, 0.50071500E+02, -.67063700E+02, 0.21048300E+03, -.11082000E+03, 0.28655800E+03, -.47153100E+02, -.55852300E+01, 0.15707700E+03, -.77300500E+02, -.12966800E+03, -.78517700E+02, 0.38742500E+02, 0.38453400E+02, -.14088700E+02, 0.34435700E+02, -.78516100E+02, 0.27780400E+02, -.11046600E+03, -.53928300E+03, 0.26781200E+03, 0.34032000E+03, 0.26973300E+03, 0.41088400E+02, -.39978900E+02, 0.10631700E+03, -.12546100E+03, 0.16426400E+03, -.14623800E+02, -.10896700E+03, -.94710000E+02, 0.47521200E+02, -.73230300E+01, 0.47246300E+02, 0.30349200E+02, -.28255900E+02, -.11818800E+02, 0.11629700E+02, 0.25265400E+02, -.69353600E+02, -.11848100E+03, 0.64884800E+02, -.32723800E+02, 0.14695200E+03, -.32402500E+02, 0.20966700E+02, -.49373000E+02, 0.49448200E+02, 0.64104300E+02, -.53007900E+02, -.67220100E+02, -.28823700E+02, -.53951300E+03, 0.26643200E+03, 0.12973800E+03, 0.26970900E+03, 0.35145600E+02, 0.50756800E+02, 0.10415200E+03, -.45168100E+02, 0.13840700E+03, 0.39393600E+02, 0.23990500E+03, -.53512300E+03, 0.26886600E+03, 0.46564900E+02, 0.26769100E+03, 0.92221000E+02, 0.17479400E+03, -.12392600E+03, -.13479700E+03, 0.14535000E+03, 0.12355200E+03, 0.32663200E+03, 0.13317800E+03, -.67349900E+02, 0.27730100E+02, -.66678500E+02, 0.17579800E+01, 0.34310800E+02, -.62576800E+02, -.36047800E+02, -.83165000E+02, 0.27044400E+02, -.12633300E+03, -.10402800E+02, 0.30528400E+01, -.85597500E+01, 0.14927100E+01, 0.35912400E+01, -.74786100E+01, -.10076700E+02, -.39211300E+01, 0.99516400E+01, -.51895400E+02, 0.60268100E+02, -.90370200E+01, -.57306300E+02, 0.45681700E+02, -.22384700E+02, -.47027200E+02, -.17614500E+02, -.95523800E+01, -.54601100E+00, -.37876700E+02, 0.13229100E+02, -.94729200E+01, 0.81745400E+01, -.59022800E+02, -.18748000E+02, -.52938100E+02 },
        { -.16968500E+02, 0.24513400E+00, 0.61612400E+00, 0.37858900E+01, -.16132800E+01, 0.21322400E+01, 0.92512900E+00, 0.45329500E+00, -.14067300E+01, 0.16679000E+01, 0.13353600E+01, -.90062900E+00, -.41524500E+00, -.11171900E+00, 0.35928200E+00, -.23269600E+00, 0.44888800E-01, -.20456100E+00, -.19656100E+00, -.22091000E-01, 0.25988300E+00, -.17139800E+01, 0.40097400E+01, 0.12779900E+01, -.35953100E-01, 0.33796400E+00, -.62288600E+00, 0.13860100E+01, 0.24269300E+01, -.24995500E+01, -.39818700E+00, -.35517500E+01, -.30034500E+00, 0.17849800E+01, -.24829400E+01, -.78616800E+00, -.44525100E-01, -.34653300E+01, 0.87855500E-01, -.73338100E+00, 0.95003300E+00, 0.12793800E+01, -.82429500E+00, -.18998100E+01, 0.13992500E+01, -.69866400E+00, -.21496200E+00, 0.72383100E-02, 0.15463300E+01, 0.35369000E+00, 0.12124600E+01, -.85753300E+01, -.31737000E+00, -.17548700E+00, 0.18402000E+00, 0.11306100E+01, 0.12785900E-01, -.73931000E+00, 0.13233700E+01, -.11542300E+00, 0.67476500E+00, -.81238100E+00, -.16734900E+01, 0.16432200E+00, 0.19041000E+01, 0.38739500E+00, 0.75643500E+00, 0.22938400E-01, 0.78239500E+00, 0.62833300E-02, 0.15075400E+00, -.33711100E+00, -.26306600E+00, 0.44244100E-01, 0.10371400E+01, 0.16684300E+01, 0.21016800E+01, 0.42623500E+01, 0.26075700E+00, -.90780800E-01, 0.82780200E-01, 0.19508100E+01, 0.25432700E+01, -.17916300E+01, 0.19971500E+00, 0.82620800E+01, -.45520100E+00, 0.51212300E+00, -.29671000E+00, 0.51548400E+00, -.49543400E+00, 0.68947000E-01, -.33253400E+01, 0.25843300E+00, -.12202900E-01, -.19547700E+01, -.17879400E+00, 0.17498800E+01, -.26639500E+01, 0.55613700E+00, -.13654800E+00, 0.17780600E+00, 0.42828900E+00, 0.15993100E+01, 0.29247200E+00, -.70157600E+00, -.16462700E+00, -.17675000E+01, 0.74130800E+00, -.43610100E+00, -.13723700E+01, -.15951700E+00, -.19459500E+00, -.26865400E-01, 0.19642100E+00, -.50966400E+00, 0.34827000E+00, -.92555900E+01, 0.11172800E+00, 0.26011600E+01, 0.24979700E+00, -.10267800E+00, -.28969200E-02, 0.26917300E+00, 0.19289800E-01, 0.28923500E+01, -.11931400E+04, 0.15016300E+04, 0.25717400E+04, 0.99207100E+03, -.11470600E+04, -.32019200E+04, -.42967100E+04, 0.21551300E+04, 0.15716700E+04, 0.21470100E+04, 0.24817100E+03, 0.71791700E+03, 0.40916300E+03, -.13463900E+04, 0.76085500E+03, 0.54291400E+03, 0.20545600E+04, 0.44375600E+04, -.22153400E+04, -.16182500E+04, -.22187900E+04, -.50475800E+03, -.36077700E+03, -.75852100E+03, 0.68922800E+03, -.11675500E+04, -.75246300E+03, -.11756900E+04, -.24441200E+04, 0.12024600E+04, 0.11577700E+04, 0.12228200E+04, 0.56139000E+03, 0.10668300E+04, -.90586300E+02, -.10331700E+04, -.48816400E+03, 0.10673000E+04, 0.56608800E+03, 0.62662600E+03, -.32733300E+03, 0.56739500E+03, -.31335000E+03, -.11743200E+03, 0.43700400E+03, -.18118600E+03, -.85775600E+02, 0.27426400E+03, 0.13809000E+03, 0.25345100E+03, 0.22238400E+04, -.11378000E+04, -.11141300E+04, -.11118600E+04, 0.28534100E+03, 0.25978500E+03, -.62938700E+03, -.64628700E+03, -.75652200E+03, 0.33545900E+03, -.69241000E+03, 0.70955900E+03, -.36417000E+03, -.11566200E+04, -.35477000E+03, -.41157100E+03, -.27336500E+03, -.37594100E+03, -.54593000E+03, -.56158000E+03, 0.38054400E+03, -.48895800E+03, -.11885900E+04, 0.60653800E+03, 0.65392200E+03, 0.59428000E+03, -.34822900E+03, -.61211600E+03, 0.24216300E+03, -.46603400E+02, 0.83121200E+03, -.48102400E+03, 0.79340300E+03, 0.22598300E+02, -.64133000E+00, -.88630100E+03, -.11235900E+02, -.48687600E+03, -.21733900E+03, 0.88905600E+02, -.20112600E+03, 0.21033400E+03, 0.32997500E+03, -.39494800E+03, -.36917800E+04, 0.18456600E+04, 0.21899000E+04, 0.18458300E+04, 0.50387500E+03, 0.54080300E+03, 0.77923800E+03, -.59374100E+03, 0.10887700E+04, 0.97882000E+03, 0.10005400E+04, -.12891600E+04, 0.64397000E+03, -.30881400E+03, 0.64460300E+03, 0.68485200E+02, 0.27443900E+03, 0.17414800E+02, -.58140100E+03, 0.35602000E+03, 0.45051200E+03, 0.76272400E+03, 0.44753000E+04, -.22459400E+04, -.18085900E+04, -.22374000E+04, -.29737100E+03, -.25517200E+03, -.92272100E+03, 0.35756300E+03, -.10206700E+04, -.30066200E+03, -.16211400E+04, 0.18832200E+04, -.96063700E+03, -.33488200E+03, -.94146400E+03, -.45598200E+03, -.73930800E+03, 0.12812100E+04, 0.14644400E+04, 0.76214100E+02, -.75502600E+03, -.13356900E+04, -.93409000E+03, 0.46784000E+03, 0.25812500E+03, 0.46704600E+03, -.41126300E+02, -.27692400E+03, 0.48408900E+03, 0.13692400E+03, 0.34246800E+03, -.13759100E+03, 0.77173000E+03, 0.71124900E+02, 0.36464700E+02, 0.45649700E+02, -.22690300E+01, -.75271400E-01, 0.29735700E+02, -.27085100E+02, 0.30585100E+02, -.53565400E+02, 0.39403000E+03, -.50930200E+03, -.25558000E+02, 0.25340200E+03, -.21003300E+03, 0.39042800E+03, 0.39418100E+03, 0.11395700E+03, 0.73067700E+02, -.28461400E+03, -.14680600E+03, 0.14844200E+03, 0.17495900E+03, -.10652600E+03, 0.47516300E+03, -.11093400E+03, 0.39995600E+03 },
        { 0.50723700E+01, -.17179800E+00, -.17823300E+00, 0.26075400E+00, 0.45985600E+00, -.12297600E+01, 0.11098000E+01, -.26569700E+00, -.78634100E+00, -.12191300E+01, 0.22112700E-01, 0.48418800E-01, -.35778000E-01, 0.34557800E-01, 0.30643900E+00, -.28241400E+00, -.24666000E-01, 0.31338900E+00, 0.40576100E+00, 0.10117900E+00, 0.26045200E+00, -.76558100E-01, 0.36402900E+01, 0.13748300E-01, -.42677400E-01, -.53840500E-01, 0.17893600E+00, -.26831400E+00, -.14638500E+00, 0.26993800E+00, -.15748800E+00, 0.11719900E+01, 0.69841200E-01, -.78712900E-01, -.87512000E+00, -.84577800E-01, -.17217600E+00, -.12016900E+01, 0.16114800E+00, -.77990700E+00, 0.20398700E+00, 0.30232700E+00, 0.10413200E-01, -.11491200E+01, -.24714200E+00, 0.67279100E-01, -.53986800E-01, 0.46350200E-01, 0.35370400E+00, -.37364600E-02, -.43556500E+00, -.25106800E+01, -.88194600E-01, 0.32683100E+00, 0.30358100E+00, -.18783400E-01, -.57074200E-01, 0.29004900E+00, 0.91814500E+00, -.96257900E-01, -.35540700E-01, -.13942000E+00, 0.46977900E+00, -.90121400E-01, 0.12218200E+00, 0.18301900E+00, 0.73348900E+00, -.35273400E-01, 0.38649400E+00, 0.40970900E-02, -.17223200E+00, 0.30021200E+00, -.85735000E-01, -.30564900E-01, 0.38777900E+00, 0.14817300E+00, -.69268300E-01, 0.54766400E+00, 0.25667200E+00, -.17926900E+00, -.57407000E-03, -.19883700E+00, -.32807100E+00, -.33521400E-01, -.37287300E+00, 0.25819500E+01, -.10076200E+00, 0.36548800E-01, -.28818000E-01, 0.82940900E-01, -.84435000E-01, 0.22348000E-01, -.60998300E+00, 0.60432100E-02, 0.31400900E-01, -.42197300E+00, -.30232200E+00, 0.10930800E+00, -.53490800E+00, -.59947900E-01, 0.14890200E-01, 0.13482600E+00, 0.11154400E+00, -.35481800E-01, -.10237800E-02, -.43094300E+00, 0.11581400E-01, 0.28096400E+00, 0.18000900E+00, -.12311800E+00, 0.37058100E+00, -.54007600E-01, 0.13173000E+00, -.43492100E-02, -.84722200E-01, 0.73255000E-01, 0.10367800E+00, 0.49344500E+00, 0.10373700E+00, 0.12714700E+01, -.26161700E+00, 0.25686700E-01, 0.34636900E-01, 0.11023800E+00, 0.51167500E-02, 0.96396100E-01, 0.17174200E+00, -.11598500E+03, -.21733600E+03, -.77015400E+02, 0.83283800E+00, 0.29782600E+02, 0.34795600E+03, -.17810400E+03, -.11170600E+03, -.17419900E+03, -.38477000E+02, 0.49640000E+02, -.12086900E+03, 0.66082000E+01, -.70378000E+02, 0.44970200E+01, 0.11422100E+03, -.13344100E+02, 0.44293500E+01, -.89422900E+02, 0.66488400E+01, -.49492500E+02, -.21614600E+02, -.43409200E+02, -.86727800E+02, 0.12368400E+01, -.23066500E+02, -.59205600E+02, -.88926200E+02, 0.18691500E+02, -.28877000E+01, 0.44487000E+02, -.63023300E+02, -.17454000E+03, 0.79158000E+02, -.65713100E+02, 0.88548700E+02, -.15197500E+03, 0.53718600E+02, -.85350500E+02, 0.47853900E+02, 0.75210600E+02, 0.42639300E+02, 0.49729000E+02, -.48086500E+02, 0.67032200E+02, -.18950700E+02, -.10705300E+02, 0.21731700E+02, -.66564300E+02, -.16297600E+03, 0.88604300E+02, -.92875600E+01, 0.81557800E+02, -.19162000E+02, 0.15548800E+02, -.53181700E+01, 0.69194800E+02, 0.48600900E+02, 0.27100000E+01, -.40141000E+02, -.24081100E+03, 0.10893400E+03, 0.21992600E+03, 0.12043000E+03, 0.11114100E+03, 0.50387600E+02, -.31823000E+01, -.96624400E+02, -.18358000E+02, 0.88891300E+01, 0.74828500E+02, 0.52515700E+02, -.31436600E+02, -.91868600E+02, -.26250200E+02, 0.79039800E+01, 0.24961100E+02, -.41073900E+02, -.30977500E+02, -.41859600E+02, 0.20863300E+02, -.51061000E+02, 0.40455400E+02, -.29352900E+02, 0.12926200E+03, -.20163300E+02, 0.99409400E+02, 0.55975000E+02, -.78749000E+02, -.56614400E+02, -.13400700E+03, 0.15188200E+02, 0.14248600E+02, 0.44594900E+03, -.22048100E+03, -.22998900E+03, -.22305100E+03, 0.74259600E+01, -.29573400E+02, -.11384000E+03, 0.11968400E+03, -.28263500E+02, -.34634100E+02, -.21043100E+03, 0.45245900E+03, -.22542400E+03, -.14414500E+03, -.22620200E+03, -.58057600E+02, -.22068700E+02, -.11353700E+03, 0.63165600E+02, -.12801300E+02, -.51475000E+02, -.22795400E+03, 0.95963600E+02, -.25061600E+02, -.97918800E+01, -.47978300E+02, 0.26763500E+02, 0.11428900E+03, 0.35899900E+02, 0.19722000E+03, -.35302300E+02, 0.85803300E+02, 0.40247900E+02, 0.12955100E+02, -.24683400E+01, -.28536900E+03, -.63838400E+01, 0.14245600E+01, 0.15758200E+03, -.25776500E+03, -.16145600E+03, -.72869600E+02, 0.98313600E+02, 0.12984200E+03, 0.26244000E+02, -.57747500E+01, 0.44775500E+02, -.13141600E+02, 0.25964600E+02, 0.63053300E+02, -.80888800E+02, -.47446400E+02, -.51853100E+02, 0.46913700E+02, -.57701000E+02, -.10564000E+01, -.40762700E+01, -.68342900E+01, 0.31966700E+01, -.12197400E+01, -.50993100E+01, -.37908900E+01, -.82514000E+00, 0.67906700E+01, -.26439300E+02, 0.37558800E+02, -.63117700E+01, -.68873400E+01, -.45628000E+02, 0.25066200E+02, -.26092400E+02, -.40604100E+01, 0.34339900E+01, 0.35431600E+02, 0.47451000E+02, -.13912300E+02, 0.51410800E+01, -.21561400E+02, -.50984000E+02, -.54298000E+02, -.27591600E+02 },
        { -.13596200E+02, 0.43288900E+00, 0.51575600E+00, 0.19175100E+01, -.89582500E+00, 0.27838200E+01, -.20074900E+01, -.86924600E-01, 0.17665000E+01, 0.28857700E+01, -.45801800E-01, 0.22406800E+01, 0.63648400E-01, -.50383600E-02, -.36922500E-01, -.96337200E-01, 0.13397000E+01, -.38636300E+00, 0.16350700E+00, -.10962200E+00, -.38186400E+00, 0.45490300E+00, 0.10222600E+01, -.14036300E+01, -.49754800E-02, -.34087100E+00, 0.28987100E+00, -.89478800E+00, -.18125100E+01, -.16466500E+01, -.10497600E+01, -.18988400E+01, 0.48467800E-01, -.25733600E+00, 0.26714900E+01, 0.12760500E+00, -.17130300E+00, 0.33373500E+00, 0.10708500E-01, 0.20173300E+00, -.48361900E+00, 0.11577700E+01, -.71768900E+00, -.85710300E+00, 0.56369300E+00, 0.13863400E+00, -.22005700E+00, 0.82243800E-02, 0.34521100E+00, -.73345000E-01, -.84808700E+00, 0.10056200E+01, -.14053600E+00, 0.68182400E+00, -.18300600E+01, -.29911800E+00, 0.51592700E-02, 0.81307100E+00, 0.20198000E-01, -.76534500E-01, -.97286200E+00, 0.56208900E+00, 0.12862200E+01, 0.67424300E-01, -.88972500E+00, -.32652000E-01, 0.14234600E+01, -.15028500E-01, 0.29740300E+00, 0.15282200E-03, 0.39294300E-01, 0.15997100E+00, 0.15879300E+00, 0.28141000E-01, -.16575600E+01, -.19472500E+01, 0.78944700E+00, 0.50612000E+01, -.10018500E+01, -.14841300E+01, -.64734600E-01, 0.13382900E+01, 0.14896900E+00, 0.55309200E+00, -.13652400E+01, 0.43515300E+01, -.16666100E+00, 0.26794400E+00, 0.60549300E+00, -.14990100E+00, 0.96329000E-01, -.24596800E-01, -.88047600E+00, -.16439700E+00, -.26157900E-01, 0.82762400E-01, 0.25840200E+00, -.17267700E-01, 0.95883600E-01, 0.29773100E+00, -.93848400E-01, -.64370900E+00, -.12233600E-02, 0.29669000E+00, 0.83370000E-01, 0.35279700E+00, 0.51948600E-01, 0.14756500E+01, -.26264900E-02, 0.65259200E-01, -.25550300E+01, 0.78766200E-01, 0.14594600E-01, 0.15985100E-01, 0.83914200E+00, 0.99929000E-02, -.49136400E-01, 0.18497100E+01, 0.14895400E+00, -.44020700E+00, 0.26993500E+00, 0.35062400E+00, -.17903100E-02, 0.10913000E+01, -.17299500E-01, 0.81752300E+00, -.11788000E+00, -.62089700E+00, 0.19479800E+03, 0.42197300E+02, -.13212300E+03, -.50423700E+03, 0.48688100E+03, -.24526100E+03, -.50225800E+03, -.24306800E+03, -.14603500E+03, 0.33379000E+02, 0.40008700E+02, 0.40580700E+03, 0.23082200E+03, -.14562000E+01, 0.49009000E+02, -.29181000E+04, 0.14549500E+04, 0.18875800E+04, 0.14591700E+04, 0.18979800E+03, 0.41586000E+03, 0.15423600E+03, -.10333400E+04, 0.34417900E+03, 0.46429900E+03, 0.61161500E+03, -.59183000E+02, 0.57603500E+02, 0.27806900E+03, 0.29440100E+02, 0.68411100E+02, 0.22210100E+03, -.16751300E+03, -.29329300E+03, -.73347500E+03, 0.26121400E+03, 0.49893500E+02, 0.27432500E+03, -.13552800E+03, 0.33977900E+03, -.13698100E+03, 0.34582000E+03, 0.13967600E+03, 0.56528000E+02, -.36248100E+02, -.36466600E+03, 0.21817000E+03, -.55361300E+03, 0.71552000E+03, -.34981500E+03, -.36538500E+03, -.35811900E+03, -.11407600E+03, -.12400400E+02, -.31502400E+03, -.10687200E+03, -.13081000E+03, -.81646500E+01, -.36796700E+03, 0.34004100E+03, -.16269900E+03, -.29258800E+03, -.17015600E+03, -.25838900E+02, 0.13323400E+03, -.34163200E+03, -.10644300E+03, -.55904200E+02, 0.60064800E+02, 0.36653900E+03, -.92708800E+02, 0.70867800E+02, -.13046200E+03, 0.46291100E+02, -.34558200E+02, -.49910200E+02, -.53351400E+01, 0.15218900E+02, 0.21113400E+03, -.67131400E+02, -.21145700E+02, 0.76114900E+03, -.37750900E+03, -.42115900E+03, -.38091700E+03, -.15306200E+02, 0.13804500E+03, -.34478300E+03, 0.90509800E+02, -.27169500E+03, 0.60224100E+02, 0.38816800E+03, 0.15886800E+04, -.79512800E+03, -.86251400E+03, -.79394400E+03, -.63710200E+02, -.18179200E+03, -.13051800E+03, 0.62338600E+03, 0.46506400E+02, -.24995500E+03, -.42924200E+02, -.61198100E+03, 0.30521700E+03, -.37531700E+03, 0.30584600E+03, -.32399600E+02, 0.16467800E+03, -.20885500E+02, -.24084700E+03, 0.33295600E+03, 0.88370500E+02, 0.57584400E+03, 0.12302600E+04, -.62779400E+03, -.20182400E+03, -.61512100E+03, -.92821600E+02, -.57348100E+00, -.25582900E+03, 0.12751000E+03, -.29423700E+03, -.32903800E+02, -.27022500E+03, 0.24655500E+03, -.11926400E+03, 0.30913200E+03, -.12380200E+03, -.10614000E+03, 0.18998300E+02, -.12171800E+03, 0.23406700E+03, 0.28755100E+03, 0.22600000E+02, -.51704200E+03, -.64226500E+03, 0.31527200E+03, 0.23750100E+03, 0.32143800E+03, 0.41849900E+02, -.54144900E+02, 0.20507700E+03, 0.13057300E+03, 0.58070900E+03, -.72889400E+02, 0.19922300E+03, 0.15060300E+02, -.80061900E+00, 0.10617600E+02, 0.51974600E+01, -.14558900E+02, 0.15772700E+02, 0.11799400E+02, 0.20909800E+01, -.20049200E+02, -.46834500E+02, 0.27747900E+02, 0.21222200E+02, 0.21237500E+02, -.14227900E+03, 0.66334300E+02, -.66136000E+02, -.12616000E+02, 0.16765300E+02, -.60289500E+01, 0.12074500E+02, -.52869300E+02, -.12696700E+01, -.15724400E+02, -.61834500E+02, -.10812200E+03, -.72376700E+02 },
        { -.18986500E+01, 0.61501400E-01, 0.67975700E-01, -.48254000E-01, -.15401300E+00, 0.43974000E+00, -.36408900E+00, 0.18620200E+00, 0.20252700E+00, 0.44964000E+00, 0.60658800E-02, -.98740200E-01, 0.16112100E-01, -.10910100E-01, -.10030700E+00, 0.30671700E-01, -.17125900E+00, -.16704700E+00, -.24541900E+00, -.55779000E-01, -.15943800E+00, -.42912800E-01, -.13561400E+01, -.21384400E-01, -.34565400E-01, 0.16055400E-03, -.38366200E-01, 0.65091600E-01, 0.12640100E+00, -.44310300E+00, 0.10793600E-01, -.18975800E+00, -.18104100E-01, 0.18287000E-01, -.70330300E+00, 0.48370300E-01, -.35256300E-01, -.20260200E+00, -.48953400E-01, 0.16380800E+00, -.38351900E-01, -.27026800E+00, -.94161500E-01, 0.20565300E+00, -.12519100E+00, -.44224300E-01, 0.20110800E-01, 0.37387400E-02, -.10038400E+00, 0.34018400E-01, 0.54428700E-01, -.45700400E+00, 0.13528800E-02, -.11368600E-01, 0.64016200E+00, -.75828800E-01, -.45615200E-03, -.46930000E+00, 0.68779000E-01, 0.12480900E-01, 0.28657100E-01, -.20733100E-01, -.23441200E+00, 0.30422000E-01, 0.27464100E-01, -.55079500E-01, 0.73072100E-02, 0.86627300E-02, 0.76557900E-01, -.67156000E-03, 0.31365300E-01, -.47178100E-01, 0.21538600E-01, 0.17351600E-01, 0.72194800E-01, -.20401900E+00, -.24748800E-01, -.10998300E+01, -.13516500E+00, 0.57948900E-01, 0.37792600E-02, 0.18957800E+00, -.70667900E-01, 0.35770400E-01, 0.23748400E+00, 0.93998000E+00, 0.14346500E+00, 0.61977700E-01, -.12796800E-02, 0.18515800E+00, 0.19028200E-01, -.16963000E-01, 0.46069500E+00, -.19349600E-01, 0.86353800E-01, -.82160900E-02, 0.17805700E+00, 0.44556500E-01, -.16200900E+00, 0.13567100E+00, -.30491000E-01, -.27003700E+00, 0.77392000E-02, 0.16434700E+00, 0.61512000E-01, -.39216300E-01, 0.11151300E-01, 0.75014100E-01, 0.10767400E+00, -.40808100E-01, -.19183500E+00, -.19942100E-01, 0.46897900E-01, -.44371600E-03, 0.25169700E-02, 0.13383400E+00, 0.13538300E-01, -.15863100E+01, 0.11794800E-01, -.70809200E-01, -.25272300E-01, 0.18084000E-01, 0.11418200E-01, 0.12083500E+00, 0.73546100E-02, 0.10316900E+00, 0.33775200E-01, -.14982200E-01, 0.86374800E-02, 0.36920100E+02, -.24151200E+02, 0.49684900E+03, 0.27439400E+03, -.13709600E+03, -.38445100E+02, -.13767500E+03, -.36747300E+02, 0.45003700E+02, -.54959100E+02, 0.25283000E+02, -.84314300E+02, 0.40627600E+02, -.35077200E+03, -.32450800E+03, 0.16269700E+03, 0.19675600E+03, 0.16222000E+03, 0.57775800E+02, 0.29908200E+02, 0.72300700E+02, -.79820500E+02, 0.11021600E+03, 0.67486600E+02, -.96532800E+02, -.95545200E+02, 0.49334100E+02, 0.67152700E+02, 0.47863600E+02, 0.22002600E+01, 0.14524000E+02, -.76889900E+01, -.91029800E+02, -.99469900E+02, 0.26185000E+02, 0.57022200E+02, 0.12778600E+03, -.64724200E+02, -.12995300E+02, -.63951400E+02, 0.76558600E+02, 0.47987400E+02, -.79882000E+02, -.25076600E+02, -.96595600E+02, 0.53991300E+02, -.32096700E+02, 0.75317700E+02, -.37760200E+02, -.10615700E+02, -.37544500E+02, -.11185500E+02, 0.59396700E+00, -.31866000E+02, -.20826000E+02, -.15304000E+02, 0.78345800E+01, 0.17593500E+02, 0.36224100E+03, -.18128000E+03, -.15628200E+03, -.18107800E+03, 0.31043600E+01, 0.79971200E+02, -.13502100E+03, -.38148100E+02, -.16663200E+03, 0.69003600E+02, 0.53569300E+02, -.36630600E+02, 0.20456700E+02, 0.10613000E+02, 0.18335100E+02, -.10257700E+02, 0.22312200E+01, 0.54093800E+01, 0.14442300E+02, 0.37902200E+02, -.10433400E+00, 0.35724600E+02, 0.32930500E+03, -.16380900E+03, -.16564600E+03, -.16454100E+03, -.14475600E+02, 0.58002800E+02, -.10640500E+03, 0.82431100E+01, -.13369400E+03, 0.38490600E+02, 0.11230900E+03, 0.86107400E+02, -.43317000E+02, -.49621800E+02, -.43180300E+02, -.41751000E+02, 0.49323500E+02, -.13651000E+03, -.34232200E+02, -.33076000E+02, 0.47240900E+01, 0.26349200E+03, -.34622100E+01, 0.20449100E+01, -.34948400E+02, 0.17760300E+01, -.15525300E+02, 0.24381200E+02, -.22597000E+02, -.23302700E+01, 0.58842900E+02, 0.83395200E+01, 0.32312800E+02, 0.27246000E+03, -.13727300E+03, -.82916500E+02, -.13622200E+03, -.68714200E+01, 0.20057700E+02, -.77098100E+02, -.88876900E+01, -.88749500E+02, 0.16590400E+02, -.11562800E+03, -.11199800E+03, 0.56560200E+02, 0.13608600E+03, 0.56178500E+02, -.16365200E+02, 0.57340400E+02, 0.37168500E+01, -.33437400E+01, 0.69391400E+02, 0.66656100E+02, -.58536500E+01, -.12995300E+03, 0.64647000E+02, 0.47106800E+02, 0.64897000E+02, 0.13478600E+02, -.49308500E+01, 0.54541500E+02, 0.83161600E+02, 0.13260400E+03, -.18189900E+02, 0.50600300E+02, 0.25322900E+01, -.42438400E+01, 0.67160000E+01, 0.61531200E+00, -.68851700E+01, 0.74015400E+01, 0.45351400E+01, 0.17151700E+01, -.70651900E+01, 0.14665300E+02, -.14332000E+02, 0.36055800E+01, 0.50746200E+01, -.54384800E+02, -.24941000E+02, 0.93454400E+01, -.77166600E+01, 0.20584900E+01, 0.13607200E+02, 0.32234900E+02, -.13235500E+02, -.10131700E+02, -.98051200E+00, 0.17773900E+02, -.31479700E+02, 0.12844000E+02 },
        { 0.30821000E+00, -.14850700E-01, -.22404300E-01, 0.17011600E-01, 0.74216900E-01, -.26959200E+00, 0.19407200E+00, -.19570700E+00, 0.24665200E-02, -.16775400E+00, -.14939000E-02, 0.14260500E+00, 0.88670800E-03, -.35047400E-02, 0.78429200E-01, -.48452800E-01, -.85193600E-01, -.33467000E-02, 0.49753800E-01, -.37176300E-01, -.15321900E+00, 0.47990000E-01, 0.12882400E+00, -.62933300E-01, 0.30697600E-01, -.82945000E-02, 0.25983400E-01, -.85006500E-02, -.10490900E+00, 0.35673100E-01, -.71276600E-01, 0.15412900E+00, 0.20127000E-01, -.10518000E+00, 0.75289100E+00, 0.29941500E-01, 0.21391000E-02, 0.56621300E-01, 0.30971500E-02, -.27917600E-02, -.12190900E-01, -.79266000E-01, 0.32552500E-01, 0.46590600E-01, -.44569100E-01, 0.33871900E-01, 0.15894300E-01, -.24316200E-03, -.63622400E-01, -.41734100E-02, -.11382200E-01, 0.41729100E+00, 0.86761300E-02, 0.19145600E-01, 0.17250000E+00, -.83698300E-01, -.60557100E-03, -.39268400E-01, -.63980500E-01, 0.39819700E-02, -.17845200E-02, 0.11828800E-01, 0.29303000E-01, -.91500500E-02, -.59710800E-01, 0.22779100E-01, -.10689800E+00, 0.60278100E-03, -.10991000E+00, -.58574600E-04, -.99060600E-02, -.26935700E-01, -.17976500E-01, -.11414000E-02, -.45610400E-01, -.19848000E-02, 0.13844100E-01, 0.20544000E+00, -.14369200E+00, 0.78523800E-01, 0.46834600E-02, -.73558600E-01, -.16462300E+00, -.55069800E-01, 0.20001800E-01, 0.36677300E+00, 0.54912600E-01, 0.18761800E-01, 0.11999100E-01, 0.13968200E+00, -.38819600E-01, 0.19067800E-02, 0.12371100E-01, -.17423000E-02, -.69167900E-02, -.42730500E-02, 0.24349000E-01, 0.74637000E-01, 0.22681200E+00, -.25718000E-01, 0.36029000E-02, -.91883600E-01, 0.36072400E-01, 0.79048500E-01, -.81996400E-02, -.13655000E+00, -.66109500E-02, 0.91945400E+00, 0.46331500E-02, -.13064400E-03, 0.73506900E-01, 0.67171000E-02, 0.22621900E-01, -.17205800E-02, 0.68827700E-01, 0.11651100E+00, 0.93632200E-02, -.82535000E+00, -.11111700E-02, -.14758300E+00, 0.26012000E-01, 0.76929000E-03, -.43434300E-04, 0.19211500E-01, -.29272200E-02, 0.95966000E-01, -.10172300E-01, -.19213700E+00, 0.36028800E-01, -.73686600E-01, -.18001400E+02, 0.78429700E+02, 0.18807300E+01, -.15287500E+01, 0.10729500E+02, -.98893500E+00, 0.37596600E+01, 0.14424900E+02, -.18254800E+01, -.29229200E+01, 0.10935200E+01, 0.15306200E+02, -.74886400E+01, 0.92731300E+02, -.46822100E+02, -.68188400E+02, -.46361800E+02, 0.53113000E+01, -.23767500E+02, 0.17278300E+02, 0.46928400E+02, 0.20841600E+02, -.12334100E+02, -.71200400E+02, -.50188200E+02, 0.21425100E+02, 0.16148400E+02, 0.25045600E+02, -.88465500E+01, -.19345800E+02, 0.64288200E+01, -.38935600E+02, 0.95399900E+01, -.17028400E+02, 0.29726400E+02, 0.25704800E+02, -.11989700E+02, -.25678900E+02, -.12844600E+02, -.49082300E+00, 0.79711000E+01, -.21402800E+02, -.21336500E+02, 0.18527300E+01, 0.71617300E+01, 0.62234100E+01, 0.12611400E+02, -.60275300E+01, -.69552100E+01, -.63203700E+01, 0.40662000E+00, 0.70849300E+01, -.84721600E+01, -.64421000E+01, -.10972400E+02, 0.14137900E+02, -.13692700E+02, 0.14171400E+03, -.72350100E+02, -.58721500E+02, -.70861600E+02, 0.11128700E+02, 0.22435300E+02, -.56327400E+02, -.35233500E+02, -.84764400E+02, 0.36877500E+02, -.42855600E+02, -.20751200E+02, 0.10158900E+02, 0.25395500E+02, 0.10374000E+02, -.77785700E+00, 0.12155700E+02, -.60895200E+01, -.11635700E+02, 0.15994000E+01, 0.14105800E+02, 0.96302900E+01, 0.99401500E+02, -.50838000E+02, -.54479900E+02, -.49715500E+02, -.60399900E+00, 0.12424700E+02, -.43401100E+02, -.22349000E+02, -.54599100E+02, 0.24327700E+02, -.14921900E+02, -.46348100E+02, 0.23750600E+02, 0.14651400E+02, 0.23190200E+02, -.53662500E+01, 0.28133000E+02, -.50663200E+02, -.54039000E+02, -.83162700E+01, 0.17116200E+02, 0.24999900E+02, 0.10316700E+03, -.51475500E+02, -.50505200E+02, -.51588900E+02, -.65212800E+01, -.17878400E+02, -.10871100E+02, 0.20038200E+02, -.24491100E-01, -.14899400E+02, -.66960500E+02, 0.97903100E+02, -.46233000E+02, -.19230200E+02, -.48964700E+02, 0.74232200E+01, 0.26816700E+02, -.14467100E+02, 0.39593900E+02, -.32575400E+02, 0.19052600E+02, -.30205500E+02, -.12303600E+03, 0.61515000E+02, 0.85737900E+02, 0.61491600E+02, 0.12337700E+02, 0.36525900E+02, 0.17796800E+02, -.99914600E+01, 0.29021100E+02, 0.35846100E+02, 0.71186300E+02, -.48207900E+02, 0.25015800E+02, 0.83802000E+01, 0.24114100E+02, 0.39339900E+01, 0.44948700E+01, 0.83664200E+01, 0.74306300E+01, 0.20363700E+02, 0.44949500E+01, 0.89712200E+01, -.81020500E-01, 0.42103100E+00, -.21269700E+00, -.11528200E+00, -.14171500E+01, 0.13697800E+01, 0.57445500E+00, 0.22852500E+00, 0.18235700E+00, -.74680300E-01, 0.13722700E+01, -.46176000E+00, 0.37569000E+00, -.14960500E+02, -.15429400E+02, -.61758000E+00, 0.44059300E+01, 0.13699900E+01, -.22091500E+01, 0.25335800E+02, 0.24301200E+01, -.23799200E+01, -.22168600E+01, -.50604200E+01, -.84527700E+01, 0.52346400E+00 },
        { 0.47077400E+01, -.11722800E+00, -.17946600E+00, -.23104700E+00, 0.85148800E+00, -.17866800E+01, 0.13460000E+01, -.18251100E+01, 0.18739800E+01, -.13243100E+01, -.13441800E-01, 0.15118200E+01, 0.32877100E+00, 0.57308300E-01, 0.60404900E+00, -.27867000E+00, 0.46994800E+00, 0.64952200E+00, 0.99995300E+00, -.93900100E+00, -.13424600E+01, 0.22538700E+00, 0.90160600E+01, 0.52023900E+00, 0.36100500E+00, -.23139000E+00, 0.14589700E+00, -.33396500E+00, -.13979800E+01, -.67272900E+00, -.95676600E+00, -.74490200E+00, 0.87219200E-01, -.87508700E+00, 0.32522300E+01, 0.52232800E+00, 0.84394100E-01, 0.10861700E+01, 0.41190400E-01, 0.97864400E+00, -.81093200E+00, -.10629700E+01, 0.14237000E+00, 0.48392700E+00, -.69376300E+00, 0.23637900E+00, 0.26592300E+00, -.15951400E-01, 0.74122600E+00, -.89882500E-01, 0.62039600E+00, -.70931300E+00, -.81272200E-01, 0.30330300E-01, 0.83226700E+00, 0.65955500E-01, -.89266600E-01, -.63196700E-01, -.28653700E+00, 0.17224500E+00, 0.28279000E+00, -.26703100E+00, 0.24189900E+00, -.81989000E-01, -.20811800E+00, 0.82714000E-02, -.96593400E-01, -.16199500E-01, 0.26118700E+00, -.37979800E-02, -.69804300E-01, 0.38895900E+00, 0.19457900E+00, -.15491700E+00, 0.86854200E-01, 0.53250000E+00, 0.68350500E+00, 0.35813200E+01, -.16747200E+00, 0.74236500E+00, -.26452700E-02, 0.80339500E+00, -.15177400E+01, -.14247400E+00, 0.61379200E-01, -.68401300E+01, 0.12899000E+00, 0.98406700E-01, 0.73253300E-01, 0.50466800E+00, 0.70025400E+00, -.50546600E-01, -.51106100E+00, 0.24149300E+00, -.17178500E+00, 0.37739000E+00, -.16932800E+00, 0.10784800E+00, -.57011000E+00, 0.21551500E+00, 0.59327600E-01, 0.22942000E+00, -.21386300E+00, -.13876500E+00, 0.75980200E-01, 0.30556000E+00, -.26432700E-01, -.10768000E+01, 0.24792600E+00, -.10157600E+00, 0.21887200E+01, -.11747000E+00, 0.10246800E+00, -.12042600E-01, -.73541400E+00, 0.22129300E+00, -.28011500E-02, -.19367700E+01, -.29096300E+00, 0.54437900E+00, -.90342200E-01, -.22795200E+00, 0.29203700E-01, -.26237800E+00, -.45544900E-03, 0.31411000E-01, 0.28704000E+00, -.26322200E+00, -.35550300E+00, -.39552300E+00, -.85950300E+00, 0.18175200E+04, 0.50785000E+03, -.25797500E+03, 0.30474200E+02, -.25397300E+03, 0.15346500E+02, 0.27334100E+02, -.14562600E+03, 0.77970000E+01, -.12127500E+03, 0.52390200E+02, -.10377300E+04, -.10621900E+04, 0.53019400E+03, 0.46547600E+03, 0.53114600E+03, 0.25923000E+03, 0.11674200E+03, 0.19068700E+03, -.21131800E+03, 0.40917200E+03, 0.21636800E+03, -.74460700E+02, -.12998000E+03, 0.46239300E+02, 0.87335400E+02, 0.64952000E+02, -.37676300E+02, -.37028700E+02, 0.15042400E+01, -.17875500E+03, -.87042200E+02, -.34909400E+02, 0.12804500E+03, 0.13083600E+03, -.64352900E+02, 0.12632100E+03, -.65332900E+02, 0.15475300E+03, 0.17176500E+03, -.23472800E+03, -.12245100E+03, -.17432900E+03, 0.20956500E+03, -.52511500E+02, -.19421700E+03, 0.10177900E+03, 0.73500100E+02, 0.96940000E+02, -.14719800E+02, 0.67631100E+02, 0.35926800E+02, 0.25574500E+02, 0.28271700E+02, 0.79433100E+02, 0.18790200E+03, 0.11188000E+04, -.57153800E+03, -.47665400E+03, -.55946400E+03, 0.75715200E+01, 0.23794900E+03, -.42962800E+03, -.12185800E+03, -.56286400E+03, 0.16167000E+03, 0.23672600E+03, -.80882100E+02, 0.27264300E+02, 0.42320000E+02, 0.40409500E+02, -.29276300E+02, -.26186600E+00, -.21695500E+02, -.53100800E+02, 0.12182500E+02, 0.10392600E+02, 0.59185100E+02, 0.10722200E+04, -.54067900E+03, -.46869300E+03, -.53627000E+03, -.48424800E+02, 0.21680100E+03, -.41656400E+03, -.74851800E+02, -.54956600E+03, 0.11402500E+03, 0.33996300E+03, 0.87859000E+03, -.43788500E+03, -.39535100E+03, -.43910800E+03, -.23384100E+03, 0.92182500E+02, -.47514800E+03, -.63388800E+00, -.30123400E+03, -.49191300E+02, 0.34598400E+03, 0.36410100E+03, -.18062600E+03, -.14899600E+03, -.18211800E+03, -.66632000E+02, -.23176100E+01, -.11426300E+03, 0.80270000E+02, 0.57733800E+02, -.50332400E+02, -.18899600E+03, 0.21819600E+03, -.93717400E+02, 0.12228700E+02, -.10908100E+03, 0.25932900E+02, 0.48838400E+02, 0.70343300E+01, 0.11265700E+03, -.93680900E+02, 0.57670300E+02, -.15774800E+03, -.84380200E+03, 0.42519700E+03, 0.23991200E+03, 0.42165200E+03, 0.16461800E+03, 0.34443300E+03, -.17014300E+03, -.34909900E+03, 0.10600500E+03, 0.37757100E+03, 0.36974600E+03, -.96056200E+02, 0.53412800E+02, -.85841400E+01, 0.48167200E+02, 0.29276400E+02, 0.29504300E+02, -.84790500E+01, 0.10706700E+03, 0.14679500E+03, -.67594700E+01, 0.60104400E+02, 0.45520700E+01, -.10134600E+02, 0.16600100E+02, 0.16240300E+01, -.24423000E+02, 0.24617900E+02, 0.17783500E+02, 0.43887600E+01, -.18004000E+02, 0.22816500E+02, -.14072100E+02, 0.55428500E+01, 0.90936100E+01, -.68291400E+02, -.10511400E+03, 0.14692800E+02, -.47107800E+01, 0.20630400E+02, 0.63786400E+02, 0.10630600E+03, -.54825900E+02, -.42631900E+02, 0.10132500E+00, 0.75269700E+01, -.49720100E+02, 0.23147900E+02 },
        { 0.10249100E+02, -.36012900E+00, -.32636900E+00, -.27306800E+01, 0.53940700E+00, -.16812300E+01, 0.99001300E+00, 0.10914100E+00, -.64428800E+00, -.13230100E+01, 0.39111000E-01, 0.12839600E+01, 0.37820900E-01, 0.17216200E+00, -.36399500E+00, 0.11365500E+00, 0.13601400E+01, 0.15195200E+01, -.42792200E+00, 0.39986100E-01, 0.93137200E+00, 0.40926000E-01, 0.81813400E+01, 0.92998800E+00, 0.18017800E+00, -.92033900E-01, 0.26795800E+00, -.17364100E+00, -.56097800E-01, 0.65822900E+00, -.48725200E+00, -.16669400E+01, 0.24415300E-01, 0.75449900E+00, -.29663800E+01, -.51981400E+00, -.13565600E+00, 0.18514500E+01, 0.38785300E-02, -.82908100E+00, 0.68707000E+00, 0.49328400E+00, -.63621800E+00, -.13322400E+00, 0.95152000E+00, 0.14810400E+00, 0.46622800E-01, 0.26343400E-01, -.54914700E+00, -.73236800E-01, 0.42445400E+00, 0.35570000E+01, 0.25603000E-01, 0.35132900E-01, -.66533200E-01, 0.30719900E+00, -.30645600E-01, 0.87137100E-01, 0.10385500E+00, -.74334500E-01, 0.27295100E+00, 0.40797000E+00, 0.48982300E+00, -.11455400E+00, 0.65711500E-01, 0.12256500E+00, 0.20608700E+00, 0.77981100E-02, -.60225600E+00, 0.31324600E-02, 0.53519200E-01, -.51126300E-01, -.94239500E-01, -.18690100E+00, 0.10140600E+01, 0.92744100E+00, -.35408000E+00, -.32410800E+01, 0.42342900E+00, 0.12216100E+01, 0.67202200E-01, -.89755600E+00, 0.51844400E+00, -.12279400E+01, 0.69061400E+00, 0.25359300E+01, 0.83662700E-01, 0.22834800E-01, -.72586300E+00, 0.50480400E+00, 0.16366300E+00, 0.34876800E-01, -.11376600E+01, 0.10055300E+00, -.30570900E+00, -.19328700E+00, -.20442000E+00, 0.25498100E+00, -.15495800E+00, 0.45955600E+00, 0.33888900E-01, -.21997900E+00, 0.15666000E+00, 0.12350100E+00, 0.73052600E-01, -.25053900E+00, -.45862500E-01, 0.10309700E+01, 0.20601900E+00, -.95061500E-01, 0.19768600E+01, -.24306000E-01, 0.32834600E+00, -.85065300E-02, -.49006100E+00, 0.11062600E+01, -.94154500E-01, -.10731200E+01, -.34896100E+00, 0.23095000E+00, 0.21003800E+00, -.51029300E-01, -.41708400E-01, -.71013500E+00, -.13491900E-01, 0.34404300E+00, -.87074200E-01, -.45898100E+00, -.49692500E+00, -.16273200E+00, -.99777100E+00, -.31781500E+00, -.90181400E+03, 0.44504700E+03, 0.50439800E+03, 0.45174000E+03, 0.22193100E+03, -.61869200E+01, 0.23141500E+03, 0.18035300E+01, 0.12177400E+03, 0.11723100E+03, -.23744000E+02, -.32886400E+02, 0.10720900E+02, 0.39861900E+03, 0.16592600E+02, 0.23479900E+03, -.42211900E+02, -.34633100E+02, 0.20922900E+03, 0.13995100E+03, 0.61311200E+01, -.25530500E+03, -.25711700E+03, 0.10687700E+03, 0.10575200E+03, 0.12842700E+03, 0.17855600E+02, 0.92091400E+02, -.51845400E+02, -.26422800E+03, -.75490300E+02, 0.81871000E+02, 0.13408100E+03, 0.32172300E+03, -.15889400E+03, -.56506100E+02, -.16062000E+03, -.99164400E+02, 0.15402900E+03, -.17312400E+03, -.31752000E+03, -.10272400E+03, 0.12919600E+03, -.60327600E+03, -.14162400E+02, 0.90435800E+01, 0.82240900E+02, 0.66063400E+01, -.11149100E+03, -.36059100E+02, 0.12704500E+02, -.48881700E+02, -.74826100E+02, 0.34241400E+02, 0.33245000E+02, 0.10516600E+04, -.52989100E+03, -.40406700E+03, -.52601100E+03, -.89201500E+02, 0.35862300E+02, -.31962400E+03, 0.25594200E+03, -.21760300E+03, -.52913000E+02, 0.17522800E+03, -.74766600E+02, 0.22475600E+02, 0.31461900E+03, 0.37296600E+02, -.45891100E+01, 0.63759100E+02, -.32649200E+01, 0.15749600E+01, 0.52044200E+02, 0.72567000E+02, -.13055000E+02, 0.80774400E+03, -.40654500E+03, -.35014400E+03, -.40432800E+03, -.34095600E+02, 0.55953000E+02, -.20497100E+03, 0.27777000E+03, -.20565600E+03, -.11754900E+02, 0.29453900E+03, 0.96739200E+02, -.43398000E+02, -.11457400E+03, -.47842800E+02, -.11442500E+03, 0.54685800E+02, 0.10095300E+03, -.91405700E+02, -.13259300E+03, 0.63828200E+02, 0.23224100E+03, -.16659500E+03, 0.85293700E+02, -.15768200E+03, 0.83108300E+02, 0.15309300E+03, 0.15581100E+02, 0.33357100E+02, -.31992200E+02, 0.83274000E+02, 0.50521500E+02, 0.96380400E+02, 0.83141600E+03, -.39863100E+03, -.13922800E+03, -.41567000E+03, -.58256200E+02, -.58920400E+02, -.82215800E+02, 0.24575300E+03, -.19915100E+03, -.78058000E+02, -.25684700E+03, -.37147200E+03, 0.18474000E+03, 0.35914600E+03, 0.18503100E+03, 0.39236400E+02, -.91853000E+02, 0.16508500E+03, 0.69469800E+02, -.11019800E+03, 0.35757700E+02, -.60506500E+02, -.37095300E+03, 0.19067400E+03, -.20840200E+02, 0.18584300E+03, -.13305100E+01, -.27275500E+02, 0.76418500E+02, 0.23709200E+02, 0.14986400E+03, -.42856300E+01, 0.17701400E+03, 0.81330500E+00, -.10588500E+02, 0.28204400E+01, -.36418100E+01, -.58527200E+01, 0.10803000E+02, 0.94299100E+01, -.76759600E+00, -.10541300E+02, 0.74369500E+00, -.22975600E+01, -.15332200E+02, -.68492300E+01, 0.17383300E+02, -.12895700E+03, -.78133500E+01, 0.80666000E+02, -.80654100E+01, -.11839600E+02, 0.10390400E+03, -.48051200E+02, 0.19236700E+01, 0.60488500E+01, -.29810400E+02, 0.90836100E+02, 0.75519900E+01 },
        { -.10073400E+02, 0.43148600E+00, 0.27967500E+00, 0.11649200E+01, -.54273900E+00, 0.17677200E+01, 0.27018500E+00, 0.65356300E-01, -.41302500E+00, 0.12440400E+01, -.32511800E-01, 0.14956000E+00, 0.13442500E+01, 0.19215100E+00, 0.64963000E+00, -.34298500E-01, 0.47066600E+00, 0.63834900E+00, -.37416800E+00, -.32072700E-01, -.60138000E+00, -.12914700E+00, 0.15759700E+02, 0.12865700E+01, 0.40074600E+00, -.71582300E-01, 0.25099000E+00, 0.67729900E+00, 0.89583300E-01, -.93995000E+00, -.35230100E+00, -.41169200E+00, 0.93135400E-02, 0.10317400E+01, -.19449100E+01, -.17281300E+00, -.14421000E+00, -.11753100E+01, 0.88380500E-01, -.66010300E-02, 0.29588000E+00, -.28686300E+00, -.22465000E-01, -.35011900E+00, 0.66388900E+00, -.19500600E-01, 0.57573400E+00, 0.92888100E-02, -.29143400E+00, 0.14441500E+00, 0.10666300E+01, 0.25734300E+00, 0.73824800E-01, 0.28414500E+00, 0.63702800E+00, -.32517600E+00, 0.12726700E+00, 0.13700800E+00, 0.26081900E+00, -.48797300E-01, -.26334400E+00, -.35248800E+00, 0.71915300E+00, 0.34137800E-01, 0.11167000E+00, 0.25682500E+00, 0.58038200E+00, -.45122700E-01, 0.13714700E+01, 0.10104400E-02, -.23855600E+00, 0.10325900E+00, -.59384000E-01, 0.12243100E+00, -.14361800E+01, -.15087500E+00, 0.32360100E+00, 0.58098400E+01, -.18487900E+00, 0.75607900E-01, 0.64400000E-02, -.78998700E-01, -.20682600E+00, -.60193800E+00, 0.41072600E+00, 0.84101400E+01, 0.14505300E+00, 0.17972500E+00, -.49245200E+00, 0.70556500E+00, -.66601800E-01, -.20328600E-01, -.19781400E+01, -.26652300E+00, 0.28622400E-01, -.94602800E+00, -.52959200E+00, -.74301100E-01, 0.19633300E+00, -.19343700E+00, 0.49887700E-01, 0.35806800E+00, -.17450600E+00, -.69940300E+00, 0.17577800E+00, 0.33572400E+00, 0.68684700E-02, -.20687300E+01, 0.17377200E+00, -.17547200E+00, -.19430800E+00, -.10047600E+00, -.12975800E+00, -.27183000E-02, 0.72548900E-01, -.37215300E+00, 0.95162300E-01, -.20001700E+00, 0.96347000E-01, 0.36412600E+00, -.10504000E+00, -.72551000E-01, -.26844100E-01, 0.58659200E-01, 0.26747100E-01, -.69668100E+00, -.10773600E-02, -.22274400E+00, 0.14091700E+00, -.10941000E+01, 0.21185400E+01, 0.93493500E-01, -.34595300E+00, 0.36686100E+02, -.44044100E+02, -.21278700E+01, -.50681800E+02, -.26460000E+02, -.84345400E+01, -.18542800E+02, -.67564600E+01, -.29213500E+02, -.19683200E+02, 0.52579500E+03, -.26004300E+03, -.40348900E+03, -.26310100E+03, -.14263500E+03, -.66320400E+02, -.11339100E+03, 0.85794000E+02, -.14483800E+03, -.91143800E+02, -.95015000E+02, -.19226800E+03, 0.95714000E+02, 0.37081400E+02, 0.96614500E+02, 0.81401400E+01, 0.66246000E+01, 0.50235500E+02, -.31158200E+01, 0.54017400E+02, 0.19452000E+02, 0.46511800E+02, 0.25097300E+03, -.12497600E+03, -.53106600E+02, -.12582200E+03, 0.32565600E+02, -.14469200E+02, 0.80886600E+01, 0.82970600E+02, -.14675800E+02, -.15154300E+02, -.16574800E+03, -.48452900E+01, 0.44977100E+01, -.27225700E+02, 0.30761900E+01, -.35931600E+02, 0.16634500E+02, -.41356900E+02, -.22753200E+02, 0.39999300E+01, 0.68143900E+00, 0.44293900E+02, 0.97745100E+01, -.15139900E+02, -.33214500E+01, -.46477700E+01, -.62528200E+02, -.19590300E+02, 0.22444500E+02, 0.35202600E+02, 0.37477200E+02, -.11324900E+02, 0.88676400E+02, 0.88282000E+01, 0.25642300E+02, -.57523800E+02, -.43135600E+01, -.13169100E+01, 0.12465300E+01, -.16621100E+02, 0.39428500E+01, 0.10978800E+02, -.66016700E+01, 0.65412200E+01, 0.28009700E+02, -.22709800E+02, -.31003200E+02, -.13378700E+02, -.38433600E+02, -.29184400E+02, 0.27198500E+02, 0.46966400E+02, 0.36338700E+02, -.24901500E+02, 0.52281100E+02, -.77991600E+02, 0.38394300E+02, 0.48250700E+02, 0.38272300E+02, 0.25732200E+02, -.68752600E+02, 0.12269600E+03, 0.55945100E+02, 0.72038200E+02, -.53034700E+02, -.10428600E+03, 0.24418900E+03, -.12290000E+03, -.48521200E+02, -.12183600E+03, -.68645100E+02, -.49570200E+02, -.16421700E+02, 0.43255600E+02, -.10901800E+03, -.52770200E+02, -.81253800E+02, 0.14367800E+03, -.72197100E+02, -.11096800E+03, -.71777400E+02, -.21450600E+02, -.40368400E+02, -.23986100E+02, 0.29015800E+01, -.26369600E+02, -.33910500E+02, -.85689900E+02, 0.32137200E+03, -.16081200E+03, -.36306500E+03, -.15970600E+03, -.12257900E+03, -.53582300E+02, -.90017900E+02, -.23046700E+02, -.10498800E+03, -.68307700E+02, -.16673700E+03, 0.42680800E+02, -.18874600E+02, 0.31744700E+02, -.21746600E+02, 0.21175000E+02, 0.42822500E+02, -.44378200E+02, -.46662200E+02, -.61532600E+02, 0.30677900E+02, 0.56433000E+02, 0.25536200E+00, -.21493700E+01, -.39076400E+00, 0.22459000E+01, 0.63529600E+01, -.60164200E+01, -.98318200E+01, 0.12204200E+01, 0.29807100E+00, 0.26056400E+02, -.25422800E+02, -.68965900E+01, -.18051800E+01, 0.17851900E+02, 0.41310900E+02, 0.20805000E+02, -.36523800E+01, 0.38928600E+01, -.17152900E+02, 0.25214600E+02, 0.62542100E+01, 0.10063400E+02, -.51330500E+01, 0.32254100E+02, -.25498600E+02, 0.23878200E+02 },
        { -.14344100E+01, 0.29058600E-01, 0.37986200E-01, -.24292500E+00, -.16616600E+00, 0.13802200E+00, 0.11810600E+00, 0.14722400E+00, -.83187500E+00, 0.39964700E-01, -.33126100E-02, -.12330400E+00, -.14780400E-02, -.38252900E-02, -.24298900E-01, 0.15711200E-01, -.76262700E-01, -.43695800E-01, -.79840900E-01, 0.11384100E+00, 0.26515900E-01, 0.21636100E-01, -.84422300E+00, -.95130700E-01, 0.13036700E-01, 0.28222100E-01, 0.13311700E-01, 0.19114700E+00, 0.92913100E-01, 0.54451500E-01, 0.12001500E-01, -.19874800E-01, -.98186400E-02, 0.11915600E+00, -.42891900E+00, -.16137700E-01, -.25829700E-01, -.10939700E+00, -.43652000E-02, -.32011500E-01, 0.29942100E-01, 0.15637900E+00, 0.34851600E-01, -.96274400E-01, 0.96295700E-01, -.22870900E-01, 0.14232900E-01, 0.30438700E-02, -.95996700E-01, 0.16131400E-01, 0.61927100E-01, 0.53393200E+00, 0.20508000E-01, 0.62342700E-01, -.22638900E+00, -.37506100E-01, 0.14079900E-02, 0.22623100E-01, 0.23673400E-02, -.22373200E-01, -.72314500E-01, 0.20817300E-01, 0.48963500E-01, -.20971300E-01, -.55197900E-01, -.80537200E-02, -.14629600E-01, 0.14836700E-02, -.27739800E-01, 0.62007500E-03, 0.13368200E-01, -.35976300E-01, -.20224700E-01, 0.67560700E-02, 0.14997300E-01, 0.24267900E-01, -.43239400E-01, 0.13258100E+00, -.71948200E-01, 0.42589900E-01, 0.79932400E-02, -.39108900E-01, 0.64927500E-01, -.75389500E-01, 0.15090900E+00, 0.13371600E+01, 0.37570500E-01, 0.82465000E-02, -.98625700E-01, 0.17873900E+00, -.71482800E-04, 0.83112700E-02, 0.11642500E+00, -.51033300E-01, 0.25104300E-01, -.48898000E-01, -.78072000E-01, -.11142300E+00, 0.35594100E-01, -.24668000E-01, -.54435300E-02, 0.51876600E-01, 0.25355600E-01, -.55806700E-01, -.33835500E-01, 0.59638600E-01, -.12724700E-01, -.46484100E+00, -.14966700E-01, 0.60569300E-02, -.20784800E-01, -.11555900E-02, -.38390700E-01, -.66706700E-03, -.89891700E-01, -.56607100E-01, -.70065000E-02, 0.24174000E-01, 0.34839800E-01, -.56745200E-01, -.23479400E-01, -.13021600E-01, -.34892000E-02, -.40733600E-01, 0.41310600E-03, 0.18881200E-01, 0.33364200E-02, 0.10179700E+00, -.42741100E-01, -.15642300E+00, -.19670000E+00, -.37119200E-02, 0.11943300E+00, 0.19239400E-01, -.34600000E+02, -.72459700E-01, -.22686900E+02, -.13524200E+02, -.62147500E+01, -.13958200E+02, 0.20947900E+02, -.24808700E+02, 0.40786700E+02, 0.78422900E+02, -.38899600E+02, -.18350000E+03, -.39227500E+02, -.42040800E+02, 0.46455800E+01, -.23750900E+02, -.18266200E+02, -.22907600E+02, -.93299300E+01, -.70992600E+01, 0.53716500E+02, -.21629400E+02, -.23689000E+02, -.26845800E+02, 0.13755100E+01, -.38761400E+01, -.43747000E+01, 0.29647400E+02, -.52982800E+01, -.12982600E+01, -.31799300E+02, -.22797600E+02, 0.11678400E+02, 0.80937900E+01, 0.11373400E+02, 0.11924300E+02, -.28870100E+02, 0.40912100E+02, 0.66019500E+02, -.96746300E+01, -.27875100E+02, 0.10195200E+03, -.20261500E+02, 0.10311700E+02, -.31502300E+02, 0.10180700E+02, 0.90000200E+01, 0.10408400E+02, 0.76128800E+00, -.55242200E+01, 0.23488200E+02, -.44861900E+01, 0.99874000E+01, -.24188000E+03, 0.12177700E+03, 0.80471100E+02, 0.12095900E+03, -.31008200E+01, -.13057500E+02, 0.60741600E+02, -.53841600E+02, 0.10222600E+03, -.15549200E+02, 0.72725600E-01, 0.38244800E+02, -.13884000E+02, -.62979700E+02, -.19113800E+02, 0.48406000E+01, -.69039300E+01, -.49967200E+01, 0.14158700E+02, -.17278800E+01, -.75757700E+01, -.89037100E+01, -.18855300E+03, 0.94548500E+02, 0.74460200E+02, 0.94323900E+02, 0.24641500E+01, -.15092900E+02, 0.46583100E+02, -.54649700E+02, 0.78448400E+02, -.15175900E+02, -.35243700E+02, -.23391100E+03, 0.11635500E+03, 0.12107000E+03, 0.11690000E+03, 0.26352300E+02, -.41937100E+01, 0.56851700E+02, -.21815900E+02, 0.38987800E+02, -.40726300E+00, 0.11045200E+03, -.15106300E+03, 0.75071700E+02, 0.10787400E+03, 0.75551600E+02, -.98226000E+01, 0.77804500E+01, 0.28852500E+02, -.32485900E+02, -.38761800E+01, 0.46552900E+01, 0.62816100E+02, -.13702700E+03, 0.64375100E+02, 0.22129100E+02, 0.68510000E+02, 0.22252000E+01, -.70330700E+01, 0.26500900E+02, -.24710100E+02, 0.41012900E+02, -.74019800E+01, 0.42457300E+02, 0.47982600E+02, -.23881400E+02, -.13607100E+03, -.23919000E+02, -.39784200E+02, -.10442600E+02, -.89506000E+01, -.83736800E+01, 0.44628900E+02, -.34014600E+02, 0.15620900E+02, 0.39167600E+02, -.20650300E+02, 0.43601100E+01, -.19620600E+02, 0.35865700E+00, 0.35714000E+01, -.70900300E+01, -.10207200E+02, -.10563400E+02, 0.23153100E+01, -.26191700E+02, -.13422900E+01, 0.20542000E+01, 0.73524400E+00, -.25821800E+00, 0.13297600E+01, -.20539100E+01, -.29828200E+01, -.22660600E+00, 0.86348000E+00, -.61115800E+01, 0.68511300E+01, 0.11377100E+01, 0.68680600E+00, 0.12344300E+02, 0.28532000E+02, -.58541100E+01, -.15479500E+02, 0.23628900E+01, -.32261700E+00, -.22570100E+02, 0.70396100E+01, -.19458300E+01, 0.37994000E+01, -.51182400E+01, -.13845800E+02, -.88880300E+01 },
        { 0.40980300E+01, -.65021200E-01, -.17036600E+00, 0.20604100E+00, 0.38707800E+00, -.24703700E+00, -.81059600E+00, 0.36966100E+00, 0.29948900E+00, 0.46762000E-01, 0.37014200E-02, 0.15765900E+00, -.13507100E-01, -.64338200E-02, 0.44795900E-01, -.61071300E-01, 0.16663300E+00, 0.43443200E-01, 0.48386700E+00, -.65546700E+00, -.27315500E+00, -.65530900E-01, -.13644700E+01, -.24173200E-01, -.32765900E-01, 0.15287500E-01, 0.33605300E-01, -.11661400E+00, -.85892100E-01, 0.19492600E+00, 0.60348800E-01, 0.17078600E+00, 0.11095100E-01, -.50776600E+00, 0.11677800E+01, 0.26888200E+00, 0.57173600E-01, 0.63741200E+00, -.14056300E+00, 0.44832400E+00, -.24563200E+00, -.65136200E+00, 0.32703300E+00, 0.21718000E+00, -.33346900E+00, 0.82358200E-01, 0.24235200E-03, -.10490200E-01, -.31848100E+00, 0.18193600E-01, -.49444900E+00, 0.96003700E+00, 0.49226100E-01, -.43293000E-01, 0.81969000E+00, -.24428600E+00, 0.22943900E-01, -.62274200E+00, -.34170800E+00, 0.14532500E-01, 0.14485600E+00, 0.33374800E-01, -.56729400E+00, 0.98799900E-01, 0.12575000E+00, -.31969800E-01, 0.33534900E+00, 0.10793700E-02, 0.51664900E+00, -.21010700E-02, -.42358000E-02, -.78525800E-01, 0.10745300E-01, -.31225700E-01, -.30290300E+00, 0.16967400E+00, -.34521300E-01, -.30365200E+00, 0.11747600E+00, 0.20721300E-01, -.21136600E-01, -.56928700E+00, 0.14827100E+00, 0.95729000E-01, 0.97502300E-03, 0.17826900E+01, 0.10154200E+00, 0.42695000E-01, 0.13366100E+00, 0.23687200E-01, -.25753500E+00, -.37245700E-01, 0.58148100E+00, -.75645400E-01, -.26986900E-01, 0.25250700E+00, 0.16942300E+00, 0.14481300E+00, 0.81114900E-01, -.11427100E+00, -.76644100E-01, -.42068500E+00, 0.18808000E+00, 0.36630800E+00, 0.66112300E-01, 0.32332900E-02, 0.89545300E-02, 0.32525000E+00, -.64596600E-01, 0.36791300E-01, -.51324400E-01, -.15961100E-01, -.99976800E-01, -.17000400E-02, 0.22362000E+00, -.19330500E+00, -.33104200E-01, -.10155900E+00, -.21949300E+00, 0.11733300E+00, 0.21639900E+00, 0.12549000E-02, 0.25992000E-02, -.16307900E+00, 0.12358300E-03, -.83261400E+00, -.77581000E-01, 0.24535300E+00, 0.29605700E+00, -.11649500E+01, -.67286000E+00, -.20096000E+00, -.74620000E-01, 0.13815000E-01, -.19993500E+01, -.95055100E+00, -.59431000E+01, -.31850800E+02, -.11845400E+02, -.78818800E+02, -.65389200E+02, -.22634500E+02, 0.86216800E+02, 0.13536600E+04, -.67626200E+03, -.11031700E+04, -.67694100E+03, -.57168900E+02, -.15501700E+03, -.57149600E+02, 0.50304800E+03, -.53461900E+02, -.16454100E+03, -.47924200E+03, 0.99658300E+02, -.49822300E+02, -.11641600E+03, -.49768400E+02, -.48016300E+02, -.13860800E+03, 0.69934700E+02, 0.14617900E+03, 0.29460700E+03, -.14587600E+03, 0.13040200E+01, -.54109200E+02, 0.28486000E+02, -.20925800E+03, 0.26881700E+02, -.97924200E+02, -.28499200E+02, -.34573500E+02, -.14682900E+02, 0.47747300E+02, -.63040800E+02, 0.34370900E+03, -.22107100E+03, 0.10502100E+03, 0.57764600E+02, 0.11087800E+03, 0.84364300E+02, 0.28635400E+02, 0.57572600E+02, 0.11585700E+01, 0.39321400E+02, 0.22749700E+02, 0.11645800E+03, -.48711400E+03, 0.24306300E+03, 0.22909700E+03, 0.24368700E+03, 0.18761300E+02, -.55388800E+02, 0.16872400E+03, -.12280500E+03, 0.19467800E+03, -.60150400E+01, -.11408700E+03, 0.70017000E+02, -.29093200E+02, -.24357500E+02, -.34944400E+02, 0.85247800E+01, -.36974800E+01, -.75004100E+01, 0.29972600E+02, -.59172300E+02, 0.84482900E+01, 0.16073600E+02, -.49550400E+03, 0.24669400E+03, 0.19250800E+03, 0.24807900E+03, 0.32407700E+01, -.60843700E+02, 0.13940000E+03, -.16273000E+03, 0.21120400E+03, -.61927200E+01, -.19704500E+03, -.15673700E+04, 0.78539000E+03, 0.74955700E+03, 0.78330300E+03, 0.10268100E+03, 0.18604300E+03, 0.12008100E+03, -.47834300E+03, 0.81487600E+02, 0.15358800E+03, 0.57589600E+03, -.32242300E+03, 0.16093900E+03, 0.38638900E+03, 0.16134900E+03, 0.47209300E+02, -.15811400E+02, 0.13843400E+03, 0.57081900E+00, -.89599500E+01, -.78958700E+01, 0.37384500E+02, -.52982300E+03, 0.25833300E+03, 0.39552500E+02, 0.26487400E+03, 0.63750400E+02, 0.69863000E+02, 0.73536000E+02, -.96341000E+02, 0.97370200E+02, 0.69047700E+02, 0.78823900E+02, -.21725600E+03, 0.10519700E+03, -.88952800E+02, 0.10912700E+03, 0.40343400E+02, 0.88644600E+02, -.22166200E+02, -.11871200E+03, -.23108200E+02, 0.55047600E+02, 0.34715900E+03, 0.24096700E+03, -.12056100E+03, -.60314400E+02, -.12077700E+03, -.30410800E+02, -.94278500E+01, -.49004200E+02, -.89815100E+01, -.16500400E+03, 0.10543700E+01, -.11462300E+03, -.86161300E+01, 0.35701100E+01, -.71530700E-01, -.13677700E+01, 0.29007000E+01, -.47612500E+01, -.86975500E+01, -.45568100E-01, 0.47644700E+01, 0.21845400E+02, -.10606900E+02, 0.11370200E+01, -.97507000E+00, 0.40415500E+02, -.34067500E+02, 0.30721500E+02, 0.64608400E+00, -.55076500E+01, -.16010900E+02, -.93799000E+01, 0.35430500E+02, -.20810700E+02, 0.21746600E+02, 0.37720000E+02, 0.53127900E+01, 0.28864600E+02 },
        { 0.25242200E+02, -.45773600E+00, -.15752000E+01, -.58559100E+00, 0.90337000E+00, -.28270500E+01, 0.71203000E-01, 0.27301400E+00, -.20752700E+01, -.19308900E+01, 0.59097600E-01, -.27631100E+01, -.27272600E+00, 0.96299700E+00, -.67266800E+00, 0.29826400E+00, -.14115500E+01, -.10492100E+01, -.59038900E+00, -.38036000E+00, 0.59112100E+00, -.40422500E+00, -.23018500E+02, -.17512700E+01, -.20389200E+01, -.21120300E+00, -.25768300E+00, 0.22589200E+00, 0.98080600E+00, -.86568500E+00, 0.10791600E+01, 0.94213200E+00, -.13426600E+00, 0.36186600E+00, 0.35598800E+01, -.37358900E-02, 0.75687700E-01, 0.29554400E+00, -.45154400E+00, 0.14357900E+01, -.20859700E+00, -.69088100E+00, 0.11395500E+01, 0.12934000E+01, -.17576500E+01, 0.56521000E+00, 0.16003100E+00, -.10986100E-01, -.10577100E+01, 0.16093800E-01, 0.11394500E+01, 0.15654500E+02, -.20192600E+00, -.78427300E+00, -.48724100E+01, 0.52600700E+00, -.12859200E-01, -.89209300E+00, -.90178100E+00, -.18462000E+00, 0.22827200E+00, 0.14038400E+01, 0.14258300E-01, 0.27487500E+00, -.14937200E+01, -.27434100E+00, 0.43320900E+01, 0.12987300E-01, 0.26007900E+01, -.52200700E-02, 0.49159300E-01, 0.52348700E+00, 0.30361700E+00, -.31374200E+00, 0.14039100E+01, 0.88550800E+00, -.94771600E+00, -.18124900E+01, -.63765200E+00, 0.11388800E+01, -.32912800E-02, -.14642300E+01, -.26778700E+01, 0.98745200E+00, -.51616700E+00, -.13692300E+02, 0.36813400E+00, -.13844500E+00, 0.11295400E+01, 0.65829200E+00, 0.80538500E-01, -.86209100E-02, 0.94614300E+00, 0.83934000E+00, -.41682900E-02, 0.66274900E-01, 0.11011700E+00, -.50726900E+00, -.24831900E+01, -.11618400E+00, 0.11958000E+00, -.91581900E+00, 0.63629000E+00, -.86681400E+00, 0.29402100E+00, -.43788600E+00, 0.17591800E+00, 0.12890600E+02, -.55823600E+00, -.18652700E-01, -.14905500E+01, -.38210200E+00, -.22669900E+01, -.21751700E-01, 0.56801800E+00, 0.33602600E+00, -.30432800E+00, -.80870400E+00, -.91152900E+00, 0.39658200E+01, 0.10836800E+01, -.39322300E+00, 0.50700200E-01, -.34266200E+00, 0.11628000E-01, -.45226900E+00, 0.35039900E+00, -.12645200E+01, -.10171400E+01, 0.83945200E+00, 0.33123700E+01, 0.79832100E+00, 0.11195400E+01, -.22177700E+00, -.69740600E+01, 0.15054200E+01, -.45020700E+03, -.15338900E+03, -.15941600E+03, -.12689600E+03, 0.63892100E+03, -.42269100E+03, 0.62539600E+03, -.15828500E+04, 0.79191000E+03, 0.26989900E+03, 0.79120400E+03, -.91896000E+03, 0.43037700E+03, -.41309000E+03, -.17483800E+04, -.55976300E+03, 0.16980200E+03, 0.10842500E+04, 0.30236800E+03, -.12221500E+03, 0.39882800E+03, -.15107900E+03, 0.17295100E+03, 0.22216100E+03, -.20575700E+03, 0.24165300E+02, -.78906700E+03, 0.31950200E+03, -.44073500E+03, -.70460100E+03, 0.36273700E+03, 0.69196200E+03, 0.35196100E+03, 0.75213700E+03, -.36606400E+03, 0.78935600E+03, 0.10836700E+04, -.11746900E+03, -.19111300E+03, 0.90729600E+03, -.13199000E+03, 0.11074300E+03, -.46125300E+03, 0.66660000E+02, -.55277900E+02, 0.12932400E+03, -.12529300E+03, -.22212200E+02, 0.43216400E+03, -.17569200E+03, 0.57325300E+02, -.32584900E+04, 0.16044700E+04, 0.10040600E+04, 0.16294900E+04, -.13232200E+03, -.10225200E+03, 0.70254300E+03, -.63515400E+03, 0.11215300E+04, -.10375800E+03, 0.48903400E+03, 0.36980700E+03, -.11178000E+03, -.11630500E+04, -.18480800E+03, 0.14323800E+02, -.20348800E+03, -.57161200E+02, 0.82741300E+02, 0.13618700E+03, -.26167400E+03, -.85179000E+02, -.18736500E+04, 0.91761000E+03, 0.95842800E+03, 0.93744900E+03, -.34912300E+02, -.11640300E+03, 0.41551300E+03, -.46889600E+03, 0.66321800E+03, -.17627600E+03, -.15716300E+02, 0.13108700E+04, -.66756900E+03, -.23437600E+03, -.65617000E+03, 0.39189700E+03, -.55168100E+03, 0.26505700E+03, 0.13740200E+04, 0.86543200E+03, -.43740400E+03, -.46964700E+03, -.95732700E+02, 0.42973000E+02, 0.12325900E+03, 0.48130600E+02, -.57089500E+03, 0.83386400E+02, -.26772200E+03, -.23369000E+03, 0.11640700E+03, -.43327300E+02, 0.29402700E+03, -.84615300E+03, 0.42169300E+03, 0.19962800E+03, 0.42304100E+03, -.94323700E+02, -.21794700E+03, 0.33936600E+03, 0.10923400E+02, 0.36956000E+03, -.19998900E+03, 0.44633500E+03, 0.13492100E+04, -.65003400E+03, -.11391400E+04, -.67368400E+03, -.70888700E+03, -.25942300E+03, -.48786600E+03, -.58353000E+02, 0.77373500E+03, -.65653700E+03, -.52002600E+03, 0.34386700E+03, -.16652300E+03, 0.19976400E+03, -.17226100E+03, 0.14347400E+03, 0.25094300E+03, -.23556300E+03, -.27810900E+03, -.39792500E+02, 0.15478600E+03, -.11086900E+03, 0.53609700E+01, 0.99256000E+01, 0.12545300E+02, 0.11436200E+02, 0.70936900E+01, -.10215300E+02, -.36798900E+02, 0.62882300E+00, 0.28818100E+01, -.76597100E+02, 0.45781900E+02, 0.34587100E+02, 0.24832000E+02, 0.10795800E+03, 0.69267600E+03, -.83132300E+02, -.26951700E+03, 0.55321300E+02, 0.14362100E+02, -.32308900E+03, 0.32471200E+02, 0.72906900E+02, -.74068400E+02, -.89073100E+02, -.23993100E+03, -.13569100E+03 },
        { 0.14748600E+02, -.42002800E+00, -.59929700E+00, -.11503700E+01, 0.16226500E+01, -.40489100E+01, 0.16610600E+01, -.64454400E+00, -.10323200E+01, -.42826400E+01, 0.12283400E+00, -.24616200E+01, -.20058900E+00, 0.15302800E+00, 0.37936100E-01, -.35890500E+00, -.29297300E+00, 0.13887300E+00, 0.13369200E+01, -.12218500E+01, 0.22004100E+00, -.49687000E+00, 0.37748100E+01, 0.22234400E+01, -.87533700E-01, 0.35333500E+00, -.25761600E+00, 0.17987000E+01, 0.57668600E+00, 0.17114800E+00, 0.78432900E+00, -.72981500E+00, 0.39862800E-01, -.27936900E+00, 0.83515300E+00, 0.54852300E+00, 0.32897300E+00, 0.17512100E+01, 0.12888200E+00, 0.47889100E-01, -.95657900E-01, -.13691800E+01, 0.33875200E-01, 0.65966600E+00, 0.87575200E-01, -.81430100E-01, -.14877800E+00, -.49258400E-01, 0.29689000E+00, -.26221500E+00, 0.12979800E+00, 0.11649900E+01, -.20000500E+00, -.63674700E-01, 0.30671100E+01, -.77623500E+00, 0.91849800E-01, -.33419200E+00, -.10020300E+01, -.11672700E+00, 0.80637500E+00, 0.49963800E+00, -.11707700E+00, 0.26990400E-01, 0.14762200E+00, 0.62221100E+00, -.36374400E+00, -.18842000E-01, -.12662400E+00, 0.36000400E-02, -.27154400E+00, 0.17320300E+00, -.21129600E+00, 0.30570700E-01, -.69876400E+00, 0.74027600E+00, -.20748300E+00, 0.45853200E+01, -.10436700E+01, -.23059200E+00, -.69420500E-01, 0.10289400E+00, 0.15665500E+01, -.14042100E+00, -.99366700E+00, -.15135300E+02, -.60416200E+00, -.90752000E-01, 0.88138600E+00, -.10690500E+01, -.81218500E+00, 0.33288000E-01, -.30506600E+00, 0.47047900E+00, 0.68519100E-01, 0.13441200E+00, 0.37114600E+00, 0.61095100E+00, -.15275400E+01, -.19744800E+00, -.62779500E-01, 0.62337000E+00, -.56663500E+00, -.94663100E-02, 0.16504500E+00, 0.53647000E+00, 0.35914600E+00, 0.70903300E+01, -.54708700E+00, 0.29773000E+00, -.45326200E+01, 0.12203400E+00, -.76434400E+00, 0.38001500E-01, 0.16216200E+01, 0.85600900E-01, -.20973600E-01, 0.11245100E+02, -.43716300E-01, -.14917800E+01, 0.38426400E-01, 0.37160600E+00, 0.19295800E-01, 0.61583700E+00, -.69748600E-02, 0.85381500E+00, -.19168800E-02, 0.16887700E+01, 0.23060700E+00, 0.15944600E+01, -.41867400E+01, -.42170100E+00, 0.11171900E+01, 0.11156200E+00, 0.17365900E+01, -.48443600E+01, 0.17572400E-01, -.20079700E+03, -.12790500E+03, -.54081100E+03, -.32888400E+03, -.12560600E+03, 0.67238800E+03, 0.61078000E+04, -.30471100E+04, -.48738100E+04, -.30543800E+04, -.15689000E+01, -.70053000E+03, -.44368000E+02, 0.26088400E+04, 0.93932700E+02, -.64804100E+03, -.18609400E+04, 0.16009500E+04, -.76060900E+03, -.10315000E+04, -.80084500E+03, -.33275500E+03, -.85237000E+03, 0.27121000E+03, 0.12243300E+04, 0.14417500E+04, -.96147000E+03, -.29198700E+03, -.66804400E+03, 0.33156900E+03, -.99660200E+03, 0.33328200E+03, -.70701500E+03, -.13845900E+03, -.24126800E+03, -.19226700E+03, 0.14641300E+03, -.37981100E+03, 0.20823700E+04, -.13906800E+04, 0.66091900E+03, 0.45067100E+03, 0.69682000E+03, 0.73885100E+03, 0.81295200E+02, 0.65928600E+03, 0.29169600E+03, 0.32970300E+03, 0.67608500E+02, 0.59697500E+03, -.31136200E+04, 0.15749800E+04, 0.13464800E+04, 0.15573900E+04, 0.24036500E+03, -.41027700E+03, 0.11313200E+04, -.72712700E+03, 0.12953400E+04, -.13104300E+03, -.44237900E+03, 0.17426500E+03, -.60290900E+02, 0.14089900E+03, -.86809600E+02, 0.28559300E+02, -.61492400E+02, 0.10570800E+03, 0.10505500E+03, -.40765500E+03, 0.19437300E+02, 0.16128000E+03, -.30507600E+04, 0.15357000E+04, 0.10867400E+04, 0.15268000E+04, 0.11776300E+03, -.28900700E+03, 0.77020300E+03, -.11357700E+04, 0.12482500E+04, -.37524600E+01, -.10296000E+04, -.91758500E+04, 0.45921900E+04, 0.43464500E+04, 0.45862800E+04, 0.61326500E+03, 0.13202500E+04, 0.39795000E+03, -.30513700E+04, 0.24589600E+03, 0.10098600E+04, 0.29366000E+04, -.20280100E+04, 0.10149400E+04, 0.23941000E+04, 0.10146000E+04, 0.42022300E+03, -.20545400E+01, 0.68610500E+03, -.46526200E+02, -.26268300E+02, 0.76352200E+02, 0.12300800E+03, -.43616000E+04, 0.21167800E+04, 0.88727000E+03, 0.21803900E+04, 0.50784700E+03, 0.58684300E+03, 0.53205600E+03, -.93172200E+03, 0.81493800E+03, 0.58640700E+03, 0.96174600E+03, -.19236100E+04, 0.94419900E+03, 0.39073800E+02, 0.96396600E+03, 0.83114100E+03, 0.46215500E+03, 0.28322800E+03, -.41229400E+03, 0.27470400E+03, 0.33706100E+03, 0.24322300E+04, 0.12658700E+04, -.64230500E+03, -.41229300E+03, -.63441900E+03, -.22355200E+03, -.22380100E+03, -.10956700E+03, 0.43496000E+02, -.70221300E+03, -.10635800E+03, -.83356000E+03, -.36923400E+02, 0.35890100E+02, 0.15873500E+01, -.15864600E+02, -.95384700E+01, -.18626400E+01, 0.37756600E+01, -.28237500E+01, 0.22111800E+02, 0.86348100E+02, -.29191600E+02, 0.47730800E+02, 0.17886200E+02, 0.25984300E+03, -.38770100E+03, 0.15688900E+03, -.14463900E+02, -.42987700E+02, -.41018700E+02, -.22145400E+03, 0.17244800E+03, -.20303400E+03, 0.14965000E+03, 0.20621900E+03, 0.22105000E+03, 0.11949000E+03 },
        { 0.48674300E+01, -.17917800E-01, -.13959500E+00, -.27999400E-02, 0.63056600E+00, 0.11354700E+00, 0.69574200E-01, -.14151900E+00, -.42432200E+00, -.15527000E+00, -.57012400E-01, 0.16278000E+00, 0.18965500E-01, -.22514300E-01, -.36821600E-02, -.22657600E-01, 0.14292500E+00, -.24814600E+00, 0.25080400E+00, 0.13557200E-01, 0.38876200E+00, 0.56420800E-01, 0.17855800E+00, 0.75968300E-01, 0.33927600E-01, -.27611300E-01, 0.28231400E-01, -.12582600E+00, -.11053600E+00, 0.12451800E+00, 0.50372500E-01, -.16778600E+00, 0.13852500E-01, -.39383500E-02, 0.42440500E+00, 0.29485700E-01, 0.55157600E-01, 0.46388600E+00, -.75490500E-01, 0.17635300E+00, 0.44766900E-01, -.29691400E-01, -.14336000E-01, 0.20737200E+00, -.14041400E-01, -.57355500E-01, 0.12407100E-01, -.69763800E-02, -.50780300E-02, 0.24271600E-01, 0.51804200E+00, -.54761800E+00, -.43399900E-01, -.11149400E+00, -.98380100E-01, 0.24171400E+00, -.15392300E-01, 0.12779300E+00, -.18664000E-01, 0.14192900E-01, 0.19051500E+00, -.62096800E-01, -.49031600E-02, -.14165800E-01, -.15724300E-01, 0.81694000E-01, -.44532500E+00, -.46848400E-03, 0.42810500E-01, -.71328600E-03, -.22939200E-01, -.13320400E-01, 0.30974600E-01, -.46319400E-02, -.90515000E-01, 0.61292100E-02, 0.43492400E-01, -.45764500E+00, 0.38829300E-01, 0.23557600E+00, 0.19587000E-01, -.27634300E+00, -.79234600E+00, 0.12803700E+00, 0.21678800E+00, -.95629000E+00, 0.12236300E+00, 0.29906700E-01, 0.10723600E+00, 0.22241200E+00, 0.36804400E-01, -.89859800E-02, 0.59152400E+00, -.16468400E-01, 0.14446500E+00, 0.36897800E-01, 0.22977500E-02, -.23589800E+00, -.12724100E+00, 0.15990200E-01, 0.22904200E-01, -.64530400E-02, 0.23620800E-01, -.12702800E+00, -.28675400E-01, 0.84043000E-01, -.15925000E-01, 0.81426300E+00, -.40679600E-01, 0.14355100E-01, 0.28699100E+00, -.24919500E-01, -.73183500E-01, -.47582100E-02, -.39916500E-01, -.17022000E-02, -.18070600E-01, -.68174700E+00, -.57479400E-01, -.30678000E-01, 0.72546600E-01, 0.52598200E-01, 0.15169400E-01, -.34978100E-01, -.99633500E-03, 0.20110700E+00, 0.19642800E-02, -.21039900E-01, 0.40095400E-01, -.74934700E-01, 0.21422600E+01, 0.87632800E-01, -.68276000E-01, 0.32945000E-01, 0.40419100E+00, -.40840600E+00, 0.93224400E-01, 0.12678500E+00, 0.46524600E+02, 0.62339800E+02, -.43212300E+02, 0.40910400E+02, -.18955100E+03, -.99020500E+02, 0.48845300E+02, 0.25919600E+03, 0.49549100E+02, 0.89717300E+02, -.20154700E+01, 0.13663400E+02, 0.49488600E+02, 0.23151800E+02, 0.28680300E+02, -.24377700E+02, -.81544900E+02, 0.34395800E+02, 0.87261900E+01, 0.40829500E+02, 0.25224200E+02, 0.88586000E+02, -.46720900E+02, -.87299500E+02, -.33420600E+02, 0.82850300E+02, 0.56843700E+02, 0.16289300E+03, -.82987300E+02, -.97715000E+02, -.81387600E+02, -.38981000E+02, 0.28750300E+02, -.74997200E+02, -.10340000E+03, 0.59385000E+01, 0.19824000E+02, -.38599800E+03, 0.11515500E+03, -.63089900E+02, 0.90679100E+02, -.57695300E+02, -.14095500E+02, -.22257800E+02, -.27741500E+02, -.16751400E+02, -.84400400E+02, 0.45307200E+01, 0.54400600E+01, 0.38701200E+03, -.18970800E+03, -.91299100E+02, -.19355200E+03, 0.64368900E+01, 0.40441200E+01, -.56746200E+02, 0.18860600E+03, -.10204800E+03, -.47993500E+02, 0.25907500E+03, -.69038200E+02, 0.22173000E+02, 0.13749100E+03, 0.34495400E+02, -.42585900E+01, 0.22236000E+02, 0.25294800E+02, 0.43029800E+01, 0.33702600E+02, 0.15868300E+02, 0.98996200E+01, 0.29846600E+03, -.14618200E+03, -.11662300E+03, -.14934500E+03, 0.31911000E+02, 0.25807300E+02, -.25370400E+02, 0.19162300E+03, -.80691700E+02, -.25779000E+02, 0.25888200E+03, 0.39817800E+03, -.19748900E+03, -.24910800E+03, -.19895800E+03, -.73334100E+02, -.29729100E+02, -.71474500E+01, 0.90540500E+02, -.54801400E+02, -.48724200E+02, -.58681100E+02, 0.15085300E+03, -.74709300E+02, -.15307100E+03, -.75474100E+02, 0.33711900E+02, -.11362800E+02, -.57719600E+01, 0.48905400E+02, 0.47661500E+01, -.12818800E+02, 0.25239400E+02, 0.21285800E+03, -.10182200E+03, -.40620200E+02, -.10639100E+03, -.39113300E+02, -.73549200E+02, -.23942700E+02, 0.35091100E+02, -.35741000E+02, -.68703800E+02, -.56062800E+02, 0.43455400E+02, -.24494400E+02, 0.20035100E+03, -.21892200E+02, -.10963100E+01, -.12423800E+02, 0.19191500E+02, 0.27209800E+02, -.14160400E+03, 0.45287500E+02, -.14885200E+03, -.14272300E+03, 0.70786400E+02, 0.17447500E+02, 0.71459600E+02, 0.29185400E+01, -.89077700E+01, 0.44888100E+02, 0.33485400E+02, 0.49418400E+02, -.62591100E+01, 0.67073800E+02, 0.27625100E+00, -.30111500E+01, -.26651200E+01, 0.48236800E+00, 0.17408000E+01, -.16268800E+00, -.15977800E+00, -.20547600E+00, -.65589000E+00, 0.24501200E+02, -.25041600E+02, -.11769500E+02, -.37206800E+01, -.25756400E+02, -.51326800E+02, 0.18761100E+02, 0.30851300E+02, -.12474100E+02, 0.18263500E+02, 0.36618000E+02, -.30475200E+02, 0.56983800E+01, -.13729600E+01, 0.16708800E+02, 0.18271700E+02, 0.29607000E+02 },
        { -.15483500E+01, 0.92431000E-01, 0.70660200E-01, -.45597700E-02, -.23109600E+00, 0.10517100E+01, -.90086700E+00, 0.85243700E+00, 0.90261700E-01, 0.47287000E+00, -.25917800E-01, -.66729800E+00, 0.91997800E-01, 0.27996900E-01, -.67276600E-02, 0.21502100E+00, 0.17759100E+00, 0.88387700E-01, -.45663100E-01, 0.50256000E-01, 0.47810600E+00, -.11701100E+00, -.17273700E+01, 0.39520300E-01, -.24046100E+00, -.56567500E-01, 0.45325600E-03, 0.87498800E-01, 0.33129300E+00, -.76201700E+00, -.29397900E-01, 0.11051100E+01, -.26689700E-01, 0.43435800E+00, -.21563800E+01, -.21810100E+00, -.14885800E+00, -.13928500E+01, 0.93583000E-01, -.15062400E+00, 0.37737500E+00, -.42821600E+00, 0.13266500E+00, -.19628000E+00, -.29860900E-01, -.81946700E-01, -.25192800E-01, 0.29213900E-01, 0.32090000E+00, -.17948100E-01, 0.36817500E-01, -.88002700E+00, 0.40219800E-01, 0.16303200E+00, 0.10716500E+00, 0.34686200E-01, -.31696300E-01, -.54969100E-01, 0.55589600E+00, -.85799200E-01, 0.17317200E+00, 0.46264500E-01, 0.10203100E+00, 0.12889700E+00, 0.19708000E+00, 0.22652400E-01, 0.68487300E+00, -.51450700E-02, 0.59598200E+00, 0.21828500E-02, -.18983200E-01, 0.70231600E-01, 0.29843600E-01, 0.51190700E-01, -.46585800E-01, -.51136400E-01, 0.47334400E-01, -.24038300E+00, 0.81779100E-01, 0.13165700E+00, 0.23043900E-01, -.16994000E+00, 0.11628500E+00, -.79839200E-02, 0.38799600E+00, 0.41103500E+01, -.10932400E+00, 0.70923800E-02, -.34413100E+00, 0.37413700E-01, 0.20754300E+00, 0.27202400E-01, -.47908000E+00, -.12366800E+00, 0.18607200E+00, -.39280300E+00, 0.14739500E-02, -.25404900E+00, 0.10190400E-03, -.56418500E-01, -.42193900E-01, -.14697100E+00, 0.52834900E-01, -.84758700E-03, -.32718800E-01, -.27637600E+00, 0.86805500E-01, 0.27401300E+01, 0.71476600E-01, -.48146600E-01, 0.36543300E+00, -.48830100E-01, 0.75136900E-01, 0.12225100E-02, 0.24227900E+00, 0.46370000E+00, -.65359600E-02, 0.36193200E+00, -.14048900E-01, 0.10372500E+00, 0.51569600E-02, 0.34810800E-01, 0.17472400E-01, 0.34483500E+00, 0.43191500E-02, 0.64357300E+00, 0.15594200E+00, -.17761100E-01, 0.11039300E+00, 0.84739600E+00, 0.18118000E+00, 0.35249900E+00, 0.14165500E+00, -.41404000E-01, 0.10521200E+01, -.32465500E+00, 0.30195500E-01, -.72809800E-01, -.87549500E+00, -.76125800E+02, -.12645900E+03, 0.34909500E+02, -.56190900E+02, 0.97750100E+03, -.48949800E+03, -.39521500E+03, -.48880300E+03, -.15386900E+02, -.15550400E+03, 0.13274800E+02, 0.48911400E+03, -.37361300E+01, -.14173700E+03, -.30665000E+03, -.31484900E+02, 0.72122400E+01, 0.48210200E+01, 0.15565900E+02, -.62853900E+02, -.12190700E+03, 0.78775600E+02, 0.99102300E+02, 0.23043500E+03, -.13724400E+03, 0.36926600E+02, -.18022700E+02, 0.96601600E+01, -.19877900E+03, 0.89291500E+01, -.88397200E+02, 0.11537700E+02, -.90833400E+02, -.16433200E+03, 0.63225500E+02, -.47366900E+02, 0.34954600E+02, -.34522100E+02, 0.11068600E+02, 0.14295900E+03, 0.17430400E+02, 0.40994300E+02, -.36998400E+02, 0.48226000E+02, 0.22211000E+02, -.11438000E+02, -.12859400E+01, 0.89434500E+01, 0.96488400E+02, -.50365000E+02, 0.56096200E+02, -.48171900E+02, 0.50065800E+02, -.59265900E+02, 0.92082800E+02, 0.16696900E+03, 0.31026200E+01, -.20402900E+02, -.40362400E+02, -.57439600E+02, 0.24761500E+02, 0.17963000E+03, 0.28772500E+02, 0.19343400E+01, 0.61738200E+02, -.11581400E+02, -.45327800E+02, -.54805500E+02, 0.54156500E+02, 0.16784600E+02, -.18345300E+02, 0.60525200E+01, 0.13307600E+02, 0.93408500E+01, 0.41655100E+02, -.53368400E+02, 0.93527900E+02, 0.11662100E+03, 0.87886000E+02, -.21320300E+02, -.33699900E+02, -.86869600E+03, 0.43842900E+03, 0.38095600E+03, 0.43415900E+03, 0.56893900E+02, 0.16211300E+03, 0.39545300E+02, -.39672500E+03, -.20700100E+02, 0.13006900E+03, 0.16706000E+03, 0.55731200E+02, -.26417000E+02, -.49107500E+01, -.27796600E+02, 0.10016400E+03, -.10401900E+02, 0.60829400E+02, 0.95635600E+02, 0.21224600E+02, 0.72169500E+01, -.11041700E+03, -.21195600E+03, 0.10595900E+03, 0.31158100E+02, 0.10586700E+03, 0.41890200E+02, 0.52899600E+02, 0.10281200E+02, -.58729100E+02, 0.25149100E+01, 0.62244000E+02, 0.55691100E+02, 0.17612700E+03, -.92568300E+02, 0.18332500E+03, -.87799900E+02, -.10583700E+02, -.66630800E+02, 0.75531600E+02, 0.62529100E+02, -.18101400E+03, -.19355100E+02, -.35054600E+02, 0.29199900E+02, -.11855300E+02, -.31890800E+02, -.14845800E+02, 0.22567100E+02, 0.49546900E+02, -.41686400E+02, -.47337500E+02, -.13901900E+03, 0.66010000E+02, -.72923000E+01, -.45459000E+01, -.97985600E+00, -.16516600E+01, -.19468900E+01, 0.40509400E+00, -.12550300E+01, 0.12503000E+02, 0.40575600E-02, 0.74072000E+00, 0.36522200E+02, -.27965400E+02, 0.71263500E+01, -.14516400E+01, 0.12646000E+02, -.10666600E+03, 0.37813200E+02, 0.34963200E+02, -.16107300E+02, -.84617400E+01, 0.11395800E+03, 0.83762000E+01, -.22614000E+02, 0.22899900E+02, 0.41704100E+02, 0.39652000E+02, 0.46493200E+02 },
        { -.14091100E+01, -.91066000E-01, -.26383300E-01, -.80232000E+00, -.24728600E-01, -.16911900E+01, 0.10375400E+01, -.12286100E+01, 0.50081700E+00, -.15490400E+01, 0.47637000E-01, 0.12376100E+00, 0.16004300E+00, 0.27579600E-01, 0.43244900E+00, -.21565800E+00, -.26993100E+00, 0.49443500E+00, 0.69083700E+00, -.39952800E+00, -.11490400E+01, 0.70542300E-01, 0.29383200E+01, -.38188500E-01, 0.15282000E+00, 0.33325500E-01, -.20702700E+00, 0.74734300E-01, -.28860100E+00, -.32033800E+00, -.90045300E+00, -.25320500E+00, 0.62873600E-01, -.29505000E+00, 0.36864000E+00, 0.24152600E+00, 0.35463000E-01, -.79764400E+00, 0.34484100E+00, -.79465400E-01, -.21772900E+00, -.89823000E+00, -.40957300E-01, -.53423800E+00, 0.30422000E+00, 0.56061100E-01, 0.31963100E+00, -.14315200E-01, 0.26180100E+00, -.39207500E-01, -.27077200E+00, 0.10650900E+01, -.26662500E+00, 0.86712200E-01, -.54206200E-01, -.59004700E+00, -.74111900E-01, 0.51936900E+00, -.27119800E+00, 0.74142000E-01, 0.97772500E-01, -.76914900E+00, 0.35481600E+00, -.89563400E-02, 0.14579600E+00, 0.29842200E+00, -.11757300E+00, -.13752300E-01, 0.45991100E+00, 0.16131200E-02, -.11805500E+00, 0.14589500E+00, -.28033600E-01, -.29904300E-01, -.39620700E+00, 0.53614400E-03, 0.60001900E+00, 0.55647900E+01, -.13445300E+01, 0.26954200E+00, 0.27561000E-01, -.12593600E-01, -.85609700E+00, 0.10851500E+00, 0.19435800E+00, -.25816900E+01, 0.29389400E+00, 0.34190600E+00, 0.76053700E+00, 0.96556200E+00, 0.51355400E+00, -.16587000E-01, 0.84638000E+00, -.17396300E+00, 0.20607100E+00, 0.13687100E+00, -.17373100E+00, -.44073000E+00, -.11379300E+01, 0.23834600E+00, -.14029000E-01, 0.36822300E+00, -.11715400E+00, -.45890200E+00, -.14252300E-01, 0.81258100E+00, -.74098700E-01, -.28107000E+01, -.59207900E-01, 0.68064600E-01, 0.18098600E+01, -.45705300E-01, -.18852900E-01, -.97908900E-02, -.59252700E+00, -.75179300E+00, -.51790300E-01, -.92329600E+00, -.14389800E+00, -.88114300E-01, 0.12228500E+00, -.22896800E-01, 0.18272900E-01, 0.39780500E-01, -.59507900E-02, 0.10018100E+00, 0.11131900E+00, -.47549100E+00, 0.12965900E+00, -.22330200E+00, 0.34080800E+00, 0.49099700E+00, 0.46466700E-01, 0.49008000E-01, 0.25557600E+01, -.55129100E+00, 0.20435800E-01, 0.14566900E+00, -.66482600E+00, -.46737300E-01, -.72219500E+02, 0.19078900E+02, -.12340800E+03, -.39279300E+03, 0.19526300E+03, 0.47779200E+03, 0.19645700E+03, 0.48987100E+02, 0.12813400E+02, -.43661500E+01, -.20773200E+03, -.62615400E+02, 0.32506200E+02, 0.11357900E+03, -.30126800E+03, 0.12125000E+03, 0.12568700E+03, 0.15069100E+03, 0.18454200E+02, 0.48723800E+02, -.72410900E+01, -.13973100E+03, 0.58444300E+02, 0.48256600E+02, 0.15137300E+03, -.73370200E+02, 0.38241600E+02, 0.88207200E+02, 0.36780300E+02, 0.51623600E+02, 0.11492700E+03, -.38556200E+02, -.12061500E+03, -.48696100E+01, 0.15676800E+03, -.41871100E+03, 0.78626800E+02, -.45792400E+02, 0.11681600E+03, -.39503000E+02, -.36373200E+01, -.32597400E+02, -.92300200E+02, -.34193400E+02, -.11259400E+03, -.11380300E+02, 0.28746200E+02, 0.45592100E+03, -.23021900E+03, -.16600900E+03, -.22803400E+03, 0.68204200E+01, 0.49413800E+02, -.14049200E+03, 0.16926400E+03, -.25609100E+03, -.41729600E+02, 0.46144300E+03, -.10086800E+03, 0.33189100E+02, 0.40452600E+02, 0.50395500E+02, -.31972400E+02, -.43828200E+02, 0.21190000E+02, -.40838700E+02, 0.43238800E+02, -.38896300E+02, 0.28104700E+02, 0.47873300E+03, -.24163800E+03, -.15289700E+03, -.23954800E+03, 0.43371300E+02, 0.89958900E+02, -.12124700E+03, 0.18198500E+03, -.28287800E+03, -.97595800E+01, 0.37343700E+03, 0.14287200E+04, -.71008700E+03, -.66925600E+03, -.71415100E+03, -.10862400E+03, -.15315100E+03, -.74029200E+02, 0.39310000E+03, -.10761100E+03, -.16270700E+03, -.57227100E+03, 0.62850700E+03, -.31266400E+03, -.36566200E+03, -.31432900E+03, -.50340700E+02, -.27836900E+02, -.12797000E+03, 0.79291700E+02, -.43250100E+02, -.49578800E+02, -.19179400E+03, 0.30084600E+03, -.12805500E+03, -.77021500E+02, -.15036900E+03, -.31390500E+02, -.61634100E+02, 0.61701100E+02, 0.22913000E+03, -.32005300E+02, -.52102900E+02, -.77294200E+02, 0.40155800E+03, -.20344400E+03, 0.68573300E+02, -.20105600E+03, -.25428200E+02, -.63706300E+02, -.13847500E+03, -.29716000E+01, -.32540200E+03, -.18780700E+02, -.26746500E+03, 0.58035400E+02, -.24314100E+02, 0.36428200E+01, -.28868100E+02, 0.20089900E+02, 0.44665200E+02, -.85985400E+02, -.64949900E+02, -.13234700E+03, 0.31042400E+02, 0.40983200E+01, 0.75521200E+01, -.89882000E+01, -.47107300E+01, 0.83319300E+01, 0.57084400E+01, -.60781500E+01, -.40799100E+01, 0.16358000E+01, 0.61639300E+00, 0.61636900E+02, -.68961900E+02, -.12432700E+02, -.36586800E+01, -.91433200E+01, 0.14611200E+02, 0.60438200E+02, 0.21121900E+02, -.20632900E+02, 0.44456200E+02, 0.17421800E+02, -.52058300E+02, 0.26304000E+02, -.30897100E+02, 0.45988000E+02, 0.26323100E+02, 0.70109300E+02 },
        { -.76993100E+01, 0.24252800E-01, 0.31968700E+00, -.11264400E+00, -.10132200E+01, 0.39752400E+00, 0.89484300E+00, -.33146500E+00, -.20189500E+00, 0.35649400E+00, -.15682600E-01, 0.12146300E+01, 0.69571900E-01, 0.17409900E-01, -.11700500E+00, -.37615000E-01, 0.44331900E-01, 0.32901400E+00, -.15373100E+00, 0.54512000E+00, 0.39938200E+00, -.13199000E-02, 0.18173800E+01, 0.44989800E-01, -.88555900E-03, -.56947000E-01, -.10920400E+00, 0.88436500E-01, -.13080000E+00, -.29434400E+00, -.66778500E-01, 0.27811100E+00, 0.27736000E-02, -.50169100E+00, -.25651100E+00, 0.13958500E+00, -.52965800E-01, -.62953400E+00, 0.12932400E+00, 0.27229200E+00, -.57221700E+00, -.58197100E+00, 0.45500800E+00, -.28777600E+00, -.45199400E+00, 0.84927500E-01, 0.76654900E-02, 0.59590700E-02, 0.43356000E+00, -.16437100E+00, -.12654200E+01, 0.27518800E+01, -.13412900E+00, 0.18479100E+00, -.11068300E+00, -.53841100E+00, -.39906500E-02, 0.10042700E+01, -.82142100E-01, 0.39438900E-01, -.54412700E+00, 0.14533700E+00, 0.87023500E+00, 0.36367900E-01, -.58706100E+00, -.10571700E+00, 0.43684200E+00, -.30224900E-02, 0.99680900E-01, -.18536800E-02, -.69779400E-01, -.68948100E-02, -.23036900E-02, -.61986900E-01, -.14750100E+00, 0.51347400E+00, -.15623800E+00, 0.18011200E+01, -.25484400E+00, -.36486400E+00, -.31496600E-01, -.18376000E-01, 0.87603800E+00, 0.12769300E+00, -.36864200E-01, -.51462200E+00, 0.72469500E-01, -.68275000E-02, 0.51526000E+00, 0.32550800E+00, -.73995200E+00, -.18345800E-02, 0.10252600E+01, 0.16549700E+00, -.21428800E-01, -.43402500E-01, 0.23100100E+00, 0.22735000E+00, 0.20519400E+00, -.27660900E+00, -.36651400E-01, -.18854600E+00, -.88718500E-01, -.15302600E+00, 0.10429000E+00, -.48687300E-01, 0.11511900E+00, 0.17073700E+01, -.81285400E-01, 0.46977000E-01, -.23443800E+01, -.17444300E-01, -.16673300E+00, 0.12328800E-01, 0.65021500E+00, -.16152300E+00, -.31674900E-02, 0.20433200E+01, -.91441000E-01, 0.25165100E+00, -.74489000E-01, 0.82417500E-01, 0.17886800E-01, 0.13089600E+00, 0.50723700E-02, -.39856100E+00, -.36764600E-01, -.34156500E+00, 0.13281500E+00, -.11974600E+01, 0.15180200E+01, 0.15752500E+00, -.37187900E+00, -.89475800E-01, -.25674000E+00, 0.79898100E+00, 0.84524900E-01, -.20917200E+00, -.80164400E+00, 0.58373600E+00, 0.47920500E+00, 0.37645400E+02, -.12707400E+03, -.59905500E+03, 0.29905300E+03, 0.33972300E+03, 0.29948900E+03, 0.21873100E+03, 0.10208400E+03, 0.49891700E+02, -.56252400E+02, 0.24460300E+03, 0.14174500E+03, 0.26247300E+02, 0.19946900E+03, -.89179700E+02, -.15446200E+03, -.99465300E+02, -.18926900E+02, -.10175000E+02, -.13285200E+02, 0.34961400E+02, -.76758300E+02, -.25166500E+02, 0.76217100E+01, 0.15039700E+03, -.78569800E+02, 0.30146900E+02, -.75271800E+02, -.60080900E+02, 0.44090300E+02, -.12533900E+03, -.13125200E+03, -.16299600E+03, 0.31302700E+02, -.25843900E+03, -.80134800E+02, 0.38967300E+02, 0.32360500E+02, 0.40207700E+02, 0.63558900E+02, -.93452800E+01, 0.78890900E+02, 0.69476500E+02, -.19822600E+01, 0.10723800E+02, 0.71004600E+02, 0.43343200E+02, -.16461300E+02, -.53858300E+02, -.21622200E+02, 0.62117500E+02, 0.16009300E+02, 0.10901700E+02, 0.95494200E+02, 0.15622100E+03, -.89662400E+02, 0.44126900E+03, -.53863200E+02, 0.24878500E+02, 0.13853400E+03, 0.26951700E+02, -.12300600E+02, -.11020000E+02, 0.43986800E+02, 0.49835700E+02, 0.28056900E+02, -.26548400E+00, 0.25461900E+02, 0.82022100E+02, -.34444000E+02, -.99955300E+02, -.40872400E+02, 0.88384700E+02, 0.10524300E+03, -.47302600E+02, 0.13959400E+02, 0.16538500E+02, 0.10691200E+02, 0.31832300E+03, -.67044200E+03, 0.33485200E+03, 0.21897300E+03, 0.33506600E+03, -.43880000E+01, 0.15547900E+03, 0.24627000E+02, -.20967800E+03, -.24671100E+02, 0.10655400E+03, 0.53423900E+03, -.56585000E+03, 0.28364000E+03, 0.27970500E+03, 0.28297900E+03, 0.10445700E+03, 0.79493500E+02, 0.67966600E+02, -.10645500E+03, 0.12719900E+03, 0.72421300E+02, 0.30143500E+03, -.10187100E+02, -.26421300E+01, 0.26711100E+02, 0.51551800E+01, 0.16646900E+02, 0.65908400E+02, -.78611800E+02, -.11993700E+03, -.47501300E+02, 0.51088300E+02, -.31478000E+02, -.39404000E+03, 0.19704300E+03, -.86301600E+00, 0.19725800E+03, 0.18339200E+03, 0.10143800E+03, -.53109500E+01, -.71282400E+02, 0.66207800E+02, 0.13967300E+03, 0.13215500E+03, -.17284400E+03, 0.83335900E+02, 0.21855000E+02, 0.86336900E+02, -.39199800E+02, -.11693100E+03, 0.13210900E+03, 0.13193400E+03, 0.24134100E+03, -.98149800E+02, 0.21172900E+02, 0.24984700E+01, -.27567000E+01, 0.70382900E+01, -.16858100E+01, -.14381000E+02, 0.13361800E+02, 0.45213800E+01, -.11956700E+00, -.97288200E+01, 0.10443900E+02, -.51306100E+01, -.34525100E+01, 0.86786400E+01, -.13506500E+02, -.72318200E+02, 0.10965200E+02, 0.77795800E+01, -.91047500E+01, 0.48461900E+02, -.27646900E+02, -.47837000E+02, -.25192300E+02, 0.12096200E+02, 0.25391300E+02, 0.40975300E+02, 0.52501000E+01 },
        { 0.21752700E+02, -.32235300E+00, -.92719800E+00, -.26840000E+01, 0.21098000E+01, -.40833700E+01, -.17704900E+01, -.52736500E+00, 0.27018700E+01, -.32471200E+01, -.17126800E+01, 0.28701800E+01, 0.51667600E+00, -.21304100E+00, 0.16208300E+00, -.43800300E+00, -.31769000E+00, -.11848400E+00, 0.89188700E+00, -.19290700E+01, -.27159100E+01, 0.67226400E+00, -.92810200E+01, -.13372000E+01, -.13201300E+00, -.15964600E+00, 0.42283200E+00, -.22729800E+01, -.44739100E+01, 0.23459200E+01, -.17800500E+00, 0.49511400E+01, 0.61448300E+00, -.44766400E+01, 0.73897100E+00, 0.20168400E+01, -.11827900E+00, 0.53097000E+01, -.13798700E+01, 0.19439500E+01, -.15096300E+01, -.35566100E+01, -.49062600E-01, 0.23516100E+01, -.17959500E+01, -.51056800E-01, 0.48646100E+00, 0.35749700E-02, 0.40789800E+00, -.16103300E+00, -.10548900E+01, 0.24069300E+01, -.88091700E+00, -.37272900E+00, 0.51127700E+00, 0.17302400E+00, -.38188400E-01, 0.12592500E+01, 0.36812600E+00, -.52877600E-01, 0.30821500E+00, -.30640200E+00, 0.41018100E+00, 0.13829200E+00, 0.18338700E+00, 0.30000900E+00, 0.21256000E+01, -.75052200E-01, 0.36404600E+01, -.22489800E-02, -.42814000E+00, 0.22468900E-01, -.16482200E+00, 0.63209200E-01, -.16054100E+01, 0.88325400E+00, 0.85833200E+00, 0.69598500E+01, 0.71407900E+00, -.24537500E+00, -.42741800E-01, 0.38870100E+00, -.96500600E-01, 0.30803200E+00, 0.11222000E+00, -.42205100E+01, -.82535000E+00, 0.28880100E+00, -.81379700E-01, -.16444600E+01, -.44665900E-01, -.17193700E+00, 0.33987000E+00, -.12243800E+00, -.24171000E+00, 0.61259000E+00, -.29183500E+00, 0.43372900E+00, -.22711400E+01, 0.10767200E+01, -.27652300E+00, -.67595900E+00, -.22473000E+00, 0.80520200E+00, 0.77104700E-01, 0.10548900E+01, -.31004500E-01, -.11847900E+02, 0.10448500E+01, -.41553800E+00, 0.53052200E+01, -.43028900E+00, 0.13466100E+01, -.49528500E-02, -.20695200E+01, -.37594300E+00, 0.14118300E+00, 0.58244900E+01, 0.11949500E+00, 0.32849900E+01, -.50043800E+00, 0.36629500E+00, 0.33219500E-01, 0.11820600E+01, 0.10940300E-01, -.42065600E+01, 0.14797100E+00, -.57480400E-01, 0.10509400E+01, -.13976200E+01, -.83265900E+01, 0.12300900E+01, -.26216200E+00, -.45989300E-01, -.55784200E+01, 0.30157000E+01, -.10045800E+00, -.93392900E+00, -.70874400E+01, 0.34348600E+01, 0.33021900E+01, -.11434900E+01, 0.95391900E+03, 0.34869700E+04, -.17368500E+04, -.24219000E+04, -.17437700E+04, 0.52612000E+02, -.39403500E+03, -.10575400E+03, 0.15001800E+04, 0.19772800E+03, -.28707500E+03, -.17717000E+04, 0.16588500E+04, -.72128100E+03, -.93761200E+03, -.82881900E+03, -.15599500E+03, -.30163800E+03, 0.31903300E+02, 0.68392400E+03, -.19142100E+02, -.36989900E+03, -.33982300E+03, 0.87774200E+03, -.45644000E+03, -.59705800E+03, -.43934200E+03, -.64314000E+03, -.35745200E+03, -.87884000E+02, 0.11080100E+03, 0.73216200E+02, -.50758200E+03, 0.17603000E+03, -.36879200E+03, 0.17236400E+03, 0.13461600E+03, 0.18531700E+03, 0.36730400E+03, 0.12082300E+03, 0.32830500E+03, 0.20048400E+03, 0.20090200E+03, 0.85699900E+02, 0.25574200E+03, -.18921400E+04, 0.99983300E+03, 0.10077400E+04, 0.94641300E+03, 0.14658400E+03, -.19946200E+03, 0.67885800E+03, -.40313000E+03, 0.97097000E+03, 0.34107800E+02, -.48593100E+03, 0.38993400E+02, -.10379100E+02, 0.41141600E+03, -.19340600E+02, 0.63343900E+02, 0.98856000E+02, 0.10608000E+03, 0.25712300E+03, -.44039300E+02, 0.10815300E+03, 0.97238100E+02, -.19084200E+04, 0.99764200E+03, 0.68920000E+03, 0.95509700E+03, 0.15177000E+03, -.25425100E+03, 0.55549600E+03, -.40999200E+03, 0.10278600E+04, -.64377400E+01, -.43708600E+03, -.66295100E+04, 0.32999300E+04, 0.28104300E+04, 0.33137400E+04, 0.38046700E+03, 0.11354200E+04, 0.51026700E+02, -.19697500E+04, 0.20979100E+03, 0.93560300E+03, 0.35586400E+04, -.15917600E+04, 0.79147300E+03, 0.13106400E+04, 0.79624200E+03, 0.12540200E+03, 0.11581400E+03, 0.27320400E+03, -.29598700E+03, -.66756500E+02, 0.16161300E+03, 0.86876500E+03, -.72452100E+03, 0.28701800E+03, 0.15390200E+03, 0.36230400E+03, 0.20983400E+03, 0.51509300E+03, -.52115600E+03, -.10956500E+04, -.17776100E+03, 0.48157500E+03, -.13552000E+03, -.18251500E+04, 0.90913800E+03, -.35857000E+02, 0.91398100E+03, 0.73134500E+03, 0.42508300E+03, 0.34519100E+03, -.11310700E+03, 0.78914700E+03, 0.35469700E+03, 0.15923400E+04, -.62547300E+03, 0.27941900E+03, -.23149000E+02, 0.31208700E+03, -.32223200E+03, -.69428500E+03, 0.82345500E+03, 0.72667800E+03, 0.97755100E+03, -.59924600E+03, 0.14298700E+02, -.21072100E+02, 0.28683500E+02, -.66763500E+01, -.21923300E+02, -.10350900E+02, 0.17395100E+02, -.68683800E+01, -.46596000E+01, 0.14253400E+02, -.12070400E+03, 0.16983600E+03, 0.42718200E+02, 0.40430400E+01, 0.45066800E+02, -.26475500E+03, -.99215100E+02, 0.32933600E+02, 0.37601400E+00, -.64701900E+02, -.12502200E+03, 0.10235600E+03, -.13322800E+03, 0.63397700E+02, 0.16721100E+02, 0.72376200E+02, -.12509300E+03 },
        { 0.10259100E+02, -.15438100E+00, -.40623600E+00, 0.41119400E+00, 0.84104400E+00, -.21371500E+00, -.22375200E+01, 0.14726200E+01, -.26386800E-01, 0.10991600E+00, -.18917600E-01, -.89764700E+00, 0.26085300E-01, -.34982800E-01, 0.14096700E+00, 0.94144700E-02, -.48730100E+00, -.72066000E+00, 0.36842900E+00, -.55010500E+00, 0.17802500E+00, 0.16759900E-01, -.28850100E+01, 0.24415900E+00, -.87790600E-01, 0.53648600E-01, -.47085400E-01, -.13586300E+00, 0.49985100E+00, 0.51796400E+00, 0.45119100E-01, 0.11168400E+01, 0.13183800E-01, 0.12672100E+00, 0.12375400E+01, -.10035100E+00, 0.16931500E+00, -.15067800E+00, -.42209000E+00, 0.31438500E+00, 0.68695100E+00, -.97302100E+00, 0.87882100E+00, 0.45053800E+00, -.52127900E+00, 0.13889500E+00, 0.19840900E+00, -.17935400E-01, -.55785400E+00, 0.10830200E+00, 0.97357200E-01, 0.26083800E+01, 0.60687000E-02, -.86966500E-01, 0.18337400E+01, -.26783000E+00, 0.30188000E-01, -.11673300E+01, -.57402900E+00, 0.88511600E-01, 0.57512500E+00, -.23372200E+00, -.85536700E+00, 0.29201700E-01, 0.16600600E+00, 0.12360200E+00, -.48380600E+00, 0.13476500E-01, -.15494500E+00, -.24823600E-02, -.33691500E-01, 0.22418100E+00, 0.30642700E+00, -.11737300E+00, -.35362600E+00, -.16100800E+00, -.94186500E-01, -.22830000E+01, -.19628600E+00, -.18994900E+00, -.58159200E-02, 0.68243500E+00, 0.17869400E+01, -.11681800E+00, 0.30292000E+00, -.32535800E+01, 0.65306700E-01, -.14340200E-01, 0.42943000E+00, -.19397500E+00, -.36403200E+00, -.10041500E-01, 0.26718800E+00, 0.13142000E+00, 0.33466100E-01, 0.24783300E+00, 0.37357000E+00, 0.33678100E+00, -.37691300E+00, -.10110000E+00, -.54365300E-02, -.40464400E-01, -.15433400E-01, -.22295300E+00, 0.19517900E+00, -.33258800E+00, 0.78347400E-01, 0.17136900E+01, 0.45848800E-01, -.12750100E-01, -.15007400E+01, -.15227700E-01, 0.10927000E+00, 0.67908300E-02, 0.71521000E+00, -.56678900E-02, -.45831400E-02, -.94243300E+00, -.23569600E+00, 0.61876800E+00, 0.89047500E-01, -.26922100E-01, 0.74350200E-02, 0.25859000E+00, 0.80878100E-02, -.41614100E+00, 0.59821300E-01, -.43815100E+00, 0.17681900E+00, -.60610700E+00, 0.20368700E+01, 0.46266800E+00, -.62500000E+00, -.12358800E+00, -.25457200E+01, 0.13697400E+01, 0.21342800E-01, -.29350500E+00, -.30722500E+00, 0.48295100E-01, 0.92365300E+00, -.31047400E+00, -.51355300E-01, 0.13979900E+04, -.69924500E+03, -.94897400E+03, -.69914300E+03, -.10385200E+03, -.15150800E+03, -.98023000E+02, 0.61986200E+03, 0.27575300E+01, -.15000400E+03, -.66476200E+03, 0.43246000E+03, -.17517000E+03, -.71503200E+02, -.21599100E+03, -.17915300E+02, -.12087000E+02, -.80747000E+01, 0.19825500E+03, -.16353100E+03, -.11677400E+02, -.18181900E+03, 0.68740500E+03, -.34569800E+03, -.29778000E+03, -.34395300E+03, -.73537300E+02, -.32341500E+02, -.60283000E+02, 0.14004700E+02, -.21655600E+03, -.14184800E+03, 0.11286600E+03, 0.73317800E+02, -.30788700E+02, -.55204100E+02, -.36167300E+02, 0.70041800E+02, 0.17156800E+02, -.16414200E+02, -.42337300E+01, 0.82133200E+02, 0.14184200E+02, -.65365200E+02, -.47288500E+03, 0.24435800E+03, 0.19609400E+03, 0.23662800E+03, -.11318800E+03, -.13107600E+03, 0.14612300E+03, -.12918600E+03, 0.49433300E+03, -.52598500E+02, -.27289200E+03, 0.38834300E+02, 0.93561300E+01, 0.31541500E+02, -.19325800E+02, 0.16202100E+02, 0.32070300E+02, -.15924300E+02, 0.47931800E+02, 0.76184800E+01, 0.26651800E+02, 0.30763600E+02, -.52474900E+03, 0.26816200E+03, 0.15757400E+03, 0.26285100E+03, -.78795300E+02, -.17940700E+03, 0.18771800E+03, -.84884500E+02, 0.47796600E+03, -.80816500E+02, -.24183600E+03, -.32326200E+04, 0.16130800E+04, 0.14796300E+04, 0.16157600E+04, 0.26865700E+03, 0.35325500E+03, 0.42111300E+03, -.87622300E+03, 0.30733900E+03, 0.31261200E+03, 0.14458700E+04, -.13481900E+04, 0.67337000E+03, 0.63560300E+03, 0.67429100E+03, 0.14653700E+03, 0.96426700E+02, 0.28296100E+03, -.17979100E+03, 0.18055700E+03, 0.12232700E+03, 0.49588800E+03, -.11912200E+03, 0.28006300E+02, -.24073800E+02, 0.59546100E+02, 0.26274700E+02, 0.75847700E+02, -.14903400E+03, -.37192900E+03, -.43126400E+02, 0.66046100E+02, -.80827400E+02, 0.13571500E+03, -.65887500E+02, -.26101000E+03, -.67099300E+02, -.67382700E+02, -.88287900E+02, 0.13334700E+03, 0.18917600E+03, 0.18878200E+03, -.10385800E+03, 0.59613600E+01, -.20994300E+03, 0.98292200E+02, 0.12912100E+02, 0.10459400E+03, -.66041600E+02, -.18415600E+03, 0.22390100E+03, 0.19154400E+03, 0.32414200E+03, -.15814400E+03, 0.63764300E+02, -.42197000E+01, 0.99449100E+01, 0.19411700E+01, -.63206800E+01, 0.21030200E+01, -.45150500E+01, -.15763800E+02, 0.51870500E+00, -.49750400E+00, -.30490600E+02, 0.41018600E+02, 0.51533200E+01, -.68855300E+01, 0.93062800E+01, -.61973200E+02, -.33636100E+02, 0.74934600E+01, 0.89974000E+01, -.99484100E+02, 0.15345100E+02, 0.63078900E+02, -.33503100E+02, 0.37138400E+02, 0.15821700E+01, -.27707100E+02, -.37666800E+02 },
        { 0.12697300E+02, -.51430700E+00, -.33157500E+00, 0.11047700E+00, 0.12171700E+01, -.33010400E+01, 0.10747700E+01, -.14916100E+01, 0.34266700E+01, -.30787400E+01, 0.70284400E-02, 0.14658700E+00, -.16206700E+01, -.32255000E-02, -.29888700E+00, -.45573400E-01, -.34662900E-01, -.23392800E-01, 0.56368800E+00, -.38378100E+00, -.77194600E+00, 0.38088000E+00, -.29336200E+01, -.68636700E+00, -.18989600E-01, 0.56228800E-01, 0.19442100E+00, -.29157600E+00, -.18974500E+01, 0.64956300E+00, -.42526900E+00, -.15587800E+01, 0.84213500E-01, -.67258600E+00, 0.66751300E+01, 0.14596600E-01, 0.14614300E+00, 0.56121200E+01, -.66824800E+00, 0.46963900E+00, 0.39571300E+00, -.72630600E+00, -.94253700E+00, 0.27681200E+01, 0.86506400E+00, 0.29158400E-01, -.21711000E+00, -.46715400E-01, -.74810900E+00, -.20874300E+00, 0.20802800E+01, 0.36423200E+01, -.52280900E+00, -.90931300E+00, 0.64768800E+01, 0.53047700E+00, -.41760900E-01, -.77590700E+00, -.10507300E+01, 0.18601700E+00, 0.34995400E+00, 0.70477500E+00, -.46953200E+00, -.61697500E-01, 0.47950200E+00, 0.22603100E+00, 0.40464100E+00, 0.39865300E-01, -.40849300E-01, -.73089200E-02, 0.18530300E-02, -.46565200E+00, 0.10984000E-01, -.55012500E+00, 0.46193500E+00, -.13802800E+01, -.81037500E+00, -.14198300E+02, -.83973400E+00, -.80008100E+00, -.77079200E-01, 0.69787000E+00, -.37651300E+01, 0.70844200E+00, -.25897400E+01, -.90360600E+01, 0.81041400E+00, -.57782700E-01, 0.15266000E+01, 0.53390900E+00, 0.15021400E+00, -.43086800E-01, -.20453400E+01, 0.66138100E+00, 0.11712800E+01, -.18702400E+00, -.90526200E+00, -.29976300E+00, -.31082300E+01, -.35054200E+00, 0.38840400E+00, 0.16705500E+01, -.44916000E+00, -.66526900E+00, 0.36799200E+00, 0.12426000E+01, 0.45105700E-01, 0.12221500E+01, 0.11114600E+00, -.25795600E+00, -.56345500E+01, -.26308200E-02, -.11222200E+01, 0.12335100E-01, 0.12616500E+01, -.24652600E-01, 0.25369800E-01, -.16404600E+01, 0.49285000E+00, -.41558200E+01, 0.59658300E+00, 0.14782800E+00, 0.17009100E+00, 0.64795200E+00, 0.15187700E-01, 0.79554500E+00, -.16554100E+00, -.12347400E+01, 0.39634600E+00, 0.32498300E+01, 0.12622500E+01, -.59734700E+00, 0.15024700E+00, 0.13757000E+00, -.49585900E-01, -.33954600E+00, 0.26956400E+00, 0.29369800E+00, -.31507800E+00, 0.93505200E-01, -.97006600E+00, 0.10332700E+01, 0.64057700E-01, -.14424400E+01, 0.38700100E+02, -.73654700E+03, 0.12154700E-01, 0.83115600E+02, -.14502200E+02, -.74789400E+02, 0.20654200E+03, 0.39967000E+03, -.19051900E+02, -.23366600E+03, -.55330900E+03, 0.21662000E+03, 0.49334500E+03, 0.27672100E+03, 0.29085000E+02, 0.24383100E+02, 0.67301200E+02, -.32005900E+03, -.17863700E+03, 0.77055700E+02, 0.12464000E+03, 0.64671100E+03, -.32684800E+03, -.12718800E+03, -.32332900E+03, 0.12859100E+03, 0.12184700E+03, -.58488700E+02, -.83067400E+02, -.20941700E+03, 0.77319700E+02, -.37743000E+03, 0.19069800E+03, -.96102100E+02, -.12545400E+03, -.95409000E+02, -.13825400E+03, -.46226300E+02, -.15817700E+03, -.15803500E+03, -.23982000E+02, -.28776300E+01, -.20054300E+03, 0.82982100E+03, -.44464900E+03, -.53878800E+03, -.41494200E+03, -.18819800E+03, -.11467400E+03, -.20873600E+03, 0.25136500E+03, -.41881900E+02, -.29849700E+02, -.17016600E+03, 0.28186800E+02, -.10216800E+03, -.35128500E+02, -.14132600E+02, -.81073600E+01, 0.12797200E+02, -.71787300E+02, -.84081000E+02, 0.15190800E+02, 0.60299500E+01, -.38213800E+02, 0.66459400E+03, -.34220700E+03, -.48112100E+03, -.33236800E+03, -.14228600E+03, -.16016600E+03, -.79123400E+02, 0.32012700E+03, -.29984800E+01, -.10376400E+03, 0.26841600E+02, -.16015600E+04, 0.79992800E+03, 0.92016800E+03, 0.80084800E+03, 0.94641400E+02, 0.29795400E+03, 0.23629000E+03, -.52266300E+03, -.35967400E+01, 0.26382900E+03, 0.83994800E+03, -.77211600E+03, 0.38600900E+03, 0.42957900E+03, 0.38603300E+03, 0.84695000E+02, 0.15049500E+03, 0.43885300E+02, -.20768300E+03, 0.18608800E+03, 0.14947600E+03, 0.19298900E+03, 0.11660000E+04, -.53354900E+03, -.54939900E+03, -.58292500E+03, -.10412500E+03, -.43251600E+02, -.11686500E+03, 0.41331200E+03, -.17329200E+03, -.86538000E+02, -.27648600E+03, 0.47121700E+03, -.23084400E+03, -.33618000E+03, -.23574900E+03, -.33275300E+03, -.15653600E+03, -.10152600E+02, 0.10123600E+03, -.69899400E+02, -.15239700E+03, -.24517400E+03, -.20396600E+03, 0.11045400E+03, -.94702300E+01, 0.10219600E+03, 0.58659400E+02, 0.68180900E+02, -.33864400E+02, -.66300000E+02, 0.63524000E+02, 0.56230200E+02, 0.81435800E+02, 0.30309500E+01, -.12558000E+02, -.42442400E+01, 0.66537400E+00, 0.50724300E+01, -.72168300E+01, -.72001000E+01, 0.13859700E+01, 0.46469100E+01, -.43201100E+02, 0.37768100E+02, -.63158900E+01, -.96087800E+01, -.52253900E+01, -.39662900E+02, -.53167100E+02, 0.36432800E+02, -.77376800E+00, -.12173000E+03, 0.11973200E+03, 0.22562600E+02, -.20997800E+02, -.14263800E+02, -.83373800E+02, -.59588200E+02, -.47867900E+02 },
        { -.14579500E+02, 0.38150000E+00, 0.85915200E+00, -.21261600E+01, -.55846300E+00, 0.23468800E+01, -.18886700E+01, 0.91002500E+00, 0.14569700E+01, 0.15527000E+01, -.16156400E+00, -.37160400E+00, 0.58287600E+00, -.75072900E+00, -.78896200E+00, 0.15980700E+00, -.21975500E+00, 0.19496700E+00, 0.14315400E+00, -.86804800E+00, -.19822500E+01, 0.58864000E+00, -.33153700E+01, 0.57396100E+00, 0.12255900E+01, 0.32005000E+00, 0.47519300E+00, -.60536100E+00, -.20740600E+01, -.16338900E+01, -.17198500E+01, -.30023400E+01, 0.18799700E-01, -.18740600E+01, 0.38012700E+01, 0.99955300E+00, 0.55682400E-01, 0.50378400E+01, 0.12534500E+00, 0.22903100E+01, -.21876400E+01, -.24944300E+01, -.12859700E+01, 0.23327500E+01, 0.81909700E-01, 0.61927000E+00, 0.12841900E+01, -.44860100E-01, 0.15498100E+01, -.31380700E+00, -.43168800E+00, 0.60672800E+01, -.40802100E+00, -.19547400E+00, 0.68059000E+00, -.35381600E-01, 0.16166300E-01, 0.84193700E+00, -.11010000E+01, 0.37024500E+00, 0.13641500E-01, -.50501400E+00, 0.14731200E+00, 0.15235600E+00, 0.38195200E+00, -.10333200E+00, -.12900200E+01, -.92302800E-02, 0.84855800E+00, -.11441400E-01, 0.31490900E-01, -.27672300E-01, 0.21439400E+00, -.24544900E-01, 0.72132300E+00, -.87035900E-01, 0.55429300E+00, 0.22085100E+01, 0.91469500E-01, 0.11863300E+01, 0.45105000E-01, 0.56428200E+00, -.17938500E+01, -.24355600E+00, -.96827800E+00, -.18305000E+00, -.14218400E+00, -.57155900E-01, 0.31464400E+00, -.63278800E-01, -.76504000E-01, 0.14023400E+00, -.22785900E+01, 0.38995000E-01, 0.14006200E+00, -.80284500E+00, -.18016300E+01, -.64954900E+00, -.13142000E+01, -.27174100E+00, 0.11562500E+00, -.92543600E+00, 0.94517600E+00, -.41647600E+00, 0.17923600E+00, 0.51518400E+00, 0.34989500E+00, 0.81195100E+01, 0.31062800E+00, -.33652900E+00, 0.39679800E+01, -.14598400E+00, -.10686500E+01, -.10052300E-02, -.79200000E+00, 0.71776400E+00, 0.19514300E+00, 0.35489700E+01, 0.10823700E+01, 0.70100300E+01, -.24751600E+00, 0.76124200E-02, 0.13515400E+00, 0.67563100E+00, 0.34353500E-02, 0.50560600E+00, 0.43670100E+00, 0.17591600E+01, -.63507900E+00, -.53055100E+00, 0.14217100E+01, 0.30121800E+00, -.38108200E+00, 0.17162100E+00, 0.31667900E+01, -.29370900E+01, -.21175800E+00, -.49967000E-01, -.79609500E+00, 0.35906000E+00, 0.18760300E+01, -.17593000E+01, -.91301600E-01, 0.30591900E+00, 0.13575800E+00, -.15451100E+04, -.21017500E+00, 0.12651600E+03, 0.24872000E+03, -.14866200E+03, 0.66998300E+02, 0.16582300E+03, 0.14821600E+03, 0.31471400E+02, 0.10199000E+04, -.42436100E+03, -.43339800E+03, -.50920900E+03, -.61379800E+02, -.17286200E+03, 0.52770400E+02, 0.56053200E+03, -.32171500E+03, -.17915500E+03, -.23988500E+03, 0.57470600E+03, -.29802000E+03, -.31589600E+03, -.28772000E+03, -.23424300E+03, -.24060000E+03, -.48348700E+01, 0.17943700E+03, -.35541800E+03, -.26085700E+03, 0.14394900E+03, -.45089000E+03, 0.21988200E+03, -.34424500E+03, 0.22615900E+03, 0.48701300E+02, 0.22977400E+03, 0.21778200E+03, 0.10416600E+02, 0.16046200E+03, 0.12450200E+03, 0.40364200E+03, -.19480500E+04, 0.99947900E+03, 0.69358100E+03, 0.97428600E+03, 0.21200500E+03, 0.99680000E+02, 0.50722500E+03, -.31571300E+03, 0.10432300E+04, -.34908700E+02, 0.30880500E+03, 0.21954400E+03, -.49040100E+02, 0.34336900E+03, -.10965200E+03, 0.37216900E+02, 0.20816600E+02, 0.63204400E+02, 0.33753500E+03, 0.73538200E+02, 0.38821300E+02, -.51796600E+02, -.14698200E+04, 0.76028000E+03, 0.39590500E+03, 0.73560600E+03, 0.20760500E+03, 0.13227200E+03, 0.30537900E+03, -.39307900E+03, 0.69718000E+03, 0.56721800E+02, 0.42178000E+02, -.25944600E+04, 0.12872600E+04, 0.96528600E+03, 0.12964400E+04, 0.98045800E+02, 0.44781000E+02, 0.43593800E+03, -.26860200E+03, 0.52104900E+03, 0.13545900E+03, 0.13119200E+04, -.17333300E+04, 0.86161800E+03, 0.15220000E+04, 0.86694400E+03, 0.18572100E+03, 0.74181600E+02, 0.34455400E+03, -.22879400E+03, 0.17888700E+03, 0.99992100E+02, 0.82605000E+03, -.96439000E+03, 0.41734000E+03, -.91560500E+03, 0.48230400E+03, 0.10922500E+03, 0.29846300E+03, -.34068800E+03, -.10817400E+04, -.15977800E+02, 0.27734300E+03, 0.93304500E+02, -.16751500E+04, 0.83765300E+03, -.18976000E+04, 0.83871800E+03, 0.64935200E+02, 0.36549700E+03, 0.24118400E+03, -.24534400E+03, 0.91828200E+03, 0.18872300E+03, 0.10561300E+04, -.63790100E+03, 0.29427400E+03, 0.52740100E+03, 0.31845900E+03, -.81847000E+02, -.32015400E+03, 0.49434000E+03, 0.40137500E+03, 0.82313500E+03, -.29663200E+03, 0.19797100E+03, -.17271300E+02, 0.12815600E+02, 0.23389200E+02, -.17366000E+02, -.12055600E+02, 0.14948600E+02, -.26329500E+02, -.22297500E+01, -.17706000E+02, -.61517600E+02, 0.87133900E+02, -.45795000E+02, 0.11473800E+02, 0.14022600E+02, 0.98598600E+02, -.61195800E+02, -.65096500E+02, 0.45211400E+02, 0.91955900E+02, -.11475400E+03, -.99912400E+01, 0.52280800E+01, 0.46184400E+02, 0.88499000E+02, -.87555100E+02, -.99977300E+02 },
        { 0.12546500E+02, -.40333700E+00, -.40698800E+00, 0.21230400E+01, 0.14841100E+01, -.36415800E+01, 0.15863200E+01, -.15292500E+01, 0.28602400E+01, -.35141100E+01, 0.10356200E+00, 0.83475500E+00, -.40351700E+00, 0.14186200E+00, 0.11439800E+01, -.42076300E+00, 0.59810400E+00, 0.72654200E+00, 0.47551800E+00, -.13629300E+01, -.89851700E+00, -.37613200E-01, 0.14862800E+02, 0.14953400E+01, -.46881700E-01, 0.18500800E-01, -.29333500E+00, -.54567000E+00, -.16614100E+01, -.57862000E+00, -.66482500E+00, -.18614500E+01, 0.68563900E-01, -.34385800E+00, 0.32639700E+01, 0.30172800E-02, -.40066700E-01, 0.36794800E+01, -.64471400E+00, 0.89984400E+00, 0.39914400E+00, -.56108500E+00, -.78977500E+00, 0.20627100E+01, 0.13043500E+01, -.27023900E+00, 0.31892300E+00, -.26033700E-01, -.51355500E+00, 0.48092700E-01, 0.30949300E+01, -.24579900E+01, -.22210200E+00, -.50178500E+00, 0.66143100E+01, 0.71603000E+00, 0.45070600E-01, -.82864600E+00, -.19320500E+00, 0.14982900E+00, 0.43847100E+00, 0.16107000E+00, -.80987700E-01, -.13278700E+00, 0.46506200E+00, 0.29508200E+00, 0.63417100E+00, -.25224900E-01, 0.60281100E+00, -.51294800E-02, -.18046700E+00, 0.33784700E-01, 0.16042700E+00, -.45624500E+00, -.69998000E+00, -.64610200E+00, -.32672100E+00, -.58998500E+01, 0.67668100E+00, -.93893800E+00, -.72012200E-01, 0.13892800E+01, -.24760100E+01, 0.37761800E+00, -.18690500E+01, -.56806600E+01, 0.34982500E+00, -.40332300E-01, 0.61289300E+00, 0.48338000E-01, 0.10829400E+00, -.77525300E-01, -.16576000E+01, 0.12089600E+00, 0.88977900E+00, 0.74835600E-01, -.45232800E+00, 0.99504000E-01, -.19418600E+01, -.29330200E+00, 0.16627900E+00, 0.10893000E+01, 0.74328500E-01, -.18154300E+00, 0.13785800E+00, -.58442400E-01, -.12264600E+00, 0.19643300E+01, 0.93744100E-01, -.16153300E+00, -.35422400E+01, -.57291100E-01, -.88991100E+00, -.20556200E-01, 0.95815900E+00, -.35722000E+00, 0.61724700E-01, 0.23577700E+01, 0.34647400E+00, -.13400500E+00, 0.24527500E+00, 0.22137500E+00, 0.82718500E-01, 0.10155300E+01, 0.30002300E-02, -.16704500E+00, 0.22427700E-02, 0.33979400E+00, 0.32994500E+00, 0.27161200E+01, 0.16336400E+01, -.75429800E+00, -.30258900E+00, 0.17385500E-01, 0.34637200E+01, -.17083200E+01, 0.58109300E-01, 0.42144600E+00, 0.52381500E+00, -.93512800E+00, -.15902400E+00, 0.54214300E+00, 0.32779500E-01, -.13909500E+01, -.58441100E-01, 0.57785500E+00, 0.28075500E+01, -.82440500E+02, -.52788100E+02, -.60645200E+02, 0.27287000E+03, 0.34531900E+03, -.72067500E+02, 0.37791700E+02, -.68268100E+03, 0.27133400E+03, 0.58659600E+03, 0.34010600E+03, 0.38091900E+02, 0.99074300E+02, 0.30576800E+02, -.29815900E+03, 0.41195300E+02, 0.13022900E+03, 0.97183200E+02, 0.42991700E+03, -.20637000E+03, -.11526800E+03, -.21499800E+03, 0.21988300E+03, 0.21423100E+03, -.10057100E+03, -.21416300E+03, -.73145700E+02, 0.13935500E+03, -.15402000E+03, 0.37978300E+03, -.17612900E+03, 0.77690800E+02, -.18979500E+03, -.11923600E+03, -.15070000E+03, -.20253700E+03, -.90724400E+02, -.20809000E+02, -.60000000E+02, -.39194000E+03, 0.11790100E+04, -.62945600E+03, -.43941800E+03, -.58945100E+03, -.31680200E+03, -.26782100E+03, -.27209500E+03, 0.33697500E+03, -.27415900E+03, -.43817100E+02, -.58736700E+03, -.17211100E+03, 0.52630200E+02, -.69887200E+02, 0.86088800E+02, -.25087300E+02, 0.36868700E+02, -.10172200E+03, -.28455800E+03, -.45627500E+02, 0.11200900E+02, 0.56176700E+02, 0.89176800E+03, -.47782600E+03, -.32276300E+03, -.44581900E+03, -.27311300E+03, -.33363900E+03, -.87299800E+02, 0.43836800E+03, -.81274200E+02, -.16322200E+03, -.26794400E+03, -.89714700E+03, 0.45778900E+03, 0.67615900E+03, 0.44846300E+03, 0.18558000E+03, 0.21511800E+03, 0.22987100E+03, -.48884300E+03, -.84395100E+02, 0.14745900E+03, 0.99592700E+02, -.13787000E+03, 0.73382400E+02, -.27550100E+03, 0.68980900E+02, 0.68798500E+02, 0.71483500E+02, 0.14096200E+02, 0.11948600E+02, 0.16152700E+03, 0.72010800E+02, -.20669900E+03, 0.81419200E+03, -.35606300E+03, 0.25675900E+03, -.40748400E+03, -.70965600E+02, -.12954300E+03, 0.82613000E+02, 0.54172800E+03, -.57037700E+02, -.13224200E+03, -.14745400E+03, 0.12096400E+04, -.60157700E+03, 0.56807400E+03, -.60485200E+03, -.32711000E+03, -.31843200E+03, -.85057200E+02, 0.26558500E+03, -.39247800E+03, -.23889600E+03, -.62779800E+03, 0.15883200E+03, -.55982400E+02, -.35333800E+03, -.79480800E+02, 0.86804700E+02, 0.19096600E+03, -.26354600E+03, -.26748400E+03, -.38345900E+03, 0.17865700E+03, 0.42198200E+02, 0.87256200E+01, -.12371900E+02, -.10476600E+02, 0.59362400E+01, 0.85196200E+01, -.13928000E+02, 0.62204100E+01, 0.41791000E+01, 0.73433100E+01, 0.30774500E+02, -.44168500E+02, 0.22341100E+02, -.18359800E+02, -.57207300E+01, -.78992400E+02, 0.22122200E+02, 0.67781700E+02, -.13791000E+02, -.21378100E+03, 0.23515100E+03, 0.66220800E+02, -.26134300E+02, -.47242300E+01, -.49372500E+02, -.23047000E+02, 0.51115100E+02 },
        { -.17630900E+01, 0.55001700E-01, 0.66665800E-01, 0.65714400E+00, -.22946200E+00, 0.55667700E+00, -.16542400E+00, 0.10294000E+00, 0.37785900E+00, 0.52716500E+00, 0.13772000E-01, -.64672300E-01, -.16289200E-01, 0.21708200E-01, 0.23139500E-01, 0.77230300E-02, 0.23011500E+00, 0.15588200E+00, -.25545500E-01, 0.11789200E-01, 0.82725100E-01, 0.15196700E-01, 0.10877100E+01, 0.53720000E-01, -.34897600E-02, -.33563300E-01, 0.23698700E-03, -.10473900E+00, -.12908800E+00, -.33233600E-01, -.73265700E-02, -.23294300E-01, -.16090100E-01, -.75583900E-01, 0.19059100E+00, -.55324300E-01, -.27912300E-01, 0.23959100E+00, -.66578400E-01, 0.19737700E+00, -.12624300E+00, -.17377700E-02, -.22074900E+00, 0.56284200E+00, -.25653300E+00, 0.19851100E-01, -.17270900E-01, 0.26826500E-02, -.13496800E+00, -.21857100E-01, -.10994800E+00, 0.14266500E+01, -.12756400E+00, -.40588500E+00, -.34229500E+00, 0.21387800E+00, -.56608300E-03, -.13830900E-01, 0.92924400E-01, -.25951700E-01, 0.69033100E-01, 0.11058200E+00, -.34777200E-01, -.31987300E-01, -.40250900E-01, -.28384300E-01, 0.10550300E+00, -.52116200E-02, -.12478800E+00, 0.67404900E-03, 0.10551800E-01, 0.73495200E-01, 0.13810200E-01, -.67184200E-02, 0.33043800E-01, 0.11664600E+00, 0.56955400E-01, 0.12474300E+00, 0.36698700E+00, -.88264300E-01, -.95862300E-02, 0.30745300E+00, -.76800100E-01, 0.21207000E-01, -.11261900E+00, -.15565800E+01, -.16405600E+00, -.24790000E-01, -.17406900E+00, -.20056600E+00, 0.22380100E+00, -.13945700E-01, -.38802000E+00, 0.57475600E-01, -.17549600E-01, -.16331300E-01, 0.10692000E-02, 0.73638900E-01, -.32242100E+00, 0.15182300E+00, -.13464800E-01, 0.18025800E+00, -.10188700E+00, 0.74986300E-01, -.15798900E-02, 0.35559400E-01, -.14757800E-01, -.10535600E+01, 0.74237000E-01, -.19404200E-01, 0.23102400E+00, -.50482800E-01, -.13573200E-01, -.39870400E-02, -.17196100E+00, -.21600500E+00, 0.30168300E-01, -.42708600E+00, -.24840900E-02, -.14601800E+00, -.10927300E+00, -.43407400E-01, 0.76534100E-02, -.14710700E-01, 0.41559000E-02, -.19766400E+00, 0.72904600E-01, 0.16747100E+00, -.84562200E-01, 0.34219700E+00, -.10654100E+01, 0.13933400E+00, 0.10059400E+00, -.17837000E-01, -.25585800E+00, 0.11916400E+00, 0.22678000E-01, 0.16371900E-01, -.91083200E-03, -.70983900E-01, -.22072800E-01, 0.18233800E+00, 0.49206700E-01, 0.33660800E-01, -.45940700E-02, -.75397300E-01, 0.13847300E-03, -.72856000E+02, 0.12582100E+01, -.14294900E+02, -.59340100E+02, -.83163300E+02, -.16565600E+02, 0.89549800E+02, -.25635800E+02, 0.59749100E+01, 0.45813400E+02, 0.12667900E+02, -.52470000E+00, -.15473400E+02, 0.10794000E+02, 0.18317800E+02, 0.13932900E+02, -.12027800E+02, -.27804400E+02, -.14954400E+03, 0.76351200E+02, 0.42189000E+02, 0.74777200E+02, 0.31961100E+02, -.19947800E+02, 0.58412800E+02, 0.31286700E+02, 0.59649000E+02, -.13792800E+02, 0.11077600E+03, 0.20377400E+01, 0.16055700E+01, -.12684700E+02, -.10265000E+01, -.15468900E+02, 0.48971700E+01, -.70801300E+01, 0.22555500E+01, 0.87716500E+01, -.95805800E+00, -.36841700E+02, -.11829600E+03, 0.53942900E+02, 0.68229400E+02, 0.59147900E+02, -.22033400E+01, -.15921600E+01, 0.35780200E+02, -.21191000E+01, 0.47481500E+00, 0.16352200E+02, -.93011600E+02, 0.56480900E+01, 0.26003000E+00, -.14269200E+02, -.28203300E+01, 0.36144600E+01, 0.54240200E+01, -.10659800E+02, -.21206000E+02, -.14288400E+02, 0.31859200E+01, -.10496500E+02, -.73699200E+02, 0.32334400E+02, 0.70718600E+02, 0.36841100E+02, -.96473100E+01, -.18388900E+02, 0.31853600E+02, 0.11469500E+02, 0.16704400E+02, -.47458500E+01, -.85630300E+02, 0.40942100E+03, -.20441100E+03, -.16965000E+03, -.20470300E+03, 0.94360100E+00, -.77121700E+02, -.21765700E+02, 0.14767400E+03, 0.40357300E+02, -.53494900E+02, -.30613800E+03, 0.19299600E+03, -.96489700E+02, -.76208200E+02, -.96500200E+02, -.27494300E+02, -.19097300E+02, -.37257800E+02, 0.41292700E+02, -.19475000E+01, -.15704100E+02, -.12151300E+03, -.82105300E+02, 0.47003400E+02, -.37718600E+02, 0.41002900E+02, 0.72452800E-01, -.10880900E+02, 0.31206500E+02, 0.85493600E+01, 0.24912500E+02, -.62020100E+01, 0.59853600E+02, 0.17343300E+03, -.85243000E+02, -.11525800E+03, -.86739100E+02, -.56002000E+02, -.35702500E+02, -.26140900E+02, 0.10136300E+02, -.34350000E+02, -.40211200E+02, -.89624900E+02, 0.43705500E+02, -.19334200E+02, 0.18927000E+02, -.21860500E+02, 0.21660200E+02, 0.46679700E+02, -.46832600E+02, -.49245700E+02, -.74551300E+02, 0.40626500E+02, -.80576800E+01, -.22307400E+00, 0.33686200E+00, -.11968200E+01, 0.90578700E+00, 0.24253800E+01, -.24076400E+01, 0.33610500E+00, -.54319500E-01, 0.16623900E+01, -.43282300E+01, 0.30133700E+01, -.25249500E+00, -.11335400E+01, -.20713200E+01, 0.33139500E+02, -.42177600E+01, -.52370600E+01, 0.42127000E+01, -.41010300E+01, 0.10003800E+02, 0.87173700E+01, 0.13612000E+02, -.69834500E+01, -.77386000E+01, -.10589400E+02, -.37356500E+01 },
        { -.18845100E+02, 0.10635300E+01, 0.62466400E-01, -.91838500E+00, -.40474100E+00, 0.90328000E+00, 0.20586600E+00, 0.93772100E+00, -.17241500E+01, 0.49286200E+00, 0.15416500E+00, -.41338800E+01, 0.45765900E+00, 0.19233900E+00, -.45293300E-01, 0.32945300E+00, -.12741600E+01, 0.29997100E+00, -.89442700E+00, 0.49329100E+00, 0.13682700E+00, -.53553800E+00, 0.31526400E+01, 0.18255500E+01, -.36988200E-01, 0.24889900E+00, -.35319700E+00, 0.19679100E+01, 0.28437200E+01, -.46353200E+00, 0.67615800E+00, 0.68913400E+00, -.68465100E-01, 0.12626700E+01, -.74442800E+01, -.19409300E+00, 0.86750000E-01, -.43348600E+01, 0.72112200E+00, -.14048400E+01, 0.86397000E+00, -.44554000E+00, -.80069300E-01, -.14358300E+01, 0.50936300E+00, -.72605800E+00, -.41100600E-01, 0.12181400E-01, 0.56523800E-01, 0.12566100E+00, -.37066400E+00, -.48924500E+01, -.68867400E-01, 0.33509900E+00, -.32580300E+00, -.31358800E-01, 0.34786400E-01, 0.46198800E+00, 0.69230000E+00, -.13632400E+00, -.50897700E-02, -.57734000E+00, 0.13708500E+00, -.91895500E-01, 0.57346100E+00, 0.40846500E+00, 0.49878200E+00, -.11741300E-01, 0.77151300E+00, 0.66772200E-02, -.24097100E+00, 0.62013400E+00, -.26942500E-01, 0.19519500E+00, 0.64176100E+00, 0.40084300E+00, -.52723500E+00, 0.49874200E+01, -.94505500E-01, 0.30485800E+00, 0.34492900E-01, 0.41862400E+00, 0.11772800E+01, -.17694900E+00, 0.96076900E+00, 0.18370600E+01, -.45005200E+00, -.23222500E+00, -.85803300E+00, -.17980300E+01, -.28809400E+00, 0.72284800E-01, 0.15757400E+01, -.84262000E+00, -.51489900E+00, 0.40751900E+00, 0.12019000E+01, 0.87286900E+00, 0.21048600E+01, -.30996900E+00, -.21204000E-01, -.64316200E+00, 0.52980500E+00, 0.36982700E+00, -.13444900E+00, -.22564300E+01, -.97813800E-03, 0.59738200E+01, -.22026600E+00, 0.30959600E+00, -.12377500E+01, 0.67624800E+00, 0.50104900E+00, -.32878800E-02, 0.18533400E+01, 0.14019800E+00, -.20165700E-01, -.36190300E+01, -.78840500E+00, 0.21679500E+00, 0.13865100E+00, -.44091800E-01, 0.50795600E+00, 0.50966700E+00, -.51753100E-01, 0.11132000E+01, 0.92045900E-01, 0.32693000E+00, -.17796800E+00, 0.97640900E+00, -.27608100E+01, -.48941900E-01, 0.11143700E+01, 0.71331200E+00, 0.77436300E+01, -.47455500E+01, -.34532900E+00, 0.48745100E+00, -.12752300E+01, 0.47501200E+00, -.42655700E+00, -.96044900E+00, -.12433500E+00, -.37151700E+00, 0.57491300E+00, -.31290000E+00, 0.10966200E-01, -.24302100E+01, 0.24745600E+03, -.12631300E+03, -.14667300E+03, -.29039800E+03, 0.16257600E+03, -.63270100E+02, 0.10024600E+04, -.38303200E+03, -.36409200E+03, -.50149500E+03, 0.13134800E+02, 0.13530200E+02, -.12402000E+03, 0.44842700E+03, -.16065300E+03, -.16215000E+02, -.24309600E+03, -.57564700E+03, 0.24057600E+03, -.12527000E+03, 0.28788400E+03, -.11386500E+03, -.22618900E+03, 0.93120200E+02, 0.59143600E+02, 0.18342300E+03, -.17063700E+03, 0.83571400E+03, -.50342800E+03, 0.25321300E+03, 0.38304300E+02, 0.25160200E+03, 0.18573400E+03, 0.97186500E+02, 0.18275800E+03, 0.98818100E+02, 0.11711100E+03, 0.39176400E+01, 0.42166900E+03, -.30796700E+04, 0.17431100E+04, 0.12730500E+04, 0.15398000E+04, 0.19556400E+03, -.10768400E+02, 0.75443300E+03, -.37982500E+03, 0.96937400E+03, -.11144400E+03, 0.44792300E+03, 0.12531900E+03, 0.10368100E+02, 0.70541600E+02, -.62665000E+02, 0.12153000E+02, -.88658000E+02, 0.91716300E+02, 0.29005700E+03, 0.95438500E+02, -.66128700E+02, 0.68895200E+02, -.20301200E+04, 0.11105500E+04, 0.95860000E+03, 0.10149500E+04, 0.20841500E+03, 0.60195300E+02, 0.47076600E+03, -.33377000E+03, 0.63872800E+03, -.26137800E+02, -.54742500E+02, 0.55166700E+03, -.32772900E+03, -.44963000E+03, -.27571000E+03, 0.33141200E+02, -.29103800E+03, 0.12030600E+03, 0.67185600E+03, 0.59273300E+03, -.25573100E+03, 0.26179200E+03, -.94374600E+03, 0.44956900E+03, 0.39782700E+03, 0.47183000E+03, 0.10806400E+03, 0.72113700E+02, 0.21667300E+03, 0.38889600E+02, 0.42157800E+03, 0.13421000E+02, 0.67934500E+03, -.12647300E+04, 0.54968200E+03, -.14020500E+03, 0.63228800E+03, 0.98585400E+02, 0.10667000E+03, -.34421900E+02, -.77684500E+03, 0.14389900E+03, 0.13785400E+03, 0.21628400E+03, -.78034200E+03, 0.41984500E+03, -.13561500E+03, 0.38999200E+03, 0.19803000E+03, 0.26607100E+03, -.71548200E+02, -.21479900E+03, 0.22850100E+03, 0.15281100E+03, 0.59753700E+03, -.96769400E+02, 0.16924900E+02, 0.27439700E+03, 0.48377500E+02, -.13693600E+03, -.29419400E+03, 0.32362500E+03, 0.33887500E+03, 0.33790000E+03, -.27867400E+03, -.12424000E+03, -.14371000E+02, 0.57560200E+01, 0.16246800E+02, -.44340000E+01, -.56098600E+01, 0.75134000E+01, -.28501800E+02, -.21530800E+01, -.13912800E+02, 0.15341400E+02, -.74272400E+01, -.14708400E+02, 0.25489800E+02, 0.97627000E+01, 0.14617800E+03, 0.26064600E+02, -.35696800E+02, 0.57207100E+00, 0.11933800E+03, -.20594300E+03, -.16482200E+02, 0.65463000E+02, 0.25724800E+02, 0.12113000E+03, 0.33975900E+02, 0.14584700E+02 },
        { -.29264000E+01, 0.39877100E-01, 0.10412900E+00, -.88920800E-01, -.34889500E+00, 0.12102100E+00, 0.77921000E+00, -.72484600E+00, 0.65588900E-01, -.92966100E-01, -.27883900E-01, -.35435900E+00, 0.18888100E-01, -.67687300E-02, 0.80872300E-01, 0.45404200E-01, -.38146100E+00, -.23205700E-01, -.30655900E+00, 0.48356900E+00, -.25055000E+00, -.28531700E-01, 0.89742600E+00, -.51629300E-01, 0.89308500E-01, 0.25891500E-01, 0.15185800E-01, 0.11753400E+00, 0.13586900E+00, 0.14551500E+00, 0.13270300E+00, -.53377200E-01, -.49211600E-02, -.28025900E+00, -.84066500E-01, 0.15966100E+00, -.33249700E-01, 0.35430900E+00, 0.74702700E-01, 0.17077900E+00, -.46871200E+00, 0.95961700E-01, 0.11767400E+00, -.90083100E-01, -.18528200E+00, 0.97873000E-01, -.18025700E-01, 0.24129600E-02, -.11414900E+00, -.28622100E-01, -.25354400E+00, 0.82233500E+00, 0.81661000E-01, 0.51226300E-01, -.43032800E+00, -.80267700E-01, -.32675300E-02, 0.13293500E+00, -.87160800E-01, 0.89350800E-02, -.13806200E+00, -.91854100E-02, 0.16691900E+00, -.87471400E-01, -.11525700E+00, -.11254800E-02, -.44665900E+00, 0.16327400E-01, -.10369400E+01, 0.19151200E-02, 0.17905200E-01, 0.74817500E-01, -.69558800E-01, 0.14058500E-01, 0.22761600E+00, 0.10596700E+00, -.17886600E+00, 0.14806300E+01, -.97742900E+00, 0.28195800E+00, 0.53492600E-02, 0.53374400E-01, -.17368500E-01, -.14094200E+00, 0.96936200E-01, -.21731400E+01, 0.26647200E+00, 0.10796900E+00, 0.30425100E+00, 0.49452200E+00, -.14991200E+00, -.13923100E-01, 0.54028900E+00, 0.11438700E+00, 0.29761600E-01, -.10708700E+00, -.17870700E+00, -.79897200E-01, -.33628500E+00, 0.11422900E+00, 0.80011000E-01, 0.78171100E-01, -.55024400E-01, 0.39899200E-01, -.42466600E-01, 0.20559600E+00, -.59915200E-02, 0.42348800E+00, 0.40295200E-01, -.27441900E-01, 0.10018000E+01, -.14910800E-02, 0.44017400E-02, -.49939500E-02, -.22368000E+00, 0.18996000E-01, 0.56613900E-01, -.20755000E+01, -.45412300E-02, 0.46927400E+00, -.10853600E+00, -.19282600E-01, 0.11011000E-01, -.17499000E-01, 0.43061300E-02, 0.21241900E+00, 0.89540900E-01, 0.52228200E-01, -.44654200E-01, 0.61160300E+00, 0.87757000E+00, 0.26616300E+00, -.81670500E-01, 0.11057800E+00, 0.13594800E+01, -.52559800E+00, -.93683000E-01, -.15953300E-01, 0.23833100E+00, 0.51140000E-01, 0.20766600E-01, -.29584200E+00, 0.83260000E-01, -.23349800E+00, 0.22043600E-01, -.27405700E-01, -.20166600E-01, 0.64592100E+00, 0.99208200E-01, 0.34162100E+02, 0.69342100E+02, 0.33514400E+02, -.40159300E+01, 0.12168200E+03, 0.28739300E+03, -.12929700E+03, -.14646500E+03, -.14349600E+03, -.11339600E+02, 0.66458500E+01, -.67457000E+02, 0.10291100E+03, 0.15128500E+02, -.10015100E+02, -.67582400E+02, 0.10363600E+03, -.50695000E+02, -.10016300E+03, -.51924200E+02, -.63879400E+02, -.76449100E+00, -.22204700E+02, -.20010900E+02, -.21598100E+02, -.21678200E+02, -.94020400E+01, 0.10192300E+02, -.94929200E+01, 0.83148800E+02, -.48888500E+01, 0.83275700E+02, -.13763900E+02, 0.21851600E+02, 0.35784000E+02, 0.14826100E+02, -.14669000E+02, 0.30662900E+02, -.10688200E+03, 0.43534800E+02, 0.99468100E+02, 0.53518300E+02, 0.15062100E+02, -.47641200E+02, 0.59952700E+02, 0.36097100E+02, 0.11429100E+03, -.43383200E+02, 0.16470400E+02, -.87120200E+02, 0.43309200E+02, 0.74720800E+02, 0.43598200E+02, -.33898800E+01, 0.17685000E+01, 0.23445600E+02, -.20879400E+02, 0.87883900E+01, -.57607300E+01, 0.68137000E+02, -.15054000E+03, 0.74592900E+02, 0.86009000E+02, 0.75473200E+02, 0.26530400E+02, -.34298700E+02, 0.60341100E+02, 0.22303000E+02, 0.10972000E+03, -.28238100E+02, 0.70193500E+01, -.47482400E+03, 0.24050200E+03, 0.20940200E+03, 0.23718200E+03, 0.81522200E+02, 0.69526200E+02, 0.55242500E+02, -.14210900E+03, 0.61704900E+02, 0.56243100E+02, 0.53460800E+02, -.51404400E+02, 0.27470500E+02, 0.17374100E+02, 0.25784000E+02, 0.27404900E+02, -.12927100E+02, 0.58647400E+02, 0.31373700E+02, -.14937200E+02, -.36140600E+01, 0.87273600E+01, -.32578300E+03, 0.15129500E+03, 0.22409300E+03, 0.16291500E+03, 0.37744100E+02, 0.44064500E+02, 0.22783100E+02, -.13309900E+03, 0.55659500E+02, 0.48106700E+02, 0.74147000E+02, -.11164800E+03, 0.50937200E+02, 0.18495200E+03, 0.56156400E+02, 0.10476100E+03, 0.22291900E+02, 0.20677900E+02, 0.13124300E+02, 0.50583800E+02, 0.26870700E+02, 0.13561800E+03, -.70299800E+02, 0.30919500E+02, -.32852200E+02, 0.34975700E+02, -.38656800E+02, -.97694500E+02, 0.11203700E+03, 0.85864400E+02, 0.83150400E+02, -.82625100E+02, -.32684200E+02, -.31638500E-01, 0.36831100E+01, -.55624600E+01, -.49500200E+00, 0.24474900E+01, -.24406600E+01, 0.26824100E+01, 0.27495800E+00, 0.50921000E+01, 0.15622100E+02, -.12115900E+02, 0.12556500E+02, -.30922800E+01, -.17425800E+01, -.25713000E+02, 0.17404000E+02, 0.61411900E+01, -.98504600E+01, -.12368000E+02, 0.26862600E+01, 0.58166200E+01, -.92629100E+01, 0.14428800E+02, 0.24321500E+02, 0.21205400E+02, 0.20640400E+02 },
        { 0.21354000E+02, -.30846800E+00, -.71310700E+00, 0.52709100E+00, 0.20995000E+01, -.12542900E+01, -.16753300E+01, -.18303600E+00, 0.18686700E+01, -.10210300E+01, -.47888200E-01, 0.21640100E+01, -.35601600E-01, 0.33582800E-01, 0.15351500E+00, -.94950100E-01, 0.17570000E+01, 0.18721600E+00, 0.22447800E+01, -.15944700E+01, -.18093300E+00, 0.13611800E+00, -.59493800E+01, -.12701300E+01, -.28111800E+00, -.25956600E+00, 0.12665300E+00, -.16892000E+01, -.22644700E+01, 0.63066200E+00, -.25660300E+00, -.24967700E+01, 0.21443500E-01, -.13337700E+00, 0.64060600E+01, -.72386000E-01, 0.34801200E+00, 0.46015900E+01, -.25671400E+00, 0.11156500E+01, -.10958500E+01, 0.16850200E+01, -.35214600E+00, 0.25768200E+00, -.34629500E+00, 0.28508900E+00, -.45751300E+00, -.50701000E-01, 0.11943500E+01, -.17940300E+00, 0.43025700E+00, -.23942300E+01, 0.14937400E+00, -.70020700E+00, -.61976700E+01, 0.15780200E+01, -.15698800E-01, 0.46527800E+00, -.44970700E+00, -.13774400E-01, 0.45890200E+00, 0.48620300E+00, -.16730000E+00, -.20859000E+00, -.12998500E+01, -.10477600E+00, 0.32150500E+00, -.16105000E-01, -.14481000E+01, 0.75056100E-03, 0.17304400E+00, 0.93163000E-01, 0.67311700E-01, 0.32210200E-01, -.15578800E+01, 0.28969900E+00, 0.97880400E+00, 0.67236900E+01, 0.10732600E+01, -.64647300E+00, 0.17687700E+00, -.76642300E+00, 0.39135400E+00, 0.14200600E+01, -.62479500E+00, -.85317700E+01, -.74144600E+00, 0.16575000E+00, 0.14984200E+01, -.93026900E+00, 0.43583300E+00, -.15847500E+00, 0.28031300E+01, -.10351500E-01, 0.27403800E+00, 0.70356200E+00, 0.47447700E+00, -.46487300E+00, -.10753600E+01, 0.93406100E+00, -.39847100E+00, -.11813500E+01, -.21246300E+00, 0.12330300E+01, -.89897000E-01, 0.17167200E+01, 0.82981400E-01, -.42400300E+01, -.10090000E+00, 0.26743600E+00, 0.33241700E+01, -.33471700E+00, -.46935100E+00, -.10173200E-01, -.15339300E+01, -.17729500E+01, -.11823600E+00, 0.55814200E+01, -.10129700E+00, 0.36969300E+01, -.39894900E-01, -.89147200E-02, 0.30019300E-01, -.13833600E+01, -.19632800E-01, -.51560200E+00, 0.24523900E+00, 0.12146400E+01, -.17200500E+00, -.58310500E+01, -.49426700E+01, 0.11730000E+01, 0.89750400E+00, 0.19374000E+00, -.63212300E+01, 0.80076400E+00, 0.56461200E+00, 0.14385300E+00, 0.19583400E+01, 0.20183600E+01, -.17104400E+01, -.43108100E+00, -.11996600E-01, -.18543500E+01, 0.77481200E-01, 0.72479100E+00, 0.44783600E-02, -.19592800E+01, -.83501800E+00, 0.61216200E+01, -.48602300E+03, -.23566700E+03, 0.41491500E+02, -.94529100E+03, -.68457300E+03, 0.37616600E+03, 0.24654700E+03, 0.34091900E+03, -.32459400E+02, -.18750300E+03, 0.36107000E+03, -.10017500E+03, -.24718200E+02, -.14960700E+03, 0.21916400E+03, -.11969300E+04, 0.55440500E+03, 0.57495200E+03, 0.59917700E+03, 0.24748100E+03, 0.93843400E+01, 0.15091800E+03, 0.72391700E+02, 0.70138800E+02, 0.14496400E+03, 0.68881300E+03, -.15820000E+03, 0.97472700E+02, -.24840200E+03, 0.77720000E+02, -.16235100E+03, 0.68231100E+02, -.13396400E+03, -.14534100E+03, -.11311800E+03, 0.83592500E+02, 0.24645000E+02, -.10284800E+04, 0.75870900E+03, 0.85120400E+02, 0.51373300E+03, 0.54981100E+02, 0.36258700E+03, 0.71009600E+02, -.45725100E+03, -.12236500E+03, 0.20807000E+03, 0.23295800E+03, 0.48223300E+03, -.16642200E+03, -.48383900E+03, -.24133900E+03, 0.24318800E+02, -.65535000E+02, -.35689600E+02, 0.31303700E+03, -.20753600E+02, 0.22982900E+02, -.24905600E+03, -.38064900E+03, 0.28537600E+03, 0.79783400E+02, 0.18898700E+03, 0.74959800E+01, 0.33829200E+03, -.81212800E+02, -.43771900E+03, -.28105500E+03, 0.20323200E+03, -.81793000E+02, 0.12516800E+04, -.68694700E+03, -.64500800E+03, -.62431100E+03, -.29376300E+03, -.15789700E+03, -.27266400E+03, 0.48071600E+03, -.88216300E+02, -.11695600E+03, 0.73609600E+03, -.86620400E+03, 0.40407100E+03, 0.55426500E+03, 0.43255900E+03, -.40730800E+02, 0.18538500E+03, -.75845700E+02, -.35834300E+03, 0.37392400E+03, 0.13024400E+03, 0.54753200E+03, 0.10600000E+04, -.54810500E+03, -.96874300E+03, -.53021100E+03, -.65874300E+02, 0.68702600E+01, -.26886500E+03, 0.98213700E+02, -.36049700E+03, -.99580400E+01, -.40274900E+03, 0.57039900E+03, -.23698600E+03, -.80450800E+03, -.28735200E+03, -.29576900E+03, -.13486000E+03, -.15179900E+03, -.38985100E+01, -.17178800E+03, -.15655200E+03, -.56950300E+03, 0.49262000E+03, -.25346300E+03, 0.16554300E+03, -.24536000E+03, -.17246200E+01, 0.10838500E+03, -.27453800E+03, -.57237200E+02, -.10219500E+03, 0.50446800E+02, -.45014900E+02, 0.27302500E+01, -.14997800E+02, 0.30377900E+02, 0.12021200E+02, -.52555600E+01, 0.52581300E+01, -.51235400E+02, -.19240200E+01, -.23169600E+02, -.53973600E+02, 0.45669400E+02, -.63158500E+02, 0.25930000E+02, 0.21757100E+01, 0.19754200E+03, -.45681400E+02, -.83723000E+02, 0.18043500E+02, 0.17944700E+03, -.22665300E+03, -.45322800E+02, 0.72743900E+02, -.80467900E+02, -.21668400E+02, -.38480100E+02, -.73395500E+02 },
        { 0.33893000E+01, -.10108800E+00, -.11702800E+00, -.12945000E+00, 0.52301300E+00, -.11450100E+01, 0.44939100E+00, -.60092600E+00, 0.83606800E+00, -.84522900E+00, -.14754100E-01, 0.28909800E+00, 0.36145800E-01, 0.33944300E-01, 0.14483300E+00, -.12287200E+00, -.57319600E-01, -.66957200E-01, 0.31728200E+00, -.58415000E+00, -.80940100E+00, 0.16338300E+00, 0.27552900E+01, 0.12611800E+00, 0.10721300E+00, -.18245000E-02, 0.15200300E+00, 0.43942300E-01, -.10574000E+01, -.25326800E+00, -.31738700E+00, -.17951300E+01, 0.67316100E-01, -.29751100E+00, 0.25547500E+01, 0.31882300E+00, 0.88485600E-01, 0.25850400E+01, -.22792500E+00, 0.34569500E+00, -.22423000E+00, -.58297300E+00, -.53331200E+00, 0.12390800E+01, -.99346900E-01, 0.16478800E+00, -.74593100E-01, -.22119400E-01, 0.12520300E-01, -.11269600E+00, 0.78863100E+00, -.23770200E+00, -.17055200E+00, -.46414100E-01, 0.24271400E+01, -.23709900E+00, -.18763000E-01, -.59707600E+00, -.51410500E+00, 0.95923700E-01, 0.32080100E+00, 0.97329600E-01, 0.38014100E+00, -.31199800E+00, -.61871200E+00, 0.10231900E+00, -.54014300E+00, -.10103300E-01, -.72848700E+00, -.66810000E-03, -.17770400E-01, 0.10668000E+00, 0.49703300E-01, -.21076800E+00, 0.99728100E-02, -.18521900E+00, -.45827500E-01, -.29142700E+01, 0.68917000E+00, -.56683200E+00, -.60853300E-01, 0.90971400E+00, -.60740900E+00, 0.75725700E-01, -.95395500E+00, -.10555100E+01, 0.46470900E-01, -.19843800E-01, 0.91442100E-01, -.19488400E+00, 0.33746600E+00, -.52737700E-01, -.14015900E+01, 0.10295700E+00, 0.30773100E+00, -.12869300E+00, -.37556700E-03, 0.35287700E+00, -.55506500E+00, 0.10094900E+00, 0.93675800E-01, 0.45079500E+00, -.33231200E+00, -.62245100E-01, 0.48771800E-01, -.20429000E+00, 0.39549300E-01, 0.22597500E+01, 0.71557700E-02, -.29736300E-01, -.90148100E+00, 0.48446600E-01, -.12457700E+00, -.11678400E-03, 0.47294900E+00, 0.12016900E-01, 0.71483200E-01, -.23813800E+01, 0.36968800E+00, 0.26697800E+00, 0.30487100E-01, 0.58019300E-01, 0.11989100E-01, 0.38654800E+00, 0.15806800E-01, 0.14771200E+00, -.93109000E-01, -.32019100E+00, 0.20714700E+00, 0.60731100E+00, 0.47830800E+01, -.45550100E+00, -.52988900E+00, -.37107000E-01, 0.40650300E+00, 0.43340200E+00, -.14824300E-01, -.10517800E+00, 0.75795100E+00, -.44467800E+00, -.63808800E+00, 0.36474600E+00, -.43349600E-01, -.62263400E+00, -.31520600E-01, 0.15942700E+00, -.38581300E-01, 0.60125500E+00, 0.61856100E-01, -.24855200E+00, -.33383600E+00, 0.12906300E+03, 0.38192100E+02, -.33793300E+03, -.36901600E+03, 0.18443600E+03, 0.24271200E+03, 0.18428400E+03, 0.93372000E+01, 0.25215000E+02, 0.10998200E+03, -.48783600E+02, -.34229100E+02, 0.42021600E+02, 0.11037300E+03, -.24163000E+02, 0.23534400E+01, 0.83391700E+02, 0.12107800E+02, 0.17700300E+03, 0.15298900E+03, -.59549600E+02, -.12212500E+03, -.18723100E+03, 0.12798600E+03, 0.64798100E+02, 0.93904300E+02, -.37037300E+02, -.42002500E+02, -.47000600E+02, -.68137700E+02, -.29327400E+02, -.13852200E+03, -.11646500E+03, -.33008300E+02, 0.52112700E+01, -.64633700E+02, 0.12299600E+03, -.18874500E+01, -.16532400E+03, -.61513300E+02, -.14727300E+03, -.63206500E+01, -.10855200E+03, -.71880100E+02, -.31675800E+02, 0.13388600E+02, -.10238300E+02, 0.98002100E+02, -.33528000E+02, -.17884200E+03, -.49006700E+02, -.62717700E+01, -.15714100E+02, -.51175300E+02, 0.58459900E+01, -.92548100E+01, -.39896300E+01, -.35586800E+02, 0.17013700E+03, -.65578900E+02, -.13352200E+03, -.85119000E+02, -.12080700E+03, -.29342700E+02, -.70459800E+02, -.28660800E+02, -.41183000E+02, -.14230900E+02, -.10370400E+02, -.93052300E+03, 0.45089400E+03, 0.47277700E+03, 0.46531500E+03, 0.57545600E+02, 0.16373600E+03, 0.11136200E+03, -.31037000E+03, 0.33581600E+02, 0.10007200E+03, 0.73289800E+03, -.74770900E+03, 0.36680400E+03, 0.25967100E+03, 0.37383600E+03, 0.42816300E+02, 0.11923500E+03, 0.76410500E+02, -.19010300E+03, 0.22719100E+03, 0.10496900E+03, 0.29427400E+03, 0.59926200E+03, -.29760200E+03, -.14092400E+03, -.29969200E+03, -.43914100E+02, -.52336500E+02, -.94186700E+02, 0.99121300E+02, -.15728200E+03, -.51077200E+02, -.27689800E+03, 0.55137700E+03, -.26179500E+03, 0.11578300E+02, -.27578800E+03, -.20669400E+03, -.17770800E+03, -.25164000E+02, 0.14534900E+03, -.10101200E+03, -.14733200E+03, -.35269500E+03, 0.17138100E+03, -.82847700E+02, -.96585600E+02, -.85652700E+02, 0.73117900E+01, 0.35638000E+02, -.12240600E+03, -.77986400E+02, -.57954200E+02, 0.17550900E+02, 0.63219300E+02, 0.29810500E+01, -.82356100E+01, 0.94266600E+01, 0.39629500E+01, 0.17951300E+00, -.32116000E+01, -.12590600E+02, 0.17399300E+01, -.94766900E+01, 0.39159300E+01, -.12508200E+02, -.22216500E+01, 0.19122300E+01, 0.30904200E+01, 0.22115200E+01, 0.38812800E+00, -.13841300E+01, -.19343200E+01, -.41343200E+02, 0.24518900E+02, 0.10408200E+02, -.83530800E+01, -.13283100E+02, 0.42756900E+01, -.17976900E+02, -.79060200E+00 },
        { -.19098900E+01, -.28566500E-01, 0.66708500E-01, -.64071900E+00, -.17877200E+00, -.97179700E+00, 0.33539800E+00, -.16352000E+00, 0.15589300E+00, -.97740900E+00, 0.10222200E+00, 0.51093900E+00, 0.52375800E-01, 0.83541700E-01, 0.63369600E-01, 0.28413100E-01, 0.76890600E+00, 0.36253500E+00, 0.11451700E+00, -.15284500E+00, 0.60150300E-01, -.88662800E-01, 0.33501000E+01, 0.20466100E+00, 0.22249400E-01, -.51548100E-01, 0.69915800E-01, -.23941500E-01, -.10061300E+00, 0.11638400E+00, -.10959000E+00, -.84914000E+00, -.29452200E-01, 0.27840300E+00, -.66388800E+00, -.29866100E+00, -.70837000E-01, 0.61287600E+00, -.27061700E+00, 0.64562100E-01, 0.16311100E+00, 0.44532600E+00, -.32197600E+00, 0.15073800E+00, 0.10517800E+00, 0.23664200E-01, 0.15690300E-02, 0.86236900E-02, -.13531900E+00, 0.56131300E-01, -.24815600E+00, 0.33109900E+00, -.62649600E-01, -.36299700E+00, -.44302800E+00, 0.29562700E+00, -.87709300E-02, -.23427000E+00, 0.25672500E+00, -.70231700E-01, 0.12413500E+00, 0.29271300E+00, -.17345400E+00, 0.12876800E+00, -.29608000E-01, -.44510500E-01, 0.61137100E+00, 0.10513300E-01, -.17379200E+00, 0.80500500E-03, 0.63508100E-01, 0.14265600E+00, 0.11635100E+00, 0.47069600E-01, 0.80891600E-01, 0.29006100E+00, 0.89949600E-01, -.66898200E+00, 0.36969200E+00, 0.42412900E+00, 0.19364800E-01, 0.13335100E-02, 0.32136000E+00, -.34642700E+00, 0.52199700E+00, 0.28240600E+01, 0.44170000E-01, 0.18680400E-01, -.41939800E+00, 0.29504400E+00, 0.15021900E+00, -.90211700E-03, 0.84169400E-01, 0.14599600E-01, -.85666800E-01, -.17859500E+00, 0.15920400E+00, 0.14251500E+00, 0.17918700E+00, 0.17020500E+00, 0.12247300E-01, -.17004300E+00, 0.31590700E-01, 0.10400200E+00, 0.27558200E-01, -.25759700E+00, -.47475900E-01, 0.72141300E-01, 0.88141900E-01, -.19551500E-01, 0.73667400E-01, -.32787700E-01, -.33649500E-01, -.89992700E-02, 0.10489500E+00, -.16131300E+00, 0.41503800E-01, -.23591700E+01, -.23152500E+00, 0.35910500E+00, 0.20188000E-01, -.25555100E-01, 0.93987500E-02, -.30928000E-01, -.23548900E-03, 0.93352300E-01, 0.63517900E-01, -.32367600E+00, -.42621400E-01, 0.28052900E-01, 0.11348800E+01, -.37372700E-01, 0.84085200E-01, -.37776600E-01, 0.66106300E+00, 0.24941000E+00, -.38572400E-01, -.10711500E+00, -.43622000E+00, 0.21442800E+00, 0.11369900E+00, 0.26817000E+00, 0.40420600E-02, 0.11713800E-01, 0.70932100E-04, 0.29283400E-01, -.15359500E-02, 0.28627300E+00, 0.30038200E-01, -.12206000E+00, -.30643600E-01, -.34342200E+00, 0.25289600E+02, -.92644700E+02, -.93885600E+02, 0.40270100E+02, 0.66245900E+02, 0.46833400E+02, 0.24496600E+02, 0.38947500E+02, 0.74612900E+01, -.23745300E+02, 0.16759300E+02, 0.47268100E+02, 0.11418500E+02, -.42822600E+02, 0.18495800E+02, -.41250600E+01, 0.21423400E+02, 0.53502800E+02, 0.56921500E+02, -.15917200E+02, -.29239900E+02, -.37345400E+02, 0.41304600E+02, 0.10831100E+03, 0.24855200E+02, -.76608700E+01, -.10639400E+02, -.12450400E+02, 0.15957700E+02, -.15307900E+02, -.35940400E+02, -.13263300E+02, -.26755400E+02, -.87746000E+01, -.22248100E+02, -.80444000E+02, 0.60668500E+02, -.50752000E+02, 0.40213800E+02, -.80551500E+02, -.37566000E+02, -.79366900E+01, -.59007700E+02, 0.31444000E+02, -.35998400E+02, 0.99640500E+02, 0.10697000E+02, -.13937200E+01, -.80207900E+02, -.53546700E+01, -.69512500E+01, -.31585700E+02, -.31547800E+01, -.98561700E+01, -.65647000E+01, -.25867300E+02, 0.11834600E+02, -.39528800E+02, 0.25407100E+02, -.12835000E+02, 0.19738200E+02, -.51502400E+02, -.61673600E+01, -.11501400E+02, -.54549400E+02, -.25825500E+01, -.11281400E+02, 0.33761900E+02, -.23238400E+03, 0.11136400E+03, 0.12481900E+03, 0.11621700E+03, 0.37356500E+02, 0.26854300E+02, 0.54172800E+02, -.60329400E+02, 0.59423700E+02, -.98232500E+01, 0.15046100E+03, -.21796100E+03, 0.10710200E+03, 0.48687500E+02, 0.10897200E+03, 0.10729400E+02, 0.18835300E+02, 0.36144200E+02, -.33391400E+02, 0.84401300E+02, 0.14652300E+02, 0.63141200E+02, 0.27928800E+02, -.76152300E+01, 0.70361600E+02, -.13988000E+02, -.12586300E+02, -.42437300E+02, 0.37338000E+02, 0.69381600E+02, 0.17819800E+02, -.45433400E+02, -.22899000E+02, 0.21757500E+03, -.10282100E+03, 0.13125200E+03, -.10884500E+03, -.37446000E+02, -.59688200E+02, -.27239300E+02, 0.55765300E+02, -.82957500E+02, -.47207200E+02, -.98473700E+02, 0.16478600E+03, -.79199400E+02, -.73874300E+02, -.82359100E+02, -.10090800E+02, 0.16151300E+02, -.76168300E+02, -.38957100E+02, -.92151000E+02, 0.72883200E+01, -.26944600E+02, 0.11099800E+01, -.90830200E+00, 0.16243200E+01, 0.17976300E+01, 0.59564400E-01, -.26280100E+01, -.10519700E+02, 0.69051300E+00, -.10136400E+01, 0.10781300E+02, -.15036800E+02, -.44379100E+01, 0.27416200E+01, 0.67734200E-01, -.42991300E+00, 0.12444200E+02, -.38076600E+00, -.35991900E+01, -.13602500E+02, -.23869800E+02, 0.23855100E+01, 0.30295000E+01, -.63392600E+01, 0.15026900E+01, 0.11986600E+02, 0.12744000E+02 },
        { 0.96595500E+01, -.29629800E+00, -.29894400E+00, -.43897000E+00, 0.10882600E+01, -.28174900E+01, 0.35560700E+00, -.15203100E+01, 0.39597200E+01, -.27861700E+01, -.53505900E+00, 0.12551400E+01, 0.11539800E+00, 0.11722600E+00, 0.97081700E-01, 0.59943500E-01, 0.14612400E+00, 0.18093900E+00, 0.54761600E+00, -.10883300E+01, -.21287800E+01, 0.15412900E+01, 0.16428500E+00, -.14719600E+01, -.10390200E+00, -.22615900E+00, 0.73664200E+00, -.13448000E+01, -.41987000E+01, 0.13175100E+01, -.43163100E+00, 0.27617000E+01, 0.54684200E+00, -.66463500E+00, 0.52483400E+01, 0.27696700E+00, -.26689600E-02, 0.54788400E+01, -.62565200E+00, 0.17244700E+01, -.46331100E+00, -.37489900E+00, 0.40952300E+00, 0.19450300E+01, 0.45115000E+00, 0.92185900E-01, -.22440100E-01, -.22361900E-01, 0.29305700E+00, -.32333000E+00, 0.21739000E+01, 0.19056300E+01, -.21195400E-01, -.58731500E+00, 0.34839900E+00, 0.15506200E+01, 0.19441600E-01, 0.10840100E+01, -.33349200E+00, 0.10255600E+00, 0.71023300E+00, 0.40029100E+00, 0.99079700E+00, 0.16044700E+00, -.20174800E+00, -.15114600E+01, 0.21782600E+01, -.10953400E-01, 0.96689900E+00, -.97263000E-03, -.99911800E-01, 0.45660600E+00, 0.21980100E+00, -.23955300E+00, 0.10301800E+01, -.90940600E+00, 0.10359500E+01, -.38553500E+01, -.66136600E-01, -.77058100E+00, -.37949400E-01, 0.25060700E+01, -.16038400E+01, 0.11443900E+01, -.90849800E+00, -.20682500E+02, -.36184200E+00, -.17722700E+00, 0.11600300E+01, -.22178400E+01, 0.28214400E+00, -.15452300E-01, 0.18766300E+01, -.12224100E+00, 0.77649200E+00, 0.12808100E+01, -.14297200E+01, -.16781600E+01, -.51110900E+00, -.69047900E+00, 0.14810300E+00, 0.13928700E+01, -.21923200E+00, -.92859500E+00, -.29772300E+00, 0.18897200E+01, -.14652800E+00, -.56278900E+00, -.60066000E-01, -.66303500E-01, -.30657800E+01, -.21301800E+00, -.11050800E+01, -.64046700E-03, -.51062900E+00, 0.88353400E+00, -.49610400E+00, -.23782100E+01, -.29862400E-01, -.22749200E+01, 0.79840600E+00, 0.22136800E+00, 0.11531000E-01, 0.61013000E+00, -.18649700E-01, 0.25748500E+00, -.16902400E+00, -.15783800E+01, 0.57261000E+00, 0.48154300E+00, -.96671600E+00, -.20745100E+00, 0.56230900E+00, 0.14993000E-01, 0.10219100E+00, -.39724500E+00, 0.31982700E+00, 0.13528700E+00, -.18123300E+01, 0.17862400E+01, -.18864600E+00, 0.44675900E+00, 0.15464700E+00, -.12435200E+01, 0.15736700E-01, 0.61414100E+00, 0.63932100E-01, -.10795300E+01, -.16629400E-01, -.28421500E+01, -.51895600E+00, 0.15379600E+01, -.25794900E+01, 0.81462400E+03, -.67606900E+02, -.49816200E+01, -.54706500E+02, 0.33540400E+02, 0.82381400E+02, 0.12355400E+03, -.17267300E+03, -.34858500E+03, 0.11245600E+03, 0.13300600E+03, -.35608100E+02, -.47273700E+03, 0.22966000E+03, -.11996100E+03, 0.23674400E+03, -.65513100E+02, 0.76142400E+02, 0.76739400E+02, 0.29305300E+02, 0.18681900E+03, 0.12289500E+03, 0.36999300E+03, 0.99731100E+02, -.51193400E+02, 0.19535000E+03, -.50609000E+02, 0.26617900E+03, -.15583200E+03, -.16428500E+02, 0.79780300E+02, -.16334400E+03, -.90163700E+02, -.14940800E+03, -.20522700E+03, 0.14332200E+03, -.16476300E+03, 0.10232400E+03, -.11937700E+03, -.23231100E+03, 0.85613300E+02, 0.47752100E+02, 0.72887500E+02, -.21092100E+03, 0.25183000E+03, -.21655500E+03, 0.10287100E+03, -.13152200E+03, 0.10811100E+03, -.24544200E+02, -.12083900E+03, 0.13047000E+03, -.49912800E+02, 0.75880000E+01, -.97670000E+02, 0.13913500E+03, -.11167600E+03, 0.68834500E+02, -.75158100E+02, 0.55102300E+02, -.52085300E+02, -.83215100E+02, 0.49197200E+02, 0.33621100E+02, -.40133900E+02, -.10369900E+03, 0.26051800E+02, -.16434600E+03, 0.75456000E+02, 0.14472400E+03, 0.82999400E+02, 0.66376900E+02, 0.81084400E+02, 0.74257900E+02, -.12192700E+03, 0.16010600E+02, 0.27450000E+02, -.18002700E+03, -.25875700E+03, 0.13058000E+03, -.50854200E+02, 0.12908500E+03, 0.36865300E+02, 0.40496000E+02, 0.26490500E+02, -.80693800E+01, 0.17023900E+03, 0.22435000E+02, 0.22364200E+03, 0.84900100E+02, -.79639000E+01, 0.50473200E+03, -.42351400E+02, -.29140700E+02, -.85680300E+02, 0.21962800E+03, 0.49387900E+03, 0.15255600E+03, -.11055700E+03, 0.16319800E+03, 0.33457800E+03, -.15764200E+03, 0.12820000E+04, -.16849500E+03, 0.24631600E+03, -.20068400E+02, -.14267600E+03, 0.67300200E+02, -.39094500E+03, 0.21473200E+02, 0.40583400E+02, 0.38846300E+03, -.18600200E+03, -.28780600E+03, -.19352600E+03, -.12068500E+03, -.11071900E+03, 0.89221000E+01, 0.16798300E+03, -.20459500E+03, -.11475600E+03, -.43737400E+03, 0.65141400E+01, -.13606000E+01, -.24850300E+02, 0.10433500E+02, 0.89880500E+01, -.11314500E+02, -.40059200E+02, -.92628800E+00, 0.29639600E+02, 0.40141200E+02, -.46834300E+02, -.24988400E+02, 0.41250900E+01, -.18362800E+02, 0.15567900E+02, 0.53444000E+02, 0.26724400E+00, -.60584800E+02, -.34508900E+02, -.20419200E+03, 0.43893900E+01, 0.26207700E+02, -.33228500E+02, -.36128600E+02, 0.12467400E+03, 0.76695400E+02 },
        { 0.98215200E+01, -.23964400E+00, -.33434400E+00, -.10001900E+01, 0.14181500E+01, -.32128600E+01, 0.58383800E+00, -.25652000E+01, 0.54077200E+01, -.24826700E+01, -.44957500E+00, 0.25663500E+01, 0.78952900E+00, 0.35732600E-01, 0.76067500E+00, -.23905300E+00, 0.14121000E+00, 0.47603900E+00, 0.13431800E+01, -.13120900E+01, -.28203400E+01, 0.98317900E+00, 0.67679400E+01, -.45420600E+00, 0.39136300E+00, -.59783500E+00, 0.66109500E+00, -.17042700E+01, -.30312800E+01, 0.32594400E+00, -.67997700E+00, 0.44090500E+01, 0.62286700E+00, -.50444700E+00, 0.45709500E+01, 0.15812900E+00, 0.91437400E-01, 0.87904100E+00, 0.35649300E+00, 0.18908900E+01, -.77194100E+00, -.16886700E+01, 0.72732000E+00, 0.11650300E+01, -.66680700E+00, 0.24691600E+00, 0.24230800E+00, -.10805400E-01, 0.12147100E+01, -.13398500E-01, 0.49373300E+00, -.53426700E+01, -.23171800E+00, -.65980600E+00, 0.18937500E+01, 0.71082000E+00, -.11820500E+00, -.10275300E+01, 0.30205900E+00, 0.13081100E+00, 0.13779300E+01, -.32483600E+00, -.92229100E+00, 0.19497800E+00, -.15909000E+00, 0.60921000E-01, 0.82546000E+00, -.29162600E-01, 0.96249200E+00, -.50493400E-02, -.11028500E+00, 0.96266100E+00, 0.63762900E+00, -.25027200E+00, 0.75677700E+00, 0.11733800E+01, 0.25474200E+01, 0.27355800E+01, 0.14182600E+01, 0.90270600E+00, 0.46113300E-01, 0.32116700E+01, -.17086500E+01, -.16396900E+00, 0.12530300E+01, -.22327700E+02, -.15618200E+01, 0.85858700E-01, -.11951000E+01, -.32291400E+01, 0.10950200E+01, -.14757600E+00, 0.12278200E-01, -.18450200E-01, -.43474100E+00, 0.21879400E+01, 0.36177700E+00, -.50909200E+00, 0.24942100E+01, 0.30659300E+00, -.23854200E+00, -.72689600E+00, 0.15350200E-01, 0.67871600E+00, 0.33635800E+00, 0.14258500E+01, -.18470100E+00, -.46902000E+01, 0.11314500E+01, -.50565400E+00, 0.94192600E-01, -.46333000E+00, 0.10362600E+00, -.20042200E-01, -.12682000E+01, 0.15788500E+01, -.23495200E+00, -.72613100E+01, -.40014300E+00, 0.29773800E+01, 0.27771200E+00, 0.11404200E-01, -.14432300E-01, 0.11838500E+01, 0.25224000E-02, 0.34019800E+00, 0.54202600E+00, -.15543000E+01, 0.47003300E+00, 0.38247400E+01, -.41652200E+01, 0.12549800E+01, 0.61853500E+00, -.14862600E+00, -.70853600E+01, 0.20245400E+01, -.25763200E+00, -.47682900E+00, -.49200200E+01, 0.11914500E+01, -.43892200E+00, -.87610500E+00, -.76984500E-01, 0.40524600E-01, 0.15581600E-01, 0.82713000E-01, -.13486300E-02, 0.10448100E+01, 0.31971600E+00, -.22922100E+01, -.38473400E-01, 0.74418500E+00, 0.14740600E+01, 0.37552500E+00, 0.11126800E+04, -.51143200E+03, -.64891800E+03, -.55496200E+03, 0.33230300E+02, 0.13107700E+03, -.37409100E+03, 0.23863600E+03, -.16528400E+03, 0.77946200E+02, -.11382200E+03, 0.67576900E+03, -.31053500E+03, -.20615100E+03, -.33831000E+03, -.43100000E+03, -.33188200E+03, 0.11867400E+03, 0.23902800E+03, 0.14288500E+03, -.35019800E+03, -.99198600E+03, 0.42553500E+02, -.49296500E+02, 0.36582100E+03, -.20456800E+02, 0.26648500E+03, 0.79171300E+02, 0.17092500E+03, 0.17848600E+03, 0.14067100E+03, -.19283000E+02, 0.18130200E+03, -.32396000E+03, 0.14637600E+02, 0.66548300E+03, 0.16227300E+03, 0.31893500E+03, -.82550500E+02, 0.31928000E+03, 0.35601700E+03, 0.33004900E+03, -.18349300E+03, 0.19958300E+03, -.17654700E+03, 0.56992300E+02, 0.38852700E+03, 0.88400000E+02, -.21579600E+01, 0.82252600E+01, 0.16676900E+03, 0.27273700E+02, 0.88357600E+02, -.48991900E+02, -.63856100E+02, -.45874500E+03, 0.18443000E+03, 0.44114000E+03, 0.23018000E+03, 0.38035500E+03, -.10804300E+03, 0.30537900E+03, 0.37105500E+03, 0.40354400E+03, -.19000700E+03, 0.40988100E+03, -.19228400E+02, 0.48763700E+02, -.14760900E+03, 0.87076500E+01, 0.50005800E+02, 0.82698600E+02, -.16340000E+03, 0.10369500E+03, -.44372800E+02, 0.69369900E+02, 0.38940400E+03, 0.11006500E+04, -.53191700E+03, -.14724800E+03, -.55000800E+03, -.15600600E+03, -.16134100E+03, -.12842900E+03, 0.15160800E+03, -.48347900E+03, -.13056600E+03, -.27697300E+03, -.11269500E+04, 0.52223100E+03, 0.44564900E+03, 0.56377000E+03, 0.89509700E+02, 0.17226100E+03, 0.13071700E+02, -.50908400E+03, 0.20625800E+03, 0.16948400E+03, 0.42539200E+03, -.12939600E+04, 0.60327200E+03, -.10252100E+03, 0.64834100E+03, 0.51474900E+03, 0.34517400E+03, 0.92992900E+02, -.29339500E+03, 0.57670200E+03, 0.27586900E+03, 0.99214300E+03, -.68023200E+03, 0.32325200E+03, 0.14194800E+03, 0.33953100E+03, -.10990300E+03, -.35212100E+03, 0.55455100E+03, 0.33055900E+03, 0.54383600E+03, -.29776500E+03, -.66638600E+01, -.54328300E+01, 0.24456400E+02, -.36502000E+02, -.83875100E+01, 0.10656500E+02, -.61027500E+01, 0.15776600E+02, -.33681700E+01, 0.34200300E+02, -.27736900E+01, 0.55619400E+01, 0.35124900E+02, -.30789300E+02, -.11024300E+02, -.30226600E+02, 0.11236200E+02, 0.10979800E+02, -.26228300E+02, 0.63932300E+02, -.81465700E+02, -.35755800E+02, -.25234200E+02, 0.70776000E+01, 0.52446700E+02, 0.11568100E+02, -.60864500E+01 },
        { -.19199100E+02, 0.85519200E+00, 0.43113700E+00, -.15547100E+01, -.14867000E+01, 0.34455800E+01, -.22475500E+01, 0.15051200E+01, -.13043900E+00, 0.24887600E+01, -.21961400E+00, -.39304400E+01, 0.18909000E+01, 0.12627900E+00, 0.13641500E+00, 0.86601600E+00, -.14807300E+01, -.24524800E+00, -.16114900E+01, 0.28036600E-01, -.10210700E+01, -.31249700E+00, 0.31485300E+01, 0.41496800E+00, -.29805000E+00, 0.10324000E+00, 0.66816900E+00, 0.17751800E+00, -.53264400E+00, 0.21006700E+00, 0.28421000E+00, 0.92412800E+00, 0.85095100E-02, -.42989800E+00, 0.36248800E+01, 0.30999900E+00, -.32128800E+00, 0.48975200E+01, -.71740200E+00, 0.14383400E+01, -.10619100E+00, -.23519200E+01, 0.24211900E+00, 0.27160300E+01, -.20376700E+00, -.64695100E+00, -.33212300E+00, 0.59449600E-01, -.58189800E+00, -.17979800E+00, 0.21718300E+01, 0.98022300E+01, 0.21635100E-01, 0.97441500E-02, 0.41627100E+01, 0.50878800E+00, 0.95696700E+00, -.37672700E+00, 0.12231800E+01, 0.23751900E-01, -.40750600E+00, -.21118700E+00, 0.48205300E+00, -.21473300E+00, -.75571300E+00, 0.32174400E+00, -.67906700E+00, -.51492200E-01, 0.21602500E+00, -.21861400E-02, -.34624400E+00, 0.26714400E+00, 0.27863500E+00, -.49591400E-02, -.18622600E+01, -.32937900E+00, 0.74271100E+00, -.10810400E+01, 0.10152700E+01, 0.86142300E+00, 0.32164400E-01, 0.18654100E+00, -.66296300E+00, -.57510400E+00, 0.12974200E+01, 0.35746000E+01, 0.34540200E+00, 0.95524400E-01, -.77815500E+00, 0.66892100E+00, 0.17548300E-01, -.39665600E-01, 0.47475400E+00, -.15996700E+00, -.41071400E-01, 0.74822700E+00, -.58252700E+00, -.91942400E+00, -.58495300E+00, -.12502500E+00, -.33099300E+00, -.23596300E-01, 0.10069700E+00, -.63099500E+00, 0.21158600E+00, 0.80845400E+00, -.37470600E-01, -.30909400E+01, 0.19157400E+00, -.66407400E-01, -.30844100E+01, 0.10416100E+00, -.57341700E+00, 0.12909600E-02, 0.86606400E-01, -.80191900E+00, 0.14041300E+00, -.37755700E+01, 0.14801900E-01, 0.15973900E+01, -.31556100E+00, -.16328500E+00, 0.40677700E-01, 0.33058000E+00, 0.19105900E-01, -.10364700E+01, 0.11947800E+00, -.23515000E+00, -.71780100E-01, -.11879500E+01, 0.48436800E+01, 0.36591900E+00, -.53088400E+00, 0.11953900E+00, 0.36097000E+01, 0.10129900E+00, -.61204600E-02, -.11809100E+00, 0.24897400E+00, 0.24019800E+00, 0.37740700E+00, 0.21144800E+00, -.79378100E-01, 0.19412700E+00, 0.48224900E-01, 0.55891500E-01, -.12693200E-01, 0.13698300E+01, 0.23266100E+00, -.18322400E+01, -.21323000E+00, -.19329700E+00, 0.14815700E+01, 0.21823200E+00, -.36616800E-01, 0.14206300E+03, -.35306800E+03, 0.11773200E+01, -.46319200E+02, -.56030700E+02, 0.67558100E+02, 0.12698500E+03, -.23125400E+02, -.90818200E+02, 0.17849100E+03, 0.53723400E+03, -.26531700E+03, -.12557900E+02, -.26886900E+03, -.98207700E+02, -.46405500E+02, -.57495100E+02, 0.20337300E+02, -.14459000E+03, -.65448800E+02, -.60718700E+03, -.75100700E+01, -.12338800E+02, 0.57212400E+02, 0.42334400E+01, -.51122800E+01, 0.39499400E+02, 0.49957800E+02, 0.39675500E+02, 0.50535900E+02, 0.33929400E+02, 0.20344800E+03, 0.39805200E+03, -.23228000E+03, 0.29914700E+02, -.19886100E+03, 0.94715900E+02, 0.82316300E+02, -.51567800E+02, 0.15011800E+03, 0.28877000E+00, 0.35441300E+02, 0.26537400E+02, -.78761600E+02, 0.56657500E+02, 0.21819600E+03, 0.39446200E+02, -.80791700E+01, 0.19569400E+02, 0.42351800E+02, 0.43628800E+02, 0.34375300E+02, 0.19264700E+02, 0.42075600E+02, 0.20648400E+03, -.10037400E+03, -.65252700E+02, -.10276400E+03, 0.73244100E+02, 0.48302700E+02, -.49760600E+02, 0.77137100E+02, 0.25102800E+02, 0.20782100E+02, 0.12341400E+03, -.29355000E+03, 0.15629200E+03, 0.31856000E+02, 0.14624700E+03, -.24442600E+02, 0.19814500E+02, 0.33483000E+01, -.85291800E+02, -.35831500E+02, 0.48002900E+02, 0.21009300E+02, 0.32801500E+03, -.15969300E+03, 0.15347100E+02, -.16382400E+03, -.37755600E+02, -.48237100E+02, -.55565200E+02, 0.66054100E+01, -.20172000E+03, -.24034800E+02, -.72908900E+02, -.10134200E+03, -.17033500E+02, 0.80392200E+02, 0.50959800E+02, 0.70723900E+02, 0.14901900E+03, -.19869200E+03, -.37949500E+03, -.11107100E+03, 0.16493300E+03, -.19189500E+03, -.22030800E+03, 0.93944200E+02, -.59234600E+03, 0.11100000E+03, 0.93598300E+02, -.74849300E+01, 0.13444200E+03, -.36005700E+01, 0.22020200E+03, 0.78782400E+01, 0.14479400E+03, -.38075700E+03, 0.17178100E+03, 0.18662900E+03, 0.19008600E+03, 0.14374800E+02, -.10248600E+03, 0.20960500E+03, 0.10027600E+03, 0.33183200E+03, -.79600000E+02, 0.18130800E+03, 0.22642100E+01, 0.30767700E+01, 0.96597700E+00, -.23798100E+01, 0.83258000E-02, 0.48991900E+01, 0.77463600E+01, 0.18980500E+01, -.48226000E+01, 0.55728700E+02, -.57904200E+02, -.81150500E-02, -.72754300E+01, 0.18398600E+01, -.17719800E+02, 0.53083500E+02, 0.82248100E+00, 0.56757900E+01, 0.19964800E+02, 0.18807500E+02, -.18823400E+02, -.12388900E+02, 0.47665900E+00, 0.14413800E+03, -.57691800E+01, 0.35882700E+02 },
        { -.15535500E+02, 0.41812000E+00, 0.88240200E+00, -.17403000E+01, -.79190800E+00, 0.26244400E+01, -.23426700E+01, 0.12552800E+01, 0.14324400E+01, 0.16053100E+01, -.24594900E+00, -.80847200E+00, 0.66728800E+00, -.66544400E+00, 0.17619100E+00, 0.41137400E+00, -.36476100E+00, 0.33273400E+00, -.97203500E-01, -.76618800E+00, -.18962600E+01, 0.36827000E+00, 0.13070200E+01, 0.69712400E+00, 0.99532600E+00, 0.30017800E+00, 0.51197500E+00, -.41459400E+00, -.20996000E+01, -.12860900E+01, -.17294500E+01, -.24152500E+01, 0.76414000E-01, -.13028300E+01, 0.10000800E+01, 0.10118400E+01, -.27210900E+00, 0.44020000E+01, 0.49799200E-01, 0.18663300E+01, -.17840900E+01, -.40932500E+01, -.89840000E+00, 0.24893300E+01, -.96402500E+00, 0.74541700E+00, 0.11311300E+01, 0.28234200E-01, 0.97854800E+00, -.15838000E+00, -.13014300E+01, 0.80043600E+01, -.45910100E+00, 0.41033000E+00, 0.56697600E+01, -.12578800E+01, 0.10141900E+00, -.71667800E+00, -.15943000E+00, 0.23194500E+00, -.55389400E+00, -.18205600E+00, -.65859500E-01, 0.33253900E+00, 0.31926500E+00, -.27357800E+00, -.29509400E-02, -.29173000E-01, 0.35158900E+01, -.15166300E-01, 0.11471900E-01, -.32754100E+00, 0.42507900E+00, 0.39532400E+00, -.10571300E+01, -.18315600E+01, 0.89991500E+00, -.55407900E+01, 0.18496100E+01, 0.26995500E+01, 0.10296000E+00, -.27522100E+00, -.29452000E+01, 0.74341100E+00, 0.13770000E+01, 0.67869700E+01, 0.26717600E+00, -.84247500E-01, -.75420900E+00, -.11109500E+00, -.13685900E+01, 0.95651300E-01, 0.13113700E+01, -.34690700E+00, -.44155500E+00, 0.97867800E+00, -.13954900E+01, -.16260600E+00, 0.10349300E+01, -.85856700E+00, -.92071000E-01, -.12836700E+01, 0.93097000E+00, 0.46113600E+00, 0.46154700E+00, 0.57198600E+00, 0.19127500E+00, 0.17697700E+00, 0.10547800E+01, -.38304600E+00, -.95661200E+00, 0.28418300E-01, -.10569400E+01, 0.53770700E-03, -.72823800E+00, 0.91480800E+00, 0.80724900E-01, 0.46431300E+01, 0.62669300E+00, 0.29314500E+01, -.32651100E-01, -.24624800E-01, 0.10154400E+00, 0.33466900E+00, -.15432700E-01, 0.33895200E+00, 0.16985800E+00, 0.82332400E+00, -.55531800E+00, 0.64778400E+00, -.29263700E-01, -.48302200E+00, -.79015700E-01, 0.28840000E-01, 0.38669200E+01, -.31359100E+01, -.72662300E-01, 0.20732500E+00, -.69127000E+00, 0.40455100E-01, 0.11384000E+01, -.61794400E+00, -.59609500E-01, -.49699400E-01, 0.65191900E-01, 0.50618800E+00, 0.36926600E-01, -.20312800E+01, 0.28247100E+00, -.34394100E+01, -.22486200E+00, 0.39291200E-01, -.10357600E+01, 0.65911200E-01, 0.70870000E-01, -.41560400E+00, 0.70640700E+03, 0.52427300E+00, -.39437900E+02, -.12955200E+03, 0.13058500E+03, 0.10051800E+03, 0.57591200E+02, -.14372700E+03, -.79092900E+02, 0.52138900E+02, -.18901300E+02, 0.27613700E+02, -.26195000E+02, 0.43727000E+00, 0.10776200E+03, -.44732500E+02, -.92021000E+02, -.17968600E+03, 0.60314700E+02, 0.87624300E+02, 0.11098200E+03, -.63181300E+02, 0.52372700E+02, -.55255500E+02, 0.10625500E+03, -.70777900E+01, -.82986700E+02, 0.70716300E+02, 0.40630800E+01, 0.17974100E+02, -.69996400E+02, 0.33631200E+03, -.20866400E+03, -.37789100E+02, -.16807900E+03, -.55528800E+02, 0.55161900E+01, -.11141600E+03, 0.16785100E+02, 0.32560200E+02, -.12350300E+02, -.11350700E+03, -.18554800E+03, 0.10731200E+03, 0.17818200E+03, 0.92790900E+02, -.24779400E+02, -.37899900E+02, -.60578400E+01, -.86120800E+02, -.18911200E+02, -.16769800E+02, 0.13821900E+03, 0.15586500E+03, -.90972900E+02, 0.10515300E+02, -.77705500E+02, -.53859100E+02, -.85283900E+00, -.74350700E+02, -.39661000E+02, 0.19238100E+02, -.21023900E+01, -.11531500E+03, -.97848300E+03, 0.50203900E+03, 0.44306000E+03, 0.48898200E+03, 0.13209100E+03, 0.13743200E+03, 0.10331300E+03, -.34147200E+03, 0.97885400E+02, 0.14601800E+03, 0.10611700E+03, -.16273800E+03, 0.89185400E+02, 0.92513300E+02, 0.81458200E+02, -.22662800E+01, 0.26728200E+02, -.16565500E+02, -.91819000E+02, 0.14070800E+01, 0.63552000E+02, -.73399500E+02, -.20425400E+03, 0.11367500E+03, 0.73218800E+02, 0.10227600E+03, 0.55811600E+02, 0.66968400E+02, 0.54709500E+01, -.83470500E+02, 0.12129200E+02, 0.72896400E+02, -.80863200E+02, 0.60133400E+03, -.30809800E+03, -.81723000E+02, -.30028700E+03, 0.32962000E+02, -.17415600E+03, 0.18694600E+01, 0.23503800E+03, -.29337500E+02, -.13598200E+03, -.21281900E+03, 0.25709200E+03, -.12059300E+03, -.43882600E+03, -.12857000E+03, -.48067500E+02, -.64023900E+02, -.24332100E+02, 0.21958600E+02, -.57294800E+02, -.40323700E+02, -.19482000E+02, 0.82554900E+01, 0.61172400E+01, 0.13519800E+01, 0.55225700E+01, -.23968700E-01, -.31858200E+01, -.49440900E+01, 0.34953300E+01, -.17842100E+01, 0.75203000E+02, -.74411600E+02, 0.43463300E+01, -.80242700E+01, -.26221600E+01, -.88350300E+00, 0.89400200E+02, -.53889800E+01, -.32382700E+01, -.33562000E+02, 0.14944200E+02, 0.11560900E+02, -.38513200E+01, -.19635600E+02, 0.10783500E+03, 0.20670300E+02, 0.83017100E+02 },
        { 0.40488800E+02, -.98693000E+00, -.15243100E+01, 0.77534800E+01, 0.44319000E+01, -.79649700E+01, 0.48972100E+01, -.41176500E+01, 0.19675900E+01, -.64414500E+01, 0.35284400E+00, 0.64932700E+01, -.36133700E+00, 0.29066000E+00, 0.18259200E+01, -.19536500E+01, 0.22097700E+01, 0.59930400E+00, 0.17979600E+01, -.30329800E+01, -.14143000E+01, 0.29423400E+00, 0.18348700E+02, 0.15230800E+01, -.46689700E+00, 0.71096900E+00, -.22885000E+01, 0.36952000E-01, -.25467600E+01, -.10996200E+00, -.10077900E+01, -.31762700E+01, 0.13992000E+00, 0.73070200E+00, 0.60351200E+01, 0.14502000E+00, 0.98976100E-01, 0.51801500E+01, -.29932200E+00, 0.87716700E+00, -.25471900E+00, -.11004400E+01, 0.19625100E+00, 0.10147100E+01, 0.86808200E+00, 0.36396900E+00, 0.14231200E+01, -.66654700E+00, -.28394800E+00, -.13388900E+00, 0.16222400E+01, 0.71226700E+01, -.33985600E+00, -.14743100E+00, 0.21047400E+01, 0.78471100E-01, 0.56167200E-01, 0.13104500E+01, -.15467800E+01, 0.29699000E+00, -.13433900E+00, 0.27148800E+00, 0.11136800E+01, 0.12288600E+00, 0.27043100E+00, 0.50602400E+00, -.10248100E+01, -.19258400E-01, 0.11675800E+01, 0.89134700E-01, -.37882200E+00, -.15629600E+00, -.12948800E+00, 0.43992600E-01, 0.80856900E-01, -.89664300E+00, -.53165800E+00, -.61195400E+00, -.17424600E+01, 0.38328800E+00, -.21408900E+00, 0.46692600E+00, -.55044100E+00, -.75833300E+00, -.10955000E+01, -.10553000E+02, 0.33979300E+00, -.96732400E-01, 0.91689700E+00, 0.45686900E+00, -.18402400E-01, 0.85487700E+00, -.24235100E+01, 0.37155000E+00, -.24874100E+00, -.99153500E+00, -.53327200E+00, 0.70355300E+00, -.13899800E+01, -.24125200E+00, 0.31400700E+00, 0.20387400E+01, -.30972100E+01, -.36006300E+01, 0.10106900E+01, 0.30310600E+01, 0.14035700E+01, 0.12426900E+00, -.86893400E+00, 0.47200400E+00, -.65932200E+01, 0.36054100E+00, -.39909000E+00, 0.12374100E+00, 0.14543000E+01, -.56246400E+00, -.13746700E+00, -.74858700E+01, -.10054900E+00, -.10703000E+02, 0.12193200E+01, -.81778500E+00, -.24078600E+00, -.28945000E+01, 0.75206300E+00, 0.18331100E+01, -.50712900E+00, -.53806900E+01, -.29567800E-01, -.78624700E+01, 0.13744900E+01, 0.73119400E+00, 0.13925700E+01, -.44739900E-01, -.71042900E+00, -.39225600E+01, 0.80614900E+00, 0.19658600E+01, 0.23015200E+01, -.37868400E+00, -.10209400E+00, 0.11589300E+01, -.15921800E+00, 0.24037500E+01, 0.18049900E-01, -.32529600E+00, -.40340600E+00, 0.29283000E+01, -.17288800E+01, -.63329700E+01, 0.28871500E+00, -.19293700E+01, -.46374000E+01, -.14494900E+01, -.23635100E+01, 0.37511900E+00, -.13544200E+01, 0.11525800E+02, 0.30951600E+03, 0.57263600E+03, -.62705000E+03, -.67276700E+03, 0.49276200E+03, 0.55421300E+03, 0.64488700E+03, 0.87885200E+03, -.45319300E+03, -.74419900E+03, -.44411800E+03, -.77561500E+03, -.16564000E+03, -.17766600E+02, 0.14165800E+03, 0.63960300E+03, -.12545400E+03, -.13541100E+04, -.48863500E+02, -.26077700E+02, 0.13430400E+04, 0.28975700E+02, 0.96397400E+03, -.18081500E+03, -.57955300E+02, 0.39080000E+03, -.72289500E+02, -.23955100E+03, 0.72194700E+03, -.34084500E+03, 0.19480000E+03, 0.43678100E+03, 0.17229700E+03, -.19882000E+02, -.55220500E+03, 0.57423000E+03, 0.12892500E+04, 0.52057100E+03, -.81119100E+03, 0.12729500E+04, -.93598500E+03, 0.42103400E+03, 0.31848200E+03, 0.46864400E+03, -.13124600E+03, -.37189300E+03, 0.45092100E+03, 0.54298800E+02, 0.41628600E+03, -.43917900E+03, 0.53443000E+03, -.36314700E+03, 0.22930000E+03, 0.20052700E+03, 0.18642100E+03, 0.44439300E+03, -.28839100E+03, 0.54583000E+03, 0.13155400E+04, 0.53220800E+03, -.62677300E+03, 0.13321900E+04, -.15789800E+03, 0.83789000E+02, -.91514000E+02, 0.73903600E+02, 0.32321000E+03, 0.45206600E+03, -.17636800E+03, 0.13852400E+03, 0.41943400E+03, 0.34976600E+03, 0.18092500E+04, 0.22584200E+04, -.11180100E+04, -.10546000E+04, -.11270600E+04, -.50749400E+03, -.27966000E+03, -.15381700E+03, 0.36953600E+03, -.43168800E+03, -.28852800E+03, -.69414700E+01, 0.12989500E+04, -.62905100E+03, 0.76189100E+03, -.64647100E+03, -.75683100E+02, 0.15965900E+02, -.19020100E+03, 0.47280000E+03, -.16728700E+03, -.59000100E+02, -.60924200E+03, -.68656500E+03, 0.31640800E+03, 0.27549500E+04, 0.35144800E+03, 0.12618200E+04, 0.46397100E+03, -.83796600E+03, -.65207200E+03, -.33845600E+03, 0.46243000E+03, 0.16262800E+04, -.79676500E+02, 0.19900300E+02, -.76085000E+03, 0.36673700E+02, -.61170500E+03, -.10660100E+04, 0.11423100E+04, 0.11707000E+04, 0.54424000E+03, -.99957700E+03, -.70241000E+03, 0.79156600E+01, 0.43264100E+01, -.11496900E+03, 0.26252100E+02, 0.60194400E+02, -.55923500E+02, -.13044100E+03, 0.29763100E+01, 0.11200500E+03, 0.34353300E+03, -.36854300E+03, 0.35913700E+02, -.35842300E+02, -.57717900E+02, 0.90962600E+02, 0.39380200E+03, 0.10581800E+03, -.20718800E+03, 0.25094700E+02, -.38303600E+03, -.11354300E+03, 0.13518300E+03, -.14406700E+03, 0.39878300E+03, 0.32039500E+03, 0.43168200E+03 },
        { -.29220600E+01, 0.96032400E-01, 0.97320500E-01, -.18795600E+00, -.21101400E+00, 0.47294900E+00, 0.81692500E+00, -.88048600E+00, 0.81359800E-01, -.24627700E-01, -.25964100E-01, -.38155000E-02, 0.91101700E-01, 0.22577400E-01, -.14407400E+00, -.15984400E-01, 0.29107700E-01, -.78271000E-01, -.56642900E+00, 0.55813600E+00, 0.55882500E+00, -.78967300E-02, -.75889500E+00, -.10282900E+00, -.22884200E+00, -.17722000E+00, -.47506400E-01, -.36516400E+00, -.55422900E+00, -.33899500E+00, 0.44815200E+00, 0.13598200E+00, 0.31626800E-02, -.19644900E+00, -.22227900E+00, 0.20492800E-01, -.54772800E-01, 0.13365600E+00, -.44029000E-01, 0.14601400E+00, 0.78599200E-01, -.43980400E+00, -.13626500E+00, 0.40359800E+00, 0.13285400E+00, -.40773000E-01, 0.75724300E-01, 0.32424100E-02, -.26555000E+00, 0.44155600E-01, 0.42542800E+00, -.44649200E-01, -.67669400E-02, -.21209400E-01, 0.11437800E+01, -.16218100E+00, 0.39487600E-02, -.38916100E+00, 0.17673000E-01, -.34893700E-01, 0.16191200E+00, 0.41755000E-01, -.23099300E+00, 0.40492400E-02, -.10061900E+00, -.34838700E-01, 0.20414400E+00, 0.53630300E-04, 0.28895800E+00, 0.14494300E-03, 0.34367000E-01, -.14243900E+00, -.52489500E-01, -.43646700E-02, -.30833800E+00, 0.59057400E-02, 0.15554600E+00, 0.46150900E+00, 0.18489600E+00, -.38148500E+00, -.12708100E-01, 0.23742100E+00, 0.21647900E+00, 0.44029800E-01, -.21952800E+00, 0.20341400E+00, -.15683900E+00, 0.63302300E-01, 0.28107900E-01, -.12423200E+00, -.21813900E-01, -.31198100E-01, -.94509900E+00, 0.11428100E+00, -.18377400E-01, -.15417800E+00, -.44637600E-01, 0.87647000E-01, -.73730300E+00, 0.12007500E+00, -.28107700E-01, 0.14597600E+00, -.63950200E-01, 0.20535200E+00, 0.88349500E-01, 0.24499400E+00, 0.11959700E-01, -.64852700E+00, 0.33991200E-01, -.44879200E-01, -.77029400E+00, -.25662700E-01, 0.55354100E-01, 0.42734600E-02, 0.24933600E+00, 0.25446100E+00, -.40969900E-01, -.31681400E+00, -.11768300E+00, 0.45783300E+00, 0.27803700E-01, -.85731600E-02, 0.56262300E-02, 0.26972100E+00, 0.16574100E-01, 0.29308600E+00, 0.11867600E+00, 0.15861100E+00, 0.18798700E+00, 0.13407300E+01, -.66074900E+00, 0.24888200E+00, -.19268800E+00, -.29569700E-01, -.11860400E+00, 0.38146500E+00, -.20366800E-01, -.18694500E+00, -.28684200E+00, 0.62350900E+00, -.56139700E-01, 0.18826900E-01, 0.31250900E-01, -.16727600E+00, -.17848100E-01, -.45108300E-01, -.22276700E-01, 0.11794600E+00, 0.70703000E-01, 0.13599500E+01, 0.26000100E-01, -.34831700E-01, 0.25021500E+00, -.59243200E-01, -.19833900E+00, -.26363800E-01, 0.12932300E-01, 0.17382300E-01, 0.38634500E+02, 0.80147900E+02, -.35524400E+02, -.10764500E+02, -.46664000E+02, 0.78203000E+02, -.18749400E+02, 0.46048100E+02, -.15043400E+02, -.52897600E+01, -.22994600E+02, -.37912300E+02, -.95929900E+02, 0.75220000E+02, 0.86135800E+02, 0.99205600E+02, -.95409400E+02, -.11559000E+03, -.31168500E+01, 0.24246700E+01, -.18019000E+02, 0.15768600E+01, -.41274400E+02, 0.25275100E+02, 0.11351800E+02, -.21351100E+02, 0.48008300E+02, 0.21006300E+01, -.19815900E+02, -.10425100E+02, -.29779300E+02, 0.69670600E+02, 0.52113200E+01, 0.34206100E+02, -.31528400E+02, 0.35121200E+02, 0.47317700E+02, 0.24018500E+02, -.17102700E+02, -.15483500E+03, 0.10425800E+03, -.61302300E+02, -.44088000E+02, -.52136500E+02, 0.18686700E+02, 0.14806100E+02, -.93742800E+01, 0.19229800E+02, -.13996000E+02, 0.12442800E+02, -.11194300E+03, -.79713700E+02, 0.25429800E+02, 0.69459200E+02, 0.39863600E+02, 0.28327000E+02, -.64729900E+02, 0.54050500E+02, 0.53425400E+02, 0.66145100E+02, -.47573400E+02, -.61689700E+02, 0.18067800E+03, -.82950800E+02, -.63801300E+02, -.90358500E+02, -.43543800E+02, -.52562100E+02, -.26332400E+02, 0.66682600E+02, -.72675700E+02, -.32223200E+02, 0.40498800E+02, -.26914200E+02, 0.15538900E+02, 0.86800300E+02, 0.13457300E+02, -.30155900E+02, -.34278700E+02, 0.45623200E+02, -.21728200E+02, -.97073800E+02, -.22728000E+02, 0.16050100E+02, -.67441400E+02, 0.33575800E+02, -.83944500E+02, 0.33731700E+02, -.30432900E+02, -.73158500E+02, 0.24877300E+02, 0.51457000E+01, 0.59248800E+02, -.68212100E+02, 0.61284900E+02, -.21659100E+03, 0.10216100E+03, -.10178500E+03, 0.10829600E+03, -.20452000E+02, 0.58779300E+02, 0.30202300E+02, -.76273500E+02, 0.98372500E+02, 0.32468300E+02, 0.55524400E+02, 0.10499500E+02, -.50313900E+01, 0.11244000E+02, -.51936900E+01, 0.26602400E+01, 0.15542200E+02, -.25757000E+02, -.54641200E+02, -.89856400E+00, 0.15133300E+02, 0.38715100E+01, -.34486900E+01, 0.22916100E+01, -.22306500E+01, -.32500600E+01, 0.14796500E+01, -.10024200E+01, 0.41047900E+01, -.19750000E+01, 0.31045300E+01, -.37277800E+02, 0.33235600E+02, 0.72055900E+01, -.57260000E+01, -.23627300E+01, -.45984200E+00, -.36558800E+02, 0.53820500E+01, 0.46243600E+01, -.87213600E+01, -.32768700E+02, 0.82167200E+01, -.58874700E+01, 0.14550200E+02, -.40057900E+02, -.29189500E+02, -.45376900E+02 },
        { 0.36044400E+01, -.13926700E+00, -.45576200E-01, 0.71605200E+00, 0.52964400E+00, -.10869600E+01, 0.21830300E+00, -.11931200E+01, 0.46037500E+01, -.63509300E+00, -.13155600E-01, 0.65314500E+00, 0.10975100E-01, 0.46988900E-01, 0.22830300E+00, -.14867100E-01, 0.29634200E+00, 0.35529700E+00, -.35146300E-01, -.10169600E+00, -.20933600E+00, 0.59902300E-01, 0.88128900E+01, 0.61639400E+00, -.24338700E-01, -.27333200E+00, 0.58080900E-01, -.93686100E+00, -.77348200E+00, -.77117100E+00, -.41403600E+00, 0.73428700E+00, 0.10968400E+00, -.50446100E-01, 0.23862100E+01, -.27762300E+00, 0.32852900E-01, -.31655300E-01, 0.14267400E+00, 0.32180300E-01, 0.58408300E+00, -.98481000E+00, -.25182500E+00, 0.97779500E-01, 0.87064500E+00, -.11573500E+00, 0.22445700E+00, -.11793000E-01, 0.77896100E-01, -.38191100E-02, 0.12139900E+01, -.77426500E+01, 0.29367200E+00, -.32826800E+00, 0.19019000E+01, 0.58305400E+00, -.41919400E-01, -.22192500E+00, 0.25366800E+00, 0.80239800E-01, 0.36771000E+00, 0.10680600E+00, -.76373100E-01, -.89371400E-01, -.15120400E-01, 0.58808300E-01, 0.10164300E+01, -.20366400E-01, 0.85703300E+00, -.41793600E-02, -.45096700E-01, 0.44349400E+00, 0.33786600E+00, -.24763200E+00, 0.35192900E+00, -.96796500E-01, 0.24600500E+00, -.40675600E+01, 0.14467200E+01, -.26384000E+00, -.36606300E-01, 0.21994700E+00, -.22703100E+01, 0.73777500E+00, -.10405900E+01, -.47507400E+01, -.28703000E+00, -.30051500E+00, 0.57836300E-01, -.11005800E+01, 0.67046000E+00, -.21160500E-01, -.15597400E+01, 0.19237200E+00, -.30969900E-01, 0.51690100E-01, -.28989200E+00, -.91575900E-01, -.26269100E+00, -.13498800E+00, 0.95089000E-01, 0.68057600E+00, -.29274000E+00, -.51866000E+00, 0.24627400E+00, 0.52421000E+00, 0.23727900E-01, -.30128500E+01, 0.29396700E+00, -.96146500E-01, -.23104700E+01, -.14282800E+00, -.38713100E+00, 0.74674800E-04, 0.38228500E+00, -.80414100E+00, -.24449300E-01, -.20525200E+01, -.32613300E+00, -.10209300E+01, 0.11455800E+00, -.95646900E-01, 0.33997800E-01, 0.27882800E+00, 0.14457000E-01, -.57992400E-01, 0.15502400E+00, 0.89074200E-01, -.16304100E+00, 0.25453000E+01, -.47326200E+01, 0.32769000E+00, 0.20373000E+00, -.30514500E-01, 0.26081300E+01, -.38360000E+00, 0.69873500E-02, 0.46869100E-02, -.78539900E+00, 0.27383500E+00, 0.24582500E+00, 0.12748900E+00, 0.15131000E+00, -.62017400E+00, -.42923700E-01, 0.17378100E+00, 0.39102600E-02, -.46476700E+00, -.47000600E-01, -.49081000E+00, -.48093100E+00, 0.12665600E+01, -.16096000E+01, -.10048900E+00, -.35740400E-01, -.16640400E+00, -.27086100E-01, -.48822100E-01, 0.14773800E+01, -.97860400E+02, -.31421800E+01, -.13517700E+03, 0.18374400E+03, -.92248500E+02, -.40681400E+02, -.65131700E+03, 0.30257700E+03, 0.56732800E+02, 0.32567800E+03, -.33577200E+02, 0.58121500E+02, -.14666500E+01, -.39501200E+02, 0.21779500E+03, 0.84569600E+02, 0.73417900E+03, -.47299800E+02, 0.28875800E+02, 0.17443700E+03, 0.23272200E+02, 0.23183000E+03, -.82229600E+02, 0.19573600E+02, 0.18646300E+03, -.99658100E+02, -.27601700E+02, -.97437600E+02, -.78012800E+03, 0.48787900E+03, 0.24724900E+03, 0.38994200E+03, -.73561000E+02, -.66755900E+02, 0.22617700E+03, -.64235000E+02, 0.10935900E+03, -.70868800E+02, 0.22176000E+03, -.23563600E+03, 0.14128100E+03, -.15193700E+02, 0.11774900E+03, -.30525100E+02, -.11474400E+03, 0.95521000E+02, -.25956700E+02, -.11097000E+02, -.70432500E+02, 0.21127600E+03, -.39497500E+03, 0.23652100E+03, 0.25105000E+03, 0.19714800E+03, -.46326400E+02, 0.47599500E+02, 0.97647500E+02, -.80942000E+02, 0.77933700E+01, -.14518600E+01, -.10431100E+03, 0.52068500E+03, -.28516000E+03, -.20258500E+03, -.25992500E+03, 0.26531300E+02, 0.12714700E+02, -.10592900E+03, 0.92709700E+02, 0.39233300E+02, -.45448000E+02, -.28496300E+03, 0.32429400E+03, -.16894800E+03, -.18871700E+03, -.16226700E+03, 0.14542700E+01, 0.10045900E+02, -.13126500E+03, 0.13589000E+03, 0.18067900E+03, -.13402300E+02, -.19748300E+03, -.20103700E+03, 0.11305100E+03, 0.31240700E+03, 0.10059400E+03, 0.42496400E+02, 0.64206500E+02, 0.13248900E+03, 0.23299100E+03, 0.10581300E+03, 0.28418800E+02, 0.15822000E+03, 0.48840900E+03, -.22159400E+03, 0.53088000E+03, -.24474900E+03, 0.23458000E+03, -.71508400E+02, -.20593400E+03, 0.76743800E+02, -.36802200E+03, -.14122800E+02, -.80685400E+02, 0.35161300E+03, -.17170700E+03, -.16907700E+03, -.17554600E+03, -.69909800E+02, -.51530000E+02, -.26972500E+02, 0.13062200E+03, -.24359000E+03, -.47200300E+02, -.36543200E+03, 0.10375600E+02, 0.12420300E+01, -.10206700E+02, 0.14000100E+02, 0.39732000E+01, -.63425600E+01, -.37116700E+02, 0.12345900E+01, 0.13827800E+02, 0.65022100E+02, -.67444000E+02, -.25674000E+02, 0.11223300E+02, -.80907800E+01, 0.25990100E+02, 0.84309800E+02, -.11617000E+02, -.28134700E+02, 0.31158700E+02, -.16126800E+03, -.21117300E+01, 0.42025700E+02, -.54537100E+02, 0.36831800E+02, 0.12041200E+03, 0.10009700E+03 },
        { -.43220700E+01, 0.80574300E-01, 0.14673200E+00, -.22104100E+00, -.43341100E+00, 0.23253900E+00, 0.90801600E+00, -.82478500E+00, -.13845000E+00, -.13255800E+00, -.32210000E-01, -.74154600E+00, 0.13215200E-01, -.14509500E-01, 0.50630100E-01, 0.87400300E-01, -.78834500E+00, -.18733700E+00, -.64221300E+00, 0.86652600E+00, -.27328500E+00, 0.21668100E-01, 0.26511300E-01, -.83781400E-01, 0.63710500E-01, 0.50181400E-02, -.59847200E-02, -.29918900E-01, -.41912400E-01, -.10674800E+00, -.51951000E-01, -.49370100E-01, -.91778600E-05, -.25789500E+00, 0.97876800E+00, 0.11648800E+00, -.11383800E-01, 0.30319000E+00, 0.58710600E-01, 0.23691700E+00, -.33149300E+00, 0.12912600E+00, -.31230700E-02, 0.10024400E+00, 0.40579700E-01, 0.41119500E-01, -.24944000E-01, -.56729300E-02, 0.81987800E-02, -.16726500E-01, -.65546000E-02, 0.29412100E+00, -.66819500E-02, -.83119300E-01, -.24979100E+00, 0.38604700E-01, 0.11550800E-02, 0.18982500E+00, -.88328900E-01, 0.19426400E-01, 0.40840800E-01, -.61520100E-01, 0.10283000E-01, 0.49370400E-02, 0.62057200E-01, 0.22309500E-01, -.40788600E+00, -.64354600E-02, -.18880500E+00, -.16039000E-03, -.25763600E-01, -.10527500E+00, -.12850400E-01, 0.19404600E-01, -.20704400E+00, -.25932300E-01, 0.35766900E-01, -.67152500E+00, 0.39217000E+00, 0.75709200E-01, 0.13490900E-01, -.25806800E+00, 0.23098000E+00, -.18642100E+00, 0.13535200E+00, 0.21933900E+01, -.18810400E-01, -.33119200E-01, -.14487600E+00, 0.19583200E+00, -.13380900E-01, 0.33866700E-01, 0.95077400E-01, -.39808800E-01, 0.12165800E-01, -.11152300E+00, 0.48955100E-01, -.55367900E-01, 0.27059700E+00, -.72054900E-01, 0.84543700E-03, -.33106900E-01, 0.65701100E-01, -.19410600E+00, 0.58112300E-01, -.16438600E+00, 0.95840600E-02, -.15691700E+00, -.10772600E-02, -.98495700E-02, -.71538400E+00, 0.53519500E-02, -.67835400E-01, 0.27936100E-02, 0.13133100E+00, -.51837700E-01, 0.31361700E-01, 0.30815900E+00, 0.94034700E-01, -.91358900E-01, -.34303800E-01, -.14867200E-01, 0.18878400E-01, 0.73213400E-01, 0.34179700E-02, -.70575900E-01, -.26663600E-01, 0.47189200E-02, -.96612800E-01, -.50757400E+00, 0.10050700E+01, -.76126700E-01, -.20072200E+00, -.42484900E-01, -.30792400E+00, 0.24156800E+00, 0.17828900E-01, -.12944000E-01, 0.41583900E+00, -.33222600E+00, -.23618500E-01, 0.16736100E+00, -.57163100E-01, 0.24562200E+00, -.78847400E-02, 0.18549000E-02, 0.30776500E-02, -.51074500E-01, 0.10084900E-01, -.99283300E+00, -.53252500E-01, -.10710600E+00, 0.22913500E+00, 0.49992600E-01, 0.23688500E-01, -.63869200E-03, -.46778400E-01, 0.11901900E-01, -.94080000E+00, -.68170100E-01, 0.73137600E+02, 0.78700500E+02, -.40772300E+02, -.37790500E+01, -.51543500E+02, 0.40357200E+02, -.14236000E+02, 0.43459000E+02, -.20162900E+02, -.31142500E+02, -.56672500E+02, 0.47077400E+02, 0.63229900E+02, 0.36961200E+02, -.67464800E+02, -.79087300E+02, 0.83953100E+01, -.60035600E+01, -.28579900E+02, -.41246200E+01, -.25088300E+02, 0.20488700E+02, 0.22417600E+01, -.56711300E+01, 0.41358700E+02, 0.64358800E+01, -.42857200E+02, -.10052900E+02, -.24345700E+02, 0.57014900E+02, 0.50457800E+01, 0.33811900E+02, -.22767100E+02, 0.27691500E+02, 0.37011300E+02, 0.40383400E+02, -.15677700E+02, -.13879700E+03, 0.69704800E+02, -.38619300E+02, -.22240600E+02, -.34844700E+02, 0.69373200E+01, 0.33323800E+01, -.12477500E+02, 0.81038500E+01, -.21224700E+02, 0.10681800E+02, -.74585000E+02, -.49199800E+02, 0.13997700E+02, 0.47240500E+02, 0.24660300E+02, 0.16204500E+02, -.50384400E+02, 0.34527400E+02, 0.27486200E+02, 0.61002400E+02, -.41550300E+02, -.81477400E+02, -.95171900E+01, 0.11330400E+02, 0.27387600E+02, 0.46785900E+01, -.34485700E+02, -.28917000E+02, 0.31175900E+00, -.13441400E+02, -.63244600E+02, -.61834200E+01, 0.27426100E+02, -.59850500E+02, 0.31852300E+02, 0.13355100E+03, 0.29944800E+02, -.23737200E+02, -.21114800E+02, 0.28790200E+02, -.36949200E+02, -.85879400E+02, -.27006800E+01, -.10502200E+02, -.14974000E+03, 0.74333900E+02, -.54352100E+02, 0.74862000E+02, -.13583100E+02, -.39885000E+02, 0.26982000E-01, -.66822000E+02, 0.54428000E+02, -.32951800E+02, 0.60517000E+02, -.33060900E+02, 0.10263800E+02, -.25063100E+03, 0.16624500E+02, -.19814900E+02, -.10412300E+02, 0.47933000E+02, -.92093500E+01, 0.71549200E+02, -.16656600E+02, -.29976800E+02, 0.27606600E+02, -.13247600E+02, 0.63202200E+01, -.13812500E+02, 0.87617700E+01, 0.93767700E+01, -.24791200E+02, -.58547500E+02, 0.22997900E+02, 0.14689500E+02, 0.85413800E+01, -.35623000E+00, 0.20225900E+01, 0.13850400E+01, -.16969700E+01, -.53900100E-01, 0.22803800E+00, 0.31531300E+01, -.80566800E+00, -.88366300E+00, -.21903300E+02, 0.24610800E+02, 0.54780500E+01, -.35155200E+01, -.18624600E+01, 0.23654700E-01, -.24268800E+02, -.14887600E+00, 0.60287000E+01, -.59855900E+01, -.21066500E+02, 0.61319200E+01, -.60498900E+01, 0.79253500E+01, -.16176500E+02, -.17199800E+02, -.34257400E+02 },
        { -.96247300E+01, 0.25151500E+00, 0.40880200E+00, 0.99318500E+00, -.10702200E+01, 0.26267700E+01, -.70375000E+00, 0.21707400E+00, 0.64828200E+00, 0.29061300E+01, -.75773800E-01, 0.12483700E+01, -.18674200E+00, -.16999500E+00, 0.26371300E-01, 0.12744800E+00, 0.92322900E-01, -.96999700E-01, -.13177700E+00, 0.12649900E+01, 0.22519900E+00, 0.30111300E+00, -.28961800E+01, -.14760600E+01, 0.16417000E+00, -.12469600E+00, -.14163600E+00, -.51449200E+00, 0.63965200E+00, 0.15190700E+00, -.10641200E+00, 0.41187300E+00, -.38899000E-01, 0.83768200E-01, -.93387100E+00, -.26533000E+00, -.13689200E+00, -.17519600E+01, -.42073300E-01, -.49040900E+00, 0.38421900E+00, 0.15825600E+01, -.23678500E+00, -.70477400E+00, 0.74590100E+00, 0.51915400E-01, 0.35270900E+00, 0.31640800E-02, -.90662900E+00, 0.19598600E+00, -.16505800E+00, 0.25508800E+01, 0.14555800E+00, -.24031400E+00, -.26470400E+01, 0.49981100E-01, -.44716300E-01, 0.81629900E+00, -.16784800E-01, 0.66823800E-01, -.67090500E+00, -.50858900E+00, 0.37842900E+00, 0.34025400E-01, 0.70685200E-02, -.54519300E-01, -.77687000E+00, 0.10925600E-01, 0.36525700E+00, -.28108800E-02, 0.79071100E-01, 0.96966200E-01, 0.33005500E+00, -.12308900E+00, -.96308600E-01, -.32648000E+00, -.64850200E-01, -.33854700E+01, 0.46432600E+00, -.11711100E+00, 0.27914200E-01, 0.24087900E+00, 0.94780500E-01, 0.19601300E+00, 0.87560200E+00, 0.72397300E+01, 0.39605800E+00, 0.17180000E+00, -.57149200E+00, 0.94969500E+00, 0.78705500E+00, -.62690700E-01, -.19303500E+00, -.24769400E+00, 0.23331900E+00, 0.32469500E+00, -.28459400E-01, -.76212700E+00, -.65682900E+00, 0.35014800E+00, 0.33543700E-01, 0.21281900E+00, 0.33360600E-01, -.24554100E+00, -.86000000E-01, 0.53933600E+00, -.16681000E+00, -.55461500E+01, -.47481200E-02, 0.11940900E-01, 0.20071300E+01, 0.90303400E-02, 0.32530300E+00, -.10602900E-01, -.70106800E+00, -.30022300E+00, -.18121200E+00, 0.29564900E+00, -.39792900E+00, 0.11703400E+01, 0.23442700E+00, -.17558700E+00, -.54439000E-02, -.11652100E+00, -.42710900E-02, 0.12690800E+00, 0.12477800E+00, -.50217000E+00, -.15126700E+00, 0.55910700E+00, -.25580800E+01, 0.69173800E+00, -.10326800E+00, 0.45742700E-01, 0.71139600E+00, 0.91360800E+00, 0.10000100E+00, -.15155400E+00, 0.31146100E+00, 0.72425700E+00, -.48849600E+00, -.28130300E+00, -.85118400E-01, -.28494900E+00, -.18391700E-01, -.34227400E-01, 0.33587200E-01, -.56986200E+00, -.19444000E+00, 0.19013500E+01, 0.20873700E+00, -.61225900E+00, 0.16896300E+00, -.45418800E+00, -.40919400E+00, 0.87111000E-01, 0.21552500E+00, 0.13010200E-02, 0.32129500E+01, -.12410600E+00, -.14484200E+01, -.23298000E+03, -.19077700E+03, 0.22056800E+02, -.11300000E+02, 0.22634000E+02, -.33339000E+02, -.85015200E+02, -.11102000E+02, 0.12746400E+02, 0.12788400E+03, -.12521800E+03, -.60713500E+02, 0.66291800E+01, 0.15486800E+03, 0.96436100E+02, -.24305600E+02, 0.55426300E+01, 0.20457000E+03, 0.11589900E+02, 0.17237700E+03, -.85654200E+02, -.82709500E+02, 0.31792400E+02, -.11142500E+03, -.48753200E+02, -.18172900E+02, -.21189700E+03, 0.21189200E+03, -.22775400E+03, 0.10574200E+03, -.10483200E+03, 0.29028000E+01, -.45335400E+00, -.21499700E+02, -.39476800E+02, -.62175700E+02, 0.49786700E+03, -.20785700E+03, 0.11807600E+03, -.33026600E+01, 0.10382200E+03, -.43528500E+02, -.86360200E+02, 0.44081800E+02, 0.49925500E+00, 0.10816300E+03, -.71225400E+02, 0.19034200E+03, 0.58511300E+02, 0.19095800E+02, -.18886300E+03, -.29787000E+02, -.56250100E+02, 0.72163700E+02, -.14696100E+02, 0.69976800E+02, -.97122300E+02, -.27074400E+02, 0.25709500E+03, 0.23128600E+03, -.13792200E+03, -.13229800E+03, -.11501900E+03, 0.47711900E+02, 0.11543200E+03, -.45684700E+02, 0.12139200E+03, 0.19618500E+03, 0.39961600E+02, 0.19597800E+03, 0.37774900E+03, -.19646000E+03, -.37054600E+03, -.18908600E+03, -.40602900E+02, 0.62931400E+02, -.14924300E+03, 0.15881000E+03, 0.20674900E+03, 0.68742800E+01, 0.80418200E+02, 0.69580700E+03, -.34655200E+03, 0.37753300E+02, -.34779900E+03, -.28698700E+02, 0.67062700E+02, -.92076900E+02, 0.21561700E+03, -.14687200E+03, 0.32576400E+02, -.15912900E+03, 0.43754600E+03, -.20453800E+03, 0.68929100E+03, -.21960000E+03, 0.84410000E+02, -.98725800E+02, -.18379200E+03, 0.49554100E+02, -.32404800E+03, -.36931000E+02, -.85494700E+02, -.22899400E+03, 0.10667200E+03, 0.37562700E+02, 0.11491700E+03, -.82922100E+02, -.19292000E+03, 0.25016500E+03, 0.31763000E+03, 0.27227600E+03, -.19074500E+03, -.10083500E+03, 0.87872400E+01, -.91529600E+01, -.12841900E+02, 0.12619500E+02, 0.10212300E+02, -.10598000E+02, -.27548900E+02, 0.23189600E+01, 0.12534300E+02, 0.30524500E+02, -.19488900E+02, -.10233700E+02, 0.10710500E+02, -.13904600E+02, 0.23609100E+02, 0.22865800E+02, 0.29207000E+01, -.36513400E+02, 0.28966300E+02, -.15917500E+02, -.31397000E+02, 0.38141600E+02, -.43706900E+02, 0.50798600E+00, 0.91231300E+02, 0.48886600E+02 },
        { -.19421000E+02, 0.56020000E+00, 0.67274600E+00, -.21463800E+01, -.21815100E+01, 0.40004700E+01, -.22546100E+01, 0.14084800E+01, -.29248200E-01, 0.30026700E+01, -.27197900E+00, -.38444900E+01, 0.56141200E+00, -.14132000E-01, -.23693100E+01, 0.10864800E+01, -.18974800E+01, -.16947100E+01, -.17001400E+01, 0.86009600E+00, -.15151100E+01, 0.29953900E+00, -.23864700E+02, -.15352700E+01, -.27987300E+00, -.12257900E+00, 0.97740100E+00, 0.24878000E+00, -.25475300E+00, -.77822900E+00, 0.99277300E+00, 0.17662200E+01, -.41163600E-01, -.24080500E+01, 0.73337500E+01, 0.12630400E+01, 0.42914100E+00, 0.49305000E+01, 0.24678500E-01, 0.19323300E+01, -.16362400E+01, -.38423000E+01, 0.11016000E+00, 0.32029300E+01, -.18121300E+01, 0.20684600E+00, -.92802800E+00, -.85044900E-02, 0.10146800E+01, -.71911600E+00, 0.50725800E+00, 0.42439500E+01, -.35099100E-01, -.28316300E+00, 0.15814500E+01, 0.49604100E-02, 0.57736300E-01, -.37810600E+00, -.14174600E+01, 0.35782500E+00, 0.56710500E-01, 0.55607700E-01, -.77043300E+00, 0.11134200E+00, -.35935100E+00, -.40975600E+00, -.19556600E+01, 0.48870600E-01, -.19488900E+01, -.10096800E-01, 0.39986400E+00, -.37987500E+00, 0.13781900E+00, -.61793500E-01, 0.12093300E+01, 0.18384200E+00, 0.49420700E+00, -.61121600E+00, 0.64316200E+00, -.22667700E+00, -.24099500E-01, 0.88750400E+00, 0.68033600E+00, -.50108000E+00, -.38355200E+00, -.64792700E+01, -.51555900E+00, -.32391200E-01, -.36881600E+00, -.58850000E+00, 0.32184600E+00, 0.32522700E-01, -.22922300E+01, 0.66085100E-01, -.47030500E-01, -.23276000E-01, -.77295600E+00, -.82362800E+00, -.14156500E+01, -.12629000E+00, 0.56530300E-01, 0.74528100E+00, -.33320500E+00, -.13561100E+01, 0.35847100E+00, 0.13745700E+01, 0.32352200E+00, -.42256900E+01, 0.53209000E+00, -.29136400E+00, -.28488400E+01, -.71713100E-01, -.34278100E+00, 0.35326200E-01, -.53259200E-01, -.49382600E+00, 0.16831800E+00, -.64543000E+00, 0.93043800E-01, 0.24415700E+01, -.58526400E+00, -.56662000E-01, 0.11893500E+00, 0.98003700E+00, 0.48949200E-01, -.31901900E+00, 0.36883000E+00, 0.79020700E+00, -.41818100E+00, 0.25692400E+01, 0.78657800E+00, 0.25135100E+00, -.31113300E+00, -.14929600E-01, 0.51276600E+01, -.11865900E+01, -.12247600E+00, -.72709400E-01, -.51623200E+00, -.23074600E+00, 0.63261500E+00, 0.51066800E-01, -.47603000E-01, -.22203500E+00, -.15959400E-01, -.32575900E-01, -.48500600E-01, 0.68263300E+00, 0.53712400E+00, -.11700300E+01, -.41150000E+00, 0.23211300E+00, 0.17967300E+01, 0.11627600E+00, -.21238900E-01, -.45300200E-01, -.16007600E+00, 0.46584000E+00, -.49517800E+01, -.33821300E+00, 0.24023700E+01, -.24831400E+00, -.53679000E+03, 0.14150300E+00, -.23848200E+03, -.74375500E+02, 0.72733900E+02, 0.25735300E+03, 0.39295100E+02, 0.22281000E+03, -.27760800E+03, 0.26001200E+03, 0.22023300E+03, 0.50769400E+02, -.27473500E+03, 0.12041900E+03, 0.42189400E+02, 0.16944400E+01, -.53260800E+03, -.23133300E+02, -.53022700E+03, 0.15231400E+03, 0.55497900E+02, -.18249000E+03, 0.18954500E+03, 0.13846100E+03, -.45321500E+03, 0.48237600E+03, -.38500800E+03, -.54354800E+02, -.24210200E+03, 0.84586300E+02, 0.24077500E+03, -.25578400E+03, -.40871600E+03, -.29758500E+03, 0.38211700E+03, -.11773800E+04, 0.65457200E+03, -.33117900E+03, -.13735400E+03, -.32774800E+03, 0.11641300E+03, 0.20552800E+03, -.18347300E+03, 0.41092900E+02, -.19355700E+03, 0.24088600E+03, -.58485800E+03, 0.18652100E+03, -.16829100E+03, 0.82072200E+02, -.95468200E+02, -.16290000E+03, -.15868100E+02, -.15764700E+03, -.38901200E+03, -.12784700E+03, 0.17205800E+03, -.84689700E+03, 0.10464400E+04, -.49594800E+03, -.41571700E+03, -.52094200E+03, -.29940600E+03, -.37205300E+03, -.11368600E+03, 0.28789600E+03, -.40193600E+03, -.27774900E+03, -.87708500E+03, -.82625900E+03, 0.41948700E+03, 0.57129200E+03, 0.41214800E+03, 0.13495100E+03, 0.56507200E+02, 0.64157300E+02, -.17574900E+03, -.38531900E+02, 0.79636900E+02, -.37990900E+02, -.74376500E+03, 0.35993300E+03, -.46018100E+03, 0.37145500E+03, -.12476700E+02, -.10372500E+03, 0.16703200E+03, -.14858100E+03, 0.22790200E+03, -.78156900E+02, 0.47029800E+03, -.15188000E+03, 0.66232800E+02, -.15351900E+04, 0.72263000E+02, -.65388200E+03, -.88554600E+02, 0.46656300E+03, 0.12208700E+03, 0.45950500E+03, -.14503700E+03, -.62590900E+03, -.21792200E+03, 0.11994800E+03, 0.41617400E+03, 0.11120300E+03, 0.29797700E+03, 0.48683000E+03, -.45996200E+03, -.54828400E+03, -.88191000E+02, 0.46159900E+03, 0.33487600E+03, -.12237700E+02, 0.67818100E+01, 0.37438600E+02, -.16909500E+02, -.17993500E+02, 0.20088000E+02, 0.68739400E+02, -.64389000E+01, -.33068500E+02, -.24869000E+03, 0.23339300E+03, -.29263000E+01, -.79767800E+01, 0.15299300E+02, -.46475900E+02, -.25917100E+03, -.29081500E+02, 0.10594900E+03, -.34272900E+02, 0.41736000E+02, 0.76130900E+02, -.70472400E+02, 0.87847900E+02, -.27243300E+03, -.23784400E+03, -.30528200E+03 },
        { -.17869100E+01, 0.12903200E+00, 0.87223500E-01, -.27100700E+00, -.24360300E+00, 0.15809800E+01, -.11130500E+01, 0.11576600E+01, 0.12316100E+00, 0.14274900E+01, -.88373100E-01, -.11455300E+00, 0.18618300E+00, 0.27042600E-01, -.50435900E+00, 0.24122700E+00, 0.44371400E+00, -.17629800E-01, -.68471800E-01, -.37537800E+00, 0.24259300E+00, -.41736200E-01, -.46884800E+01, -.91265800E-01, -.32939800E+00, -.76723700E-01, 0.24474500E-01, 0.58336400E-01, 0.11182300E+00, -.11300700E+01, 0.27368500E+00, -.25535400E+00, -.32684500E-01, 0.61848900E-01, -.25224200E+01, -.45758500E-01, -.27258800E+00, 0.19087100E+01, -.83185100E-01, -.89728600E-01, 0.11933800E+00, -.10679600E+01, -.68590400E+00, 0.98342800E+00, -.49432500E-02, -.42727000E-01, -.16575700E+00, 0.52352400E-01, 0.75204500E+00, -.13749200E+00, 0.79335800E+00, -.38508100E+01, 0.95426300E-01, 0.34055100E+00, 0.30279900E+01, -.23314100E+00, -.79154900E-01, -.52292700E+00, 0.85191900E+00, 0.70614400E-01, -.69184600E-02, -.14229100E+00, 0.14848800E+00, -.58166300E-01, -.10999900E+00, 0.64753600E-01, -.11612800E+01, 0.26427500E-01, -.11409700E+01, 0.48712900E-03, 0.14145900E-01, 0.13324800E+00, 0.80227600E-01, -.51320700E-01, 0.57232600E+00, -.25809600E+00, -.18431400E+00, -.37620600E+01, -.75990000E+00, 0.40395700E+00, 0.10486400E-01, 0.83748000E-01, 0.69455500E+00, -.33478200E+00, 0.36236700E+00, -.44633100E+01, 0.30343500E+00, -.11667000E-01, 0.22483200E+00, 0.28568800E+00, 0.25120000E+00, 0.11282100E-01, 0.13777400E+01, -.53599000E-01, 0.16122200E+00, 0.44330700E+00, 0.64955500E+00, -.50194400E+00, -.28829700E+00, 0.54641700E-01, 0.10506800E-01, 0.23667100E+00, -.69018700E-01, -.16964700E-01, 0.23282500E-01, 0.54938000E+00, -.54911000E-01, -.31286600E+01, 0.11419600E+00, -.14564200E-01, -.57089400E+00, 0.28779700E-01, 0.39498700E-01, 0.15605700E-02, -.18916600E+00, -.30445700E+00, -.65483100E-02, -.93355100E+00, -.30694600E-01, -.22633800E+00, -.56220600E-02, -.70374900E-01, -.20271500E-01, -.12582900E+00, -.16305600E-02, -.39272700E+00, -.44743900E-02, -.34302400E+00, -.13950700E-01, -.44429700E+00, -.22863800E+00, 0.10580400E+00, 0.10911500E+00, 0.30760500E-01, 0.24489400E+00, 0.17487400E+00, 0.27047500E-01, -.57569800E-02, -.27843100E+00, 0.21932700E+00, 0.37280700E-01, 0.36427600E-02, 0.19713800E-01, -.14260900E+00, 0.16736100E-01, 0.12376700E-01, 0.46705000E-02, 0.10662200E+00, -.71201500E-02, -.11099900E-01, 0.35117100E-01, -.14127300E+00, 0.56007900E+00, 0.32737200E-01, 0.17194600E-01, 0.11761200E+00, 0.18653400E-02, 0.13349600E-01, 0.60193200E+00, -.30922100E+00, -.37780100E+00, 0.18932600E+00, -.69396100E-01, -.22575300E+02, -.11147200E+02, -.19461800E+03, 0.94766700E+02, 0.51057300E+02, 0.97481800E+02, 0.28002200E+02, -.21120200E+01, 0.16279700E+02, -.13874700E+02, 0.38499300E+02, 0.19172900E+01, 0.21522900E+03, -.17208100E+02, 0.14919100E+02, -.21588100E+02, 0.83846800E+01, -.13883500E+02, -.19365600E+01, 0.20984000E+02, 0.36094800E+02, 0.29407100E+01, 0.15106400E+02, -.44616200E+02, -.10420600E+03, 0.62147500E+02, 0.79733100E+02, 0.52011700E+02, 0.75403000E+00, 0.31285200E+02, 0.94805000E+01, -.71977600E+02, -.23740300E+02, 0.46562700E+02, -.10415600E+03, -.71381300E+01, 0.14158200E+02, 0.76624600E+01, 0.35240100E+01, 0.44859800E+01, -.26823000E+01, 0.35195900E+01, -.36982700E+01, -.24262100E+02, 0.14868300E+02, 0.19010800E+02, -.64815600E+02, 0.33770400E+02, 0.80462800E+02, 0.32182900E+02, -.28304000E+02, 0.29112800E+02, -.17451100E+02, -.99600300E+02, -.32646100E+02, 0.45604000E+02, -.15465700E+03, 0.21159700E+03, -.11014200E+03, -.86286900E+02, -.10555400E+03, -.28604900E+02, -.39045000E+02, -.35007600E+02, 0.22386800E+02, -.49236100E+02, -.37117400E+02, -.24527100E+03, 0.46621900E+01, -.36422000E+01, 0.25157400E+02, -.24282400E+01, 0.17215400E+02, 0.45508300E+01, -.23246500E+02, 0.64509300E+01, 0.22944700E+02, 0.53094800E+01, -.84399700E+02, -.22418300E+03, 0.11109700E+03, 0.56759200E+02, 0.11207300E+03, 0.23653300E+02, 0.22296800E+01, 0.50565500E+02, -.80260800E+01, 0.59657600E+02, 0.12653100E+02, 0.62038700E+02, 0.12160700E+03, -.54386300E+02, -.11595100E+03, -.61166700E+02, -.14870400E+02, -.32735700E+02, 0.42092200E+01, 0.43639500E+02, -.34247500E+02, -.20325000E+02, -.99588600E+02, 0.45443800E+02, -.21557300E+02, -.79394100E+01, -.22512500E+02, 0.28208300E+02, 0.47820700E+02, -.65031400E+02, -.53492600E+02, -.83379200E+02, 0.52543900E+02, -.21879200E+02, 0.10715400E+01, 0.13186900E+01, 0.44643000E+01, 0.12694100E+01, -.23719200E+01, 0.24606500E+01, 0.22270100E+01, 0.43221700E-01, -.35391600E+01, 0.62316100E+01, -.10913300E+02, -.40390000E+01, 0.21503400E+01, 0.17891800E+01, -.40159200E+01, 0.10541900E+02, -.57341000E+01, 0.79034600E+01, 0.51902000E+01, -.26338700E+02, 0.89234900E+01, -.93425800E+00, -.17903900E+01, 0.12735400E+02, 0.22630800E+01, 0.81962800E+01 },
        { -.12548800E+02, 0.30540100E+00, 0.41521300E+00, -.25440600E+00, -.15041700E+01, 0.28571100E+01, -.87109900E+00, 0.15492400E+01, -.13733600E+01, 0.22326200E+01, 0.11242300E+01, -.50905300E+01, -.14594400E+00, -.11022900E-01, -.13047500E+00, 0.81995700E+00, -.13541300E+01, -.18082500E+00, -.12453200E+01, 0.69297900E+00, 0.11797800E+01, -.14255500E+01, -.83730200E+00, 0.25114900E+01, -.19578500E+00, 0.35272600E+00, -.79686200E+00, 0.18229900E+01, 0.38794700E+01, -.29432900E+01, 0.44265300E+00, -.54492400E+01, -.69835300E+00, 0.47667100E-01, 0.47569500E+01, -.11410300E-01, 0.20049300E+00, 0.21537600E+01, 0.10862200E+00, 0.60210600E+00, -.10069500E+00, -.15461000E+01, 0.11653300E-01, 0.22048100E+01, -.22404200E+00, 0.56958600E+00, -.42072500E+00, -.43048300E-01, -.58966000E+00, -.13676400E+00, 0.93985100E+00, 0.61935400E+01, 0.26664200E-01, -.40505700E+00, 0.10077500E+01, -.22791500E+00, 0.39987200E-01, -.75779600E+00, -.13957600E+01, 0.18253600E+00, 0.21168400E+00, -.78032300E-01, -.11916700E+01, 0.28236300E+00, -.16136100E+00, 0.85998300E-02, -.21358200E+01, 0.93575600E-01, -.20267800E+01, -.44709300E-02, 0.45677900E+00, -.35872800E+00, 0.20369900E+00, -.30275500E-01, 0.12916800E+01, 0.43352200E+00, 0.13472600E+01, 0.35411300E+01, -.18003900E+01, 0.10616400E+01, 0.11730400E+00, 0.83290700E+00, 0.13865000E+00, -.14902400E+01, 0.17633500E+01, -.22751500E+01, -.36636600E+00, 0.74667000E+00, -.46846300E+00, -.91182400E-01, 0.22757700E+00, -.21035000E-01, -.68461800E+00, -.18689100E+00, 0.19932100E-01, 0.24205700E+00, -.85181600E+00, -.69162100E+00, -.12630800E+01, 0.61241700E-01, -.76833700E-01, 0.43167600E+00, 0.21001200E+00, -.16785800E+00, 0.10190600E+00, 0.89323000E+00, -.14214600E+00, -.61565700E+01, 0.40417500E+00, -.20403500E+00, -.23599400E+01, -.94337400E-01, -.33520200E+00, -.41115100E-02, -.42658800E+00, -.61219100E+00, 0.91419100E-01, -.47521100E+01, 0.10026800E+00, 0.72762700E+00, -.33207000E+00, -.14606200E+00, 0.65549700E-01, 0.45451200E+00, 0.20332000E-01, -.68381700E+00, 0.20011000E+00, -.37143300E+00, -.12322200E-02, 0.30465900E+00, 0.19460300E+01, 0.56578500E+00, -.35154300E+00, -.87213400E-02, 0.33872300E+01, 0.30595200E+00, -.13634800E+00, -.14113100E+00, -.18935900E+01, 0.23247600E+00, 0.10499800E+01, 0.34924800E+00, 0.20732200E-01, 0.43166800E+00, 0.15818000E-02, -.13229500E+00, 0.29849600E-03, 0.15342300E+01, 0.38427300E+00, -.17722600E+01, -.20056300E+00, -.30275200E+00, 0.14709800E+01, -.12885800E-02, -.19762800E+00, -.99524100E-01, -.56708100E+00, 0.13468100E+00, -.19365800E+01, -.69012600E+00, -.84191700E-01, -.11936200E+00, 0.23719000E+00, 0.14681300E+01, 0.38520900E+03, 0.39741400E+03, -.18413500E+03, -.47890400E+02, -.19901000E+03, -.21775400E+03, -.11739700E+03, 0.44662500E+02, 0.11050700E+03, 0.12499300E+03, -.14032500E+03, -.60585000E+03, 0.41618900E+02, -.46772600E+02, 0.29417100E+03, -.20382300E+02, 0.19504600E+03, -.80055100E+01, 0.47258500E+01, 0.10228900E+03, 0.36695000E+02, -.25539900E+02, 0.15495600E+03, 0.27354600E+03, -.22250100E+03, 0.10096400E+03, -.13661500E+03, 0.11555200E+03, -.10689200E+03, 0.11639400E+03, 0.48311100E+03, 0.11941200E+03, -.16602500E+03, 0.16033400E+02, -.19539900E+03, 0.74456600E+02, 0.22249100E+03, 0.97759300E+02, -.19926800E+02, -.53394400E+02, 0.97477100E+02, -.27411600E+02, 0.21313800E+02, -.55815900E+02, 0.41635800E+02, 0.41697400E+02, -.40806000E+02, 0.58383300E+02, -.20411000E+02, 0.16368900E+03, -.11437500E+03, 0.12588300E+03, 0.40389600E+03, 0.18589300E+03, -.19213500E+03, 0.19416400E+03, -.64912400E+02, 0.57946200E+02, -.70982300E+00, 0.31983900E+02, -.34836000E+01, 0.80923600E+02, -.10991900E+03, -.59650900E+02, -.33544100E+02, 0.97673500E+02, 0.33420300E+03, 0.84707800E+03, -.41057700E+03, -.15960600E+03, -.42336300E+03, -.17858900E+03, -.10418900E+03, -.13910700E+03, 0.80339000E+02, -.28925900E+03, -.68468100E+02, -.21077000E+03, -.63971200E+02, 0.47497900E+02, 0.18826200E+03, 0.32222000E+02, 0.24286000E+02, 0.62431500E+02, -.81411100E+02, -.96471900E+02, -.86188700E+00, 0.43717900E+02, -.13334700E+03, -.60850200E+02, 0.35491700E+01, 0.19851200E+02, 0.31186600E+02, 0.28547800E+03, 0.17123500E+02, -.38745000E+02, -.92322200E+02, 0.62754600E+02, 0.37315600E+02, 0.28517000E+03, -.94104100E+02, 0.48995000E+02, -.13814400E+03, 0.46831900E+02, -.84260900E+02, -.20467300E+03, 0.25295200E+03, 0.18039200E+03, 0.24826200E+03, -.18139000E+03, -.15179000E+03, 0.50469000E+01, 0.66551400E+01, -.25890500E+02, 0.38982300E+01, 0.14724000E+02, -.10418200E+02, -.18856100E+02, 0.23227300E+00, 0.24124700E+02, 0.66900200E+02, -.74656200E+02, 0.11107700E+02, -.19580800E+02, -.17072600E+02, 0.74371400E+01, 0.78902300E+02, 0.17352400E+02, -.36384300E+02, 0.46413200E+01, -.82951100E+02, -.25458600E+02, 0.15188100E+02, -.40486600E+02, 0.12148300E+03, 0.51309300E+02, 0.61989300E+02 },
        { 0.97196800E+01, -.34267100E+00, -.34448400E+00, 0.60883500E+00, 0.98337800E+00, -.23752700E+01, 0.26043500E+01, -.91950900E+00, -.18349400E+01, -.22546600E+01, 0.15306000E+00, 0.34851800E+00, -.37217400E+00, 0.37218900E-01, 0.39781700E+00, -.70722300E+00, 0.71146400E-01, 0.47057100E+00, 0.42135400E+00, 0.49944000E+00, 0.79386500E+00, -.18397100E+00, 0.85586700E+01, 0.67109700E+00, 0.12402500E+00, -.65874500E-01, -.15741100E+00, -.21150100E+00, 0.81799700E+00, 0.31246600E+00, 0.30943100E-02, 0.78772400E+00, -.86363500E-02, 0.44171000E+00, -.23001600E+01, -.39905800E+00, -.38992800E-01, -.25785300E+01, 0.22022300E+00, -.10732100E+01, 0.40200100E+00, 0.16926800E+01, 0.43579100E+00, -.17126700E+01, -.90564500E-01, 0.21207100E+00, 0.28118500E-01, 0.16286700E-01, 0.22703200E+00, 0.43454200E-01, -.12193000E+01, -.24231300E+01, 0.49973400E-01, 0.24373200E+00, -.28251600E+01, 0.26764300E+00, -.64558400E-01, 0.14181100E+01, 0.53079300E+00, -.11748400E+00, -.15961700E-02, -.21913800E+00, 0.98827100E+00, -.15877600E+00, 0.41618600E+00, 0.33301800E+00, 0.19053000E+00, -.39176100E-01, -.66233500E+00, 0.78932700E-02, -.25289400E+00, 0.78083000E+00, 0.14607200E-01, -.30644600E-01, 0.56187400E+00, 0.32879600E+00, -.20686100E+00, 0.97465200E+00, -.89829700E-01, -.32097300E+00, -.15680500E-01, 0.24290800E+00, 0.81138200E+00, 0.12482900E+00, -.34225900E+00, -.18797500E+01, -.23237600E+00, -.16909500E+00, 0.13358900E-02, -.24940800E+00, 0.16859500E+00, 0.33578900E-01, -.62485000E+00, 0.12857100E+00, -.54946200E-01, 0.40037900E-01, 0.36461100E+00, 0.39461900E+00, 0.74463100E+00, -.61672500E-01, -.32607600E-01, -.19829700E+00, -.42391600E-01, 0.17185100E+00, -.69046500E-01, -.43811400E+00, 0.59580600E-01, 0.20654600E+01, -.12814700E+00, 0.86759900E-01, 0.65721700E+00, -.37575500E-01, 0.79137900E-01, 0.23870000E-02, 0.15933300E+00, 0.34712300E+00, -.10704500E+00, 0.26453800E+01, 0.21016600E+00, 0.40257100E+00, 0.25675100E+00, 0.12658700E+00, -.23016500E-01, -.82527600E-01, -.12641100E-01, -.31794400E+00, -.24791500E+00, -.15981400E+00, 0.29745800E+00, -.16742300E+01, -.80507300E-01, -.42563200E+00, -.17050100E-01, -.94457400E-02, -.32810200E+01, 0.14902400E+01, -.33640200E-01, -.18506600E+00, -.19514400E+00, -.18207000E+00, -.20314600E+00, 0.11766000E+00, 0.36452400E-01, -.27067200E+00, 0.48706400E-02, 0.36566100E-01, -.16606900E-01, -.19065600E+00, -.40070000E-01, 0.82358600E+00, -.12977900E-01, 0.30314000E+00, -.99497800E+00, -.23328000E-01, 0.19766600E+00, -.10793400E+00, 0.92318100E-01, -.54944100E-01, 0.12406100E+00, -.16721500E+00, 0.62392300E+00, -.54513900E+00, -.62158200E-01, -.11334400E+01, -.18887100E+00, -.52281300E+03, 0.23216400E+03, 0.10771700E+02, 0.26164000E+03, 0.12370900E+03, 0.15027800E+03, -.76496700E+02, -.97846200E+02, 0.50788700E+02, 0.16801100E+03, 0.73306100E+03, 0.10529900E+02, 0.18583600E+01, 0.93903700E+02, -.59414000E+01, 0.16600000E+03, -.10854300E+03, -.19111600E+02, 0.81223900E+02, -.12724300E+03, -.50275900E+02, -.81849500E+02, -.57694500E+03, 0.42435700E+03, -.26699700E+02, 0.28822900E+03, -.14004800E+03, -.31088100E+02, 0.97257500E+02, -.16325800E+03, 0.11179800E+02, -.32674500E+02, 0.18797700E+03, -.18554900E+03, 0.11803500E+03, -.66513000E+02, 0.92644100E+02, -.29939300E+02, -.10431100E+03, 0.79103100E+02, 0.45673100E+01, 0.23022000E+02, -.67511800E+02, 0.22914800E+03, -.25802400E+03, 0.18218200E+03, 0.15434800E+02, 0.12836800E+03, -.10838500E+03, 0.66393700E+02, 0.95366800E+01, -.17476400E+03, -.82871400E+02, 0.37497300E+02, -.12652700E+03, 0.21550200E+03, -.14072800E+03, -.99854700E+02, -.10700200E+03, 0.14846000E+02, 0.36627500E+02, -.80341200E+01, 0.16861300E+02, 0.12521900E+03, -.17668700E+02, -.39238000E+02, 0.33999900E+02, -.28314800E+02, -.16620700E+03, -.17248100E+02, 0.28798700E+02, 0.53836900E+02, -.76446200E+02, 0.10593000E+03, 0.29624000E+03, 0.21790000E+02, 0.47796000E+01, 0.15479300E+03, -.68431100E+02, 0.19827800E+03, -.77325800E+02, 0.14693800E+02, 0.20434400E+02, 0.30420100E+02, 0.16131700E+03, -.12174300E+02, 0.67811100E+01, -.50598800E+02, 0.67720900E+03, -.31000200E+03, 0.60772500E+03, -.33964600E+03, 0.82699600E+02, -.16171200E+03, -.14778100E+03, 0.18534300E+03, -.39210100E+03, -.98517300E+02, -.20194700E+03, 0.20807700E+03, -.10283700E+03, -.10022000E+03, -.10352800E+03, -.48222300E+02, -.60114600E+02, -.74858600E+01, 0.83498200E+02, -.10212300E+03, -.68004100E+02, -.21238600E+03, 0.92754700E+01, -.48316400E+01, -.25404100E+00, 0.12217600E+02, 0.22979800E+01, -.30602600E+01, -.35172100E+02, 0.16296500E+01, 0.16435400E+01, 0.52871200E+02, -.62069000E+02, -.23432400E+02, 0.19420200E+02, -.24311800E+00, 0.30681000E+02, 0.56071900E+02, -.16789600E+02, -.28057900E+02, 0.19965700E+02, -.12010200E+03, -.83861300E+00, 0.44148800E+02, -.47115800E+02, 0.42156900E+02, 0.11251700E+03, 0.75861200E+02 },
        { 0.20455400E+02, -.62722400E+00, -.76109700E+00, -.26174200E+01, 0.16372600E+01, -.40170400E+01, -.77758500E+00, -.33877000E-02, 0.90270700E+00, -.29669300E+01, 0.10281800E+00, -.75664800E+00, -.35344700E+00, -.16961500E+00, -.91483200E-01, -.80672900E-01, -.91376000E+00, -.77022300E+00, 0.84255400E-01, -.16693900E+01, 0.41066500E+00, -.22444900E+00, -.14141800E+02, -.30542600E+00, -.88072300E+00, 0.13869800E-01, -.26140600E+00, -.24970200E+01, -.14805900E+01, 0.87834800E+00, -.42389000E+00, -.45761500E+00, 0.89288600E-01, -.20967900E+01, 0.11318300E+01, 0.62222400E+00, 0.15601000E+00, 0.24527300E+01, -.48475400E+00, 0.10387900E+01, -.64847200E+00, -.97961100E+00, 0.23504500E-01, 0.18258500E+01, -.17236600E+01, 0.12111600E+00, -.10581800E+01, -.63581500E-02, 0.67142300E+00, -.22209900E+00, -.45830000E+00, -.19796300E+01, 0.13131900E+00, -.20484500E+00, 0.44749500E+00, 0.70519700E+00, 0.88606300E-02, -.12428000E+01, -.21480500E+00, 0.15400200E+00, 0.59127600E+00, 0.34315900E-01, -.76201800E+00, -.22202300E+00, -.83386800E-01, -.47069000E+00, -.17060500E+00, 0.30477200E-01, -.31550100E+01, 0.34874300E-02, 0.33495000E+00, 0.22475700E+00, 0.14845000E-01, -.31504400E+00, 0.28538100E+01, 0.92340100E+00, -.18074500E+00, -.34663800E+01, 0.82533400E+00, -.71882900E+00, -.37263600E-01, 0.68452500E+00, 0.74979400E-01, 0.72005400E+00, -.85598500E+00, -.12558400E+02, -.51555400E+00, -.38212300E+00, 0.60313200E-01, -.13892700E+01, 0.26435200E-01, 0.52891400E-01, 0.52531200E+00, 0.28159800E+00, -.21210700E+00, 0.12053800E+01, -.34199600E-01, 0.32039300E+00, 0.60122100E+00, -.42298400E+00, -.10493400E+00, 0.18867100E+00, 0.17489600E+00, 0.62191400E+00, -.23354700E+00, -.40928400E+00, -.16536300E+00, -.25031900E+01, 0.76340900E-01, -.64447600E-01, 0.16588100E+01, -.14769400E+00, 0.27086900E+00, -.45158100E-02, -.73555400E+00, 0.49006100E+00, -.22093000E+00, 0.24616100E+01, -.54817200E+00, 0.12655500E+01, 0.11053800E+00, 0.24339800E+00, -.79686900E-02, -.40555000E+00, -.44823800E-01, 0.96699500E+00, 0.84625000E-01, 0.98496500E+00, -.31152700E+00, 0.13604500E+00, -.41299400E+01, -.86678100E-01, 0.40609900E+00, -.50352600E-01, -.33348900E+01, -.46178900E+01, 0.26095100E-01, 0.51226700E+00, 0.36386900E+00, 0.12017400E+01, -.73593000E+00, -.13084400E+01, -.52452500E-01, 0.14401800E+00, -.66480900E-01, 0.60294500E+00, 0.68272500E-01, -.24919200E+01, 0.18006300E-01, -.15516600E-01, 0.54895800E+00, 0.48004000E+00, -.16763800E+01, 0.67088800E-01, 0.63040600E-01, -.59969500E+00, -.45180000E+00, 0.10279500E+00, -.96309800E+00, -.28606700E+00, -.13135000E+01, -.25285900E+00, -.81575200E+00, 0.21654500E+01, -.65234200E+00, -.44042900E+00, 0.77919400E+02, 0.24180200E+03, 0.15885700E+01, 0.24682600E+02, -.13105200E+03, 0.20942700E+03, 0.12807400E+03, 0.19237500E+03, -.18284600E+03, -.18031700E+03, 0.12746500E+03, -.86178300E+02, 0.84478900E+02, -.65066900E+02, 0.14882200E+02, 0.49723800E+02, -.10284200E+03, -.21343000E+02, 0.12723300E+03, 0.35397200E+02, -.33015300E+03, 0.84617400E+03, -.76791800E+03, 0.98314200E+02, -.42373700E+03, 0.11052200E+03, -.10877800E+03, -.23087700E+03, 0.10725800E+03, -.77458000E+02, -.96182200E+02, -.67240800E+03, 0.18195400E+03, -.14897100E+03, -.13196400E+03, -.91346400E+02, 0.20238200E+02, -.31398100E+02, -.92918400E+02, -.21302700E+03, -.18658800E+03, 0.19061600E+02, -.25821800E+03, 0.12489700E+03, -.20194500E+03, 0.40603000E+03, -.63944600E+02, 0.14079900E+02, -.23992500E+03, -.30698200E+02, 0.36225200E+02, 0.83084500E+02, -.20713300E+03, -.43693900E+03, 0.11528300E+03, 0.30268000E+02, 0.10053400E+03, -.56144200E+02, -.63096300E+02, -.10852900E+03, -.18417100E+02, -.70213800E+02, -.23921100E+03, -.10281700E+03, -.12666500E+03, 0.31110100E+02, 0.18133700E+02, 0.12895500E+03, -.16238300E+02, -.11156900E+03, -.99271100E+02, 0.80931300E+02, -.59358300E+00, -.22607000E+03, -.65113700E+02, -.32195000E+03, -.15286600E+04, 0.79314100E+03, 0.84191300E+03, 0.76428200E+03, 0.27580100E+02, -.17450400E+03, 0.57295900E+03, 0.24676900E+03, 0.57895800E+03, -.17675500E+03, 0.56580600E+03, 0.36099400E+03, -.24411600E+03, -.33783100E+03, -.18298800E+03, -.11939300E+03, 0.62220700E+02, -.15417000E+03, -.23296200E+03, -.10685000E+03, 0.80108700E+02, -.18373900E+03, 0.49368900E+03, -.22045500E+03, -.32265800E+03, -.24504000E+03, 0.71653600E+02, 0.16907900E+03, -.37168000E+03, -.40607900E+03, -.31457200E+03, 0.17912400E+03, -.22221500E+03, -.48390100E+00, 0.10346700E+02, -.81644300E+01, 0.37559600E+01, 0.31109700E+01, -.10375800E+02, 0.14592200E+02, -.74920600E+00, 0.11199100E+02, -.42104600E+02, 0.39486400E+02, 0.29254600E+02, -.42540400E+02, -.25382200E+02, -.20056800E+02, -.37433100E+02, 0.19787800E+02, 0.47990300E+01, -.83244000E+02, -.51064700E+02, 0.42065300E+02, -.42981300E+02, 0.33602000E+02, -.10913100E+03, -.12828500E+03, -.70500600E+02 },
        { 0.28413900E+01, -.14885100E+00, -.13139200E+00, -.18959100E+01, 0.61490100E+00, -.11497200E+01, 0.82193200E+00, -.95683200E+00, 0.45067800E+00, -.74513300E+00, -.34942000E-01, 0.73832200E+00, 0.42516000E-01, 0.18309400E-01, -.56144000E-01, -.13794900E+00, 0.92705600E-01, 0.37069400E+00, 0.77215800E+00, -.24873100E+00, -.26161900E+00, 0.91817600E-01, 0.25823100E+01, -.65622400E+00, -.42047300E-01, 0.94250200E-01, -.53598000E-01, -.11760000E+00, -.90265800E+00, 0.39871600E+00, -.98555300E+00, -.68599400E+00, 0.78718000E-01, 0.33986900E+00, 0.55326000E+00, -.68815800E-01, 0.19346700E-01, 0.59674100E+00, 0.22851400E-01, -.20515300E+00, 0.22025200E+00, 0.11605300E-01, -.76636500E-01, 0.25834300E-01, 0.51491400E+00, 0.22915400E+00, 0.68125400E-01, -.10001800E-01, 0.74307000E-01, -.10126800E+00, 0.34738300E+00, 0.54808000E+01, -.31839500E+00, 0.33199800E-01, -.16487700E+01, -.33703200E-01, -.35123200E-01, 0.95705700E+00, -.45175900E+00, -.66168300E-02, 0.92569000E-01, -.20489000E+00, 0.11150000E+01, -.12195800E+00, 0.10964100E+00, 0.40602900E+00, -.12019300E+00, -.14198200E-01, 0.84710400E-01, 0.32423200E-02, -.82462600E-01, 0.12465900E+00, -.12529100E+00, -.77761200E-01, 0.48689100E-01, 0.64097000E-01, 0.49081100E-01, 0.18582400E+00, -.28878000E+00, -.20070000E+00, -.21671600E-01, -.67271900E+00, -.19007800E-01, -.57859900E-01, -.63304400E+00, -.57713100E+00, -.15783000E+00, 0.22036800E-01, 0.31535300E+00, -.14652200E+00, 0.79134500E+00, -.21898600E-01, -.12721100E+01, -.38343700E-01, 0.16659600E-01, 0.19547200E-02, -.16257500E+00, -.33360400E+00, -.71815200E+00, 0.19285600E+00, -.14018900E-01, 0.74284200E+00, -.33280700E+00, -.46389000E+00, -.78615600E-01, 0.56342300E+00, -.29664900E-01, -.22866400E+01, -.10062600E+00, 0.11612100E+00, -.12051100E+01, 0.41234900E-01, -.92697400E-01, 0.21547100E-02, 0.49555900E-01, -.69242900E+00, -.49731500E-01, -.18694100E+01, 0.38035300E+00, -.27125400E+00, 0.14434900E+00, -.29671300E-01, -.51784100E-01, -.15153600E+00, 0.87916800E-02, 0.55862000E-01, -.14876000E+00, -.60182000E+00, 0.27507400E+00, -.14873300E+01, 0.19359800E+01, -.34860500E+00, 0.98248400E-01, -.59286600E-01, 0.15668200E+01, 0.14522200E+01, 0.26924400E-01, -.20791400E+00, -.78953600E+00, 0.59727600E-01, -.26418300E+00, 0.72274900E+00, -.11113400E+00, -.58671600E-01, -.16764900E-01, -.70874500E-01, -.23907800E-01, 0.67947300E+00, -.70247900E-01, -.59362600E-01, -.54209000E-01, 0.21437500E+00, -.30665400E+00, -.36599500E-01, -.13015000E+00, 0.61470000E-01, -.24703100E-01, 0.48032700E-01, 0.85416600E+00, -.29569900E+00, -.33083700E+00, -.10654900E+00, 0.51523500E-01, -.16920900E+00, 0.97017700E-01, 0.39917500E+00, -.77980800E-01, -.71511400E+02, 0.98435500E-01, 0.45050200E+02, 0.40962000E+01, -.15336400E+02, -.31032500E+02, -.37348400E+02, 0.19544400E+02, -.11836000E+03, -.93523500E+02, 0.44047200E+02, 0.21343400E+02, 0.46790100E+02, -.21780000E+00, 0.12037000E+02, 0.30470600E+02, -.54999500E+01, 0.37813500E+01, 0.89581400E+01, 0.10790100E+03, -.15819300E+03, 0.79425500E+02, 0.12919000E+02, 0.79088200E+02, 0.29631900E+02, -.21717400E+02, 0.55631600E+02, 0.47899300E+02, 0.62037800E+02, -.39468300E+02, 0.19567100E+03, -.16317700E+01, 0.35841300E+01, 0.71993100E+02, 0.80525000E+00, -.46589400E+01, -.79468900E+01, 0.17879200E+02, 0.15770700E+02, -.63260100E+01, -.49831200E+01, 0.21898800E+02, -.99065500E+02, 0.51482700E+02, 0.21574000E+01, 0.49536600E+02, 0.30965200E+02, 0.12078100E+02, 0.23255900E+02, 0.14873700E+02, 0.13919100E+02, -.13688100E+02, 0.12064500E+03, 0.13620100E+03, -.67298900E+02, -.10889800E+03, -.68129500E+02, -.31565500E+02, -.26372100E+02, 0.12042900E+02, 0.59775200E+02, -.10907000E+02, -.26896900E+02, -.58028500E+02, 0.17201600E+03, -.85783900E+02, -.58015100E+02, -.86016400E+02, -.19480800E+02, -.28444800E+02, -.15421400E+02, 0.44072000E+02, -.20414700E+02, -.32126800E+02, -.48763900E+02, -.18579500E+03, 0.93126500E+02, 0.10870000E+02, 0.92909200E+02, -.59991700E+00, -.18066800E+02, 0.42462200E+02, -.40474800E+02, 0.51553300E+02, -.13255600E+02, 0.38978700E+02, -.14888900E+03, 0.73310800E+02, 0.81365700E+02, 0.74443300E+02, -.16129800E+02, 0.47875600E+02, -.17074000E+01, -.79362500E+02, -.88599700E+01, 0.43861000E+02, 0.11487500E+03, -.34616800E+02, 0.16307900E+02, 0.44633800E+02, 0.17376000E+02, 0.21421200E+02, 0.17523100E+02, 0.91240000E+01, 0.10875400E+02, 0.10395900E+02, 0.12510300E+02, -.15207900E+00, -.40607400E+01, -.17131400E+01, -.84539500E+00, -.13445100E+00, 0.92563100E+00, -.43133300E+00, 0.11167400E+01, 0.83339000E-01, 0.78812000E-01, 0.26852100E+02, -.23873400E+02, -.48772900E+01, 0.32994300E+00, -.26376300E+01, -.16314700E+01, 0.23280400E+02, -.53190100E+01, -.24687000E+01, 0.14807700E+02, 0.13761000E+02, -.14201600E+02, 0.24023700E+00, 0.85779300E+00, 0.31535600E+02, -.14189400E+01, 0.26545200E+02 },
        { 0.25172400E+02, -.53199500E+00, -.90435000E+00, 0.43834000E+01, 0.29786900E+01, -.45961600E+01, 0.25700700E+01, -.20015900E+01, -.71249200E+00, -.36135500E+01, 0.16610400E+00, 0.57496200E+01, -.10267200E+00, 0.15524200E-01, 0.12048800E+01, -.12990300E+01, 0.21717700E+01, 0.73003500E+00, 0.32402200E+01, -.22915100E+01, -.10594400E+01, 0.98420400E-01, 0.43657800E+01, -.72881100E+00, -.43872900E+00, 0.36231700E+00, -.12903300E+01, -.10521600E+01, -.26849100E+01, -.15207800E+01, -.19385400E+01, -.32265800E+01, 0.89623100E-01, 0.25153900E+00, 0.30721600E+01, 0.49124200E+00, -.22684000E-02, 0.53479900E+00, -.43543700E-01, 0.74598200E+00, -.80593100E+00, 0.20749500E+01, -.26287100E+00, -.12087400E+01, 0.11233400E+01, 0.30092500E+00, 0.68907000E+00, -.43063100E-01, 0.12278300E+01, -.10877300E+00, 0.18555000E+01, 0.20291600E+01, -.21919000E+00, 0.10118600E+00, -.56773300E+01, 0.80382400E+00, -.13029700E+00, 0.25567400E+01, -.49921600E+00, 0.99450400E-01, -.16400900E+00, -.66061300E+00, 0.24368600E+01, -.27929500E-01, 0.11168800E+00, 0.73839400E+00, -.16526400E+00, -.53838600E-01, 0.18281200E+01, -.63771800E-03, -.39480200E+00, 0.51590600E+00, 0.82103100E-01, 0.15236200E-01, -.22499600E+01, -.20890800E+00, 0.70103500E+00, 0.64526400E+01, -.84885100E+00, -.17712800E+00, -.74034800E-01, 0.35769600E-01, -.44061400E+00, 0.27073400E+00, -.36214400E+00, 0.30517400E-01, 0.26509100E+00, 0.42380000E+00, 0.72167700E+00, 0.83676900E+00, 0.13240400E+01, -.18708200E+00, -.57683400E+00, -.23570700E+00, 0.23632800E+00, -.48292700E-01, 0.29435500E+00, -.68708200E+00, -.18998800E+01, 0.79631000E+00, -.17363100E-01, 0.53176700E+00, -.64787800E+00, -.76624900E+00, 0.10801200E+00, 0.13776100E+01, -.25396200E-01, -.26612000E+01, -.24380600E+00, 0.26532300E+00, -.11760400E+01, 0.35465300E-01, -.62442400E+00, -.15139200E-01, 0.30890700E+00, -.20345700E+01, -.22227300E-01, -.41336100E+00, 0.19687600E+00, 0.21816600E+01, 0.12967100E-01, 0.19018000E-01, -.16622100E-01, 0.32903400E+00, 0.28330400E-01, 0.61064900E-02, -.35002000E-01, -.89290100E+00, -.39694600E-02, -.13412700E+01, 0.50004100E+01, -.19746000E+00, -.52686500E-01, 0.80602700E-02, 0.62883200E+01, -.18297900E+01, 0.17799200E+00, 0.12653800E+00, 0.25392500E+00, 0.71177200E+00, -.34352800E+00, 0.70119400E+00, -.10749600E+00, -.13290300E+01, -.31207800E-01, 0.24033400E+00, -.13894600E+00, 0.14958400E+00, -.35231700E-02, 0.13542200E+01, -.13204900E+00, 0.98066700E+00, -.17246900E+01, -.50798100E+00, -.59938400E+00, -.10955400E+00, -.82073500E-01, 0.87524100E-01, 0.27993300E+01, 0.25790700E+00, -.85131900E+00, 0.44073000E+00, -.73688900E-01, -.79948500E+00, 0.31367700E-01, 0.48735100E-01, 0.20921100E+00, 0.11640300E+01, 0.24430100E+01, 0.72547100E+02, 0.24186200E+03, -.20656300E+03, -.17366800E+03, -.39763000E+03, 0.20345000E+03, 0.35317700E+03, 0.15623200E+03, -.63729000E+02, -.59991900E+02, -.77235800E+02, -.22068100E+02, -.26268500E+02, -.58736600E+02, -.57990500E+01, -.74014400E+02, 0.17521800E+02, -.68041400E+02, 0.60980100E+03, -.29625100E+03, -.27135700E+03, -.30456500E+03, -.26296300E+03, 0.10873800E+03, -.33026900E+03, -.37651400E+03, -.19269200E+03, 0.12212200E+03, -.47990600E+02, -.44704200E+02, 0.49718600E+02, 0.69539800E+01, 0.22516800E+02, -.13065400E+02, 0.32986200E+01, -.21569700E+02, -.10739300E+02, 0.14868300E+02, 0.12709300E+01, 0.10684500E+03, 0.38972900E+03, -.20092000E+03, -.21920800E+03, -.19402900E+03, -.23989300E+03, 0.99047200E+02, -.24845600E+03, -.35035800E+03, -.18610600E+03, 0.15529500E+03, -.39870800E+02, -.12338700E+04, 0.61390800E+03, 0.56399200E+03, 0.61596000E+03, 0.15305400E+03, 0.91102900E+02, 0.24510000E+03, -.40133900E+03, 0.13941300E+03, 0.73772600E+02, 0.16349100E+03, -.65886500E+03, 0.33103800E+03, 0.21316000E+03, 0.32978100E+03, 0.10489700E+03, 0.60287400E+02, 0.10651400E+03, -.13314400E+03, 0.15485100E+03, 0.74023800E+02, 0.11799300E+03, 0.23586200E+03, -.12450800E+03, 0.17570500E+03, -.11810800E+03, 0.41757100E+02, 0.98561100E+02, -.94433400E+02, -.61648700E+02, -.13246900E+03, 0.97135100E+02, -.20904300E+03, 0.32896800E+03, -.15467800E+03, 0.22759900E+02, -.16322300E+03, -.76613500E+02, -.15485700E+03, 0.10913500E+03, 0.32786500E+03, 0.29727200E+02, -.12299000E+03, -.65474300E+02, -.17595500E+02, 0.12253700E+02, -.10706500E+03, 0.81353200E+01, -.14070800E+02, -.24617500E+02, -.10262000E+02, 0.44959500E+02, 0.66647000E+00, -.26870900E+02, 0.15928800E+03, 0.24286600E+01, 0.27825800E+01, 0.14344400E+02, -.26274400E+00, -.74465400E+01, 0.53951800E+01, -.62987800E+01, 0.31951600E+01, -.14734700E+02, 0.14097200E+02, -.17677400E+02, -.70206100E+01, 0.72600100E+01, 0.20717800E+02, 0.82181100E+00, 0.16863000E+02, -.30200600E+02, 0.13991600E+02, -.51264800E+02, 0.56589400E+02, 0.27973500E+02, -.81095100E+01, 0.31256700E+00, 0.28709600E+02, 0.11901900E+02, 0.26336000E+02 },
        { -.11763100E+02, 0.61912600E-01, 0.10910400E+01, -.11717200E+01, 0.30326900E+00, 0.80614500E-01, 0.23572600E+00, 0.58784900E+00, -.14859800E+00, -.51761500E+00, 0.17750300E+00, -.80208300E+00, -.84217600E-01, -.47684800E+00, 0.24411700E+00, -.56099800E-01, -.54568900E-01, 0.12057300E+01, 0.20010200E+00, -.23760900E+00, -.73348100E+00, 0.16141300E-01, 0.82847000E+01, 0.86826500E+00, 0.93480600E+00, 0.35224300E+00, 0.34544100E+00, -.46020600E+00, -.56279000E+00, 0.45928200E+00, -.13737500E+01, -.31323000E+01, 0.53953500E-01, -.38704300E+00, -.50248500E+01, 0.97738600E+00, -.30089800E-01, -.50210300E+00, 0.26178000E+00, -.49194800E+00, 0.28792100E-01, -.61715100E+00, -.41504300E+00, -.24576000E+00, -.20566900E+00, 0.39789900E+00, 0.26668900E+00, 0.10282600E-01, 0.39365800E+00, -.80609200E-01, -.22549900E+01, 0.50401400E+01, -.45905200E+00, -.15186000E+00, -.72231000E+00, -.66826300E+00, -.63666800E-01, 0.65008400E-01, -.44635900E-01, 0.16675800E-02, -.39323300E-01, -.16134500E+00, 0.55647500E+00, -.17851700E+00, -.83154200E+00, 0.12490300E+00, 0.11272700E+01, -.23375200E-01, -.14275400E+01, 0.52433600E-02, -.89489900E-01, 0.83664300E+00, 0.29945000E+00, -.42383000E+00, -.27982700E+00, 0.33215200E+00, 0.61614700E+00, 0.59767700E+01, -.63237700E+00, -.16114900E+00, -.52785700E-02, 0.68177000E+00, 0.21220500E+00, -.32451900E+00, -.41793000E+00, -.16240900E+01, -.18337800E+00, 0.18544700E+00, 0.32249900E+00, 0.21939800E+00, 0.86333700E+00, -.19821200E-02, -.24792200E+00, -.12416500E+00, -.41624300E-01, -.14257900E+00, 0.45810200E-01, -.18951000E+00, -.53172500E+00, 0.58286500E+00, -.14079800E-01, 0.84570600E+00, -.52750200E+00, -.40555900E+00, -.19419200E+00, 0.41003400E+00, -.98596200E-01, -.55623300E+01, 0.72055500E-01, 0.14356500E+00, 0.10630400E+01, 0.85391100E-01, 0.47470400E+00, -.54668600E-02, -.39520800E+00, -.10901400E+01, 0.63288100E-01, 0.20909000E+01, 0.63683000E-01, 0.20325800E+00, -.36743700E+00, 0.19750500E-01, -.13017400E-01, 0.44111000E+00, -.98077200E-02, 0.52873800E+00, 0.16421400E+00, -.50239200E+00, -.82301200E-01, -.21164900E+00, -.14014700E+01, 0.43189900E+00, 0.41081000E+00, -.75830600E-02, 0.56789600E+01, -.13933100E+00, -.75398700E-01, -.27682100E+00, -.16487700E+01, 0.95220100E+00, -.28411100E+00, 0.73339600E+00, 0.98825200E-01, -.78850300E+00, -.12925700E-01, -.24245800E+00, -.24509900E-01, -.15809900E+00, 0.16848700E+00, 0.60231200E+00, 0.73765100E-01, -.12303700E-01, 0.66513900E+00, 0.79886200E-01, 0.18130000E+00, -.13381100E-01, 0.37633000E+00, -.25163100E-01, -.13258900E+00, -.11782700E-01, 0.16554300E+00, 0.12320200E+00, 0.25760200E+00, -.10531300E+01, 0.86169500E-01, 0.39295900E+00, 0.47442000E-01, -.17551300E+01, -.20448200E+00, 0.13076500E+03, 0.95638400E+02, -.98532900E+02, -.16352000E+03, -.16510600E+03, 0.12348800E+03, -.19412700E+03, -.17672800E+03, 0.95078500E+02, -.33456600E+02, 0.89409400E+02, -.74440900E+02, 0.17031100E+02, 0.36865200E+02, -.56749600E+02, -.24290900E+02, 0.17531900E+02, 0.26049700E+03, 0.20898100E+03, -.10293500E+03, -.23721100E+03, -.10408900E+03, -.57169500E+02, 0.35001600E+02, -.12436400E+03, -.37084700E+02, -.81681900E+02, 0.38510200E+02, 0.33395500E+03, 0.54697000E+02, 0.21598600E+01, 0.16821700E+03, -.27152100E+02, -.68151300E+01, 0.88216600E+01, -.51891800E+01, 0.53764700E+02, -.15014100E+02, -.21472500E+01, 0.66832100E+02, 0.22646500E+03, -.11267400E+03, -.31147600E+03, -.11220800E+03, -.61272800E+02, 0.86334500E+02, -.14259200E+03, -.84468100E+02, -.15093300E+03, 0.91623500E+02, 0.26662400E+03, 0.74974200E+02, -.38769400E+02, -.11596200E+03, -.38647200E+02, -.96697800E+01, -.35472600E+02, 0.71406500E+02, 0.26891100E+02, 0.61489400E+01, -.36202100E+02, -.26567400E+03, 0.20850200E+03, -.10436800E+03, -.21138700E+03, -.10382900E+03, -.89356700E+01, -.40120800E+02, 0.15515800E+02, 0.36396600E+02, -.80598300E+01, -.52468500E+02, -.89274300E+02, -.25890300E+02, 0.58058100E+01, -.18751700E+03, 0.12933900E+02, -.60890500E+01, -.17765400E+01, -.15633600E+02, -.11359400E+03, -.15847100E+02, 0.21864000E+02, -.10327500E+03, -.37303300E+03, 0.19117000E+03, 0.17486600E+03, 0.18814800E+03, -.52837700E+02, 0.11266800E+03, 0.62593200E+01, -.12125100E+03, -.22279700E+02, 0.10051200E+03, 0.25020100E+03, -.14764100E+03, 0.68260400E+02, 0.15842100E+03, 0.73004100E+02, 0.50285700E+02, 0.37769800E+02, 0.23903100E+02, 0.45288000E+02, 0.43532800E+02, 0.22887700E+02, 0.13300900E+03, -.80362000E+01, -.76555400E+01, 0.71673400E+01, -.32873500E+01, -.54358200E+01, 0.76463200E+01, 0.90936600E+01, 0.10556400E+01, -.11641700E+02, 0.35563700E+02, -.30221000E+02, -.15748200E+01, 0.96719300E+01, 0.10149800E+02, -.11805700E+02, 0.27886700E+02, -.11418500E+01, 0.44554200E+01, -.53615400E+01, 0.90856500E+02, -.19047000E+02, -.44680500E+01, 0.82620500E+01, 0.61449500E+02, -.39377100E+01, 0.37977900E+02 },
        { -.10151400E+02, 0.12273700E+00, 0.33805900E+00, -.19821400E+01, -.11008700E+01, 0.37096100E+00, -.29270900E-01, 0.37667700E+00, -.25509400E+01, 0.11429600E+00, -.68688200E-01, 0.70752100E+00, 0.13168300E-01, -.79870100E-01, -.27720100E+00, 0.14089600E+00, 0.32704500E+00, -.23671100E+00, 0.49936000E+00, 0.41055900E+00, -.27400300E+00, 0.19074200E+00, -.52742900E+01, -.12643100E+01, 0.13775700E+00, 0.13234000E-01, 0.33375900E+00, 0.41056200E+00, -.82736600E-01, -.11693600E+01, -.78974700E-01, -.11554000E+01, -.23684700E-01, 0.83729400E+00, 0.50706100E+00, -.70667400E-01, -.12126100E+00, -.21043100E+00, -.46233900E+00, 0.71220400E+00, -.16388800E-01, 0.17673900E+01, 0.13853400E+00, -.13340700E+00, 0.74997500E-01, 0.36599300E-02, -.22452000E+00, 0.62290200E-02, -.25561000E+00, -.31918300E-01, 0.44610200E+00, 0.25050300E+01, 0.40389900E+00, -.16308100E+00, -.39365200E+01, 0.89405000E+00, 0.67397000E-01, 0.68116100E+00, 0.21886300E-01, -.18192900E+00, -.15538900E+00, 0.72896000E+00, 0.41737300E+00, 0.66065400E-01, 0.29187500E-01, -.47276400E-01, -.78355800E-01, 0.12366200E-01, -.68412900E+00, 0.35944100E-02, 0.88597400E-01, 0.26253600E+00, 0.87900400E-01, -.45673800E-02, 0.49769800E+00, 0.53637600E-01, -.75449800E-01, 0.10940000E+01, -.40742900E+00, -.43427300E+00, 0.11083500E-02, 0.20003800E+00, 0.15880000E+01, 0.27145100E+00, -.12401200E+00, -.51824300E+01, -.20720100E+00, 0.59348500E-01, 0.36749700E+00, -.47650100E-01, 0.61997600E+00, 0.17619100E-01, 0.28269400E-01, 0.43167500E-01, 0.56200600E-01, 0.18265700E+00, 0.33249300E+00, -.46604900E-01, -.80059000E+00, 0.40423000E+00, -.12792600E+00, 0.31445600E-01, -.59750600E-02, 0.38677800E+00, 0.22361800E-01, 0.37391600E+00, -.47737800E-01, -.14504600E+01, -.12801100E+00, 0.16448900E+00, 0.60851000E-01, -.35986000E-01, -.32869400E+00, -.67647800E-02, -.11103100E+00, -.10522900E+01, -.96044100E-01, -.33182600E+00, -.25373900E+00, 0.18340200E+01, 0.79316700E-02, -.12874900E+00, 0.22131800E-01, -.45879000E+00, -.24039600E-01, -.23401600E+00, 0.69036400E-01, 0.54837200E+00, -.34543700E+00, -.20588200E+01, 0.21366300E+00, 0.17652600E+00, -.82570300E-01, 0.85443900E-01, -.36577400E+00, -.80211900E+00, -.30056700E-01, 0.39693400E-01, 0.12798300E+01, -.15545300E+00, -.49969900E+00, -.87994200E+00, -.23223000E-01, -.45447000E+00, 0.61057200E-03, 0.24631400E+00, -.80771100E-02, -.19339200E+01, 0.73628100E-01, 0.16800200E+01, 0.13973900E+00, 0.52377100E+00, -.16472500E+00, -.85169300E-01, -.16172900E+00, -.16194300E+00, 0.22463000E-01, 0.54249500E-02, 0.18240900E+00, 0.17467000E+00, -.75862800E+00, -.86337900E-01, 0.12833400E+00, -.22315100E+00, -.94442500E-02, -.54745600E+00, 0.31231200E-01, 0.88801100E+00, -.97386500E-01, 0.85358300E-01, 0.11902900E+03, -.86868800E+02, 0.28967900E+02, -.24628900E+02, 0.86198300E+02, 0.39505200E+03, 0.91326200E+02, -.48314500E+02, 0.11740300E+03, -.45678000E+02, 0.13898300E+03, -.74999200E+02, -.38379500E+02, 0.53687800E+02, -.40963100E+02, -.50089400E+02, -.13452500E+03, 0.14246200E+03, -.78386100E+02, -.10671200E+03, -.71199700E+02, -.13622600E+03, -.22842900E+02, -.85839800E+02, -.15622800E+03, -.62223100E+02, 0.37611700E+01, -.22918700E+03, -.16257100E+03, 0.89908200E+02, -.80933900E+02, 0.81310600E+02, -.30917300E+02, -.70722400E+02, 0.41762300E+02, -.27094000E+02, 0.57403300E+02, -.67202400E+02, 0.14630900E+03, 0.11484600E+03, -.61301500E+02, -.95870200E+02, -.57387600E+02, -.12787300E+03, -.26356800E+02, -.57988600E+02, -.10497300E+03, -.20573000E+02, 0.49172300E+01, -.21563800E+03, -.29523600E+03, 0.14987400E+03, 0.16619100E+03, 0.14763000E+03, 0.68516900E+02, 0.87469600E+02, -.27813000E+02, -.12039500E+03, 0.11178600E+03, 0.47562800E+02, 0.25274600E+03, -.23818200E+02, 0.15546200E+02, -.66588200E+02, 0.11944300E+02, -.93173800E+01, 0.31375000E+02, -.51418600E+02, 0.23948700E+02, 0.96299200E+02, 0.27309700E+02, 0.98077400E+01, 0.17709400E+03, -.87006900E+02, 0.24653800E+03, -.88512500E+02, 0.22927500E+02, 0.44462500E+02, -.93249200E+01, 0.10064400E+03, -.42275300E+02, 0.40401600E+02, -.72048300E+02, 0.38023200E+03, -.19051100E+03, 0.39113900E+03, -.19003900E+03, 0.13330900E+03, -.11338600E+03, -.68427900E+02, 0.17527500E+03, -.10140700E+03, -.66862300E+02, -.51279600E+02, 0.86265100E+02, -.38766700E+02, -.12002500E+03, -.43326100E+02, -.42389800E+02, -.56403100E+02, 0.34847700E+02, 0.59621400E+02, -.39280100E+01, -.49113100E+02, -.80729300E+02, 0.96663500E+01, -.19114300E+00, 0.13264200E+01, 0.69596500E+01, -.11252500E+01, 0.14789500E+01, -.13057300E+02, 0.23876200E+01, -.28501600E+00, 0.35495000E+02, -.40473200E+02, 0.60712600E+01, 0.10352700E+02, 0.68622700E+01, 0.93962700E+01, 0.38586300E+02, -.85792800E+01, -.19032000E+02, -.34919700E+02, -.61436400E+02, 0.24393400E+02, 0.90713600E+01, -.20859000E+02, 0.31997200E+02, 0.70058400E+02, 0.43025000E+02 },
        { -.13711400E+01, 0.26964300E-01, 0.57740300E-01, -.80004900E-01, -.22681500E+00, 0.49332800E+00, -.15037100E+00, 0.19122100E+00, -.31120800E+00, 0.54429100E+00, -.35582500E-02, -.26994700E-01, -.19336000E+00, -.54664300E-01, -.26679100E+00, 0.32517600E-01, -.10379800E+00, -.83248800E-01, 0.77539300E-01, 0.39858700E+00, 0.16308900E+00, 0.11001600E+00, -.41897400E+01, -.47879200E+00, 0.25565900E-01, 0.49819500E-01, -.72483500E-01, 0.17305200E+00, 0.50180100E+00, 0.40996500E+00, 0.36999800E+00, 0.34469800E+00, -.43340200E-01, 0.83405400E-01, -.58213000E+00, -.54453200E-01, -.12399500E-01, -.14652600E+00, 0.11708500E+00, -.31150800E+00, -.90273800E-02, 0.47729300E+00, -.60392300E-01, -.27449700E+00, 0.10400400E+00, -.40430500E-01, 0.40853400E-01, 0.54600200E-02, -.60403300E-01, -.99805300E-02, -.42302100E+00, 0.28960600E+00, -.26078000E-01, -.80962600E-01, -.96831000E+00, 0.50117900E-01, 0.13197700E-01, 0.37896900E+00, 0.16146200E+00, -.26004200E-01, -.21395200E+00, -.47363400E-01, -.19754200E-01, 0.26485600E-01, -.49732200E-01, 0.48708300E-01, 0.32889600E-01, -.78630800E-02, 0.17384100E+00, 0.49767900E-06, -.44655000E-01, 0.10704000E-02, -.22123800E-01, 0.93211200E-02, -.24633500E-02, 0.75827600E-01, 0.83796400E-01, 0.11300100E+01, 0.11853500E-01, 0.80816900E-01, 0.12342300E-01, -.11847000E-01, -.25355200E-02, 0.30391000E-01, 0.31181300E-01, -.12939000E+01, -.56970400E-01, 0.30241300E-01, 0.22739800E+00, -.95577700E-01, -.15559000E+00, 0.15404600E-01, 0.69634700E+00, 0.63984800E-02, 0.31194300E-01, -.10239800E+00, -.14056400E+00, -.50574500E-01, -.28200000E+00, 0.30608300E-01, -.53511900E-02, 0.52683600E-01, 0.21958000E-01, -.26986800E-01, -.18500700E-01, 0.80170400E-01, -.25052500E-01, -.15944300E+00, 0.35715700E-02, -.21340800E-01, 0.47435300E+00, -.31277000E-01, -.76436800E-01, -.39868400E-02, -.20273600E+00, 0.17815500E+00, -.50660400E-01, 0.86196000E+00, -.93031100E-01, 0.22533100E+00, 0.22175200E-01, 0.14505000E-01, 0.47240500E-02, 0.42020100E-02, -.28567500E-02, 0.19124800E+00, 0.45317700E-01, 0.13377000E-02, -.41694900E-01, 0.37506800E+00, -.21638000E+01, 0.12732200E+00, 0.21167700E+00, -.11532800E-01, -.90251400E-01, -.27202400E+00, 0.25533800E-01, 0.58694200E-01, -.50661500E+00, 0.18612900E+00, 0.15136500E+00, 0.86969900E-01, 0.59268200E-01, -.81572300E-01, -.76742400E-02, -.11238800E-01, 0.95445700E-02, -.22542000E+00, 0.50457400E-02, -.43300100E+00, -.34386300E-01, -.81386400E-01, -.10141100E+00, -.30458100E-01, 0.50623900E-02, -.46165600E-01, 0.48705400E-02, -.13054700E-01, -.37995300E-01, 0.46489400E-01, -.28047000E+00, 0.40866700E-01, 0.39333600E-02, 0.70994700E-01, -.21675600E-01, -.88203600E-01, 0.71294400E-02, -.20410700E-01, -.18876700E-01, -.29094000E-01, 0.10061400E+00, 0.19900500E+02, -.60792100E+01, -.19807700E+02, -.28870700E+01, -.18888000E+02, 0.48875500E+02, -.24976100E+02, 0.14817300E+02, -.24351900E+02, 0.25211000E+02, -.10762600E+02, -.13641700E+02, 0.64775800E+00, -.61687900E+01, -.38612800E+01, -.36332100E+02, 0.16632800E+02, -.70634100E+01, 0.97885000E+01, -.82844300E+01, -.10418600E+02, -.16710500E+02, -.64628800E+00, 0.25205400E+02, 0.23834500E+02, -.20464500E+02, -.47873500E+02, -.27696900E+02, 0.16525900E+02, 0.15218200E+02, 0.13860700E+02, -.20084800E+01, -.42695700E+01, 0.14787800E+02, -.74315300E+01, -.11645200E+00, 0.86144300E+00, 0.62560200E+01, -.57760600E+01, 0.37694500E+01, 0.79507300E+01, 0.29697000E+01, -.49342900E+01, -.23218600E+02, 0.66574600E+01, 0.19164300E+02, 0.20893800E+02, -.25751400E+02, -.29497700E+02, -.15232400E+03, 0.76154300E+02, 0.75106400E+02, 0.76067200E+02, 0.31860900E+01, 0.82085500E+01, 0.44928600E+02, -.56690400E+02, -.74275900E+01, 0.16563800E+02, 0.72877200E+02, -.13781600E+03, 0.68994800E+02, 0.81053500E+02, 0.68942400E+02, 0.95935500E+01, 0.77064200E+01, 0.29846400E+02, -.38563200E+02, 0.15923700E+02, 0.15960300E+02, 0.24794000E+02, 0.65204400E+01, -.39053700E+00, -.19511800E+01, -.32596500E+01, -.23415300E+01, -.42845100E+01, 0.28809000E+01, 0.10569300E+02, 0.46635100E+01, -.85666300E+01, 0.81214500E+01, 0.11452000E+03, -.57108000E+02, -.23248100E+02, -.57136500E+02, -.12028300E+02, -.40153700E+02, 0.19521900E+02, 0.44461100E+02, -.67254800E+01, -.35216800E+02, -.19598100E+02, -.44303900E+01, 0.27179200E+01, -.99647300E+01, 0.21771500E+01, -.94351500E+01, -.26046300E+02, 0.22208600E+02, 0.13476900E+02, 0.20873000E+02, -.22856400E+02, -.35618700E+02, 0.13064100E+01, 0.98368600E+00, -.18867300E+01, 0.74934900E+00, 0.19258600E+01, -.17904700E+01, -.61170700E+01, 0.55713200E-01, 0.19971200E+01, 0.39888600E+01, -.48702300E+01, -.22569300E+01, -.27397200E+01, -.12604800E+01, 0.47203100E+01, 0.46542100E+01, -.94028700E+00, -.47308000E+01, -.82064000E+01, -.14967200E+02, 0.26557600E+01, 0.41363900E+01, -.42554700E+01, 0.14699100E+01, 0.24550500E+01, 0.42067500E+01 },
        { 0.75711800E+01, -.12985000E+00, -.22073300E+00, 0.91700600E+00, 0.10237700E+01, -.59027200E+00, -.91826500E+00, -.29809700E+00, 0.49372900E+01, 0.26764500E+00, 0.77793100E-01, 0.13771900E+01, 0.19024400E+00, 0.68025800E-01, 0.63079700E+00, 0.21859700E-01, 0.13765200E+01, 0.12359200E+01, 0.79519700E+00, -.16423900E+01, 0.11529300E+00, -.30499300E+00, 0.13128900E+02, 0.18367700E+01, 0.22801000E+00, -.52491700E-01, -.43184900E-01, -.65851900E+00, -.82898400E+00, -.25774500E+00, -.11097900E+01, -.24623400E+01, 0.11782400E+00, 0.67360300E+00, -.26982300E+01, -.51731500E+00, -.24689800E-01, -.28243300E+00, 0.88037700E-01, -.10813300E+01, 0.37745200E+00, -.94285600E+00, -.16742000E+01, 0.56704300E+00, -.83625200E+00, 0.33813900E-02, -.21685200E+00, 0.36260800E-01, -.76831700E-01, 0.92494700E-01, -.84849200E+00, 0.20171800E+01, -.30914000E+00, 0.11014700E+00, 0.17468000E+01, -.10691000E+00, -.24858900E-03, -.54195000E+00, 0.49288200E+00, -.86038700E-01, 0.68562000E-01, 0.35860700E+00, -.44295900E+00, -.43253800E-01, 0.74722800E-01, -.11515700E+00, -.24112900E+00, 0.21096900E-01, -.98312900E+00, 0.19258200E-02, -.49629600E-01, -.26341600E+00, -.32827000E+00, 0.12965800E+00, 0.59666300E-04, 0.29581100E-01, -.45530100E+00, -.66277800E+00, -.10058900E+01, 0.69483800E+00, 0.20520800E-01, -.64352600E+00, -.97857700E+00, -.21832700E-01, -.68818400E-02, -.13555600E+01, 0.49718700E+00, 0.10178400E+00, 0.64963600E+00, 0.28810300E+00, -.96831700E+00, -.46978300E-01, 0.25326200E+01, 0.32092000E+00, -.30337800E+00, -.15951000E+00, -.29700700E+00, 0.16262200E+00, -.10835900E+00, -.81959000E-01, 0.19721500E+00, 0.20551600E+00, 0.29016400E+00, 0.58082500E+00, -.23003400E+00, -.74067600E+00, -.26194700E+00, 0.46650700E+00, 0.10668400E+00, -.17943200E+00, 0.59371700E+00, 0.67118600E-02, 0.93875500E-01, -.29106600E-01, -.30899600E+00, 0.22387500E+00, 0.22070100E+00, -.69178500E+01, -.41455600E+00, -.33620500E+00, -.48411000E+00, -.14537300E+00, 0.38917800E-01, -.32089700E+00, 0.29533600E-02, 0.30204000E+00, 0.15518900E+00, -.13652800E+00, -.62538300E-01, 0.21339300E+01, 0.41426700E+01, 0.15161100E+00, -.50509600E+00, 0.29919400E-01, 0.17367700E+01, -.66089900E+00, -.20477400E+00, -.32800500E-01, -.31768900E-01, -.63391400E+00, 0.32895300E+00, 0.31079300E-02, 0.47063500E-01, -.25130000E+00, -.29711100E-01, -.10821900E+00, -.34467100E-01, 0.26817600E+01, 0.31317700E+00, 0.59951300E-01, -.32106200E+00, 0.44077900E+00, 0.53600400E+00, -.31186600E-01, 0.95922300E-01, -.22649200E-01, -.29570100E+00, 0.26910000E-02, -.11485900E+01, 0.15161300E+00, 0.93244600E+00, -.23230400E+00, -.36148600E-01, 0.18707700E+00, 0.38240000E-01, -.79205600E+00, -.24215100E+00, -.39997400E-01, 0.30860500E+00, 0.54457700E+00, -.63236900E+00, 0.11598100E+01, 0.14679200E+03, 0.20309500E+03, -.18278600E+02, 0.41970500E+03, 0.16119900E+03, -.96977800E+02, 0.20771800E+03, -.82682600E+02, 0.22718000E+03, -.88310400E+02, -.82964100E+02, 0.10313700E+03, -.37507400E+02, -.59740500E+02, -.31280000E+03, -.13051400E+03, 0.65856900E+02, 0.40709000E+02, 0.64452600E+02, -.39278200E+02, -.44691100E+02, 0.32107200E+02, -.81494500E+02, -.60505300E+01, -.66996000E+02, -.26197100E+03, -.22546400E+03, 0.87563400E+02, -.17465400E+03, 0.11231400E+03, -.28187000E+02, -.11525700E+03, 0.63497400E+02, -.64174700E+02, 0.69856100E+02, -.79227000E+02, 0.12768700E+03, -.94757600E+02, 0.52070300E+02, 0.15082900E+03, 0.45336200E+02, -.39151400E+02, -.44471700E+02, 0.42573200E+02, -.27271500E+02, 0.24786200E+02, -.75977700E+02, -.34630700E+03, 0.83992400E+02, -.37058100E+02, -.40848700E+02, -.39683100E+02, 0.46966600E+02, 0.92156600E+02, -.13427200E+03, 0.51830000E+02, 0.14327100E+03, 0.30210200E+02, 0.41702700E+03, 0.68106900E+02, -.30985800E+02, -.99103500E+02, -.34887100E+02, -.47754900E+02, 0.47897600E+02, -.10270100E+03, 0.11448400E+03, 0.17086100E+03, 0.23721200E+02, 0.10687100E+03, 0.21063000E+03, -.88942400E+02, 0.40689500E+03, -.10514400E+03, 0.12772300E+02, 0.16747600E+02, 0.47416500E+02, 0.23914500E+03, -.33668600E+02, -.33445200E+01, -.14537800E+02, 0.75801000E+03, -.38495200E+03, 0.44613000E+03, -.38227400E+03, 0.15799900E+03, -.14516400E+03, -.21271000E+03, 0.13046100E+03, -.27349800E+03, -.81525500E+02, -.36968800E+03, 0.19287500E+03, -.86592500E+02, -.23648900E+03, -.94729900E+02, -.82214400E+02, -.98267600E+02, 0.14414100E+01, 0.65713800E+02, 0.10068800E+03, -.95273000E+02, -.21781700E+03, 0.16803300E+02, 0.20709100E+01, -.53535600E+01, 0.15252300E+02, 0.22786400E+01, -.50304100E+01, -.31476700E+02, 0.14428300E+01, 0.93007900E+01, 0.20460300E+02, -.25396300E+02, -.20507400E+01, 0.31135400E+01, -.10057300E+02, 0.25224300E+02, 0.26593300E+02, -.19069800E+00, -.31389100E+02, 0.61216600E+01, -.17189500E+03, 0.13318000E+02, 0.28420000E+02, -.34580900E+02, -.11548400E+02, 0.69740600E+02, 0.15963700E+02 },
        { 0.82706000E+00, -.52388700E-01, -.44366300E-01, -.53099700E+00, 0.12053700E+00, -.87220800E+00, 0.33226400E+00, -.24915200E+00, -.22535500E+00, -.39786800E+00, -.34703600E-01, 0.61589700E+00, 0.10480200E+00, 0.17855000E-02, 0.86232800E-01, -.63741000E-01, -.14688600E+00, -.99873300E-01, 0.89749700E-02, -.89303900E-01, -.28087400E+00, 0.17214000E+00, -.14120200E+00, -.11653400E+00, 0.46000700E-01, -.27499700E-01, 0.30627900E-01, -.78932500E-01, -.29582600E+00, 0.85906100E-01, -.24049700E+00, 0.32164400E+00, 0.54226400E-01, -.15079500E-01, 0.61638900E+00, 0.37887800E-01, 0.77298300E-02, -.34522100E+00, 0.22735100E+00, -.24633100E+00, -.49770700E-01, 0.13298400E+00, 0.20586600E+00, -.66220800E+00, 0.94511900E-02, 0.11817800E+00, 0.42253800E-01, 0.42880600E-02, 0.38967800E+00, -.89973400E-01, 0.30732700E+00, -.10670100E+01, 0.13796200E+00, 0.29172700E+00, -.54659000E+00, -.10276000E+00, -.66632700E-01, 0.40310400E+00, -.12612300E-01, 0.48508900E-01, -.10276100E+00, -.23670900E+00, 0.46890500E+00, -.15751200E+00, -.28145900E+00, 0.80565200E-01, -.74465900E+00, -.21523100E-02, -.79352500E+00, 0.17048900E-02, -.15383000E-01, 0.69128200E-01, -.39713700E-01, -.89648600E-02, -.54304500E-02, 0.30021800E-01, 0.28786300E-01, 0.21865400E+01, -.51157900E+00, 0.16617000E+00, 0.91397000E-02, 0.21544700E+00, -.24131400E+00, -.24304300E+00, -.60793200E-01, -.10797100E+00, 0.95699900E-01, 0.36943800E-01, 0.14112200E+00, 0.43428900E+00, 0.19191000E+00, 0.28377100E-01, 0.12979900E+00, 0.79223100E-02, 0.49928700E-01, -.74250400E-01, 0.85480300E-01, -.13933800E+00, 0.30047600E+00, 0.60395900E-02, 0.54335800E-01, 0.21350400E+00, -.15087600E+00, -.44413000E+00, -.18961900E-01, -.76771500E-01, 0.23151000E-01, -.34662800E+00, -.85556000E-01, 0.29951500E-01, 0.30550900E+00, 0.20996400E-01, 0.76439800E-02, 0.33658200E-02, -.15690200E+00, 0.63285000E-01, -.38389400E-01, 0.15004900E+01, 0.11887100E+00, -.31966500E+00, 0.60502700E-01, -.54363400E-02, -.10665300E-01, -.57660100E-01, 0.38842500E-02, 0.29551800E+00, -.41410300E-01, 0.63963300E-01, -.20700700E-01, -.42447400E+00, -.16953000E+00, 0.28099400E-01, -.10415300E+00, -.67071200E-02, 0.14380900E+00, 0.27890600E+00, -.24139000E-01, 0.27975100E-01, 0.37798200E+00, -.47194700E+00, -.45816100E+00, 0.27155800E+00, -.95669400E-01, 0.37150400E-01, -.47618500E-02, -.12023400E+00, -.73470000E-02, 0.14932000E+00, -.44085700E-01, -.39830300E+00, -.71960900E-02, 0.58587000E-01, -.17688000E+00, 0.20947200E-01, 0.10301400E+00, 0.70015100E-01, 0.99058600E-01, -.99018900E-02, -.12749300E+00, -.80548700E-01, 0.92328500E-01, 0.29043200E-01, 0.58017500E-01, -.33779400E-02, 0.45833600E-01, 0.14714800E+00, -.74337700E-01, 0.14562600E+00, -.38879300E-01, -.15196000E+00, 0.89277200E-01, -.18936800E+00, -.23760800E+00, 0.39521300E+02, 0.30616500E+01, 0.12788200E+01, 0.18128600E+02, -.12057300E+02, 0.44800200E+02, -.92091100E+01, 0.36586800E+02, -.15345600E+02, -.20906300E+02, 0.40452800E+01, -.15889800E+02, -.14040500E+02, -.24889800E+02, -.39981300E+02, 0.20930600E+02, 0.10267300E+02, 0.19934600E+02, -.47899700E+01, -.22556100E+02, 0.13236200E+02, 0.15390900E+02, 0.59983700E+01, -.35719400E+02, 0.58024200E+02, -.42912800E+02, 0.18959600E+02, 0.10194300E+02, 0.21425700E+02, -.90163500E+01, -.20202200E+02, 0.59967900E+01, -.14154900E+01, 0.30859400E+02, -.16062700E+02, 0.33038900E+02, -.73397100E+01, 0.57753400E+01, 0.13212400E+02, 0.35264700E+01, 0.92334900E+01, -.10402200E+01, 0.10680900E+02, 0.28971700E+02, -.10139400E+01, -.20247000E+02, 0.30652200E+02, 0.55977800E+02, -.27291200E+02, -.25428700E+02, -.27828100E+02, 0.84744100E+01, 0.15070500E+02, -.12417100E+02, 0.35956100E+02, 0.28801200E+02, 0.36990900E+01, 0.85977900E+02, 0.29687200E+02, -.15102400E+02, -.41405900E+02, -.14900900E+02, -.15295400E+02, 0.29959000E+00, 0.55021300E+01, 0.24327600E+02, 0.22982900E+02, -.73265600E+01, 0.48076800E+02, 0.88701500E+02, -.42831800E+02, -.17808600E+02, -.44338700E+02, -.76648000E+00, 0.81646800E+01, -.12533800E+02, 0.15872700E+02, -.32273200E+02, 0.95931900E+01, -.33402000E+02, 0.11177300E+03, -.57328800E+02, 0.59795800E+02, -.56121800E+02, 0.17421300E+02, -.14173000E+02, -.52278200E+02, 0.16740600E+01, -.61334700E+02, -.84637800E+01, -.69909100E+02, -.12234900E+02, 0.64726200E+01, 0.35539600E+01, 0.62403400E+01, -.14981000E+02, -.27244500E+02, 0.21184000E+02, 0.33641000E+02, 0.57170100E+02, -.30551100E+02, -.87619000E+00, 0.25057800E+01, -.14417600E+01, -.81000500E+00, 0.25017600E+01, 0.25991900E+00, -.98186800E+00, -.59382300E+01, 0.51589000E+00, 0.75991600E+00, 0.10714700E+02, -.96826900E+01, 0.21257800E+01, 0.13614300E+01, -.23799300E+01, 0.46073600E+01, 0.10556400E+02, 0.64215000E+01, -.86140600E+01, 0.60099000E+01, -.11981200E+02, -.66648000E+01, 0.68445800E+01, -.31411300E+01, 0.10044900E+02, 0.12687700E+02, 0.87459100E+01 },
        { -.13020700E+00, -.73805500E-01, -.76098000E-01, -.77094100E+00, 0.17965700E+00, -.16181000E+01, 0.10500800E+01, -.10372000E+01, 0.51244800E-01, -.62696500E+00, -.47075700E-02, 0.71759100E+00, 0.13162900E+00, -.20920100E-01, 0.34689000E+00, -.24251900E+00, -.57532200E+00, 0.25281900E+00, 0.70427400E+00, -.30286500E+00, -.91145300E+00, 0.84182100E-01, 0.84307100E+00, -.13846200E+00, 0.97725000E-01, 0.48558400E-01, -.24842600E+00, 0.10726800E+00, -.23533300E+00, -.17697600E+00, -.74584400E+00, -.98857000E-01, 0.81794500E-01, -.49762200E+00, 0.43421400E+00, 0.36720500E+00, 0.62870200E-01, -.65907600E+00, 0.25872300E+00, -.97824100E-01, -.14465500E+00, -.76994500E+00, -.45637400E-01, -.36390700E+00, 0.41640100E+00, 0.46557700E-01, 0.30135100E+00, -.23127100E-01, 0.75048900E-01, -.37049400E-01, 0.83190700E-01, 0.29538100E+00, -.18194900E+00, 0.17309400E+00, 0.12332300E+00, -.64261700E+00, -.73610100E-01, 0.52511000E+00, -.47156500E+00, 0.99735200E-01, 0.11164900E+00, -.72463800E+00, 0.53522900E+00, -.67209900E-01, -.17996000E-01, 0.34960800E+00, -.49852800E+00, -.13601400E-01, 0.23551100E+00, 0.85450000E-03, -.13582000E+00, 0.20905300E+00, 0.30706000E-01, -.48141700E-01, -.42607600E+00, -.14699900E+00, 0.48227000E+00, 0.37028900E+01, -.11140200E+01, 0.43774200E+00, 0.24101600E-01, -.44377300E+00, -.12355600E+01, 0.10296200E+00, 0.13746400E+00, 0.29749400E+00, 0.30046100E+00, 0.21340600E+00, 0.55207700E+00, 0.55467800E+00, 0.61597500E+00, -.98673500E-02, 0.63601600E+00, -.29134800E+00, 0.34786000E-01, 0.30900400E+00, 0.10410300E+00, -.21759200E+00, 0.11336200E+00, 0.10587900E+00, -.13082200E-01, 0.89913000E-01, -.12574000E+00, -.40673400E+00, -.33651200E-02, 0.43595500E+00, -.60158000E-01, -.23367700E+01, -.11046300E+00, 0.13796600E+00, 0.12113000E+01, 0.64651900E-01, 0.72742300E-01, -.43962200E-02, -.25008500E+00, -.84564900E+00, -.49911100E-01, -.19387800E+01, -.20401200E-02, -.28328800E+00, 0.17037300E+00, -.10950000E+00, -.22909400E-01, -.29076900E-01, -.11904600E-01, -.25190300E+00, -.61849500E-01, -.76072100E+00, 0.10178100E+00, -.74455900E+00, 0.71551500E+00, -.18564700E-01, 0.18337400E+00, 0.44434600E-01, 0.31578000E+01, 0.13869900E-01, -.64679900E-01, 0.63862200E-01, -.73175500E+00, -.67165200E+00, 0.56135400E+00, -.50787500E-01, -.49861300E-01, -.16823400E+00, -.28306500E-02, -.25208000E-01, -.11021400E-01, -.10576800E+00, -.25981600E-01, 0.80990000E-04, -.10304000E+00, 0.21598000E+00, -.65657200E+00, -.54746900E-01, -.14052300E+00, 0.39423600E-01, 0.55662900E-01, 0.47506300E-02, 0.64949900E+00, 0.18886400E+00, -.13160900E+00, -.16435400E-01, 0.11656200E+00, -.62298900E+00, 0.15554000E+00, -.13659300E-01, -.14377600E+00, 0.80569100E+00, 0.26794100E-01, 0.13872900E+00, 0.40898500E+00, 0.38258500E+00, -.73622200E-01, -.93989200E-01, 0.30735400E+02, 0.77933100E+02, 0.41409900E+02, -.17604200E+02, -.29033200E+02, -.21218000E+02, -.12384900E+02, 0.81609200E+01, -.34260800E+02, -.50013100E+00, -.70643300E+01, 0.31957800E+01, -.56409500E+02, 0.28869300E+02, -.65812500E+01, 0.25608800E+01, -.14640600E+02, -.73352200E+01, 0.45227200E+02, -.53283000E+02, -.10299500E+03, -.91210800E+02, 0.36057100E+02, 0.10387000E+02, 0.25394600E+02, -.18911700E+02, -.70872400E+02, -.12795700E+02, -.19730900E+01, -.80862900E+01, -.19770800E+02, -.86875200E+01, 0.58359500E+01, -.53522100E+01, -.26151000E+02, 0.79247700E+01, -.35762100E+01, 0.55940200E+02, -.44780700E+01, -.84349200E+01, 0.38933300E+02, -.28938000E+02, -.72333100E+02, -.77017200E+02, 0.39220400E+02, -.22291200E+02, 0.12764900E+03, -.65650800E+02, -.44480100E+02, -.63254500E+02, 0.10002500E+02, -.15153900E+02, -.18128900E+02, 0.55847800E+02, 0.55630600E+01, -.24956400E+02, -.56476900E+02, -.13872300E+03, 0.67965800E+02, 0.54662200E+02, 0.69142600E+02, 0.24390000E+02, 0.34639100E+02, 0.12658900E+02, -.12259800E+02, 0.48150300E+02, 0.18558400E+02, 0.68063500E+02, -.10410100E+02, 0.47316700E+01, 0.74492200E+01, 0.51819200E+01, 0.94486300E+01, 0.10740200E+02, 0.85021700E+01, 0.78666700E+01, -.87913200E+01, 0.15096300E+02, 0.98700600E+01, 0.65820000E+02, -.30616500E+02, -.38275700E+02, -.33735600E+02, -.27943400E+02, 0.52201000E+01, -.37739900E+02, 0.10359400E+02, -.23774800E+02, -.76849900E+01, -.65569400E+02, 0.66637500E+02, -.31658000E+02, -.83739400E+01, -.32906200E+02, -.56351200E+01, 0.15596100E+02, -.48486100E+02, -.14097600E+02, -.33335800E+02, 0.49003000E+01, 0.14383400E+02, 0.15347600E+01, 0.22047900E+00, 0.20025400E+01, 0.11493100E+01, -.51232200E+00, -.13013500E+01, -.25749400E+01, 0.64342700E+00, -.62880000E+00, -.13135500E+02, 0.13371900E+02, -.21066700E+01, -.10013300E+01, -.19056100E+01, 0.56510700E+01, -.11593200E+02, 0.36836700E+00, 0.68192000E+01, 0.12065900E+02, 0.14562200E+01, 0.57727900E+00, 0.23163700E+01, 0.72733300E+00, -.17061500E+02, -.16821300E+02, -.12817300E+02 },
        { -.11139000E+02, 0.35419600E+00, 0.38721700E+00, 0.18582300E+01, -.98307600E+00, 0.24335800E+01, -.25639700E+01, 0.11082600E+01, 0.14394100E+01, 0.21962000E+01, 0.16338700E-01, -.55184600E-01, -.13329300E+00, 0.12993700E-02, -.18480100E+00, 0.22591600E+00, 0.50201900E+00, -.14637700E+00, -.65884700E+00, 0.13052000E-01, 0.32139700E+00, -.23149600E+00, 0.29979000E+00, 0.12058300E+00, -.97160600E-01, -.13630300E+00, 0.14938000E+00, 0.80294800E-01, 0.51825900E+00, -.11005400E+01, 0.16247700E+00, 0.37833300E+00, -.45192000E-01, 0.10650500E+00, -.13572000E+00, -.28907800E+00, -.84561300E-01, -.12140700E+01, -.36153800E-01, -.90676900E-01, 0.14777300E+00, 0.56089300E+00, -.54189500E+00, -.16974800E-01, -.22988100E-01, -.21802800E+00, -.31895000E+00, 0.14968500E-01, 0.41507700E+00, 0.83053600E-01, 0.79467500E-02, -.18505200E+01, -.42346700E+00, -.18657400E+00, -.83419900E+00, 0.11188500E+01, -.15021100E-01, 0.14214100E+00, 0.76258400E+00, -.10585700E+00, 0.45974800E+00, 0.15795800E+00, -.53890900E+00, -.53321300E-01, 0.51539900E+00, 0.14681300E+00, -.12851300E+00, -.42958200E-02, 0.21029600E+00, 0.17795800E-02, 0.19180800E-01, -.15586900E+00, -.12972300E+00, -.15842100E+00, 0.70215800E+00, 0.25359500E+00, -.30544200E+00, -.38269300E+01, 0.12946500E+01, -.11716800E+01, -.26413700E-01, 0.62218000E+00, -.37609000E+00, 0.47706600E+00, -.15297400E+01, -.59212500E+00, -.56886600E+00, -.56060700E-01, 0.36912100E+00, -.11269200E+01, -.49536000E-01, -.69116200E-02, -.94092700E+00, 0.30126700E+00, 0.26143600E+00, -.83160900E+00, -.14795000E+00, 0.36239400E+00, -.21692500E+01, 0.59498700E+00, -.22716200E-01, 0.43188600E+00, -.41529600E-01, 0.45697200E+00, 0.97710300E-01, -.51733400E-01, -.34560200E-01, -.67501700E-01, 0.32765500E+00, -.15475500E+00, -.22986100E+01, -.15336700E+00, -.66229500E-01, -.78641700E-02, 0.42620000E+00, -.15027600E+00, 0.15144900E+00, -.32432800E+01, -.48565700E-01, 0.78774800E-01, -.21911800E+00, 0.95724600E-01, 0.65945000E-01, 0.58044400E+00, 0.19311900E-01, -.18944700E+00, 0.18039700E+00, -.17393300E+00, 0.23501600E+00, 0.17890800E+01, 0.12696000E+01, 0.44986000E+00, -.62720500E+00, -.12135600E+00, -.34681900E+00, 0.12760800E+01, -.55200400E-01, -.27179200E+00, -.95523000E+00, -.32382400E-01, 0.10081000E+01, 0.59186800E+00, 0.56575200E-01, 0.10443400E+01, -.16456700E-01, -.19848400E+00, 0.22711800E-01, 0.14636800E+01, 0.58007200E-01, -.22076300E+01, -.21312600E+00, -.85005900E+00, 0.12376600E+01, 0.11925600E+00, 0.23585200E+00, 0.83820000E-01, -.43283500E-01, -.54676000E-01, -.15200400E+01, -.17858300E+00, 0.68860900E+00, -.23221100E+00, -.11441300E+00, 0.48833600E+00, 0.34444300E-01, 0.24009700E+00, -.88608000E-01, -.28354900E+00, 0.89892800E-01, -.59113800E+00, -.12115500E+01, 0.65798400E+00, 0.10593800E+01, -.20684600E+00, 0.20414700E+00, -.43053800E+03, -.27718900E+03, 0.14810500E+03, -.91915000E+02, 0.14107900E+03, -.15758800E+03, 0.36178400E+02, 0.68693800E+02, -.15502000E+03, 0.20160500E+02, 0.17918000E+02, 0.38406200E+03, -.10879200E+03, 0.46179400E+02, -.77032500E+02, 0.55391200E+02, 0.45772700E+02, -.30505800E+02, 0.55409300E+02, 0.14976200E+03, 0.10730000E+03, 0.14448300E+02, 0.28136700E+03, 0.21128500E+03, -.79441100E+02, 0.13289900E+03, -.10512400E+03, 0.13491200E+02, 0.73307200E+02, -.48303000E+02, 0.92743200E+02, -.29651900E+02, 0.32035900E+02, -.89180100E+02, 0.78741200E+02, -.42980600E+02, -.29874200E+03, -.36888900E+02, 0.45394900E+02, -.11017300E+02, 0.52004600E+01, 0.13732500E+03, 0.63091100E+02, 0.16108400E+02, 0.34907100E+03, 0.10499400E+03, -.54195700E+02, -.43246900E+02, -.55260100E+02, -.36689100E+02, -.46081800E+02, 0.47830200E+02, 0.51354600E+02, -.84406200E+01, -.12715900E+02, -.20044100E+03, 0.75503400E+02, -.38851400E+02, -.85058700E+02, -.36714900E+02, 0.14581100E+02, -.46191200E+02, 0.61818700E+02, -.41797400E+02, -.92200400E+02, -.41677700E+02, -.14404100E+02, -.21085700E+02, -.99561400E+01, -.40317800E+03, 0.10383200E+02, -.15625000E+02, 0.27833900E+01, -.61344600E+02, -.17162400E+03, -.34760500E+01, 0.28991800E+02, -.60208200E+02, -.84981400E+03, 0.42640500E+03, 0.13039800E+02, 0.42888400E+03, -.45312900E+02, 0.17940000E+03, 0.10729600E+03, -.22745500E+03, 0.17129500E+03, 0.13248000E+03, 0.41656000E+03, -.20414300E+03, 0.89553200E+02, 0.26028100E+03, 0.99872200E+02, 0.66581700E+02, 0.61045600E+02, 0.43723700E+02, -.40629100E+02, -.65626100E+02, 0.63303800E+02, 0.17903200E+03, -.16161500E+02, -.13532200E+02, 0.40737200E+01, -.10631800E+02, -.48801400E+01, 0.93762600E+01, 0.23593100E+02, -.16662700E+01, -.89776000E+01, 0.35745600E+01, 0.10556400E+01, 0.10679200E+02, 0.11243700E+02, 0.13737400E+02, -.14968800E+02, -.34615800E+01, 0.61516300E+01, -.27464300E+00, -.14511000E+02, 0.14855900E+03, -.18292600E+02, -.13803800E+02, 0.25429500E+02, 0.39790800E+02, -.11836700E+02, 0.58995900E+01 },
        { -.22959000E+02, 0.66305400E+00, 0.12371500E+01, 0.38625800E-02, -.86385200E+00, 0.41405900E+01, -.16991900E+01, 0.14670200E+01, -.10249400E+01, 0.30757300E+01, -.76757000E-01, 0.56033800E+01, 0.32000100E+00, -.16243100E+01, 0.47010800E+00, -.32337000E+00, 0.13905700E+01, 0.10494700E+01, 0.27358400E+01, 0.97363100E+00, -.22404400E+00, 0.11546000E+00, 0.71191100E+01, -.97531800E+00, -.17801100E+00, -.95072900E+00, -.19172300E+00, 0.73899600E+00, 0.71271800E+00, -.21732900E+01, -.13279800E+01, 0.21955200E+01, 0.89184700E-01, 0.73521400E+00, -.14852600E+01, 0.62342400E+00, 0.22629300E+00, -.76068700E+01, 0.96681400E+00, 0.42204400E+00, 0.19608800E-01, -.57003200E+01, 0.21911100E+01, -.15334900E+01, -.24285800E+01, 0.79243700E+00, 0.56949400E+00, -.88319900E-02, 0.28365800E+01, 0.31717700E+00, -.44924400E+01, 0.51465900E+01, -.20610100E+01, 0.54486200E+00, 0.41415200E+01, -.23304000E+01, -.27491200E+00, -.74583700E+00, 0.15674200E+00, 0.11952400E+00, 0.11448500E+01, -.70101800E+00, -.15718100E+00, 0.11837300E+01, 0.66775000E+00, 0.98673800E-01, 0.56470000E+01, -.62983600E-01, 0.70049000E+01, -.12579900E-01, -.54183900E+00, 0.11989200E+01, 0.66090700E+00, 0.16231900E+00, 0.54307300E+00, -.72210200E+00, 0.16606600E+01, 0.84551500E+01, -.24109100E+01, 0.40990800E+01, 0.21752500E+00, -.37473700E+01, -.31119200E+01, -.35316400E+00, 0.28310700E+01, 0.18362900E+01, 0.53409200E+00, 0.21733800E+00, 0.23808900E-01, 0.58281400E+00, -.39636200E-01, 0.13493400E+00, 0.48366300E+01, -.60290000E+00, -.85660600E+00, -.44704600E+00, -.16144400E+01, -.27637100E+01, 0.11365900E+01, -.33031700E+00, 0.35923100E+00, -.16321600E+01, 0.13301700E+01, -.24482500E+01, -.49585600E+00, 0.18403800E+00, -.30886200E+00, 0.44934100E+01, 0.41121500E+00, -.40457400E+00, 0.85481300E+01, -.14221900E+00, -.19905000E+00, -.60780600E-01, -.24060400E+01, 0.11775600E+01, 0.37486700E+00, -.61871700E+01, 0.89153100E+00, 0.22702700E+01, -.77545800E+00, -.56489900E-01, 0.86749900E-01, 0.52392000E+00, -.33004500E-01, 0.28585900E+00, 0.19378700E+00, -.32196900E+01, -.29727400E+00, -.89859500E+00, 0.15593500E+02, 0.41532400E+00, 0.25118200E+00, -.12334900E+00, 0.95875000E+00, -.17514900E+01, 0.31930700E+00, 0.42367600E+00, -.97386800E+00, -.22669500E+01, 0.35061800E+01, 0.20833600E+00, 0.23673100E-01, 0.19484000E+01, -.47302200E-01, 0.49214600E-01, 0.19229600E-01, 0.50426700E+01, 0.84628600E+00, -.60319400E+01, -.59004100E+00, 0.21769500E+01, -.27274700E+01, 0.85447200E+00, 0.62109700E+00, -.39468900E+00, -.95123400E+00, 0.10456100E+00, -.50284200E+01, 0.52831900E+00, 0.19385900E+01, -.11463100E+01, -.92437000E-01, 0.59929200E+00, -.76116000E-01, -.82827500E+00, 0.40365000E+00, 0.62739900E-01, -.12419300E-01, 0.10687100E+00, 0.49433000E+00, -.81163900E+01, -.46328400E+00, -.61159000E+01, -.96133000E+00, 0.18394700E+00, 0.78652300E+03, -.43236000E+03, 0.45390700E+03, -.39552900E+03, 0.50555800E+03, -.19818100E+03, -.25397600E+03, 0.26779700E+03, -.21153700E+03, -.16740300E+03, -.62575900E+03, 0.95428100E+03, -.44488600E+03, -.32527100E+03, -.47805000E+03, -.10237600E+03, -.31388500E+02, -.23054500E+03, 0.16182300E+03, -.18209800E+03, -.26573200E+03, 0.83129000E+02, -.73780500E+03, 0.34308000E+03, 0.33291000E+03, 0.36839500E+03, -.73995500E+02, -.16085400E+03, 0.16099900E+03, -.14593600E+03, 0.22322700E+03, -.91827000E+02, 0.41838500E+03, 0.32417800E+03, -.13389900E+03, 0.35049400E+02, -.16436100E+03, 0.50306200E+02, 0.97546000E+02, -.11445000E+03, 0.16350300E+02, -.15868200E+03, -.11282700E+03, 0.81118600E+01, -.15353800E+04, 0.77650000E+03, 0.86001300E+03, 0.77021200E+03, 0.21231500E+03, 0.29796800E+03, 0.89822600E+02, -.50307700E+03, 0.97271700E+02, 0.31585100E+03, 0.10776700E+04, -.23115300E+03, 0.11582300E+03, 0.43865700E+03, 0.11464100E+03, -.18945900E+03, -.41913700E+02, 0.16586800E+03, -.12131400E+02, 0.52021400E+02, 0.54432400E+01, 0.19644900E+03, 0.85891900E+03, -.38161900E+03, 0.49359800E+03, -.42922800E+03, 0.16140800E+02, 0.12438100E+03, -.16724400E+03, 0.24987200E+03, -.29856500E+03, 0.56484200E+02, -.30224100E+03, 0.20566000E+04, -.10435400E+04, 0.46486700E+03, -.10319900E+04, 0.13063200E+03, -.45575800E+03, -.35916100E+03, 0.53383900E+03, -.46599300E+03, -.40251300E+03, -.82169100E+03, -.12768600E+03, 0.73863400E+02, -.43552600E+03, 0.66058700E+02, -.20174900E+03, -.36582000E+03, 0.26332600E+03, 0.34366100E+03, 0.72370800E+03, -.38217000E+03, -.47022200E+02, 0.36316300E+02, 0.15402200E+02, -.15069800E+02, 0.29056400E+02, 0.47215800E+01, -.10829000E+02, -.93844600E+02, 0.38110900E+01, 0.21056700E+02, 0.81476300E+02, -.83517500E+02, 0.12188800E+02, -.50698900E+01, -.21303900E+02, 0.62184100E+02, 0.88618000E+02, -.14373600E+02, -.83253600E+02, 0.62476700E+02, -.22506700E+03, -.51445700E+02, 0.69773400E+02, -.70725900E+02, 0.49363600E+02, 0.14293600E+03, 0.61267600E+02 },
        { -.24658100E+02, 0.10742400E+01, 0.61757600E+00, 0.37559500E+00, -.22864700E+01, 0.62137800E+01, -.20741200E+01, 0.23125000E+01, -.33354200E+01, 0.53218000E+01, -.69109000E-01, -.17663300E+01, 0.40734100E+01, 0.19179400E+00, 0.16061400E+01, 0.14840000E+00, 0.44913800E+00, 0.12371600E+01, -.79325200E+00, 0.46525100E+00, 0.14670000E+01, -.76103100E+00, 0.20405900E+02, 0.31259200E+01, 0.12408500E-01, -.32908700E+00, -.43209100E+00, -.10014400E+00, 0.25982100E+01, -.95769400E+00, 0.23456400E+00, 0.17007200E+01, -.80245800E-01, 0.11748600E+01, -.14590200E+02, -.44457500E+00, -.36488000E+00, -.78085700E+01, 0.51909300E+00, -.81234200E+00, 0.69708600E+00, -.69688000E+00, -.13699300E-01, -.18249300E+01, -.29024500E+00, -.33349700E+00, 0.56271400E+00, 0.73654100E-01, -.72702200E+00, 0.62958100E+00, -.22315200E+01, -.91544200E+01, 0.58547800E+00, 0.98562700E+00, -.22657100E+01, -.96322300E+00, 0.22137000E+00, -.51936200E+00, 0.18477800E+01, -.13047400E-01, -.17237700E+01, -.14980000E+01, 0.50950900E+00, 0.18127600E+00, -.90759900E+00, -.80592300E+00, 0.41816400E+01, -.99090000E-01, 0.34432400E+01, -.15108000E-02, -.18294100E+00, 0.71209800E+00, 0.15831200E+00, 0.45413500E+00, 0.13760600E+01, 0.24131700E+00, 0.91739800E+00, 0.10780800E+02, 0.12934700E+01, 0.11778800E+01, 0.13378200E+00, -.28679200E+01, -.88362800E+00, -.27086500E+00, 0.33836700E+01, 0.27550400E+02, 0.46357500E+00, 0.22899000E-01, -.20256600E+01, 0.20914700E+01, -.80912000E+00, 0.13545400E+00, 0.25239400E+01, -.12787700E+01, -.58490900E+00, -.16060500E+01, -.41973700E+00, -.15508500E+00, 0.71710600E+01, -.16150500E+01, -.20682800E+00, -.25065100E+01, 0.14082200E+01, -.85507300E+00, 0.15848800E+00, -.24056800E+01, -.27252600E+00, -.23817600E+01, 0.10448100E+01, -.64431000E+00, 0.63705200E+01, -.98300400E+00, 0.20056200E+00, -.70266000E-01, -.12885000E+01, -.86613000E+00, 0.16810600E+00, -.84683200E+01, -.11609500E+01, 0.97649000E+01, -.83786500E+00, -.59207000E-01, -.19390600E+00, 0.20346600E+00, 0.24499600E-01, -.32995800E+01, 0.26745800E+00, 0.17268800E+01, -.42951900E-01, -.39081200E+01, 0.10826900E+02, 0.10124300E+00, -.22336700E+01, -.30887800E+00, 0.51842900E+01, 0.24561200E+01, -.38698800E+00, -.76421900E+00, 0.33290000E+01, -.21186800E+01, 0.20688700E+01, -.11066500E+01, 0.13649900E+00, -.34246200E+00, 0.71119200E-01, 0.18602900E+00, -.20034700E+00, 0.42207800E+01, 0.12318700E+01, 0.21122200E-01, -.14140800E+01, 0.28426200E+01, -.19766500E+00, 0.18636700E+00, 0.30116800E+00, -.23837700E+00, -.78900400E+00, -.56321700E-01, -.60656000E+01, 0.64267000E+00, 0.43077100E+01, -.94866400E+00, -.22122900E+00, 0.10918800E+01, 0.16983200E+00, -.11287200E+01, 0.31845400E+00, 0.14312100E+01, -.79287100E-01, -.26376300E+00, -.17600700E-01, -.79209800E+01, 0.17465400E+00, -.41212500E+01, 0.81761700E+00, -.11357900E+01, 0.49459700E+00, 0.10650700E+03, -.27726500E+03, 0.46222400E+01, -.14388600E+03, -.43629900E+02, 0.65509300E+02, -.18513300E+03, -.11470700E+03, 0.56902500E+02, 0.16428400E+03, 0.15496200E+03, -.46843000E+02, -.15747200E+03, -.75561000E+02, -.19235300E+03, 0.20853800E+02, -.13237900E+03, -.28627600E+03, -.11932900E+03, 0.20184600E+03, -.39592700E+03, 0.30278300E+03, 0.71712300E+02, 0.77650200E+02, -.15041100E+03, 0.53439000E+02, 0.17639900E+03, 0.18696300E+02, 0.26874300E+03, -.99175900E+02, 0.15339500E+03, -.13425800E+03, 0.19971300E+03, -.11651600E+03, -.51335000E+03, -.95175300E+02, -.20128500E+03, -.20390300E+02, -.15257800E+03, -.25040200E+03, -.83850000E+02, 0.19428900E+03, -.15955200E+03, -.49301200E+03, 0.18794600E+03, -.13358900E+02, 0.24135800E+03, -.14001900E+03, -.12922100E+03, 0.28022100E+03, -.17333200E+03, 0.17725900E+02, -.10364000E+03, 0.48634000E+03, -.16265000E+04, 0.83569800E+03, 0.31313200E+03, 0.81526300E+03, 0.35313100E+03, 0.11139700E+03, 0.32962500E+03, -.28297400E+03, 0.43464000E+03, 0.10776400E+03, 0.70338800E+03, 0.97210200E+03, -.50773000E+03, -.96155100E+03, -.48638600E+03, 0.62128100E+01, 0.14568400E+03, -.44082400E+03, -.36976900E+03, -.38017600E+03, 0.17119400E+03, -.44380500E+03, -.70228200E+03, 0.42095000E+03, -.34969800E+02, 0.35856700E+03, 0.79617500E+01, 0.86305400E+02, 0.33720200E+03, 0.12039700E+03, 0.21907800E+03, 0.68416200E+02, 0.42160200E+03, -.25112200E+02, 0.26983300E+02, 0.19991400E+03, 0.84057200E+01, -.83902300E+02, -.17990100E+03, 0.15648200E+03, 0.21318700E+03, -.64916200E+01, -.17723000E+03, 0.14462500E+03, -.91931800E+01, -.14657900E+02, 0.16404500E+02, -.14202300E+02, -.16337700E+02, 0.21571000E+02, -.37163600E+02, -.29619700E+01, -.22700900E+02, -.20304600E+02, 0.15254500E+02, -.77081800E+02, 0.18205500E+02, 0.37992100E+02, 0.13343200E+01, -.15217600E+02, 0.40029400E+01, -.55615700E+01, -.87203600E+02, 0.59207000E+02, 0.51940000E+02, 0.27668500E+02, 0.56083200E+01, 0.55497400E+02, 0.77958800E+01, 0.80023500E+01 },
        { 0.95346700E+01, -.13753700E+00, -.25868800E+00, 0.15176400E+01, 0.11323300E+01, -.55803200E+00, -.11149000E+01, -.44005400E+00, 0.44284500E+01, 0.19508200E+00, 0.22186600E-01, 0.18825200E+01, 0.21246500E-01, 0.31458500E-01, 0.11871900E+00, -.11510200E+00, 0.14036600E+01, 0.55696900E+00, 0.78499900E+00, -.11524100E+01, 0.13322400E+00, -.26097400E+00, 0.61211000E+01, 0.46602100E+00, -.12263600E+00, -.23296100E+00, -.21177000E-01, -.15613400E+01, -.10516200E+01, -.60071400E+00, -.53294600E+00, -.62067900E+00, 0.42219900E-01, -.98784000E+00, 0.17143200E+01, 0.22644000E+00, 0.93833900E-01, 0.33907500E+00, -.13674100E+00, 0.46326200E+00, -.54050800E+00, 0.98403200E+00, -.31494900E+00, 0.50492900E-01, -.14425900E+00, 0.19326800E+00, -.85248400E-01, -.29315600E-01, 0.11968500E+01, -.10149500E+00, 0.51348000E+00, 0.93020200E+00, -.41594000E+00, -.34192700E+00, -.22527100E+01, 0.94809100E+00, -.77199100E-01, 0.63321900E+00, -.20666300E+00, 0.13627600E+00, 0.53481100E+00, -.57119400E+00, 0.52183100E+00, -.23425200E-01, 0.74865900E+00, 0.34585600E+00, -.73441800E+00, -.36960900E-02, 0.56120900E-01, 0.61865700E-03, -.97435500E-01, 0.34656200E+00, 0.14576600E+00, -.19463600E+00, -.34086200E+00, 0.77928400E+00, 0.58756800E-01, -.14744700E+01, 0.55446000E+00, -.41988600E+00, -.71217700E-01, 0.12878100E+01, 0.17005000E+00, -.49572500E-01, -.55650300E+00, -.50797200E+01, -.17609300E+00, 0.13204200E+00, 0.74173300E-02, 0.65616500E-01, 0.25703900E+00, -.10757400E+00, -.13393100E+01, 0.42777500E+00, 0.27959500E+00, -.31893200E+00, 0.74817800E-01, 0.19434100E+00, -.24105500E+01, 0.64469600E+00, 0.20155600E-01, 0.61114200E+00, -.66588300E+00, 0.39507700E-01, 0.16297600E+00, 0.81591000E+00, 0.12133700E+00, 0.37743300E+01, -.42186900E-01, 0.62995300E-01, -.33922400E+01, -.70765500E-01, -.57099200E+00, 0.45941200E-02, 0.97562700E+00, -.28526700E+00, 0.12177600E+00, -.95873200E+00, 0.59212700E-01, 0.24468000E+00, -.30772600E+00, 0.23931000E+00, 0.36644100E-01, 0.67442500E+00, 0.26071700E-01, 0.18504600E+00, 0.44598300E-01, -.12039000E+00, 0.63360300E-01, 0.14860500E+01, 0.48735300E+01, -.57864900E-02, -.67040500E+00, -.14654600E+00, 0.15907900E+01, 0.11654500E+00, 0.52343200E-02, -.27801400E+00, -.32096400E-02, 0.82494900E+00, -.13274800E+00, 0.13944900E+01, 0.37218300E-01, -.35765500E+00, -.22421300E-01, -.35058700E-01, -.34555900E-01, 0.82234700E+00, 0.15561200E+00, 0.53202700E-01, -.21290700E+00, -.29320200E+00, 0.13898100E+01, -.30447300E+00, 0.83107200E-02, -.30615800E-01, 0.32143900E-01, -.27761700E-01, 0.68251200E+00, -.16472700E+00, -.33252200E-01, 0.33440800E+00, -.65180900E-01, 0.56560000E-01, -.10615100E+00, 0.37697300E+00, 0.12016200E+00, -.31899600E+00, -.11175200E+00, -.20619700E+00, 0.19571700E+00, 0.20410000E+01, -.21760200E+00, 0.15385900E+01, -.10874000E+01, -.45537700E-01, -.75974900E-01, 0.11334500E+00, -.13436400E+03, -.82802300E+00, -.10245500E+03, 0.29121300E+02, -.30696900E+02, -.50161500E+02, 0.59925500E+01, 0.31883200E+02, 0.27387700E+02, -.14139500E+03, 0.78588300E+02, 0.56833400E+02, 0.70353600E+02, 0.38535600E+02, 0.52300000E+02, -.82688500E+00, -.58272500E+02, 0.62143400E+02, 0.34780500E+02, 0.16138700E+03, 0.15010400E+03, -.96815300E+02, -.76224400E+02, -.75221700E+02, 0.14599400E+02, 0.97632200E+01, -.65232900E+02, -.24778800E+02, -.67886600E+02, 0.99486900E+01, -.10035000E+03, -.10293700E+03, 0.50961800E+02, 0.12257900E+03, 0.50626300E+02, 0.40087800E+02, 0.42773200E+02, 0.60448100E+01, -.55008300E+02, 0.20422800E+02, 0.28432700E+02, 0.69102400E+02, -.33097000E+03, 0.16898200E+03, 0.19334700E+03, 0.16640700E+03, 0.68367700E+02, 0.28483700E+02, 0.68805800E+02, -.52187200E+02, 0.10518800E+03, 0.13885700E+02, -.46935100E+02, -.38717600E+03, 0.19046300E+03, 0.20778600E+03, 0.19322300E+03, 0.81626400E+02, 0.73222000E+02, 0.19249200E+02, -.61141900E+02, 0.13307000E+03, 0.58786400E+02, 0.14773600E+03, -.16828100E+03, 0.83489000E+02, 0.16237800E+03, 0.84131000E+02, 0.62798500E+01, 0.34442900E+01, 0.55325700E+02, 0.13783300E+02, 0.49387400E+02, -.45924200E+00, 0.40851600E+02, 0.92812700E+02, -.46643900E+02, -.25271300E+03, -.47745300E+02, -.12608300E+03, -.18472800E+02, 0.32501000E+02, 0.25193200E+02, -.99454300E+01, -.30685700E+02, -.17888000E+03, 0.70786300E+02, -.34827600E+02, -.50659800E+02, -.34636500E+02, 0.30089700E+02, 0.67446300E+02, -.11809200E+03, -.10285700E+03, -.82850400E+02, 0.63153000E+02, 0.47415800E+02, -.53762300E+01, -.67609900E+00, 0.39746700E+01, -.26645400E+01, -.32044600E+01, -.14731100E+01, 0.14395800E+01, -.61507100E+00, -.27798800E+01, -.39728200E+02, 0.40238600E+02, -.12338400E+02, -.46497500E+01, -.27358800E+01, 0.18016400E+01, -.39625800E+02, 0.22367100E+01, 0.17034800E+02, 0.11944900E+02, 0.43468700E+02, -.44418600E+01, -.53596600E+01, 0.23587500E+01, -.47515300E+02, -.44429000E+02, -.43900200E+02 },
        { -.53865900E+01, 0.43879100E-01, 0.19667400E+00, -.13667800E+00, -.63308500E+00, 0.18387900E+00, 0.88157400E+00, -.95070300E-01, -.18643900E+00, 0.23777800E+00, 0.23775400E-01, -.66161900E+00, -.16083500E-02, -.20319700E-01, -.34780400E-01, 0.39468300E-01, -.68702800E+00, -.21469000E+00, -.85032900E+00, 0.53103900E+00, 0.46012700E-01, -.24956900E-01, 0.27200000E+00, 0.25112400E+00, 0.11844900E-01, 0.44036000E-01, -.86773900E-01, 0.20153500E+00, 0.46085500E+00, -.30986700E+00, 0.86939700E-01, 0.40129800E+00, -.35636000E-02, -.27669200E+00, -.17707000E+01, 0.14199700E+00, -.89960400E-01, -.10818300E+01, -.53336100E-01, 0.17036700E+00, -.24786100E-01, -.81509800E+00, 0.41349400E+00, 0.13463300E+00, -.29157500E+00, -.65604300E-01, 0.44919800E-01, 0.12132300E-01, 0.63174100E-01, -.47536200E-01, -.77230000E+00, 0.19507200E+01, -.11479400E+00, 0.14557900E+00, 0.20970000E+01, -.51134400E+00, 0.40001700E-01, 0.16127400E+00, 0.59605100E-01, 0.51852100E-01, -.30639600E+00, 0.39932300E-01, 0.24547800E+00, 0.92132400E-01, 0.13477900E+00, -.99780800E-01, 0.13825600E+00, 0.39123200E-02, 0.28579300E+00, -.23658100E-02, -.73621600E-01, -.89220300E-01, -.34027400E-01, -.68197200E-01, 0.66206700E+00, 0.24843800E+00, -.51594100E+00, -.26969200E+01, -.66854100E-01, -.28515600E+00, -.14435200E-01, 0.26204100E+00, 0.70821900E+00, -.25921400E-02, 0.78582400E-01, -.13673900E+01, 0.14368700E-01, -.15549600E+00, -.10169700E+00, -.27996800E+00, -.51024400E+00, 0.15371800E-01, 0.21612100E+00, 0.13295500E+00, -.96673800E-01, 0.11594700E+00, 0.25512100E+00, 0.46921600E+00, 0.24888600E+00, -.26854100E+00, -.62107200E-02, 0.15474600E+00, -.80750800E-01, -.55979200E-01, 0.80409800E-01, -.40365900E+00, 0.39708500E-01, -.34117800E+00, 0.49582300E-01, -.22373600E-01, -.15795200E+01, 0.62311800E-01, 0.29789900E+00, 0.11711200E-01, 0.44684000E+00, 0.26979300E+00, -.63841400E-02, 0.16001400E+01, 0.72603900E-02, -.53892200E+00, -.88542100E-01, 0.26214700E-01, -.78065900E-02, 0.26978300E+00, 0.60861500E-02, -.19675400E+00, -.32814300E-01, -.24587000E+00, -.37722900E-01, 0.84050300E+00, -.28490200E+00, -.31199900E-01, -.12591500E+00, -.62629200E-01, -.21923800E+00, 0.50401200E+00, -.39234900E-01, -.14075400E+00, -.67694300E+00, -.49611600E-01, -.20632500E-01, 0.30223400E+00, -.39978000E-01, 0.29062900E-01, -.32686200E-02, -.14240900E+00, -.88269000E-02, -.52035000E-01, 0.79973500E-01, -.73171300E+00, -.10172400E+00, 0.20935400E+00, -.21225600E+00, -.44546800E-01, 0.20633900E+00, 0.24302800E-01, 0.15266600E+00, -.30654500E-01, -.70736900E-02, 0.55847300E-01, 0.19360600E+00, 0.13144600E+00, 0.19084800E-01, -.26583400E+00, -.26868000E-01, 0.11237700E+00, -.24126900E-01, -.31525000E+00, -.24330000E-01, 0.32988900E+00, 0.19175100E-01, 0.10058300E+01, 0.15138100E+00, -.49120100E+00, 0.93735700E-01, -.18779500E+00, -.67882600E-01, 0.23323900E-01, 0.41414000E+00, 0.55244100E+00, 0.13083700E+02, 0.20652400E-01, -.49771600E+01, -.14001600E+02, -.14501300E+02, -.16957700E+02, 0.29212700E+02, 0.72958500E+02, -.37439100E+02, -.68926700E+02, -.36254700E+02, -.10128500E+02, -.99814000E+01, -.17653600E+02, 0.39391400E+00, -.37322400E+02, -.19696400E+02, 0.75465600E+02, -.11492900E+02, 0.49835800E+01, 0.16669800E+01, 0.58608200E+01, -.25759000E+01, 0.19780000E+01, -.11939400E+02, 0.11809300E+02, 0.33443800E+02, -.97783700E+00, 0.33213000E+02, 0.62356400E+01, -.89706300E+00, -.35721700E+02, -.25641600E+01, 0.55075100E+01, 0.16735300E+02, -.54044000E+01, -.11425100E+02, -.22123600E+02, 0.66631300E+01, 0.68118900E+02, 0.53582300E+02, -.28518200E+02, 0.21935200E+01, -.27405800E+02, -.18441100E+02, -.11348700E+02, -.11989500E+02, 0.11349400E+02, -.30948400E+02, 0.55790200E+01, 0.64937200E+02, 0.43272200E+02, -.23046300E+02, -.18905000E+02, -.21400600E+02, -.34221800E+02, -.31896000E+02, 0.43261500E+02, 0.13611900E+01, -.54809900E+02, -.25352900E+02, 0.30300200E+02, 0.51103700E+02, -.26006700E+02, -.13201000E+03, -.25585500E+02, -.27857900E+01, -.48063500E+01, -.18476800E+02, -.15561500E+02, -.15465700E+02, 0.46755700E+00, -.41263200E+02, -.70376200E+02, 0.34308100E+02, 0.20451600E+02, 0.36065700E+02, 0.19898300E+02, 0.18933700E+02, -.22363100E+02, -.24531100E+02, 0.13764200E+02, 0.75442900E+01, 0.26735800E+02, 0.26778600E+00, -.34350600E+01, 0.55160800E+02, -.62707200E+00, -.94080200E+01, -.12937100E+02, 0.21473500E+02, 0.17763700E+02, 0.12850300E+02, -.15859700E+02, 0.23738200E+02, 0.12171700E+01, -.42389000E+00, 0.14975900E+01, -.30469400E+00, -.32205400E+00, 0.56439400E+00, -.72888400E+00, 0.32591300E+00, -.15159300E+01, 0.74417000E+01, -.68233700E+01, 0.78810500E+01, 0.36437000E+01, 0.17619200E+01, 0.33470100E+01, 0.73008700E+01, 0.23728500E+01, -.34651000E+01, 0.72638300E+01, 0.19090100E+01, -.64918700E+01, 0.27285500E+01, 0.59221000E+01, 0.13615500E+02, 0.83325000E+01, 0.61054000E+01 },
        { 0.30986600E+01, -.11500700E+00, -.79015900E-01, -.59147700E+00, 0.57843000E+00, -.96805100E+00, 0.50466700E+00, -.56917100E+00, 0.99422100E+00, -.75184000E+00, -.22495900E-01, 0.44244700E+00, 0.56390800E-01, 0.79540200E-01, -.15806400E+00, -.14495800E+00, 0.19319900E+00, 0.14179300E+00, 0.98140400E-01, -.63735000E+00, -.44533200E+00, -.25982700E-01, 0.59470100E+01, 0.32265100E+00, -.12719700E+00, -.68986400E-01, -.17202300E-01, -.57350500E+00, -.10596200E+01, -.57354500E+00, -.21997200E+00, -.60957100E+00, 0.62326000E-01, -.55882600E+00, 0.68341100E+00, 0.37631200E+00, -.11159100E-01, 0.15224000E+01, -.18358300E+00, 0.62627100E+00, -.20609500E+00, -.99716700E+00, -.11812800E+00, 0.11036800E+01, -.16002300E+00, -.81865900E-01, -.67934300E-02, -.14319900E-02, 0.14657100E+00, -.50927200E-01, 0.10480000E+01, -.34994900E+01, 0.25784000E-01, 0.20606600E-01, 0.29951100E+01, -.65509200E-01, -.26196800E-01, -.91251200E+00, 0.46973600E-02, -.83484800E-03, 0.33115000E+00, 0.22884200E+00, -.32339800E+00, -.12294300E+00, 0.38515400E-01, 0.14625500E+00, -.10793100E+00, -.22363000E-02, 0.39400300E+00, -.14144100E-02, -.12424800E+00, -.18981100E+00, -.13272200E-01, 0.69142900E-02, -.11071500E+01, -.24716900E+00, -.43456700E+00, -.25107500E+01, 0.37553700E-01, 0.38440200E+00, -.74418400E-02, 0.19861200E+00, -.99534000E+00, -.14499800E+00, 0.47269600E+00, 0.67503800E+01, 0.57277400E+00, 0.28946800E-01, -.44767000E+00, 0.56031300E+00, -.17942200E+00, -.46912800E-01, 0.50602700E+00, -.17358500E+00, 0.19460200E+00, -.23804300E+00, 0.15508200E+00, -.12168600E-02, 0.66316200E+00, -.12112700E+00, 0.16487600E+00, -.15934500E+00, -.80686800E-01, -.37234300E+00, 0.13068200E+00, -.42867000E+00, 0.60188100E-01, 0.15037800E+01, -.67806300E-02, -.80615700E-01, -.40426800E+00, 0.26396100E-01, -.72970600E-01, 0.12617500E-02, 0.51892700E+00, 0.40708100E-01, 0.65552100E-01, -.18382800E+01, -.70326500E-01, 0.10878800E+01, -.18583500E-01, 0.37554300E-01, 0.99152000E-02, 0.25156900E+00, 0.28413500E-01, -.32761100E-01, -.83895300E-01, 0.14671300E+00, 0.64451800E-01, 0.78070500E+00, 0.46711300E+01, -.45513700E+00, -.59171400E+00, 0.42891700E-01, 0.85557000E+00, -.50479600E-01, -.11036200E+00, 0.10337700E-01, 0.15037600E+01, -.99166500E+00, -.34878200E+00, -.19697600E+00, -.63438100E-01, -.37893300E+00, -.10025400E-01, 0.17034600E+00, -.62574600E-01, -.64049400E+00, 0.25689200E-01, -.31764800E+00, -.24507900E+00, 0.34049600E+00, -.72405900E+00, -.23640000E+00, -.14034200E+00, -.11880300E-01, 0.97193500E-01, 0.52234000E-02, 0.73141000E+00, -.41577100E-01, -.47417400E-02, -.18293200E+00, -.60429800E-01, -.52100900E+00, -.84369300E-01, 0.55019100E+00, 0.45520900E-01, 0.37478400E+00, -.48774600E-01, 0.74516500E-01, 0.30586000E+00, 0.18830800E+01, 0.19914600E-01, 0.36886000E+00, -.47723700E+00, -.17867000E+00, -.39271500E-01, 0.11535000E+00, 0.13822700E+00, -.20235600E+00, -.68888600E+02, 0.30812400E+02, -.30882900E+02, -.33721400E+01, 0.26355800E+02, -.20857800E+01, -.90544800E+01, -.11384700E+03, 0.62023100E+02, 0.99491500E+02, 0.56902200E+02, 0.14168700E+02, 0.93859500E+01, 0.32262200E+02, -.48387400E+01, 0.22890900E+02, 0.16844300E+02, 0.15873400E+03, 0.53114100E+02, -.43857900E+02, -.88215200E+02, -.26555600E+02, -.31751000E+00, 0.21327600E+02, -.80900700E+02, -.58147000E+02, -.35812000E+00, -.78738800E+00, -.60558600E+02, -.33348800E+02, 0.14870100E+02, 0.12503500E+03, 0.16645000E+02, 0.24817900E+02, 0.15180200E+02, 0.41813100E+02, 0.49615500E+02, 0.27464300E+02, 0.12615200E+02, 0.13579300E+03, 0.92483200E+02, -.44772200E+02, 0.61743600E+02, -.46239600E+02, 0.93035800E+02, 0.15235200E+02, -.50041100E+02, 0.94665200E+02, 0.41745800E+02, -.91629400E+01, -.23906200E+03, 0.21371200E+03, -.11144400E+03, -.11376300E+03, -.10688600E+03, -.25342000E+02, 0.19061400E+01, -.33586400E+02, 0.45595400E+02, -.61719100E+02, -.15268000E+02, -.87730900E+02, -.14520200E+03, 0.62430100E+02, 0.13722900E+03, 0.72512000E+02, 0.21869700E+02, 0.31072800E+02, 0.13656600E+02, -.53924300E+02, -.59305700E+00, 0.40252300E+02, 0.52611200E+02, 0.58658200E+02, -.32116400E+02, -.18328600E+02, -.29373900E+02, -.64219600E+02, 0.64054500E+01, -.69870900E+02, -.41740300E+02, -.33015000E+01, -.14837400E+02, -.16417300E+03, -.12755800E+02, 0.22996000E+01, 0.19076800E+02, 0.63888600E+01, 0.36804100E+02, 0.83624100E+02, -.81168200E+02, -.81687600E+02, -.87758200E+02, 0.72661000E+02, 0.12996400E+03, -.28996300E+01, 0.17720700E+00, -.10158800E+01, -.82024700E+00, 0.88131200E+00, -.41739200E+01, 0.21466400E+02, 0.74583900E+00, 0.22081000E+01, -.21628400E+02, 0.22822900E+02, 0.26226000E+02, -.15786400E+01, -.49881900E+01, -.72203500E+01, -.20676100E+02, 0.31008900E+01, 0.14651200E+02, 0.31446000E+01, 0.10025900E+03, -.24789900E+01, -.20334600E+02, 0.18060300E+02, -.23714300E+02, -.27282900E+02, -.21920300E+02 },
        { -.63811000E-01, 0.16944600E-01, 0.84770300E-02, 0.11282300E+00, -.35195000E-01, 0.28862100E+00, -.17153700E+00, 0.20535300E+00, -.18914600E+00, 0.23009200E+00, -.58181000E-02, -.15918900E+00, -.19016300E-01, -.13341500E-01, -.55678600E-01, 0.32446900E-01, -.81133900E-01, -.92456600E-01, -.75384700E-01, 0.10426000E+00, 0.15158700E+00, -.27003600E-01, -.98284900E+00, -.75483000E-02, -.23672100E-01, 0.14525300E-01, -.45073200E-02, 0.10907200E-01, 0.15254100E+00, 0.47605500E-01, 0.80919700E-01, 0.18608800E+00, -.97440400E-02, 0.50933800E-01, -.39286100E+00, -.17328700E-01, 0.10669500E-02, -.23134600E+00, -.39474300E-03, -.44296100E-01, 0.71740100E-01, -.75033400E-01, 0.55213000E-01, 0.29260100E-01, -.41297900E-01, -.13653900E-01, -.75170200E-02, 0.11528200E-02, -.74883100E-01, 0.98271800E-02, -.95961100E-01, 0.25846600E+00, -.80487300E-02, 0.59913800E-02, 0.76792200E-01, -.59366400E-01, 0.77328900E-02, -.20316100E-01, 0.27985300E-03, -.11626400E-01, -.11066700E-02, 0.75012600E-02, -.34843700E-01, 0.18823000E-01, 0.54312300E-01, 0.12344600E-01, -.37743500E-02, 0.91958700E-03, 0.57298700E-01, 0.11255200E-03, -.61206600E-02, -.13252200E-01, -.26309200E-02, 0.12663600E-01, 0.40356800E-02, -.33989200E-01, -.84113700E-01, -.50721100E+00, 0.13805900E-01, -.66831700E-02, 0.16571500E-02, -.85172200E-01, 0.17458900E+00, -.19912200E-02, 0.66041600E-01, 0.30639400E+00, -.82620400E-03, -.13155500E-01, -.45155100E-01, -.52404600E-01, -.54295800E-01, 0.31093800E-02, 0.55598900E-01, -.14902200E-01, 0.75659400E-02, -.21121600E-01, 0.33491000E-01, -.97076200E-02, 0.59210000E-01, -.27106000E-02, 0.26751900E-02, -.55942600E-01, 0.14620000E-01, -.70081600E-02, 0.15900200E-02, -.40663700E-01, 0.89779600E-02, 0.42991200E+00, -.33323300E-01, 0.12945200E-01, -.16335400E+00, 0.11834000E-01, -.17556200E-01, 0.13339500E-02, 0.87943900E-01, -.14684500E-02, 0.98369100E-02, 0.60849000E-01, 0.26605300E-01, 0.15453000E-01, -.16606400E-01, 0.55880300E-02, -.58276700E-03, 0.32799700E-01, -.13935800E-03, -.11255400E+00, -.29505200E-01, -.23755000E-01, 0.28833200E-01, -.94824700E-02, 0.41106700E+00, -.85489700E-01, -.50361700E-01, -.84860100E-02, -.30067100E+00, 0.93527500E-01, 0.36763200E-02, -.20327400E-01, 0.17527500E-01, -.22756000E-01, -.83537900E-02, -.23040900E-01, -.77870300E-02, 0.25199300E-01, -.12439700E-02, 0.34980500E-01, 0.19801800E-02, 0.53239900E-01, -.19917400E-01, 0.92816600E-01, 0.45258100E-02, 0.22616400E-01, 0.15967200E-01, 0.76783200E-02, -.20007000E-01, 0.54103400E-02, -.11301300E-01, 0.20639600E-02, 0.42824100E-01, -.44164700E-01, -.86723500E-01, 0.13018400E-01, -.21053100E-01, 0.30651000E-01, -.11342500E-01, -.24773600E-01, 0.72915600E-03, -.18978800E-01, 0.22340500E-01, -.25695100E-01, -.76384600E-01, -.15268200E+00, 0.62871600E-01, -.54716100E-01, 0.83908600E-02, 0.35068400E-01, 0.33941000E-03, -.11951700E-02, -.22722500E-01, -.40648100E-01, -.61309900E-01, 0.51965800E+01, -.16896000E+01, -.17437800E+01, -.15912100E+01, 0.56155200E+00, -.59296800E+00, -.24748400E+02, 0.12437400E+02, 0.78550400E+01, 0.12372000E+02, -.44598400E+00, -.53638200E+01, 0.62908900E+01, -.34232400E+01, 0.24620400E+01, -.46903700E+01, 0.12126100E+02, 0.36927900E+00, -.53460800E+00, 0.22464800E+01, -.18539800E+00, -.33360300E+00, 0.75604600E+00, -.25072200E+01, -.57590500E+01, -.31057700E+01, 0.25251300E+00, -.11100700E+01, -.21487900E+02, 0.10557500E+02, 0.13952400E+02, 0.10741100E+02, 0.65136200E+00, -.32344300E+01, 0.59134100E+01, -.28258800E+01, 0.32919700E+01, -.36743400E+01, 0.48584400E+01, 0.58537500E+02, -.29159100E+02, -.18609200E+02, -.29268500E+02, -.24358500E+01, -.12567500E+02, -.42466700E+01, 0.17318900E+02, -.70096900E+01, -.14733900E+02, -.45912100E+02, 0.42709800E+02, -.21577500E+02, -.16873400E+02, -.21357700E+02, -.45356200E+01, -.82496700E+01, -.37148400E+01, 0.93995200E+01, -.11159900E+02, -.85972700E+01, -.27470100E+02, -.58754700E+02, 0.29505800E+02, 0.22526200E+02, 0.29372500E+02, 0.27216000E+01, -.35280200E+01, 0.17321000E+02, 0.71938000E+00, 0.19145700E+02, -.26613600E+01, 0.21462700E+02, -.21593000E+02, 0.10698900E+02, 0.48514000E+01, 0.10792100E+02, -.18905400E-01, 0.55173300E+01, 0.33379500E+01, -.59600800E+01, 0.36606600E+01, 0.36957700E+01, 0.12908700E+02, 0.45326700E+01, -.22558200E+01, 0.27091400E+01, -.22586700E+01, 0.55208000E+01, 0.10324500E+02, -.10281600E+02, -.12367500E+02, -.16200900E+02, 0.98560500E+01, -.22288400E+01, -.30052500E+00, 0.46480100E+00, -.29612200E-02, -.12955300E+00, 0.13874000E+00, -.36460100E+00, 0.37340400E+00, 0.54707200E-01, 0.53211400E-01, 0.17010800E+01, -.15805600E+01, -.17733400E-01, -.52749600E+00, -.11317600E+00, 0.45321500E+00, 0.15354700E+01, -.38146900E-01, 0.12306000E+01, 0.44032500E+00, 0.53627100E+01, -.21466800E+00, -.52417500E+00, 0.14509900E+00, 0.53509600E+00, -.20921000E+01, 0.18502900E+01 },
        { -.49943900E+01, 0.21211200E+00, 0.25971000E-01, -.15000300E+01, -.83194500E+00, 0.14848100E+01, 0.65786000E-01, 0.15997600E+01, -.73404000E+01, 0.19171800E+00, 0.20473000E-01, -.18878000E+01, 0.94224300E-02, -.33316500E-01, -.63562500E+00, 0.37057500E-01, -.76422200E+00, -.93941400E+00, -.12528100E+01, 0.81457100E+00, 0.10780300E+01, 0.33054600E-01, -.15903600E+02, -.57604000E+00, -.10975300E+00, 0.39937900E+00, -.32233300E+00, 0.17073500E+01, 0.20593000E+01, 0.13240300E+01, 0.12398300E+01, -.77427900E+00, -.16277900E+00, 0.12516200E+00, -.55167600E+01, 0.12614000E+00, -.11101400E+00, 0.25595700E+00, -.41604800E+00, -.36053100E+00, -.13964600E+00, 0.93792300E+00, -.42067900E-01, 0.62503900E+00, -.81809000E+00, 0.50383100E-03, -.37489700E+00, 0.22701700E-01, -.19642200E+00, 0.11219800E+00, -.13438500E+01, 0.75887200E+01, -.68579500E+00, 0.62549600E+00, 0.12000000E+01, -.89663500E+00, 0.21382400E-01, -.21815700E+00, -.77084400E-01, -.12715500E+00, -.21380900E+00, 0.11496600E+00, -.23096800E+00, 0.46187200E+00, -.22384100E-01, -.47519100E+00, 0.14566200E+01, 0.28327700E-01, 0.16979800E+01, -.44678500E-04, 0.87152100E-01, -.43983500E+00, -.17050800E+00, 0.44160200E+00, 0.15717700E+00, -.60328200E+00, -.27162500E-01, 0.33819300E+01, -.24886800E+01, 0.12277400E+01, 0.11466700E+00, -.16705900E+01, 0.12622700E+01, -.10159200E+01, 0.15432500E+01, 0.16148800E+01, 0.37682600E+00, 0.69805500E-01, -.33129900E-01, 0.19417700E+01, -.71131300E+00, 0.19859500E+00, 0.59961600E+00, -.20216300E+00, -.10994200E+00, -.29764100E+00, -.23186000E+00, 0.63836800E-01, 0.26418800E+01, -.10102300E+01, -.20920100E+00, -.11269700E+01, 0.79515600E+00, 0.44732800E+00, -.74031200E-01, -.71312600E+00, 0.96004700E-01, 0.28531100E+01, 0.37122600E+00, -.14737100E+00, 0.20787500E+01, -.12209300E+00, 0.13938800E+00, 0.47541900E-04, -.21095300E+00, 0.47662000E+00, 0.73575400E-01, 0.54530800E+01, 0.54240700E+00, 0.29781400E+01, -.23921900E+00, 0.17710800E+00, -.34881000E-01, -.57339300E-01, -.38399500E-01, -.12508400E+01, -.20507500E+00, 0.34779100E+00, 0.73921600E-01, -.37301300E+01, 0.15018800E+01, -.88899600E+00, 0.44861900E+00, -.54456900E-01, -.65080700E+01, -.18750600E+00, 0.24481100E+00, 0.10627100E+00, 0.31600300E+00, -.99117400E-01, -.83926800E-01, -.51246300E+00, 0.16545100E+00, -.76565900E+00, 0.92135700E-01, 0.76369100E+00, 0.19576500E-01, -.11121100E+01, -.58136800E-01, 0.17667100E+01, 0.11274400E+00, 0.21132800E+01, -.27633100E+01, 0.30323700E+00, -.11634400E+00, -.33054900E+00, -.50120000E+00, 0.16828600E-01, -.21738200E+01, 0.57997900E+00, 0.66287800E-01, -.74785000E+00, 0.11987500E+00, -.43487300E+00, 0.53848600E-01, -.47101500E+00, 0.32120000E+00, 0.89236400E+00, -.19544900E+00, -.29457100E+00, 0.90654800E+00, -.20516200E+01, -.44284400E+00, 0.13961300E+01, 0.70302600E-01, -.22256800E+00, 0.23269200E+00, 0.25125300E+00, 0.15387000E+01, 0.25014700E+01, -.18680200E+00, 0.13364900E+01, 0.13255400E+03, 0.12414300E+03, 0.54627900E+02, 0.95661400E+01, -.10455400E+03, 0.74343900E+03, -.39997500E+03, -.19577100E+03, -.37170800E+03, -.40065900E+02, 0.28822300E+02, -.15317500E+03, 0.66725500E+02, -.32895300E+03, 0.13697600E+03, -.58536200E+03, -.17846200E+02, -.31588000E+01, 0.45257700E+02, 0.89361800E+01, -.15794600E+01, 0.17128700E+02, 0.91794000E+02, -.23205400E+02, -.91331000E+02, -.19804500E+02, -.81693400E+02, 0.60176200E+03, -.31635000E+03, -.35516500E+03, -.30084600E+03, -.12426400E+03, -.74069300E+02, -.13880900E+03, 0.91414400E+02, -.17466700E+03, 0.44604700E+02, -.23487800E+03, 0.10862700E+04, -.53446000E+03, -.63285500E+03, -.54313800E+03, -.15109000E+03, -.10933400E+03, -.22114100E+03, 0.14453500E+03, -.23777300E+03, -.13508100E+03, -.90262600E+03, 0.95917700E+03, -.47508600E+03, -.53211600E+03, -.47957500E+03, -.40227800E+02, -.14298200E+02, -.31989200E+03, 0.14519400E+03, -.12360500E+03, -.27850300E+02, -.65811300E+03, -.12816400E+03, 0.58250800E+02, 0.30590600E+03, 0.64217900E+02, 0.15464400E+02, 0.51945400E+02, -.29702400E+02, -.37412600E+02, 0.38471800E+02, 0.49348800E+02, 0.18329800E+03, -.20815200E+03, 0.10231100E+03, 0.19679300E+03, 0.10420100E+03, 0.96254200E+02, 0.60396200E+02, 0.97561200E+02, -.29889000E+02, 0.43101900E+02, 0.92497300E+02, 0.41827600E+03, -.15868500E+03, 0.81450500E+02, -.88786700E+02, 0.79226600E+02, 0.35269500E+02, 0.13186000E+02, 0.11803000E+03, 0.61855400E+02, -.44155100E+02, 0.33736800E+02, -.41795400E+02, -.89809700E+01, 0.49364900E+01, -.12183300E+02, -.74812600E+01, 0.72153000E+00, 0.60662800E+01, 0.39619100E+02, -.59725900E+00, 0.92874900E+01, -.93370600E+01, 0.83589100E+01, 0.44394900E+01, -.59925600E+01, 0.82471900E+01, -.46806400E+02, -.12565600E+02, -.67425000E+01, 0.11776300E+02, -.55136100E+02, 0.48577300E+02, 0.33168800E+02, -.32844700E+02, -.12182900E+02, -.31896300E+01, 0.53321300E+01, 0.92171100E+01 },
        { -.73794200E+01, 0.23189800E+00, 0.27643600E+00, 0.26876300E+00, -.72158800E+00, 0.19390400E+01, -.68195400E+00, 0.39732400E+00, -.35882000E+00, 0.20397500E+01, -.33800900E-01, 0.64648300E+00, 0.20982100E+00, -.13240000E+00, -.12846400E+00, 0.10094800E+00, -.27625400E+00, -.51753400E+00, -.40581700E-01, 0.82309200E+00, 0.68575900E-01, 0.69207200E-01, -.54015700E+01, -.11029600E+01, 0.34955500E-01, -.10763500E+00, -.11565100E+00, -.32729400E+00, 0.11674000E+01, -.12954700E+01, -.15895200E-01, 0.12312700E+01, -.48034400E-01, 0.13414000E+00, -.90864800E+00, 0.62030000E-01, -.64740200E-01, -.43476000E+01, 0.34176100E+00, 0.17889900E+00, -.23823200E+00, 0.38766300E+00, 0.69265100E+00, -.16594900E+01, -.52302700E+00, 0.14113300E+00, 0.29824500E+00, 0.90448700E-02, 0.63256000E+00, 0.17647500E+00, -.12062100E+01, -.20896200E+01, 0.14199500E+00, 0.22071100E-01, -.39042100E+01, -.26473200E+00, -.11740600E+00, 0.42903900E+00, 0.41914600E+00, -.30072800E-01, 0.11778500E+00, -.68627600E+00, -.50170000E-01, 0.20517200E+00, 0.12778900E+00, -.10502700E+00, -.20365200E+00, -.27877000E-02, 0.96555200E+00, 0.83282500E-03, 0.65486200E-01, 0.23338300E+00, 0.26413300E+00, 0.19240800E+00, -.65662200E+00, 0.45953100E+00, 0.89848000E+00, 0.52645700E+01, 0.22072400E+00, 0.64782500E+00, 0.74088600E-01, -.31189900E+00, 0.13947000E+01, -.70669100E-01, 0.18077600E+01, 0.59065000E+01, -.11319900E+00, 0.24714800E+00, -.65329400E+00, 0.90947800E+00, 0.62046400E+00, -.85383100E-02, 0.50005700E+00, -.65519800E-01, -.44528800E+00, 0.44381600E-01, 0.18639700E+00, -.56540200E+00, -.19137800E+00, 0.55195800E+00, -.88883000E-01, -.34295000E+00, -.29267100E-02, -.30556700E-01, -.29718700E-01, 0.69553800E+00, -.96111400E-01, -.46311700E+01, 0.85739500E-01, 0.58362200E-01, 0.20227500E+01, -.57369400E-01, 0.38432700E+00, -.63367900E-02, -.85972100E+00, -.35651300E+00, -.86457700E-01, 0.62328000E-01, -.35261900E+00, 0.82688000E+00, -.18323100E+00, -.18024900E+00, -.42596000E-02, -.83030600E-01, -.11134400E-01, 0.62007600E-02, 0.21747600E+00, 0.16981400E+00, -.35046100E+00, 0.58927500E+00, -.42071300E+01, 0.10358900E+01, 0.15071500E+00, 0.96566700E-02, 0.16831500E+01, -.31426100E+00, -.68055700E-01, -.11195700E+00, -.42264600E-01, 0.56398400E+00, 0.44123400E+00, -.72184000E+00, 0.14890700E-01, 0.57985900E+00, -.18343800E-01, -.38337600E+00, 0.87348500E-02, -.11089600E+01, 0.23782600E+00, 0.19866900E+01, 0.29521500E+00, -.10046400E+01, 0.12103500E+01, -.16021600E+00, -.29318800E+00, -.69012500E-01, 0.62636900E-01, 0.26070900E-01, 0.58250900E+00, 0.25393600E+00, 0.79458300E-01, 0.24658700E+00, 0.37717300E+00, -.36221600E+00, 0.19788600E+00, -.58631200E+00, -.11183200E+00, -.15422600E+00, -.13605100E+00, 0.24900600E+00, 0.63934200E+00, -.17558100E+01, -.18143200E+00, -.11698500E+01, 0.43037700E+00, 0.19675300E+00, 0.16480900E+00, -.27511100E-01, -.57789300E+00, -.99125400E+00, -.64587600E+00, 0.52391700E+01, -.34877000E+00, 0.48769500E+02, 0.27148800E+02, 0.80388100E+01, -.29174800E+02, 0.21430600E+03, -.11021100E+03, -.29350700E+02, -.10714800E+03, -.55052600E+01, 0.60156600E+02, -.32767700E+02, 0.41437400E+02, -.10735300E+03, 0.41811100E+02, 0.50071300E+02, -.17462700E+02, -.17642700E+02, -.87876900E+02, 0.87305400E+01, -.43065100E+01, -.14487700E+02, -.78373100E+01, -.25639700E+02, 0.13836500E+02, -.24852500E+02, -.39155700E+01, 0.18777200E+03, -.95176300E+02, -.12279900E+02, -.93872800E+02, -.71094400E+00, 0.33003600E+02, -.79546300E+01, 0.87652400E+02, -.58409100E+02, 0.11765000E+02, 0.75316800E+02, 0.15357000E+03, -.74366200E+02, -.13063100E+03, -.76785200E+02, -.65055800E+01, 0.49729700E+02, -.69853800E+02, 0.42111600E+02, 0.14608900E+02, 0.45615800E+02, -.60998900E+02, 0.33809200E+03, -.17162600E+03, -.14815600E+03, -.16903700E+03, -.45234400E+02, 0.38397300E+02, -.14019700E+03, 0.41961700E+02, -.85364800E+01, 0.26413900E+02, -.75479400E+02, 0.34493100E+03, -.17060200E+03, -.42856700E+02, -.17238200E+03, -.15493700E+02, 0.42813700E+02, -.96879500E+02, 0.30150300E+02, -.10554700E+03, 0.29701100E+02, -.79737400E+02, 0.26289700E+03, -.13288200E+03, -.18662500E+03, -.13141000E+03, -.10656000E+02, -.49894900E+02, -.84286900E+02, 0.22220200E+01, -.67000500E+02, -.30569000E+02, -.13959800E+03, -.94758500E+02, 0.45197200E+02, -.13291600E+02, 0.47343100E+02, -.20086600E+02, -.54990800E+02, 0.84470800E+02, 0.61295000E+02, 0.54755300E+02, -.49128900E+02, 0.22719200E+02, 0.14590200E+00, 0.11872600E+01, -.79814100E+01, 0.12912000E+01, 0.50489300E+01, -.54002100E+01, 0.88887900E+01, 0.21921000E+00, 0.78778800E+01, -.25710700E+02, 0.24906000E+02, 0.74197000E+01, -.32032400E+01, -.48573300E+01, 0.12203600E+01, -.25592400E+02, -.19170600E+01, 0.47856100E+01, 0.12903400E+02, 0.15512100E+02, -.36273500E+01, 0.83298100E+00, -.15797600E+02, -.23262900E+02, 0.10221300E+01, -.19924500E+02 },
        { 0.80147500E+01, -.24386600E+00, -.12573700E+00, 0.13420600E+01, 0.10240400E+01, -.15207100E+01, -.14222200E+01, -.13852800E+01, 0.75844100E+01, -.56583500E+00, 0.28307100E-01, 0.14235100E+01, -.86152600E-01, -.35313000E-01, 0.59710800E-01, -.18192900E-01, 0.97170100E+00, 0.98339600E-01, 0.11935300E+01, -.71696000E+00, -.28798500E+00, 0.41950600E-02, 0.33462200E+01, -.29791200E+00, -.17182500E+00, -.20512900E+00, -.27265100E-01, -.14048800E+01, -.74651600E+00, -.11024000E+01, -.20853100E-01, -.98787800E+00, 0.11321100E+00, 0.14293100E-01, 0.55227700E+01, -.18298100E+00, 0.27099100E+00, 0.12957300E+01, -.54360100E+00, 0.54270700E+00, 0.34417800E+00, 0.20315100E+00, -.28398800E+00, 0.88909600E+00, -.59487800E+00, 0.35024600E+00, -.56385800E+00, -.43131200E-01, 0.54239400E+00, -.14271600E+00, -.18408900E+00, -.36938600E+01, 0.16730500E+00, -.11494800E+01, 0.63214600E-01, 0.10256100E+01, 0.60991900E-01, -.56103400E+00, -.29470700E+00, 0.13527700E+00, 0.72221900E+00, 0.44069600E+00, -.59064500E+00, 0.18049400E+00, 0.29253900E+00, -.11375700E+00, 0.32248800E+00, 0.12526200E-01, -.34472200E+00, -.57244100E-02, 0.10945900E+00, 0.39096900E+00, 0.41527400E+00, -.39380000E-02, 0.73796000E+00, -.49417300E+00, 0.19336700E+00, -.51946600E+01, 0.11458400E+01, -.45261400E-01, -.24664000E-01, -.71397900E+00, 0.17612800E+01, 0.99098200E+00, -.69940200E+00, -.10451200E+02, -.37374700E+00, -.27824300E+00, 0.13779000E+01, -.15620700E+01, 0.57875400E+00, 0.32998600E-01, 0.16517400E+00, 0.37236600E+00, -.32043300E+00, 0.60080100E+00, 0.10522100E+01, 0.10460600E+01, 0.96525700E+00, 0.11587200E+00, -.12010200E+00, -.10326800E+01, -.29873500E-01, 0.83529200E+00, 0.18650300E+00, -.48534300E+00, 0.46360800E-01, 0.19674200E+01, 0.14211800E+00, 0.93333600E-01, 0.81115500E+00, 0.33773100E-02, 0.14800700E+00, 0.15544500E-02, 0.44263500E+00, 0.52439700E-01, -.15336200E+00, 0.32356300E+01, -.49879700E+00, 0.18302100E+01, 0.37762800E+00, -.21955800E-01, -.16289800E-01, -.37025700E+00, -.55501400E-01, 0.41236700E+00, 0.92900100E-01, 0.12044000E-01, -.36826100E+00, -.11891300E+01, -.22196200E+01, 0.36355900E+00, 0.42296100E+00, 0.88275500E-01, -.27894300E+01, -.29213900E+01, -.10154300E+00, 0.36880700E+00, -.23663700E+00, 0.53704800E+00, -.31653200E+00, -.10203400E+01, 0.14072300E+00, -.75342900E+00, 0.56304500E-01, 0.23881800E+00, 0.27260600E-01, -.16762100E+01, 0.10164600E+00, 0.18159600E+01, 0.33324500E+00, 0.23510700E+00, 0.24236700E+00, -.36525700E-01, 0.16677700E-01, -.19402200E+00, -.17253100E-01, 0.33144900E-02, 0.62839000E+00, 0.53021000E+00, -.69336400E+00, -.13778500E-02, 0.29874800E+00, -.88161600E+00, -.18471000E-02, -.66008200E+00, 0.10313300E-01, -.56512400E+00, -.98706100E-01, 0.99419500E+00, 0.78595100E+00, 0.51020000E-01, 0.26826600E+00, -.10378100E+01, 0.78185800E-02, -.15962800E+00, 0.22472800E-01, -.10656400E-01, -.31341700E+00, -.29627100E+00, -.30458600E+00, -.12948300E+01, -.23463200E+00, 0.46672600E+00, 0.78465100E+02, -.13888200E+02, 0.44571200E+01, 0.13814600E+03, -.80929900E+02, 0.97483900E+02, -.69085200E+02, 0.47175700E+02, -.68208900E+02, 0.23556900E+02, 0.12213300E+03, 0.10436300E+02, -.56794800E+02, -.89122500E+02, 0.89617100E+02, -.56877700E+02, -.10416400E+03, -.44801000E+02, -.78821200E+01, -.34655300E+02, -.82646000E+01, -.14654400E+02, -.61488900E+02, -.43970600E+02, -.24086700E+02, 0.67352800E+02, -.39067100E+02, 0.10142900E+03, -.33684500E+02, 0.48534000E+02, -.50968800E+02, 0.20778000E+02, 0.71758800E+02, 0.14215700E+02, -.42385600E+02, -.18136200E+02, -.11969400E+03, 0.62751400E+02, 0.12384800E+03, 0.59847900E+02, 0.20156900E+02, 0.13772000E+01, -.39310500E+01, -.86702700E+02, -.41028000E+02, 0.16438400E+02, -.12195800E+03, -.28586700E+02, 0.14269900E+02, 0.10708200E+03, 0.14272900E+02, -.21046400E+02, 0.70089800E+00, 0.25580900E+01, -.45765000E+02, -.35944600E+02, 0.71912500E+01, -.69885300E+02, -.58584000E+03, 0.28894900E+03, 0.38882600E+03, 0.29289300E+03, 0.24605100E+02, -.18947000E+02, 0.15657800E+03, 0.39075200E+01, 0.19262200E+03, -.95604300E+01, 0.18339100E+03, 0.94568000E+02, -.49126000E+02, -.80220000E+02, -.47260700E+02, -.13078500E+02, -.95995000E+01, -.10190100E+01, -.21810000E+01, 0.22872900E+02, -.21196900E+02, 0.21387700E+02, 0.21856500E+03, -.10850600E+03, -.14504100E+03, -.10929700E+03, 0.27518200E+02, 0.60559800E+02, -.87423800E+02, -.86885500E+02, -.17166400E+03, 0.62717700E+02, -.54006800E+02, -.36496400E+01, -.21953000E+00, 0.29622100E+01, -.16219500E+01, -.43996600E+01, 0.32549900E+01, 0.54470500E+01, 0.73746600E+00, -.19356900E+01, 0.22976800E+02, -.23670300E+02, 0.73644300E+01, -.30957800E+01, 0.68853800E+01, -.15110800E+01, 0.22105000E+02, 0.32700900E+01, -.53549100E+00, -.55946400E+01, 0.42719300E+00, -.25232500E+01, -.90568600E+01, -.65429000E+00, 0.21614100E+02, -.18982900E+02, 0.22731100E+02 },
        { 0.20899700E+01, -.10268800E+00, -.78418300E-01, -.10100100E+01, 0.36315800E+00, -.47783400E+00, 0.21575700E+00, -.15087800E+00, -.12925900E+00, -.29587000E+00, 0.88221700E-01, -.32379300E+00, 0.19939000E-01, -.83508500E-02, -.13965700E+00, 0.15273900E-01, -.32812400E+00, -.22330100E+00, -.80394300E-01, 0.13831700E-01, 0.16402800E+00, -.12300500E+00, 0.30850700E+00, -.96744100E-01, -.11645500E-03, 0.43189800E-01, 0.20427200E+00, -.48269400E+00, -.23860000E+00, 0.11039100E+01, 0.28781200E-01, -.17130200E+00, -.32319900E-01, -.47463400E-01, 0.99064800E+00, 0.90848200E-02, 0.13245300E-01, 0.77390600E-01, -.12758700E+00, -.25333400E-01, 0.15604800E+00, 0.16039900E+00, 0.18335200E+00, 0.38625700E-01, -.48920700E-01, 0.53548200E-01, -.69757100E-01, -.34128600E-02, 0.29505700E-01, 0.43085300E-01, -.58157300E-01, -.25188500E+00, 0.19049500E-01, -.35763200E-01, 0.41070300E+00, -.12997400E+00, 0.12036700E-01, -.19739800E+00, -.22240500E-01, -.85039900E-02, 0.74094600E-02, 0.59441600E-01, -.12153900E+00, 0.35778100E-01, -.86712700E-01, -.61272800E-02, -.52397300E-01, 0.15802900E-02, 0.17889300E+00, -.10289400E-02, 0.15419600E-02, 0.80341400E-02, 0.53935700E-01, -.21960300E-02, -.22128100E-01, 0.47967500E-01, -.13645100E+00, -.64320700E+00, 0.21712900E+00, -.85862200E-01, -.43873900E-02, -.67068600E-01, -.95541900E-01, 0.13098700E+00, -.21993100E-01, -.97556500E+00, 0.61855100E-02, -.26281600E-01, 0.12864900E-01, -.19057400E-01, -.16781100E+00, 0.16254000E-03, 0.40482100E+00, 0.58123500E-01, -.76563400E-01, 0.15381200E+00, 0.59013100E-01, 0.15458400E+00, -.18839300E+00, 0.97496000E-01, -.12075100E-01, -.14157700E+00, -.11930400E-01, 0.99865500E-01, -.56922900E-02, -.14572500E-01, 0.35525900E-03, -.93757900E+00, 0.27552100E-01, 0.71363000E-02, 0.23674000E+00, 0.46303000E-02, 0.18301000E+00, 0.40720200E-02, -.12655300E+00, -.47377100E-01, 0.31767200E-01, 0.10076300E+01, 0.34878400E-01, 0.14538400E+00, -.88633700E-01, -.33538200E-01, -.11438200E-02, -.76592500E-01, -.80220600E-02, -.55956400E+00, -.80929800E-02, -.16726000E+00, -.12728900E+00, -.14487600E+00, 0.46286600E-02, -.39928200E-01, 0.76203700E-01, -.27161600E-01, -.44966000E+00, 0.13482800E+00, 0.15940000E-01, 0.50850200E-02, -.13763000E+00, -.25754000E+00, 0.34746800E+00, -.43849600E-01, 0.22658800E-01, 0.18448000E+00, -.12336900E-01, 0.27372000E-01, 0.22330000E-01, 0.55328600E+00, -.12324300E+00, 0.43101100E+00, 0.50879000E-01, -.32076800E-02, -.41399500E+00, -.61044900E-01, -.92597400E-01, 0.15132000E-01, -.12720000E-01, 0.17390700E-02, 0.61045900E+00, 0.82116600E-01, -.17093400E+00, 0.44913700E-01, -.42274700E-01, -.25535400E-01, 0.53368700E-01, 0.20377600E-01, -.35709000E-01, 0.67822100E-01, 0.99796300E-01, -.25319700E-01, -.24862200E+00, -.13433800E+00, 0.10923400E+00, -.37776400E+00, -.40124200E-02, 0.37379000E-02, -.12868900E-01, -.12768400E-01, -.50787500E-01, -.39382000E+00, -.23010300E+00, 0.68445800E+00, 0.30716500E-01, 0.11876900E+00, -.57048000E-01, -.22225400E+02, 0.30515800E+02, -.13480400E+02, 0.99904600E+01, -.26513000E+02, 0.67411200E+01, 0.62003700E+01, -.21678900E+02, -.18874800E+01, -.63596900E+01, 0.21601300E+02, -.41870800E+02, 0.14325900E+03, 0.91152900E+01, -.10501000E+01, -.24445800E+02, -.45454700E+01, -.60850700E+01, -.44547600E+01, -.20985600E+02, 0.21289700E+01, 0.24814600E+02, -.12587700E+02, 0.13550300E+02, -.51752900E+02, 0.27689200E+02, 0.99876100E+01, 0.25876800E+02, 0.46195100E+02, 0.24627400E+02, 0.43080800E+00, -.27349000E+02, 0.41252800E+01, 0.73120500E+01, 0.10478500E+03, -.16182600E+03, 0.80191000E+02, 0.11377600E+03, 0.80912700E+02, 0.44403100E+02, 0.17647300E+02, 0.20467500E+02, -.28998300E+02, 0.14338300E+02, 0.19829000E+02, 0.99133400E+02, -.93152100E+02, 0.45559500E+02, 0.50239800E+01, 0.46572300E+02, -.69530000E+01, -.99367100E+01, 0.62796800E+02, -.15656700E+02, -.18715800E+02, -.11840900E+02, 0.74940600E+02, -.92062400E+02, 0.42791900E+02, 0.11708900E+02, 0.45981000E+02, 0.91756000E+01, 0.28926000E+01, 0.20132300E+02, -.15544400E+02, 0.14910500E+02, 0.11038700E+02, 0.12524400E+02, -.30943800E+02, 0.14841400E+02, 0.77283600E+02, 0.15480900E+02, 0.74413800E+01, 0.21572700E+02, -.40116600E+02, -.23252000E+02, 0.51001200E+01, 0.40334900E+01, 0.27529400E+01, 0.38889900E+02, -.20960400E+02, 0.29121700E+02, -.19513500E+02, 0.10949900E+02, 0.37954000E+02, -.43846300E+02, -.31833200E+02, -.32198400E+02, 0.30118400E+02, 0.46737900E+02, -.42075200E+00, 0.25912800E+00, 0.22190400E+01, -.10485100E+01, -.32769200E+01, 0.12858500E+01, 0.21110700E+01, 0.41860100E+00, -.21108200E+01, 0.92384500E+01, -.78437300E+01, 0.10792700E+02, 0.35742200E+01, 0.25710900E+01, -.94768900E-01, 0.89975400E+01, 0.36399300E+01, -.17713000E+01, 0.10702200E+02, 0.16642800E+02, -.11047500E+02, -.46062700E+01, 0.12303300E+02, 0.11479300E+02, 0.38242300E+01, 0.55612400E+01 },
        { 0.10949800E+02, -.19756400E+00, -.44575900E+00, -.13414600E+01, 0.10917500E+01, -.22397100E+01, -.61801600E+00, -.58749300E+00, 0.16024800E+01, -.17393200E+01, -.83407000E+00, 0.15783000E+01, 0.29243500E+00, -.71711800E-02, -.47760600E-01, -.20425400E+00, -.24851600E+00, -.36460700E+00, 0.17628900E+00, -.77431200E+00, -.14845900E+01, 0.54386300E+00, -.69273200E+01, -.11247900E+01, -.84808700E-01, -.16747900E+00, 0.35611800E+00, -.11773900E+01, -.22284200E+01, 0.16340900E+01, 0.13061700E-01, 0.30722100E+01, 0.36477700E+00, -.20272600E+01, 0.99037400E+00, 0.86884600E+00, -.76428600E-01, 0.22254900E+01, -.22979100E+00, 0.17489900E+00, -.48111400E+00, -.12216300E+01, 0.13124500E+00, -.50962100E-01, -.10176700E+00, 0.86317900E-01, 0.30079900E+00, 0.67681600E-02, 0.51951400E+00, -.13033400E+00, 0.15894400E+00, -.26319500E+01, -.46805300E-01, 0.24460100E-01, 0.41609500E+01, -.87544200E+00, -.10421900E+00, -.47263900E+00, 0.66240800E-01, 0.20015300E+00, -.34888600E-01, -.59900300E+00, 0.14679200E+00, -.20675900E+00, -.25484600E+00, 0.18237000E+00, -.87146500E+00, -.44536900E-01, 0.57674800E+00, -.45609000E-02, -.20796600E+00, -.17811300E+00, -.32589000E-01, -.69653000E-01, -.13544700E+01, 0.38347700E+00, 0.51233500E+00, 0.26861200E+01, 0.81135000E+00, 0.56812900E+00, -.11933600E-01, -.78065000E+00, -.12138300E+01, -.41570800E+00, 0.29895400E+00, 0.44919800E+01, 0.82010300E-01, 0.74665400E-01, -.20085100E+00, 0.41499000E+00, -.33831700E+00, -.26853900E-01, 0.12339800E+01, -.33826000E-01, -.18821900E+00, 0.48344300E+00, 0.71417300E+00, 0.43168200E+00, 0.22587300E+01, -.30611200E+00, 0.13476500E-02, -.37986400E+00, -.29831600E+00, -.31808800E+00, 0.28632000E+00, -.17512500E+00, 0.12314200E+00, -.83733800E+00, -.36379500E-02, 0.66607300E-03, 0.32477900E-01, 0.60692700E-01, 0.50868500E+00, 0.18670000E-01, 0.42067700E+00, 0.59708500E+00, -.15546700E+00, 0.57657100E+01, -.19467700E+00, -.30545000E+01, 0.47221900E+00, 0.78583000E-01, -.85544300E-02, 0.31575000E-01, 0.23522700E-02, -.97177800E+00, -.23066200E+00, 0.97581600E+00, 0.48265300E+00, -.52115500E+00, -.74490400E+01, -.87577300E-01, -.17402100E+00, 0.10343700E-01, -.47155200E+01, 0.10636300E+01, 0.57412400E-02, 0.16923400E+00, -.15193500E+00, -.34242100E+00, 0.48967500E-01, -.15819000E+00, 0.23886200E+00, -.72860700E-01, -.38819800E-01, -.27866000E+00, 0.13411400E-01, -.61361600E+00, -.35206300E-01, -.21734000E+01, -.27733800E+00, 0.48804400E+00, -.19640700E+01, 0.11692400E+00, 0.27471100E+00, 0.84604700E-01, 0.24413300E+00, -.87116200E-01, -.22972200E+00, 0.20124100E+00, -.13890600E+00, 0.83158800E-01, 0.77334100E-01, -.32510600E+00, -.88200800E-02, 0.34714400E+00, -.74131400E-01, -.43636400E+00, -.11346500E+00, 0.42615800E-01, -.22174700E+00, 0.39346300E+01, 0.48709300E-01, -.95272300E+00, 0.12963700E+00, 0.70863000E-01, -.10103000E+00, -.14335500E-01, 0.11372000E+00, -.94102100E-01, -.19058600E+00, 0.73282700E+00, -.25012200E+00, 0.70522800E+00, -.12065300E+00, 0.16104500E+01, -.10239900E+03, -.12158600E+03, 0.47880400E+02, 0.11676500E+03, 0.60806400E+02, -.28365800E+02, -.15305200E+02, 0.16716900E+02, -.10667300E+03, 0.13112000E+02, 0.26591100E+02, -.22905200E+03, 0.18667400E+02, 0.25566900E+00, 0.16511100E+02, -.93257200E+01, -.10877800E+01, -.20454700E+01, 0.23499900E+02, 0.63613700E+02, 0.35704000E+02, -.13155500E+01, -.37782300E+02, -.69079700E+02, 0.28799200E+02, 0.57287300E+02, 0.34556700E+02, -.61743000E+02, -.38837100E+02, 0.18236100E+02, -.55302900E+02, 0.17595500E+02, 0.19640800E+02, -.14529600E+03, 0.11412200E+02, -.46631500E+01, -.87152700E+01, -.57076300E+01, 0.23896800E+02, -.26685400E+02, 0.13530300E+02, 0.51259800E+02, 0.30403000E+02, -.46769400E+02, -.21306800E+03, -.31655200E+03, 0.16054400E+03, 0.13613200E+03, 0.15829200E+03, 0.78443600E+02, 0.43982300E+02, 0.47269100E+02, -.15051600E+02, 0.95547000E+02, 0.32374000E+02, 0.30888400E+02, 0.54623700E+02, -.37436000E+02, -.19875100E+02, -.27302100E+02, 0.11889800E+02, 0.20322800E+02, -.45247800E+02, -.73796300E+02, -.61532200E+02, 0.28004600E+02, -.36818100E+02, 0.45711500E+02, -.23499100E+02, -.70691200E+02, -.22827100E+02, -.20898900E+02, -.14226400E+02, 0.15396600E+02, 0.53232400E+02, 0.11437800E+02, -.20258500E+02, -.23780600E+02, -.65767000E+02, 0.36733900E+02, 0.75855400E+01, 0.32826300E+02, -.62393600E+01, -.17432100E+02, 0.42820600E+02, 0.65474200E+02, 0.97590200E+02, -.14814500E+02, 0.18574900E+02, 0.25648200E+00, -.24271400E+01, 0.77295200E+01, 0.41726600E+00, -.45099400E+01, 0.48444700E+01, 0.38122400E+01, 0.24985200E+00, -.73904600E+01, 0.43872100E+01, 0.43007900E+00, -.20759200E+01, 0.53258400E+01, 0.36500300E+01, -.81579900E+01, 0.27515300E+01, 0.34631900E+01, 0.16081000E+01, -.18107000E+02, -.18076800E+02, 0.18989600E+02, -.64910100E+01, 0.14789700E+02, 0.11024400E+02, -.22799000E+01, 0.13107400E+01 },
        { 0.10138700E+02, -.22373100E+00, -.34340000E+00, 0.14309400E+01, 0.88320800E+00, -.65835900E+00, -.11984200E+01, -.27988800E+00, 0.36497300E+01, 0.47303200E-01, 0.50302200E-01, -.37366400E+00, -.97961000E-01, -.47971800E-01, 0.31819700E+00, -.27340500E+00, 0.93041300E-01, 0.64120600E-01, 0.17210300E+00, -.72760900E+00, 0.35559700E+00, 0.12534500E+00, 0.14572500E+01, 0.65930100E+00, -.20107800E+00, -.12275800E+00, -.43298900E+00, -.10706900E+01, -.36611800E+00, 0.66007200E+00, -.30994000E+00, -.90786500E-01, 0.70028400E-01, -.10782500E+01, 0.22049400E+01, -.35967400E-01, 0.15217000E+00, 0.10611300E+01, 0.47209800E+00, -.11304900E+01, 0.53681200E-01, -.54968800E+00, -.80123700E+00, -.47085700E+00, 0.70169400E+00, 0.17385500E+00, -.10349100E+00, -.22189900E-01, 0.61175000E+00, -.18450300E+00, -.28089300E+00, -.44389000E+01, -.27787200E+00, -.65083600E-01, 0.24214200E+01, -.62921900E+00, -.10557600E+00, 0.14197800E+00, -.24459700E+00, 0.28121900E+00, 0.17574600E+00, -.84262800E+00, 0.11225800E+00, -.31429800E+00, -.52882900E+00, 0.23343000E+00, -.15258300E+01, -.26950100E-01, -.81770100E+00, -.34689400E-02, -.74201600E-01, 0.14802400E-01, -.10240100E+00, -.10092100E+00, 0.17984700E+00, -.40796900E+00, 0.86673300E-01, 0.24724700E-01, 0.51162100E+00, -.87299700E+00, -.77501300E-01, -.25048300E+00, -.10538300E+01, 0.66943800E+00, -.16045300E+01, -.36127000E+01, -.16601400E+00, -.14671000E+00, 0.11070700E+01, -.84058900E+00, 0.23561900E-01, -.33902600E-01, 0.46291700E+00, 0.39248200E-01, -.10901200E+00, 0.13569700E+00, 0.43640600E+00, 0.33633400E+00, 0.11209300E+01, -.75779200E-01, -.61161600E-01, -.20917400E+00, -.23037700E+00, -.30762200E-01, -.29651800E-01, -.38689700E+00, 0.96812700E-01, -.58056300E+00, 0.70153600E-01, 0.60610200E-01, 0.44323200E+00, 0.53670400E-01, 0.60216600E+00, 0.84721700E-02, 0.17700100E+00, -.85505600E-01, 0.46597700E-01, 0.14923600E+01, 0.10085500E+00, -.74753700E+00, -.13931100E+00, -.25711000E-01, -.22723300E-01, -.18537800E+00, 0.87888100E-02, 0.11429600E+00, 0.23136000E-01, 0.52521100E-01, 0.29857600E-01, -.73455800E+00, -.16709400E+01, 0.32485700E+00, 0.32913800E+00, -.46767500E-01, 0.35201700E+00, 0.87158200E+00, 0.18253700E+00, -.10678300E+00, -.68676200E+00, 0.58551200E+00, 0.38510400E+00, 0.76223000E+00, 0.10249100E+00, 0.35225800E+00, 0.10004300E-01, -.11773600E+00, 0.25528000E-01, 0.63737600E+00, -.14749500E+00, 0.12407200E+01, 0.22700400E+00, -.37807900E+00, -.46950000E+00, 0.17411300E+00, -.29488500E+00, 0.20172300E-02, -.12350500E+00, 0.36317300E-01, -.21427800E+00, 0.11926000E-01, 0.13199500E+00, -.25007700E+00, 0.56866000E-01, 0.26249300E+00, 0.19565100E+00, -.74720300E-01, -.45488900E-01, 0.36342600E+00, 0.31953300E-01, -.27043900E+00, -.27467000E+00, -.10040500E+01, -.11409700E+00, 0.12834400E+01, -.18301100E+00, 0.30871400E+00, 0.14990800E+00, 0.45509600E-01, 0.36756500E+00, -.53434600E+00, -.16222800E+00, 0.36981100E+01, 0.30252500E+00, 0.47557000E-01, -.71633100E-01, 0.48987900E+00, 0.12034000E+00, 0.34264200E+03, -.16773800E+03, -.15331400E+03, -.17131100E+03, 0.24524700E+02, 0.10071100E+03, -.10766400E+03, -.41766300E+02, -.20267200E+03, 0.83817300E+02, -.14185800E+03, -.16143400E+02, -.13987000E+01, -.66476500E+02, 0.80753000E+01, 0.30074900E+01, 0.62966000E+01, -.66481800E-01, -.13157900E+02, 0.11372400E+02, 0.95751100E+01, -.20544500E+01, 0.15623900E+03, -.75458500E+02, -.97770500E+02, -.78107700E+02, -.90697600E+01, 0.46706000E+02, -.67509600E+02, -.31672100E+02, -.82564000E+02, 0.35751600E+02, -.56833300E+02, 0.21277000E+03, -.10993800E+03, -.13067600E+03, -.10638600E+03, -.22708900E+02, 0.24513400E+02, -.10110400E+03, 0.33396900E+02, -.45413600E+02, 0.49019200E+02, -.19971000E+02, 0.29881700E+03, -.14996900E+03, -.10132100E+03, -.14939500E+03, -.35808400E+02, -.11902400E+02, -.69551200E+02, 0.39454400E+02, -.69909400E+02, -.31469900E+00, -.12803400E+03, 0.15295800E+03, -.72314800E+02, -.19593600E+03, -.76466900E+02, -.21804200E+02, -.24703800E+02, -.12876000E+02, 0.70549100E+02, -.20795300E+02, -.29706900E+02, -.12099000E+02, -.42668500E+02, 0.21637200E+02, 0.68348700E+01, 0.21348300E+02, -.61361900E+01, -.52411000E+00, -.13008900E+01, -.51244300E+01, 0.35696700E+02, 0.27966800E+01, 0.86765100E+02, 0.15418000E+01, -.25435700E+01, 0.54000900E+02, -.80388400E+00, -.54129600E+01, 0.65896900E+01, -.36131700E+01, -.19646100E+02, -.33358100E+02, 0.90991200E+01, -.96963900E+01, 0.36855900E+01, 0.91967500E+00, -.21702100E+01, 0.83258500E+00, 0.41740100E+01, -.24482500E+01, 0.69895400E+01, -.19094800E+00, 0.27152200E+01, -.24339300E+02, 0.21588500E+02, 0.79869100E+01, 0.24990700E+00, -.32347100E+01, -.16850600E+01, -.22212600E+02, -.12189600E+01, 0.27733400E+01, 0.17349400E+02, -.19406000E+02, 0.12280400E+01, 0.45140000E+01, -.53693800E+01, -.32437800E+02, -.16947800E+00, -.23099700E+02 },
        { 0.25043100E+02, -.13138700E+01, -.29427900E+00, -.80173400E+00, 0.11511600E+01, -.29243900E+01, 0.15615400E+01, -.21303500E+01, 0.68698300E+00, -.18908800E+01, -.12317000E+00, 0.46848900E+01, -.24059700E+01, -.28728500E+00, -.96200100E+00, -.40841200E+00, 0.98191200E+00, -.26359900E+00, 0.35977800E+01, 0.51766100E+00, -.66736800E-01, 0.86674400E+00, -.21371100E+02, -.41870600E+01, -.28489300E-01, 0.12793900E-01, -.27417600E+00, -.92386700E+00, -.19939200E+01, 0.42349800E+00, -.86324600E+00, -.85091300E+00, 0.35718100E-01, -.11663800E+01, 0.70288300E+01, 0.57788100E+00, 0.18121400E+00, 0.13280500E+01, 0.97883900E-01, -.10167800E+00, -.10153400E+01, 0.27506500E+01, -.11751700E+00, -.12477300E+01, 0.25850300E+00, 0.44265000E+00, 0.15261900E-01, -.49542900E-01, 0.94909100E+00, -.34415400E+00, -.90094900E+00, 0.53699100E+01, -.40292000E+00, -.25010900E+00, -.71939000E+01, 0.40924200E+00, -.39832400E+00, 0.30207600E+01, -.11267000E+01, 0.84235900E-01, -.27865000E+00, 0.20452700E+00, 0.16204300E+01, 0.72879400E-01, -.36088300E+00, 0.42571400E+00, -.14824400E+01, 0.40184500E-01, 0.83808200E+00, -.51838000E-02, -.55290700E-01, 0.54229700E-01, 0.21943600E+00, -.61841000E-02, -.77808200E+00, -.64049900E+00, 0.52268200E-01, -.55294700E+01, -.12352800E+01, 0.60347400E+00, -.33596400E-01, -.81111800E+00, -.28364100E-01, 0.95200400E+00, -.17322800E+00, -.71396900E+01, 0.65669800E+00, 0.36904500E+00, 0.17939000E+01, 0.68927400E+00, 0.13097200E+01, -.14221600E+00, 0.43096500E+01, 0.30881600E-01, 0.34754000E+00, 0.11621600E+01, 0.14474900E+01, -.93850700E+00, -.20305500E+01, 0.15763100E+01, 0.42945600E-01, -.92283400E+00, -.40207300E+00, 0.85383500E-01, -.14726800E+00, 0.10528300E+01, 0.11390300E+00, 0.48727200E+01, -.81077100E+00, 0.73308200E+00, -.63340600E+00, 0.51065500E+00, -.35084900E+00, 0.60975800E-02, 0.53348300E+00, -.11633400E+01, -.72583600E-01, -.31665700E+01, 0.59871000E+00, 0.28852400E+00, 0.19492400E+00, 0.41943500E-01, -.16695000E+00, 0.40573000E+00, -.28442800E-02, 0.55897500E+00, -.27122900E+00, -.17405800E+01, 0.12693900E+00, 0.67845500E-01, 0.79661800E+01, -.57683900E+00, -.10423700E+00, 0.15971600E-01, 0.46997300E+01, 0.28003900E-01, 0.29949900E-01, -.15776900E+00, 0.20731100E+00, 0.27065700E+00, -.12079600E+01, 0.72181500E+00, -.17032000E+00, -.16687700E+01, -.25007700E+00, 0.31781700E+00, -.45903700E-01, -.43235300E+00, -.13019100E+00, 0.29871600E+00, -.19172600E+00, 0.53438600E+00, -.11942500E-01, -.43257500E+00, -.18759000E+00, -.60648800E-01, 0.25305800E+00, 0.31976700E-01, 0.33807800E+01, -.42105200E-01, -.13107500E+01, 0.69299100E+00, 0.20515000E+00, -.14046700E+01, 0.42748300E-01, 0.53073900E+00, 0.44816800E+00, 0.26927100E+01, -.53815900E+00, 0.16108600E+00, 0.36280400E+01, 0.39469900E+00, -.25077600E+01, -.12722700E+01, -.10491900E+00, -.85093400E+00, 0.29538900E+00, 0.12220600E-01, 0.11159700E+01, -.61862900E+00, 0.29352600E+00, -.63069500E+01, -.53345400E+00, -.81281900E+00, -.28194800E+00, -.14301100E+00, 0.26947000E+00, -.72970700E+00, 0.16575900E+03, -.37576100E+02, 0.51509500E-01, -.51062300E+02, 0.75534800E+02, 0.49711000E+02, 0.56099100E+02, -.16955800E+03, 0.69904600E+02, 0.12302200E+03, -.37897100E+02, -.80874400E+02, -.22234800E+03, 0.18980500E+02, 0.11059000E+01, 0.14332200E+02, 0.17408500E+02, 0.31267500E+02, 0.97096600E+02, -.16252000E+02, 0.46220500E+02, 0.30263300E+03, -.69682400E+02, -.19493700E+03, -.15124400E+03, -.29331100E+02, 0.35147600E+02, 0.22031700E+02, 0.22022400E+03, -.93992000E+02, 0.84466100E+01, 0.17386300E+03, 0.84521000E+03, -.46243800E+03, -.56284000E+03, -.42261100E+03, -.46369800E+02, -.33589200E+01, -.10672600E+03, 0.28420800E+03, 0.78159100E+01, -.10024500E+02, -.31515800E+03, 0.45588200E+03, -.24555200E+03, -.51431100E+03, -.22787900E+03, -.16905500E+02, 0.77702000E+02, -.19385700E+03, 0.62997500E+02, 0.39631900E+02, 0.42602700E+02, -.17796300E+02, 0.10363200E+04, -.51755700E+03, -.49978600E+03, -.51804900E+03, -.44246000E+02, 0.74765000E+02, -.29849100E+03, 0.15222500E+02, -.33131400E+03, 0.68733900E+02, -.28021600E+03, 0.96504200E+02, -.23076300E+02, -.66535000E+02, -.48108000E+02, 0.91919200E+01, -.90523400E+02, 0.31508600E+02, 0.47148000E+02, -.35536700E+02, -.60229200E+02, -.11396300E+03, -.31031400E+03, 0.13430800E+03, 0.16578200E+03, 0.15487800E+03, -.56355700E+02, -.14300900E+03, 0.23524800E+03, 0.18634200E+03, 0.16588800E+03, -.12700100E+03, 0.34378600E+02, 0.15179200E+01, -.12544400E+01, -.94730900E+01, -.16765800E+01, 0.91619100E+01, -.57916800E+01, 0.20555500E+02, -.58307000E+00, 0.69677700E+01, -.41209900E+02, 0.39959000E+02, 0.10585500E+02, 0.53518300E+01, 0.63226800E+01, 0.51684700E+01, -.39923500E+02, 0.55582300E+00, 0.41383500E+01, 0.29735400E+02, 0.13872800E+02, -.12149100E+02, 0.11094700E+02, -.11844300E+02, -.24827500E+02, 0.28795200E+02, -.25949500E+02 },
        { -.20868700E+02, 0.59085900E+00, 0.11087700E+01, 0.19140500E+00, -.11347100E+01, 0.43771900E+01, -.19844500E+01, 0.11550100E+01, 0.14465000E+01, 0.35875200E+01, -.12387900E+00, 0.41667100E+01, 0.39847200E+00, -.13032300E+01, 0.85006300E+00, -.19916000E-01, 0.14806600E+01, 0.17394300E+01, 0.28070900E+01, 0.95874800E+00, -.28943400E+00, 0.92772400E-01, 0.12017100E+02, -.64307600E+00, -.21622200E+00, -.12922000E+01, 0.19610400E+00, -.49521400E+00, -.15327100E+00, -.99919500E+00, -.92606800E+00, 0.14609600E+01, 0.72465100E-01, -.36188900E+00, -.19312800E+01, 0.80135400E+00, 0.15921600E+00, -.44482600E+01, 0.59524100E+00, 0.76124500E+00, -.31134400E+00, -.49190500E+01, 0.71414600E+00, 0.87960500E+00, -.22441600E+01, 0.35910600E+00, 0.48205200E+00, -.74956400E-02, 0.13422900E+01, 0.18520800E+00, -.43663600E+01, 0.36378900E+01, -.16146700E+01, -.51932800E+00, 0.34719600E+01, -.12839600E+01, -.54167400E-01, 0.41594500E+00, 0.44337700E+00, 0.17566800E+00, -.10466200E+00, -.71278400E+00, 0.18368500E+00, 0.74697400E+00, 0.44672800E+00, 0.19314900E+00, 0.30193400E+01, -.10807600E+00, 0.49537200E+01, -.13250300E-01, -.66326500E+00, 0.46465900E+00, 0.22583000E+00, -.20063000E+00, 0.13380400E+01, -.45390900E+00, 0.89843700E+00, -.20749800E+01, 0.74770600E+00, 0.18709900E+01, 0.11934800E+00, -.27175000E+01, -.40379700E+01, -.57587200E-01, 0.13022700E+01, 0.70704000E+01, 0.41971700E+00, 0.15767400E+00, -.75368100E+00, 0.57757500E+00, 0.24790900E+00, 0.36561700E-01, 0.28767800E+01, -.56469600E+00, 0.19240300E+00, -.98452600E+00, -.15783000E+01, -.19365100E+01, 0.41028800E+00, -.35835400E-01, 0.30982200E+00, -.65757800E-02, 0.49728100E+00, -.15587800E+01, -.31105000E+00, 0.60263200E+00, -.46120000E+00, -.41008200E+01, 0.50927300E+00, -.48337100E+00, 0.67085600E+01, -.29524300E+00, -.38706000E+00, -.66017600E-01, -.27102500E+01, -.11495500E+00, 0.36179500E+00, -.54842800E+01, 0.89896900E+00, 0.65433100E+00, -.10639300E+01, 0.28108200E-01, 0.11887800E+00, 0.40938100E+00, -.34423700E-02, -.11114500E+01, -.91601200E-01, -.18361500E+01, -.29208500E+00, -.55114400E+00, 0.14719800E+02, -.68629600E+00, -.10276800E+01, -.14523500E+00, -.10235400E+01, 0.81449400E+00, 0.37502600E+00, 0.16594500E+00, 0.26108800E+01, -.36682900E+01, 0.12733800E+01, 0.84233000E+00, 0.43169600E-01, -.26053800E+00, -.46205600E-01, 0.85840500E-01, -.52003400E-01, 0.17747100E+01, 0.56164500E+00, -.38382600E+01, -.99343400E+00, 0.23751400E+01, -.18727300E+01, 0.12501100E+00, 0.25557400E+00, -.27169500E+00, -.51469200E+00, -.59260400E-01, -.43173600E+01, 0.10087300E+01, 0.16125100E+01, -.80652600E+00, 0.17948400E+00, -.17420300E+00, 0.22988500E+00, -.91558000E+00, 0.26725900E-01, 0.21294500E+00, -.90033600E-01, 0.27711400E+00, 0.43920600E+00, -.21458400E+01, 0.14762700E+00, -.38242300E+01, 0.11368400E+01, 0.15897700E+00, 0.45321600E+00, 0.97306800E-01, 0.36861700E+00, 0.13705300E+01, -.10729400E+01, 0.28951000E+01, -.55102800E+00, 0.14677600E+01, 0.37996400E+00, 0.10831300E+01, 0.13409200E+01, 0.44874600E+00, -.76767400E-03, -.33617000E+03, -.18359100E-01, 0.31016000E+02, -.37146800E+02, -.19691100E+02, 0.69794000E+02, 0.24567600E+02, 0.15170100E+02, 0.61687800E+02, 0.95776200E+01, 0.95213400E+01, 0.18402300E+03, -.48009100E+01, 0.11437100E+02, 0.50588900E+02, -.14755800E+02, -.12327400E+03, -.14029300E+03, 0.34810400E+02, -.10344600E+03, 0.41399300E+02, -.29765600E+02, -.29853100E+03, -.20725500E+02, 0.16273900E+02, -.69441000E+02, -.24560400E+02, 0.53776400E+02, 0.21356700E+02, -.38825100E+02, 0.44881900E+02, 0.44413300E+03, -.21591600E+03, -.35168200E+03, -.22206400E+03, -.54172600E+02, -.55824700E+02, -.58116700E+02, 0.85318900E+02, -.40225500E+02, -.10294200E+03, -.67597000E+02, 0.33532000E+03, -.16836300E+03, -.60323800E+02, -.16768200E+03, -.59393900E+01, -.13300200E+02, -.12543900E+03, 0.46039200E+02, -.65294900E+01, -.20301100E+02, -.23231500E+03, -.38484800E+03, 0.19341100E+03, 0.42872100E+03, 0.19238100E+03, 0.18187100E+02, 0.22167200E+02, 0.11871700E+03, 0.77557800E+02, 0.13354000E+03, 0.10473900E+02, 0.28299400E+03, -.25090500E+03, 0.12635400E+03, 0.43579800E+03, 0.12540100E+03, 0.14776400E+02, 0.70182200E+02, 0.24429700E+02, -.82289200E+02, 0.34607400E+02, 0.66454100E+02, 0.34359100E+03, -.55396900E+02, 0.28354900E+02, -.14475500E+03, 0.27816100E+02, 0.51389300E+02, 0.60735300E+02, -.62662000E+02, -.13211800E+03, -.15513300E+03, 0.65190500E+02, -.45166500E+02, -.87327700E+01, 0.25351100E+01, -.13633800E+02, -.18660300E+01, 0.44012800E+01, -.45631600E+01, 0.14152400E+02, -.18125500E+01, 0.12392500E+02, -.18265800E+02, 0.11119600E+02, 0.31258500E+01, -.10893600E+02, -.10788200E+02, -.24459100E+02, -.17474500E+02, -.97303700E+01, -.78147200E+01, -.35861600E+02, 0.11454400E+03, 0.52116700E+01, -.21662600E+02, -.83108100E+01, -.38149400E+02, -.58544300E-02, -.52394700E+01 },
        { 0.15846700E+02, -.43800000E+00, -.57858200E+00, 0.20031500E+01, 0.12014600E+01, -.21482700E+01, -.44361000E+00, -.29289100E+00, 0.23444800E+01, -.10271000E+01, 0.15291600E+00, -.14805800E-01, -.29568100E+00, -.72255500E-01, 0.85791100E+00, -.43193300E+00, -.31487200E+00, -.18504700E+00, 0.24896500E+00, -.12566200E+01, -.36142900E+00, -.12923200E-01, -.20257900E+01, 0.73425400E+00, -.31470800E+00, 0.79251400E-01, -.83508900E+00, -.10809800E+01, 0.14031000E+00, 0.46643100E+00, 0.36245100E+00, -.20042300E+01, 0.22969800E-01, -.27606100E+00, 0.33808400E+00, 0.27451500E-01, 0.21321300E+00, 0.24398100E+01, -.13272600E+00, -.63752400E+00, 0.54978800E+00, 0.74831400E+00, -.52401600E+00, -.47587400E+00, 0.17480800E+01, -.98119500E-01, 0.25017800E-01, -.53530100E-01, 0.97487300E-01, 0.68648900E-01, 0.10359000E+01, -.61390500E+01, 0.16466800E+00, -.94991800E-01, 0.27472900E+01, -.38128900E-01, 0.30333900E-01, -.48614500E+00, -.54567200E+00, 0.26335800E+00, 0.38567900E+00, -.39607500E+00, -.78015300E+00, 0.16572900E+00, 0.13567600E+00, 0.34508300E-01, -.17914700E+01, -.53979300E-02, -.23995000E+00, -.84977800E-02, -.61928600E-02, 0.67717000E-01, 0.15985900E+00, -.87359500E-01, 0.73767900E+00, -.27774300E+00, 0.10592700E+00, -.28605500E+01, 0.88701700E+00, -.73520800E+00, -.62559000E-01, -.55365800E-01, 0.34956500E+00, 0.39793600E+00, -.90570400E+00, -.47896400E+01, -.23457600E+00, -.23289800E+00, 0.79735400E+00, -.11139300E+01, -.19218900E+00, -.11056100E-01, 0.83980200E+00, 0.45599300E-01, -.15171700E+00, 0.52670100E+00, 0.41109800E+00, 0.55455700E+00, 0.13748800E+01, -.45894100E+00, -.10527700E+00, -.53582100E-01, -.56514400E-01, 0.21109900E+00, 0.10849300E-01, -.47021500E+00, 0.41160700E-02, -.36054200E+01, 0.20849500E+00, -.32804400E-01, 0.23742100E+00, 0.47231700E-01, 0.78125200E+00, 0.80781700E-02, 0.40855400E-01, 0.30047600E+00, -.14028700E+00, 0.13568600E+01, -.10120500E+00, 0.45397700E+00, 0.19149300E+00, 0.13166200E+00, -.10519600E-01, -.17716100E-01, 0.95208700E-02, 0.93753800E-01, -.78993500E-01, 0.64200200E+00, -.27763100E-03, 0.37053100E-01, -.17972000E+01, -.50224400E+00, 0.11298600E+00, 0.32225600E-02, 0.22245400E+00, -.80804400E+00, -.13595600E+00, 0.93314900E-01, -.14054200E+00, -.16260900E+00, -.42335400E+00, -.34158600E-01, -.69244400E-01, -.20155700E+00, -.30854200E-01, 0.63185500E-02, -.37053500E-01, -.15579600E+01, 0.11876200E+00, 0.27250900E+00, -.83916500E-01, 0.80297300E+00, -.17884100E+01, -.17448300E+00, -.82074000E-01, -.21590800E+00, 0.23626200E-02, 0.66560600E-02, 0.53988900E+00, 0.15102200E+00, -.24347200E+00, -.69140400E-01, -.10791200E+00, 0.26908300E+00, -.29064000E-01, 0.30703100E+00, 0.26239800E+00, 0.10413600E+01, -.20403200E+00, -.35428600E+00, 0.95230500E+00, -.72203900E+00, -.89275200E+00, 0.18570100E+00, 0.37699400E+00, -.18790500E+00, 0.76654900E-01, 0.60596800E-02, 0.50297800E+00, 0.11023400E+01, -.23075800E+00, -.87964700E+00, 0.13100600E-01, -.45464500E+00, 0.27480700E-01, -.46445900E+00, 0.26915200E+00, -.64631900E+00, 0.57161600E-01, 0.19286300E+00, 0.28747600E+01, 0.27192200E+02, 0.76079900E+02, -.43060100E+01, -.21122500E+02, -.88779100E+02, 0.34860900E+02, 0.88370000E+02, -.21138400E+02, 0.22138100E+01, -.13155600E+03, 0.10577100E+02, -.32704900E+01, -.23907200E+01, -.17213400E+01, -.12260100E+02, 0.46424300E+02, -.10733100E+02, -.22266600E+02, 0.82019900E+02, -.40950600E+02, -.35940600E+02, -.41004300E+02, 0.35166700E+02, 0.58464000E+02, -.11808800E+02, 0.45518600E+02, -.48942600E+02, 0.11679800E+02, 0.92885700E+02, 0.27321700E+02, -.14026600E+02, -.67514600E+02, -.13661900E+02, 0.27982300E+02, 0.79690000E+02, -.39435900E+02, 0.38305300E+02, 0.47143200E+02, 0.80451800E+02, 0.20762900E+03, 0.18955000E+03, -.94592900E+02, -.19825100E+03, -.94767200E+02, -.18291700E+02, 0.31067500E+02, -.67487000E+02, 0.39716800E+02, 0.17224400E+02, 0.21768300E+02, 0.59955600E+02, 0.42112100E+03, -.20910100E+03, -.29353200E+03, -.21058100E+03, -.29619300E+02, 0.78748800E+01, -.96394200E+02, 0.47724500E+02, -.12841600E+03, 0.43856700E+01, -.77265800E+02, 0.30917400E+02, -.17037500E+02, 0.12816800E+02, -.15458500E+02, -.11964900E+02, -.22042600E+02, -.10549100E+02, 0.54342300E+00, -.47375600E+01, -.12801100E+02, -.55235700E+02, -.71257400E+02, 0.34357300E+02, 0.12602700E+03, 0.35553200E+02, -.16216800E+02, -.17663400E+02, 0.34318000E+02, 0.36740900E+02, 0.57268200E+02, -.19851600E+02, 0.19001700E+02, 0.24560100E+01, 0.17714200E+00, -.49685400E+01, -.24076200E-01, 0.36077400E+01, -.48827200E+01, 0.27417300E+01, -.10482000E+00, 0.49080900E+01, -.28777000E+02, 0.28684000E+02, 0.34381200E+01, 0.55269500E+00, -.26468200E+01, 0.72859800E+01, -.26888900E+02, 0.26401000E+00, 0.22869500E+01, 0.35924300E+02, -.28019200E+01, -.13202200E+02, 0.10300000E+02, -.77114800E+01, -.33539700E+02, 0.29327100E+01, -.30202200E+02 },
        { 0.22551100E+02, -.60215300E+00, -.74961100E+00, 0.38649600E+01, 0.29643600E+01, -.59662400E+01, 0.19396400E+01, -.33546100E+01, 0.47101900E+01, -.45537800E+01, 0.19186000E+00, 0.44801800E+01, -.27503300E-02, 0.57422300E-01, 0.17695200E+01, -.11328400E+01, 0.17695700E+01, 0.48813600E+00, 0.20471400E+01, -.28674300E+01, -.20737200E+01, 0.32920200E+00, 0.14764700E+02, 0.88592400E+00, -.75556900E-01, 0.23914400E+00, -.12455900E+01, -.46596200E+00, -.26126600E+01, -.79958000E+00, -.15613000E+01, -.38978200E+01, 0.22016600E+00, -.13625100E+00, 0.54629000E+01, 0.37063400E+00, 0.43209000E+00, 0.42705000E+01, -.63585600E+00, 0.90356700E+00, -.92035200E-01, -.53550200E+00, -.49810100E+00, 0.14269600E+01, 0.64902500E-01, 0.46878000E+00, 0.23969000E+00, -.10285200E+00, 0.45854200E-01, -.11544700E+00, 0.22910500E+01, 0.94263700E+00, -.13234400E+00, -.36461900E+00, 0.29233400E+01, 0.47259500E+00, -.52973200E-01, -.59437500E+00, -.17676600E+01, 0.46915600E+00, 0.29591600E+00, -.78763500E-01, 0.17197400E+00, -.17369000E+00, -.17126600E+00, 0.15260000E+00, -.17568000E+01, 0.30354900E-01, -.67462800E+00, -.12020300E-01, 0.13472500E-01, -.16466100E+00, 0.11027000E+00, 0.11661000E+00, -.40550900E+00, -.14829400E+01, 0.39231600E+00, -.28742100E+01, -.16194200E+01, 0.12831200E+01, -.35786000E-01, 0.34000200E-01, -.99186600E+00, -.21882000E+00, 0.40491500E+00, -.82772200E+01, 0.87070100E+00, 0.13502900E+00, 0.14002300E+01, 0.10740700E+01, 0.45676400E+00, -.10821300E+00, 0.52342300E+00, 0.26495900E+00, -.55379800E-01, 0.38074500E+00, 0.32367900E+00, 0.10017000E+01, 0.79389300E+00, -.99575800E-01, 0.56297300E-01, -.36026000E+00, -.58677400E+00, -.11623700E+00, 0.31047700E+00, -.62037400E-01, 0.25620300E+00, 0.19592400E+01, 0.17748400E+00, -.23425900E-01, 0.21585500E+01, -.12444100E-01, 0.23359900E+00, 0.76994000E-02, -.41238700E+00, 0.59871900E+00, -.63581100E-01, -.94665100E+01, -.25678100E+00, -.13522800E+01, 0.42630400E+00, -.23617900E+00, -.16873400E-01, -.11051000E+01, 0.55534000E-01, 0.13597900E+01, 0.31190200E-01, -.12878200E+01, -.47083100E+00, -.15761500E+01, 0.40734000E+01, 0.44243900E+00, -.15925100E+00, 0.29260700E-01, -.27685100E+00, -.12872200E+01, -.14422900E+00, 0.29565200E+00, 0.13276100E+01, -.89577600E+00, -.31224000E+00, -.25335800E+00, 0.52191800E-01, -.28516800E-01, -.89379500E-03, 0.31523600E-01, -.11989700E+00, -.59193500E+00, -.12431200E+00, -.11223800E+01, -.77504700E-01, 0.18384100E-01, 0.28613600E+00, -.24952300E+00, -.16536600E+00, -.79210800E-01, -.23383800E+00, 0.14678400E+00, -.11798200E+01, 0.31611600E+00, 0.14131100E+00, -.28421800E+00, 0.23674100E+00, -.11939600E+00, 0.11589400E-01, -.18145400E+00, -.15122300E-01, -.50901200E+00, -.10910800E+00, 0.34312500E+00, 0.57739400E+00, 0.21957100E+01, 0.83493500E-01, -.18049600E+01, 0.35017300E+00, 0.35955300E+00, -.16442900E-01, -.13710600E+00, -.24235000E+00, 0.53805700E+01, -.29064200E-02, -.43811200E+01, -.11543900E+00, 0.16016900E+01, 0.60473300E+00, -.35162900E+01, 0.36650100E+00, -.30785100E+01, 0.27114000E+00, 0.30611400E+00, -.42117000E+00, 0.19691000E+03, 0.20532700E+03, -.13510600E+03, -.28327400E+03, -.10690000E+03, 0.44766000E+02, -.37438800E+02, -.14909900E+01, 0.52245600E+02, -.25153100E+03, 0.16767800E+00, -.11653000E+02, -.47224400E+02, 0.14283200E+02, -.56056200E+02, -.11096300E+02, -.11570700E+02, -.79572900E+02, -.22289900E+03, 0.10229800E+03, 0.15421100E+03, 0.10850500E+03, 0.18785800E+03, 0.16827900E+03, -.13965400E+03, -.31975100E+03, -.14539400E+02, 0.34149900E+02, -.95282100E+02, -.63361300E+03, 0.31441100E+03, 0.28812100E+03, 0.32000000E+03, 0.21319500E+03, 0.17923900E+03, -.36438400E+02, -.11503500E+03, 0.14117900E+03, 0.15771300E+03, 0.55441900E+03, -.19928300E+03, 0.11314800E+03, -.93648300E+01, 0.98353500E+02, 0.10752900E+03, 0.50016700E+02, 0.12184000E+02, 0.62398100E+02, 0.10415400E+03, 0.51035400E+02, 0.87322400E+02, -.55533000E+03, 0.28642400E+03, 0.42594800E+02, 0.27754400E+03, -.20599500E+02, -.15237300E+03, 0.30404800E+03, 0.25552600E+03, 0.19977700E+03, -.14994300E+03, 0.30523300E+03, 0.25869000E+02, -.12664500E+02, 0.29136100E+03, -.17631300E+02, -.10839500E+03, -.31801400E+02, 0.70428200E+02, 0.90929500E+02, 0.74087600E+02, -.32108700E+02, 0.10356900E+03, 0.37086800E+03, -.16602800E+03, 0.75089000E+02, -.18296600E+03, 0.80700800E+02, 0.29820000E+03, -.44184300E+03, -.33049500E+03, -.28679300E+03, 0.27661100E+03, -.52192800E+02, 0.10664300E+02, 0.58759700E+01, 0.83096600E+01, 0.25966300E+01, -.48084900E+01, -.30629100E+01, -.14996500E+01, -.12752200E+00, -.49893700E+01, -.25760600E+02, 0.22984600E+02, -.66067300E+01, 0.17843000E+00, -.10863000E+02, -.70044900E+01, -.19003300E+02, 0.55333900E+00, 0.96145700E+01, 0.98364400E+02, -.11057500E+03, -.30018900E+02, 0.11505600E+01, 0.11187200E+02, -.91408000E+02, -.21977600E+02, -.49045800E+02 },
        { -.62152400E+00, 0.61128600E-01, 0.34886200E-01, -.10995600E+00, -.22803000E-01, 0.77375300E+00, -.31728500E+00, 0.43141300E+00, -.13626700E+00, 0.79964200E+00, -.31676400E-01, 0.90505900E-02, -.33972900E-01, 0.10763800E-01, -.31367000E+00, 0.49155500E-01, 0.24103000E+00, 0.10882100E+00, 0.13618100E+00, -.97037500E-01, 0.23345100E+00, -.90529500E-01, -.18930300E+01, 0.22612200E+00, -.11310700E+00, -.24406600E-01, -.20627800E+00, 0.21646400E+00, 0.58888100E+00, -.65602600E+00, 0.29770700E+00, -.45412200E+00, -.61231700E-01, -.57726600E-01, -.10676200E+01, 0.86555300E-02, -.34419100E-01, 0.90058900E+00, -.75855700E-01, 0.11040200E+00, 0.39075600E-02, -.47845800E+00, -.24033200E+00, 0.88356200E+00, 0.29699500E-01, 0.74176500E-01, -.47944600E-01, -.20004900E-02, -.40928000E-01, -.34784800E-01, -.15002500E+00, 0.50357600E+00, 0.14901900E-01, 0.19603900E-02, 0.66117800E+00, -.27159400E+00, -.16178000E-01, -.69608700E-01, -.16057900E+00, 0.49033000E-01, -.57167300E-02, -.52399500E-01, -.77029800E-01, 0.43546000E-01, -.38515000E-01, -.32446800E-01, -.61912600E+00, 0.17284500E-01, -.56275300E+00, -.70088200E-03, 0.24193400E-01, 0.13872000E-01, 0.37366600E-01, -.77982200E-02, 0.26127700E+00, -.96863300E-01, -.18012000E+00, -.16670300E+01, -.43366300E+00, 0.19083100E+00, 0.20188200E-02, -.45282900E-01, 0.33670800E+00, -.15652900E+00, 0.14790400E+00, -.16258900E+01, 0.15653600E+00, 0.23332800E-02, 0.16153300E+00, 0.25992100E+00, -.71708600E-01, 0.76517400E-02, 0.79094600E+00, 0.33383100E-01, 0.89917900E-01, 0.10780100E+00, 0.33963300E+00, -.15740900E+00, -.37802400E+00, -.34367300E-01, -.22522600E-01, 0.71594800E-01, 0.13290200E-01, -.29231600E-02, 0.12056600E-01, 0.56304900E-01, -.80656800E-02, -.68715500E+00, 0.29205500E-01, -.30975500E-01, -.30657700E+00, -.79644500E-02, -.29435100E-02, 0.57368200E-03, -.58042600E-01, 0.34325700E-01, 0.15132700E-01, 0.15082700E+00, -.36320300E-01, 0.16631100E+00, -.56816500E-01, -.13150100E-01, 0.34696200E-02, -.36550900E-01, 0.64259400E-02, 0.31779100E-01, 0.51432000E-01, 0.26117800E+00, -.85515100E-02, 0.26676100E+00, 0.33490100E+00, 0.29307100E-01, -.44357100E-01, 0.53231100E-02, 0.45978600E+00, -.62787400E-01, -.45284500E-01, 0.44991500E-01, 0.19825800E+00, -.26042200E+00, -.51648800E-01, 0.12621800E-01, -.39425700E-01, -.89132600E-01, -.14988000E-01, -.26235100E-01, -.14567400E-01, 0.50263500E+00, 0.48390900E-01, 0.15728400E+00, -.10833700E+00, 0.74408700E-01, -.66055500E-01, -.13387300E+00, -.43903000E-01, 0.25556000E-01, -.51161200E-02, -.11793200E-02, 0.71170000E+00, 0.12735000E+00, -.20164600E-01, 0.24765900E-01, 0.35759800E-01, -.31089400E+00, 0.85115000E-01, 0.71850400E-01, -.79682900E-01, -.13426100E+00, 0.59794900E-01, 0.19554400E+00, 0.45200400E-01, 0.10101800E+01, 0.58682300E-01, -.22312700E+00, -.99950200E-01, -.76914800E-01, -.28384500E-01, -.21847000E-02, 0.10650800E+00, -.38806500E+00, -.17752500E+00, 0.42366100E+00, -.86571600E-01, 0.24084300E+00, -.93458100E-01, 0.69330900E+00, 0.52341300E-03, 0.10834400E+00, -.26288700E-02, 0.38090200E-01, -.20580900E-02, 0.90817800E-01, -.29159400E+02, 0.24907000E+02, 0.46876400E+02, 0.12033100E+02, -.97091600E+01, 0.13709500E+01, 0.82944200E+01, -.92386600E+01, 0.21190300E+02, -.40927300E+01, 0.71242500E-01, 0.46957800E+01, -.59592900E+01, 0.10315700E+02, -.28341900E+01, 0.21119600E+01, 0.90366200E+01, 0.32822800E+02, -.15684800E+02, -.43648200E+01, -.16150600E+02, -.13742100E+02, -.15389400E+02, 0.19320300E+02, 0.41662400E+02, -.51887700E+01, -.80122900E+00, 0.11159900E+02, 0.13541100E+03, -.67699800E+02, -.42246600E+02, -.67994900E+02, -.29923500E+02, -.33205900E+02, -.10454500E+02, 0.29413500E+02, -.36081100E+02, -.31128900E+02, -.12437300E+03, 0.35924100E+02, -.19148700E+02, -.33554200E+02, -.17854200E+02, -.54256500E+01, -.36621300E+01, -.95848300E+01, 0.55479800E+01, -.98432400E+01, -.73956600E+01, -.14095400E+02, -.11368300E+03, 0.50019800E+02, 0.11614200E+03, 0.56829600E+02, 0.24012000E+02, 0.40402900E+02, -.62184900E+01, -.67497500E+02, 0.13180900E+02, 0.33701800E+02, 0.11756100E+02, 0.21429900E+02, -.11281400E+02, -.16551500E+02, -.10292300E+02, 0.16233200E+02, 0.21828400E+01, -.13380800E+02, -.18431300E+02, -.21296000E+02, 0.27862600E+01, -.58315600E+02, 0.98455800E+01, -.61901300E+01, -.48211800E+02, -.51494700E+01, -.91001400E+01, -.30979100E+02, 0.27596500E+02, 0.22485600E+02, -.41360200E+01, -.23865200E+02, 0.16515300E+02, -.12400500E+01, -.13969300E+01, 0.11719500E+00, -.29070400E-01, -.12001500E+00, 0.52654300E-01, 0.41663700E+01, 0.44027900E+00, -.20520700E+00, 0.18834900E+02, -.18385400E+02, 0.25480400E+01, -.29154700E+00, -.11173300E+01, -.35107500E+01, 0.18692200E+02, 0.16109200E+00, -.14080200E+01, -.73731900E+01, 0.16587600E+02, 0.20977400E+01, -.51677800E+01, 0.34088200E+01, 0.27339400E+02, 0.71048400E+00, 0.22175300E+02 },
        { 0.56008400E+01, -.13652100E+00, -.21291100E+00, 0.47936100E+00, 0.39861500E+00, -.27653400E+00, -.11477200E+01, 0.43191900E+00, 0.45188600E+00, 0.18117700E+00, 0.20807400E-01, -.30211900E+00, -.40230800E-01, -.35683300E-01, 0.16739900E+00, -.18436600E+00, -.61799800E-02, -.27481100E+00, 0.45477600E+00, -.87406000E+00, -.21527600E+00, 0.47661100E-01, -.20632800E+01, 0.15631600E+00, -.11138700E+00, -.44643500E-01, -.12425300E+00, -.28480400E+00, 0.21001800E+00, -.43219900E+00, -.11502900E+00, -.43706100E+00, 0.53822400E-01, -.35218200E+00, 0.11926000E+01, 0.14544500E+00, 0.45623500E-01, 0.38857700E+00, -.29899800E-01, -.30257400E+00, 0.39131100E+00, 0.60950600E-02, -.24265500E+00, -.57269100E+00, 0.86256800E+00, 0.52735900E-01, -.79691100E-02, -.15763400E-01, -.24371100E+00, 0.31520000E-01, 0.56660000E+00, -.39580200E+01, 0.23269200E+00, 0.10270200E+00, 0.71748300E+00, -.17371900E+00, -.41149400E-01, -.39933000E+00, -.26163300E+00, 0.72317000E-01, 0.45220000E+00, -.63839300E+00, -.67399200E+00, -.20044200E-01, 0.31121800E+00, 0.20148400E+00, -.16390600E+01, -.43578500E-03, -.56950900E+00, 0.74594200E-03, 0.30300300E-01, 0.10794500E+00, 0.11139800E-01, -.15949900E-01, -.21423500E+00, 0.24034600E-01, 0.50954300E+00, 0.36397000E+01, -.34922000E+00, -.12573500E+00, -.58394300E-02, 0.38166500E+00, 0.21331400E+00, -.27672400E+00, -.48703200E+00, 0.55401400E+00, 0.23171000E-01, 0.14741400E+00, 0.52762200E+00, 0.29030700E+00, 0.13047700E+00, 0.60562900E-02, -.37563400E+00, 0.50967600E-01, -.13045100E+00, -.16657900E+00, -.76290900E-01, 0.16876300E+00, 0.12019100E+00, 0.13962800E-01, 0.13738200E-01, 0.71445000E-01, 0.32622600E-01, 0.48870900E-01, 0.48115200E-02, -.21712400E+00, -.50048600E-01, -.70916600E+00, 0.11988100E+00, -.77417400E-01, 0.46852000E+00, -.14071000E-01, 0.22447900E+00, -.45159500E-02, -.21755400E-01, 0.20405100E+00, -.63145000E-02, -.21496200E+01, -.14590000E+00, 0.24823100E+00, 0.13493300E+00, 0.15861800E-01, 0.27418600E-02, 0.14188000E+00, 0.49863400E-02, 0.25963900E+00, 0.56803700E-01, 0.28765900E+00, 0.15783600E+00, 0.50173900E+00, -.11813100E+01, -.59245500E-01, -.36176400E-01, -.52511900E-02, 0.10036000E+01, 0.58362600E-01, -.14398000E+00, -.76364500E-01, -.64411100E+00, 0.13896000E+00, 0.10267100E+00, 0.75898000E-02, -.22926900E-01, 0.34742400E+00, -.56990200E-02, -.18088000E+00, -.28368200E-02, -.36786500E+00, 0.21970600E+00, -.44134400E+00, -.46112000E-01, -.91481100E-01, 0.93979900E-01, 0.14304300E+00, -.12838800E-01, -.47628000E-01, 0.13731000E-02, 0.18594300E-01, -.28621500E+00, -.54506000E-01, 0.34866500E+00, -.19260000E+00, 0.33131100E-01, 0.15392000E+00, 0.35866300E-01, 0.61694500E-02, 0.19149100E-01, 0.50820300E+00, -.58923600E-01, -.24732600E+00, 0.25620300E+00, -.18659800E+01, -.30736800E+00, 0.23619200E+00, -.72920200E-01, 0.84573200E-01, 0.11645400E+00, -.35168000E-02, -.15363700E+00, -.26432100E+00, 0.14033900E+00, -.33883100E+00, -.48565700E-01, -.26279100E+00, 0.26460200E-01, -.73878400E+00, 0.31334800E-01, -.38470400E-01, -.23857200E-02, 0.43302400E-01, 0.34022100E-02, -.45786600E-01, -.13081200E+01, 0.34650600E+02, 0.27557500E+02, -.38914900E+02, 0.50154800E+01, 0.78656200E+02, -.60843600E+01, -.57321000E+01, -.30002800E+02, 0.30947500E+01, -.34528600E+01, 0.14962100E+01, -.62593800E+01, 0.12713300E+02, 0.25037300E+02, -.40048000E+01, 0.17814000E+02, 0.95345900E+02, -.45271500E+02, -.24427500E+02, -.47453100E+02, -.93127600E+01, 0.19219200E+02, 0.78247500E+01, 0.45661600E+02, -.47199000E+02, 0.14154200E+02, 0.66638800E+02, 0.21258700E+03, -.10694200E+03, -.10206100E+03, -.10652700E+03, -.25334400E+02, -.13686200E+02, -.25635800E+02, 0.67653200E+02, -.28579900E+02, -.12791900E+02, -.14687800E+03, 0.12141500E+03, -.62732700E+02, -.13236500E+03, -.60614300E+02, -.12008400E+02, 0.75068400E+01, -.33809000E+02, 0.20755600E+02, -.16741100E+02, -.21118300E+01, -.15769000E+02, 0.19613200E+02, -.16380000E+02, -.18588700E+02, -.98153200E+01, 0.16732900E+02, 0.45276800E+02, -.37359300E+02, -.60369000E+02, -.29706200E+02, 0.37651400E+02, -.17413500E+02, 0.38185900E+02, -.20139300E+02, -.28882400E+02, -.18726800E+02, 0.76294500E+01, -.15274700E+02, -.10768800E+02, -.96217400E+01, -.17649600E+02, -.93747500E+01, -.86399800E+02, -.12460000E+02, 0.36000000E+01, 0.16037100E+02, 0.59857800E+01, -.13747700E+02, -.36132100E+02, 0.43305200E+02, 0.37885700E+02, 0.69102100E+01, -.28683600E+02, 0.30185300E+02, 0.81805000E-01, -.10057100E+01, -.58518700E+00, -.93808400E-01, 0.64544500E+00, -.13037800E+01, 0.87825600E+01, 0.74053500E+00, 0.50506300E+00, 0.15189100E+02, -.14548600E+02, 0.76833000E+01, 0.11433200E+01, 0.34674500E+00, -.29785900E+01, 0.15658900E+02, 0.84850600E+00, 0.70332300E+00, 0.12197000E+02, 0.13819400E+02, -.47018500E+01, -.41223500E+01, 0.45454500E+01, 0.23527000E+02, 0.32753600E+01, 0.18343000E+02 },
        { -.78741400E+01, 0.18010800E+00, 0.26210100E+00, -.16324300E+00, -.94573200E+00, 0.18044300E+01, -.27199900E+00, 0.84165800E+00, -.11176100E+01, 0.14439500E+01, 0.62115800E+00, -.24601000E+01, -.13198200E+00, 0.42712500E-01, -.34881000E+00, 0.38115700E+00, -.18389300E+00, 0.17839200E+00, -.34500200E+00, 0.33619400E+00, 0.80494200E+00, -.70979800E+00, 0.93005800E+00, 0.14185600E+01, -.80506200E-01, 0.17969200E+00, -.52842900E+00, 0.13890300E+01, 0.23806400E+01, -.12548100E+01, 0.43518300E+00, -.29405800E+01, -.32042900E+00, 0.92484400E+00, 0.18664500E-02, -.30262200E+00, 0.23028400E+00, 0.53983500E+00, 0.35056200E+00, 0.11184800E+00, 0.35235700E-01, -.30004000E+00, -.47069100E+00, 0.12130600E+01, 0.21537500E+00, 0.28287500E+00, -.25195300E+00, -.48085400E-01, -.66891200E+00, 0.62933600E-01, 0.28545700E+00, 0.16463300E+01, 0.35927300E-01, -.49457600E+00, -.99033800E+00, -.64831700E-01, 0.69460200E-02, -.10891100E+01, -.98152800E+00, 0.88637200E-02, 0.16852800E+00, -.19709100E-01, -.10547700E+01, 0.13247400E+00, -.14953500E-01, 0.26941600E+00, -.51565400E+00, 0.72767500E-01, -.77610400E+00, -.23809800E-03, 0.31179100E+00, 0.11123700E+00, 0.20967400E+00, 0.11541300E-01, 0.93968700E+00, 0.36103100E+00, 0.87590800E+00, 0.31459700E+01, -.20144000E+01, 0.13570000E+01, 0.81398000E-01, 0.46495400E+00, 0.32429900E+00, -.10006100E+01, 0.16794900E+01, -.14897600E+01, 0.10160200E+00, 0.56002000E+00, -.12170300E+00, 0.27788100E+00, -.72597900E-01, -.41454200E-01, 0.13235600E+01, -.14163400E-01, 0.31662400E-01, 0.16961500E+00, 0.33952300E+00, -.18699100E+00, -.38762600E+00, 0.46348500E+00, 0.32604300E-02, -.44777700E+00, -.11070400E+00, 0.11991600E+00, 0.45023500E-01, 0.39199400E+00, -.19907200E-02, -.61776600E+00, -.14537300E+00, 0.53547500E-01, 0.31457200E+00, 0.36760400E-02, -.18680500E+00, 0.30213300E-02, -.54920600E+00, 0.10801900E+00, -.37778300E-01, -.93291600E+00, 0.13554400E+00, 0.10820700E+01, 0.13086100E+00, -.39717300E-01, -.41641200E-01, -.77670000E+00, 0.70645300E-02, 0.16468600E+00, -.10432200E+00, -.18434700E+00, 0.37149500E-01, -.15648500E+01, -.90838600E-01, -.25434100E+00, 0.30085100E+00, 0.79191800E-01, -.22715400E+01, 0.94080000E+00, 0.67889600E-01, -.20848500E-01, 0.15454000E+01, 0.14699300E+00, -.13921200E+01, -.20146500E+00, -.21916200E+00, 0.16480400E-01, 0.27350500E-01, 0.25171300E+00, 0.52301100E-02, 0.35647500E+00, -.46591500E+00, 0.13130400E+01, 0.42036000E+00, -.67761600E+00, 0.94993600E+00, -.40430200E-01, -.16427600E-01, 0.22595000E+00, 0.87105300E-02, 0.41386300E-01, 0.11874500E+01, 0.61908900E-01, 0.31607600E+00, 0.78226000E-01, -.22274000E+00, 0.25139400E+00, -.36080200E+00, -.11407600E+00, -.84213100E-01, 0.87172800E-01, 0.22471200E+00, -.11960100E+00, -.42750000E+00, -.93218300E+00, 0.59757400E-01, 0.15144600E+01, -.66641400E-01, 0.16773900E+00, -.22447100E-01, -.11682100E+00, -.10881300E+00, -.37640900E+00, -.63716800E-01, -.24805300E+01, 0.15659200E+00, -.60211100E+00, -.20253400E+00, 0.12659900E+00, 0.55546200E+00, 0.39512600E+00, 0.78206400E-01, 0.16388900E+00, -.12208000E-01, 0.22707800E+00, 0.25342200E+01, 0.95874200E-01, 0.68577000E+02, 0.48066200E+02, -.43928700E+02, 0.14943400E+03, -.45083400E+02, 0.21013400E+02, -.58842800E+02, 0.22514500E+02, 0.60861100E+01, 0.30358600E+00, -.16076800E+02, -.90470200E+02, -.49051400E+02, 0.33676600E+01, 0.32881700E+02, -.50580200E+02, 0.25643100E+02, 0.30784800E+02, 0.25239800E+02, 0.54459500E+02, -.45205100E+01, 0.17135100E+02, 0.50164900E+02, 0.47014100E+02, -.62974600E+02, 0.50571500E+02, -.25332700E+03, 0.12707400E+03, 0.12321900E+03, 0.12669800E+03, -.23713400E+01, 0.62966400E+02, 0.21309200E+02, -.12292300E+03, 0.12087800E+02, 0.79259900E+02, 0.39801800E+03, 0.32573700E+03, -.16238400E+03, -.38218300E+02, -.16290000E+03, -.97568200E+02, -.58835400E+02, -.37118500E+02, 0.39077800E+01, -.11334000E+03, -.40408400E+02, -.46673700E+02, 0.11848300E+03, -.38044800E+02, -.97886700E+02, -.59184800E+02, -.57460300E+02, -.76325000E+02, 0.18173600E+02, 0.16969100E+03, 0.61954900E+02, -.86868200E+02, 0.18578300E+03, -.35443900E+02, 0.17246600E+02, 0.27379800E+01, 0.17644200E+02, 0.33398300E+02, 0.93854700E+01, -.17622600E+02, -.38061800E+02, -.97965900E+01, 0.25289700E+02, -.48656600E+02, -.35944300E+02, 0.14869500E+02, 0.37668300E+02, 0.18125400E+02, 0.10134900E+02, 0.15359700E+02, 0.67407400E+01, -.43167800E+02, -.18070800E+02, 0.92752900E+01, -.15415800E+03, 0.41462700E+00, 0.43035000E+01, -.97049300E+01, 0.19372100E+00, 0.51690000E+01, -.41911700E+01, -.16586600E+02, -.10517000E+01, 0.96194400E+01, -.40834700E+02, 0.35276700E+02, -.81295400E+01, -.62630700E+01, -.57058700E+00, 0.20967000E+02, -.39707200E+02, -.29106000E+01, 0.17002700E+01, 0.58150200E+01, -.17240600E+01, -.95771400E+01, 0.17113200E+02, -.29110700E+02, -.66848900E+02, 0.22759900E+01, -.39878300E+02 },
        { 0.17001400E+02, -.39929000E+00, -.10914700E+01, 0.13153200E+00, 0.58767400E+00, -.29409300E+01, 0.14595100E+01, -.24539100E+01, 0.12702500E+01, -.14293600E+01, -.48004100E-01, -.12840900E+01, 0.97273200E-01, 0.13308200E+01, -.28748800E+00, 0.51540300E-01, -.21608400E+00, -.10467800E+01, -.31538000E+00, -.68733800E-01, 0.35331000E+00, 0.21233900E+00, -.10691900E+02, -.17634400E+01, -.82973000E+00, -.44099600E-01, -.71814600E-01, -.19284700E+00, -.33198200E+00, -.66092000E+00, 0.18870500E-01, -.15564000E+01, 0.16262800E-01, 0.56844800E-01, 0.30644800E+01, -.72697500E+00, -.28627900E+00, 0.25472600E+01, -.74009400E+00, 0.18808900E+00, 0.12723000E+00, 0.21048200E+01, -.20947500E+00, -.56231600E+00, 0.74324100E+00, 0.20285700E+00, -.10109100E+00, 0.25987100E-01, -.95186700E+00, -.39660700E-01, 0.58314900E+00, 0.59100600E-01, 0.79979000E+00, 0.21712700E+00, -.29172800E+01, 0.42002200E+00, -.29194300E-02, 0.64459900E+00, 0.93666300E-01, -.13329300E+00, -.57445900E+00, 0.72528800E+00, -.15006200E+00, -.22047600E-01, -.99876500E+00, -.71443200E+00, -.19765100E+01, 0.77362600E-01, -.47427300E+01, 0.78760900E-02, 0.56105400E+00, -.67998200E+00, -.35095500E+00, 0.30337600E+00, 0.44039600E+00, 0.51993900E+00, -.89133900E-01, 0.38180000E+01, -.85184700E+00, 0.67533400E+00, 0.76186600E-01, 0.79936200E+00, 0.56264100E+00, -.89729100E+00, 0.39424200E+00, -.72992500E+01, 0.25419500E+00, 0.26394800E-01, 0.44667400E+00, 0.19774700E+01, -.78556700E+00, 0.13687700E+00, 0.10854000E+01, 0.61747100E+00, 0.18915400E+00, -.22428500E+00, -.13950600E+01, -.21949900E+00, -.17014800E+01, -.42293700E+00, 0.14508700E+00, 0.18540300E+01, -.50819900E-01, -.54574500E+00, -.28109500E+00, 0.40608600E+00, -.17089200E+00, -.68359800E+01, 0.14497600E+00, -.25743600E+00, 0.35981000E+01, -.26179300E+00, -.26444600E+00, -.17385000E-01, -.25894700E+01, 0.63950300E+00, -.11205800E+00, 0.52560100E+01, -.45036400E-01, 0.46173700E+00, -.14443200E+00, -.23049800E+00, 0.28951300E-01, -.14458900E+01, -.12582800E-02, 0.71949600E+00, 0.24724500E+00, 0.98345900E+00, -.11307700E+01, -.17227300E+01, -.59167200E+01, 0.53509300E+00, 0.15994300E+00, 0.39280300E-02, -.86154700E+01, 0.74670600E+00, 0.24306500E+00, 0.67586200E+00, 0.26746600E+01, -.32453500E+01, -.72311500E+00, -.87489600E-01, -.65707600E-01, -.31610200E+00, -.36484400E-01, -.13093800E+00, 0.33569200E-01, 0.19133400E+01, -.36850700E+00, -.57374700E+00, 0.33198300E-01, 0.51274300E+00, -.13737000E+01, -.50831500E+00, 0.38349100E+00, 0.20477600E+00, 0.79627200E-01, -.82168600E-01, 0.95890100E+00, 0.52740500E+00, -.53851300E+00, 0.68518700E+00, 0.17577500E+00, 0.40133600E+00, -.83702700E-01, -.12023600E-01, -.18431800E+00, -.30828000E+01, 0.24230800E-01, 0.43172200E+00, -.51903300E-01, 0.33309200E+01, -.16794500E+00, -.12815200E+01, -.11210500E+01, -.26656600E-01, 0.13100500E+00, -.16816600E+00, -.12354400E+01, -.25357900E+01, -.16163200E+00, 0.64580100E+01, -.44036800E+00, -.10350100E+01, 0.13050300E+00, 0.51153100E+00, -.89189900E+00, 0.35121300E+00, -.14678800E+00, 0.16036900E+00, 0.81852200E-02, 0.39072600E+00, 0.46542800E+01, 0.89787600E+00, -.25774900E+00, 0.13550200E+03, -.11472800E+03, 0.47661000E+03, 0.10278600E+03, -.82450100E+02, -.23982400E+03, -.51436000E+02, -.21256200E+02, -.87956100E+02, 0.61119500E+01, 0.10173700E+03, 0.11434400E+03, -.12319600E+03, -.90582400E+02, -.71501500E+02, 0.41918900E+02, 0.46775500E+02, 0.35529800E+02, 0.17366200E+03, 0.69356800E+02, 0.37515200E+02, 0.61408900E+02, 0.98287100E+02, -.21734200E+02, 0.41457000E+03, -.11982700E+04, 0.60048400E+03, 0.32396300E+03, 0.59945100E+03, 0.11785700E+03, 0.26457700E+03, 0.14813200E+03, -.23851400E+03, 0.30976400E+03, 0.24713700E+03, 0.12639200E+04, -.81612000E+03, 0.40827000E+03, 0.24951900E+03, 0.40799400E+03, 0.10202000E+03, 0.18986800E+03, 0.70887800E+02, -.15069400E+03, 0.31826800E+03, 0.16049400E+03, 0.77733000E+03, 0.12441600E+04, -.61511600E+03, -.70723500E+03, -.62182500E+03, -.13590000E+03, -.78697100E+02, -.29022200E+03, 0.10005200E+03, -.35458300E+03, -.35998200E+02, -.33680700E+03, 0.29326900E+03, -.14560000E+03, -.74047800E+03, -.14694100E+03, -.51185700E+02, -.37428100E+02, -.12392500E+03, 0.73591000E+02, -.29215900E+02, -.38460300E+02, -.18583400E+03, -.18255300E+03, 0.87494200E+02, 0.24443100E+03, 0.91258300E+02, -.29688300E+02, -.38689700E+02, 0.17380700E+03, 0.21492700E+03, 0.32635200E+03, -.58070500E+02, 0.82857500E+01, 0.13364900E+01, 0.30917700E+01, 0.32017500E+01, -.25706200E+01, -.11688500E+02, 0.66047100E+01, -.15085400E+02, -.17461400E+01, -.55214900E+01, -.72209200E+02, 0.80311600E+02, -.26596700E+02, 0.91164900E+01, 0.13917600E+02, 0.15632000E+02, -.78000000E+02, 0.88669200E+01, -.44269000E+01, 0.40628300E+02, -.64403400E+02, -.38957300E+02, 0.20502800E+02, -.14528200E+02, -.56622300E+02, 0.73799400E+01, -.92483800E+02 },
        { 0.16752100E+01, -.53739600E-01, -.59038500E-01, -.24510700E+00, 0.15246200E+00, -.40089600E+00, 0.34726700E+00, -.14909400E+00, -.45199500E-01, -.32717000E+00, 0.44113700E-02, 0.38681800E-01, 0.78178000E-02, 0.16097900E-01, 0.33755200E-01, -.37908900E-01, 0.79653600E-01, 0.15386600E+00, 0.13997900E+00, -.39381700E-01, 0.44303600E-01, 0.13066900E-01, 0.11775700E+01, 0.12157400E+00, 0.22861600E-01, 0.37222900E-02, -.10185800E-01, 0.40402600E-01, -.54494100E-01, 0.22294700E+00, 0.20577100E-01, -.71925600E-01, 0.60728700E-02, 0.18874000E-01, 0.54665500E-01, -.19390600E-01, 0.67513800E-02, 0.32306600E+00, 0.13941000E-01, -.93212000E-01, 0.28398900E-01, 0.56823700E-01, -.33260500E-01, -.15879700E-01, 0.92843300E-01, 0.24187300E-01, 0.31920500E-01, -.68219700E-03, -.42513900E-01, -.35915300E-02, 0.30877600E-01, 0.83216400E-01, 0.78013000E-02, -.16829800E-01, 0.11886800E+00, -.30211800E-01, -.40244700E-02, 0.20640000E-02, -.29957000E-01, 0.91831600E-02, -.20912000E-01, 0.24163600E-01, 0.53581700E-01, -.13501700E-01, -.81010300E-01, 0.55227700E-02, -.17948600E-01, -.18648400E-02, 0.94369100E-02, -.51840600E-03, -.98704500E-02, 0.13031300E-01, 0.18284000E-01, 0.89386800E-02, -.10348900E+00, -.34944900E-01, 0.49651600E-01, -.18415200E+00, 0.86839200E-01, 0.14037500E+00, 0.82165200E-03, -.12152100E+00, -.16422000E+00, -.24413500E-01, 0.10216400E+00, -.50918300E+00, 0.13540500E-01, -.12343600E-01, -.61529100E-01, -.37927800E-01, -.55015400E-02, -.75839000E-02, 0.10971800E+00, -.14822200E-01, -.44347300E-01, 0.97981600E-01, 0.57691500E-01, 0.38183200E-01, 0.25066600E+00, -.12485000E-01, -.12210200E-02, -.90864700E-01, -.57466200E-02, 0.32041600E-01, 0.99762200E-02, -.14273900E-01, -.29197300E-03, 0.14615000E+00, -.96790800E-02, 0.16278800E-01, 0.17786900E+00, 0.11650300E-01, 0.13836000E-01, -.53174700E-03, 0.14416700E-02, -.21179100E-01, 0.42827100E-02, -.36368600E+00, -.24251900E-03, -.90034800E-01, 0.17361700E-01, -.15159700E-01, -.62162000E-02, -.30930700E-01, -.12128700E-02, -.72881400E-01, -.24054900E-01, -.10294500E+00, -.48021100E-01, -.64771100E-01, 0.45285900E+00, -.32012200E-01, -.13946100E-02, -.19350600E-02, 0.43458900E+00, -.78877400E-01, -.11495500E-01, -.13720200E-01, 0.25094200E+00, -.92844400E-01, -.35857000E-01, -.84750800E-01, 0.15028200E-01, -.87131500E-02, -.43057200E-02, -.65801900E-02, -.70999600E-02, -.10492300E+00, 0.16258400E-01, 0.13263100E+00, -.20410000E-03, 0.20163100E-01, -.36598400E-01, 0.11577800E-01, -.45353800E-01, -.21665000E-01, -.26789700E-02, 0.53651500E-02, -.28788200E+00, 0.11358800E+00, 0.15135900E+00, -.98937400E-01, 0.54343800E-01, -.11027600E+00, 0.50643800E-01, -.46386200E-01, 0.33874300E-02, 0.16359500E+00, -.36316600E-01, -.16486200E-01, 0.16806300E+00, -.72078900E-01, -.10260800E+00, 0.34498000E+00, 0.11981500E-02, 0.68779800E-01, 0.38425000E-01, 0.23826600E-01, 0.11609100E+00, -.21377000E+00, -.77510500E-02, 0.12774700E+01, 0.21297300E-01, 0.16541000E+00, 0.39901200E-01, 0.20344700E+00, 0.22897700E-01, -.31561000E-02, 0.11879600E-01, 0.54345300E-01, 0.10004800E-02, 0.20133800E-01, -.24255300E+00, 0.28267600E+00, 0.13173600E+00, 0.53618400E-01, 0.16411500E+02, -.98661800E+02, 0.71719800E+01, -.11414900E+01, 0.24341600E+02, -.35721600E+01, 0.37845300E+01, 0.69917800E+01, 0.28489500E+01, 0.20944700E+02, 0.57766800E+01, 0.11809300E+02, 0.23202400E+00, -.54921200E+01, 0.26634500E+01, -.59468000E+01, 0.28267100E+01, -.24500000E+02, -.12153700E+02, 0.24310400E+01, -.62274100E+01, 0.10386100E+01, 0.88656700E+01, -.68865700E+02, 0.56903300E+02, -.29264200E+02, -.74138200E+01, -.28541900E+02, -.90728500E+01, -.19593700E+02, -.85473100E+01, 0.18284500E+02, -.18176900E+02, -.14989900E+02, -.60286700E+02, -.25265600E+02, 0.12791600E+02, 0.27234600E+02, 0.12671400E+02, 0.45545000E+01, -.87437600E+01, 0.17820400E+02, 0.12090100E+01, -.16352600E+02, -.57990400E+01, -.15135800E+02, 0.36593500E+01, -.49355000E+01, -.15663100E+02, -.18393200E+01, 0.93131500E+01, 0.11515000E+02, -.14248300E+01, -.77873700E+01, -.56789800E+01, 0.98897400E+01, -.39041200E+02, -.71538400E+02, 0.35920500E+02, 0.40637200E+02, 0.35882900E+02, 0.14930200E+02, 0.15902500E+02, 0.11387600E+02, -.36002000E+00, 0.19027400E+02, 0.11176900E+02, 0.35958200E+02, 0.18098300E+02, -.87176700E+01, -.16604200E+02, -.91054700E+01, -.10753200E+02, -.16611000E+02, -.19509200E+01, 0.24604300E+01, 0.75286100E+01, -.13484100E+02, 0.58805600E+01, 0.98970900E+00, -.13179600E+01, 0.14181800E+01, 0.12938100E+00, 0.64080900E+00, 0.64492800E+00, 0.32800100E+01, 0.15368300E+00, -.13211200E+01, 0.43280600E+01, -.43326200E+01, 0.41054900E+01, 0.12052400E+01, -.14289200E+01, -.55696800E+01, 0.47503800E+01, -.14621300E+00, 0.73100900E+00, -.85103500E+01, -.13013000E+02, 0.71828600E+01, -.38067400E+01, 0.80689200E+01, 0.76494000E+01, 0.86524400E+00, 0.39960200E+01 },
        { -.30998000E+01, 0.11121900E+00, 0.12671300E+00, -.31651100E+00, -.41052300E+00, 0.10055000E+01, -.69404800E+00, 0.37075200E+00, 0.46128000E+00, 0.74908300E+00, -.12502900E+00, -.43989000E+00, 0.15634400E+00, 0.71012800E-02, -.35020300E+00, 0.22045900E+00, -.13915700E-02, -.13572900E+00, -.27171600E-01, -.19885600E-01, -.26789300E+00, 0.81500200E-01, -.45917000E+01, -.45971300E+00, -.14643600E+00, -.42145100E-01, 0.14653600E+00, 0.47954300E-01, -.21910800E+00, -.36128900E+00, 0.25757300E+00, 0.31695500E+00, -.93067100E-02, -.40709500E+00, 0.30914400E+00, 0.25944400E+00, -.70127300E-01, 0.16880000E+01, -.79081500E-01, 0.54406200E+00, -.36948100E+00, -.84467900E+00, -.96893800E-01, 0.88492100E+00, -.14982900E+00, -.14849700E-01, -.11859600E+00, 0.12022900E-01, 0.43982500E+00, -.13653600E+00, 0.39620000E+00, -.75773400E-01, 0.10094600E+00, 0.80196100E-01, 0.11109100E+01, -.12005700E+00, 0.75264600E-02, -.11512000E+00, 0.50974300E-01, 0.79004200E-01, -.78620600E-01, -.55787300E-01, 0.19503400E-02, -.49107300E-02, -.20313800E+00, -.10529600E+00, -.79948100E+00, 0.11008700E-01, -.40661100E+00, -.20434600E-02, 0.34603900E-01, -.63001700E-01, 0.46904600E-01, 0.45305700E-01, -.12352300E+00, 0.27584200E-01, 0.92640000E-01, 0.47453200E+00, -.18243700E+00, 0.27776300E+00, 0.35269300E-02, 0.21359700E-01, 0.32272100E+00, -.22019400E+00, 0.16669900E+00, -.31433600E+01, 0.10223400E+00, -.37789800E-01, 0.13512800E-01, 0.16595100E-01, -.29509000E-01, 0.21096500E-01, 0.19141100E+00, -.14093100E-01, -.12880200E-01, 0.27326300E+00, 0.96065900E-01, -.32997700E+00, -.91838200E-01, -.14538400E+00, 0.85494800E-01, 0.31663600E+00, -.97812800E-01, -.53537100E+00, 0.18796800E+00, 0.55864400E+00, 0.35891300E-01, -.28222200E+01, 0.22052000E+00, -.10585300E+00, -.18236000E+01, 0.94144500E-02, -.12702400E+00, 0.10421300E-01, 0.23458000E-01, -.62574500E-01, 0.10660400E-01, 0.79802900E+00, 0.49808500E-01, 0.39881800E+00, -.90542200E-01, 0.44625400E-02, 0.92506200E-02, 0.16047600E+00, 0.10283600E-01, 0.48492500E-01, -.50505400E-02, 0.94403200E-01, -.11757000E+00, -.10128400E+00, 0.38476100E-01, 0.15264400E-02, -.34872600E-01, 0.60962400E-03, 0.71763800E+00, -.88179500E-01, 0.29151800E-02, -.57448900E-01, 0.17079900E+00, -.47886100E-01, 0.20586900E-02, 0.55447900E-01, 0.15016500E-01, 0.46279100E-01, 0.19591100E-01, -.74745200E-02, -.10572800E-01, -.20308300E+00, 0.10073300E+00, -.29289800E+00, -.14683300E-01, -.12835200E+00, 0.58326600E+00, 0.75656400E-01, 0.72807100E-01, -.14497700E-01, 0.60524700E-01, 0.31532900E-01, -.98987600E+00, -.14985000E+00, 0.38940200E+00, 0.87359900E-01, 0.70697900E-01, 0.90646000E-02, -.85639400E-01, 0.75399400E-01, 0.11278300E+00, 0.41345000E-01, -.12441300E+00, -.15031500E-01, -.25385800E-01, -.18552800E+00, 0.67560000E-01, -.76531300E+00, 0.49431400E-01, 0.77174900E-01, 0.36586500E-01, 0.50765700E-01, 0.14867000E+00, 0.63973100E+00, 0.50470600E+00, -.26027600E+01, 0.16547800E+00, -.28358200E+00, -.33990100E-01, -.58336100E+00, 0.26875700E-01, 0.60791400E-01, -.14237000E-01, -.42694200E-01, 0.91056800E-03, -.10920300E+00, -.16750100E+00, -.12319400E+00, -.16853400E+00, -.51832200E-01, -.21837400E+01, -.17817600E+03, 0.10457900E+02, -.43209100E+00, -.12960300E+01, -.52569500E+01, -.31345100E+00, -.10471900E+02, 0.14123000E+02, 0.39175700E+02, 0.19015800E+02, 0.76573600E+01, 0.15578500E+02, -.42578400E+02, 0.21047100E+02, 0.17264200E+02, 0.21205000E+02, -.21787200E+02, -.17160400E+02, 0.31140600E+01, -.25239000E+02, 0.80718800E+01, -.75129300E+01, -.13622100E+03, 0.51847500E+02, -.27615300E+02, 0.11409000E+02, -.25827100E+02, -.18111800E+02, -.25540500E+02, -.12309300E+02, 0.66737600E+01, -.32240000E+02, -.63246800E+01, 0.57866200E+02, -.41484700E+02, 0.21113500E+02, 0.79661500E+02, 0.20714000E+02, -.65328800E+01, -.25772400E+02, 0.35462200E+02, -.12108700E+02, -.45034200E+02, -.10447300E+02, 0.10240200E+01, 0.14154900E+02, -.63106000E+01, -.99191500E+02, -.70053100E+01, -.87665100E+01, -.36894100E+02, 0.38755800E+02, 0.71983000E+02, 0.22768700E+02, -.37320800E+02, -.51563100E+02, -.87853700E+02, 0.44683500E+02, 0.65818400E+01, 0.43781300E+02, 0.12363200E+02, 0.75518600E+00, 0.38098400E+02, 0.34668300E+02, 0.44243900E+02, -.28151500E+01, 0.46475700E+02, 0.70533000E+02, -.33125400E+02, -.11713400E+02, -.35176900E+02, -.66795300E+01, 0.16923800E+02, -.58258500E+02, -.45562900E+02, -.70439000E+01, 0.19176800E+02, -.23287700E+02, 0.40049300E+01, -.13207800E+01, 0.47793300E+01, 0.87125900E+00, 0.12678000E+01, 0.11865700E+01, -.20342500E+01, 0.38865900E+00, -.42375000E+01, 0.16605700E+01, -.17218300E+01, 0.23899000E+01, 0.31988000E+01, -.44861200E+00, -.12241800E+01, 0.20677100E+01, 0.19857700E+00, 0.37834300E+01, -.22127800E+01, -.54846900E+02, 0.64345000E+01, 0.24793100E+01, 0.55245500E+01, -.23036700E+01, 0.36758900E+01, -.48868400E+01 },
        { 0.90871400E+01, -.10296100E+00, -.42265000E+00, 0.46416300E+00, 0.86410100E+00, -.65273300E+00, -.16230000E+01, 0.68701100E+00, 0.70091300E+00, 0.17841500E+00, 0.21067100E-01, 0.60690300E+00, -.54624400E-01, -.52196600E-01, 0.16596700E+00, -.19662400E+00, 0.49599700E+00, 0.25637500E+00, 0.85559400E+00, -.14700100E+01, -.50326700E+00, 0.15229600E-01, -.14067000E+01, 0.93502500E-01, -.44544800E-01, -.35807400E-02, 0.26953200E-01, -.63116700E+00, -.71629700E+00, -.50630900E+00, -.63765200E+00, 0.23218900E+00, 0.23282300E-01, -.10659000E+01, 0.23006800E+01, 0.55855200E+00, 0.36144500E-01, 0.60257000E+00, -.69213400E-01, 0.99663700E+00, -.91381200E+00, -.16732800E+01, 0.80172300E-01, 0.14043900E+01, -.21198600E+01, 0.27111900E+00, -.33989700E+00, 0.12064200E-01, -.29068600E+00, -.17651200E+00, -.21152200E+01, 0.63141500E+00, -.87481700E-01, -.31457100E+00, -.61747100E+00, 0.16192300E+00, -.83201800E-02, -.17675100E+00, 0.78066700E-01, -.44000600E-01, 0.19695500E+00, -.68087600E-01, -.30220500E+00, -.37174700E-01, 0.18575900E-01, 0.12266800E+00, 0.43451700E+00, -.13865400E-01, -.13056900E+00, 0.26214300E-02, -.38427800E-01, 0.57787800E-03, -.18464900E+00, 0.21676300E-01, -.41758900E+00, 0.19464000E-01, 0.54942300E+00, 0.43024000E+01, -.40215400E+00, -.22142000E+00, -.22850400E-01, 0.12063100E+00, -.69364300E+00, -.20092400E+00, -.65423200E+00, 0.35580600E+01, -.22079600E-01, 0.24183300E+00, 0.18401900E+00, 0.10926000E+00, 0.81792200E-01, -.45537000E-01, -.60439100E+00, -.16981600E+00, -.57916800E-01, -.24419700E+00, 0.44597300E-01, 0.34043300E-01, 0.69702200E-01, 0.33556500E+00, -.36763300E-01, -.43183600E+00, 0.58998700E-01, 0.39028900E+00, 0.42694100E-01, 0.46822000E-01, -.20931200E-01, -.76759300E+00, 0.13043900E+00, -.48119100E-01, -.14954500E-01, -.10106100E-01, 0.43320500E-01, -.36088500E-02, 0.18733800E-01, 0.28367000E-01, 0.19994600E-01, 0.54190800E+00, -.14462700E-01, -.23001800E+00, 0.13342900E+00, 0.16919400E+00, -.12782800E-03, 0.33081600E+00, 0.48430700E-02, -.52813900E-01, -.73079800E-01, -.29801700E+00, 0.46447100E+00, -.56024100E+00, -.91805900E+00, -.19916000E+00, 0.22152900E+00, 0.25038900E-01, -.13845100E+01, 0.12187100E+01, 0.93957100E-01, -.15830500E+00, -.87708700E-02, 0.69325500E+00, -.71316800E+00, 0.11136700E+00, 0.68219600E-01, -.55945700E+00, 0.22900100E-01, -.87410800E-03, -.23108500E-01, -.54129600E+00, -.67958900E-01, -.54403400E+00, -.22638500E-01, 0.94826700E-01, 0.51903000E+00, 0.91216700E-01, 0.30144700E+00, 0.59098900E-01, 0.13019200E+00, -.31198800E-01, -.93915800E+00, -.34268000E-01, 0.47396500E+00, 0.26743500E-01, 0.55240800E-01, -.17833200E+00, 0.53423000E-02, 0.15486000E+00, -.53794000E-01, -.80399800E+00, -.46289000E-01, 0.50822700E+00, -.77242200E-01, 0.15899100E+01, 0.23199200E+00, 0.58394800E+00, 0.26482100E+00, -.61916700E-01, -.16860300E+00, -.13063700E-01, 0.47975800E+00, 0.11184900E+01, -.65853200E-01, 0.59586600E+00, 0.70093100E-01, 0.36434000E+00, -.28869200E-01, -.23687900E+00, 0.35630500E-01, -.20462700E+00, 0.18659500E-01, 0.13635600E-01, -.32174800E-02, 0.14104300E+00, 0.11800800E+01, -.58997800E+00, -.16471400E+00, 0.16282400E+00, 0.18800300E+01, -.37116800E+00, -.69681600E+02, 0.40867500E+02, 0.97992900E+01, 0.34845600E+02, 0.55012000E+01, 0.16911200E+02, 0.39507700E+01, -.53597800E+02, -.17269100E+02, 0.26457500E+02, 0.43833200E+02, -.76680800E+01, 0.48793800E+01, -.12457600E+02, 0.38987200E+01, 0.13617600E+02, 0.19924300E+01, -.26258600E+02, -.29174700E+02, -.37327400E+01, -.11054700E+02, -.44669800E+02, -.10445400E+03, 0.50527200E+02, 0.75496500E+02, 0.52141400E+02, 0.15211600E+01, 0.10406500E+02, -.22028800E+01, -.63522400E+02, -.34658600E+02, 0.23533100E+02, 0.51677400E+02, 0.16800900E+03, -.83600500E+02, 0.57886400E+02, -.83983000E+02, -.62506000E+02, -.69400700E+02, 0.22890800E+02, 0.52039800E+00, -.11810100E+03, -.48061800E+02, -.12814600E+03, -.38961600E+02, 0.34299800E+02, -.85559500E+02, 0.19479800E+02, -.18967000E+02, -.51714000E+02, 0.27848000E+02, 0.63880800E+02, 0.53554600E+02, -.55077100E+02, 0.91753800E+02, -.78270300E+02, 0.39986200E+02, 0.14600800E+02, 0.39234400E+02, 0.19645900E+02, 0.15128200E+02, 0.54971400E+01, -.20325300E+02, 0.32134900E+02, 0.16070000E+02, 0.49275200E+02, -.54315900E+00, -.62123200E+00, 0.24314900E+02, 0.29586300E+00, 0.81005300E+01, 0.22915000E+02, -.22947900E+02, -.42993700E+02, -.20915300E+02, 0.15985400E+02, -.57548300E+02, 0.23832200E+01, 0.28806700E+01, -.24111400E+01, 0.95386900E+00, 0.15801100E+01, -.47098300E+00, -.10612000E+02, -.66427700E+00, 0.28415400E+01, -.13188700E+02, 0.10358300E+02, -.12304900E+01, -.29145200E+01, 0.11736300E+01, 0.95799600E+01, -.11430800E+02, -.80029100E+00, 0.58557900E+00, 0.48316700E+00, -.11093400E+02, -.36068500E+00, 0.75420200E+01, -.88579600E+01, -.27471000E+02, -.14133500E+01, -.14170700E+02 },
        { 0.22607900E+02, -.10401400E+01, -.41639600E+00, -.22855100E+00, 0.19306000E+01, -.48858400E+01, 0.10389000E+01, -.33796900E+01, 0.58663000E+01, -.33267400E+01, -.33582000E-01, 0.34088200E+01, -.28492600E+01, -.27396800E+00, -.45282200E+00, -.34994700E+00, 0.69109300E+00, -.51332700E+00, 0.25834800E+01, -.17930200E+00, -.10372800E+01, 0.11027100E+01, -.14365700E+02, -.34248100E+01, 0.13368000E+00, -.34563000E+00, 0.40457100E-01, -.18182600E+01, -.23836400E+01, 0.10051900E+01, -.21606800E+00, -.15280000E+01, 0.10858200E+00, -.22304400E+01, 0.16733800E+02, 0.17018300E+00, 0.37383600E+00, 0.71487700E+01, -.10118800E+01, 0.70219000E+00, -.35189600E+00, 0.17673000E+01, -.18434800E+00, 0.13692000E+01, -.16050700E+00, 0.67668000E+00, -.71828000E+00, -.75569500E-01, 0.35956600E+00, -.36101500E+00, 0.34177600E+00, 0.39740200E+01, -.55881600E+00, -.15687700E+01, 0.10755600E+01, 0.13680900E+01, -.27401300E+00, 0.49710900E+00, -.14059000E+01, 0.43110000E+00, 0.96422700E+00, 0.63250400E+00, -.14573600E+01, 0.14142700E+00, -.32740100E-01, -.33197600E+00, -.27379700E+01, 0.94771600E-01, -.79332400E+00, -.18847000E-01, 0.43022300E+00, -.10152500E+01, 0.31777500E+00, -.28320900E+00, 0.79522300E+00, -.21067300E+01, 0.27993300E+00, -.21369800E+02, 0.67617600E+00, -.36767200E+00, -.28545200E-01, -.20712300E+00, -.12377600E+01, 0.16242600E+01, -.22541700E+01, -.25640500E+02, 0.19725100E+00, -.17506800E+00, 0.30155300E+01, -.65750400E+00, 0.99746800E+00, -.60402100E-01, -.29415300E+00, 0.13213600E+01, 0.43826300E+00, 0.15275400E+01, -.66371800E-01, 0.53085600E+00, -.30369400E+01, 0.19566500E+00, -.55123900E-01, 0.80272800E+00, -.13454100E+00, 0.14228000E+01, 0.11612600E+00, 0.10668400E+01, -.12254600E+00, -.23339400E+01, 0.42994000E+00, -.15546700E+00, 0.96885100E+00, -.43731900E-01, 0.28921200E+00, -.70535400E-02, -.10323800E+01, 0.10365700E+01, -.16101400E+00, -.44262500E+01, 0.26429100E+00, -.43505300E+01, 0.63103900E+00, -.11353400E+00, 0.73702700E-01, -.10516200E+01, -.24712500E-01, 0.27535500E+01, 0.14195900E+00, -.12854000E+01, -.80661900E+00, 0.24938700E+01, -.44489700E+01, 0.58116500E+00, 0.72528800E+00, -.53612900E-01, -.62432400E+01, -.88817900E+00, 0.20742000E+00, 0.31724500E+00, 0.13322400E+00, 0.45106500E-01, -.12526900E+01, 0.13929900E+00, 0.14779200E+00, -.10821800E+01, 0.22694000E-01, 0.19909300E-01, 0.62686800E-01, -.39462700E+01, -.56135900E+00, 0.23296600E+01, 0.76469300E+00, -.73140400E+00, 0.12155200E+01, -.34158900E+00, -.16926200E+00, -.33962100E+00, 0.34128000E+00, -.16359700E-01, 0.13917200E+01, 0.52323400E+00, -.23450900E+01, 0.35540500E+00, 0.68685300E+00, -.87453900E+00, 0.16209700E+00, -.46987200E+00, -.12849100E+00, -.11277500E+01, -.37634700E+00, 0.62449600E+00, 0.12272900E+01, 0.52397000E+01, -.40829100E+00, 0.14965400E+01, 0.10835900E+00, 0.41152800E+00, -.17743400E+00, 0.12629600E+00, -.10632000E+01, -.55327700E+01, -.14983400E+01, 0.17379000E+02, -.10577800E+01, 0.30320500E+01, 0.92507100E+00, 0.50355300E+01, 0.11353600E+01, 0.26475800E+01, -.32985500E+00, 0.16267300E+00, -.66059900E-02, -.88374000E-01, 0.24904000E+01, 0.17343300E+00, 0.23177000E+01, 0.13569000E+00, 0.40841300E+01, -.10012300E+01, -.79863100E-01, -.18099600E+03, 0.15371100E+03, -.25126700E+00, -.31362700E+02, -.66421000E+02, 0.64955900E+02, 0.87278000E+02, 0.11600700E+03, -.72683900E+02, -.48662600E+02, 0.35802500E+03, -.15680900E+03, -.16140600E+03, -.18023700E+03, -.80619500E+02, 0.19899600E+02, -.95098900E+02, 0.58868800E+02, -.99714900E+02, 0.18477400E+02, 0.10642400E+03, 0.55591400E+03, -.27229900E+03, -.23122000E+03, -.27657500E+03, -.16812600E+02, -.43917700E+02, -.85445400E+02, 0.24478500E+03, 0.74862100E+02, -.10163300E+03, -.53754800E+03, -.39653700E+03, 0.19688500E+03, 0.39000500E+02, 0.19776200E+03, 0.11839800E+03, 0.13993700E+03, -.37709700E+02, 0.32042300E+02, 0.26796100E+03, 0.10673400E+03, 0.11982900E+03, 0.36198600E+02, -.19970000E+02, 0.15236200E+03, -.17941400E+02, 0.94066800E+01, -.22094200E+02, -.69771000E+01, -.14980400E+03, -.13153300E+03, 0.17656700E+02, -.37753600E+03, 0.33335000E+03, -.17462600E+03, -.88349800E+02, -.16861500E+03, -.18339900E+03, -.12622000E+03, 0.10440800E+03, 0.15405500E+03, -.49720300E+02, -.12095300E+03, -.47182300E+02, -.16583300E+03, 0.84077200E+02, -.13958200E+02, 0.83880500E+02, 0.21492200E+02, 0.23818800E+02, 0.60544100E+02, 0.13331500E+03, 0.29600800E+03, 0.24899200E+02, 0.26613100E+03, -.28962500E+01, -.62216300E+01, 0.17486700E+02, -.69579900E+00, -.97862400E+01, 0.10838000E+02, 0.28308500E+02, 0.11352400E+01, -.17230700E+02, 0.38705000E+02, -.22999300E+02, 0.12372100E+02, 0.10949700E+02, 0.44150700E+01, -.39087400E+02, 0.29931300E+02, 0.61350400E+01, -.28916000E+01, 0.97727500E+01, -.51116600E+01, -.19137800E+02, -.22651100E+02, 0.30831000E+02, 0.62833800E+02, -.21117700E+01, 0.15088100E+02 },
        { -.38754800E+01, 0.81318400E-01, 0.99284500E-01, -.29844600E+00, -.48196800E+00, 0.42743600E+00, 0.41707800E+00, 0.38978700E+00, -.27917100E+01, -.43989300E-01, -.25447000E-01, -.69056100E+00, 0.37856000E-01, 0.35024600E-01, 0.23806800E-01, 0.16173500E-01, -.44885900E+00, -.22822200E+00, -.32433100E+00, 0.20202800E+00, -.30531300E+00, -.50009700E-01, -.97340700E+00, -.40601800E+00, -.14397600E+00, -.34588100E-01, 0.13821600E+00, -.22477600E-01, 0.21656000E-01, 0.10392200E-01, 0.46954700E+00, 0.19574400E+00, -.42223900E-01, -.45343400E+00, 0.11442600E+01, 0.28008400E+00, -.63793600E-01, 0.12557900E+01, -.57542200E-01, 0.45713000E+00, -.59883600E+00, -.13327800E+00, 0.87372500E-01, 0.43812800E+00, -.67319300E+00, 0.40757800E+00, -.80820100E-01, 0.61295000E-02, 0.10261300E+00, -.17923200E-01, 0.11920400E+00, 0.68639200E+00, -.14780200E+00, 0.62515500E-01, -.14886700E+00, -.10525600E-01, 0.25216800E-02, -.26119000E+00, 0.73196100E-01, -.78034100E-01, -.40912400E-01, 0.88130000E-01, -.77170600E-01, -.67208500E-01, -.45074400E-01, 0.75643900E-01, 0.45321400E+00, -.48720900E-02, 0.68836500E+00, 0.12051900E-02, -.71815400E-02, 0.12980600E-01, -.80560700E-01, 0.22844000E-01, 0.30345900E-01, 0.26039300E+00, -.23144100E+00, 0.57491600E+00, 0.60917600E-01, 0.13964200E+00, -.16857300E-01, 0.17961400E+00, 0.43040600E+00, -.87126900E-01, -.72057700E-01, -.28746800E+00, -.22420200E-01, -.60066900E-01, -.10913500E-01, -.18445800E-01, 0.45108300E-01, 0.15571500E-02, 0.38516000E+00, 0.74344100E-01, -.11573300E+00, -.99617600E-01, 0.24898600E+00, 0.22949200E+00, 0.51704500E+00, 0.26630600E+00, 0.15006300E-01, -.36598800E+00, -.15699400E+00, 0.36397600E-01, -.40312800E-02, -.68342900E-01, 0.73228500E-01, -.19295000E+00, -.12106300E+00, 0.76567300E-01, 0.85241900E+00, 0.14822000E-01, -.51770100E-01, 0.63166900E-02, -.21133000E+00, -.66660200E-01, -.26832100E-01, 0.15854700E+01, -.23288300E-01, -.25447900E+00, -.26038200E-02, -.60642100E-01, -.11813000E-01, -.32018300E+00, 0.21873600E-02, -.71860600E+00, -.52445600E-01, 0.17252700E+00, 0.47321100E-01, -.10564100E+01, -.25730000E+01, -.51033700E-01, 0.15678900E+00, 0.24518300E-01, -.17679300E+01, 0.76530300E+00, 0.57505500E-01, -.11481300E-01, -.31989000E-01, 0.17944100E+00, -.25092900E+00, -.16060500E-01, -.43931300E-01, 0.66947600E-01, 0.23514200E-01, 0.10736300E+00, 0.16920400E-01, -.79359100E+00, -.16477700E+00, 0.12466500E+00, 0.15933800E+00, -.38024600E+00, 0.45614400E+00, 0.37148200E-01, 0.68874600E-01, 0.25625800E-01, 0.31727700E-01, -.35205600E-02, -.11985000E-01, 0.58299000E-01, 0.32780300E-01, 0.73894400E-01, 0.55828500E-01, 0.89169200E-01, -.36322100E-01, 0.12144300E+00, 0.13344500E-01, 0.14817200E-01, -.86252700E-01, -.90568800E-01, 0.13720900E+00, -.73085100E-01, -.32954000E+00, 0.12460400E+01, -.12771700E+00, 0.29438800E-01, 0.53161600E-01, 0.10398600E-01, 0.37711300E+00, 0.38005300E+00, 0.38689300E+00, -.16334100E+01, 0.20889100E+00, -.42422100E+00, -.42111900E-01, -.41795000E+00, -.25354700E+00, 0.19413000E+00, -.23495200E-01, -.24992700E-01, 0.37354600E-02, -.73012400E-02, -.41564200E-01, -.77391700E-01, -.16459000E+00, -.16180300E+00, -.14380400E+01, 0.40344600E+00, -.20224300E+00, 0.31220200E-01, -.58031200E+02, 0.35039000E-01, 0.72700800E+01, 0.24099100E+01, 0.11243800E+01, 0.87217800E+01, 0.15052700E+02, 0.15260800E+01, 0.18110200E+01, -.55994400E+02, 0.30256800E+02, 0.15047700E+02, 0.28179600E+02, 0.13937400E+02, -.16570900E+02, 0.22730600E+02, 0.54447900E+01, 0.18647300E+02, -.10206200E+02, -.17757000E+02, -.13460100E+03, 0.64639700E+02, 0.32210000E+02, 0.67120000E+02, -.13027500E+02, 0.30136300E+02, 0.11122700E+02, -.53936500E+02, 0.35809300E+01, 0.39989400E+02, 0.18244200E+03, -.30236700E+02, 0.15860500E+02, 0.31264200E+02, 0.15205900E+02, -.91460600E+01, 0.33291200E+01, 0.12127300E+02, -.24988300E+02, -.17842000E+02, 0.63585200E+01, 0.55147700E+02, 0.14608400E+03, -.66335300E+02, -.75229800E+02, -.72985100E+02, -.21428500E+02, -.10984100E+02, -.45327100E+02, 0.59347400E+02, 0.23849100E+02, -.19573900E+02, 0.10610000E+02, -.20831900E+02, 0.11582400E+02, -.82192200E+02, 0.10713500E+02, 0.40217100E+02, 0.17520300E+02, -.40248100E+02, -.28143300E+02, -.56773400E+01, 0.21485700E+02, 0.42468400E+01, -.46786800E+02, 0.22114800E+02, -.28895000E+01, 0.23219400E+02, -.18882800E+02, -.43023000E+02, 0.66345400E+02, 0.23641700E+02, 0.41575800E+02, -.34196500E+02, -.74871300E+02, 0.13983500E+00, 0.11409700E+01, -.20904200E+01, -.43952900E-01, 0.12471400E+01, -.32029500E+00, -.18343600E+01, -.59577800E+00, 0.15579900E+01, -.12175500E+02, 0.11411700E+02, -.10411700E+01, -.97858000E+00, 0.96959200E+00, 0.28249000E+01, -.12252400E+02, 0.12710800E+01, -.75039300E+00, -.41411800E+01, -.23865700E+02, 0.42117700E+01, 0.28177500E+01, -.30990700E+01, -.10139000E+02, 0.39102800E+01, -.12230600E+02 },
        { 0.36748700E+01, -.98535800E-01, -.12505900E+00, 0.43175000E+00, 0.32559400E+00, -.76734600E+00, 0.33477700E+00, -.38263500E+00, 0.28782200E+00, -.67215300E+00, 0.80441100E-03, 0.47865400E+00, -.25462200E-01, 0.52873700E-02, 0.46174800E+00, -.13686700E+00, 0.11404300E+00, 0.17865300E+00, 0.20354500E+00, -.11726600E+00, -.63892600E-01, 0.64887500E-01, 0.25585800E+01, -.86795300E-01, -.10106400E-02, 0.33393500E-01, -.71693700E-01, -.12246500E+00, -.33535100E+00, 0.26718900E+00, -.16472000E+00, -.32745600E-01, 0.19663000E-01, 0.13950800E+00, 0.79534900E+00, -.11006500E+00, -.47008900E-01, 0.37684100E+00, -.81725300E-01, -.19357300E-01, 0.25598300E-01, 0.43597400E+00, 0.69456500E-01, -.13113400E+00, 0.80184500E-01, 0.99883600E-01, 0.86049300E-01, -.23264000E-02, -.14284200E+00, 0.24074800E-01, 0.12923700E+00, 0.14105100E+01, -.24416400E-01, 0.31363800E-01, -.22899900E+00, 0.93883700E-01, -.42794700E-02, 0.23663100E+00, -.60163600E-02, -.10027100E-01, -.60770100E-01, 0.99036700E-01, 0.20036100E+00, -.41993800E-01, -.77406700E-01, 0.39142200E-01, 0.13669800E-01, -.54301400E-02, -.11170900E+00, 0.45047000E-03, -.12419400E-01, -.53843900E-01, -.46316500E-01, -.94149600E-02, -.36937300E-01, -.83434000E-01, -.26011000E-01, -.48022000E+00, 0.18639700E+00, -.14382300E+00, -.74104600E-02, -.66626000E-03, -.13749300E+00, 0.16211900E-01, -.18719400E+00, 0.35890600E-01, -.95892500E-01, -.35337200E-01, -.11595000E+00, -.16304200E+00, 0.74984900E-01, -.27382700E-02, -.48060700E+00, -.23712700E-01, -.30961900E-01, 0.38161100E-01, -.13773700E+00, -.77592000E-01, 0.10261600E+00, -.25921100E-02, 0.22901800E-01, 0.13567100E+00, -.53182300E-02, -.74676200E-01, -.39525000E-01, 0.47969200E-01, -.23126200E-01, -.69010900E+00, -.71617900E-01, 0.17798500E-01, 0.10442800E+00, 0.10878600E-01, 0.20432800E-02, 0.67445000E-03, -.12794600E+00, -.10065300E-02, -.18297800E-01, 0.52512900E+00, 0.98489300E-01, -.15182000E+00, 0.58516300E-01, -.81516700E-02, -.13013800E-01, -.16630400E+00, 0.36419700E-03, 0.17818200E-01, -.59976600E-01, -.94474400E-01, 0.78022300E-02, -.10186500E+01, 0.35003600E+00, -.44008500E-01, -.38223600E-02, -.18228200E-02, -.27197000E+00, 0.34596500E+00, 0.21351600E-01, -.38837100E-01, 0.17662000E+00, 0.42174400E-01, -.15510800E+00, 0.70803000E-01, -.98889400E-02, 0.13519300E+00, 0.37394400E-02, -.17580500E-01, -.70065500E-04, -.17855400E+00, -.66569000E-01, 0.11496900E+00, 0.79032700E-01, -.14399100E+00, -.47508800E-01, -.10512800E-01, -.80029100E-01, -.21750500E-01, -.23985800E-01, 0.12135800E-01, -.33047200E-01, -.10898200E+00, -.80540200E-01, 0.65176000E-02, -.29046900E-01, 0.19963700E+00, 0.14972300E-02, 0.18508700E-01, 0.23709300E-01, 0.47667400E-01, -.14937800E-01, -.16932100E+00, 0.89637100E-02, -.41906800E+00, -.98211600E-01, 0.13676000E+00, 0.63717700E-01, 0.97502300E-01, 0.17912200E-01, -.23007300E-01, -.92041100E-01, -.93732300E-02, -.12952500E+00, 0.19420600E+00, 0.36468700E-01, 0.46852800E-01, -.63127400E-01, 0.51559500E-01, -.65336400E-01, -.13668800E+00, 0.21074200E-03, -.12478700E-01, -.11030200E-02, 0.31826100E-01, 0.27796300E-01, 0.17669500E+00, 0.17986800E-01, 0.28039400E-01, 0.55217700E+00, -.79059400E-01, 0.15735800E+00, 0.93534200E-02, 0.39465800E-01, 0.28708400E+01, -.34683700E+00, -.56277700E+01, 0.11299200E+01, -.88616700E+01, -.16588100E+02, -.56423800E+01, -.87996100E+01, -.16565700E+02, 0.74388900E+01, 0.10072000E+02, 0.82748800E+01, -.27030200E+01, -.53145900E+01, 0.53766000E+01, 0.11482100E+01, 0.11309600E+02, -.69519000E+01, 0.60699000E+01, 0.25103200E+02, -.12334900E+02, -.12953000E+02, -.12548100E+02, 0.25904000E+01, -.59668000E+00, -.94709500E+01, 0.58663200E+01, 0.68150900E+01, -.51528300E+01, -.11924900E+02, 0.39737100E+02, -.19501200E+02, -.79174900E+01, -.19876300E+02, 0.20220000E+01, 0.48511500E+01, -.23262800E+02, 0.10209100E+02, 0.13265200E+02, 0.42595600E+01, -.21059800E+02, -.41265900E+02, 0.22951100E+02, 0.33693700E+02, 0.20602000E+02, -.32784800E+01, -.11341800E+02, 0.14726800E+02, 0.23198900E+00, 0.12023000E+02, -.95620500E+01, 0.20686700E+02, 0.31797100E+02, -.15541500E+02, 0.60557900E+00, -.15908000E+02, -.17009000E+02, -.12589200E+02, 0.12560000E+02, 0.11593100E+02, -.25843600E+01, -.12338200E+02, 0.11087300E+02, 0.86646800E+01, -.37186400E+01, -.44337200E+01, -.43508400E+01, 0.74377400E+01, 0.13156900E+02, -.81257600E+01, -.12697600E+01, -.10781000E+02, 0.11788800E+02, -.93348100E+01, -.32651000E+00, 0.37242300E+00, -.53052800E+00, 0.79718200E-01, 0.52373800E+00, -.60734300E+00, -.16839400E+01, -.50219300E-01, 0.66031400E+00, -.30474800E+01, 0.28451000E+01, -.33007700E+01, -.70044800E+00, -.83740400E+00, 0.15327200E+01, -.33488700E+01, -.11065300E+01, 0.56682100E+00, -.76330100E+00, 0.17212500E+00, 0.38250000E+00, 0.17322700E+01, -.57395100E+01, -.50375800E+01, -.15923400E+01, -.25715200E+01 },
        { 0.64258600E+01, -.28512600E+00, -.22825900E+00, -.29890200E+01, 0.12724100E+01, -.21528800E+01, 0.14138900E+01, -.17577900E+01, 0.13814300E+01, -.14161000E+01, -.25352600E-01, 0.63207400E+00, 0.99586400E-01, 0.11381200E+00, 0.73660500E-01, -.27047700E+00, -.18632900E+00, 0.54578700E+00, 0.59757500E+00, -.73219900E+00, -.71750800E+00, 0.12353500E+00, 0.98540800E+01, -.93788400E-01, 0.43408700E-01, 0.27499500E-03, -.55613800E-01, -.83688800E+00, -.14365600E+01, 0.82294600E+00, -.24036700E+00, -.12643700E+01, 0.70848200E-01, -.59661900E+00, 0.25583400E+01, 0.26338800E+00, 0.25292900E-01, 0.34508700E+01, -.37569200E+00, 0.57557200E+00, -.28099900E+00, 0.44345100E+00, 0.71913900E-01, 0.63516300E+00, 0.15074800E+00, 0.12268600E+00, 0.11713900E+00, -.84844100E-02, -.26719500E+00, -.11343900E+00, 0.12372600E+01, 0.16953800E+01, 0.15963700E+00, -.11413000E+00, -.37272800E-01, 0.46031500E+00, -.16592500E-01, 0.29354200E+00, -.37108200E+00, 0.11005100E+00, 0.11588100E-01, 0.26231100E+00, 0.45282400E+00, -.19489600E+00, -.58383600E+00, 0.12754200E+00, -.10495800E+01, -.12910700E-02, -.13400600E+01, -.26243600E-02, -.72672800E-01, -.59855400E-01, -.87313900E-01, -.11749000E+00, 0.29754300E+00, 0.42448600E+00, -.49273300E-01, -.15581900E+01, 0.12912800E+00, 0.62866300E+00, -.15682000E-02, -.74241300E+00, -.54215300E+00, -.72877800E+00, -.17970600E+00, -.62534000E+01, 0.10098500E+00, -.74605100E-01, 0.30666900E+00, -.12777200E+00, -.56141400E+00, -.10647800E-01, 0.12506200E+01, 0.62609500E-01, -.28284400E+00, 0.67279700E+00, -.96840700E-01, 0.27986100E+00, 0.75959200E+00, -.25064200E+00, -.34039000E-01, 0.26223100E+00, 0.48208200E-01, 0.16614000E+00, 0.20585300E-01, 0.12381200E+00, -.10168500E+00, -.20241700E+01, 0.72496500E-02, 0.41214200E-01, 0.51532700E+00, 0.31780500E-01, 0.95259900E-01, -.80163900E-02, -.48318600E+00, 0.14951100E+00, -.12832000E+00, -.48776300E+00, -.44513300E+00, 0.54929300E+00, 0.83625600E-01, -.16929000E+00, -.44454600E-01, -.10965300E+01, -.14248000E-01, 0.92196900E+00, 0.10885300E-01, -.42420400E+00, -.57128900E+00, -.19003100E+01, -.11073900E+01, 0.96352000E-01, 0.83552100E+00, 0.51623200E-01, -.26844200E+00, -.31337600E+00, 0.79227300E-01, 0.99442400E-01, 0.43622300E+00, 0.15794100E+00, -.50489800E+00, -.56756700E-02, -.48519100E-01, -.59934500E+00, 0.48534900E-02, 0.16712600E+00, -.12780100E-01, -.71572900E+00, -.10854500E+00, 0.77185900E+00, 0.16525900E+00, -.49062300E+00, 0.87855900E+00, -.21555500E+00, -.17355100E+00, 0.41066600E-01, 0.42137300E-01, 0.33815600E-01, 0.15569300E+01, -.15617800E-01, -.58638200E+00, 0.33885300E+00, -.47535200E-01, 0.63738000E-01, -.11860500E+00, -.22944200E+00, -.20352000E-01, -.10548700E+00, 0.53894700E-01, 0.16253300E+00, 0.34139200E+00, 0.79025900E+00, 0.69155400E-01, -.16832600E+01, -.39468800E+00, -.48623000E-01, 0.80884100E-01, -.23458900E-01, -.25858500E+00, -.77078100E+00, 0.10719100E+00, 0.13161600E+01, -.19280300E+00, 0.24363800E-01, 0.38857100E-01, -.10290000E+00, -.39411600E-02, 0.23161800E+00, -.12999500E-01, -.26038100E-01, -.52371000E-02, -.17161200E-01, 0.77979900E+00, -.92361700E+00, -.45426900E+00, -.17374000E+00, -.41798600E+01, 0.52656000E+00, -.63116600E+00, -.33593300E-01, -.83936800E+00, 0.24615600E-01, 0.16235400E+02, 0.23798900E+02, -.13319300E+02, 0.45995000E+02, 0.55880100E+02, 0.27503700E+02, 0.27199900E+02, 0.14306700E+02, -.46674700E+00, -.41691900E+02, -.67520000E+01, -.18475700E+00, -.57633100E+01, -.50595800E+00, 0.35500700E+01, -.95646000E+01, -.28540700E+00, -.38280900E+02, -.14510600E+03, 0.67014700E+02, 0.28912200E+02, 0.72102600E+02, -.29173000E+02, 0.35995100E+02, 0.14931900E+02, -.44702300E+02, -.73584700E+01, 0.54584400E+02, 0.31921200E+03, -.23916600E+02, 0.12283600E+02, 0.56688600E+01, 0.12139400E+02, -.30938300E+02, -.25035400E+02, 0.60205400E+02, -.28003200E+02, -.89267100E+02, -.17163400E+02, 0.12938100E+03, 0.37416400E+03, -.18285900E+03, -.36464200E+03, -.18707500E+03, -.39002600E+02, -.35153700E+02, -.86076000E+02, 0.66504000E+02, -.36914300E+02, -.39170000E+02, -.78281300E+02, -.22732600E+03, 0.11413200E+03, -.41233100E+02, 0.11426400E+03, 0.87953100E+02, 0.57363000E+02, -.24727900E+02, -.42041600E+02, 0.51390400E+02, 0.59603300E+02, -.16055900E+02, -.55077700E+02, 0.22758300E+02, 0.84592200E+02, 0.27214500E+02, -.33024400E+02, -.60398800E+02, 0.81231700E+02, 0.49091900E+02, 0.89882500E+02, -.51866700E+02, -.71842100E+02, 0.41807800E+01, 0.12528400E+01, -.90070200E+00, -.65136700E+00, 0.17354900E+01, 0.52760500E+00, 0.49913100E+01, -.70048800E+00, -.46750800E+00, -.13068400E+02, 0.11416100E+02, 0.11031100E+02, 0.14202700E+01, 0.59492600E+00, -.72601000E+01, -.11927900E+02, 0.23016500E+01, 0.21688100E+01, -.43837400E+01, -.48718500E+02, 0.45295900E+01, -.35176100E+01, 0.14302300E+02, -.85923200E+01, 0.98422000E+01, -.16994200E+02 },
        { 0.41838900E+01, -.13507300E+00, -.18987000E+00, -.36600900E+00, 0.75994100E+00, -.20294200E+01, 0.18393200E+01, -.18676400E+01, 0.12557400E+01, -.10220700E+01, -.36786500E-01, 0.26462600E+01, 0.27101100E+00, 0.61166900E-01, 0.50511400E+00, -.39345800E+00, 0.48531000E+00, 0.68685200E+00, 0.91999100E+00, -.10647800E+01, -.14587800E+01, 0.33187600E+00, 0.89069900E+01, 0.33408300E+00, 0.35867500E+00, -.19910300E+00, 0.55816000E-01, -.84040100E-01, -.13536100E+01, -.67705600E+00, -.73385100E+00, -.24111200E+01, 0.12627300E+00, -.12148400E+01, 0.34071300E+01, 0.65407000E+00, 0.35560800E-01, 0.28770400E+01, 0.97328600E-01, 0.25720200E+00, -.10448400E+01, 0.45134900E+00, -.10090200E+01, 0.31467800E+00, 0.14217600E+00, 0.28074800E+00, -.34504900E-01, -.22313500E-01, 0.78192100E+00, -.20391800E+00, 0.15126200E+01, -.34833800E+01, -.38805600E-01, 0.19190300E+00, -.40054400E+00, 0.39969400E+00, -.16830300E+00, 0.34885800E+00, -.36207700E+00, 0.22394400E+00, 0.10802500E+00, -.44161800E+00, 0.95107400E+00, -.50534000E+00, -.95424800E+00, 0.45752000E-01, -.14604100E+01, -.11395100E-01, -.16255100E+01, 0.20157600E-03, 0.33085500E-01, 0.29289600E+00, 0.53201100E-01, -.28246100E+00, 0.15979700E+00, 0.14142400E+00, 0.87419100E+00, 0.52065400E+01, -.72926600E+00, -.53406000E-01, -.24266700E-01, 0.15399500E+01, -.24231400E+01, 0.92148700E-01, -.11249000E+01, -.62073000E+01, 0.22168200E+00, 0.20266000E+00, 0.80790400E+00, 0.10333900E+01, 0.89662300E+00, -.26180500E-01, -.98165700E+00, 0.30156600E+00, -.22617700E-01, 0.23650700E+00, -.17213400E+00, 0.77158900E+00, -.22790200E+00, 0.11519500E+00, -.52038300E-02, 0.57013400E+00, -.26740200E+00, 0.43510300E+00, 0.55224300E-01, -.18763500E+00, -.89363600E-01, -.47899700E+00, 0.43609000E+00, -.11017000E+00, 0.18347300E+01, -.15954900E+00, 0.13466700E+00, -.24120800E-01, -.51952400E+00, -.36106400E+00, 0.45918200E-01, -.86512800E+01, -.19916900E+00, -.33348300E+00, 0.14100100E+00, -.41952200E-01, 0.22061800E-01, -.42927000E+00, -.45497500E-02, 0.72826000E+00, 0.17659300E+00, -.78812800E-02, -.16748800E+00, -.94956700E+00, 0.56768800E+00, 0.55125300E+00, -.28962000E-01, 0.30497600E-01, 0.17795600E+01, -.52502100E+00, -.74289000E-01, 0.11979300E+00, 0.73395100E+00, -.48646400E+00, 0.24462600E+00, 0.23489400E+00, 0.70962700E-01, 0.10201500E+00, 0.15433000E-01, -.21283400E+00, -.17241100E-01, 0.69569800E-01, 0.16281100E+00, -.28166200E+00, -.35216300E-01, 0.38745000E+00, -.36500900E+00, 0.97638000E-01, 0.84483800E-01, -.16066200E+00, -.12718000E+00, 0.12168300E-01, -.16756700E+01, 0.46247800E+00, 0.77809700E+00, -.48959900E+00, 0.16838800E+00, 0.44101900E-01, 0.14993100E+00, -.20138800E+00, 0.40264200E-01, 0.22956300E+00, -.13176200E+00, 0.60786900E-01, 0.54824700E+00, -.18316200E+01, -.55269400E+00, -.12821200E+00, -.21967000E+00, -.13509100E+00, 0.14279200E+00, -.22270900E-01, -.12336900E+00, -.14474100E+00, -.31861700E-01, 0.12508500E+01, -.13401500E+00, 0.69884100E-01, 0.21681800E+00, -.15485800E+01, -.23974700E-01, 0.11081900E+00, 0.21869300E-01, -.20216600E-01, 0.44859400E-02, 0.32561700E-01, -.96513500E-01, -.32530300E+00, -.12140400E+00, 0.19951800E+00, -.39046600E+00, -.34279000E+00, 0.16062000E+00, -.58324300E-01, 0.53295800E-01, 0.15775900E-01, -.31058200E+00, 0.23795000E+02, -.73986800E+01, 0.54872700E+02, 0.68960100E+02, 0.18738100E+02, 0.50663900E+01, 0.10908800E+03, -.51673600E+02, -.81951300E+02, -.54263800E+02, -.58197400E+01, 0.21081900E+02, -.25167200E+02, 0.16037100E+02, -.37497600E+02, 0.25235500E+02, 0.20558200E+02, -.68270100E+02, 0.32154300E+02, 0.35044300E+02, 0.33828500E+02, 0.11807900E+02, 0.35409300E+02, -.16882900E+02, 0.15689800E+02, 0.30496800E+02, 0.37595500E+02, 0.16794600E+03, -.19621500E+03, 0.97567600E+02, -.17263000E+02, 0.98233400E+02, 0.26487200E+02, 0.21551900E+02, 0.73726600E+02, -.99139800E+01, 0.31852000E+02, 0.15026200E+02, 0.14582800E+03, 0.15612800E+03, -.88029700E+02, -.21474900E+03, -.78127500E+02, 0.14113100E+02, 0.45249500E+02, -.65188000E+02, -.51649500E+02, -.77251800E+02, 0.40874500E+02, -.77330900E+02, -.12808900E+03, 0.62669200E+02, 0.16848200E+03, 0.64473300E+02, 0.34388600E+02, 0.38528700E+02, -.33543400E+02, -.13537300E+02, 0.31295000E+02, 0.34379600E+02, 0.52972600E+01, -.24001700E+02, 0.87698500E+01, 0.66336900E+02, 0.11672900E+02, -.27190300E+02, -.40994700E+02, 0.31043400E+02, 0.37168900E+02, 0.62197600E+02, -.35437800E+02, 0.76364600E+02, 0.11470400E+01, -.47877400E+01, 0.35937900E+01, -.64526900E+00, -.25986900E+01, 0.35205400E+01, 0.11707000E+02, 0.77301100E+00, -.41280900E+01, 0.14555200E+02, -.12746800E+02, 0.22064100E+02, 0.83122200E+01, 0.21421900E+01, -.17277600E+02, 0.15762600E+02, 0.50527900E+01, 0.17763700E-01, 0.35598300E+01, 0.88905300E+01, -.39170100E+01, -.94998800E+01, 0.26063500E+02, 0.23200200E+02, 0.71187900E+01, 0.10864100E+02 },
        { 0.34310800E+02, -.46746200E+00, -.13040200E+01, -.18791500E+01, 0.35174400E+01, -.24844400E+01, -.15205800E+01, 0.71588200E+00, 0.90403400E+00, -.18866200E+01, 0.95845400E-01, -.30522100E+01, -.17273600E+00, -.14234000E-01, 0.70129500E-01, 0.30676800E+00, -.11557000E+01, -.12438800E+00, 0.10432300E+00, -.17454200E+01, -.12052500E+01, -.87595500E-01, -.12582500E+02, -.86554400E+00, -.43138400E+00, 0.43300500E-01, 0.42918100E+00, -.21642400E+01, -.19671400E+01, 0.72892000E+00, -.64799200E+00, -.39964500E+01, 0.54025700E-01, 0.17522600E-01, 0.67769400E+00, 0.10928500E+00, 0.15204500E+00, 0.47354600E+01, -.88313400E+00, 0.12311300E+01, -.18916500E+00, 0.51023300E+00, -.61133600E+00, 0.20003700E+01, -.23070400E+00, -.12444300E+00, -.87900900E+00, -.19682900E-01, 0.12234000E+01, -.12645700E+00, 0.15217300E+01, -.74027100E+00, -.33951800E+00, -.91217600E+00, 0.10746400E+01, 0.23013100E+01, 0.80831900E-01, -.13461300E+01, 0.10361600E+00, 0.14496500E+00, 0.12175500E+01, 0.34487900E+00, -.13487200E+01, -.24823700E+00, 0.66694800E+00, -.18702200E+00, 0.33940400E+00, 0.31552100E-02, -.24303500E+01, 0.96235400E-03, 0.18244500E+00, -.65611800E-01, -.27611600E+00, -.43292200E+00, 0.23212700E+01, 0.59698000E+00, -.48974400E+00, -.55875800E+01, 0.14459500E+01, -.24122500E+01, -.14182600E+00, 0.14247800E+01, -.12199600E+01, 0.16528200E+01, -.34654400E+01, -.21687300E+02, -.15665300E+01, -.74923300E+00, 0.54452500E+00, -.40668900E+01, 0.59389400E+00, -.65138800E-01, -.30472600E+01, 0.61924700E+00, -.84652900E-01, 0.12070300E+01, -.41213500E+00, 0.49371300E+00, -.22125300E+01, -.47512000E+00, -.27317200E+00, 0.23277800E+01, -.15354100E+00, 0.11830800E+01, -.17503500E+00, 0.40216900E+00, -.23298900E+00, -.10775900E+02, 0.31254200E+00, -.14675400E+00, -.17242300E+01, -.28432300E+00, -.39201800E-01, -.13537500E-01, -.68404400E+00, -.66133000E+00, -.29829300E+00, 0.67572100E+01, -.60591800E+00, -.97425600E+00, 0.35069200E+00, 0.10478500E+00, -.60341300E-01, -.67230600E+00, 0.27029400E+00, 0.23280100E+01, 0.57280700E+00, 0.25293200E+01, -.91767600E+00, 0.29235900E+01, -.18335200E+02, 0.50269800E+00, 0.17130100E+01, -.13991100E-01, -.46111800E+01, -.54629000E+00, 0.22560100E+00, 0.72121800E+00, 0.83307100E+00, -.13272500E+01, -.20251000E+01, 0.18115800E+00, 0.75277200E-01, -.16314200E+01, -.11978400E+00, -.65048000E+00, -.40637900E-01, -.81786700E+00, 0.13002900E+00, 0.25959800E+01, 0.29186700E-02, 0.21214600E+01, -.41437800E+01, -.66007800E+00, 0.37788300E-01, -.43039400E+00, 0.46164700E+00, -.10075300E+00, 0.70033700E+00, 0.86067200E+00, -.93155200E+00, 0.76537800E+00, 0.33737900E+00, -.34614700E+00, 0.16324200E+00, 0.22001500E+00, 0.44174400E+00, 0.73765200E-02, -.70236300E+00, -.96529900E-01, 0.15715100E+01, 0.23585800E+01, -.19529300E+01, -.37368200E+00, -.97239200E+00, -.12499000E+01, 0.56919800E-03, 0.16886200E+00, 0.16543500E+01, 0.28716900E+01, -.35169100E+00, -.59483600E+01, 0.39866400E-01, 0.20932600E+00, -.73189800E+00, 0.12167500E+01, 0.10725400E+01, -.28652000E+00, 0.66015500E-01, 0.36956500E+00, 0.54963500E-02, 0.52523800E+00, 0.41959300E+01, 0.22753900E+01, 0.24438300E+01, 0.74402900E+00, 0.77033300E+01, -.74271200E+00, 0.51697800E+00, 0.25117900E-02, -.18030200E+01, -.33302100E-02, -.67790300E+00, 0.87999500E+00, 0.70799200E+02, -.88376600E+01, -.53317400E+00, -.37936300E+02, -.11349700E+03, -.82625200E+01, -.21242800E+01, -.10920000E+03, 0.40321600E+01, 0.74921700E+02, -.20984000E+02, -.16395200E+02, 0.18232000E+02, 0.30831000E+02, -.89094200E+01, 0.62182100E+02, -.38585000E+03, 0.19682600E+03, -.65414600E+01, 0.19312000E+03, 0.11150300E+03, 0.71901800E+02, 0.35374500E+02, -.10014000E+03, 0.26526400E+03, 0.55901400E+02, 0.11374500E+03, -.27776700E+03, 0.14018200E+03, 0.15186200E+03, 0.13888600E+03, 0.10744400E+03, 0.72759700E+02, -.47181600E+02, -.69354900E+02, 0.32973000E+03, 0.79920900E+02, -.21301400E+02, 0.13855300E+03, -.41087100E+02, -.15925700E+02, -.69118900E+02, -.73278800E+02, -.14025000E+03, 0.29477400E+02, 0.16787100E+03, 0.68552300E+02, -.98764800E+02, -.37699300E+02, 0.72100900E+02, -.30312800E+02, 0.15108900E+01, -.36203900E+02, -.76652100E+02, -.11582800E+02, -.15009500E+02, 0.32797100E+02, 0.33878600E+02, -.36346700E+02, 0.39186400E+03, -.20625500E+03, 0.11094800E+03, 0.98245800E+02, 0.10315600E+03, 0.81508700E+02, 0.14321100E+03, 0.56058200E+01, -.39715600E+02, 0.27121400E+02, 0.12477200E+03, -.51728700E+02, -.65259300E+01, 0.25956400E+01, -.34938300E+00, -.97305500E+00, -.96685200E+01, 0.98254000E+01, -.40924000E+02, -.34128600E+01, -.17076200E+01, -.31854000E+02, 0.36879000E+02, -.51205100E+02, 0.69036400E+00, 0.24068800E+02, 0.43515800E+02, -.39568900E+02, 0.18763100E+01, -.82016600E+01, 0.33045800E+01, 0.11501400E+02, -.95529100E+01, 0.53196200E+02, -.71848400E+02, -.39386200E+02, -.74745900E+01, -.38762800E+02 },
        { -.15374500E+02, 0.19111100E+00, 0.50466000E+00, 0.53978000E+00, -.17043600E+01, 0.19599900E+01, 0.99583700E+00, 0.68113300E+00, -.23521400E+01, 0.12901000E+01, 0.95002500E+00, -.35609300E+01, -.23378000E+00, 0.15957600E+00, -.38536700E+00, 0.50256700E+00, -.49806200E+00, 0.37076800E+00, -.61757400E+00, 0.12926800E+01, 0.17402400E+01, 0.73463300E+00, 0.52799700E+00, 0.19509400E+00, -.13932900E+00, 0.15496100E+00, -.17317200E+00, 0.14153000E+01, 0.19002200E+01, 0.32813400E+00, 0.60601600E+00, -.15186400E+00, -.18793900E+00, 0.12930200E+01, -.28703600E+00, -.54574900E+00, 0.11138500E+00, -.18103300E+01, 0.57495600E+00, -.12504300E+01, 0.50878000E+00, 0.83330600E+00, -.14309600E+00, -.86275900E+00, 0.19058900E+00, 0.10613500E+00, -.20975300E+00, -.30521100E-02, -.62028900E+00, 0.91117900E-02, -.89200100E+00, 0.17329700E+01, -.40532900E-01, -.17504800E+00, -.38212600E+01, -.19377700E+00, -.22965700E-01, 0.89788700E+00, -.83127200E-01, -.19567700E+00, -.31075800E+00, 0.75833900E-01, 0.32296300E+00, 0.16194000E-01, -.27585900E+00, 0.25807100E+00, 0.46355800E+00, 0.13727500E-01, 0.73144900E+00, 0.38249900E-02, 0.51579900E-01, -.71722600E-02, -.45320400E-01, 0.14505400E+00, -.26589300E+00, -.31969400E+00, -.44387700E+00, -.75035300E-02, -.64429800E+00, -.13361000E-01, 0.14588900E-01, -.11736300E+01, 0.10071400E+01, 0.62976000E+00, -.17791700E+00, -.13307200E+01, 0.33714300E+00, -.23635400E+00, 0.11256700E+01, 0.49453600E+00, 0.28071400E-01, 0.94759900E-01, 0.61382600E+00, 0.79526000E-01, 0.10035800E+00, -.13912400E+00, -.34313100E+00, -.86388700E+00, 0.76010700E+00, -.92697500E+00, 0.14598700E+00, 0.63236900E+00, 0.20854600E+00, -.83067000E+00, -.10354700E+00, 0.25266900E+00, 0.46209100E-01, 0.62309900E+01, -.25777100E+00, 0.22219600E+00, -.28187300E+01, 0.12313800E+00, -.67506600E+00, -.53675300E-02, 0.17876800E+01, -.83069600E+00, -.56674600E-01, -.45108400E+01, -.61507200E+00, 0.36061700E+00, 0.70192100E+00, -.30477600E-01, 0.20716700E-01, -.99779400E-01, -.25421900E-01, 0.79765000E+00, -.83500500E-01, -.10979300E+01, 0.15878000E+00, -.34059600E+00, 0.45507800E+01, -.75218800E-01, 0.38713800E+00, 0.14442500E+00, 0.34719900E+01, -.14101600E+01, 0.68406300E-01, 0.19938800E+00, 0.20430100E+00, 0.11174000E+01, -.26662000E+00, 0.21292100E-01, -.50042200E-02, -.11138300E+01, 0.12113300E-01, 0.28764000E+00, 0.16537400E-02, -.18903000E+01, 0.75669700E-01, -.34471500E+00, 0.20328600E-03, -.11344000E+01, 0.18909800E+01, -.16432100E+00, -.17976600E+00, 0.15927600E-01, 0.17107300E+00, 0.85296800E-02, 0.18377900E+01, 0.47511600E-01, -.10066800E+01, 0.29026400E+00, 0.12316400E+00, -.10346400E+01, 0.25915100E-02, 0.28474600E+00, 0.44072500E-01, 0.23914300E+00, -.12564500E+00, 0.19906900E+00, 0.11186900E+01, 0.32736300E+01, -.39982700E+00, -.12668500E+01, -.17385000E+00, -.22543200E+00, -.47192500E-01, -.24984600E-01, -.10506400E+00, -.95553100E+00, 0.45165500E+00, 0.93575300E+00, -.49666700E+00, -.26938500E+00, 0.17660500E+00, -.17326500E+00, 0.49184500E+00, 0.48572100E+00, -.47551700E-01, -.61743500E-01, 0.46338700E-03, 0.64475900E-01, 0.92608300E+00, 0.24248800E+00, 0.63690800E+00, 0.11338900E+00, 0.14033400E+01, -.18167600E+01, -.35626500E+00, -.39267100E-01, -.59124500E+00, -.17990700E-01, -.59765900E+00, -.31383100E+00, 0.41414700E+00, 0.13971200E+03, 0.14887500E+03, 0.23698900E+02, 0.54433700E+02, 0.13338000E+03, -.57303800E+02, -.10634300E+03, -.66543000E+02, -.30081900E+02, -.12895000E+02, -.12304000E+02, 0.39749200E+02, -.39931700E+02, -.12491200E+01, -.31115700E+01, 0.19794000E+03, -.10716000E+03, -.61146000E+02, -.99136300E+02, -.63868100E+02, -.15048700E+02, -.15241300E+02, 0.96004600E+02, -.10335400E+03, 0.12401700E+02, 0.51728600E+02, -.11619300E+03, 0.57959200E+02, 0.17855200E+02, 0.58165900E+02, -.45673700E+02, -.27885900E+02, 0.12350800E+03, -.32683600E+02, -.20247700E+03, -.25054400E+02, 0.15382400E+03, 0.70329900E+03, -.36906400E+03, -.58013900E+03, -.35154700E+03, -.11268700E+02, 0.71627400E+02, -.20176700E+03, 0.54338400E+01, -.20462900E+03, 0.43547800E+02, -.29463100E+03, -.34286200E+03, 0.17062200E+03, -.12173600E+02, 0.17164900E+03, 0.12534100E+03, 0.67974500E+02, 0.12080500E+02, -.79257600E+01, 0.67499100E+02, 0.68822600E+02, -.15185800E+03, -.11487000E+03, 0.51400500E+02, 0.75977400E+02, 0.57208300E+02, -.79729100E+02, -.14671400E+03, 0.10800000E+03, 0.95928800E+02, 0.24462900E+03, -.12015700E+03, 0.56932300E+02, 0.75248800E+01, -.40318600E+01, 0.49969300E+01, -.11223700E+01, 0.19835800E+01, 0.24775100E+01, 0.36960100E+02, 0.10801500E+01, -.64661700E+01, 0.35910200E+01, -.16341200E+01, 0.51067500E+02, 0.94838800E+01, -.30993000E+01, -.43161800E+02, 0.57428300E+01, 0.49325300E+01, 0.50999200E+01, -.42282600E+01, -.77992400E+02, 0.23064600E+01, -.35700600E+02, 0.68073300E+02, 0.25685600E+02, 0.24270800E+02, -.81949100E+01 },
        { 0.40569200E+02, -.19801700E+01, -.76547100E+00, -.83871700E+00, 0.20938300E+01, -.57060200E+01, 0.30236200E+01, -.41912900E+01, 0.43330600E+01, -.40057000E+01, -.89435700E-01, 0.42619600E+01, -.38719100E+01, -.18100700E+00, -.12273700E+01, -.49655500E+00, 0.16140300E+00, -.77847500E+00, 0.24110300E+01, 0.10806600E+01, 0.53075700E-01, 0.14098200E+01, -.20467300E+02, -.38846600E+01, 0.13883800E+00, -.10872000E+00, -.37876700E+00, -.11352000E+01, -.19057000E+01, 0.27543000E+01, 0.67903200E+00, 0.28494000E+00, 0.30098800E-01, -.21654500E+01, 0.13008300E+02, 0.34730300E+00, 0.36821800E+00, 0.69262500E+01, -.44400000E+00, 0.28344300E+00, -.81051000E+00, 0.67150400E+00, 0.43675700E+00, 0.13361100E+01, -.66860900E+00, 0.92977300E+00, 0.31566900E+00, -.64039500E-01, -.43616200E-01, -.38935700E+00, -.10881800E+01, 0.79979700E+01, -.51561200E+00, -.10964700E+01, 0.24303300E+01, -.23384500E+00, -.49852200E+00, 0.71146000E+00, -.19513400E+01, 0.42693800E+00, 0.30297300E+00, 0.12081000E+01, -.65622200E+00, 0.19062300E+00, -.80645200E+00, -.32034000E-01, -.34634700E+01, 0.20815700E+00, -.82043900E+00, -.23504900E-01, 0.10149500E+00, -.10912700E+01, 0.14924700E+00, -.30517200E+00, 0.92791100E+00, -.10705000E+01, -.37930200E+00, -.17281800E+02, -.27943400E+01, 0.18333200E+01, 0.47837600E-01, -.12548600E+01, -.21970800E+01, 0.31096400E+00, -.12021000E+01, -.27544500E+02, 0.13619400E+01, 0.10320100E+00, 0.35935200E+01, 0.32097000E+01, -.36821000E+00, 0.23157800E-01, 0.49438800E+01, 0.21379400E+01, 0.21254000E+00, 0.13660900E+01, 0.20579200E+00, -.18748600E+00, -.30688400E+01, 0.39868600E+00, 0.42611200E+00, 0.64781500E+00, -.14690200E+00, 0.29280600E+00, 0.33571700E+00, 0.10410100E+01, 0.18661600E-01, 0.64220900E+01, -.18718200E+00, 0.13698100E+00, -.38661400E+01, 0.49007700E-01, -.85255200E+00, 0.86659500E-03, 0.55222600E-01, 0.13509000E+01, -.14572800E+00, -.49322700E+01, -.28333400E+00, -.53322200E+01, 0.54981500E+00, -.42138800E+00, 0.78254700E-01, -.16433400E+01, -.27595200E-01, 0.18294800E+01, -.16731300E+00, -.29215000E+01, -.50784300E+00, 0.46175000E+00, -.21972900E+01, 0.40900100E+00, 0.11584400E+01, 0.25355200E+00, -.78744200E+01, -.19024000E+00, 0.34988400E+00, 0.80879900E+00, 0.12475600E+01, -.12938900E+01, -.79684900E+00, -.20567600E+00, 0.66462800E-02, -.32408000E+00, -.58745500E+00, 0.36066400E+00, 0.11150400E+00, -.17795200E+00, -.11703900E+01, -.35121000E+01, 0.11724500E+00, -.14123000E+01, 0.11924900E+01, -.65570100E+00, -.17077100E+00, -.15801200E+00, 0.27366500E-01, 0.47480600E-01, 0.23622500E+01, 0.68342900E+00, -.23664900E+01, 0.83429300E+00, 0.42366200E+00, -.72578200E+00, 0.23512400E+00, -.10759400E+01, -.99320200E+00, -.23869200E+01, 0.68008300E+00, 0.12846000E+01, -.13404500E+01, 0.14739900E+02, 0.21043000E+01, 0.26605600E+01, -.12581900E+01, 0.45297100E+00, -.60280000E+00, -.60742800E+00, 0.37248200E+00, 0.33004400E+00, -.13158900E+00, -.13822800E+01, 0.95576900E-01, 0.17787600E+01, 0.21778400E-01, 0.24632200E+01, -.77017000E+00, -.50745300E+00, -.75874900E+00, -.98548400E-01, -.18560600E-02, -.95323900E-01, 0.41509600E-01, -.75994800E+00, -.26892400E+01, 0.46941700E-01, -.13176500E+01, 0.82367500E-01, 0.49427000E+00, 0.97240200E+00, 0.60670100E+01, -.62395600E-02, 0.97053400E+00, 0.28292500E+01, -.73034400E+00, -.29630700E+01, -.96624700E+02, 0.63047100E+02, 0.20043100E+03, -.83156000E+02, 0.52457200E+02, -.82187600E+01, 0.40672500E+02, 0.35517100E+01, -.10611100E+03, 0.39013700E+02, 0.18952000E+02, 0.11320400E+03, -.12014600E+03, -.71338000E+02, 0.10181900E+04, -.54122300E+03, -.34294000E+03, -.50825900E+03, -.65353600E+02, -.24969300E+03, -.27597500E+02, 0.26949700E+03, -.29260500E+03, -.20292500E+03, -.79824200E+03, 0.10987100E+04, -.52529400E+03, -.29075100E+03, -.54982700E+03, -.20817500E+03, -.29223200E+03, -.60450400E+02, 0.74691700E+02, -.62355500E+03, -.23999100E+03, -.66736400E+03, 0.49708900E+03, -.23768800E+03, -.49937800E+03, -.24837700E+03, -.38257300E+02, -.18790700E+02, 0.16886700E+02, 0.26479300E+03, -.13848700E+03, -.51613300E+02, 0.38004600E+02, -.74941600E+03, 0.40746300E+03, 0.33368400E+03, 0.37329000E+03, 0.17622000E+03, 0.91125500E+02, 0.27078200E+03, 0.52976200E+02, 0.18538700E+03, 0.78978700E+02, -.10847700E+03, 0.15573100E+03, -.70756600E+02, 0.36838300E+02, -.76963900E+02, 0.25173700E+02, 0.10421100E+03, -.30986600E+03, -.28277200E+03, -.31592600E+03, 0.99066400E+02, -.15015200E+03, 0.14656200E+02, 0.74011900E+01, -.96435900E+01, -.46771200E+00, 0.15359200E+02, -.87379000E+01, 0.14003000E+02, -.24293700E+00, 0.91948400E+01, -.51726700E+02, 0.34873000E+02, 0.12025100E+02, -.56511300E+01, -.77635700E+01, -.49254400E+01, -.42033200E+02, -.16878900E+02, 0.22629900E+02, -.19292800E+02, -.90644200E+02, 0.15453700E+02, -.15751500E+02, 0.17501900E+02, -.88315100E+02, 0.22581900E+02, -.34936500E+02 },
        { 0.47056500E+01, -.19577000E+00, -.14049200E+00, -.12681600E+01, 0.89891500E+00, -.15663500E+01, 0.13263400E+01, -.15802000E+01, 0.14472100E+01, -.10089000E+01, -.43423600E-01, 0.18539700E+01, 0.13990300E+00, 0.74232500E-01, 0.16823800E+00, -.17522300E+00, 0.10339700E+01, 0.77779500E+00, 0.89682700E+00, -.81974900E+00, -.56252100E+00, 0.43239500E-01, 0.13115000E+02, 0.10274000E+00, 0.13545300E+00, -.19335700E+00, 0.21823400E+00, -.11825400E+01, -.17448300E+01, 0.40872100E+00, -.76065900E+00, -.15224800E+01, 0.92794100E-01, -.86423600E+00, 0.21007700E+01, 0.39606600E+00, -.34928400E-02, 0.27912600E+01, -.35190700E+00, 0.69386000E+00, -.48717900E+00, -.17253700E+00, 0.14153200E-01, 0.86022400E+00, -.33682800E+00, 0.18859300E+00, -.81754100E-01, -.96620500E-02, 0.59907200E+00, -.11215600E+00, 0.10022600E+01, 0.73071300E+00, -.90508100E-02, 0.30550300E-01, 0.11516200E+01, 0.43449700E+00, -.39722200E-01, -.29858000E+00, -.21302600E+00, 0.15011700E+00, 0.24881800E+00, 0.17039200E-01, 0.10131200E+00, -.19410700E+00, -.26121700E+00, -.16949000E+00, -.42721300E+00, 0.99812800E-03, -.10163400E+01, -.13196800E-02, 0.41967300E-01, 0.14548800E-01, -.14690000E-01, -.18877300E+00, 0.23358200E+00, 0.12034600E+00, 0.19123900E+00, 0.19859900E+01, -.48132100E+00, -.75939500E+00, -.50349700E-01, 0.13877200E+01, -.91505600E+00, 0.59719000E+00, -.10442900E+01, -.10593200E+02, -.54212900E-01, -.42649600E-01, 0.61288000E+00, -.34375600E-01, 0.42580300E+00, -.39699900E-01, -.88923600E+00, 0.39956400E+00, -.60226100E-01, 0.67283900E+00, -.16891400E+00, 0.19506700E+00, -.90706100E+00, -.12865900E+00, -.14952500E-01, 0.72022500E+00, -.10572500E+00, 0.30399200E-01, -.12991500E-01, 0.62200700E-01, -.51084000E-01, -.13558200E+01, 0.24690700E-01, -.53594700E-01, 0.76002100E-01, -.13681500E+00, -.11103500E+00, -.66383600E-02, -.39890300E+00, -.16662500E+00, -.72323000E-01, -.10940400E+01, -.16265300E+00, 0.27350400E+00, 0.16135000E+00, 0.98698500E-02, 0.31780100E-02, -.38471000E+00, 0.51978200E-02, 0.27402000E+00, 0.10213000E+00, 0.57585800E+00, -.10846300E+00, -.67741200E+00, 0.12674300E+00, 0.86267700E-01, -.26202600E+00, -.30336100E-01, -.67312600E+00, 0.25867100E+00, 0.29745100E-01, 0.77933900E-01, 0.93972200E+00, -.65346800E+00, -.43233900E-02, 0.44532200E+00, 0.33588600E-01, -.76023300E-01, -.34192700E-01, -.23344000E+00, -.11930200E-01, 0.25581400E+00, 0.13287100E+00, 0.58844200E+00, -.66635400E-01, 0.55584200E+00, -.83064100E+00, -.10103600E+00, -.10027300E+00, -.89265800E-01, 0.31579800E-01, -.17466500E-02, 0.26439000E+00, 0.24749400E+00, -.17759700E+00, -.93080000E-01, 0.12363800E+00, 0.81762200E-01, 0.99793500E-01, -.54682900E-01, 0.30173800E-01, 0.12655700E+00, -.11293500E+00, -.13224800E+00, 0.37986100E+00, 0.74335500E-01, -.19444200E+00, -.17667300E+01, 0.23747400E+00, 0.22290700E+00, 0.13261900E+00, -.50814900E-01, -.22996000E+00, -.45675300E+00, -.10069300E+01, 0.37367500E+01, -.14030200E+00, 0.57644100E+00, 0.14429700E+00, 0.62496200E+00, 0.47214300E+00, 0.49621400E-01, 0.46756300E-01, 0.89588400E-01, -.24756500E-02, 0.10946400E+00, 0.84375100E+00, 0.37430600E+00, 0.31145500E+00, 0.29720200E+00, 0.83032700E+00, -.60501600E+00, -.14900600E-01, -.66288900E-01, -.59727300E+00, 0.14087100E-02, -.37763400E+00, 0.57469300E+00, -.11417300E+00, -.33325200E-01, -.16950900E+00, 0.15818200E+02, 0.19126400E+02, 0.39533100E+02, -.17900000E+02, -.40070700E+02, -.19935900E+02, -.18006700E+02, -.20298600E+02, -.15965800E+02, 0.58208500E+01, 0.10634100E+02, -.29947700E+02, -.11896300E+02, 0.21248500E+03, -.11307100E+03, -.75451100E+02, -.10608400E+03, -.41401500E+01, -.44310600E+02, -.15583600E+02, 0.74864200E+02, -.40723600E+02, -.40185700E+02, -.75839100E+02, 0.29976600E+03, -.14552700E+03, -.37414500E+02, -.14996300E+03, -.55232400E+02, -.74990700E+02, -.22394300E+02, 0.31292100E+02, -.15366800E+03, -.57932200E+02, -.15143800E+03, 0.12611400E+03, -.55639300E+02, -.22169600E+03, -.63008800E+02, -.34096900E+02, -.71023700E+02, 0.18304100E+02, 0.74372400E+02, 0.82120900E+01, -.60981200E+02, -.48044700E+02, -.14903200E+03, 0.80242200E+02, 0.23504400E+02, 0.74230600E+02, -.21917800E+02, 0.97944500E+01, 0.69116800E+02, 0.10233700E+02, 0.52829700E+02, -.17621200E+01, -.11519700E+01, -.10387900E+02, 0.67146700E+01, 0.82276000E+02, 0.53726400E+01, 0.32219800E+02, 0.79855600E+02, -.89631900E+02, -.69682700E+02, -.42250000E+02, 0.69907500E+02, 0.45651400E+01, 0.35122100E+01, 0.19327200E+01, -.99510600E+00, 0.67665600E-01, 0.35546700E+01, -.17539800E+01, 0.40299700E+00, -.29671300E-01, 0.12586600E+01, -.17184700E+02, 0.15106400E+02, -.16510400E+00, -.18555900E+01, -.25465700E+01, 0.94699400E+00, -.15761600E+02, -.32734000E+01, 0.63575300E+01, -.44812100E+01, -.25000700E+02, 0.17694600E+01, -.63401300E+00, 0.32364000E+00, -.24679600E+02, -.59232400E+01, -.20344200E+02 },
        { 0.56381900E+01, -.20874700E+00, -.20779100E+00, -.35522600E+00, 0.86463300E+00, -.17087500E+01, 0.15678600E+01, -.12960300E+01, 0.13468100E+00, -.10669500E+01, 0.15780600E+00, 0.12855000E+01, -.18840100E+00, 0.32352300E-01, -.11009400E+01, -.41845800E+00, 0.27099800E+00, -.17344400E+00, 0.23683300E+00, -.58786800E+00, -.62439400E+00, 0.17827000E+00, -.29168400E+01, -.27957100E+00, 0.11391600E+00, 0.47115800E-01, 0.30578200E-01, -.31280100E+00, -.95475000E+00, -.74708100E-02, -.67392700E+00, -.20594900E+01, 0.92680300E-02, -.23107200E+00, 0.42476300E+01, 0.10709300E+00, 0.25585100E+00, 0.15979400E+01, -.17646000E+00, 0.51220300E+00, -.39645500E+00, 0.16131800E+00, -.22762300E+00, 0.59086600E+00, -.13800000E+00, 0.14087000E+00, -.23240800E+00, -.42731700E-01, 0.19350200E+00, -.10066500E+00, 0.30691000E+00, 0.41514800E+01, -.16765500E+00, -.24941300E+00, -.18439700E+01, 0.48932600E+00, 0.61455200E-01, 0.57805900E+00, -.89660500E+00, 0.80496400E-01, 0.22464400E-01, 0.14225800E+00, -.75855800E-01, -.43861100E-01, -.98061100E-01, -.19033200E+00, -.30403500E+00, 0.11650400E-01, -.38145100E+00, -.25434400E-02, 0.16221100E+00, -.28542000E+00, -.18158600E+00, -.50325800E-01, 0.59386200E+00, 0.30747000E+00, -.26079300E-01, 0.19777900E+01, 0.11039000E+00, -.83557300E+00, -.48981700E-01, 0.37202400E+00, -.43062600E+00, 0.35416000E+00, -.15000800E+01, -.40799900E+01, -.30856000E+00, -.78347700E-01, 0.65760700E+00, -.47262100E+00, 0.20431900E+00, -.12748500E-01, -.12155600E+01, 0.20278500E+00, -.16096700E+00, -.31582700E+00, -.15764800E+00, 0.35434700E+00, -.34955800E+00, 0.29140900E+00, -.18802800E-01, 0.16060200E+00, -.83783600E-01, -.13941400E+00, -.80256000E-03, 0.22932200E+00, 0.63899700E-01, -.13961600E+01, 0.12867200E-01, 0.21636200E-01, -.76256500E-02, 0.71785100E-02, -.16855600E+00, 0.20837900E-02, -.18495700E+00, -.69108200E+00, 0.87728500E-01, -.74222100E+00, 0.15330500E+00, 0.72768800E+00, -.26023500E+00, -.73424800E-01, 0.96790300E-02, 0.16567200E+00, 0.26061800E-01, 0.15272100E-01, 0.15637400E+00, 0.27454200E+00, -.18922600E+00, 0.41096400E+00, 0.90705500E+00, 0.11300800E+00, -.26303200E+00, 0.26486600E-03, 0.18787100E+01, -.10314200E+00, -.36516900E-01, -.17334300E-01, 0.17284900E+00, -.55737900E+00, 0.28382400E+00, 0.33378700E+00, -.53568300E-01, 0.16688300E-01, 0.42020300E-02, -.75702200E-01, -.37216400E-01, 0.10063100E+01, 0.19968800E+00, -.24406500E+00, -.13267800E+00, -.32462000E-01, 0.11126000E+01, 0.14311800E-01, 0.24786100E-01, 0.12646100E+00, 0.41515500E-02, 0.20072700E-01, 0.34777000E+00, -.28683600E+00, -.94687900E-01, 0.15009300E+00, 0.90104300E-01, 0.38775700E+00, -.11750400E-01, 0.55307200E-01, -.19955500E-01, -.19379600E+00, -.11056200E+00, 0.53983700E-01, 0.64529000E-01, -.38121600E+00, 0.54664800E-01, -.69931500E+00, -.14536900E+00, 0.77838000E-01, 0.52174900E-01, -.46184300E-02, -.28736700E+00, 0.18330700E+00, 0.37624800E+00, -.18383200E+01, -.24653600E-01, 0.19560100E-01, 0.12348300E-01, -.11946400E+01, 0.67072000E-01, 0.13965000E+00, 0.20279600E-01, -.17956400E-01, -.20643400E-02, 0.59511000E-02, 0.19059800E+01, -.12345100E+01, -.40418700E-01, 0.13477000E-01, -.39314800E+01, 0.10845500E+01, -.71407600E+00, -.96019400E-01, -.51046800E+00, 0.17559600E-01, 0.25397600E+00, 0.24293200E+00, 0.57591000E-01, -.89033300E-01, 0.14291100E+00, 0.44133200E+00, -.45665000E+02, 0.49728200E+02, -.22567400E+02, -.12092600E+01, -.24592400E+02, -.80824300E+01, 0.47122300E+02, -.45250300E+02, -.58866400E+02, -.69705300E+02, 0.48965500E+02, -.27080500E+02, -.28543100E+03, 0.14871000E+03, 0.16002200E+03, 0.14245000E+03, 0.11203800E+02, 0.30570900E+02, 0.48463500E+02, -.10074100E+03, -.52424100E+01, 0.30899100E+02, -.13852900E+02, -.34206200E+03, 0.16636000E+03, 0.10290300E+03, 0.17116200E+03, 0.38784300E+02, 0.39971700E+02, 0.83437000E+02, -.41798500E+02, 0.59322500E+02, 0.32863500E+02, 0.90027500E+02, -.35174800E+03, 0.17351100E+03, 0.25200600E+03, 0.17574600E+03, 0.40415400E+02, 0.37937600E+02, 0.49487000E+02, -.86588600E+02, 0.92970500E+02, 0.32811500E+02, 0.66125100E+02, 0.10404300E+03, -.59969800E+02, 0.59433700E+02, -.51591300E+02, -.87045000E+01, -.26091700E+01, -.47320000E+02, -.29272100E+02, -.48211300E+02, 0.41490100E+01, 0.29685400E+02, 0.87662500E+02, -.45974500E+02, -.96646800E+02, -.44042500E+02, -.22927200E+02, -.53166000E+02, 0.41933800E+02, 0.47310100E+02, 0.32112700E+02, -.46515200E+02, 0.13103300E+02, -.33442400E+01, -.20771500E+01, 0.37094900E+01, 0.18982400E+00, -.40315800E+01, 0.22658000E+01, 0.30316500E+01, 0.12350400E+01, -.30898800E+01, 0.41626300E+02, -.41005300E+02, 0.10670200E+02, 0.72317700E+00, 0.23170300E+01, -.77211100E+01, 0.42659900E+02, 0.39353000E+01, -.55947400E+01, 0.79520000E+01, 0.79998100E+01, -.47875900E+01, -.87718000E+01, 0.16399100E+02, 0.47782400E+02, -.30982700E+01, 0.38436900E+02 },
        { 0.39472700E+02, -.70567000E+00, -.13361600E+01, 0.96238600E-01, 0.40833100E+01, -.42098300E+01, -.18239200E+01, -.12018700E+01, 0.42414000E+01, -.29195800E+01, -.19727100E+00, 0.54782100E+01, 0.26590800E+00, -.26439400E+00, 0.84986300E+00, -.47597900E+00, 0.16206700E+01, -.44908400E+00, 0.16705600E+01, -.36675000E+01, -.21046300E+01, 0.77755300E+00, -.88225600E+01, -.13942500E+01, -.13673700E+00, -.58841200E+00, 0.27829500E+00, -.54101800E+01, -.61922700E+01, -.10781600E+01, -.18543500E+01, -.57460900E+01, 0.15737000E+00, -.29923000E+01, 0.93526200E+01, 0.12418100E+01, 0.59652700E+00, 0.89732200E+01, -.12584400E+01, 0.46302200E+01, -.30846300E+01, 0.21761200E+00, -.18968100E+00, 0.29902200E+01, -.17402600E+01, 0.56713000E-01, -.75503800E+00, 0.17902100E+00, 0.32894700E+01, -.39614200E+00, 0.30018100E+01, -.73408200E+01, 0.35245700E+00, -.27972800E+00, -.15162400E+01, 0.29436600E+01, 0.48670100E-01, -.10762600E+01, -.71794800E+00, 0.44504800E+00, 0.10200300E+01, 0.55498800E+00, -.85084900E+00, -.42497800E+00, -.85934200E+00, -.83903700E+00, -.48454400E+00, -.24351000E-01, -.43053200E+01, -.52776400E-02, 0.31471700E+00, 0.64300600E-01, 0.44172700E-02, -.40570000E+00, -.47669700E+00, 0.15028300E+01, 0.88306500E+00, 0.48346200E+01, 0.31392900E+01, -.19735900E+01, -.24632400E+00, 0.19203200E+01, -.13267800E+00, 0.90511700E+00, -.19578300E+01, -.14928900E+02, -.10816800E+01, -.23420300E+00, 0.20862500E+00, -.17898400E+01, 0.44879400E+00, -.28500600E+00, 0.80223000E+00, 0.33549200E+00, 0.26651700E-01, 0.18092500E+01, 0.92409200E-01, 0.33755000E+00, -.10774800E+01, 0.36167000E+00, -.38431600E+00, 0.78662300E+00, -.90722100E+00, 0.12931400E+01, -.34399200E+00, 0.11737600E+01, -.20475600E-01, -.16011600E+02, 0.87649300E-01, -.36279000E-02, 0.44219000E+01, -.39998600E+00, 0.50081500E+00, 0.25046900E-02, -.31342400E+01, -.58068500E+00, -.31286200E+00, 0.11292200E+02, 0.58031000E-01, 0.18563600E+01, -.26681300E+00, 0.29028600E+00, -.35886200E-01, -.11148200E+01, 0.59269200E-01, -.25286200E+00, 0.31699100E-01, 0.21663300E+01, -.60438100E+00, -.24279100E+01, -.77673300E+01, -.13057600E+00, -.37823100E+00, -.25867600E+00, -.90418300E+01, 0.30863200E+01, 0.27145300E+00, -.29623900E+00, 0.11363900E+01, -.43406800E+00, -.25332800E+01, 0.20725100E+01, -.14267500E+00, -.18025700E+01, -.84289800E-01, -.11147200E+00, -.99984700E-01, -.63246200E+00, -.42809600E+00, 0.40808400E+01, 0.21117700E+00, 0.31980900E+01, -.60356100E+01, -.51656200E+00, 0.28888900E+00, -.32402800E+00, 0.16832900E+00, -.41787200E-01, 0.33510700E+00, 0.67055800E+00, 0.77266400E+00, -.75877800E-01, -.20281400E+00, 0.49998300E+00, -.11077600E+00, 0.70040900E+00, 0.30313800E+00, -.72598800E+00, -.16796400E+00, 0.29600900E+00, 0.14485600E+01, 0.75774300E+00, -.16151600E+01, -.23352900E+01, -.33240300E+00, -.93467600E+00, 0.89890500E-01, -.68628300E-01, 0.16179300E+01, 0.17195500E+01, -.21360500E+01, 0.10586500E+02, -.26759900E+00, -.36251500E+00, 0.86323400E-02, 0.29586800E+00, 0.73633000E+00, -.28652200E+00, 0.18090600E+00, 0.21855700E+00, -.95954700E-02, 0.63340700E+00, 0.40125800E+01, 0.11957500E+01, 0.98915300E+00, 0.21599700E+00, -.39197000E+00, -.13379100E+01, -.40188500E+00, -.43820800E-01, -.22883000E+01, 0.49078600E-01, 0.69594900E+00, 0.82426200E+00, 0.23542400E+00, 0.11137900E-01, -.56254400E+00, 0.22589200E+01, 0.10296000E+01, -.32706200E+03, 0.15954400E+03, 0.12583300E+03, 0.16355100E+03, 0.79052300E+02, -.89853700E+02, 0.16525400E+03, 0.13018500E+03, 0.18100000E+03, -.69598100E+02, 0.95695600E+02, 0.12200100E+03, -.69635600E+02, -.16721800E+03, -.61067000E+02, -.38638300E+02, 0.18966000E+02, -.41749200E+02, 0.76948200E+02, 0.12084800E+02, 0.21079200E+02, 0.55485600E+03, 0.33402700E+03, -.15796300E+03, -.10139200E+03, -.16701100E+03, -.62655800E+02, -.43906600E+02, -.36183000E+02, 0.70996700E+02, -.62197200E+02, -.46080800E+02, 0.10865500E+03, 0.12301900E+04, -.61086100E+03, -.64499200E+03, -.61477300E+03, -.56083300E+02, 0.78892900E+02, -.28665300E+03, 0.15291700E+03, -.42291400E+03, 0.69068400E+02, -.25484000E+03, -.25884400E+03, 0.14349300E+03, -.10979800E+03, 0.12943200E+03, 0.13651000E+03, 0.90286200E+02, -.46070600E+02, -.15778600E+02, 0.64382700E+02, 0.82424400E+02, 0.39269100E+02, -.11287100E+03, 0.58699000E+02, 0.74885900E+02, 0.56548000E+02, -.86367200E+02, -.12759400E+03, 0.66364200E+02, 0.62140100E+02, 0.11384200E+03, -.13922200E+03, -.19067300E+02, 0.70615900E+01, -.51018500E+00, -.13860100E+02, -.32229400E+00, 0.12106100E+02, -.95191100E+01, -.76901500E+01, -.17653200E+01, 0.12270900E+02, -.10288300E+03, 0.10051600E+03, -.13514700E+02, -.33022400E+01, -.15315000E+02, 0.10070900E+02, -.10177500E+03, -.57976800E+01, -.73482600E+00, -.17285600E+02, -.16858200E+02, 0.13901000E+02, 0.13869200E+02, -.78135100E+01, -.10163100E+03, 0.16540000E+02, -.92905300E+02 },
        { 0.21503600E+02, -.10649500E+01, -.40564500E+00, 0.65271500E+00, 0.64164700E+00, -.19981400E+01, -.35506100E+00, -.15651300E+00, 0.12422100E+01, -.93938700E+00, 0.80184700E-01, -.38628700E+00, -.14414300E+01, -.22090200E+00, -.17625600E+00, -.29947300E+00, -.82761300E+00, -.65176000E+00, 0.65216200E+00, -.21117600E+00, 0.42016800E+00, 0.12300600E+00, -.11620100E+02, -.11670700E+01, -.21030100E+00, 0.22194400E-01, 0.90518600E-02, -.12069100E+01, -.23483300E+00, 0.14534500E+01, 0.28296200E+00, -.72012600E+00, -.61319100E-01, -.12983700E+01, 0.25169300E+01, 0.34189200E+00, -.63478700E-01, 0.33590200E+01, -.49568100E+00, 0.17443500E-01, -.18034100E-01, -.79909000E+00, -.12804500E-01, 0.21156100E+01, -.68012500E+00, 0.65304500E+00, -.23588900E+00, 0.55537700E-02, -.90090200E+00, -.27327200E+00, -.13843100E+01, 0.75260200E+01, -.99362300E-01, -.39135100E+00, 0.17139600E+01, -.65422100E+00, -.31728600E-01, -.22835000E+00, -.78026300E+00, 0.10843700E+00, 0.22280300E+00, 0.62532800E+00, -.19732200E+00, 0.13118100E+00, -.82661100E+00, 0.23160500E-01, -.20642500E+01, 0.33217500E-01, -.32881200E+00, -.97645800E-02, -.22619000E-02, -.45019000E+00, -.74034300E-01, -.24474400E+00, 0.92595600E+00, 0.16335900E+00, -.10847600E+01, -.67773600E+01, -.34200800E+00, -.10299100E+01, -.66898100E-01, -.16299600E+01, -.38568500E+00, 0.16422900E+01, -.28021300E+01, -.17921000E+02, -.64224300E-01, -.23995600E+00, 0.30552000E+01, -.22631500E+00, -.45688000E+00, 0.36925600E-01, 0.40751600E+01, 0.10063100E+01, -.33868900E-01, 0.68572300E+00, 0.86835100E+00, 0.22553700E+00, -.12191900E+01, 0.71996100E+00, -.20220200E+00, -.80052400E+00, 0.10809800E-01, 0.82787100E+00, -.18873600E+00, -.92551900E-02, 0.17212900E+00, 0.31629400E+01, -.54763200E+00, 0.46947700E+00, -.57403300E+00, 0.23021100E+00, -.17147900E+00, 0.16213200E-01, 0.15109700E+00, -.73656400E+00, 0.35829600E-01, 0.51308700E+01, 0.23307100E+00, 0.28354300E-01, -.31833500E+00, -.10219800E+00, -.10402700E+00, -.33232600E+00, -.19774400E-01, -.67258900E+00, -.39463100E-02, -.86656100E+00, -.28802600E+00, -.18868700E+01, 0.10041100E+01, 0.47371400E+00, 0.41703400E+00, -.55853300E-01, -.31535100E+00, 0.27865300E+00, 0.23248600E+00, 0.32867600E-01, -.69833300E+00, 0.41923600E+00, 0.34166700E+00, 0.72444300E+00, -.79068800E-02, -.16693500E+00, -.11152600E+00, 0.20465300E+00, 0.44385100E-01, 0.13858600E+01, -.39704800E+00, 0.93633700E+00, 0.18460800E+00, -.46295500E+00, 0.26937900E+00, -.27972400E+00, -.23761700E+00, 0.15939300E+00, -.49803000E-01, 0.13789100E-01, 0.16158800E+01, -.98440900E-01, -.85690500E+00, 0.47473100E+00, -.48913100E-01, -.92754300E-03, 0.90669300E-01, -.10902900E+00, -.10455600E+00, -.90153900E-01, 0.20289700E+00, 0.29167800E+00, -.39706200E+00, 0.17076800E+01, 0.51156100E+00, 0.34903900E+00, -.46924200E-01, -.17038200E+00, -.10370700E+00, -.22451900E-01, 0.52074600E+00, 0.10151700E+01, 0.16707300E+00, -.20442900E+01, 0.34022300E+00, -.45168300E-01, -.23041600E+00, 0.65450600E+00, -.83034900E+00, 0.20095700E+00, -.12642100E+00, -.19790500E+00, 0.18196000E-02, -.79638500E-01, 0.48717000E+00, -.37417700E+00, -.55283900E+00, 0.42452000E-01, 0.10835100E+01, 0.73200400E+00, 0.36091300E+00, -.61693300E-01, 0.53657700E+00, -.31234900E-01, -.25226300E+00, 0.33183400E-01, 0.64433900E-01, -.30304400E+00, 0.16191100E+00, -.10692700E+01, -.73636300E-01, -.62708000E-01, 0.51104400E+02, -.32397100E+02, -.38137800E+00, -.52726400E+01, -.19680300E+02, -.13333600E+02, -.55480700E+01, 0.14800800E+02, -.22514100E+02, 0.54238700E+00, 0.11508100E+03, -.64837900E+02, -.78996100E+02, -.57143400E+02, -.10510600E+02, -.13768600E+02, -.10301900E+02, 0.37639500E+02, -.19722000E+02, -.17258600E+02, 0.19171400E+01, 0.14618000E+03, -.69371700E+02, -.37778700E+02, -.73265200E+02, -.16553500E+02, -.13252400E+02, -.41868000E+02, 0.54379400E+01, -.67849300E+02, -.65869600E+01, -.45218300E+02, 0.96394300E+02, -.49424600E+02, -.99491200E+02, -.48188900E+02, -.35222000E+02, -.58541700E+02, -.16768000E+02, 0.12837000E+02, -.10847900E+01, -.47258400E+02, 0.18142700E+02, -.26147600E+02, 0.16992000E+02, 0.16111700E+02, 0.12469100E+02, -.33821400E+02, -.21451400E+02, 0.53700700E+02, 0.36279500E+02, 0.35470800E+02, -.25440400E+02, -.29357600E+02, -.62153100E+02, 0.27609300E+02, 0.52273800E+02, 0.31388400E+02, 0.31559000E+02, 0.57528400E+02, -.17178000E+02, -.82121800E+01, 0.69879300E+00, 0.49053200E+02, -.37156900E+01, 0.41024400E+00, 0.25257500E+01, -.14397400E+00, -.71191100E+00, 0.18570800E+01, -.67426600E+00, 0.56672100E+01, -.13887400E+00, -.22597700E+00, -.86920000E+01, 0.73274600E+01, 0.15318000E+00, -.91083500E+00, -.16044100E+00, -.60166000E+01, -.84508500E+01, -.15851400E+01, 0.42096200E+01, -.49718700E+01, -.77516100E+00, 0.14956100E+01, -.59831100E+01, -.61262100E+00, -.12604000E+02, -.10795900E+01, -.92610200E+01 },
        { 0.17750100E+02, -.37916500E+00, -.10739200E+01, 0.61081700E+00, 0.47157800E+00, -.15607000E+01, -.17257400E+00, 0.93588000E-01, -.28113700E+00, -.38072400E+00, 0.90408200E-01, -.24797100E+01, -.16994800E+00, 0.52949900E+00, -.13832800E+00, 0.13391000E+00, -.16252800E+01, -.98433700E+00, -.49842600E+00, 0.11106400E-01, 0.65869200E+00, -.51806500E+00, -.10811700E+02, 0.33564700E+00, -.12096800E+01, -.24062200E+00, -.59588000E+00, 0.59359800E+00, 0.24778500E+01, -.68047900E+00, 0.12369800E+01, -.47856200E-01, -.14136800E+00, -.10358600E+00, 0.29171700E+01, 0.23070600E+00, 0.41432300E+00, -.72210100E+00, 0.20242400E+00, 0.86043200E+00, -.34957600E+00, -.30239900E+01, 0.17375900E+01, 0.37744200E+00, -.16094400E+01, 0.56329800E+00, -.12996800E+00, -.53474700E-01, -.38653200E+00, -.21406700E+00, -.29413500E+01, 0.15300100E+02, -.57817700E+00, -.51751300E+00, -.25052300E+01, -.12223700E+01, 0.81455700E-01, 0.94048600E+00, -.16527000E+01, -.27415000E-02, -.23263000E-01, 0.64247600E+00, 0.30816900E+00, 0.76252700E+00, -.13304900E+01, 0.58203400E-01, 0.25791300E+01, -.16204000E-02, 0.74156900E+00, -.55480700E-02, -.19275200E+00, 0.95473800E+00, 0.49950600E+00, -.62840000E+00, 0.87765600E+00, 0.53013500E+00, -.10010700E+01, 0.48859700E+00, -.14807500E+01, -.88802300E+00, -.89603500E-01, -.44657700E+00, -.12477500E+00, 0.11437900E+01, -.16108900E+01, -.14722500E+02, 0.16611900E+00, -.14410100E+00, 0.21902800E+01, -.41520300E+00, -.70539600E+00, -.83727100E-02, 0.11771700E+01, 0.46072500E+00, -.13870800E+00, 0.55733500E+00, 0.12303900E+01, 0.87960700E+00, -.64185600E+00, -.21620700E+00, -.14707300E+00, -.11982700E+01, 0.15693400E+00, 0.65694700E-01, 0.46956500E+00, -.50798500E+00, 0.23589300E+00, 0.80638200E+01, -.20439400E+00, 0.18511900E+00, -.47404500E+01, -.13564800E+00, -.81466600E+00, 0.12649200E-01, 0.20649200E+01, -.72504200E+00, -.14761900E+00, -.18896900E+01, -.82812600E+00, 0.26612500E+01, 0.49798300E+00, -.11875800E+00, -.17551000E-01, 0.42494500E+00, -.10658800E-01, -.47490900E+00, 0.23587700E+00, -.16997900E+01, -.14669000E+00, 0.47247900E+00, 0.49787500E+01, 0.11575700E+01, 0.20236300E+00, -.21125100E+00, 0.21305600E+01, 0.24701100E+00, 0.19326100E+00, -.37215800E+00, -.25311100E+01, 0.16486000E+01, 0.10209000E+01, 0.72085000E+00, -.61570800E-01, -.12626200E+00, 0.57068300E-03, -.96038100E-01, -.20255100E-01, 0.13124600E+01, 0.23954700E+00, 0.18634900E+01, 0.18964200E-01, -.64415500E+00, 0.18583400E+01, -.33600800E+00, -.17567800E+00, -.34079500E-01, 0.66667500E-01, 0.42569000E-01, 0.22615700E+01, -.15981100E+00, -.19637400E+00, 0.52959900E+00, 0.11837100E-01, -.43378500E+00, 0.90533000E-01, -.31796700E-01, -.36146000E-01, 0.81719400E-01, 0.10977300E+00, 0.57489200E+00, 0.18135400E+00, -.10178300E+01, -.18732300E+00, -.28912900E+00, -.44058700E+00, -.84479600E+00, -.33001400E-01, 0.12897000E+00, -.59214400E+00, -.13079000E+01, 0.86104800E+00, -.10950400E+01, -.32292600E+00, -.40707100E+00, 0.79574800E-01, -.12582200E+01, -.11919400E+01, 0.53522000E+00, -.11716400E+00, -.36616400E+00, 0.94579200E-02, -.26665200E+00, 0.69951300E+00, -.11162200E+01, -.92066500E+00, 0.14925800E+00, -.17759200E+01, 0.80290400E+00, -.17225000E+00, 0.21371700E-01, 0.49659000E+00, -.30459000E-01, 0.53269400E+00, 0.23000800E+00, -.23879700E-01, -.68824300E+00, 0.17939800E+00, 0.53328300E-01, -.14967500E+00, 0.17481100E+00, -.43058500E-01, 0.92654600E+02, -.52267900E+00, -.66054800E+01, 0.24442600E+02, -.35818100E+02, -.80039000E+02, -.59403700E+02, 0.32274900E+02, -.59843900E+02, -.14097700E+03, 0.80845100E+02, 0.13729300E+03, 0.71101900E+02, 0.19265800E+01, -.99667300E+01, 0.64390000E+02, -.50689500E+02, 0.91814200E+01, -.12435800E+02, -.29702000E+03, -.47355000E+03, 0.22748000E+03, 0.15429600E+03, 0.23655200E+03, 0.71916700E+02, 0.69769100E+02, 0.73865200E+02, -.71664000E+02, 0.11687800E+03, 0.56581700E+02, 0.50009600E+02, -.47805800E+03, 0.22834300E+03, 0.30234500E+03, 0.23890400E+03, 0.50012100E+02, 0.47230500E+02, 0.93184800E+02, -.63797200E+02, 0.13281000E+03, 0.31658500E+02, 0.14829000E+03, 0.68280000E+02, -.45265300E+02, 0.24314300E+03, -.34928500E+02, -.23268400E+02, -.50327400E+01, -.12126100E+02, -.10310200E+02, -.53602900E+02, -.12813200E+01, 0.20631700E+02, 0.58623800E+02, -.31726800E+02, -.69260700E+02, -.29015700E+02, 0.61460100E+01, -.98546200E+01, -.81312000E+01, -.79396900E+01, -.16188100E+02, -.21269700E+01, -.48148500E+01, -.45312600E+01, -.11558800E+01, 0.45673500E+01, -.20149900E+00, -.45578900E+01, 0.35119700E+01, 0.10578500E+02, 0.10912500E+01, -.35361700E+01, 0.43222200E+02, -.42183100E+02, 0.16807100E+02, 0.50658700E+00, 0.70073200E+01, -.14891300E+02, 0.43098100E+02, 0.34713000E+01, -.10729900E+01, 0.44823600E+01, 0.14948400E+02, -.14607100E+01, -.15882400E+02, 0.20728500E+02, 0.42046000E+02, -.55387500E+01, 0.41521100E+02 },
        { 0.21716900E+02, -.52273500E+00, -.83688100E+00, 0.33985800E+01, 0.19115700E+01, -.31208900E+01, 0.10655300E+00, -.32701000E-01, 0.51651400E+00, -.20666600E+01, 0.24852000E+00, 0.50770000E-01, -.33684800E+00, -.59878300E-01, 0.12180300E+01, -.76189400E+00, -.18653300E+00, 0.10082300E-01, 0.70082900E+00, -.18997000E+01, -.27933600E+00, -.27524200E+00, 0.17091400E+01, 0.18262800E+01, -.31355900E+00, 0.52051500E+00, -.14621300E+01, 0.42215300E+00, 0.76421700E+00, -.10634400E+00, -.24709400E-01, -.28592700E+01, -.56231200E-01, 0.29599600E+00, 0.34675100E+00, 0.13392900E+00, 0.41614400E+00, 0.17887900E+01, 0.18190800E+00, -.22797900E+00, -.42292900E-01, -.88942400E+00, -.30651800E-01, 0.29083300E+00, 0.41471400E+00, 0.14190900E+00, 0.81743000E-01, -.80301300E-01, -.22606000E+00, -.16748300E+00, -.32188300E+00, 0.24600000E+01, -.10172600E+00, 0.10569000E+00, 0.13150400E+01, -.36307300E+00, 0.75128800E-01, 0.41182100E+00, -.15237100E+01, 0.26175100E+00, -.28331000E-01, -.63981500E-01, 0.18956600E+00, 0.80959800E-01, -.13834600E+00, 0.34833600E+00, -.94699900E+00, 0.81510300E-03, -.47897300E+00, -.67935100E-02, -.18417200E+00, 0.18118800E+00, -.93433600E-01, -.85098600E-01, 0.81118600E+00, -.33202200E+00, -.99479600E+00, -.22656700E+00, -.15338800E+01, -.85208500E+00, -.12693600E+00, -.54277100E+00, 0.10759500E+00, 0.51842000E+00, -.13409400E+01, -.82719500E+01, 0.16186700E-01, -.19554500E+00, 0.14012600E+01, -.80909900E+00, -.59091600E+00, -.56784400E-01, 0.78898500E+00, 0.10246400E+00, -.13035000E+00, 0.21130900E+00, 0.67877100E+00, 0.69647200E+00, 0.45367300E+00, -.16521600E+00, -.15087100E+00, -.44389700E+00, -.53311500E+00, -.50300900E-01, 0.19253200E+00, 0.13102000E+00, 0.35950200E+00, -.51944400E+00, -.10383800E+00, 0.18793400E+00, -.21237600E+01, 0.52923900E-01, 0.22256100E+00, 0.38146600E-01, 0.66657700E+00, -.48532500E+00, -.43785300E-01, 0.25634300E+01, -.10121600E+00, -.64880000E+00, -.88273100E-01, -.67591000E-01, -.39289000E-01, -.40458700E+00, 0.36784600E-01, -.58567600E+00, -.10026900E+00, -.10153200E+01, -.17882000E+00, -.20233500E+01, 0.35916800E+00, 0.22616100E+00, 0.59503100E+00, -.42511200E-01, -.99142200E-02, -.29036600E+00, 0.16444600E+00, 0.97938800E-01, -.12448400E+01, 0.74732200E+00, 0.26071600E+00, 0.71312400E+00, -.20182900E-01, 0.59106000E-01, 0.20702500E-01, 0.10974500E+00, -.52824000E-01, 0.36905100E+00, -.22557400E+00, 0.25709200E+00, 0.13821000E+00, -.13756700E+00, -.87020700E+00, -.29072900E+00, -.33499100E+00, -.56791600E-01, -.24444300E+00, 0.13567600E+00, 0.35341700E+00, -.12173000E+00, -.25905400E+00, 0.13053500E+00, -.90721800E-01, 0.36822000E+00, 0.48780100E-01, 0.71662600E-01, 0.11829200E+00, 0.58393000E+00, 0.32622000E-01, 0.76056100E-01, 0.16620000E+00, 0.48345700E+00, -.31485100E-01, 0.43581300E+00, 0.13505000E+00, -.26992500E+00, -.20875200E-01, 0.77079600E-01, 0.83428300E+00, 0.20590500E+01, 0.10128800E+00, -.10374600E+01, 0.37082400E+00, -.13230100E+00, -.12008500E+00, 0.61986300E-01, -.63984500E+00, -.42767600E+00, -.10814300E-01, -.59649200E-01, -.10148200E-01, 0.16952300E+00, -.57305500E+00, 0.49304100E+00, -.28846300E-01, -.25712300E-01, 0.31555400E+01, 0.10369900E+00, 0.28482700E+00, 0.92001600E-01, 0.98663400E+00, 0.14059700E-01, -.28907200E+00, 0.10939000E+00, -.89621000E-02, -.33197600E+00, 0.22385100E-01, -.75680800E+00, -.42692700E+00, 0.89359900E-01, 0.32285800E-01, -.22711700E+00, 0.30678400E+01, 0.20460900E+01, 0.36982100E+01, -.29448500E+02, -.43988200E+02, -.23694300E+02, 0.44963800E+01, -.22898600E+02, -.59497500E+02, 0.31968000E+02, 0.21585800E+02, 0.29489300E+02, 0.17818000E+01, -.11462200E+02, 0.40138200E+02, -.30621000E+02, -.25741700E+02, -.33018400E+01, -.15228200E+03, -.12040400E+03, 0.56677800E+02, 0.70162900E+02, 0.60255200E+02, 0.48024900E+01, 0.12487000E+02, 0.91690900E+01, -.53810400E+02, -.24819500E+02, 0.18204200E+02, -.11877600E+02, -.52228800E+02, 0.22772500E+02, 0.25655400E+02, 0.26022900E+02, -.11129500E+02, -.28092600E+02, 0.15105600E+01, -.36252600E+02, 0.21678200E+02, -.24330700E+02, 0.24517100E+02, 0.35509300E+02, -.21476000E+02, 0.25022300E+02, -.17402000E+02, -.28864900E+02, -.24979200E+02, 0.36018700E+02, 0.22451000E+02, -.78940700E+00, -.27026700E+02, -.59832500E+02, -.34940100E+02, 0.15583300E+02, 0.11685000E+02, 0.17270100E+02, 0.26138700E+02, 0.36394900E+02, -.73203100E+01, 0.56680000E+01, 0.17803200E+02, 0.31295400E+02, 0.35644000E+01, -.15449600E+01, 0.23500300E+01, 0.19169300E+01, -.63996200E+00, -.17956100E+01, 0.11860900E+01, 0.41500200E+01, 0.43133900E-01, -.19526300E+01, 0.11476900E+02, -.11925700E+02, 0.33468500E+01, -.13040200E+01, 0.42793300E+01, -.37196600E+01, 0.11676600E+02, 0.37242900E+00, 0.10672200E+01, 0.44496900E+00, 0.59479900E+01, -.66630800E+00, -.67101300E+01, 0.37664800E+01, 0.11234900E+02, -.17922500E+01, 0.94362700E+01 },
        { -.11474800E+02, 0.15997200E+00, 0.35719400E+00, -.72773900E+00, -.13407200E+01, 0.81129000E+00, 0.11695100E+01, 0.55387200E+00, -.31103100E+01, 0.50340600E+00, 0.39344500E-01, -.17887900E+01, 0.46912700E-01, 0.99642300E-01, -.16283200E+00, 0.22562200E+00, -.12860600E+01, -.39088500E+00, -.15811100E+01, 0.48393800E+00, -.52946400E+00, -.66670100E-01, -.98577500E+00, 0.35560000E+00, 0.28519700E-01, 0.14131400E+00, 0.22073000E+00, 0.10956700E+01, 0.75528300E+00, -.18747700E-01, 0.45679400E+00, 0.63849200E+00, -.54459400E-01, 0.35667400E+00, -.31752000E+01, 0.19562300E+00, -.14657400E+00, -.54732100E+00, -.35262800E-01, -.18374600E-01, 0.24813000E+00, -.30467300E-01, 0.27273100E+00, 0.38685700E+00, 0.67242300E-01, -.34593900E+00, -.73763200E-01, 0.27274200E-01, -.85984700E+00, 0.45942300E-01, 0.15808800E+01, 0.16828100E+01, 0.31785100E+00, 0.56847700E+00, 0.97502300E+00, 0.29821200E+00, 0.92358800E-01, 0.11905200E-01, 0.16554500E+00, -.20292700E+00, -.14589200E+00, 0.63487600E+00, -.22769900E-02, -.13600800E+00, 0.21443600E+00, 0.86658800E-01, -.96897400E+00, 0.15917300E-01, -.74572600E+00, 0.45493700E-02, 0.21710500E-01, -.34303600E+00, -.33083900E+00, -.12525200E-02, 0.52762600E+00, -.91253800E-01, -.54629200E+00, 0.22678100E+01, -.18266000E+01, -.45087400E-01, 0.50450300E-01, 0.83494500E+00, -.28245300E+00, -.67584500E+00, -.32516100E+00, -.30737600E+01, 0.71454500E-01, 0.35666800E-01, -.40939500E-01, 0.77561700E+00, -.39877000E+00, 0.98751900E-01, -.13192600E+01, 0.19658700E+00, 0.55783400E-01, -.37886900E+00, -.44209200E+00, 0.40004000E+00, -.52828800E+00, -.19340600E+00, -.33078200E-01, 0.54888400E+00, 0.28325000E+00, 0.37570800E+00, 0.37483800E-01, -.43075700E+00, 0.73596300E-02, 0.17180300E+01, 0.90931400E-01, -.78387800E-01, -.60919000E+00, -.55580100E-01, -.19099400E+00, -.39813500E-02, 0.59649600E-01, 0.23972200E+00, 0.47449700E-01, -.16991900E+01, -.15943700E-01, -.11022600E+00, 0.45118300E-01, -.11708400E+00, 0.39435000E-02, -.49745700E+00, -.17729400E-02, 0.20901900E+00, 0.80620600E-01, 0.11535600E+00, 0.30465900E-01, -.17451700E+01, -.17693800E+01, 0.28624300E+00, 0.34779400E+00, 0.52911100E-01, -.38368300E+01, 0.12060200E+01, 0.17491900E+00, -.59673100E-01, 0.17562000E+00, 0.49791700E+00, -.17248400E+00, -.34580900E+00, 0.51368300E-01, 0.16753700E+00, 0.56086900E-01, 0.17891400E+00, 0.25654600E-01, -.44111700E+00, -.21675400E+00, -.15954500E+00, 0.20290500E+00, -.50997700E+00, 0.82469400E+00, 0.23395100E+00, 0.95282200E-01, 0.10896800E+00, -.76063000E-01, -.91923900E-03, -.58077600E+00, -.19603400E+00, -.12582400E+00, -.12284700E+00, -.34057700E-01, 0.32696100E+00, -.54802000E-01, 0.15386000E+00, 0.11668400E-01, -.57742100E+00, -.29703700E-02, -.16613200E+00, -.41914700E+00, 0.62624200E+00, 0.32113700E+00, -.97185200E+00, 0.14280000E+00, 0.45342100E+00, -.15532500E-01, -.10460700E+00, -.16991200E+00, 0.90682200E-01, -.10667500E+00, -.12848700E+00, 0.16177600E+00, 0.14183400E+00, -.10507200E+00, 0.32211400E+00, -.31920500E-02, -.14670500E+00, -.67804200E-02, -.44331000E-01, -.27663400E-02, -.20934600E-01, -.61752400E+00, 0.12354400E+00, -.12224300E+00, 0.13010100E+00, 0.89516300E+00, 0.19797600E+00, 0.76300500E+00, -.25308600E-01, -.52655700E+00, 0.44140400E-02, 0.53817800E-04, 0.82003300E-01, 0.17416400E-01, 0.14221600E+00, 0.11547600E+00, -.87815500E+00, 0.15373600E+00, -.42089500E-01, 0.67496300E-02, 0.13009200E+00, -.47026400E-02, -.26969100E+02, -.27879400E+02, 0.23407900E+02, 0.43330100E+02, 0.36646800E+02, -.35240800E+02, 0.25660700E+02, 0.26928600E+03, -.14079400E+03, -.15166300E+03, -.13465300E+03, -.17251500E+02, -.26727000E+02, -.59145000E+02, 0.87378300E+02, -.14415300E+02, -.35438700E+02, 0.83413400E+00, 0.34581900E+03, -.16771500E+03, -.11355500E+03, -.17292300E+03, -.28861700E+02, -.21790800E+02, -.10780300E+03, 0.67045700E+02, -.48919500E+02, -.18688700E+02, -.72766800E+02, -.11754900E+01, 0.34450000E+01, 0.35627300E+02, 0.62173300E+00, -.22378200E+02, -.48413500E+02, -.16384700E+02, -.51446000E+02, 0.10416700E+02, -.36863100E+02, -.17357000E+02, 0.93871000E+02, -.42626800E+02, -.14577700E+03, -.46967800E+02, -.55916700E+02, -.52420100E+02, 0.46187600E+02, 0.33697300E+02, 0.10479400E+02, -.51049800E+02, -.11059900E+03, -.98890200E+02, 0.52332700E+02, 0.22864700E+02, 0.49505500E+02, 0.32529900E+02, 0.46341200E+02, 0.89559900E+01, 0.19935200E+02, 0.19555400E+02, 0.42788800E+02, 0.26105500E+02, -.37354400E-01, 0.12495700E+01, -.76633200E+00, 0.63215900E+00, 0.29647300E+01, -.23810800E+01, -.15587500E+01, -.21190700E-01, 0.10016500E+01, -.46043100E+01, 0.61864800E+01, -.13047800E+02, -.25640800E+01, -.56627100E+01, 0.62873500E+01, -.60115500E+01, -.24165500E+01, 0.25481100E+01, -.49532600E+01, 0.96824600E+01, 0.22560200E+01, 0.43886100E+01, -.15614400E+02, -.16815700E+01, -.48926700E+01, -.30054500E+01 },
        { 0.17365800E+02, -.40989600E+00, -.55538100E+00, -.15154800E+01, 0.22395600E+01, -.46366500E+01, -.12101100E+00, -.30190500E+01, 0.66657400E+01, -.35417900E+01, -.96691800E+00, 0.31670700E+01, 0.79478800E+00, -.35361300E-01, 0.81347300E+00, -.43502500E+00, -.50989700E+00, -.41020700E+00, 0.15727700E+01, -.23306400E+01, -.44169700E+01, 0.34865600E+00, -.59395100E-01, -.14140300E+01, 0.12759200E+00, -.47470900E+00, 0.81265400E+00, -.24481000E+01, -.43891300E+01, 0.13650700E+01, -.79126200E+00, 0.45124700E+01, 0.94256600E+00, -.10901000E+01, 0.28687000E+01, 0.42403900E+00, 0.56461600E-01, 0.33935100E+01, -.70800500E+00, 0.13116700E+01, 0.42223100E-01, -.13802500E+00, 0.44750500E+00, 0.63450300E+00, 0.10913100E+00, 0.20179000E+00, -.20646400E+00, -.14886600E-01, 0.20980500E+01, 0.15095700E-01, 0.23878100E+01, -.11551000E+02, -.35358000E-01, -.95044900E+00, 0.37976500E+01, 0.17161300E+01, -.15244500E+00, -.16824900E+01, 0.71500800E+00, 0.35322600E+00, 0.18743200E+01, -.12009400E+01, -.16437000E+01, -.70524000E-01, 0.42078500E+00, 0.28613600E+00, -.24134600E+01, 0.11937900E-01, -.21581600E+01, -.26693200E-02, 0.58103200E-01, 0.28230700E+00, 0.36106600E+00, -.17635500E+00, 0.14843300E+01, 0.17118000E+01, 0.40679500E+01, 0.62798000E+01, 0.37547100E+00, 0.12587300E+01, 0.17136400E+00, 0.42580200E+01, 0.77580500E+00, -.21491800E+01, 0.20529600E+01, -.18052600E+02, -.17462900E+01, 0.50844800E+00, -.90576500E+00, -.21756900E+01, -.12396700E+00, -.74370600E-03, -.12159200E+01, 0.28777600E+00, -.77148600E+00, 0.12060500E+01, 0.60976600E+00, 0.17092100E+01, 0.43495700E+01, -.14780400E+00, -.42024900E+00, -.87970400E+00, 0.41130900E+00, 0.23391200E+01, 0.57698200E+00, -.29001400E+00, -.40969100E+00, -.49850000E+01, 0.14678300E+01, -.83429100E+00, -.30005000E+01, -.52837400E+00, -.51646500E-01, -.29353900E-01, -.12110300E+01, 0.26462900E+01, -.30528600E+00, -.13073000E+02, -.83770600E+00, 0.10719800E+01, 0.71283500E+00, 0.18654700E+00, -.65140700E-01, 0.15421200E-01, -.12201300E-01, 0.31169900E+01, 0.65263300E+00, -.13205200E+01, 0.61941500E+00, 0.25340200E+01, -.10441000E+02, 0.73962400E-01, 0.11939900E+01, -.20032900E+00, -.10959900E+02, 0.14477200E+01, -.27513300E+00, -.13219100E+00, -.58536600E+01, 0.70139600E+00, 0.71162000E+00, -.53507000E+00, 0.17401300E+00, 0.14653400E+00, 0.36365800E-01, -.18800400E-01, 0.44585200E-01, -.18079700E+01, 0.27392600E+00, -.32785700E+01, 0.21198600E+00, 0.45902000E+00, 0.13444400E+01, 0.23331500E+00, 0.91265200E+00, -.31270200E+00, -.36385100E+00, 0.23527800E-01, -.16990000E+01, 0.76858800E+00, -.41161200E+00, -.57909400E+00, 0.99554400E-01, 0.38351200E+00, -.28100100E+00, -.12072500E+01, 0.55757900E-01, -.12960400E+01, 0.36496800E-01, 0.34815000E+00, -.24697200E+00, 0.31644000E+01, 0.73444900E+00, -.91732600E-01, -.93378900E+00, 0.38873700E+00, -.15632300E-01, -.11010700E+00, 0.28408800E+00, 0.30889800E-01, -.65161600E+00, 0.42172400E+01, -.11708900E-02, 0.34531600E+00, 0.13367100E+00, -.76534500E+00, -.29272200E+00, -.91714500E-01, -.10408900E+00, -.24321500E+00, -.68511000E-03, 0.18690700E+00, 0.15713600E+01, -.48011300E+00, -.58416300E-02, 0.50778800E-01, 0.69692700E+00, 0.26263600E+00, 0.11462300E+00, 0.45728100E-02, 0.98252200E+00, 0.12348200E-01, -.97841400E+00, 0.13499500E+01, -.19436100E-01, -.37678700E+00, -.13458900E+00, -.87454300E+00, 0.57071700E+00, -.36683200E+00, 0.87563300E-01, -.10206400E+01, -.26114300E+00, -.93065900E+00, -.10512100E+03, 0.38168200E+02, 0.11029900E+03, 0.10508000E+03, -.12053100E+03, 0.21119300E+02, 0.67215400E+03, -.35336500E+03, -.40146100E+03, -.33532200E+03, -.67172300E+02, -.65413500E+02, -.79376000E+02, 0.23574000E+03, -.86312100E+02, -.75443500E+02, 0.49898100E+02, 0.92989600E+03, -.45419400E+03, -.32403300E+03, -.46532800E+03, -.13554100E+03, -.94462000E+02, -.21376100E+03, 0.12514500E+03, -.30572900E+03, -.92454000E+02, -.11580700E+03, 0.85888900E+03, -.43037200E+03, -.56809400E+03, -.42923200E+03, -.11729600E+03, -.10213200E+03, -.17028600E+03, 0.11251800E+03, -.20089300E+03, -.87806900E+02, -.74317300E+02, -.15897400E+03, 0.93221600E+02, 0.87880900E+01, 0.78330600E+02, 0.27097900E+02, -.22140700E+02, 0.15338000E+03, 0.93841600E+02, 0.71692300E+02, -.13873400E+02, -.59317800E+03, -.27110000E+03, 0.13784000E+03, 0.18328400E+03, 0.13610900E+03, 0.62656400E+02, 0.99362100E+02, -.16712000E+02, -.19014700E+02, 0.28540600E+02, 0.89120400E+02, -.34010700E+02, 0.42678500E+01, 0.87702700E+01, -.12249500E+02, -.22482300E+01, 0.10259300E+02, -.68512900E+01, 0.22115900E+02, -.11487500E+01, 0.11676200E+02, -.70579000E+02, 0.66134000E+02, -.71900500E+01, -.80330900E+01, -.83809100E+01, -.13205500E+02, -.70107600E+02, -.82304700E+01, 0.14658200E+02, -.22120400E+02, -.59456300E+01, 0.11456600E+02, -.16713500E+02, 0.13036600E+00, -.82581300E+02, 0.51914300E+01, -.64671300E+02 },
        { -.82497500E+01, 0.26391500E+00, 0.30844800E+00, 0.73438100E+00, -.47520100E+00, 0.16908900E+01, -.14757000E+01, -.29307800E+00, 0.65160100E+00, 0.12510800E+01, -.10092100E+00, 0.73555700E+00, 0.56373200E-01, -.73163400E-01, -.58807600E-01, -.36868800E-01, 0.26573200E+00, -.76482300E+00, 0.49107500E+00, 0.12558400E+00, -.75287200E-01, 0.48505800E+00, -.42195200E+01, -.14152900E+01, -.13084500E+00, -.15438800E+00, 0.11407500E+00, -.45311000E+00, -.12997800E+01, -.13095500E+01, -.73411200E+00, 0.22532200E-01, 0.10783400E+00, -.54987900E+00, 0.27329000E+01, 0.30733800E+00, -.56756700E-01, -.89982800E+00, -.19841600E+00, 0.47446400E+00, -.21933900E+00, 0.48859100E+00, -.13181800E+00, -.26687000E+00, 0.23295200E-01, 0.76145200E-01, -.10350500E+00, -.10062800E-01, 0.20464000E+00, -.53511300E-01, -.16339600E-01, -.26370800E+00, -.12240600E+00, 0.12084300E+00, -.55510100E+00, -.35998600E-01, -.29816400E-01, 0.66510800E+00, -.13774800E+00, 0.97296600E-01, -.38087000E+00, -.25114400E+00, 0.46763600E+00, -.13769400E+00, -.20879600E+00, 0.10345800E-01, -.92201400E+00, -.11795300E-02, -.93514800E+00, 0.51627900E-04, 0.12357900E-01, 0.22420100E+00, 0.12766600E+00, 0.80829000E-02, -.56534700E+00, -.10867600E+01, 0.59262400E+00, 0.28330600E+01, -.86589800E+00, -.40454200E+00, -.19409500E-01, 0.13912800E+01, -.11117900E+01, 0.53337300E+00, -.49640700E+00, -.46164000E+01, 0.96173800E-01, 0.12854300E+00, 0.61346700E+00, -.22085300E+00, 0.23425200E+00, -.31997000E-01, 0.37721200E+00, -.63814400E-01, 0.21535100E+00, 0.31721600E+00, -.38926700E+00, -.61300200E+00, -.28092500E+00, -.15148300E+00, 0.13474100E+00, 0.57326000E+00, -.14066700E+00, -.66001000E+00, -.14441100E+00, 0.31356600E+00, -.58791800E-01, 0.34007100E+00, -.18341100E+00, -.95241900E-02, 0.86047700E+00, 0.23419800E-01, -.48576700E-01, -.28306700E-02, -.36972100E+00, 0.20392100E+00, -.29316500E-02, -.12726700E+01, 0.18229400E+00, -.53702600E+00, -.73725500E-02, 0.94419200E-01, 0.15602900E-01, 0.44657300E+00, 0.90004000E-02, 0.43427500E+00, -.24341300E-01, 0.28872100E+00, 0.31283000E+00, 0.12633200E+01, 0.13440800E+01, 0.94216600E-01, -.61433100E+00, 0.45841600E-02, 0.53635400E+00, -.21673000E+00, -.82447800E-01, -.58701200E-01, 0.77966100E+00, -.50683000E+00, 0.17773300E+00, -.57694600E+00, -.18859300E-01, 0.41768000E+00, -.32813500E-02, -.48944200E-01, -.16304000E-01, -.98414800E+00, 0.92500100E-01, 0.67538100E+00, 0.55724000E-01, 0.11723600E-01, 0.19150100E+00, 0.73170500E-01, -.10634100E+00, -.81295700E-01, 0.37020400E-01, 0.43025700E-02, -.18653500E+00, 0.19868500E+00, 0.11297200E+00, -.25093600E+00, 0.75728700E-01, -.15286600E+00, -.10906500E-01, -.16318900E+00, 0.38090000E-01, 0.14125500E+00, -.95022500E-01, -.24883600E+00, 0.26515800E+00, -.98731300E+00, -.37968600E+00, 0.95386100E+00, -.82062700E-01, 0.16725100E+00, 0.55724900E-01, -.24630800E-01, -.22155000E+00, -.69882800E+00, -.11071200E+00, 0.13604800E+01, -.29575300E-01, -.16811300E+00, 0.12364400E+00, -.47379200E+00, 0.43735400E+00, 0.78634800E-01, 0.67227400E-01, 0.19302300E+00, 0.96183700E-03, 0.56486300E-01, -.68809500E+00, 0.71491700E+00, 0.57341300E+00, -.12048000E+00, -.10731500E+01, -.33273600E+00, -.79237200E+00, -.18184100E-01, -.25958000E+00, 0.20960000E-01, -.11423000E+00, -.74838100E-01, -.29289900E-01, 0.32333500E+00, -.95981700E-01, 0.45797200E+00, -.18734700E+00, -.82791900E-01, -.13633600E-02, 0.18030000E+00, 0.15705600E+00, -.59098200E+00, 0.83272900E-01, 0.31550500E+02, 0.66562700E+02, 0.29233700E+02, -.73442100E+01, 0.45596200E+02, -.65296400E+01, -.15115200E+01, 0.35341500E+01, 0.27152400E+01, 0.12549100E+02, 0.31584000E+02, -.64279800E+02, 0.86687300E+01, 0.56340900E+02, 0.28935000E+02, 0.18984300E+03, 0.15099500E+03, -.70607200E+02, -.15302500E+02, -.75262000E+02, -.86261400E+01, -.10191900E+02, -.43134300E+02, 0.51466400E+02, 0.52622400E+02, -.64794500E+01, 0.11510500E+01, 0.54375600E+02, -.17473500E+02, -.14145900E+01, -.27152400E+02, -.35842900E+01, -.13841100E+02, -.67640000E+01, 0.21451600E+01, -.23701800E+02, -.58773200E+01, -.78277700E+02, 0.88544300E+02, -.38847300E+02, -.19362200E+03, -.43509100E+02, -.73260800E+01, -.17001400E+02, -.29135800E+02, 0.93193700E+00, -.89151000E+00, -.16171100E+02, 0.21530500E+02, 0.51664600E+01, 0.15915800E+00, -.11793400E+02, -.29168600E+01, -.11013000E+02, -.13158200E+02, 0.15788700E+02, 0.17676700E+02, 0.60548800E+01, -.13063200E+02, 0.15920300E+02, 0.18168400E+01, -.20429500E+01, -.54976900E+00, 0.16421100E+01, 0.67864900E+00, -.95836800E+00, -.15447500E+02, -.28768100E+00, 0.81920300E+00, -.98376400E+01, 0.10996600E+02, -.16942400E+02, 0.82114800E+00, -.46373000E+01, 0.17517900E+02, -.10614500E+02, 0.52882000E-01, -.33875200E+01, 0.16340000E+01, -.35203700E+01, -.21727200E+01, 0.20742900E+02, -.23577800E+02, -.71145700E+01, 0.74946800E+00, -.88601800E+01 },
        { -.31338100E+00, -.16120100E+00, 0.79324100E-01, -.11924600E+01, -.14450600E-01, -.15951300E+01, 0.44165400E+00, -.41072000E+00, -.27170800E+00, -.21851200E+01, 0.61515800E-01, 0.26402700E-01, 0.16724000E+00, 0.48191800E-01, 0.26603100E+00, -.24539400E-01, 0.17279300E+00, 0.89871900E-01, 0.30371900E+00, -.44607500E+00, -.57754400E+00, 0.14952300E-01, 0.15766600E+01, 0.28021700E-01, -.61868900E-02, -.59005000E-01, 0.87345700E-01, -.51551000E-01, -.29422300E+00, -.52898200E-01, -.22683300E+00, -.81340400E+00, 0.84237900E-02, 0.37692600E+00, 0.45087200E+00, -.16776900E+00, -.76934100E-02, 0.45864600E+00, -.11277600E+00, 0.20307400E+00, 0.12002800E+00, 0.51135900E+00, 0.12075400E+00, -.59738800E+00, 0.37846000E+00, -.50442500E-01, 0.90332900E-01, 0.21901000E-02, 0.45228900E+00, 0.81022100E-01, 0.49597600E+00, -.16074300E+01, 0.13169300E+00, 0.28155600E+00, -.79393000E+00, 0.41831800E+00, 0.40983300E-02, -.92661900E-01, 0.18356300E+00, -.51409200E-01, 0.17648200E+00, 0.26529500E+00, -.14571100E+00, 0.16129500E-01, 0.48404800E-01, -.71355600E-01, 0.29768700E+00, -.78230800E-03, -.40942400E+00, 0.13246400E-02, 0.53561800E-01, 0.21357600E+00, 0.11569400E+00, -.51598300E-01, 0.25338400E+00, 0.63803100E-02, -.36993600E-01, -.14489600E+01, 0.55663900E+00, -.32111000E+00, -.16516100E-01, 0.59155200E+00, 0.14059800E+00, 0.30194000E+00, 0.26497500E-03, -.27794000E+01, -.21838600E+00, -.77639900E-01, -.26715500E+00, -.40600400E+00, 0.58154300E+00, -.35696900E-01, -.22746700E+00, 0.40324100E-01, -.29833000E-01, 0.23348000E+00, 0.35992400E+00, 0.14664200E+00, -.27006500E+00, 0.31330600E+00, -.64441900E-01, 0.14654200E+00, -.17280300E+00, 0.16892300E+00, 0.16868000E-01, -.60643900E-01, -.57048800E-01, -.28399000E+01, 0.12554500E+00, 0.25010300E-01, 0.39916400E+00, -.82661700E-01, 0.20771900E+00, -.72618700E-02, -.15068300E+00, -.59570500E+00, 0.89887100E-02, -.14468800E+01, -.23519800E+00, -.27455500E+00, -.75194300E-01, -.96171400E-01, -.28167600E-02, -.20253800E+00, 0.87788700E-03, -.27080600E+00, 0.14369900E+00, -.59823500E-01, -.96161100E-01, -.15103700E+00, -.11460900E+01, 0.49137500E+00, 0.13541000E+00, -.65745900E-01, -.39386600E+00, 0.59919300E+00, 0.57451900E-01, -.16528700E+00, -.55885700E+00, 0.61247000E+00, 0.38122200E+00, -.56650800E-01, 0.83278200E-01, 0.13897300E+00, 0.57253100E-02, 0.23365500E-01, 0.21452000E-02, -.78875600E-01, -.97635500E-01, 0.16571300E+01, 0.17545300E+00, -.38500100E+00, 0.11256600E+01, -.21897900E-01, -.15805600E+00, -.73957000E-01, -.24489100E-01, 0.51650600E-02, 0.62627800E-01, 0.19962500E+00, -.85485900E-01, -.34637800E-01, 0.95481000E-01, -.71107300E-01, 0.76346900E-01, -.14465400E+00, 0.27708900E-01, 0.19111000E+00, -.72544600E-01, -.18619700E+00, -.14751000E+00, -.87792200E+00, -.29714200E-01, -.40868100E+00, 0.18085100E+00, 0.12799000E+00, 0.22201200E-01, 0.99996200E-02, -.27950400E+00, -.19523000E+00, -.24113600E+00, -.98427200E+00, 0.33744100E-01, 0.16817600E+00, 0.68919200E-01, 0.49892900E+00, 0.39994400E+00, 0.23789500E+00, 0.40399800E-01, 0.13527100E+00, -.19613700E-02, -.14601800E+00, -.53414800E+00, -.78105800E-01, 0.50381800E-01, 0.80222600E-02, -.14463500E+01, 0.67421300E+00, -.18583200E+00, -.43290900E-03, -.37963200E-01, -.66723700E-02, 0.25675000E+00, 0.10194800E+00, -.83146300E-01, -.26868700E+00, 0.16335400E-01, 0.30526300E+00, 0.24452400E-01, -.68478500E-01, -.57420900E-01, 0.13080100E+00, -.25584600E-01, 0.33215200E+00, 0.80216600E-01, 0.21335400E+00, -.89854300E+01, -.13714300E+02, 0.75463900E+01, 0.18001400E+01, -.14194700E+03, 0.76817100E+02, 0.11816600E+03, 0.71099600E+02, 0.15638200E+02, 0.20632000E+02, 0.29946700E+02, -.38537500E+02, 0.42841000E+01, 0.17608600E+02, -.48835800E+02, -.22870300E+03, 0.11162400E+03, 0.58015600E+02, 0.11430300E+03, 0.24063800E+02, 0.35905100E+02, 0.49027700E+02, -.27344900E+02, 0.54744700E+02, 0.25966500E+02, 0.60212900E+02, -.20378200E+02, 0.51373800E+01, 0.51979600E+02, 0.10146600E+02, 0.31399400E+02, 0.74006700E+02, -.94037300E+01, -.15781900E+02, -.22968200E+02, 0.56989000E+02, -.21507800E+02, 0.35346900E+02, -.21146000E+02, 0.79323300E+02, -.17865300E+02, 0.19633800E+02, 0.20732400E+02, -.46023200E+02, -.30728300E+02, -.54250900E+02, 0.23567800E+02, 0.21196700E+02, 0.26675900E+02, -.13506400E+02, -.40880000E+02, -.13221500E+02, -.30817900E+02, -.64866800E+02, 0.21648900E+02, 0.18397800E+02, 0.37891800E+02, -.57403800E+02, 0.21461300E+02, -.15929100E+01, -.22543100E+01, -.63848900E+00, -.16854700E+00, -.21264700E+00, -.10384500E+01, 0.38647600E+01, 0.18238000E+00, 0.69454800E+00, 0.65797700E+01, -.55157800E+01, 0.11969900E+02, -.16301400E-01, -.19804900E+01, -.72033000E+01, 0.69589300E+01, 0.10791000E+01, -.23512000E+01, -.77223800E+00, 0.80254800E+01, 0.10020500E+01, -.70944000E+01, 0.12396300E+02, 0.10099700E+02, -.21883300E+00, 0.56701500E+01 },
        { 0.11710100E+02, -.17390000E+00, -.43095400E+00, 0.21180600E+01, 0.12474200E+01, -.10179700E+01, -.14468500E+01, -.42225400E+00, 0.59572700E+01, 0.23247000E+00, 0.11877500E+00, 0.14681000E+01, -.88280100E-01, -.10843800E+00, 0.50192000E+00, -.39768900E+00, 0.15035300E+01, 0.11808900E+01, 0.23095700E+00, -.10537700E+01, 0.88943100E+00, -.12366400E+00, 0.11562400E+02, 0.15902100E+01, -.14580200E+00, -.29546900E+00, -.52491700E+00, -.20148800E+01, -.11884800E+01, 0.99331600E+00, -.84145500E+00, 0.15736300E+01, 0.80512100E-01, -.25717900E+01, 0.15421500E+01, 0.22497200E+00, 0.66375500E-01, 0.39293800E+00, 0.46228400E+00, -.55442000E+00, -.62594400E+00, -.81834000E+00, -.54931900E+00, -.30067100E-03, -.34765700E+00, 0.38569300E+00, -.24875700E-01, -.10943100E-01, 0.31147900E+00, -.30486900E+00, -.10373900E+01, -.16716600E+01, -.60849900E-01, -.42627800E+00, -.48543100E+00, -.70271000E+00, -.14713500E+00, 0.71871600E+00, -.28283200E+00, 0.14492800E+00, 0.57113000E-02, -.79785900E+00, 0.81685300E+00, -.43631100E-01, -.49900600E+00, 0.12447100E+00, 0.28566700E+00, -.80411800E-02, -.26797700E+00, 0.18650100E-02, -.63514900E-02, 0.24085800E+00, -.38885100E-01, 0.33028400E-02, -.24765400E+00, 0.18633800E+00, 0.46830200E+00, 0.71138600E+01, -.13670900E+01, -.34104500E-01, -.18182100E-01, -.39173000E+00, 0.34488600E+00, -.10876000E+00, -.37997400E+00, -.19914000E-01, 0.19899300E+00, 0.27066100E+00, 0.88240400E+00, 0.13260100E+01, 0.25089500E+00, 0.39918600E-02, 0.72032400E-01, -.55815600E-02, -.49248700E-01, -.75283100E-01, 0.11678900E+00, 0.16118000E-01, 0.10938700E+00, 0.18953300E+00, -.12804700E+00, -.54959400E+00, -.34085000E-01, 0.83310500E-01, -.10121000E+00, 0.51945600E-01, 0.10789100E+00, 0.24667200E+01, -.90275700E-01, 0.15581800E+00, 0.14030800E+01, -.36898300E-01, 0.15885000E+00, 0.26324800E-02, 0.28007800E-01, -.14519200E+00, -.26827600E-01, 0.45111100E+01, -.14922600E+00, 0.20984700E+01, 0.11925600E-01, 0.79094700E-01, -.27735100E-01, 0.78425500E-01, -.22552700E-01, -.13302600E+00, 0.28173600E-01, -.49817200E+00, 0.78498500E-01, -.31107300E+01, -.42374000E+00, 0.35023200E+00, 0.74588900E+00, -.65288900E-01, 0.11876100E+01, 0.95813900E+00, 0.26891300E+00, -.36172800E+00, -.12551000E+01, 0.15136500E+01, -.37486900E+00, 0.64716800E+00, 0.14587600E+00, -.35986800E+00, 0.16378800E-01, 0.99311100E-01, 0.26221000E-01, -.19044100E+01, -.27063200E+00, 0.20164200E+01, 0.36545800E+00, -.31250800E+00, 0.51220800E-01, 0.34695200E+00, -.15388000E+00, 0.29903800E-02, 0.13347600E+00, -.51827700E-02, -.11978300E+01, -.75955700E-02, 0.13083600E+00, -.50669200E+00, 0.23298900E+00, -.48825600E+00, 0.33430400E+00, 0.17453000E+00, -.76699900E-01, 0.12393800E+01, -.12450600E+00, -.15746100E+00, 0.30674300E+00, -.91662900E+00, -.96508700E-01, 0.31487200E+01, 0.12435900E+01, 0.65134100E+00, 0.11625800E+00, 0.10888600E+00, 0.66347700E+00, 0.89622000E-01, 0.45251300E+00, 0.14329000E+01, 0.65766400E+00, -.42703200E+00, 0.92881100E-01, -.11381100E+00, 0.57159000E-01, 0.12458100E+01, 0.19083400E-01, -.54972000E-01, 0.44816100E-02, -.76556500E-01, -.48140800E+00, -.29925200E+00, -.53000500E-01, -.68541400E-01, -.36814100E-01, -.36813800E-01, -.22084700E+00, -.73871500E-02, 0.36293500E+00, -.81731800E-02, 0.31586600E+00, -.48663000E+00, 0.63008300E-01, 0.99246800E-01, 0.53656200E-01, 0.59164900E+00, 0.13683600E+00, -.14498100E+00, -.46003900E-01, 0.23368200E+00, 0.40634900E-01, -.32651000E+00, -.48470900E-01, 0.69402200E+00, 0.17362600E+01, -.18278800E+02, -.59350300E+01, -.17008500E+02, 0.30140900E+03, -.15758400E+03, -.25716700E+03, -.15062400E+03, -.76488700E+02, -.70587300E+02, -.19840800E+02, 0.66614800E+02, -.12158800E+03, -.67213500E+02, 0.23827000E+03, 0.36000800E+03, -.17749000E+03, -.59140500E+02, -.18004800E+03, -.76271700E+02, -.72444900E+02, -.49416700E+02, 0.39337500E+02, -.18236600E+03, -.62511500E+02, 0.93730000E+01, 0.22244400E+03, -.11119200E+03, -.23301500E+03, -.11110600E+03, -.53000800E+02, -.83928200E+02, -.56649300E+02, -.18350800E+02, -.63572900E+02, -.59480700E+02, 0.22588100E+02, -.10699900E+03, 0.57295900E+02, -.15582800E+03, 0.53423600E+02, -.11761400E+02, -.15386800E+02, 0.61424400E+02, 0.32864800E+02, 0.97913000E+02, -.19137400E+02, -.10096300E+03, -.68991300E+02, 0.33559700E+02, 0.93388100E+02, 0.34485500E+02, 0.22579900E+02, 0.51039600E+02, 0.22183000E+01, 0.31537400E+02, 0.23624600E+02, 0.33512200E+02, -.19488500E+02, 0.26605500E+01, 0.36717100E+01, -.52914400E+00, 0.46695800E-01, 0.25836900E+01, -.14271200E+00, -.49343200E+01, -.65507300E+00, 0.55432400E+00, -.23698800E+02, 0.23145800E+02, -.19105000E+02, -.21992800E+01, -.27664000E-01, 0.73840500E+01, -.23841500E+02, -.15851400E+01, 0.28592900E+01, 0.23495300E+01, -.12485400E+02, -.31627000E+00, 0.12175100E+01, -.58423200E+01, -.25990600E+02, -.16410100E+01, -.22491300E+02 },
        { 0.14807600E+02, -.26656400E+00, -.57801400E+00, -.98241500E+00, 0.12240600E+01, -.22829800E+01, -.14779900E+01, -.20705000E+00, 0.21868600E+01, -.15334900E+01, -.12629500E+01, 0.10744700E+01, 0.25503000E+00, -.72965100E-01, 0.28326000E+00, -.38901500E+00, -.46383100E+00, -.23892000E+00, 0.79788700E+00, -.11084000E+01, -.15096400E+01, 0.77246800E-01, -.44557100E+01, -.32944300E-01, -.71512900E-02, -.14399000E+00, -.15853900E-01, -.71745000E+00, -.96277400E+00, 0.10403700E+01, 0.60018200E+00, 0.26922300E+01, 0.33787900E+00, -.23740400E+01, -.14236400E+00, 0.10028400E+01, 0.13443900E-01, 0.24833700E+01, -.91549600E+00, -.58891700E-01, 0.87246700E-01, 0.58222700E+00, 0.13733100E+01, -.12335700E+01, 0.90722800E+00, 0.21451700E+00, 0.21785700E+00, -.26668700E-01, 0.27581900E+00, -.15981000E+00, -.13900500E+00, -.21816200E+01, 0.46616900E+00, 0.19574600E+00, 0.12147800E+01, -.30426800E+00, -.43864300E-01, 0.17234900E+01, -.64160100E+00, 0.28442100E+00, 0.27447400E+00, -.45574400E+00, 0.10119300E+01, 0.22231100E+00, 0.10365900E+00, 0.21187800E+00, -.34996300E+01, -.10850500E-01, -.40127600E+00, -.90682600E-02, -.25603700E+00, 0.99483800E+00, 0.60527300E+00, -.52088300E-01, -.43938400E+00, 0.31689000E+00, -.47144700E+00, 0.47811200E+01, -.52482000E+00, -.40703300E+00, -.65889800E-01, 0.75331300E-01, -.99864500E+00, 0.51108100E+00, -.10160100E+01, -.84590200E+01, -.42153900E+00, -.11510900E+00, 0.50213900E+00, -.11254400E+01, -.20197300E+00, -.35443800E-01, 0.55787700E+00, 0.16149100E+00, -.67664000E-01, 0.23106900E+00, 0.27244200E+00, 0.82572700E-01, -.72347400E+00, 0.24226200E+00, -.19424100E-01, 0.19092700E+00, -.50902000E+00, -.47573700E+00, 0.33291600E-01, 0.29563000E+00, 0.98936400E-01, -.25459800E+01, -.17548100E+00, 0.44045100E-01, -.43807800E+00, -.86421900E-01, -.14646100E+00, 0.16119800E-01, -.40638900E+00, -.18908100E+00, -.15239500E-01, 0.90855600E+01, 0.31396700E+00, -.61831200E+00, -.37379000E+00, 0.95357800E-01, -.13816700E-01, 0.28544500E-01, 0.96041500E-02, -.19801900E+01, -.21227800E+00, 0.59617400E+00, 0.46667300E+00, -.20706600E+01, -.25915500E+01, 0.22077800E+00, -.22548200E+00, -.43442300E-01, -.37221300E+01, 0.21781800E+01, 0.75193100E-01, -.77970700E-01, -.38583100E+00, -.61956700E+00, 0.14427900E+00, 0.52186100E+00, 0.15766000E+00, -.14264500E+00, 0.10947800E-01, -.28039600E+00, -.33387100E-01, 0.12470600E+01, 0.69330700E-02, 0.24668500E-01, -.12574600E+00, 0.30602700E+00, -.70262200E+00, -.14997800E+00, -.65316100E-01, 0.60330300E-01, 0.22518300E-01, -.13302500E-01, 0.88700800E-01, 0.12620600E+00, 0.96971200E-01, -.14704000E-01, 0.15225900E+00, -.15459300E+00, 0.22835900E+00, -.15383800E+00, -.23653800E+00, -.46804100E+00, 0.57654000E-01, 0.25134900E+00, 0.79704600E-01, 0.20880100E+01, -.11087500E+00, 0.26666100E+00, -.37182900E+00, -.26233400E-01, 0.34774900E-01, 0.13193800E-01, 0.30329300E+00, -.11247500E+01, -.54118300E+00, 0.31089200E+01, -.61913900E-01, 0.54416700E+00, -.21571300E+00, 0.18782600E+01, 0.33666600E+00, 0.70420500E+00, -.53612700E-01, 0.92601500E-01, -.48845800E-02, 0.13106400E+00, 0.20427400E+01, 0.10004600E+01, 0.53761700E+00, 0.45428000E-01, 0.50346800E+00, 0.11072900E+01, -.14364500E+00, 0.25952000E-01, -.23404300E+00, -.13198900E-01, -.49067200E+00, -.10707400E+00, 0.96870300E-01, -.17164600E-02, -.15310700E-01, -.51131200E+00, 0.13427300E+00, -.14509400E+00, 0.35497900E-01, -.42541200E+00, -.10444200E+00, -.48736700E+00, 0.33560600E+00, 0.51045700E-03, -.21175800E+01, 0.99713300E+00, 0.23068100E+02, 0.14448300E+03, -.57154000E+03, 0.30359300E+03, 0.49262600E+03, 0.28598900E+03, 0.11373000E+03, 0.12288400E+03, 0.48924900E+02, -.12640200E+03, 0.18601300E+03, 0.10454000E+03, -.30980500E+03, -.90682400E+03, 0.44608600E+03, 0.20142400E+03, 0.45333400E+03, 0.16178100E+03, 0.17077400E+03, 0.14427300E+03, -.75541600E+02, 0.40259800E+03, 0.14156800E+03, 0.10669600E+03, -.35721400E+03, 0.17720400E+03, 0.34978500E+03, 0.17825900E+03, 0.12146600E+03, 0.21139000E+03, 0.46776300E+02, -.70383000E+02, 0.30712800E+02, 0.16857900E+03, -.71542000E+02, 0.25587700E+03, -.13860100E+03, 0.27893500E+03, -.12840700E+03, -.55289600E+01, 0.41503400E+02, -.18057400E+03, -.99290300E+02, -.21592100E+03, 0.41144500E+02, 0.30279100E+03, 0.15423300E+03, -.76205400E+02, -.16417200E+03, -.76769100E+02, -.86989200E+02, -.18088700E+03, 0.49875400E+02, 0.38496100E+02, 0.41798500E+02, -.15787200E+03, 0.10206600E+03, -.60698200E+01, -.10476200E+02, 0.12021500E+01, 0.50192800E+00, -.30017900E+01, -.22808900E+01, 0.52296200E+01, 0.10273000E+01, -.13661000E+01, 0.42596000E+02, -.39334300E+02, 0.38606800E+02, 0.34093000E+01, -.48679300E+01, -.17163100E+02, 0.43930800E+02, 0.45993900E+01, -.11222600E+02, -.31335400E+01, 0.31614800E+02, -.19119500E+01, -.54042000E+01, 0.20765700E+02, 0.54335500E+02, -.21658300E+01, 0.41543700E+02 },
        { -.62376900E+02, 0.13444000E+01, 0.25613100E+01, 0.28248400E+01, -.58540300E+01, 0.10128400E+02, 0.14464000E+01, 0.36989900E+00, -.30661700E+01, 0.77989000E+01, -.24487100E+00, -.81564600E+00, 0.19195200E+00, 0.43123200E+00, -.11404800E+01, 0.73103900E+00, 0.10686300E+01, -.18545900E+00, -.14903100E+01, 0.53316800E+01, 0.18909700E+01, 0.21084400E+00, 0.17929600E+02, -.80613300E+00, 0.99814400E+00, 0.17745500E+00, 0.56746200E+00, 0.63849600E+01, 0.55567000E+01, 0.13050500E+01, 0.23927300E+01, 0.28258600E+01, -.11780700E+00, 0.68183900E+01, -.73914300E+01, -.28627400E+01, -.30248400E+00, -.70683300E+01, 0.14613700E+01, -.65688600E+01, 0.45637000E+01, 0.69157900E+01, -.68980400E+00, -.83696100E+01, 0.79397800E+01, -.55619600E+00, 0.15578600E+01, 0.19122800E+00, -.27226800E+01, 0.87114000E+00, 0.23736500E+01, -.13592400E+01, 0.11031800E+01, 0.23964100E+01, -.22309900E+01, -.30112700E+01, 0.81981100E-01, 0.88910500E+00, -.10760600E+01, -.38417400E+00, -.21598200E+01, 0.29821300E+00, 0.16077300E+01, 0.31481300E+00, 0.26332600E+00, 0.57678600E+00, -.55885400E+00, 0.38654000E-01, 0.33451300E+01, 0.81389600E-02, -.17423800E-01, -.19842500E+00, 0.34028700E+00, 0.80676700E+00, -.34695600E+01, -.39787300E+01, -.27090500E+00, -.23415900E+01, -.28784600E+01, 0.24882100E+01, 0.25312200E+00, -.13728000E+01, 0.14916500E+01, -.17260300E+01, 0.38945000E+01, 0.35626500E+02, 0.16065200E+01, 0.59429800E+00, -.17968000E+01, 0.32440500E+01, 0.71256000E+00, 0.21043400E+00, -.87194800E+00, -.13574300E+01, 0.61968500E+00, -.20051400E+01, 0.92907100E-01, -.15967600E+01, 0.22754700E+01, 0.47298200E+00, 0.48244600E+00, -.15203800E+01, 0.27806700E+00, -.20308700E+01, 0.13477500E+00, 0.22738600E+00, 0.27380900E+00, 0.14936700E+02, -.69995600E+00, 0.36649000E+00, -.72232300E+00, 0.86659200E+00, -.30210300E+00, 0.31915400E-01, 0.17978000E+01, 0.74395800E+00, 0.41046200E+00, -.97526700E+01, 0.22624000E+01, -.29151100E+01, -.10413500E+00, -.58724000E+00, -.33502800E-01, 0.11972900E+01, -.19630900E-01, 0.20045800E+00, -.64455200E+00, -.20521900E+01, 0.56242600E+00, 0.26091000E+01, 0.19895700E+02, -.12881100E+01, -.16715500E+01, 0.39638000E+00, 0.11042200E+02, -.46059000E+00, -.86250300E+00, 0.57157700E+00, 0.49369800E+01, -.61741000E+01, -.10829600E+01, -.12166300E+01, -.54863400E+00, 0.50305600E+00, 0.10204200E-01, -.32656400E+00, -.65752400E-03, 0.80487400E+01, -.80549000E-01, -.64099200E+01, -.13135100E+01, -.15520200E+01, 0.36217300E+01, -.51045700E+00, 0.18982300E+00, 0.14451200E+01, 0.47100100E+00, -.81435800E-01, 0.51923500E+01, -.91589200E+00, -.28119300E+00, 0.13184100E+01, 0.38882900E+00, -.27954200E+01, 0.23552900E+00, 0.94973400E+00, -.15839800E+01, -.16723700E+00, 0.86605500E+00, 0.59062900E-01, -.12977900E+01, 0.70409300E+01, 0.19380200E+01, -.30204300E+01, 0.17728300E+00, 0.74642400E+00, -.38946400E+00, -.19566700E+00, -.23669100E+01, -.71225700E+01, -.12176100E+00, 0.42328000E+00, -.14246100E+01, 0.19267200E+01, -.63803800E+00, 0.55030400E+01, -.19241100E+00, 0.59969700E+00, -.27945600E+00, -.61438100E+00, -.17280600E-01, -.51938500E+00, 0.39471900E+01, -.24011800E+01, -.23244700E+00, -.37767700E+00, -.57916100E+01, 0.22879300E+01, -.14652700E+01, -.11529700E+00, -.13687400E+01, -.86650500E-01, 0.11111400E+01, -.15445400E+01, 0.47960100E+00, 0.97860800E-01, 0.60201700E+00, -.10879800E+01, 0.18588500E+01, -.64637700E+00, -.64843400E-01, -.15770800E+00, -.49411500E+00, 0.19443900E+01, 0.60481500E-01, -.90820100E+00, -.71950000E+01, 0.30039300E+01, 0.32093600E+01, -.32954200E+03, 0.33272600E+03, -.16008900E+03, -.14548700E+03, -.16544700E+03, -.10728200E+03, -.72402200E+02, 0.45534600E+02, 0.83098400E+02, -.34361300E+03, -.82959700E+02, -.26051300E+02, 0.17709900E+02, -.11652900E+02, -.14576100E+03, -.92297900E+01, -.98279900E+02, -.58351900E+02, 0.16338400E+03, -.84452400E+01, -.38659500E+03, -.99115700E+02, 0.20703200E+03, 0.76379200E+03, -.42448000E+03, -.37880500E+03, -.38134700E+03, 0.86117700E+01, 0.18067000E+03, -.17787800E+03, 0.15635500E+03, -.29274500E+03, 0.13394500E+03, -.12818200E+03, -.37802400E+03, 0.18773200E+03, 0.32986900E+03, 0.18800600E+03, 0.24589700E+03, 0.14144800E+03, 0.65863600E+01, -.27477900E+02, -.74894600E+01, 0.18342500E+03, -.40967500E+03, 0.33548800E+02, -.21161200E+02, -.19315500E+02, -.16403700E+02, -.92550100E+02, -.12505400E+03, -.12559500E+02, -.31133700E+02, 0.87399900E+02, -.10576700E+03, -.14707100E+02, 0.38282900E+01, 0.69884200E+00, -.87071100E+01, -.45103700E+01, 0.49932100E+01, -.19075100E+01, 0.63308500E+02, -.91448200E+00, 0.91378900E+01, -.69417000E+02, 0.67562500E+02, 0.59800700E+02, 0.20908700E+01, -.12195900E+02, -.77045400E+02, -.67763500E+02, -.19089700E+01, 0.78007200E+01, -.96129200E+01, -.25941400E+02, 0.14142100E+02, -.85255300E+02, 0.11590500E+03, -.63504100E+02, 0.17926500E+02, -.72970700E+02 },
        { -.24342600E+02, 0.71736400E+00, 0.87130500E+00, -.45785400E+01, -.31341200E+01, 0.72242200E+01, -.32692900E+01, 0.23412300E+01, -.18932300E+01, 0.65772500E+01, -.32745700E+00, -.33398400E+01, 0.40904000E+00, -.22757800E+00, -.28643400E+01, 0.11277600E+01, -.12065900E+01, -.11028000E+01, -.62742500E+00, 0.34401000E+01, 0.19457200E+01, 0.47939600E+00, -.32776600E+02, -.39056400E+01, -.33242700E-01, -.33384200E+00, 0.12813600E+01, -.31352000E-01, 0.14444200E+01, 0.26358800E+01, 0.96797400E+00, 0.31208400E+01, -.40657600E-01, -.10488900E+00, -.34606200E+01, -.38226300E+00, -.88710200E-01, -.17274200E+01, 0.13768800E+00, -.17276200E+01, 0.75885700E+00, -.11612700E+01, -.42311300E+00, 0.85832500E+00, -.16748000E+01, 0.88505800E-01, -.11769100E+01, 0.67558200E-01, -.13257400E+01, -.17229400E+00, -.48564900E+01, 0.10293900E+02, -.32536100E+00, -.21594500E+00, -.36713700E+01, -.85895200E+00, 0.13774900E+00, 0.37943000E+00, -.14885200E+01, 0.20778600E+00, -.20357400E+01, 0.54210900E+00, -.49511000E+00, 0.42449700E+00, -.70139800E+00, -.11733400E+01, 0.32324800E+01, 0.53799400E-01, 0.24010400E+01, 0.10034800E-01, 0.42996700E+00, -.77562500E+00, -.22969800E+00, 0.32248300E+00, 0.47970400E+01, -.18272700E+01, -.11585800E+01, -.16114300E+02, 0.89291300E+00, -.13592200E+00, 0.53033900E-01, -.43393100E+01, -.19859500E+01, 0.18403300E+01, 0.31221600E-01, 0.16028300E+02, 0.32230600E+00, -.53584400E+00, 0.80858800E-01, -.11775800E+01, 0.63957900E-01, 0.90516700E+00, 0.23056800E+01, -.89104400E+00, -.26405500E-01, -.16036800E+01, -.48232600E+00, -.79562600E+00, 0.42656500E+01, -.80508600E+00, 0.13083400E+00, -.13727400E+01, -.12244200E+01, -.25167200E+01, 0.39675000E+00, 0.16217600E+01, 0.98629400E+00, -.32303400E+01, -.36069600E+00, 0.17332000E+00, 0.19217200E+01, 0.17281300E+00, 0.66335900E+00, 0.92731600E-01, -.85933600E-01, -.76155800E+00, -.54910100E-01, -.16427200E+02, 0.43198200E+00, -.60327600E+01, 0.73828900E+00, -.46737500E+00, -.21908200E+00, -.16820100E+01, 0.37260100E+00, 0.32835900E+00, -.66588500E+00, -.38178900E+01, 0.29482700E+00, -.70853900E+01, 0.12743800E+02, -.38569500E-01, -.85247300E+00, -.38606000E-01, -.36374400E+00, 0.58906500E+01, 0.27806600E+00, -.56458900E+00, 0.26305000E+01, -.42144500E+00, -.18196800E+01, 0.18929500E+01, -.13078400E+00, -.23299300E+00, 0.11589700E+00, -.49578500E+00, 0.33420200E+00, 0.41577700E+00, -.24456200E+00, 0.97408600E+00, 0.49307200E+00, -.97637800E+00, 0.82298400E+00, -.40302200E+00, -.81958800E+00, 0.34699300E+00, -.43032400E+00, 0.75662400E+00, -.52095200E+01, -.13890500E+01, 0.30281700E+01, -.32886400E+00, 0.10248400E+01, -.10219300E+01, 0.29262100E-02, 0.16254500E+01, 0.28912000E+00, 0.17709600E+00, 0.28421200E+00, -.19459300E+01, -.57364800E+00, -.68430600E+01, -.92428100E+00, 0.12215600E+01, 0.15824200E+01, 0.59574500E+00, 0.71663500E-01, 0.10032200E+00, -.91180900E+00, -.19205700E+01, -.19774500E+01, 0.70348300E+01, 0.24446800E+00, 0.34994300E+00, -.21030200E+00, 0.27605000E+01, -.99418400E+00, -.12459100E+01, -.21402600E+00, -.63855000E+00, 0.65473700E-01, 0.36043700E+00, -.18984200E+01, 0.40575800E+01, 0.18533700E+01, 0.38327200E+00, 0.18640200E+02, -.51711800E+01, 0.44018000E+00, 0.10851900E+00, -.14027700E+01, -.69607900E-01, -.16192200E+01, -.13315300E+01, 0.12392900E+00, 0.29000600E+00, -.75816400E-01, -.17057900E+01, -.22594100E+01, -.74009800E-01, 0.33036700E+00, -.19569900E+01, -.51185400E-01, -.28028100E+00, 0.10210200E+00, -.27755600E+01, -.34978500E+01, 0.23970200E+01, 0.13198900E+01, 0.43386900E+00, -.12496100E+04, 0.63820100E+03, 0.79009500E+03, 0.62277000E+03, 0.79823100E+02, 0.31146500E+03, -.57649200E+02, -.42264300E+03, 0.43920200E+03, 0.32442500E+03, 0.41614100E+03, -.12406200E+04, 0.60053800E+03, 0.95756200E+03, 0.62280500E+03, 0.18108700E+03, 0.28569000E+03, 0.61325200E+02, -.23711100E+03, 0.63948900E+03, 0.30193300E+03, 0.24227600E+03, -.75105900E+03, 0.43562100E+03, 0.15184000E+03, 0.37652700E+03, -.42104300E+02, -.16449100E+03, 0.22048200E+03, 0.10863000E+03, 0.50825100E+03, -.19975600E+03, 0.28006000E+02, 0.69438200E+03, -.35687600E+03, -.38269200E+03, -.34520300E+03, -.86148600E+02, -.11556500E+03, -.22047700E+03, -.88437100E+01, -.18657100E+03, -.92274300E+02, 0.30681400E+03, -.20155900E+03, 0.90885000E+02, -.33602000E+02, 0.99222000E+02, 0.19755000E+02, -.91110800E+02, 0.25159100E+03, 0.11386400E+03, 0.35174700E+03, -.31394700E+02, -.13466600E+03, -.87952100E+01, -.88625600E+01, 0.13660000E+02, 0.49850700E+01, -.11920700E+02, 0.10961000E+02, -.42606600E+02, 0.14362200E+01, -.12112300E+02, 0.55340200E+02, -.47106000E+02, 0.83433200E+01, 0.75762600E+01, 0.16200900E+02, 0.27613500E+02, 0.43656600E+02, 0.13172800E+02, -.13789100E+02, 0.70339000E+01, 0.52917000E+02, -.83034300E+01, 0.58137100E+02, -.78494500E+02, 0.61422800E+02, -.12134300E+01, 0.20415100E+02 },
        { -.27765800E+02, 0.11852200E+01, 0.69075700E+00, 0.33029000E+00, -.24007700E+01, 0.64385100E+01, -.16707300E+01, 0.27455600E+01, -.66073000E+01, 0.53241700E+01, -.36182500E-01, -.11368900E+01, 0.36076100E+01, 0.69589000E-01, 0.78261900E+00, 0.58036400E-02, -.48200400E-02, 0.21189500E+00, -.10465000E+01, 0.10976300E+01, 0.19003900E+01, -.75119100E+00, 0.85174000E+01, 0.22437800E+01, -.15346600E+00, 0.96039000E-01, -.94255300E+00, 0.20814000E+01, 0.42839300E+01, -.22058900E+01, 0.19414900E+00, 0.31234700E+01, -.11682600E+00, 0.24656600E+01, -.15351300E+02, -.71952700E+00, -.30622400E+00, -.12290900E+02, 0.12401200E+01, -.15991200E+01, 0.92474400E+00, -.11892200E+01, 0.14418600E+01, -.50221100E+01, -.21826800E+00, -.33044100E+00, 0.69317700E+00, 0.81082600E-01, 0.78716300E+00, 0.77927300E+00, -.31500700E+01, -.11551200E+02, 0.15654300E+00, 0.22317300E+01, -.24681800E+01, -.20411500E+01, -.23522700E-02, -.13720800E+00, 0.20741100E+01, -.20546100E+00, -.80193100E+00, -.15153800E+01, 0.37320800E+00, 0.69597800E+00, -.39517800E+00, -.68930300E+00, 0.52143300E+01, -.67778200E-01, 0.53750800E+01, 0.17672700E-02, -.18633200E+00, 0.10959400E+01, 0.29255700E+00, 0.12279000E+01, -.66519300E+00, -.46307800E-01, 0.16973200E+01, 0.22479300E+02, -.95358300E+00, 0.36072700E+01, 0.23393000E+00, -.41375200E+01, 0.97307300E+00, -.91598300E+00, 0.57660100E+01, 0.26887100E+02, 0.22409800E+00, 0.11564200E+00, -.21876500E+01, 0.27640400E+00, -.11204900E+01, 0.14178300E+00, 0.54878900E+01, -.20697000E+01, -.18506700E+01, -.63150500E+00, 0.48639500E+00, -.51972700E+00, 0.87848900E+01, -.11611600E+01, -.23158200E+00, -.48969300E+01, 0.21500600E+01, -.59612400E+00, -.22914500E+00, -.32266400E+01, -.12775400E+00, 0.38452000E+01, 0.66457200E+00, -.22146200E+00, 0.94756900E+01, -.28702900E+00, 0.12585600E+01, -.53585900E-01, -.10273700E+01, 0.57157500E-01, 0.30166700E+00, -.80848200E+01, -.77174800E+00, 0.10225200E+02, -.94189200E+00, -.18041700E+00, -.20606800E+00, 0.23224300E+00, -.16703700E-01, -.30754000E+01, 0.24576500E+00, 0.31493600E+00, 0.88144900E-01, -.48389000E+01, 0.10441200E+02, 0.35456500E+00, -.12631000E+01, -.27968200E+00, 0.25343900E+01, 0.79254300E+00, -.45670400E+00, -.74830100E+00, -.78344500E+00, -.28516000E+00, 0.33204600E+01, -.18901700E+01, 0.34510600E-01, 0.17848800E+01, -.10289700E+00, 0.53415400E+00, -.73070000E-01, 0.45680900E+01, 0.10978400E+01, -.81342000E+00, -.66342500E+00, 0.28300300E+01, -.10530700E+01, 0.12158400E+01, 0.46204200E+00, -.24490300E+00, -.11550300E+01, 0.10205300E+00, -.68012500E+01, 0.13444200E+00, 0.41895600E+01, -.16015000E+01, -.56509700E+00, 0.18680000E+01, -.11945000E+00, -.13953300E+01, 0.51516400E+00, 0.11321400E+01, 0.25353100E+00, -.30473300E+00, -.88313900E+00, -.14508500E+02, 0.54189700E+00, -.52041600E+01, -.59473200E+00, -.40865800E+00, 0.78466400E+00, 0.42287300E+00, 0.34371400E-01, 0.16093300E+01, -.37480700E+00, -.24215300E+00, 0.55957200E+00, -.65724000E+00, 0.86127300E-01, -.24002000E+01, -.26002100E+00, -.14350400E+01, 0.40853200E+00, -.28934700E-01, -.32095500E-02, 0.97205500E-01, -.28384900E+01, -.13829000E+00, -.73928600E+00, -.22938700E+00, -.23550100E+01, 0.14878300E+00, 0.51256000E+00, -.42986200E+00, -.12715100E+01, 0.57370700E-01, 0.23862600E+00, 0.10610200E+00, -.35208200E+00, 0.32169100E+00, -.29193200E+00, 0.75542100E-01, -.15570700E+00, 0.30104300E+00, -.95165000E-01, 0.18334700E+00, 0.14739900E+00, 0.44370100E+00, -.23876000E+00, -.40769600E+00, -.10504400E+01, -.60938200E+00, -.21317500E+00, -.79668800E-01, 0.45815400E-01, 0.53939700E+02, -.20963700E+02, -.92425600E-01, 0.30046500E+02, -.31866600E+02, 0.14676600E+02, -.71182000E+01, -.58734900E+02, -.29281700E+02, -.23683600E+03, 0.14036500E+03, -.77161100E+02, -.15936100E+03, -.70219200E+02, -.18224800E+02, -.51624400E+02, 0.19700800E+02, 0.29292200E+02, -.95213500E+02, -.53438800E+02, -.93237100E+02, 0.98515900E+02, -.52951900E+02, -.43899100E+02, -.49268400E+02, 0.12169800E+02, 0.34045900E+02, -.85296600E+01, 0.52201800E+02, -.24811400E+02, 0.27818500E+02, -.49178900E+02, 0.26476700E+02, -.23382100E+02, -.41068600E+02, -.13039000E+02, 0.20510900E+02, -.55544800E+01, 0.11700100E+02, 0.77843300E+01, -.23847000E+02, -.18644400E+01, -.15032600E+03, 0.31047100E+02, -.14837700E+02, 0.30081100E+01, -.15620100E+02, -.32534100E+01, 0.88641800E+01, -.38944600E+02, -.65198000E+02, -.82879400E+02, 0.13053900E+02, 0.49712900E+01, 0.13396700E+01, 0.48870800E+00, -.12541700E+01, -.83167100E+00, 0.64501700E+00, -.10996200E+01, 0.34043700E+01, -.27342100E+00, 0.73876200E+00, -.46118200E+01, 0.32394200E+01, 0.13837800E+01, -.49104900E+00, -.14489800E+01, -.29442200E+01, -.35544400E+01, -.14808800E+01, 0.41349700E+00, -.65219700E+00, -.70288300E+01, 0.49340300E+00, -.81671500E+01, 0.12580400E+02, -.39190600E+01, 0.35122600E+01, -.16698200E+01 },
        { -.89565900E+00, -.21254300E-01, 0.12953500E-01, -.57090800E+00, -.36769600E-01, -.92283800E+00, 0.32859300E+00, 0.50234500E-01, -.22794400E+00, 0.35897700E-01, 0.46858100E-01, 0.10195700E+01, 0.64294600E-01, 0.21996400E-01, 0.19189100E-01, -.19747400E-01, 0.21868500E+00, 0.10822800E+00, 0.13326000E+00, -.15220900E+00, 0.26712400E-01, -.87594400E-01, 0.10245800E+01, 0.13717400E+00, -.11867700E-01, -.13113700E-01, -.23573500E-05, 0.53273500E-01, 0.13835600E+00, -.87262700E-01, -.15425600E-02, -.34575100E+00, -.13611000E-01, 0.45055300E-01, -.26320700E+00, -.24861000E-01, -.18144600E-01, -.43493800E-01, -.13269500E+00, -.56284200E-01, 0.17551800E+00, 0.37495300E+00, -.40837300E-01, -.37257200E+00, 0.26583500E+00, -.18214900E-01, 0.56992500E-01, -.29806400E-05, 0.37195900E-02, 0.95300400E-01, 0.27919600E+00, -.12589100E+01, 0.44453700E-01, 0.10823900E+00, -.75259600E+00, 0.11888200E+00, -.18308800E-01, -.72777400E-01, 0.97245700E-01, -.66989400E-01, 0.12079300E+00, 0.10162800E+00, -.89578300E-01, 0.99821400E-01, -.45171800E-01, 0.45194100E-01, 0.26209900E+00, 0.75714300E-02, 0.29812800E+00, 0.50938700E-03, 0.36601500E-01, 0.55455000E-01, 0.67035700E-01, 0.80406200E-01, -.47037000E-01, 0.23226400E+00, 0.13647000E+00, 0.21978000E+00, 0.14427800E+00, 0.54546200E+00, 0.31930200E-01, -.28340500E+00, 0.18656100E+00, -.35612900E+00, 0.57736700E+00, 0.25600400E+01, 0.40481200E-01, 0.47256400E-01, -.30621300E+00, 0.27967700E+00, -.30966500E-01, 0.13388200E-01, 0.30326300E+00, -.24930200E-01, -.95123500E-01, -.16170600E+00, 0.32882500E-01, 0.81660600E-01, 0.95528300E-01, 0.14748000E+00, -.13123100E-02, -.31890800E+00, 0.11578300E+00, 0.12464700E+00, 0.16213500E-01, -.10082600E+00, -.33749000E-01, 0.21392500E+00, 0.11106100E+00, -.32845600E-01, 0.41064200E+00, -.25115800E-01, 0.59858200E-02, -.63611200E-02, -.11440800E-01, -.88850300E-03, 0.32062000E-01, -.80255300E+00, -.18225300E+00, 0.59629100E+00, 0.30458600E-02, -.88922400E-03, 0.95196100E-02, 0.10106900E-01, -.94534500E-02, -.10580500E+00, 0.43501900E-01, -.44581100E+00, -.62478000E-01, -.25907700E+00, 0.86113900E+00, -.72203700E-01, 0.14650200E+00, -.19246000E-01, 0.15233100E+00, -.19918200E+00, -.30543900E-01, -.28971400E-01, -.60123700E+00, 0.19270700E+00, 0.29553900E+00, 0.12164500E+00, 0.44211100E-01, -.71795900E-01, -.27266000E-02, 0.12574000E+00, 0.93656100E-02, 0.19136100E+00, -.13614500E-01, -.48101400E+00, -.34583600E-01, -.28549000E+00, 0.67080600E+00, -.43368000E-01, 0.46331700E-02, 0.53845700E-02, -.12635100E-01, -.39959900E-02, 0.12999600E+00, -.70493500E-01, -.34186000E+00, 0.70083000E-01, -.63471800E-01, 0.93867300E-01, -.66786800E-01, -.18739600E-01, 0.29280700E-01, -.62227100E-02, 0.26299200E-01, 0.85734700E-02, 0.89544600E-02, 0.48206100E+00, 0.12795400E+00, -.37237900E+00, 0.89191200E-01, -.48630500E-02, 0.78628100E-03, -.49579900E-02, -.16903700E-01, 0.23738800E+00, 0.15091900E+00, -.62907700E+00, 0.52515500E-01, -.12624500E+00, 0.13815200E-01, -.28794500E-01, -.18003700E+00, -.23874600E+00, -.10823600E-01, -.75160400E-01, 0.71655500E-03, 0.18516400E-01, -.11325500E+00, -.63952800E-01, -.11815800E+00, -.18081700E-01, 0.18899900E+00, -.36770300E-01, -.33598100E-01, -.24270400E-02, 0.72886900E-01, 0.36343000E-02, -.39227400E-01, -.94047100E-01, 0.86327900E-02, 0.36734000E-01, 0.42560600E-02, -.11641500E+00, -.82686200E-02, 0.55017800E-02, 0.17246000E-01, -.11946300E+00, 0.86707800E-02, 0.32237500E-02, -.79151900E-03, -.15224400E+00, 0.11091200E+00, 0.48320800E-01, 0.10162100E+00, 0.46673100E-01, -.37950300E-01, -.37076900E-01, -.26176700E+02, -.26984700E+00, -.86205900E+01, 0.24935500E+01, -.13032000E+02, -.88799500E+01, 0.18465400E+02, 0.71335900E+01, 0.64205400E+02, 0.51017500E+02, -.25679700E+02, 0.25833300E+02, -.25336200E+02, -.48396300E+01, -.57853900E+01, -.22263800E+02, -.33423900E+01, 0.34848500E+01, 0.17188300E+01, -.17158200E+02, -.49325400E+02, 0.30479600E+02, -.94372700E+01, 0.24709300E+02, -.17274400E+02, -.46087900E+02, 0.18461000E+02, 0.80867500E+01, 0.46746400E+02, -.39848100E+02, 0.29123100E+02, 0.13592800E+02, -.65388600E+01, -.65109500E+02, -.64331500E+01, -.15587300E+02, -.15496500E+02, 0.84089500E+01, 0.11501800E+02, 0.23219200E+02, -.17629100E+02, 0.19751700E+02, -.28238500E+02, 0.13477800E+02, 0.16777800E+02, 0.13904500E+02, 0.16054500E+02, 0.22923600E+02, 0.10917300E+02, 0.10008800E+01, -.15276400E+01, 0.22310300E+02, -.25101000E+02, -.39244200E-01, 0.73081900E+00, 0.12527000E+01, 0.46164500E+00, -.67807000E+00, 0.14635900E+01, -.66349400E+01, 0.11010900E-01, -.12463600E+01, 0.25562000E+01, -.27023300E+01, -.78569800E+01, 0.22131200E+00, 0.27049200E+01, 0.82632700E+01, 0.17428300E+01, 0.37691000E+00, -.62973800E-01, 0.89528400E+00, 0.73901300E-01, -.77719000E+00, 0.90698600E+01, -.13579100E+02, 0.85480900E+00, -.43343100E+00, 0.19676500E+01 },
        { -.27411900E+02, 0.82579100E+00, 0.94391600E+00, -.52789200E+01, -.32638900E+01, 0.74884300E+01, -.30659300E+01, 0.28110700E+01, -.49741900E+01, 0.66385500E+01, -.31221500E+00, -.29999400E+01, 0.33838400E+00, -.32556600E+00, -.22257900E+01, 0.10370400E+01, -.16132200E+01, -.12376300E+01, -.61410800E+00, 0.40733600E+01, 0.28690200E+01, 0.20017100E+00, -.30378400E+02, -.36593700E+01, -.27313000E-01, -.56030700E+00, 0.10507500E+01, -.32973300E-01, 0.34755400E+01, 0.63251500E+00, 0.13529400E+01, 0.53695500E+01, -.18590400E+00, -.27180400E-01, -.32990300E+01, -.79149300E+00, -.46219600E+00, -.74026000E+01, 0.42551100E+00, -.16048100E+01, 0.74295200E+00, 0.68825500E+00, 0.15184500E+01, -.34780500E+01, -.10881500E+01, 0.19879900E+00, -.62522300E+00, 0.12731200E+00, 0.78953800E+00, 0.39590200E+00, -.52738300E+01, -.35233800E+01, -.40619900E+00, 0.67339400E+00, -.34621800E+01, -.11243400E+01, -.21385700E+00, 0.26254600E+00, 0.23154800E+01, -.26031000E+00, -.23554800E-02, -.33349200E+00, -.14705800E+01, 0.98192400E+00, -.40054600E+00, -.12746500E+01, 0.39990500E+01, 0.25051100E-01, 0.47466500E+01, -.59730000E-02, 0.32964400E+00, -.14253700E+00, 0.33163100E+00, 0.70777100E+00, 0.12853100E+01, -.68226600E+00, 0.12700200E+01, -.70321400E+00, 0.12726400E+01, 0.16135900E+01, 0.23061100E+00, -.48901600E+01, -.31564400E+00, 0.15390300E+01, 0.18732400E+01, 0.37312300E+01, -.51994700E+00, -.32838800E+00, 0.24293100E+00, -.19248500E+01, -.45764600E+00, 0.21796400E+00, 0.47143400E+01, -.60329100E+00, -.12572500E+01, 0.56745800E+00, -.22518700E+00, -.12456900E+01, 0.39846500E+01, -.72070800E+00, -.26100700E+00, -.32067900E+01, 0.24125200E+01, 0.98363200E+00, -.46996700E+00, -.13926900E+01, -.51174000E+00, -.27710800E+01, 0.80990800E+00, -.33509400E+00, 0.81802100E+01, -.22060900E+00, 0.11913500E+01, -.57711600E-01, -.18929600E+01, 0.37917200E+00, 0.15677000E+00, -.25836000E+01, -.10341800E+00, 0.56481800E+01, -.57897000E+00, -.84516900E-01, 0.81512600E-02, -.12280200E+00, -.10953300E+00, -.10927800E+01, 0.29601400E+00, -.17464600E+00, -.34275700E+00, -.16746000E+01, 0.30715700E+00, 0.65279800E+00, 0.17375300E-01, -.13656300E+00, -.57221200E+01, 0.15403300E+01, 0.79338100E-01, -.72340100E+00, -.21086100E+01, 0.14058000E+01, 0.14519500E+01, -.11814200E+01, 0.10735900E+00, 0.39602500E+00, 0.52696300E-01, 0.45541900E+00, 0.16217100E+00, -.29002400E+00, 0.46768100E+00, 0.40821300E+01, 0.70091400E+00, 0.15787200E+01, 0.77304800E-01, 0.10893800E+01, 0.39559700E+00, -.48055000E+00, -.44935200E+00, -.19778400E-01, -.39431000E+01, 0.13177300E+00, 0.11256500E+01, -.81551800E+00, 0.17320800E-02, 0.94971200E+00, -.31656100E-01, -.14606900E+01, 0.44646000E+00, -.15486200E+00, -.46147400E-01, -.48062300E-01, -.32604500E+00, -.10993300E+02, -.92440300E-01, -.12265400E+01, -.97376400E+00, -.19223700E+00, 0.55522800E+00, 0.12622700E+00, -.47057800E-01, 0.56796900E+00, -.59534500E+00, 0.60988900E+01, 0.57379000E+00, 0.24634500E+00, 0.33778000E+00, -.15290200E+01, -.33434100E+00, -.48678800E-02, 0.35249200E-01, -.61692300E-01, 0.26981700E-01, -.18992300E+00, -.27423700E+01, -.35943900E+00, -.31313600E+00, 0.28706300E-01, 0.69599100E-02, -.52293000E+00, 0.51222700E+00, -.24473200E-03, -.79956600E+00, 0.34868800E-01, 0.39809100E-01, 0.87464500E+00, -.36692200E+00, -.34594500E-01, -.72507600E-01, -.32589700E+00, -.50409600E+00, 0.28031100E+00, 0.35703500E-01, -.33864200E-01, 0.32887200E-01, 0.10080000E+00, -.31959000E+00, -.76226200E+00, 0.69006900E-01, -.99249200E+00, -.73326200E+00, -.22752700E+00, 0.17368300E+00, -.17855600E-01, 0.10899500E+01, 0.38138700E+01, 0.38116100E+02, -.40473200E+02, 0.48634000E+02, 0.99408700E+01, -.74041900E+02, -.45857400E+02, -.29427300E+03, 0.94851800E+02, -.44483300E+02, -.18886300E+03, -.48073500E+02, -.10639200E+02, -.46251100E+02, 0.42733500E+02, 0.36485700E+02, -.99706300E+02, -.59160300E+02, -.74145900E+02, 0.62082900E+02, -.41991300E+02, 0.96551500E+01, -.31127200E+02, 0.38504000E+02, 0.97412400E+02, -.22005000E+02, 0.23905500E+02, -.39982800E+02, 0.80549900E+02, -.18407000E+02, -.96812200E+01, 0.74171700E+01, 0.26954300E+02, 0.38758900E+01, 0.27269100E+02, 0.25278400E+02, -.10097700E+02, -.28554300E+02, -.50628000E+02, 0.26964300E+02, -.16942600E+03, 0.42223300E+02, -.17858600E+02, -.11222000E+02, -.20584400E+02, -.16497300E+02, -.19768300E+02, -.40581700E+02, -.62832900E+02, -.90222800E+02, -.13489100E+02, 0.24071200E+02, 0.78178200E-01, 0.12912900E+00, -.42570200E+01, -.12970600E+01, 0.20889600E+01, -.39049400E+01, 0.93990900E+01, -.13468600E+00, 0.37195800E+01, -.33882000E+01, 0.28544600E+01, 0.63562900E+01, -.31378700E+01, -.48745500E+01, -.84979000E+01, -.17792800E+01, -.22340800E+01, 0.18757100E+00, -.31262300E+01, -.57392600E+00, 0.27445000E+01, -.16564600E+02, 0.25837800E+02, -.75779800E+00, -.28782800E+01, 0.25138600E+01 },
        { -.74381400E+01, 0.20034900E+00, 0.25343400E+00, -.25617000E+00, -.64272700E+00, 0.15035300E+01, -.49588700E+00, 0.74074300E+00, -.74517100E+00, 0.12906800E+01, 0.19992500E-01, -.70545100E+00, 0.14308500E-01, -.48617000E-02, -.33385700E+00, 0.18883300E+00, -.11593900E-01, 0.10800400E-01, -.21260300E+00, 0.29019000E+00, 0.39105000E+00, -.22924200E+00, 0.45331900E+00, 0.64829900E+00, 0.43335400E-01, 0.11508500E+00, -.24087700E+00, 0.93487600E+00, 0.11499600E+01, -.21802900E+00, 0.36905500E+00, -.77414400E-02, -.51257200E-01, 0.50683900E+00, -.30263700E+01, -.93538300E-01, 0.80020000E-01, -.13984800E+01, 0.22091000E+00, -.48105200E+00, 0.34688000E+00, -.27148700E+00, -.14445900E+00, -.35661300E+00, 0.37381400E+00, -.15116900E+00, 0.15350300E+00, -.14957400E-01, -.29311000E+00, 0.11959200E+00, -.39661400E+00, -.18479400E+01, 0.38379000E-01, -.62960900E-02, 0.12375100E+01, -.54139400E+00, 0.13639200E-01, -.68318400E+00, -.16163600E+00, 0.31502200E-01, -.66767100E-01, -.16885000E+00, -.31501600E+00, 0.98125200E-01, 0.13342500E+00, 0.28852800E-01, -.14003600E-01, 0.15646300E-01, 0.31493300E+00, -.13613100E-02, -.72857200E-02, 0.14758300E+00, 0.14814900E+00, 0.65966300E-01, -.48636500E-01, -.26151300E+00, 0.49737500E-01, -.48997500E+00, -.76492500E+00, 0.65373700E+00, 0.20513500E-01, -.22010400E-01, 0.29022500E+00, -.25607600E+00, 0.96013400E+00, 0.18949500E+01, 0.36893600E+00, 0.12005300E+00, -.37720200E-01, 0.52703900E+00, -.18705600E+00, -.11377700E-01, 0.10611400E+01, -.72317700E-01, 0.97437300E-01, 0.28001000E-01, 0.33194700E+00, 0.18797200E-01, 0.37249600E-01, -.58038600E-01, -.23669100E-01, -.42025300E+00, -.18602200E-01, -.30193300E-02, 0.14674200E+00, -.14155300E-01, 0.80885000E-01, 0.20352100E+01, 0.13512400E+00, -.30647400E-01, -.84207900E+00, 0.24523600E-01, -.16800400E-03, 0.34791000E-02, 0.42400100E+00, 0.22978100E+00, 0.28501000E-01, -.22906800E+01, -.11748900E+00, -.28890200E+00, -.19110800E-01, 0.43398200E-03, 0.17548300E-01, 0.31702300E+00, 0.72273500E-02, -.56461000E-01, 0.14935400E-01, -.21038200E+00, 0.76922400E-01, 0.18043700E+01, 0.40864600E+00, -.17821900E-01, 0.73060700E-02, 0.13585600E-01, 0.34217500E+00, -.40383600E+00, -.64273500E-01, 0.53857000E-01, -.29153300E+00, -.93316200E-01, 0.17234900E+00, -.23204000E+00, 0.84946600E-02, -.88346900E-01, -.98685900E-03, 0.28978000E-01, -.90788200E-02, 0.22357600E+00, 0.85269700E-01, -.87838500E+00, -.15617600E+00, 0.68308500E-01, 0.28036400E+00, 0.49701200E-01, 0.18056400E+00, 0.56720100E-01, 0.46550700E-01, -.20934100E-01, -.60743000E-01, 0.18026000E+00, 0.19321200E+00, -.42142000E-01, 0.53731700E-01, -.44104800E+00, 0.19527200E-01, -.75054600E-02, -.90486000E-01, -.17652000E-01, 0.26235300E-01, 0.33120400E+00, 0.13228100E-01, 0.13320900E+01, 0.20198500E+00, 0.13959500E+00, -.13025400E+00, -.13410100E+00, -.65212900E-01, 0.31824100E-01, 0.22619300E+00, 0.81525600E-01, 0.30628900E+00, -.68439500E+00, -.70352400E-01, -.14980000E-01, 0.10727400E+00, 0.68962000E-01, 0.58184200E-01, 0.76572200E-01, -.46618300E-02, 0.17397400E-01, 0.27358700E-02, -.18566000E-01, -.40420100E+00, -.81327600E-01, -.41739700E-01, -.62093000E-01, 0.58605300E-01, -.31214900E-01, -.14153000E+00, 0.36660300E-02, 0.17549600E+00, 0.25951200E+00, 0.81540200E-01, 0.27442200E+00, 0.32559600E-01, -.78970000E-01, -.11129200E+00, 0.60649200E+00, -.91732900E+00, -.13937300E-01, 0.45675800E-01, 0.48101900E+00, 0.15227000E+00, -.45603100E+00, -.14728100E+00, 0.62835300E+00, 0.12443900E+01, -.21178900E+00, -.29698800E+00, -.47984600E-01, -.15045100E+00, -.43127000E-01, 0.66505500E+00, -.42878100E-01, -.30909000E+02, 0.16342000E+01, 0.45277800E+01, -.26135300E+02, -.55605400E+02, 0.47367300E+01, -.84398600E+02, -.35542400E+02, 0.17450900E+02, -.10257300E+02, 0.17999600E+02, -.65534500E+01, 0.13852100E+02, 0.90746300E+01, -.95387100E+01, -.38032200E+02, 0.81221500E+01, 0.25884500E+02, -.42895000E+01, 0.12797500E+01, 0.10618300E+03, 0.22673800E+01, 0.45275800E+01, 0.23908700E+02, -.37537000E+02, -.42439300E+02, 0.91117100E+01, 0.14519700E+02, -.51062900E+01, 0.11988000E+03, -.60924300E+02, -.11236200E+03, -.59840300E+02, 0.31910300E+02, -.19321200E+02, -.24332400E+02, -.33479100E+01, -.53685900E+02, -.56150200E+00, -.16264200E+03, -.32864800E+02, 0.15330700E+02, -.79665300E+02, 0.16328600E+02, -.20519000E+02, -.62773300E+02, 0.80149700E+02, 0.53192900E+02, 0.63340000E+02, -.50156300E+02, -.87942500E+01, -.15052700E+01, 0.47090400E+00, 0.82486900E-01, -.22639800E+00, 0.19940200E-01, -.63860600E+00, 0.11367000E+02, 0.44094800E+00, -.29856900E+00, 0.14811900E+02, -.15136200E+02, 0.96742200E+01, -.15395800E+01, -.19013900E+01, -.11755800E+02, 0.14814000E+02, 0.11024700E+01, -.30482700E+01, -.11088000E+01, 0.10063800E+02, 0.64617200E+00, -.13405000E+02, 0.14671600E+02, 0.23140500E+02, 0.71570700E+01, 0.15624100E+02 },
        { 0.42853100E+01, -.16241400E+00, -.11384900E+00, -.11997200E+01, 0.70353800E+00, -.12204700E+01, 0.45280400E+00, -.52646500E+00, 0.94512100E+00, -.10384800E+01, -.27076000E-01, 0.15753300E+00, 0.13163100E+00, 0.10404200E+00, -.48721800E+00, -.11205800E+00, 0.15376800E-01, -.11568800E+00, -.53276500E-01, -.69583100E+00, -.39195600E+00, -.11091800E+00, 0.41701300E+01, -.11952400E+00, -.31550200E+00, -.67461900E-01, 0.22504700E+00, -.88910700E+00, -.15606500E+01, -.66951300E+00, -.53450500E+00, -.64868200E-01, 0.10344800E+00, -.56065000E+00, 0.23181600E+01, 0.29879800E+00, -.95404300E-01, 0.17413600E+01, -.29232300E+00, 0.83723600E+00, -.41906000E-02, -.15643000E+01, 0.31002000E+00, 0.13782400E+01, -.19686400E+00, -.38334000E-01, -.22216800E+00, 0.10423100E-01, 0.18855400E+00, -.75201200E-01, 0.13941800E+01, -.21886900E+01, -.62444000E-01, 0.13011300E+00, 0.31411000E+01, 0.10308300E-01, 0.10607500E-02, -.94761600E+00, 0.17411600E+00, -.17087900E+00, 0.61575000E+00, 0.68362700E+00, -.52656000E+00, 0.13656000E+00, 0.35961000E+00, 0.13800700E+00, 0.81231500E+00, 0.14374300E-01, 0.13900500E+01, 0.49279400E-03, -.10271400E+00, -.56809400E+00, -.21273500E+00, 0.14765500E+00, -.12396100E+01, -.49457800E+00, -.56008300E+00, -.45040700E+01, -.46243800E+00, 0.75916000E-01, -.11924100E-02, -.15174600E+00, -.47141800E+00, 0.24447200E+00, 0.17689600E+00, 0.17467900E+01, 0.25554200E+00, -.86845100E-01, -.11596000E+00, -.29100300E+00, -.31046900E+00, -.16711400E-01, 0.10487600E+01, -.12954200E+00, 0.44662900E-01, 0.30340300E+00, 0.65225800E-01, -.26450100E+00, 0.14709600E+00, -.86390100E-01, -.10380200E-02, -.22278400E+00, 0.11249900E+00, -.34015000E-01, -.16831800E-01, 0.10178400E+00, 0.23977200E-01, -.15590400E+01, -.22624200E-01, -.19836800E-01, -.17382700E+00, -.52500900E-01, 0.12761800E+00, 0.87601000E-02, -.57316000E-02, -.75012100E-01, 0.49572600E-01, 0.39041900E+00, 0.12140400E+00, -.11743900E+01, 0.14570000E+00, 0.11234900E+00, -.40360700E-01, -.14826300E+00, 0.14188100E-01, 0.21156600E-01, -.68768100E-01, 0.22378200E+00, 0.61869800E-01, -.66395100E+00, 0.13514100E+01, -.13755200E+00, -.55798300E-01, 0.26868900E-01, -.46500600E+00, 0.24949200E+00, -.23605000E-01, 0.58856400E-01, 0.61233200E+00, -.40318500E+00, 0.20925400E-01, -.28072400E+00, -.67922200E-01, 0.35131200E+00, 0.62048000E-02, -.20987600E-02, -.20892400E-01, 0.63909600E+00, -.10384400E+00, 0.53770900E+00, 0.23693000E-01, 0.14850700E+00, -.45401800E+00, -.74545400E-02, 0.20782100E-01, 0.74615900E-01, -.73324900E-01, 0.22282600E-01, -.10729700E+00, -.77213200E-01, 0.36303000E+00, -.71882200E-01, -.71561800E-01, 0.13722500E+00, 0.31508800E-01, 0.26388400E+00, 0.84258900E-03, 0.81766000E-01, 0.57941400E-01, -.18800800E+00, -.39764400E+00, -.16755400E+01, -.14497800E-01, -.97813200E+00, 0.16918700E+00, 0.61178600E-01, 0.75207000E-01, 0.17001300E-01, -.27778600E+00, -.28960900E+00, -.10774300E+00, -.15485100E+01, -.11956000E-01, -.21145300E+00, -.16695100E-01, 0.48891700E+00, 0.23338400E+00, -.16086100E+00, 0.41489300E-01, 0.51520500E-01, -.51269400E-02, 0.86461600E-01, -.17463900E+00, 0.55925500E+00, 0.15920500E+00, -.46792200E-01, -.51397600E-01, -.15379700E+00, -.26279000E+00, 0.11253700E-01, 0.18361900E-01, 0.47440800E-02, 0.13616800E+00, -.23605000E+00, -.19619200E-01, -.76340900E-01, -.15424000E-01, 0.40865400E+00, 0.52945700E-01, 0.42157700E-01, -.24768700E-01, -.95497200E-02, 0.72178900E-01, 0.13331200E+00, -.55924600E-01, 0.78949600E-01, 0.22236600E+00, -.48682300E-01, -.64334200E-01, -.31292000E-01, -.13461800E-01, 0.75173000E-01, -.23797800E+00, -.54816300E-01, 0.10515900E+00, 0.16624200E+02, -.28630100E+02, -.10789100E+02, 0.14155100E+02, 0.16804400E+02, 0.81867000E+02, -.32644500E+02, 0.11907500E+02, 0.46729600E+02, 0.16387200E+02, 0.50088700E+01, 0.12088800E+02, 0.29504900E+01, -.11952600E+02, 0.18429500E+02, 0.15688000E+02, -.22062600E+01, 0.34437700E+02, -.14376300E+02, -.54914700E+02, -.17168500E+02, -.55841200E+01, -.41113300E+01, 0.51784500E+01, 0.35599200E+02, -.38219400E+00, -.84714600E+01, 0.57749900E+01, -.78771600E+00, -.13227600E+01, 0.15923500E+02, 0.60021100E+00, 0.10640800E+02, 0.49012100E+01, -.17180300E+02, 0.76352500E+01, 0.32417400E+00, 0.58264800E+01, 0.32986900E+02, -.15645600E+02, 0.53713000E+01, 0.10711900E+02, 0.77624500E+01, -.41729400E+01, -.11604300E+02, 0.13234700E+02, -.19830700E+01, 0.28098900E+02, -.99697700E+01, -.20056700E+02, 0.51224800E+00, -.97027300E+00, 0.84717300E+00, 0.21569200E+00, -.14884500E+00, 0.14309600E+01, 0.23349100E+01, -.94143200E-01, -.10000500E+01, -.81596200E+01, 0.81064300E+01, 0.13067000E+02, 0.27591300E+01, 0.96320700E+00, -.53735200E+01, -.85315900E+01, 0.11874800E+01, 0.28394400E+00, 0.80968300E+00, -.21041700E+01, -.83401800E+00, -.13959500E+01, -.31609100E+00, -.11495900E+02, 0.32253200E+01, -.10962300E+02 },
        { 0.76175800E+01, -.18735200E+00, -.26899100E+00, -.39357200E+00, 0.83700300E+00, -.13826900E+01, 0.29522100E+00, -.66524600E+00, 0.96982300E+00, -.10289200E+01, 0.23114800E-02, 0.52642100E+00, 0.44727000E-01, 0.99973400E-02, 0.19605500E+00, -.13749700E+00, -.17869700E-01, 0.61452000E-01, 0.32068200E+00, -.57832500E+00, -.44848700E+00, 0.88903500E-01, 0.10484600E+01, 0.51653300E-01, 0.96078600E-02, -.64807400E-01, 0.11792500E-01, -.71174000E+00, -.87457100E+00, 0.54514700E-01, -.35460700E+00, -.75398700E+00, 0.42614200E-01, -.48934300E+00, 0.15709300E+01, 0.21952400E+00, 0.50807000E-01, 0.14676900E+01, -.16847200E+00, 0.46025900E+00, -.26339700E+00, -.32431600E+00, -.38311300E-02, 0.57344900E+00, -.24320000E+00, 0.86527600E-01, -.10399800E-01, -.93525300E-02, 0.25824700E+00, -.71785700E-01, 0.44018300E+00, -.17165000E-01, -.22370700E-01, -.72113000E-01, 0.59393500E+00, 0.25022000E+00, -.58809200E-02, -.27330300E-01, -.16833600E+00, 0.89046400E-01, 0.18360300E+00, -.73992600E-03, 0.54489000E-01, -.59755300E-01, -.27273700E-01, 0.19875600E-01, -.33621200E+00, 0.16281300E-01, -.39604000E+00, 0.25206900E+00, -.35811100E-01, 0.25342000E-01, -.58269900E-02, -.72496400E-01, 0.19160800E+00, 0.94443600E-01, 0.11523500E+00, -.26820000E+00, 0.85381900E-01, 0.33113400E-01, -.15314700E-01, 0.11224000E+00, -.39717700E+00, -.11777100E-01, -.37720800E+00, -.41823800E+01, -.42432000E-01, -.61735700E-01, 0.16316800E+00, -.20954300E+00, 0.15668800E+00, -.13394000E-01, -.30175700E+00, 0.10499100E+00, -.92772100E-01, 0.35466400E+00, -.12982100E+00, 0.85738900E-01, -.99430800E-01, -.79787500E-01, -.54893700E-02, 0.35164900E+00, -.59917100E-01, 0.27119600E-01, -.54106100E-01, 0.62967600E-01, -.55003500E-01, -.16455600E+01, -.50512200E-02, -.71453500E-02, 0.76316000E+00, -.25892300E-01, 0.66543800E-01, -.36705100E-02, -.42275100E+00, 0.11219300E+00, -.72427400E-01, 0.11126400E+01, -.15517200E+00, -.26194000E+00, 0.84190800E-01, -.37329600E-01, -.21348800E-01, -.50487300E+00, -.59446900E-02, 0.39476700E+00, 0.17162600E-01, -.10817000E+00, -.14922100E+00, -.11425600E+01, -.16279400E+01, 0.10475600E+00, 0.33552100E+00, -.58628600E-02, -.12282200E+01, -.37637600E-01, 0.97030900E-01, 0.10327400E+00, -.33730400E-01, 0.11571400E+00, 0.23129400E-01, 0.99194200E-01, 0.33495300E-01, -.15601100E+00, 0.66475000E-02, 0.43036300E-01, 0.52331000E-02, -.41744900E+00, -.12053600E+00, 0.31916800E+00, 0.10502600E+00, -.12961500E+00, -.71467500E-01, -.12739700E+00, -.93597900E-01, -.11676400E-01, -.38001800E-01, 0.10634400E-01, 0.35396800E+00, 0.79675000E-01, -.36694400E+00, 0.14517200E+00, -.22616600E-01, 0.50983300E-01, -.66968800E-01, -.99003900E-01, 0.52051000E-01, -.20060200E+00, -.52581900E-02, -.10689700E-01, -.15659300E+00, 0.85774600E+00, 0.19292300E+00, -.13761000E+01, 0.11297600E+00, -.26216800E-01, -.31169500E-02, -.93751200E-02, -.78884900E-01, 0.59131000E+00, 0.63239800E-01, -.21129200E+01, 0.87534600E-01, -.25904000E+00, -.49713700E-01, 0.93467500E-02, -.98050900E-02, -.96753900E-01, -.17347500E-01, -.32649200E-01, -.28438500E-02, 0.16875600E-02, 0.49160800E+00, -.14139600E+00, -.23004200E+00, -.54580400E-02, -.22296200E+01, 0.63234000E+00, -.30309400E+00, -.16580200E-01, -.62896500E+00, 0.13119600E-01, 0.64135100E+00, -.42169000E-01, 0.81350200E-01, -.20496700E+00, 0.49445300E-01, -.34571200E-01, -.50299100E-01, -.11311000E+00, -.80813000E-02, -.43155400E-01, 0.18209800E-01, 0.12181800E+00, 0.71802100E-01, 0.16222300E+00, -.11125700E+00, 0.39687200E+00, 0.23482400E+00, 0.49817500E-01, 0.60804300E-01, 0.29535300E-01, 0.19755300E+00, 0.10527100E-01, -.14830000E-02, 0.65311900E+00, 0.25098200E+02, 0.15564900E+02, -.29299700E+02, -.11089600E+01, -.10866100E+03, 0.73327500E+02, -.34192100E+02, -.58870400E+02, -.36822000E+02, -.18290900E+02, -.10627300E+02, -.14346700E+01, 0.18710900E+02, -.55634900E+02, -.16907300E+02, -.37525000E+02, 0.34432400E+02, -.25894900E+02, 0.87638600E+02, -.17310300E+02, 0.22339800E+02, 0.69660100E+02, -.38621800E+02, -.30351700E+02, -.41901900E+02, 0.58574300E+02, 0.27497700E+01, -.43382400E+01, 0.15604400E+01, 0.50789900E+02, 0.20595800E+01, -.10858400E+02, 0.43317100E+01, 0.48886600E+01, -.12437000E+02, -.10992200E+02, 0.42398500E+01, 0.12037900E+02, -.17585600E+02, 0.93542800E+01, -.51250700E+02, 0.88783300E+01, -.18768700E+02, -.42482000E+02, 0.26246900E+02, 0.19338400E+02, 0.14840600E+02, -.40128400E+02, 0.32803200E+02, -.39139900E+00, 0.63888500E+00, -.25204400E+01, -.36795000E+00, 0.13241000E+01, -.22125300E+01, 0.68878200E+01, 0.70637500E+00, 0.26947600E+01, 0.32787300E+01, -.28271300E+01, 0.16860500E+01, -.20790100E+01, -.27110900E+01, -.38307300E+01, 0.37292000E+01, -.11350500E+01, -.30051500E+00, -.11944100E+01, 0.13744600E+02, 0.11950200E+01, -.80528800E+01, 0.11386000E+02, 0.71267700E+01, -.15334800E+01, 0.74947500E+01 },
        { 0.15175300E+02, -.44182600E+00, -.60022800E+00, -.13074300E+01, 0.15264900E+01, -.39471800E+01, 0.15244800E+01, -.70398500E+00, 0.60477400E+00, -.39387600E+01, 0.76296000E-01, -.27544000E+01, -.61484000E-01, 0.24179200E+00, 0.53757600E+00, -.21160400E+00, -.21935700E+00, 0.83437000E+00, 0.38497000E+00, -.17112300E+01, -.45266600E-02, -.45160600E+00, 0.13229900E+02, 0.34693000E+01, 0.10180500E+00, 0.12806600E-01, 0.91025500E-01, 0.64839500E+00, -.30894000E+00, 0.14286500E+01, 0.11792300E+01, -.14537200E+01, 0.60759600E-01, -.12797100E+01, 0.48684200E+00, 0.57270100E+00, 0.25471900E+00, 0.58845600E+01, -.41372700E+00, 0.27614500E+00, -.21517200E-01, -.54993300E+00, -.10677800E+01, 0.26715100E+01, 0.79575700E+00, -.37876200E+00, -.23007200E+00, -.46786900E-01, -.75960600E+00, -.31762100E+00, 0.22325600E+01, -.18942300E+00, 0.25282000E+00, -.62524600E+00, 0.40819800E+01, 0.34768200E+00, 0.24122600E+00, -.77109800E+00, -.94132700E+00, 0.40169100E-01, 0.34576800E+00, 0.44956900E+00, -.49519900E+00, -.40816600E+00, -.25235700E-01, 0.43414000E+00, -.21679800E+01, -.29300600E-01, -.23051100E+01, 0.18090200E-02, -.20873100E+00, -.25035800E+00, -.39408600E+00, -.47790700E+00, 0.64387300E+00, 0.83978600E+00, -.11022000E+01, -.43784100E+01, 0.88371200E+00, -.19281600E+01, -.14559200E+00, 0.16819700E+01, 0.20859700E+00, -.66320100E-01, -.26183600E+01, -.10231800E+02, -.42903400E+00, -.25647100E+00, 0.42423400E+00, -.10584200E+01, -.59263700E+00, -.12684500E-01, -.22960200E+01, 0.50730100E+00, 0.90460700E+00, -.23855800E+00, 0.21257800E-01, 0.97671900E+00, -.17015900E+01, -.42456100E+00, 0.22919400E-01, 0.19442400E+01, -.84195800E+00, 0.12776400E+00, 0.13564900E+00, -.54228300E-01, 0.24859700E+00, 0.19841600E+01, -.28811000E+00, -.77153100E-02, -.42400100E+01, -.61267900E-02, -.52788200E+00, 0.30495800E-01, 0.98223300E+00, 0.52720700E+00, -.11204900E+00, 0.10311000E+02, 0.19613400E+00, -.16312300E+01, 0.23746800E+00, 0.44852300E+00, 0.13030300E-01, 0.30463600E+00, 0.38769800E-01, 0.13072200E+01, -.13236000E+00, 0.24702300E+01, -.15956000E-01, 0.18948200E+01, -.25985500E+01, -.13061700E+01, 0.13915800E+00, 0.33427500E-01, -.14718000E+00, -.17821200E+01, 0.26259300E-01, 0.72802900E+00, 0.29964600E+01, -.20189600E+01, -.21463400E+01, 0.11965600E+01, -.11549100E+00, -.87054400E+00, -.39928600E-01, -.33364900E+00, -.57237700E-01, -.64207700E+00, -.22106300E+00, -.12788600E+01, -.47222300E+00, 0.96127500E-01, -.47920800E+00, -.63205600E+00, -.37806800E-01, 0.27812500E+00, 0.53948700E+00, -.11786500E+00, 0.15447000E+01, -.20278300E+00, -.10980000E+01, 0.43767200E+00, 0.61375500E-01, -.31947400E+00, 0.10892800E+00, 0.88497200E+00, -.22599000E+00, 0.80788900E+00, -.13574100E+00, -.35339500E+00, 0.44017200E+00, 0.58084300E+01, -.33612300E+00, 0.22660000E+01, 0.12275700E+01, -.15574000E+00, -.32709300E+00, 0.26194400E-01, 0.28780200E+00, 0.86108500E+00, 0.47240400E+00, -.36598800E+01, -.16393400E+00, -.48976900E+00, -.62431500E-01, 0.50806600E-01, 0.44837600E+00, 0.51415400E+00, -.38701600E-01, 0.67953900E-01, 0.18201300E-02, 0.79223700E-01, 0.10677300E+01, -.51069400E-01, 0.34887500E+00, -.39081500E-01, -.20795300E+00, -.65222500E+00, -.49095700E+00, -.58781600E-01, -.58111700E+00, -.23019300E-03, -.38214000E+00, -.53842400E-01, 0.36800200E+00, 0.41491200E+00, 0.34816600E-01, -.39731400E-01, 0.43428700E+00, -.13331700E+00, 0.15023400E-01, -.17348500E+00, -.46547500E-02, 0.39288900E-01, 0.23819500E+00, 0.10361300E+00, -.41384000E-01, 0.58271600E+00, 0.37746300E+00, 0.14253700E+00, 0.30139400E-04, -.15639900E-01, -.24006400E+00, -.11277900E+00, 0.80654400E+00, 0.84960600E+00, 0.54914100E+00, 0.62792300E+02, 0.10696500E+03, -.90240700E+01, 0.32471100E+03, -.23324100E+01, 0.21896600E+01, 0.99527600E+02, 0.11478700E+01, 0.13039800E+02, -.79557400E+01, -.21908000E+02, -.29791300E+01, 0.87766900E+02, -.15902600E+00, 0.67940900E+02, -.85779100E+02, 0.53003600E+02, -.10805300E+03, 0.42839200E+02, -.27631600E+02, -.92413200E+02, 0.67585100E+02, 0.52690100E+02, 0.56316600E+02, -.70435000E+02, 0.48313100E+02, -.19509600E+03, 0.10053100E+03, -.69606600E+02, 0.97877400E+02, -.34623300E+02, 0.31022700E+02, 0.19526600E+02, -.18978700E+02, 0.11125600E+03, 0.53785900E+01, 0.30376100E+03, 0.40299200E+02, -.18871600E+02, 0.89754000E+02, -.20328400E+02, 0.28025500E+02, 0.75285900E+02, -.61705200E+02, -.41111100E+02, -.73875800E+02, 0.63970200E+02, -.28264200E+02, 0.16433400E+01, 0.58902200E+00, 0.14913800E+01, 0.82127100E+00, -.69475000E+00, 0.11372200E+01, -.24045300E+02, -.44289100E+00, -.12239300E+01, -.83789200E+01, 0.88372700E+01, -.30179500E+02, -.18099300E+00, 0.32733700E+01, 0.28257200E+02, -.93088900E+01, -.14464400E+01, 0.33999200E+01, 0.30734600E+00, -.18620300E+02, 0.69588400E-01, 0.28080900E+02, -.33192000E+02, -.17908400E+02, -.11711100E+02, -.99002200E+01 },
        { 0.94078900E+01, -.25387000E+00, -.36453600E+00, 0.76196500E+00, 0.11544500E+01, -.26029900E+01, 0.80175900E+00, -.52862400E+00, 0.11811100E+01, -.24081600E+01, 0.68501800E-01, -.10491500E+00, 0.48889900E+00, 0.22868100E+00, 0.12803400E+01, -.17347800E+00, 0.99125000E-01, 0.55282400E+00, -.70576300E+00, -.17686500E+01, -.78933400E+00, -.51338900E+00, 0.19183700E+02, 0.25149700E+01, -.49829300E-01, -.13648000E+00, 0.21815700E+00, -.10585600E+01, -.12494700E+01, -.11559400E+01, -.11830100E+01, -.11847500E+01, 0.11270200E+00, -.51104000E-01, 0.51308600E+00, 0.10942300E+00, -.48456200E-01, 0.46982800E+00, -.24067400E+00, 0.92847200E+00, -.97944600E-02, -.14442700E+01, 0.71896000E-01, 0.82134400E+00, -.12162200E+00, 0.40783400E-01, -.56510700E-01, -.12984600E-02, 0.63370600E-01, 0.39009100E-02, 0.17936700E+01, 0.37971500E+00, 0.16036200E+00, 0.31909700E+00, 0.11825400E+01, 0.25207200E+00, -.27760600E-01, -.60155200E+00, -.26493300E+00, 0.49658300E-01, 0.31191100E+00, -.24919300E+00, 0.14334900E+00, -.81115700E-01, 0.57963000E+00, -.68481200E-01, -.21110700E+00, 0.30599500E-01, -.10723200E+01, 0.46635700E-02, 0.17599000E+00, 0.16464400E-01, -.46631800E-01, -.41785400E-01, -.27003100E+00, 0.12650900E+00, 0.54948800E-01, 0.30728100E+01, -.13816900E+01, -.26017500E+00, -.20660000E-01, 0.98497700E+00, 0.64781200E+00, -.73267200E+00, -.12171400E+00, 0.24256500E+01, 0.24954200E+00, 0.12369800E+00, -.39807000E+00, 0.13899400E+01, 0.43751700E+00, -.33110800E-02, -.30322900E+01, 0.21137100E+00, -.12809200E+00, -.78873600E-01, 0.43957300E-01, 0.44082200E+00, 0.10332200E+00, -.10836700E+00, 0.11587900E-01, 0.30665700E+00, -.15770300E+00, 0.79752800E-01, 0.59809200E-01, -.21752000E+00, 0.69051800E-01, 0.54111900E+00, 0.86088800E-01, -.34894000E-01, -.14958200E+01, 0.39889100E-01, 0.13194000E+00, 0.26481600E+00, 0.82255000E+00, -.96584100E-01, 0.11222400E+00, 0.14424900E+01, -.47614100E+00, -.35742700E+01, -.18303400E+00, -.85660500E-01, 0.36661400E-01, 0.22832500E+00, -.10846000E-01, 0.66290000E+00, 0.28665800E+00, 0.10174000E+00, -.29994200E+00, 0.22178300E+01, -.69922500E+01, 0.66098700E+00, 0.52620600E+00, -.44087400E-01, -.75419200E+00, -.16076500E+01, 0.98117400E-01, 0.20730100E+00, -.17684100E+01, 0.76983900E+00, 0.63178100E+00, -.28982900E+00, 0.95512600E-01, 0.30590300E+00, 0.17631200E-01, 0.10461200E+00, 0.66840100E-01, -.14339000E+01, -.70240700E-01, -.44602200E+00, 0.24921600E+00, -.98011100E-01, 0.55424800E+00, 0.24810400E+00, 0.64678800E-01, -.16097400E+00, -.40955600E-01, -.87066600E-02, -.17822600E+01, -.15331400E-01, -.61096300E+00, 0.35489800E-02, 0.27267600E-01, 0.70801400E+00, -.12086900E+00, -.54053000E+00, 0.24100900E+00, -.31880500E+00, -.17303200E+00, -.52159100E+00, -.28320300E+00, -.16091700E+01, -.21560400E+00, 0.20091500E+01, 0.43006500E-02, 0.11635900E+00, 0.73057400E-01, 0.21696300E-01, -.25263100E+00, 0.10670200E+01, 0.53169700E+00, -.21791700E+01, 0.38498900E+00, -.24033400E+00, 0.14474500E+00, -.16453900E+01, -.15106300E+00, -.42375100E+00, -.12838400E-01, 0.43874800E-01, 0.93471900E-02, -.65937900E-01, -.23806300E+01, 0.28751000E+00, 0.39622200E+00, 0.50448300E-01, 0.18904600E+01, -.34601600E+00, 0.15511000E+00, 0.18392400E-01, -.47645200E+00, 0.29374300E-01, -.35386500E+00, 0.43094800E-01, -.12339400E+00, 0.26163800E+00, 0.30621000E-01, -.93517500E+00, -.38809300E+00, -.28621100E-01, 0.77911100E-01, -.68479600E-01, 0.12990400E+00, -.12735600E+00, -.19481600E-01, -.21388200E+00, 0.32481100E+00, -.91097600E+00, -.56830500E+00, -.19305200E+00, 0.30182700E-01, -.67601100E-01, 0.45617600E+00, 0.14131600E-01, -.66592700E+00, -.84749400E+00, -.47346000E+00, -.17185600E+00, -.69367800E+02, -.10723700E+02, -.82443300E+02, -.12338300E+03, 0.61431600E+02, 0.52024800E+02, 0.61755900E+02, 0.20220200E+02, 0.28993100E+02, 0.22039100E+02, -.24581900E+02, -.28125900E+02, 0.15275700E+02, 0.24666400E+02, 0.26162500E+02, -.12110500E+02, 0.29829800E+02, -.12954400E+02, 0.16723400E+02, 0.62710800E+02, -.25889800E+02, 0.26063200E+02, 0.13172700E+02, 0.41382000E+02, -.32117600E+01, 0.10600600E+03, -.50650300E+02, -.14828200E+03, -.52672000E+02, 0.50750800E+01, -.66133200E+01, -.47914700E+02, -.19286500E+02, -.46165900E+02, -.66420400E-01, -.20843100E+02, -.40146400E+02, 0.19668200E+02, -.54111300E+02, 0.19903000E+02, -.29764600E+02, -.77572900E+02, 0.70330800E+02, 0.11131700E+02, 0.26855300E+02, -.60291800E+02, -.12801900E+02, -.10376400E+01, -.52177900E+00, -.55093600E+00, -.76578000E-01, 0.91154700E+00, -.11963100E+01, 0.10853200E+02, 0.64071900E-01, 0.41225000E+00, 0.51028600E+00, 0.68444200E-01, 0.86387100E+01, -.88588400E+00, -.30439700E+01, -.11644700E+02, -.77807500E-01, 0.69303700E+00, -.26152200E+01, -.10346900E+01, 0.13409700E+02, 0.52022400E+00, -.17480900E+02, 0.16793400E+02, 0.67982900E+01, 0.64372900E+00, 0.27473400E+01 },
        { 0.32974200E+02, -.71469200E+00, -.20168400E+01, -.76043200E+00, 0.13842900E+01, -.44676100E+01, 0.25814800E+01, -.30969200E+01, 0.65667200E+00, -.26351800E+01, -.57848400E-01, -.17322900E+01, 0.36095800E-01, 0.11102600E+01, -.98623700E-01, -.30563100E+00, -.14276400E+01, -.12261800E+01, -.53874800E+00, -.36096800E+00, 0.55529100E+00, 0.19496900E+00, -.75720500E+01, 0.88728900E-01, -.74769300E-01, 0.51934200E+00, -.55658100E+00, -.29119400E+00, -.67646900E+00, 0.19036300E+01, 0.42856400E+00, 0.15959100E+01, 0.22363800E-01, -.85375400E+00, 0.38267300E+01, -.18732600E+00, 0.14143500E+00, 0.20622100E+01, 0.57102100E-01, -.73571500E+00, -.28976700E+00, 0.12097000E+01, -.60377900E+00, 0.84701100E+00, 0.64435500E+00, -.36791400E+00, 0.54975400E+00, -.32984800E-01, -.36309500E+00, 0.32533000E-01, 0.15056800E+01, -.75810400E+01, 0.64663000E-01, -.55539600E-03, 0.32625500E+01, 0.55087100E+00, 0.24825700E-01, 0.36388200E+01, 0.88885900E-01, 0.35660100E+00, -.79060600E+00, -.11315000E+01, 0.10673500E+01, -.14032700E+00, 0.16161000E+01, 0.91706800E+00, -.88233700E+01, -.52865900E-01, 0.95516800E+00, -.16076500E-01, -.57841100E+00, -.13206000E+01, -.76007200E+00, 0.80472800E+00, 0.36085900E+00, 0.19580000E+00, -.10884400E+00, -.49528200E+01, 0.11400000E+01, 0.20900400E+01, 0.10060600E+00, -.76967200E+00, -.64902700E+00, -.21321500E+01, 0.12338400E+01, -.35295900E+01, 0.26026600E+00, -.81516400E-01, -.13820700E+01, 0.11947600E+01, -.31874300E+00, 0.39132800E-01, 0.75888300E-01, 0.18051500E+00, 0.28208000E-01, 0.32862500E+00, -.15256100E+01, -.39651300E+00, 0.21924600E+00, -.34662000E+00, 0.15049300E+00, 0.18398400E+01, 0.92849000E-01, 0.91439800E-01, -.55574200E+00, 0.15368900E+00, -.38378000E+00, -.87329700E+01, 0.41416700E-01, -.23029700E+00, 0.70972800E+01, -.61000600E-01, 0.73780800E+00, -.28682100E-01, -.34447600E+01, 0.16172000E+01, -.26318300E-01, 0.44897700E+01, -.77320900E-01, -.21237500E+01, -.56297100E+00, -.46422900E+00, -.25747500E-01, -.31405000E+01, -.19583900E-01, 0.68840500E-01, -.11001400E+00, 0.59039200E+00, -.87950400E+00, -.47983700E+01, -.83263600E+01, -.18556600E+00, 0.98672900E+00, 0.10200100E+00, -.17131700E+02, 0.15209200E+01, 0.61473300E+00, 0.99400800E+00, 0.43373500E+01, -.29309200E+01, -.28411900E+00, -.18118500E+01, 0.54197700E-01, 0.39005700E+00, 0.33577000E-01, 0.75681200E+00, 0.10878400E+00, -.10653800E+01, -.13719800E+01, 0.22813200E+01, 0.64292700E+00, -.11589900E+01, -.12759000E+01, -.59912700E+00, -.84527600E+00, 0.19434900E+00, -.48874200E+00, 0.65924400E-04, 0.13280000E+01, 0.49640700E+00, -.23305100E+01, 0.46808600E+00, -.27984400E+00, 0.17241000E+01, -.17047600E+00, -.66925300E+00, -.97433900E-02, -.90189000E+00, 0.27023100E+00, -.13859100E+01, -.18838400E+01, 0.33603700E+01, 0.10159100E+01, -.26596900E+01, 0.27735100E+00, 0.98490500E+00, 0.29424900E-01, -.18325300E+00, 0.75564600E+00, 0.24628100E+01, -.32928200E+01, 0.65484900E+01, 0.55364800E+00, 0.25807900E+01, 0.27736100E+00, 0.50656200E+01, 0.14741200E+01, -.14853500E+01, 0.19157700E+00, 0.11769400E+01, -.23756900E-01, 0.26009600E+00, -.23111100E+01, 0.68552700E+00, -.87286800E+00, -.65854600E-01, -.72003600E+00, 0.10679500E+01, 0.18672000E+01, -.13646900E-01, -.18857100E+01, 0.90832100E-01, -.14282600E+00, 0.88642300E+00, -.71625100E+00, 0.10694700E+00, -.38527400E+00, -.20754700E+01, -.40749200E+00, 0.78275400E-01, 0.14360000E+00, -.28416500E+00, 0.14525800E+00, 0.20612800E+01, 0.64188200E+00, -.30018800E+00, 0.79971500E+00, -.16434300E+01, -.52753100E+00, -.15654100E+00, 0.14789900E+00, -.15105500E+00, -.20400900E+01, -.30010200E+00, 0.72442900E+00, -.35656000E+01, -.33583200E+01, -.10761400E+01, 0.11777200E+01, 0.45002300E+02, 0.71336100E+03, 0.10411500E+04, -.51525900E+03, -.61669100E+03, -.52098700E+03, -.18211000E+03, -.27171200E+03, -.34161100E+02, 0.89690900E+02, -.38050400E+03, -.20105200E+03, -.35780100E+03, 0.38324800E+03, -.18473300E+03, -.30618500E+03, -.19201400E+03, -.69684700E+02, -.12613200E+03, 0.18377300E+02, 0.25000100E+03, -.46539000E+02, -.84275300E+02, 0.11309100E+03, -.72273800E+03, 0.36118900E+03, 0.37444500E+03, 0.36309400E+03, -.88829000E+01, 0.12186800E+03, 0.10364800E+03, -.18543900E+02, 0.30142000E+03, 0.68813500E+02, 0.76187800E+03, 0.55450300E+02, -.31077400E+02, 0.22140800E+03, -.28202200E+02, 0.28965700E+02, 0.15936200E+03, -.12488300E+03, -.13792600E+03, -.15749200E+03, 0.10803200E+03, -.90668400E+02, 0.10180200E+02, 0.45027600E+01, -.17118500E+01, 0.16346200E+00, 0.35948500E+01, 0.39278800E+01, -.40681000E+02, 0.53038600E+00, 0.72669400E+00, -.50999000E+02, 0.46092900E+02, -.26771800E+02, 0.60457700E+01, 0.13481300E+02, 0.57444800E+02, -.48751700E+02, -.50175600E+01, 0.15243000E+02, 0.29904800E+01, -.49938600E+02, -.11318900E+01, 0.51842100E+02, -.52038600E+02, -.82972900E+02, -.59013100E+01, -.53949300E+02 },
        { -.70006500E+01, 0.17463300E+00, 0.29292800E+00, 0.75616600E+00, -.97587800E+00, 0.22219700E+01, -.14759300E+01, 0.14178900E+01, -.96926700E+00, 0.18210300E+01, -.51278900E-02, 0.60656800E+00, -.29222900E+00, -.79691500E-01, -.76973100E+00, 0.24996800E+00, -.23581500E+00, -.43295200E+00, -.54471700E+00, 0.60841200E+00, -.53897700E-01, -.11761200E+00, -.12033000E+02, -.19271700E+01, -.30085700E+00, 0.27795200E+00, 0.82429900E-01, 0.13534100E+00, 0.33807000E+00, -.10825900E+01, -.26194000E+00, -.12380500E+00, -.81103900E-01, 0.90392600E+00, -.10623100E+01, -.11163200E+00, -.17175900E+00, -.22457800E+01, 0.19562000E+00, -.21521300E+00, -.20197600E+00, 0.72918700E+00, -.29224500E+00, -.52715000E+00, -.35269800E+00, -.16386600E-01, -.28873100E+00, 0.24044800E-01, -.85773700E-01, 0.12118700E-01, -.37758600E+00, 0.25170600E+01, -.21321100E-01, -.25746100E-01, -.33914300E+01, 0.25946100E+00, 0.82703000E-02, 0.16259900E+00, 0.43828800E+00, -.20243500E+00, -.23626400E+00, 0.53786100E-01, 0.65827800E-02, 0.12528100E+00, 0.48595000E+00, -.27036000E-01, 0.10711000E+01, 0.23706300E-01, 0.14630700E-01, 0.79822000E-02, 0.13043400E+00, -.42223200E+00, -.38994900E+00, -.99012900E-04, 0.73119300E+00, -.14257100E+00, -.53621400E+00, 0.12956600E+01, -.14338700E+01, -.52777700E+00, 0.39147200E-01, -.23080800E+00, -.14106800E+00, 0.20602400E+00, -.26259200E+00, 0.11559300E+02, 0.44992600E+00, 0.37933400E+00, 0.33047700E+00, 0.13855700E+01, 0.30074700E+00, 0.42218600E-01, -.24164100E+00, -.27690700E+00, 0.47011600E+00, -.97421700E+00, -.36731400E+00, -.77757900E+00, -.17946000E+01, 0.46496800E+00, 0.34332800E-01, -.71815100E-01, 0.30990000E+00, -.31301100E+00, -.10680300E+00, 0.27954100E+00, -.67215500E-01, -.30253500E+00, -.25700900E+00, -.15237600E-01, 0.82987500E+00, 0.24132600E-01, -.25990200E+00, -.37798500E-02, -.21658000E+00, 0.48394600E-01, -.11496700E+00, 0.98059900E+00, -.14369600E+00, 0.43481900E+00, 0.29594900E+00, 0.12742700E+00, 0.12104200E-01, 0.14583400E+00, 0.25521300E-02, 0.65853500E+00, -.15902200E-02, 0.43383700E+00, 0.17034200E+00, 0.90422200E+00, 0.10031200E-01, -.21876600E+00, -.18363000E+00, 0.78394200E-01, 0.14756300E+01, -.11758200E+01, 0.59775500E-02, 0.28350000E+00, 0.26904400E+00, -.25358600E+00, 0.75434200E+00, -.19944500E+00, 0.32936100E-02, 0.55331600E-01, 0.96571500E-02, -.10366100E+00, 0.56148600E-02, -.91755300E+00, 0.16282400E+00, 0.30510600E+00, -.57327800E-01, -.12121100E+00, -.81813900E+00, -.30113400E+00, -.29897500E+00, -.85166700E-01, 0.43144300E-01, 0.58498000E-02, 0.13268100E+01, 0.10645500E+00, -.65472100E+00, 0.19806900E+00, 0.10545700E+00, -.26634400E+00, -.79609400E-02, 0.32607600E-01, 0.39449800E-01, 0.41166900E+00, -.10757200E+00, 0.44654100E-01, 0.69235700E+00, 0.82314500E+00, -.31647200E+00, -.66922900E+00, -.37023900E+00, -.25810600E+00, 0.92417800E-01, 0.31249100E-01, 0.40494800E+00, 0.55752700E+00, 0.19988000E+00, -.37170000E+01, 0.91872000E-01, -.20680200E+00, 0.17735200E-01, -.43324300E-01, 0.84751100E-01, -.19004400E+00, -.11025300E-01, 0.79919500E-02, 0.10227300E-02, 0.80158500E-01, 0.80496500E+00, 0.59330800E+00, 0.20888300E+00, 0.91195700E-01, 0.50994800E+00, 0.12085700E+00, 0.25453000E-01, -.24094400E-02, 0.42461000E+00, -.10789500E-01, -.33216700E+00, 0.34449000E+00, 0.48996700E-01, -.21015900E+00, -.87755400E-01, 0.36741300E+00, 0.43783100E-01, 0.42912700E-01, 0.28371300E-01, -.14137500E+00, -.64990800E-01, -.25259600E+00, 0.12008700E+00, -.12302300E+00, -.10791300E+00, -.52187000E-01, 0.12358100E+00, 0.40345100E-01, -.12117900E+00, -.71315900E-02, -.29997300E+00, -.88984800E-01, 0.43258700E+00, 0.79745100E+00, -.63370800E+00, 0.14813800E+00, -.19618700E-01, 0.12277800E+00, -.21025000E+03, 0.87319000E+01, -.10228400E+01, 0.19662900E+02, -.42665200E+01, 0.45719300E+01, 0.17441900E+02, -.34857100E+02, 0.58213300E+01, 0.65411400E+01, 0.13913400E+02, -.57064700E+02, -.14316300E+03, 0.69946800E+02, 0.12657100E+03, 0.71602900E+02, 0.99152800E+01, 0.63000300E+01, 0.13593000E+02, -.63732700E+02, 0.32982500E+02, 0.50133500E+01, -.30601100E+01, 0.15647700E+03, -.77925400E+02, -.30793100E+02, -.78491000E+02, -.39076500E+02, -.44960100E+02, 0.86464700E+01, 0.41348700E+02, -.20456600E+02, -.44389600E+02, -.35196800E+02, -.29110400E+02, 0.16581900E+02, -.45025000E+02, 0.14564700E+02, 0.87000300E+01, -.41494700E+01, 0.19905500E+02, 0.26335100E+02, 0.19629600E+02, -.31595600E+00, 0.31943900E+02, -.20568000E+01, 0.14394400E+00, 0.12786200E+01, 0.33293000E+00, -.13044400E+01, 0.30250700E+00, 0.11215000E+01, 0.41132200E+00, -.79838100E+00, 0.16497800E+02, -.15550800E+02, -.78573300E+01, -.15702800E-01, 0.40741400E+00, 0.66992000E+00, 0.15580000E+02, 0.11598300E+01, -.13570300E+01, 0.13067100E+01, 0.18135600E+02, -.14320600E+01, -.17639200E+00, -.30224700E+01, 0.21356600E+02, -.21579700E+00, 0.18417800E+02 },
        { -.84661300E+01, 0.32677000E+00, 0.13085900E+00, -.19233500E+01, -.11368500E+01, 0.21021300E+01, -.19413200E+00, 0.22040000E+01, -.84439000E+01, 0.96128500E+00, -.91200200E-02, -.22553800E+01, 0.14004800E+00, -.45196800E-01, -.48285700E+00, 0.84652100E-01, -.80504700E+00, -.71991300E+00, -.14581600E+01, 0.76432600E+00, 0.14425400E+01, -.16410400E+00, -.10717900E+02, 0.45956400E+00, 0.11408700E+00, 0.37910200E+00, -.22309200E+00, 0.24487700E+01, 0.28810100E+01, 0.15929100E+01, 0.12552500E+01, 0.46679800E+00, -.17407600E+00, -.14813200E+00, -.64174900E+01, 0.15949200E+00, -.11285300E+00, -.83947300E+00, -.21992300E+00, -.84263900E+00, 0.14165500E+00, 0.18360300E+01, 0.50888600E+00, -.78668200E+00, 0.26646100E+00, -.28390400E-01, -.96914400E-01, 0.13607100E-01, -.62636200E+00, 0.12405000E+00, -.24867000E+00, 0.84251500E+01, -.14623000E+00, 0.11288000E+01, -.43587900E+00, -.14976800E+01, 0.41916500E-01, 0.10060700E+00, -.61846800E+00, -.16386300E+00, -.37016000E+00, -.51328200E+00, 0.25769800E-01, 0.46180700E+00, 0.55944700E+00, -.26645400E+00, 0.23173200E+00, 0.45773500E-01, 0.10854700E+01, 0.61954500E-02, 0.95688300E-01, -.37095400E+00, -.26062000E+00, 0.51326000E+00, -.94514500E+00, -.29211900E+00, -.15917300E+00, 0.10020800E+02, -.44219000E+01, 0.15162800E+01, 0.12188400E+00, -.10857700E+01, 0.27328700E+01, -.16910800E+01, 0.22857400E+01, 0.40442000E+01, 0.78765400E+00, 0.39214000E+00, -.14016300E+00, 0.32366600E+01, -.75526400E+00, 0.17374300E+00, 0.25302200E+00, -.28700100E+00, -.60168800E-02, -.30419200E+00, -.34346000E-01, -.69647700E-01, 0.16681000E+01, -.77336200E+00, -.17140400E+00, -.13501800E+01, 0.80894400E+00, 0.23318100E+00, -.19089400E+00, -.96214400E+00, 0.19522100E+00, 0.67856400E+01, 0.68903200E-01, -.45168000E-01, 0.35247200E+01, 0.40946400E-01, 0.35426000E+00, 0.71117500E-02, 0.49838500E-01, 0.86250800E+00, 0.13127600E+00, 0.80608200E+01, 0.71838800E+00, 0.39520500E+01, -.16642600E+00, 0.27727400E+00, -.35908800E-01, 0.25952600E+00, -.37579300E-01, -.97479900E+00, -.20875500E+00, 0.21828900E+00, 0.32973600E+00, -.32078400E+01, 0.45282300E+01, -.10427100E+01, 0.31516500E+00, -.34624700E-01, -.65327300E+01, 0.88076900E-01, 0.21251700E+00, 0.10518900E+00, 0.18350200E-01, -.51025500E-01, -.56813400E+00, -.11044000E-01, -.60516900E-01, -.59366200E+00, 0.85846200E-01, 0.60940300E+00, 0.33551000E-01, 0.11365300E+01, -.12071700E+00, 0.26264500E+01, 0.23598900E+00, 0.15629600E+01, -.11161100E+01, 0.38852100E+00, -.80924400E-01, -.23558900E-01, -.31171000E+00, 0.32878000E-01, -.20547200E+01, -.44704200E+00, -.19595000E+00, -.37944400E+00, 0.44281500E-01, -.17292200E+00, 0.14889700E+00, -.55777500E+00, 0.26866300E-01, 0.13647700E+01, 0.10225900E+00, -.41272200E+00, 0.12074300E+00, -.36430200E+01, -.34042300E-01, 0.19118600E+01, 0.26633900E+00, -.17761400E+00, 0.18153300E+00, 0.20836400E+00, 0.77643000E+00, 0.11644100E+01, -.19953100E+00, 0.28399400E+01, 0.63791200E+00, -.75214700E-01, 0.14137500E+00, -.45732700E+00, 0.76285500E-01, 0.63714700E+00, -.41319900E-02, -.67726500E-01, 0.34431900E-02, -.14156500E+00, -.13460700E+01, -.56045600E+00, 0.60252500E-01, -.20737800E+00, -.10132000E+01, -.95805400E+00, -.72588800E+00, -.56514800E-01, -.86521000E+00, 0.10374400E-01, 0.52475800E+00, -.23548200E+00, 0.15383300E+00, 0.19948800E+00, 0.18247800E+00, 0.21990200E+00, 0.58011900E+00, -.17282700E-01, -.78171600E-01, 0.21403600E+00, 0.44991500E-01, 0.99269500E-01, -.17208700E+00, 0.10291900E+00, 0.25063900E+00, -.23605100E+00, -.12277700E+00, 0.21784000E-02, -.15073500E+00, 0.10172500E-01, 0.14513000E+00, -.44163500E-01, 0.36228700E+00, 0.16201600E+01, -.49104200E+00, 0.71751600E+00, -.31395500E+00, -.39230800E+00, 0.33913900E-01, 0.47575700E+03, -.23151100E+03, -.31745400E+03, -.23798100E+03, -.76904800E+02, -.10110700E+03, -.14200800E+02, 0.74107700E+02, -.20180900E+03, -.91908100E+02, -.17838200E+03, 0.14479200E+03, -.77880000E+02, 0.92764000E+01, -.72329100E+02, -.26756100E+01, 0.25922900E+02, -.42712300E+02, 0.81927600E+02, -.55910300E+01, 0.17179700E+02, 0.21292300E+02, -.76570200E+02, 0.40300900E+02, 0.40191800E+02, 0.38559800E+02, -.13398600E+02, 0.10103200E+02, 0.10114800E+02, -.41978500E+01, 0.44924400E+02, 0.19616000E+01, 0.76295700E+02, -.85816700E+01, 0.51873100E+01, -.20000900E+02, 0.41548300E+01, -.12047900E+02, 0.11129200E+02, -.56837800E+01, -.54330700E+02, -.48980400E+02, 0.78348800E+01, 0.11706800E+02, 0.31383100E+01, 0.22413600E+01, -.20102500E+01, -.55729900E+00, 0.18513900E+01, -.75635100E+00, 0.32338000E+00, 0.97266800E+00, 0.13545900E+01, -.13737500E+02, 0.12524800E+02, -.66275800E+01, -.90058500E+00, 0.87656600E+00, 0.36022000E+01, -.13487400E+02, -.18397600E+01, 0.37291500E+01, -.83951700E+00, 0.24289600E+01, 0.85343000E+00, 0.71755500E+00, 0.22219700E+01, -.14236100E+02, -.17383000E+01, -.11839900E+02 },
        { 0.15378400E+02, -.69895300E+00, -.36817000E+00, -.53159200E+00, 0.13439400E+01, -.38631900E+01, 0.13144900E+01, -.12936900E+01, 0.19942000E+01, -.36107600E+01, 0.82950000E-02, -.15652100E+00, -.30435200E+01, -.92040000E-01, -.14584100E+01, 0.55844700E-01, -.60623300E+00, -.99793700E+00, 0.10103700E+01, 0.21984200E+00, -.54620500E+00, 0.42296900E+00, -.18316000E+02, -.25442100E+01, -.23563500E+00, 0.16583500E+00, 0.47804300E+00, 0.44708000E+00, -.13077300E+01, 0.55280400E-01, -.36274800E-01, 0.40709200E+00, 0.56656200E-01, -.37612300E+00, 0.10001600E+02, 0.24126400E-01, 0.16688900E+00, 0.36204800E+01, -.23120900E+00, 0.49057600E+00, 0.26553300E-01, -.11257400E+01, 0.39847300E+00, 0.10375300E+01, -.75785700E-01, 0.31144600E-01, -.58564200E+00, -.21428600E-01, 0.80953900E+00, -.31067000E+00, 0.32506400E+00, 0.19368100E+01, -.72164500E+00, -.69656100E+00, 0.39614700E+01, 0.41387300E+00, -.19163200E+00, -.36030100E+00, -.37667700E+00, -.69589500E-01, 0.14171900E+01, 0.12214500E+01, -.14271100E+01, 0.31029500E+00, 0.87956800E+00, 0.19170900E+00, -.41952000E+00, 0.67518800E-01, 0.50987900E+00, -.42536000E-02, 0.13448500E+00, -.11174700E+01, -.29954300E+00, 0.76830500E-02, -.60249000E+00, -.11767700E+01, -.14292400E+00, -.10961500E+02, -.47275000E+00, -.40161100E+00, -.22018800E-01, -.22671900E+00, -.75158700E+00, 0.85901200E+00, -.22845500E+01, -.15558000E+02, -.34003600E+00, -.73005900E-01, 0.21692500E+01, -.19319600E+01, -.22647900E+00, -.43709300E-02, 0.94102700E+00, 0.66336500E+00, 0.24366000E+00, 0.65609200E+00, 0.80073600E-01, 0.90524200E-01, -.33173000E+01, 0.62456000E+00, 0.26643600E-01, 0.41813500E+00, -.53827700E-01, 0.10402200E+01, -.11457400E+00, 0.88886200E+00, 0.10031600E+00, 0.56578300E+01, -.34887500E+00, 0.26140100E+00, -.35582800E+01, 0.55252400E+00, -.60087600E-01, 0.25959700E-01, 0.87500900E+00, 0.65570400E+00, 0.14149100E+00, -.22100000E+01, 0.11682400E+01, -.66004200E+01, 0.20337500E+00, 0.47487400E-01, 0.14569900E+00, 0.39756700E+00, -.25914100E-01, 0.16689700E+01, -.15009700E+00, -.14554600E+01, 0.15928200E+00, 0.30086500E+01, -.10845800E+01, -.22580900E+00, 0.78842500E+00, 0.14784200E+00, -.16446200E+01, -.15722100E+01, 0.72135600E-01, 0.30304500E+00, -.19683900E+01, 0.33773300E+00, -.15535300E+00, 0.21334600E+00, 0.54799200E-01, 0.25044500E+00, 0.51042800E-01, -.50492500E-01, 0.90544400E-01, -.30091400E+01, -.14737900E+00, -.21464700E+01, 0.40428500E+00, -.11358900E+01, 0.73094700E+00, 0.24102900E+00, 0.56232600E-01, -.11934000E+00, 0.22524500E+00, 0.99833200E-02, -.13707800E+00, -.80402900E-01, -.10787900E+01, -.31223100E+00, 0.33867200E+00, -.91440300E+00, -.21423400E-02, 0.13406800E+00, -.15254300E+00, -.38592800E+00, -.11445100E+00, -.13098500E+00, 0.25842800E+00, 0.48353900E+01, 0.11568500E+00, 0.30088900E+01, -.15987100E+00, 0.79074800E+00, -.21665100E+00, -.34201200E+00, -.86552800E-01, -.16412800E+00, 0.41603500E+00, -.14189400E+01, 0.92401600E-01, 0.81994500E+00, -.20155000E+00, 0.69951100E+00, -.19840200E+00, -.28744400E+00, -.95938700E-01, 0.75450600E-01, 0.51372200E-02, -.91037500E-01, -.43233000E+00, 0.40541200E+00, -.23648500E-01, 0.37795100E-01, 0.16998200E+01, 0.29372900E+00, 0.11385100E+00, 0.16762200E+00, 0.94464400E+00, -.17975700E-01, -.24507700E+00, -.44947900E+00, -.45403500E-01, -.13729500E+00, 0.21648600E+00, -.74500100E+00, -.43745600E+00, -.24090700E+00, 0.80060500E-01, -.81298900E-01, 0.39588800E-01, -.70447700E-01, -.11500000E+00, -.22960900E+00, -.11034700E+01, -.72590500E-01, 0.54175300E-01, -.62175000E-02, 0.16801900E+00, -.20165500E+00, -.34328100E+00, 0.58128300E-01, -.47953300E+00, -.94654300E-02, 0.27880400E+00, 0.20008300E-01, 0.96344800E+00, 0.28815000E+00, 0.79417600E+00, -.43115000E+00, 0.48692900E+02, -.10240200E+03, -.22854600E+00, -.64478600E+01, -.73115300E+01, 0.19865600E+02, 0.30015200E+02, -.15784100E+02, -.12328200E+02, 0.87151300E+02, 0.17956700E+03, -.99150500E+02, -.12583300E+03, -.89862700E+02, -.33400800E+01, 0.58491300E+01, -.43291900E+02, -.21862600E+02, -.93357500E+02, 0.11623800E+02, -.43408100E+02, -.25889100E+02, 0.16312000E+02, 0.13880900E+03, 0.12422100E+02, 0.43976600E+02, 0.82756700E+01, 0.26567600E+02, 0.98629800E+01, -.24510200E+02, 0.18310600E+02, -.30610800E+03, 0.78540900E+02, -.38107300E+02, 0.20755500E+02, -.38974700E+02, -.72097000E+01, 0.14181300E+02, -.51550000E+02, -.88047300E+01, -.39400100E+02, 0.60947600E+01, 0.19600300E+02, 0.12657500E+01, -.26704100E-01, -.18713500E+01, -.10708900E+01, 0.16543100E+01, -.19929800E+01, 0.90611400E+01, -.33966900E+00, 0.17807100E+01, -.68642300E+01, 0.48215500E+01, 0.79539500E+01, -.71868400E+00, -.44138100E+01, -.13922200E+02, -.44502900E+01, -.92425900E+00, 0.10742600E+01, -.20566800E+01, -.16539700E+02, 0.20470700E+01, -.96326400E+01, 0.19022900E+02, -.73224200E+01, 0.42514100E+01, -.52145000E+01 },
        { 0.46768300E+01, -.11131300E+00, -.19002300E+00, -.41313100E+00, 0.71301000E+00, -.14968400E+01, 0.43350500E+00, -.49070900E+00, 0.51243700E+00, -.12888500E+01, -.40922200E-02, 0.20443900E-01, 0.33825400E+00, 0.81599400E-01, 0.15042800E+00, -.13487200E+00, -.17918000E+00, -.17780800E+00, 0.20590700E+00, -.95208800E+00, -.98916600E+00, 0.69202400E-01, 0.31175800E+01, 0.45062400E+00, 0.44896500E-02, -.36063000E-01, 0.19958000E+00, -.10915700E+00, -.13119100E+01, -.92443500E+00, -.70313800E+00, -.15253000E+01, 0.10020500E+00, -.45013800E+00, 0.19255200E+01, 0.46833800E+00, 0.74533000E-01, 0.15724200E+01, -.20618400E-01, 0.53125100E+00, -.41989000E+00, -.16148000E+01, -.53342800E-01, 0.69130600E+00, -.46035500E+00, 0.20167300E+00, -.14530000E+00, -.12667100E-01, 0.68100100E+00, -.12979900E+00, 0.79049900E+00, -.28209000E+01, -.17068800E+00, 0.40310200E+00, 0.23402600E+01, -.42308400E+00, -.75338100E-01, -.60014300E+00, -.28945500E+00, 0.22307500E-01, 0.67682100E+00, 0.19232900E+00, 0.33014500E+00, -.17334200E-01, -.82384900E+00, -.56074800E-01, 0.32460200E+00, 0.25033600E-02, -.16791000E+00, 0.49050600E-03, 0.14993300E-01, -.48176100E-01, -.97363300E-01, 0.20303800E-03, 0.23147200E+00, 0.24616300E-02, 0.69424300E-01, 0.16024500E+01, -.47830200E+00, -.16474500E+00, -.83933600E-02, 0.12830100E+00, 0.13193100E-01, -.42000200E-01, -.40195900E+00, -.38829900E+01, -.10557400E+00, -.15918100E-04, 0.38476700E+00, -.13796500E+00, -.21498900E+00, 0.20365400E-01, -.10441600E+00, 0.10097600E+00, 0.23168600E-01, 0.59959000E-02, -.15584900E+00, 0.50777200E-01, -.38201500E+00, -.13789400E+00, -.19677300E-01, 0.16243600E+00, 0.14058500E-01, 0.32043300E-03, -.18819300E-01, 0.10327700E+00, 0.21129700E-01, 0.59387000E+00, -.63805000E-01, -.12144300E-01, -.61005800E+00, -.21768000E-01, -.13671500E+00, 0.51266000E-02, 0.36588200E-02, 0.29500600E+00, -.56554500E-01, 0.18047800E+01, -.15580700E-01, -.92173500E+00, 0.11902300E+00, 0.53829600E-01, -.14080900E-02, -.57854000E-01, -.37146300E-02, 0.32579300E+00, 0.21169200E-01, -.31849600E-01, 0.45780000E-01, 0.99516500E-01, -.21735300E+01, -.21574400E-01, 0.27778700E+00, -.25592100E-01, -.11346000E+01, -.24382900E+00, 0.63381200E-01, 0.10936900E+00, -.78868200E+00, 0.21850000E+00, 0.28693700E+00, 0.26610600E+00, 0.82491200E-01, -.27678600E-01, -.29069900E-02, 0.34533800E-01, 0.23308500E-01, -.78693900E-01, -.99353800E-02, -.74789200E+00, -.30827800E-01, -.29435700E-01, -.85367600E+00, -.49973700E-02, -.59833800E-01, -.68298900E-01, -.44058100E-01, 0.22535300E-02, 0.28574600E+00, 0.47447300E-01, -.36833900E+00, -.17926900E-01, -.76139300E-01, 0.86091200E-01, -.69897800E-01, -.36626200E-01, 0.44734100E-01, -.11749500E+00, 0.43045300E-01, 0.13810300E-01, 0.32204900E-01, 0.21576100E+01, 0.21129500E+00, -.85904300E+00, -.10648500E+00, 0.16843400E+00, -.11047700E-01, -.23493400E-01, 0.18339300E+00, -.45265400E+00, -.34874500E+00, 0.13611700E+01, 0.52587900E-01, 0.24876000E+00, -.22314000E+00, 0.12918500E+01, 0.24396100E+00, 0.19045300E+00, -.23155100E-02, 0.53832400E-01, -.54454800E-02, 0.53878800E-01, 0.16405000E+01, 0.20908300E+00, 0.82822400E-01, 0.69891300E-01, -.63654200E+00, 0.37923400E+00, 0.24265800E+00, -.15040700E-01, -.20289200E+00, -.18385200E-01, 0.54550200E-01, -.25006800E+00, 0.27526700E-01, 0.17958700E-01, -.76847800E-01, 0.37317300E+00, 0.10091600E+00, -.55093900E-02, -.59863300E-02, 0.82082000E-01, -.56969400E-01, 0.22540700E+00, -.17889100E-01, 0.95786800E-01, -.53546200E+00, 0.27159700E+00, 0.25473200E+00, 0.70277800E-01, 0.51489100E-01, -.29927500E-01, 0.17042600E+00, 0.77521700E-01, -.48214200E+00, 0.47149700E+00, 0.82672800E+00, -.83001100E-01, 0.11891100E+00, 0.15707200E+00, 0.31579100E+00, -.39746100E+00, 0.56698400E-01, -.70851500E+02, 0.27193400E-01, 0.18914400E+01, -.70287900E+00, 0.76005000E+01, 0.51870600E+01, -.23852600E+02, -.21019900E+01, 0.63006800E+02, 0.11861400E+03, -.60129800E+02, -.36317400E+02, -.59227300E+02, -.10133300E+02, -.13177600E+02, -.22296600E+02, 0.13451300E+02, -.36340200E+02, -.79228800E+01, -.43847100E+02, -.54452800E+00, 0.22181200E+01, 0.20339600E+02, -.95973700E-01, 0.41747800E+02, -.57691600E+01, 0.15827600E+02, 0.13422300E+02, -.99379700E+01, 0.48640400E+01, -.16872600E+03, 0.50875000E+02, -.23868500E+02, -.20450500E+02, -.25289900E+02, -.83080600E+01, 0.45748900E+01, -.18855700E+02, -.86677800E+01, -.22401800E+02, 0.35906600E+01, -.23643700E+01, 0.11560200E+01, 0.31092700E+00, 0.52372800E-01, -.66007600E+00, 0.53686600E+00, -.68781300E+00, 0.72106400E+01, -.13970800E+00, -.30120500E+00, -.11188200E+01, -.94632300E+00, 0.64880500E+00, 0.13482700E+00, -.17260000E+01, -.86301300E+01, 0.33819600E+00, -.10236900E+00, 0.85719000E+00, -.10455100E+01, -.13368500E+02, 0.80019200E+00, -.70131500E+01, 0.11159900E+02, -.29198200E+00, 0.79658300E+01, -.89013700E+00 },
        { 0.15171400E+02, -.41793200E+00, -.57070500E+00, 0.30820700E+01, 0.20121800E+01, -.46544400E+01, 0.21733100E+01, -.12984100E+01, 0.92209500E+00, -.45926000E+01, 0.20325400E+00, 0.96548000E+00, 0.88201300E-01, 0.25584900E+00, 0.19512100E+01, -.69718300E+00, 0.62291800E+00, 0.76029600E+00, 0.73164300E+00, -.22830900E+01, -.10747400E+01, -.55882900E+00, 0.23357500E+02, 0.29919100E+01, -.21914200E+00, 0.28479400E+00, -.80942000E+00, 0.67311000E+00, -.73805200E+00, -.25193500E+01, -.91053600E+00, -.10173600E+01, 0.71648800E-01, 0.91387000E+00, 0.12549700E+01, -.36164100E-01, 0.33462500E-01, -.62889900E+00, 0.61392800E-01, 0.10804600E+01, 0.11907200E+00, -.14002100E+01, 0.61646800E+00, -.59264100E+00, 0.86282100E+00, -.14526300E+00, 0.69548100E+00, -.32247800E-01, 0.94406100E+00, 0.25143400E+00, 0.24275100E+01, -.98479800E+01, -.66859200E-01, 0.28850200E+00, 0.56339600E+01, 0.33270100E-01, -.79112800E-01, -.12973200E+01, 0.20238700E+00, 0.38535700E-01, 0.13634800E+01, -.21684800E+00, -.44660500E+00, 0.15541100E+00, 0.98087600E+00, 0.38185700E+00, 0.63369700E+00, -.21431800E-01, 0.74139100E+00, 0.10054600E-02, -.16606100E+00, 0.52382400E-01, -.65284300E-01, 0.15732100E+00, -.18864500E+01, -.10171000E+00, 0.10248900E+01, 0.79102000E+01, -.11131600E+01, 0.57560800E+00, 0.19263000E-01, 0.91886000E+00, 0.21195900E+00, -.89378100E+00, 0.25393000E+00, -.34198600E+01, -.80025200E-01, 0.28181900E+00, 0.18770300E+00, 0.64195400E+00, -.64315700E+00, -.43965600E-01, -.84717600E+00, 0.20898200E+00, -.12241900E+00, -.33006200E+00, -.41193900E+00, 0.33791700E+00, -.94183300E+00, -.21716800E+00, 0.35731800E-01, 0.16528600E+00, 0.45374500E+00, 0.31630600E+00, 0.12439000E+00, -.33085500E+00, -.18199900E+00, 0.53621300E+01, 0.33818400E+00, -.23797500E+00, -.28284600E+01, -.75994400E-01, -.48614200E+00, -.33052500E-01, 0.78721900E+00, 0.46870300E+00, 0.26431500E+00, -.37287400E+00, 0.26651600E+00, -.34511100E+00, -.40648300E+00, 0.14489500E+00, 0.91543600E-01, 0.10690000E+01, -.11856700E-01, -.28972000E+00, 0.14886800E+00, 0.19120200E+00, 0.21497900E+00, 0.26141400E+01, 0.10658500E+00, -.53986300E-01, 0.14564200E+00, -.20456000E-01, 0.22104400E+01, -.27758800E+01, -.16716700E+00, 0.25199100E+00, -.18001000E+01, -.16808500E+00, 0.20268700E+01, -.72050000E+00, 0.18228000E+00, 0.84335500E+00, 0.21181700E-01, 0.14474900E+00, -.36791400E-01, -.73529100E-01, 0.47396200E+00, -.38267200E+01, -.41420700E+00, 0.37253600E-01, 0.30331600E+00, 0.58893300E+00, 0.36397000E+00, -.25322200E+00, -.22181500E+00, -.11319300E+00, -.26170300E+01, 0.52346300E+00, 0.91484100E+00, -.90794000E+00, -.12918300E+00, 0.51861000E-01, 0.33352200E-01, -.93711500E+00, -.11021900E+00, 0.27844100E-01, -.90687800E-02, 0.42185500E+00, -.17304200E+00, 0.21792000E+01, 0.89053400E+00, 0.38969100E+00, -.40689800E+00, 0.18055600E+00, -.68239800E-02, 0.61123800E-01, 0.18887600E+00, 0.81899900E+00, 0.10826400E+01, -.43456600E+01, 0.15843200E+00, 0.49507800E+00, -.22253600E+00, -.54620000E+00, -.69852100E-01, -.15743000E+00, -.25277000E-01, 0.21857500E+00, 0.51181100E-02, -.15239600E+00, -.72297200E-01, -.70186500E+00, -.85391300E+00, -.66741400E-01, -.35784000E+01, 0.19319500E+01, 0.61896000E+00, 0.68358300E-02, 0.10578700E+01, 0.36156000E-02, 0.34602100E+00, -.30633800E+00, -.10575000E+00, -.12404700E+00, 0.14894600E+00, -.40857700E+00, -.42339100E-01, -.16856000E+00, -.67307000E-01, 0.64631400E+00, 0.73813800E-01, 0.26039400E+00, -.17842300E+00, 0.61675200E+00, 0.83162500E-01, -.96674800E+00, -.39630800E+00, -.14312900E+00, -.19939300E+00, -.20053100E-01, -.27019700E+00, -.38506000E-02, -.49839600E+00, 0.25754000E+00, 0.43841000E+00, 0.53370300E-01, 0.85286800E+00, 0.23626200E+00, 0.78243500E+00, -.44761600E+00, 0.12719700E-01, 0.14778700E+01, 0.32240200E+01, -.52640900E+01, -.53681800E+01, 0.81103100E+01, 0.18931800E+02, 0.10668500E+02, -.78266300E+01, -.15516700E+02, -.11979400E+02, 0.50733000E+00, -.73877800E+02, 0.59026400E+01, 0.38462400E+01, 0.41935100E+01, 0.34293800E+01, -.20755300E+02, -.11742600E+02, 0.56858800E+01, 0.24492600E+02, -.23102800E+02, 0.78840900E+01, 0.10658300E+03, 0.11393600E+02, -.26735600E+02, 0.13261600E+02, 0.46818700E+01, -.96046900E+01, -.54789500E+01, 0.74764000E+01, -.23045300E+02, -.14230800E+01, -.13177100E+01, 0.56375700E+02, 0.55551100E+00, 0.12561000E+02, 0.22948000E+02, -.26231000E+02, -.63995800E+01, -.18244000E+02, 0.17328900E+02, 0.15845300E+02, -.62484300E+00, -.44572800E+00, -.13224400E+01, -.96313600E-01, 0.45526000E+00, -.34581600E+00, -.18302800E+01, -.62507900E-02, 0.16459500E+01, -.22115200E+01, 0.26116500E+01, 0.57199900E+01, -.55869200E+00, -.50392200E+00, -.52970700E+00, -.21528100E+01, -.54436100E+00, -.16560100E-01, -.85921300E-01, 0.38470500E+01, 0.34023100E+00, 0.10910200E+01, 0.20149400E+01, -.44237000E+01, -.78799700E+01, -.15026100E+01 },
        { -.67757400E+01, 0.25657700E+00, 0.18436600E+00, 0.15369200E+01, -.11368700E+01, 0.19844900E+01, -.98228200E+00, 0.10489300E+01, -.14250500E+01, 0.15480000E+01, 0.10177900E-01, -.88272200E+00, -.83249400E-01, -.13855500E+00, 0.65868800E+00, 0.22526100E+00, -.33086100E+00, -.99729800E-02, 0.99980100E-01, 0.10784600E+01, 0.61277100E+00, 0.93513800E-01, -.82709500E+01, -.16039200E+00, 0.26908700E+00, 0.71398600E-02, -.11778100E+00, 0.91661700E+00, 0.20159500E+01, 0.54948900E+00, 0.70472200E+00, 0.12312500E+01, -.13446300E+00, 0.70300800E+00, -.27594000E+01, -.50296700E+00, 0.40750600E-02, -.31136400E+01, 0.28267000E+00, -.73405400E+00, 0.23159300E+00, 0.11369900E+01, -.83958200E-01, -.15474300E+01, 0.14273200E+00, -.91149500E-01, 0.24085600E+00, 0.35764600E-02, -.62692300E+00, 0.20462200E+00, -.21154300E+01, 0.14119500E+01, 0.14834400E+00, -.24068000E+00, -.26083200E+01, -.22823900E+00, 0.62771700E-01, 0.47033000E+00, 0.18859700E+00, 0.17297300E+00, -.78322100E+00, -.72015200E+00, -.26013900E+00, 0.18229500E+00, -.28682100E+00, -.59433700E+00, 0.42355700E+00, -.16167700E-01, 0.10268000E+00, -.50630200E-02, 0.20377600E+00, 0.19817800E+00, 0.19180600E+00, 0.13878800E-01, 0.19757500E+01, -.61260300E-01, 0.88491800E+00, 0.18045700E+01, 0.12425800E+01, 0.19584600E-01, 0.50004700E-01, -.11623000E+01, -.13420200E+00, 0.31432600E+00, 0.24310700E+00, -.42264800E+00, -.32315400E+00, 0.45438300E-01, 0.22741000E+00, -.19456600E-02, 0.13760800E+00, 0.66877700E-01, 0.36428200E+00, -.18163100E+00, 0.81535400E-01, -.29385800E+00, -.43574200E+00, -.15202300E+00, 0.79341800E+00, -.23348100E+00, -.13471400E+00, -.57208400E+00, 0.47758300E+00, 0.39186900E+00, -.11008700E+00, -.31413100E-01, -.11905700E+00, 0.63590200E+00, 0.21323400E+00, -.10694500E+00, 0.32199600E+01, -.56750500E-01, 0.10146000E-01, -.22254200E-01, -.11717900E+01, 0.39811500E+00, -.65437200E-01, -.27602600E+01, 0.48075700E+00, 0.23638800E+01, -.21509300E+00, -.53100100E-01, 0.34360000E-01, 0.69954000E-01, -.21420100E-01, -.65525900E+00, -.48177300E-01, 0.27503200E+00, -.30511500E-01, -.72133900E+00, 0.21662400E+01, -.19781700E+00, -.26519800E+00, 0.31476700E-01, 0.15594300E+01, 0.18397200E+00, -.44428100E-01, -.16650400E+00, 0.98113300E+00, -.21464200E+00, -.23319000E+00, 0.92307100E-02, 0.54144500E-01, -.70911800E+00, 0.30428900E-01, 0.78746800E-01, -.11576900E-01, -.18259500E+01, 0.26368800E+00, 0.42969900E+00, -.13667900E+00, 0.23071100E+00, 0.17925800E-01, -.81342300E-01, -.10246300E+00, -.14518900E+00, 0.64979100E-01, -.58971900E-01, -.28189500E+00, 0.27727700E+00, 0.13132800E+00, -.21447400E+00, 0.13849200E+00, -.47145500E+00, 0.52595700E-01, -.17302000E-01, 0.83246100E-01, 0.66209800E+00, -.23400200E+00, -.16509600E+00, 0.97728300E+00, 0.13222500E+01, -.37792500E+00, 0.16198800E+01, 0.12992400E+00, -.20827300E+00, -.30484300E-01, 0.12408200E+00, 0.72757800E+00, 0.12330800E+01, 0.59551500E+00, -.44135500E+00, 0.34408400E+00, 0.61058700E-01, -.25348400E+00, -.10046000E+01, -.65449700E+00, -.78923900E-01, -.80726400E-01, -.11849100E+00, 0.11812700E-01, -.13720600E+00, 0.86253700E-01, -.65681100E+00, -.86459000E+00, 0.77448700E-01, -.11821700E+01, 0.48026100E+00, 0.17704700E+00, -.76219300E-01, 0.60406100E+00, -.15366400E-01, -.26907100E+00, 0.11785500E+00, -.16739200E-01, -.25996600E-01, 0.86087400E-01, -.42591000E+00, -.31935700E+00, -.13471100E+00, 0.54036000E-01, -.14274000E+00, -.73786300E-01, -.10459800E+00, -.44526300E-01, -.33585900E+00, -.70062700E+00, 0.56893200E+00, 0.28800700E+00, 0.10848500E+00, 0.21107400E+00, -.50993400E-01, -.44633100E+00, 0.74006100E-01, 0.27757000E+00, -.32238800E+00, 0.53512600E+00, 0.23920800E+00, -.54974300E+00, -.28131000E-01, -.35460300E+00, 0.18706900E+00, 0.55173300E-01, 0.27133600E+00, -.75997400E-01, 0.22318400E+02, 0.81741900E+01, -.19906800E+02, 0.87894300E+01, 0.27322500E+02, 0.69355600E+01, -.23202500E+02, -.80308600E+02, 0.35592800E+02, 0.22591900E+02, 0.39909800E+02, 0.90414900E+01, 0.11269000E+02, 0.26679600E+02, -.20516400E+02, 0.75692400E+01, 0.12695700E+02, 0.51409800E+02, 0.88878100E+01, -.55923600E+01, 0.10657900E+03, -.43743600E+01, -.22143700E+02, -.12859700E+01, 0.56547200E+01, 0.18978200E+02, 0.99930200E+01, -.81733100E+01, 0.22582200E+02, 0.82094600E+01, -.31695000E+01, 0.11202800E+02, -.41152500E+01, 0.52101300E+01, -.13828800E+01, -.47161100E+01, 0.31823800E+01, -.24412700E+02, -.39293500E+01, -.14345000E+02, -.15487900E+01, -.96901300E+00, -.54695700E+00, 0.31125100E+00, -.68372500E-01, 0.41999600E+00, -.57514700E+01, -.59739000E-01, 0.96493400E+00, 0.72556700E+01, -.76249300E+01, -.10405000E+02, 0.95630700E+00, 0.11885900E+01, 0.52763900E+01, 0.77182200E+01, 0.70420300E+00, -.41364800E-01, 0.97048800E+00, 0.41228400E+01, -.85432600E+00, 0.61456400E+01, -.85645900E+01, 0.26810500E+01, -.39363200E+01, 0.10753600E+02 },
        { 0.46491300E+00, -.65014600E-01, -.20609500E-01, -.56848700E+00, 0.51724100E-01, -.95140900E+00, 0.34251300E+00, -.39752500E+00, 0.41797400E-01, -.10143100E+01, -.29383700E-02, 0.33486000E+00, 0.12017900E+00, 0.35711600E-01, 0.13708300E+00, -.35008700E-01, 0.11965100E+00, 0.25110100E-01, -.19974700E-01, -.11722800E+00, -.31500100E+00, 0.17530100E+00, 0.11230600E+01, -.93696200E-01, 0.63996500E-01, -.49517800E-01, 0.87251600E-01, -.18464500E+00, -.49537000E+00, 0.17148800E+00, -.31576300E+00, 0.15030900E+00, 0.41747900E-01, 0.86173600E-01, 0.52124600E+00, -.72965600E-01, -.22040500E-01, -.10368800E+00, 0.18193100E+00, -.13203500E+00, -.97866400E-01, 0.22681900E+00, -.74443200E-01, -.30411300E+00, -.45953300E-01, 0.98910200E-01, 0.59146800E-01, 0.75063200E-02, 0.33841300E+00, -.85541500E-01, 0.24847100E+00, -.55711700E+00, 0.42746800E-01, 0.11253800E+00, -.10639500E+01, 0.15201700E+00, -.58826200E-01, 0.42803600E+00, 0.12560500E+00, 0.36684700E-02, -.72724900E-01, -.11461800E+00, 0.49421700E+00, -.17429900E+00, -.26584700E+00, 0.75581300E-01, -.21758400E+00, -.59332000E-02, -.62077200E+00, 0.26856800E-02, -.93880700E-02, 0.99863900E-01, -.35511100E-01, -.16568700E-01, -.59765400E-01, -.58809100E-01, 0.16052800E+00, 0.20387700E+01, -.39354100E+00, -.20034800E-01, 0.49875100E-02, 0.54025600E+00, -.26449400E+00, -.56121000E-01, -.87703400E-01, -.11133500E+01, -.20050900E-01, 0.51048800E-01, 0.91492400E-01, 0.25350100E+00, 0.45168700E+00, 0.57309300E-02, -.16913300E+00, 0.17701800E-01, 0.65855200E-01, -.37927300E-02, 0.71856200E-01, -.14741700E+00, -.11744000E+00, 0.20525300E+00, 0.18962000E-01, 0.29287900E+00, -.22829600E+00, -.30947600E+00, -.18321200E-01, 0.13202600E+00, 0.22483500E-02, -.17119500E+01, 0.26746000E-01, 0.22356100E-01, 0.55543300E+00, -.24000100E-01, 0.11572800E+00, 0.58754200E-03, -.27147500E+00, -.17593900E+00, -.29410100E-01, 0.12874700E+01, 0.82254900E-01, -.39737000E+00, 0.31431200E-01, 0.24640300E-01, -.83258400E-02, 0.34903400E-01, 0.22084700E-02, 0.21104300E+00, 0.17696600E-01, -.11031300E-01, -.15501800E-01, -.16453100E+00, -.13577400E+01, 0.27063400E+00, -.50298600E-01, -.24659100E-01, -.53526800E+00, 0.30923000E+00, 0.20737600E-01, -.32628000E-01, -.76731900E-01, -.59116200E-01, -.14603400E+00, 0.73468300E-01, -.27435300E-01, 0.13655500E+00, -.12637600E-02, -.73867200E-01, 0.12861000E-02, -.22976500E+00, -.98967800E-01, 0.47746700E-01, 0.82986000E-01, 0.21613700E-01, 0.11519400E+00, 0.76160900E-01, 0.14160500E+00, 0.26254100E-01, 0.65585200E-01, -.20015400E-01, -.48398600E+00, 0.36591300E-01, 0.10652700E+00, 0.90182400E-02, 0.77605400E-01, -.17578100E-01, 0.34628500E-01, 0.87186400E-01, -.14054700E-01, 0.62284500E-01, -.95949500E-01, -.22426400E+00, -.24686100E-01, -.10103500E+01, -.32958500E+00, 0.80498300E+00, -.40171500E-01, -.47972500E-01, 0.94893100E-02, -.13366400E-03, -.97633300E-01, 0.29295400E+00, 0.11273700E+00, -.18600700E+01, 0.94631900E-02, -.17880000E+00, 0.69750700E-01, -.34827400E+00, 0.51907400E-01, -.75347800E-01, 0.14594900E-01, 0.11440600E-01, 0.21697400E-02, -.86762200E-01, -.82326100E+00, -.19747100E-01, -.61281400E-01, -.56385900E-01, -.38035100E+00, -.15736100E+00, -.10427400E+00, 0.59305400E-02, 0.18712500E+00, -.40478400E-02, 0.64666300E-01, -.88818900E-02, 0.14448500E-02, -.10850800E-01, 0.28060800E-01, 0.84833200E-01, -.20539800E-01, 0.25434700E-01, -.24660200E-01, 0.95877000E-01, 0.56613200E-02, 0.91314200E-01, -.59884000E-01, -.37076500E-01, -.27736400E+00, 0.98031300E-01, 0.29234400E-02, -.37143000E-02, 0.77055000E-01, 0.38648600E-01, -.62195400E+00, 0.91632300E-02, -.13722000E+00, 0.32252000E+00, 0.12264400E+00, 0.32433700E-01, 0.14151500E+00, 0.50899800E-02, -.94463100E-01, 0.12338500E+00, 0.23474900E-01, 0.16287100E-01, -.12543500E-01, 0.83992800E-01, 0.65091800E+01, -.12581200E+02, 0.49793500E+01, 0.13849800E+02, 0.44954200E+01, 0.23676400E+02, -.57267100E+02, 0.27210600E+02, 0.54476500E+02, 0.28594800E+02, 0.35879500E+01, -.38754200E+01, 0.15918000E+02, -.17179700E+02, 0.21994400E+01, -.33831900E+01, 0.42833400E+01, 0.37727600E+02, -.19337000E+02, -.29785200E+02, -.19005500E+02, 0.69746100E+01, -.10639500E+02, 0.50966700E+01, 0.97563300E+01, -.92561800E+01, -.62721700E+01, -.62155300E+02, 0.12841800E+02, -.48619300E+01, -.19154700E+02, -.63557000E+01, 0.39763900E+01, 0.62813900E+01, -.10563900E+02, 0.11676900E+01, 0.24086400E+00, 0.77644500E+01, 0.54365100E+01, -.40226600E+00, 0.88776700E-01, 0.26415100E+00, -.14666500E-01, -.40883000E+00, 0.99148900E-02, 0.84135800E+00, -.65505900E-01, -.19148300E+00, 0.64664100E+01, -.59502100E+01, -.13170400E+01, -.29902000E+00, -.70394400E+00, -.53731600E+00, 0.63464200E+01, 0.19455800E+00, -.31159700E+00, 0.24999500E+00, -.62471300E+00, -.24212300E+00, -.76262600E+00, -.14183300E+00, 0.49556600E+01, 0.13744100E+01, 0.59472300E+01 },
        { -.51973900E+02, 0.11243900E+01, 0.18698000E+01, 0.34441500E+01, -.57792000E+01, 0.85278300E+01, -.16245500E+01, 0.35097500E+01, -.20912600E+01, 0.60943200E+01, 0.96248200E-01, -.64241200E+01, -.56522200E+00, 0.77071900E-01, -.96353500E+00, 0.97614900E+00, -.13272000E+01, -.58656000E+00, -.57519600E+01, 0.41971700E+01, 0.28536200E+01, -.55932900E+00, 0.10100000E+02, 0.31102800E+01, 0.44822900E+00, 0.26028000E+00, -.36686900E-01, 0.55780600E+01, 0.77634200E+01, 0.16307600E+01, 0.46297600E+01, 0.72815700E+01, -.33717300E+00, 0.25095800E+01, -.79637300E+01, -.19648400E+01, -.27446200E+00, -.51056900E+01, 0.76663300E+00, -.29612900E+01, 0.25653400E+01, -.21737000E+01, 0.57151400E+00, -.62942400E+00, 0.46620800E+00, -.80317000E+00, 0.29758300E+00, 0.97619800E-01, -.33758300E+01, 0.63861900E+00, -.30251700E+01, -.32669200E+01, 0.30210100E+00, 0.61856500E-01, 0.10653600E+02, -.25163200E+01, 0.22670700E+00, -.33018100E+01, 0.15504500E+01, -.41650800E+00, -.41337100E+00, 0.11634900E+01, -.38874200E+01, 0.40507300E+00, -.90539900E-01, -.84389300E+00, 0.55216900E+00, 0.56000000E-01, 0.10477200E+01, -.43959700E-02, 0.30917600E+00, -.12696900E+01, -.88210500E-01, 0.40159500E+00, 0.28298900E+00, -.77667000E+00, -.95764200E+00, -.75096400E+01, 0.10313800E+01, 0.12853700E+01, 0.20928500E+00, -.88389500E+00, 0.10618900E+01, -.15185600E+01, 0.19798700E+01, 0.16873400E+02, 0.54708700E-01, -.30518600E+00, -.16363100E+01, 0.19426900E+00, -.26471400E+01, 0.29087000E+00, 0.28312700E+00, 0.88705200E-01, -.16866800E+00, -.15232700E+01, -.56161200E+00, 0.87803100E+00, 0.27410200E+01, -.96967800E+00, 0.15234700E+00, -.13294700E+01, 0.12716400E+01, 0.89938900E+00, 0.81248900E-01, -.22983000E+01, 0.16934500E+00, 0.83283400E+01, 0.49463200E+00, -.49399700E+00, 0.24065700E+00, 0.90343500E-01, 0.84221200E+00, 0.21819200E-01, 0.28118700E+00, 0.33720600E+01, 0.36530200E+00, -.86659400E+00, 0.37439800E+00, -.51826900E+01, -.29139800E+00, -.34555300E+00, 0.68647000E-01, 0.10604900E+00, -.65641600E-02, -.16277600E+01, 0.17461200E-01, 0.80936300E+00, 0.39784800E+00, 0.29948500E+01, -.54365500E+01, 0.53324000E+00, -.42570700E+00, 0.91954400E-01, -.77538900E+01, -.57055000E-01, -.26543200E+00, 0.52298800E+00, 0.93987000E+00, -.19490300E+01, 0.19448700E+01, -.26468700E+01, 0.17145400E+00, 0.40010300E+01, 0.97495700E-01, -.24395600E+00, 0.16822300E+00, 0.18841400E+01, -.48484800E+00, -.58102000E+01, 0.32151100E-01, -.27162900E+01, 0.26729900E+01, 0.76364600E+00, 0.50022800E+00, 0.53607800E+00, -.30153300E+00, -.66019500E-01, -.48245000E+01, -.33459000E-01, 0.18326100E+01, -.10518300E+01, -.41313200E-01, 0.86341100E+00, 0.19259000E+00, -.84554900E+00, -.85600100E+00, -.18581600E+01, 0.11182700E+01, -.85395600E+00, -.49565000E+01, 0.16522400E+01, 0.36157200E+01, 0.91185500E+01, 0.13310700E+01, 0.14464900E+01, -.86617300E+00, -.15479400E+00, -.16567200E+01, 0.10595300E+01, 0.12418200E+00, -.53796300E+01, 0.79797400E+00, 0.13561500E+01, -.11767400E+00, 0.21793900E+01, -.13812100E+01, -.11736700E+01, -.44104300E-01, -.15856900E-02, -.46445400E-02, 0.22290100E+00, -.24071700E+01, 0.68429600E+00, 0.23753900E+00, 0.17077000E+00, 0.13380600E+02, -.41164300E+00, 0.14111600E+01, -.36359400E-01, -.17165400E+01, 0.25781300E-01, -.21103700E+00, -.21042700E+01, 0.18618300E+00, -.12482000E+00, 0.63426900E+00, -.39315600E+01, 0.11295300E+00, -.23908800E+00, 0.20531200E+00, -.61168800E+00, 0.19536500E+00, 0.11892900E+01, 0.53138400E-01, -.15330500E+01, 0.56819900E+00, -.67654200E+00, -.54997500E+00, -.11376500E+00, 0.37019000E+00, -.16547300E+00, -.39731000E+01, -.40514500E+00, 0.18462400E+01, -.11475400E+01, -.48415300E+01, 0.50844900E+00, 0.26884100E+01, 0.14061400E+01, 0.50181200E+01, -.53784700E+00, -.12962500E+00, -.28907100E+01, -.36337900E+00, -.96167200E+00, -.50428400E+01, 0.59939100E+02, 0.14548900E+03, 0.41033900E+02, -.31134300E+02, 0.37271400E+03, 0.83390400E+02, -.89663900E+02, 0.89267400E+02, -.42402300E+02, 0.52161600E+02, 0.94653500E+02, -.79884200E+02, -.10257300E+03, -.15187800E+03, 0.77500200E+02, 0.58068400E+02, 0.39744300E+02, -.25763600E+02, 0.30318800E+03, -.21902600E+02, 0.17694500E+03, 0.35931700E+02, -.46648700E+01, -.86215500E+02, -.19356300E+03, 0.90798000E+02, -.14091200E+04, 0.32897700E+03, -.15903100E+03, -.13233200E+03, -.16340200E+03, -.89149900E+00, 0.89409100E+02, -.23811500E+03, -.15314700E+03, -.35432700E+03, 0.89567600E+02, 0.95049700E+02, 0.28838000E+00, -.77522700E+00, -.12361500E+02, -.24951800E+01, 0.65922400E+01, -.10692000E+02, 0.48368000E+02, -.18749700E+01, 0.13701600E+02, -.28695600E+01, -.36020600E+01, 0.31497200E+02, -.89464300E+01, -.25589900E+02, -.65790200E+02, 0.58619700E+01, -.52524500E+01, -.46129100E+01, -.12135000E+02, -.53023500E+02, 0.11999600E+02, -.53029500E+02, 0.79546900E+02, -.54406400E+01, 0.12029200E+02, 0.14731800E+02 },
        { -.13089600E+02, 0.35743700E+00, 0.45110000E+00, -.17076500E+01, -.17133500E+01, 0.27903600E+01, -.19151800E+01, 0.12124900E+01, 0.10470900E+00, 0.20397500E+01, -.21699400E+00, -.33039800E+01, 0.35824200E+00, -.20612600E-01, -.14441900E+01, 0.89421100E+00, -.13784500E+01, -.12368500E+01, -.10477900E+01, 0.11754500E+01, -.32294500E+00, 0.64112100E-01, -.16787900E+02, -.11009800E+01, -.15478300E+00, -.19669700E+00, 0.91996500E+00, 0.17270200E+00, 0.48074900E+00, 0.34837300E-01, 0.67115600E+00, 0.24076000E+01, 0.74035000E-02, -.13070800E+01, 0.38515200E+00, 0.81724400E+00, 0.88117300E-01, 0.38533200E+00, 0.26565800E+00, 0.57308000E+00, -.59049700E+00, -.25824000E+01, 0.69138500E+00, 0.96676600E+00, -.11426900E+01, -.14331400E+00, -.71042400E+00, 0.51236500E-01, 0.64835500E+00, -.47983200E+00, -.48948700E+00, 0.14260800E+01, 0.41205100E-01, 0.89361500E-01, -.50547700E+00, -.21489200E+00, 0.33024700E-02, 0.10648300E+00, -.46172900E-01, -.31912200E-01, 0.10623400E+00, -.11460900E+00, 0.20345400E+00, -.20899500E-01, -.23944100E-02, 0.13466900E-01, -.20091000E+00, 0.16503300E-01, -.67271000E+00, 0.31419000E-02, 0.10858600E-01, 0.18543100E+00, -.27790900E-01, -.33815800E-01, 0.70015100E+00, 0.42284300E+00, -.49402600E-01, 0.14769400E+01, -.10835800E+01, 0.35321600E+00, 0.34801200E-01, -.24904100E+00, 0.31772000E-01, -.54973700E-01, 0.27995200E+00, -.16367500E+01, 0.17236400E+00, 0.13132900E+00, 0.35656500E+00, 0.37577900E+00, -.13601000E+00, 0.41873600E-01, 0.89772500E+00, 0.88909900E-01, 0.10069100E+00, -.17765400E+00, -.22768800E-01, -.16686200E+00, -.46598900E+00, -.38796500E-01, 0.37553900E-01, 0.36954200E+00, -.26147300E+00, -.13954600E+00, -.10032700E-01, 0.37536900E+00, 0.91328100E-01, -.89556500E+00, 0.16760400E+00, -.54995900E-01, 0.31658000E+00, -.30727000E-01, 0.13846000E+00, 0.11440000E-01, -.11268700E+00, 0.14998200E-02, 0.77412300E-02, -.28431400E+00, -.18518700E+00, 0.25542100E+00, -.14558600E+00, -.19205400E-01, -.40320800E-02, -.13316900E-01, 0.42416600E-02, 0.44268100E+00, 0.20307200E+00, 0.37652300E+00, -.44658200E-01, 0.87266200E+00, -.11395500E+01, 0.40554200E+00, 0.19766000E+00, 0.47826000E-01, 0.11492600E+01, -.55904700E+00, 0.13282900E-01, 0.26830700E-01, -.27738600E+00, 0.48815200E+00, 0.78960300E-01, -.20195100E+00, 0.58599800E-01, -.34538200E+00, 0.20615400E-02, 0.21315100E-01, 0.80746100E-02, 0.67341300E+00, 0.13907500E-02, 0.12821200E+01, -.11595700E-01, 0.28474800E+00, -.55844500E+00, -.10793800E+00, -.57426900E-01, 0.70813600E-01, 0.98021000E-02, 0.65571000E-01, 0.62268000E+00, 0.85444700E-02, 0.73256200E-01, 0.10516100E+00, -.60576500E-01, 0.12802500E+00, -.12610700E+00, 0.23878000E+00, 0.91223600E-01, -.28459500E+00, 0.14501900E+00, 0.87012700E-01, -.47089500E+00, 0.31121700E-01, 0.27456000E+00, -.14202600E+01, -.11692400E+00, -.19400900E-01, -.73555600E-02, 0.24235600E-01, 0.16575200E+00, -.50769100E+00, -.21047500E+00, 0.87912900E+00, -.41380200E-02, -.12255800E+00, -.68149000E-01, 0.79058700E+00, 0.38880000E+00, 0.33667300E+00, 0.60968100E-02, 0.55222000E-01, -.92476300E-02, -.14119900E-01, 0.56197000E+00, 0.45246000E-01, 0.22630300E+00, -.31369600E-01, -.98191200E+00, 0.13448300E-01, 0.17900300E+00, 0.10769700E-02, -.52055800E+00, -.22825500E-01, -.21109200E+00, 0.51696300E+00, -.12423200E+00, 0.84446500E-01, -.18021700E+00, 0.27624900E+00, -.47419500E+00, 0.19026200E+00, 0.59554300E-01, 0.65005900E-01, -.22394600E-01, 0.11066300E-02, -.13977100E+00, -.19318600E+00, -.40892600E-01, 0.23908700E-01, -.63446800E-01, 0.13086000E-01, 0.37490100E-01, -.36297300E-01, 0.50300500E+00, 0.77323400E-01, -.17252400E+00, -.10547200E+01, 0.65908700E-01, -.26600900E+00, -.23297300E+00, 0.62475300E-01, -.10829200E-01, -.23719300E+00, -.52906700E-01, -.53548600E+00, -.73468900E-02, 0.14184200E+00, 0.11853900E+00, 0.13329600E+00, -.34964000E+02, -.41279900E+02, 0.30131500E+01, -.22458400E+02, 0.11598600E+03, -.44106100E+02, -.49622700E+02, -.57534700E+02, -.18199800E+02, -.48996900E+01, 0.12777400E+01, 0.95820500E+02, 0.31486700E+02, -.87908800E+01, -.50431000E+02, 0.24141900E+01, 0.25604900E+01, -.17722400E+03, -.11152000E+01, 0.32468000E+02, 0.30353800E+00, -.19283700E+02, 0.44969700E+01, 0.23943800E+01, 0.29274900E+01, 0.75689300E+02, -.11556800E+03, 0.56735700E+02, 0.18930700E+01, 0.61013300E+02, -.10058000E+01, -.41007300E+02, 0.57196900E+02, -.12413300E+02, 0.49615400E+02, -.30694500E+02, -.24745300E+02, 0.89420700E+00, 0.12436000E+01, 0.10254000E+01, -.29335300E+00, -.19478600E+00, 0.78163600E+00, 0.21432600E+01, 0.10320800E+00, -.19804600E+01, -.61562700E+01, 0.57291300E+01, 0.43893600E+01, 0.60110800E+00, 0.23688200E+01, 0.94222200E+00, -.78148900E+01, 0.48974100E+00, 0.11099300E+01, -.65656900E+00, 0.28513700E+01, 0.61689400E-02, -.17963400E+01, -.19108300E+01, -.64574400E+01, 0.70948800E+01, -.73082600E+01 },
        { -.81890300E+01, 0.17573900E+00, 0.26746500E+00, 0.53102800E+00, -.11797800E+01, 0.19240200E+01, -.60172200E+00, 0.11739800E+01, -.10001100E+01, 0.14400700E+01, 0.78754400E+00, -.36523100E+01, -.15185100E+00, 0.44127500E-02, 0.77939100E+00, 0.53454800E+00, -.69420200E+00, 0.27322500E+00, -.38969700E+00, 0.94217900E+00, 0.15893000E+01, -.10007600E+01, 0.50175300E+01, 0.19559000E+01, -.81267300E-01, 0.23157000E+00, -.69761200E+00, 0.14801900E+01, 0.32944100E+01, -.11831000E+01, 0.45279200E+00, -.31222500E+01, -.52223600E+00, 0.47771900E+00, -.18371200E+01, -.73389700E-01, 0.11350900E+00, -.13253700E+01, 0.11441000E+00, -.41200300E+00, 0.39232500E+00, -.35257200E+00, 0.29318300E+00, -.73035000E-01, 0.13922200E-01, 0.19073200E-01, -.26482500E-01, -.21343800E-01, -.67493300E+00, -.45698900E-02, -.65710600E+00, 0.33281000E+01, 0.45107800E-01, 0.14235000E+00, 0.26084900E+00, -.56058600E+00, 0.28677200E-01, -.13482400E+00, -.69056200E+00, 0.32100200E-01, -.16790000E+00, 0.13181200E+00, 0.39418800E+00, -.38254800E-01, -.13020600E+00, 0.10549400E+00, -.32913400E+00, 0.25368400E-01, -.85454600E+00, 0.79805200E-03, 0.53436000E-01, 0.21211300E+00, 0.46272700E-01, -.28629500E-01, 0.57465500E+00, -.10011100E+00, -.31830500E+00, -.24031100E+00, -.13191300E+01, 0.47998200E+00, -.19408000E-02, -.47369400E+00, -.79159000E+00, 0.55413300E-01, 0.90116700E-01, 0.78503600E+00, 0.36426900E+00, -.81152900E-01, 0.12606000E+00, 0.47732100E+00, 0.16074500E-01, 0.21003900E-01, -.80545100E-01, 0.14489800E+00, -.51487600E-01, -.10838200E+00, 0.60503000E-01, -.18057200E+00, 0.53484400E+00, -.46285200E+00, 0.16322900E+00, 0.58505400E+00, -.30989600E+00, -.70359500E+00, -.91090700E-02, -.10959500E+00, 0.13492000E+00, 0.30693700E+01, -.20141300E+00, 0.10281900E+00, -.13248800E+01, 0.14560400E+00, 0.16691300E-01, 0.13004700E-01, 0.94457700E+00, 0.16712800E+00, -.49963600E-01, 0.10376400E+01, -.40604400E+00, -.20947800E+01, 0.21312000E+00, 0.32967500E-01, -.21166300E-01, -.20464900E-02, 0.58097300E-02, 0.65708400E+00, -.12432600E+00, -.38748300E+00, -.11558700E+00, 0.10913400E+01, 0.39085800E-01, -.32210100E+00, 0.11351000E+00, -.73143200E-01, -.28047900E+00, -.50645500E+00, 0.21519700E-01, 0.99078400E-01, 0.15279300E+00, -.42419000E+00, -.23425800E+00, 0.33952700E+00, -.12836600E-01, -.31029100E+00, -.44948200E-01, -.34913000E-01, -.22196500E-01, -.33905300E+00, 0.52537100E-01, -.70579400E+00, -.24259500E+00, 0.42221600E+00, -.37067900E+00, -.76136000E-01, -.23369000E-01, 0.56897500E-01, 0.20348200E+00, -.35209600E-01, 0.10898600E+01, -.34352700E-01, -.90409500E+00, 0.19555100E+00, -.68916900E-01, 0.68607600E-02, -.28217900E+00, 0.28533200E-01, 0.43392600E-01, -.21800000E+00, -.71543400E-01, -.96677000E-01, 0.32499700E+00, 0.81995800E+00, -.96601500E-01, -.14850000E+01, -.30141400E+00, -.40917600E-01, 0.48128300E-01, -.13126400E-01, 0.74884100E-02, 0.17210800E+00, -.34664400E+00, 0.45874800E+01, -.18166400E+00, 0.60185100E+00, 0.10722500E+00, -.32982800E+00, -.75572200E-01, -.53545300E+00, 0.51870300E-02, -.14941900E-01, 0.16076600E-02, 0.45476300E-01, -.11730400E+01, -.52859900E+00, -.63530100E+00, -.34924100E-01, -.78183700E+00, -.69595100E+00, -.63655700E-01, -.48814800E-01, 0.17214900E+00, 0.32521400E-01, -.74994000E+00, 0.68501400E+00, -.19702300E+00, 0.24660300E+00, -.46822600E-01, 0.17054000E+00, -.21255100E+00, 0.29559300E-01, 0.86613300E-01, -.15404400E+00, 0.15808600E+00, 0.79241000E-01, -.13881300E+00, -.22108200E+00, -.15900000E+00, 0.14931800E+00, 0.14704300E+00, 0.55151300E-01, 0.45550500E-01, -.82096900E-01, 0.14510000E+01, -.23646200E-01, 0.77405200E-01, -.11488900E+01, 0.61718900E-01, 0.59884700E-01, -.11729500E+00, 0.50632700E-01, -.29027300E+00, -.64677300E-01, -.56033200E-01, 0.72912300E+00, -.18192500E-01, -.48261800E-01, -.10874800E+01, 0.71554700E-01, -.76856800E-01, 0.26925700E+02, -.34002600E+01, -.27478400E+02, -.52096700E+02, 0.30337200E+02, -.12389500E+02, 0.26028700E+02, 0.62590800E+01, 0.19632700E+02, 0.35991100E+02, 0.43715400E+02, 0.30342200E+02, 0.69194600E+01, 0.23939500E+02, 0.41809300E+02, -.22247100E+02, -.46109800E+02, -.20344100E+02, 0.15093900E+02, 0.15420500E+02, -.38961900E+02, 0.28326200E+01, -.29298000E+02, 0.14305400E+02, 0.62273100E+02, -.96879300E+02, 0.46600500E+02, 0.16350900E+01, 0.48473100E+02, -.64621900E+01, -.48944300E+02, 0.46148400E+02, -.12318000E+01, 0.64669100E+02, -.37633100E+02, 0.92174900E+02, -.62370600E+00, -.10447300E+01, -.66695900E+00, -.27182100E+00, -.91397000E+00, 0.62189100E+00, -.27410100E+01, -.67224800E-01, 0.46103100E+00, -.85216500E+01, 0.11978700E+02, 0.45102400E+01, 0.10855600E+01, 0.76694000E+00, 0.24467900E+01, -.11403400E+02, 0.75728600E+00, -.21852600E+00, 0.79079800E+00, 0.15259500E+02, -.11114500E+01, 0.29457200E+01, -.42168400E+01, -.17203100E+02, -.77083100E+00, -.11125000E+02 },
        { -.25685600E+02, 0.82864600E+00, 0.83620500E+00, 0.20480800E-01, -.29086400E+01, 0.70570100E+01, -.19508200E+01, 0.28859200E+01, -.69304000E+01, 0.66417600E+01, -.55554200E-01, 0.91636800E-01, 0.54179500E+00, -.24570700E+00, -.79343900E+00, 0.27116800E+00, -.14895900E-01, -.53062600E+00, -.39086400E+00, 0.27253900E+01, 0.24793600E+01, -.21763500E+00, -.14310100E+02, -.16594300E+01, 0.65086200E-01, 0.46382400E-01, -.44046800E+00, 0.15678800E+01, 0.47861100E+01, 0.35329400E+00, 0.19810900E+01, 0.44759800E+01, -.27234400E+00, 0.14362000E+01, -.76663400E+01, -.54386600E+00, -.18550900E+00, -.10009900E+02, 0.13970600E+01, -.21018400E+01, -.48031000E+00, 0.34885300E+01, 0.18548800E+01, -.62801700E+01, -.11494300E+01, 0.40959600E+00, 0.29595400E+00, 0.71750000E-01, 0.92496300E+00, 0.34931700E+00, -.59134700E+01, -.16133700E+01, 0.58393800E+00, 0.97081800E+00, -.13450300E+02, -.13409800E+01, -.16966600E+00, 0.21408600E+01, 0.13869800E+01, -.34812900E+00, -.70395500E+00, -.72888400E+00, 0.48405100E-01, 0.44220700E+00, -.88023100E+00, -.55904800E+00, -.13164500E+01, 0.11194200E-01, 0.50996300E+00, 0.64474100E-02, 0.23265200E+00, 0.14609600E+00, 0.18458200E-01, 0.94707400E+00, -.11634900E+00, 0.14234500E+01, 0.13990300E+01, 0.14465200E+02, 0.15125200E+00, 0.18260200E+01, 0.19321000E+00, -.24509000E+01, 0.58663000E+01, -.82654400E+00, 0.41899400E+01, 0.11922800E+02, -.10336200E+01, 0.20611600E+00, -.16029400E+01, -.13372600E-01, -.11510500E+00, 0.10000000E+00, 0.28805800E+01, -.26718600E+00, -.17006300E+01, -.10600000E+00, 0.85906000E+00, -.45031200E+00, 0.29777900E+01, 0.76754400E+00, -.41796800E+00, -.22055700E+01, 0.69920000E+00, 0.11931200E+01, -.35266200E+00, -.29289800E+00, -.18621700E+00, -.53841600E+01, 0.22250900E+00, 0.13539100E+00, 0.73868200E+01, -.14120300E-01, 0.16315800E+01, -.17066500E-01, -.22363500E+01, 0.58386500E+00, -.33250700E-01, 0.95269700E+00, -.56838600E+00, 0.33800900E+01, -.90291600E+00, -.37450400E+00, -.78436900E-01, -.12585200E+01, -.45106600E-01, -.73538100E+00, 0.21646900E+00, 0.54547500E+00, -.76893700E+00, -.36702500E+01, -.65895300E+01, 0.15926300E+01, 0.64645800E+00, 0.15556400E-01, -.54757700E+01, 0.78919000E+00, -.10217500E+00, -.49053900E+00, -.65528400E+00, 0.17370700E+01, 0.97651200E+00, -.21614300E+01, -.24004100E-01, 0.26070300E+01, 0.13173000E+00, -.90288100E+00, 0.28641000E+00, -.27755800E+01, 0.52058600E+00, 0.53327000E+01, 0.20495300E+01, -.36308600E+01, 0.43079200E+01, 0.83678800E+00, 0.85564400E-01, -.77130400E-01, -.12456900E+00, 0.18095700E+00, -.53446100E+01, -.93447800E+00, 0.20027200E+01, -.74158100E+00, 0.80477000E+00, -.50790100E+00, 0.22609900E+00, -.13498900E+01, -.49023500E-02, -.73648800E+00, -.43552200E+00, 0.48120300E+00, 0.14462600E+01, -.90400100E+01, -.11619300E+01, -.34151300E+00, -.36644800E+00, -.19884200E+00, 0.35222100E+00, -.60789100E-01, -.89172400E+00, -.28917100E+00, -.13457200E+01, 0.15446600E+02, -.50247100E+00, 0.20310400E+01, 0.28230000E+00, -.22963700E+01, -.65610000E-01, -.72267200E-01, 0.31614800E-01, -.85852500E-01, 0.34943500E-02, -.72000500E-01, -.32926400E+01, -.67854300E+00, 0.68745200E+00, 0.15908100E-01, 0.28497200E+01, -.12225400E+01, 0.78900700E-01, 0.17658000E-01, -.19994600E+01, 0.71489500E-01, 0.22131900E+00, 0.70563000E+00, 0.33259000E-01, 0.39134000E+00, 0.72078900E-01, -.10072700E+01, 0.11756800E+00, 0.28655900E+00, 0.52292600E-01, 0.19702000E+00, 0.17364300E+00, 0.47444300E+00, -.21396400E+00, -.17189000E+00, 0.79209500E+00, -.87515800E+00, -.57499700E+00, -.16473800E+00, -.13346700E+00, -.91101500E-01, 0.13464500E+01, -.22300400E-01, -.70384200E-02, -.25621500E+01, -.61397700E+00, -.34871200E+00, -.37682600E+00, -.28848000E+00, -.55343800E+00, 0.34886800E+00, -.15975200E+00, -.12601500E+01, 0.68443500E-01, 0.56545800E+00, -.12910300E+01, 0.55467300E+00, 0.20557500E+01, 0.85866900E+00, 0.12186300E+02, -.11098400E+03, -.20157000E+03, 0.10528000E+03, 0.40215800E+02, 0.10063300E+03, -.44765800E+01, -.59619500E+02, 0.35604500E+01, -.91926400E+02, 0.41626100E+02, -.51777000E+02, 0.28110200E+02, 0.70306600E+02, -.33961100E+02, -.72580300E+02, -.34299000E+02, -.12747100E+03, -.45927900E+02, 0.16377700E+02, 0.30144100E+02, 0.63181900E+02, -.62379100E+02, 0.39967200E+03, 0.79889900E+02, -.38845500E+02, 0.49557700E+02, -.47448100E+02, -.37050800E-01, 0.56792800E+02, 0.10838600E+02, 0.75754200E+02, 0.76853800E+02, 0.47118300E+02, -.91932700E+02, -.53082400E+00, -.17538100E+01, 0.63810000E+01, 0.16913800E+01, -.26325800E+01, 0.42638100E+01, -.15617800E+02, 0.33475900E+00, -.63416100E+01, 0.77852000E+01, -.51084200E+01, -.99037200E+01, 0.39692900E+01, 0.71054700E+01, 0.18836200E+02, 0.64666800E+01, 0.31815900E+01, -.39493000E+00, 0.61806800E+01, 0.83548300E+01, -.52527600E+01, 0.18499600E+02, -.17693900E+02, 0.20560000E+02, -.12253100E+02, -.38438100E+01 },
        { 0.11290800E+02, -.27405100E+00, -.42547200E+00, -.14461200E+01, 0.14446600E+01, -.34320100E+01, 0.22506400E+00, -.13679900E+01, 0.30968700E+01, -.35216200E+01, -.71530400E+00, 0.10860600E+01, 0.93135000E+00, 0.24372700E+00, -.19264800E+00, 0.10620700E+00, -.20581100E+00, -.28821000E+00, 0.64876500E+00, -.23142400E+01, -.34123200E+01, 0.18811900E+01, -.34478700E+01, -.17817400E+01, -.33886000E+00, -.34295500E+00, 0.12756000E+01, -.17255800E+01, -.61232100E+01, 0.40352100E+00, -.10215500E+01, 0.45708100E+01, 0.77933900E+00, -.14986700E+01, 0.57770000E+01, 0.11315900E+01, 0.21436800E-01, 0.49893900E+01, -.31169500E+00, 0.27131600E+01, -.16395600E+01, -.31629400E+01, 0.13082900E+01, 0.70724100E+00, -.12459800E+01, 0.58522200E-01, -.67587500E-01, 0.56730700E-02, 0.31530200E+01, -.59585500E+00, 0.18948900E+01, -.40694400E+01, -.12049300E+00, -.23186300E+00, 0.57530600E+01, 0.81280100E+00, -.80179700E-01, -.36828600E+00, 0.42788600E+00, 0.34561000E+00, 0.18400400E+01, -.32026200E+00, 0.78089400E+00, -.28135400E+00, 0.65010000E-01, -.20126800E+01, 0.57979000E+00, -.90302600E-01, -.36571200E+00, 0.16122400E-02, -.39942700E+00, -.19662900E+00, -.51383600E+00, 0.50406000E-01, -.73913100E+00, 0.52531000E-01, 0.11690000E+01, 0.63945800E+01, 0.93893600E+00, 0.56873800E+00, -.24453700E-01, -.75154500E-02, -.18263200E+01, -.10614900E+00, -.94841300E+00, -.85300400E+01, -.58693500E+00, -.29610600E+00, 0.11201300E+01, -.21265800E+01, -.12025000E+01, 0.10162500E+00, 0.32457800E+01, 0.16345200E-01, -.59311800E+00, 0.16229300E+00, 0.37460600E+00, 0.12541900E+01, 0.48394400E+01, -.95379400E+00, 0.62149600E-01, -.40596100E+00, -.40454500E+00, -.26221000E+00, 0.17968400E+00, -.97634400E+00, 0.20692600E+00, 0.89979100E+01, -.20021600E+00, 0.24199800E+00, -.20205300E+01, 0.26940900E+00, 0.10212700E-01, 0.16507000E-01, 0.14446000E+01, 0.11853400E+01, -.12123400E+00, -.79453300E+01, 0.37547900E+00, -.34303200E+01, -.23819200E+00, -.54652700E+00, 0.25408600E-01, 0.22172200E+00, -.66034500E-02, -.58027100E+00, -.21248700E+00, -.59655200E+00, 0.33246100E+00, -.12859500E+01, 0.56663700E+01, -.51153800E+00, -.50170100E+00, -.37599800E-02, 0.16603700E+01, 0.87829600E+00, -.29944700E-01, -.30449700E+00, 0.48476900E+00, 0.58797500E-01, 0.15559400E+00, 0.30335600E+00, 0.18574200E+00, -.77213200E+00, 0.58863000E-01, 0.99495100E-01, -.42273900E-01, -.14054800E+01, 0.43077900E+00, -.20173900E+01, -.43278500E+00, 0.11655500E+00, 0.89223200E-02, 0.31723400E+00, 0.94054300E-02, -.14937200E+00, -.69934500E-01, -.11133100E-01, -.22497000E+01, -.29878100E-01, 0.12260100E+01, -.66660900E+00, 0.12159200E+00, -.23726000E+00, 0.89122600E-01, 0.20064300E-01, -.13875800E-01, 0.10047700E+00, -.13040000E+00, 0.10543000E+00, 0.10265000E+01, 0.19553600E+01, -.11598000E+00, 0.18206300E+00, 0.65132200E+00, 0.91981000E-01, 0.43192500E-02, 0.83178800E-01, 0.32451700E+00, -.78019100E-01, -.23343700E+00, 0.50820900E+01, -.17597600E+00, 0.64072400E+00, -.66379300E-01, 0.64569800E-01, -.48090200E+00, -.26064000E+00, -.12023800E+00, -.87592400E-01, 0.13371600E-02, 0.51260300E-01, 0.81439300E+00, 0.10549300E+00, -.48041700E+00, 0.33517300E-01, 0.96643500E+00, -.12603100E+00, 0.40973000E+00, 0.14346300E-01, 0.82987600E+00, -.25912300E-01, -.26234800E+00, -.11332600E+00, 0.80269100E-01, 0.22792100E-01, -.28773000E-01, -.32754400E+00, 0.18898400E+00, -.34562200E-02, 0.24890000E-01, -.30964800E+00, -.16024700E+00, 0.13760100E+00, 0.26166200E+00, -.27146500E+00, -.51550200E+00, 0.23727400E+00, 0.30050000E+00, 0.80414300E-01, 0.89603500E-01, -.10316100E-01, 0.46122700E+00, 0.87355500E-01, -.31494800E+00, 0.96158500E-01, 0.13166600E+01, 0.36966500E+00, -.13952200E+00, 0.60740200E-01, 0.13481900E+00, -.63028700E+00, -.30849800E-01, 0.17974200E+01, -.24039800E-01, -.66021700E+00, 0.24190600E+00, -.44530700E-01, -.28270300E+00, 0.13706600E+00, 0.42595300E-01, 0.55807900E+02, -.95521400E+01, -.79662100E+00, -.69993300E+02, 0.46688600E+01, 0.72655500E+01, 0.25783000E+02, -.44362700E+01, -.17828200E+02, -.12274300E+02, 0.21901400E+02, 0.51292200E+02, -.48133800E+02, 0.20541700E+02, 0.67369800E+02, 0.24452900E+02, -.44100100E+02, 0.10021500E+02, -.18398400E+01, -.20438300E+01, 0.32136900E+02, -.49483600E+01, 0.13187200E+03, -.43312100E+02, 0.18073300E+02, 0.54865600E+02, 0.22738400E+02, 0.40068200E+01, -.15523000E+02, 0.16255600E+02, 0.95456500E+01, -.14118800E+01, -.19485500E+02, -.14863900E+02, -.18749100E+00, -.96591000E-01, -.47719700E+00, 0.53918100E+00, 0.16010600E+00, 0.39646300E+00, -.87646200E+01, -.12245000E-01, 0.33751400E+00, -.22915500E+01, 0.27779600E+01, -.21221600E+01, 0.65364700E-01, 0.28430600E+01, 0.88544000E+01, -.27344400E+01, -.31935400E+00, 0.16568400E+00, 0.91262300E+00, 0.12650500E+02, -.50510600E+00, 0.84562700E+01, -.86356600E+01, -.44218800E+01, -.78993500E+01, 0.16299600E+01 },
        { -.38422800E+01, 0.14228000E+00, 0.14842200E+00, -.10897100E+00, -.54171500E+00, 0.12314100E+01, -.10157200E+01, 0.67075400E+00, 0.40347000E+00, 0.84118800E+00, -.14696500E+00, -.69801300E+00, 0.21081800E+00, 0.17036900E-02, 0.16526500E+00, 0.30264600E+00, -.92648300E-01, -.13902200E-01, -.13731700E+00, 0.73529100E-01, -.87570100E-01, 0.17053800E-02, -.13804500E+01, -.17796500E+00, -.13110100E+00, 0.90749800E-02, 0.83512000E-01, 0.22877300E+00, 0.43950400E-01, -.17738500E+00, 0.31114900E+00, 0.90601100E+00, 0.65528500E-02, -.14687300E+00, -.11856300E+01, 0.15068700E+00, -.21773200E+00, 0.86100600E+00, 0.26865100E-01, 0.92276800E-01, -.12874400E+00, -.95856500E+00, 0.10752500E-01, 0.38488200E+00, -.20538900E+00, 0.37882200E-02, 0.78263900E-01, 0.38398900E-01, 0.16191000E+00, -.70224400E-01, 0.15290200E+00, -.58208200E+00, 0.92712900E-01, 0.24317800E+00, 0.24606900E+01, -.47437300E+00, -.89852200E-02, -.39427200E+00, 0.53612100E+00, 0.30603000E-01, -.20514200E+00, -.79114100E-01, 0.11935200E+00, -.18867600E-01, -.26656800E+00, 0.88937800E-01, -.60136100E+00, -.37169500E-02, -.55513000E-01, -.12930800E-02, -.88189800E-01, 0.63510000E-01, 0.13041400E+00, 0.60297600E-01, -.70415200E+00, -.25616300E+00, 0.21538500E+00, -.48295000E+00, -.87794200E-01, 0.59660600E+00, 0.18256100E-01, -.83949700E-01, 0.19948400E+00, -.37296000E+00, 0.81286500E+00, -.28515500E+00, 0.23225800E+00, 0.27983900E-01, -.39884500E+00, 0.15864700E+00, -.34759800E-01, 0.90656900E-03, 0.22223900E+00, -.15416700E+00, 0.13084800E-01, 0.51220200E+00, -.30558400E-01, -.56830000E+00, -.17361400E+00, -.18284000E+00, 0.52297600E-01, 0.20346300E+00, -.78091200E-01, -.45350800E+00, 0.19909800E+00, 0.69939100E+00, 0.17313700E-01, -.28817000E+01, 0.23775600E+00, -.99259300E-01, -.20395700E+01, 0.32058700E-01, -.18624300E-01, 0.12726900E-01, 0.89790200E-01, 0.89433000E-01, -.58947200E-02, 0.28456600E-01, 0.75132400E-02, -.33349500E+00, 0.71112900E-01, -.19081700E-01, -.11637100E-02, 0.10161500E+00, 0.19521800E-02, -.27131400E+00, -.54493600E-01, -.32100600E+00, 0.15365900E-01, -.39639500E+00, 0.54680000E-01, 0.75117800E-01, 0.65434300E-01, 0.25239300E-01, 0.25156500E-02, -.59524300E-01, 0.37814200E-01, 0.66356800E-02, -.13015000E-01, 0.33202500E+00, -.56061100E-01, -.17838600E+00, 0.13145300E-01, 0.79659200E-01, 0.23087000E-01, 0.33499700E-01, 0.95982000E-02, -.56318000E+00, 0.85101300E-03, -.74913800E+00, 0.31884600E-01, -.25852400E+00, 0.54207000E+00, 0.95186500E-01, 0.10877400E+00, 0.31642300E-01, 0.37793200E-01, 0.36658900E-01, -.84516800E+00, 0.15062400E+00, 0.56854900E+00, 0.81905200E-02, 0.13189800E+00, -.22574700E-01, 0.52161300E-01, -.12872600E+00, -.32759000E-01, 0.10538500E+00, -.19896400E-01, 0.37749800E+00, 0.12122000E+00, 0.10240700E+01, 0.83586300E-01, 0.62566300E+00, -.40355200E-01, -.60844900E-01, -.40434100E-01, 0.34817600E-01, 0.54744900E+00, 0.34769200E+00, 0.43729500E+00, -.22030100E+01, 0.10000600E+00, -.29824900E+00, 0.36310800E-01, 0.20147600E+00, 0.13289700E-01, 0.39538300E+00, -.20252600E-01, -.37938100E-01, 0.11613100E-02, -.75096600E-01, -.31424500E+00, 0.30379100E+00, 0.49513400E-01, -.12163000E+00, -.10680200E+00, 0.35241900E+00, 0.23925400E+00, 0.48904100E-01, 0.51962400E+00, -.15625600E-01, 0.40466500E-01, 0.12671700E+00, 0.53751600E-01, -.39182800E-01, -.50130600E-01, -.25776400E+00, -.34373100E+00, 0.24197500E-01, -.12091900E-01, 0.21458800E+00, -.51468400E-01, -.15062200E-01, 0.98207800E-01, 0.12797000E+00, 0.21257800E+00, 0.29178800E-01, 0.59776100E-01, 0.14345400E-01, -.10151000E+00, -.15751300E-01, 0.14484000E+00, -.19792000E-01, 0.24536500E+00, -.31480800E-01, -.22294100E+00, 0.33154800E-01, -.83977800E-01, -.70729100E-01, 0.24061900E-01, 0.10753300E+00, -.52248000E-03, -.45786200E+00, 0.24943600E-01, 0.10123300E+00, -.37408100E-01, -.51632700E-01, 0.28737500E-01, -.54058500E+00, 0.39357100E-01, 0.20506800E+00, 0.96757000E+02, -.44328900E+02, 0.39653500E+01, -.48274800E+02, -.12037700E+02, -.25792100E+02, 0.15406900E+02, 0.65113400E+02, -.18128000E+02, -.22320300E+02, -.84748800E+02, 0.56681900E+02, -.27443700E+02, -.10068900E+03, -.28347300E+02, 0.19630400E+02, -.52627000E+01, -.44242100E+01, 0.74220000E+01, -.34152000E+02, 0.27650800E+01, -.60591000E+02, -.10101800E+02, 0.60693700E+01, -.33017400E+02, 0.51429500E+01, -.19544000E+01, 0.16142500E+01, -.97769100E+01, -.25445900E+02, 0.10994100E+02, 0.56724000E+01, 0.71127500E+02, 0.10465300E+01, 0.84872500E-01, 0.56450200E+00, -.41761200E+00, -.34791100E+00, 0.92803900E-02, 0.41560800E+01, -.24870800E+00, -.69493600E+00, -.52656300E+01, 0.60550400E+01, 0.21774500E+01, 0.15352000E+00, -.16083000E+01, -.48665600E+01, -.65011100E+01, -.23720900E+00, -.23885700E-01, 0.33959500E+00, -.33722500E+01, -.62646200E+00, -.39373700E+01, 0.44039300E+01, -.96096500E+01, 0.34827700E+01, -.85832500E+01 },
        { -.10749800E+02, 0.49787500E+00, 0.20737500E+00, -.83197500E+00, -.72279200E+00, 0.18235800E+01, -.78818600E+00, 0.76074300E+00, -.62745900E+00, 0.13929600E+01, -.15816100E-01, -.19555300E+01, 0.11623600E+01, 0.13692800E+00, 0.54900300E-01, 0.27464700E+00, -.28665200E+00, 0.23422700E+00, -.60682200E+00, -.21002600E+00, -.25436800E+00, -.53027500E+00, 0.70194700E+01, 0.10200000E+01, -.14676800E+00, 0.47508800E-01, 0.10942600E+00, 0.40437200E+00, 0.34165200E+00, -.22951500E+00, 0.19355100E+00, -.10393800E+01, -.58974000E-01, 0.48350000E+00, 0.32019500E+01, -.23985600E+00, 0.24377800E-01, 0.27192400E+01, -.34046200E+00, 0.74067600E+00, 0.19814800E+00, -.50734500E+00, -.26859900E+00, 0.13196500E+01, 0.84037300E+00, -.43419400E+00, -.32260700E+00, -.18595700E-01, -.72263400E+00, 0.31152200E-01, 0.14864300E+01, 0.64270200E+01, -.13072500E+00, -.32753100E+00, -.62641300E+00, 0.72937100E+00, 0.53151800E+00, 0.17784800E+00, 0.20911500E-01, -.13224700E+00, 0.23146100E-01, 0.17208700E-01, -.14961000E+00, 0.13527500E+00, 0.46933900E+00, 0.16931700E+00, 0.96595300E+00, -.11847500E-01, 0.14223800E+01, 0.18460800E-02, -.29233000E-01, 0.65572600E-01, 0.52566700E-01, 0.22293700E-01, -.36462600E+00, -.60389400E+00, -.25360700E+00, -.44547200E+01, 0.89401500E+00, -.60356800E+00, -.38145100E-01, 0.46193800E+00, 0.82044700E+00, 0.14773900E+00, -.11546900E+00, 0.21937900E+00, -.28481500E+00, -.17728100E+00, -.56670700E+00, -.10826800E+01, 0.32018200E+00, -.35816700E-01, -.15789000E+01, -.21219500E+00, -.82881400E-02, 0.43133100E+00, 0.13107500E+00, 0.12050600E+00, 0.20384300E+00, -.52081200E-01, -.19531700E+00, 0.20123700E+00, -.14441000E+00, 0.92981800E-01, -.10757300E+00, 0.20024900E+00, -.92592400E-02, -.19312200E+01, -.19960000E+00, 0.88372800E-01, 0.42985100E+00, 0.17786600E-01, 0.12454200E+00, 0.83705300E-02, -.24420500E+00, -.14754200E-01, -.85780900E-01, 0.80910200E+00, 0.64901600E-01, -.17544500E+01, 0.27176200E+00, -.31042200E-01, -.73422700E-01, -.43333000E+00, 0.70148800E-02, 0.44893900E+00, -.12532400E+00, -.55152800E+00, -.45057500E-01, 0.81488400E-01, -.11037000E+01, -.22014500E+00, 0.16137500E+00, -.75857300E-01, -.55930200E+00, 0.36317700E+00, 0.33092400E-02, 0.76240900E-01, 0.16737000E+00, -.27796400E+00, -.70547800E+00, 0.42288700E+00, -.99007700E-01, -.17280200E+00, -.41731400E-01, -.47286000E-01, -.16479100E-02, 0.13820400E-01, -.14254100E+00, 0.27471300E+00, 0.76564000E-01, -.36941400E+00, 0.67167800E+00, -.23824300E+00, -.14429200E+00, -.19780800E+00, -.17636000E-01, 0.49575500E-01, 0.99550600E+00, -.20081600E+00, -.21635100E+00, 0.30476100E+00, 0.56933000E-01, 0.59275100E+00, 0.11799400E+00, 0.93372300E-02, -.52490400E-01, 0.21147600E+00, -.15720400E-01, -.41402600E-01, 0.34477100E+00, 0.34755500E+00, -.39309000E+00, 0.10559000E+01, 0.10255900E+00, 0.13370500E-01, 0.34156300E-01, -.67205400E-02, 0.12222500E-01, -.72390400E+00, -.11175700E+00, 0.47682100E+00, -.72726000E-01, -.53034200E-01, -.51680500E-01, 0.41912300E+00, 0.13251000E+00, 0.50366900E+00, 0.35053400E-01, 0.53021200E-01, -.37873400E-02, 0.10884500E+00, 0.16448600E+01, 0.23540200E-01, 0.58287700E+00, -.70415400E-01, -.46862700E+00, 0.22577000E+00, -.34616800E+00, 0.68693400E-02, 0.19335700E+00, -.27764800E-02, -.32914000E+00, -.85604600E-01, 0.72805900E-01, 0.19443500E+00, -.30389400E-01, -.94038300E-01, 0.28846200E+00, -.69937500E-01, -.19753100E-01, -.21774500E+00, -.52578600E-01, -.70538200E-01, 0.15764400E+00, -.18768700E+00, -.39895400E+00, 0.30318000E+00, 0.29260000E+00, 0.61618400E-01, 0.28125100E-01, -.21600700E-01, 0.19814100E+00, -.14769400E-01, -.37037500E+00, -.78642300E-01, -.36617600E-02, -.67519300E-01, -.72782700E-01, -.24373200E-01, 0.21748300E-01, 0.41706200E-01, 0.13141200E-01, -.89119600E-01, 0.14162700E-01, -.28075800E-01, -.26968900E+00, -.58280700E-01, -.87921500E-01, 0.13870700E+00, 0.93320800E-02, 0.58743700E+00, 0.17175400E+00, 0.69279000E+02, 0.63844000E+02, 0.44672400E-01, -.61223200E+01, -.27937500E+02, -.81932700E+01, -.28883600E+01, 0.41057400E+01, -.22037400E+02, -.40535700E+02, 0.11855600E+02, -.14394900E+01, -.93874000E+02, -.61786500E+01, 0.45357300E+02, -.69503100E+01, 0.38888400E+01, -.89443600E+01, -.15250000E+02, 0.76948300E+01, -.13733300E+03, 0.57961900E+02, -.16688500E+02, -.49699000E+02, -.29286100E+02, -.63170500E+01, 0.99018400E+01, -.65003400E+01, -.15047400E+01, -.14011600E+02, 0.13263300E+02, -.25809000E+02, 0.70240500E+00, 0.85122100E+00, 0.48619600E+00, -.30729900E+00, 0.73635300E-01, -.60303000E+00, 0.68001500E+01, -.20330400E+00, -.42249100E+00, 0.22937300E+01, -.29653100E+01, -.17108100E+00, -.88931900E+00, -.26521600E+01, -.61670900E+01, 0.33546400E+01, -.85696300E-01, -.49273800E+00, -.14664000E+01, -.17331000E+02, 0.11526500E+01, -.65256300E+01, 0.66099400E+01, 0.52479300E+01, 0.77722500E+01, 0.48932400E+00 },
        { 0.34626000E+01, -.14434200E+00, -.16374200E-01, 0.82260700E+00, 0.47463300E+00, -.10464100E+01, -.33586500E+00, -.12227700E+01, 0.52709700E+01, -.52807800E+00, -.18520000E-02, 0.14617300E+01, -.13979400E+00, -.37247900E-01, -.10800500E+00, 0.11283400E-01, 0.19207200E+00, 0.76937400E-01, 0.71810600E+00, -.19214100E+00, -.99277000E+00, 0.11081800E+00, -.30784000E+00, -.88990900E+00, -.17979600E-01, -.57348000E-01, 0.20494200E+00, -.51635700E+00, -.87637000E+00, -.11051000E+01, -.22171000E-01, -.44201600E+00, 0.35541600E-01, 0.50124700E+00, 0.59637800E+01, -.13610400E+00, 0.14403000E+00, 0.12208400E+01, -.31532200E+00, 0.99308800E+00, -.10725600E+00, -.13164700E+01, -.47923400E-01, 0.14683000E+01, -.12059500E+01, 0.91677900E-01, -.33231300E+00, -.13491400E-01, 0.50808800E-02, -.82933000E-02, -.73534100E+00, -.10478400E+00, -.13942000E+00, -.68460900E+00, 0.27026500E+01, 0.52686200E+00, 0.12228800E+00, -.14215800E+01, 0.18784600E-01, 0.13970500E-01, 0.43082700E+00, 0.12271100E+01, -.10667000E+01, 0.26354500E+00, 0.91919800E-01, -.35838500E+00, 0.26073300E+01, -.30605500E-02, 0.13398900E+01, -.90552400E-02, 0.80003600E-01, 0.31073900E+00, 0.35363000E+00, -.19418200E+00, 0.10438800E+01, -.80320800E+00, -.14613800E+00, -.88605900E+01, 0.19518500E+01, -.53165500E+00, -.84793800E-01, -.10141700E+00, -.23208100E+01, 0.15979100E+01, -.19266200E+01, -.50912500E+01, -.39286000E+00, -.47551700E+00, 0.50427300E+00, -.26656600E+01, 0.79483600E+00, -.54583600E-01, -.11501400E+01, 0.16562300E+00, -.24103400E+00, 0.51529200E+00, 0.77957300E+00, 0.47351700E+00, 0.45422800E+00, 0.23827500E+00, 0.25250900E-01, -.10418900E+01, 0.29808100E-01, 0.92785900E-01, 0.19341300E+00, -.66955500E+00, 0.15510900E+00, 0.25494000E+01, 0.18282100E+00, -.21937300E-01, 0.97366300E+00, 0.82323100E-01, 0.45359600E+00, 0.88182100E-02, 0.63985200E+00, 0.61320100E+00, -.47850500E-01, 0.12448100E+01, -.11497500E+00, 0.99673400E+00, 0.45405600E+00, -.12330800E+00, -.17925000E-01, 0.43933500E+00, 0.59908000E-03, 0.59627700E+00, 0.18325100E+00, -.72459800E+00, -.10556900E+00, 0.18628000E+01, 0.51878400E+00, 0.53413400E+00, 0.33099600E-02, -.49312700E-01, -.18511800E+01, -.58803100E+00, -.79865100E-01, 0.65750600E-02, -.54345300E+00, 0.22468500E+00, -.65095300E+00, -.66402300E+00, -.91754900E-02, -.33777200E+00, -.20821000E-01, 0.53223700E-01, -.15577300E-01, 0.14554100E+01, 0.31896800E-01, 0.69313700E+00, -.93090600E-01, 0.61608400E+00, 0.12512600E-01, 0.41605400E-01, 0.87185900E-01, 0.84476800E-01, 0.74802900E-01, 0.15783500E-01, 0.14123200E+01, 0.13841800E+00, -.74655900E-01, 0.29263600E+00, 0.14814300E+00, -.39091900E+00, 0.11915500E+00, -.24092800E-01, -.14574700E+00, -.65138300E+00, 0.60011300E-01, 0.64632000E+00, -.12256100E+00, -.21967700E+00, 0.20604000E+00, -.11401800E+01, 0.99578000E-01, -.17255100E+00, -.54020700E-01, -.29783700E-01, -.35489400E+00, -.58738600E+00, -.43533600E+00, -.13867100E+01, -.22822300E+00, 0.48309300E+00, 0.39128300E+00, 0.14574000E+01, -.10960400E+00, 0.11821400E+00, 0.13030300E-01, -.21900200E-02, -.48676200E-02, 0.38616600E-02, 0.46985400E+00, 0.45344500E+00, -.76804700E-01, 0.12558500E+00, 0.64177600E+00, 0.35318700E+00, 0.29100100E+00, -.46208900E-02, -.58766900E+00, -.15047200E-01, 0.34555900E+00, -.57440900E+00, 0.13496800E+00, -.90241300E-01, 0.12533800E+00, -.70085100E-01, 0.41435000E+00, 0.82804000E-02, -.53042900E-01, 0.33755400E-01, -.35905400E-01, 0.62216700E+00, -.47900400E-01, 0.21189400E-01, 0.10043900E+01, 0.26942500E+00, 0.19470300E+00, 0.10622900E+00, -.10673800E+00, -.38083000E-01, 0.13006600E+01, -.38192700E-02, -.30410400E+00, 0.49435700E+00, -.25555600E+00, 0.29308900E+00, -.44404000E+00, -.19929200E+00, 0.52419300E+00, 0.24018900E+00, -.22559300E-01, 0.61569900E+00, -.37831400E-02, 0.15262200E+00, -.19372300E+01, 0.61564100E-02, -.29176200E-01, 0.68712900E+00, -.47875500E-01, 0.20062300E+00, -.93473900E+00, 0.40766500E-01, 0.17884000E+03, 0.58104700E-01, -.23957300E+01, -.18827900E+02, 0.12661300E+02, 0.48556200E+02, 0.32588800E+01, -.18310300E+02, -.12138400E+02, -.58970800E+02, 0.29447800E+02, -.69784500E+02, 0.29298200E+02, 0.32005200E+02, -.34880000E+01, 0.11513700E+02, -.74615800E+01, 0.45778700E+02, 0.55504700E+01, -.67416100E+02, 0.59416000E+02, -.27215600E+02, -.10244200E+03, -.30137500E+02, -.43529100E+01, 0.19300300E+02, -.23216200E+02, -.28428300E+02, -.11081600E+02, 0.25127100E+02, -.41179900E+02, 0.12536100E+01, 0.83140800E+00, 0.21187300E+01, 0.16161600E+00, -.11028000E+01, 0.14479800E+01, 0.86664700E+01, -.34033300E-01, -.24269400E+01, 0.94226200E+01, -.10459900E+02, 0.52447100E+01, -.12958000E+00, -.12935800E+00, -.79015500E+01, 0.10250100E+02, -.40163700E+00, -.12955500E+01, 0.70760700E+00, -.12756900E+02, -.65362600E+00, -.85061100E+01, 0.87367000E+01, 0.60619800E+01, 0.65365000E+01, 0.50907000E+01 },
        { -.10925300E+02, 0.29323500E+00, 0.37640500E+00, -.11475700E+01, -.12087100E+01, 0.22119500E+01, -.77148600E+00, 0.68841100E+00, -.57378500E+00, 0.17560500E+01, -.48142400E-01, -.18809000E+01, 0.15156200E+00, 0.30944500E-01, -.13432800E+01, 0.42087200E+00, -.52741900E+00, -.55481400E+00, -.53798900E+00, 0.48175200E+00, -.39300500E+00, -.15480000E+00, -.88689600E+01, -.22788500E+00, -.10170200E+00, -.77824200E-01, 0.23262400E+00, 0.54025500E+00, 0.71266300E+00, -.64448500E+00, 0.74552000E+00, -.37572100E+00, -.10708300E+00, -.61852100E+00, 0.11344100E+01, 0.46544500E+00, 0.24184700E+00, 0.18472000E+01, 0.12255300E+00, 0.92124500E+00, -.71906600E+00, -.13472600E+01, -.42045300E+00, 0.15535700E+01, -.22940300E+00, 0.22147600E-01, -.33979700E+00, -.24899000E-01, 0.12918000E+00, -.17637200E+00, 0.30941200E+00, 0.68450000E+00, -.26475200E-02, -.30037100E+00, -.17765400E+01, 0.89763200E-01, 0.21316700E-01, -.26916300E+00, -.82029500E+00, -.17979100E-01, 0.17844200E+00, 0.81277100E-01, -.59861900E+00, 0.18246900E+00, 0.82215300E-01, -.13679600E+00, 0.97545900E-01, 0.46890200E-01, 0.52299500E+00, -.17027500E-02, 0.20251300E+00, -.55605300E-01, 0.59748800E-02, 0.81793600E-01, 0.75775100E+00, 0.38851400E+00, -.22634900E+00, 0.11354000E+01, -.10753300E+01, 0.64404500E+00, 0.17184100E-01, -.15454900E+00, 0.57211900E+00, -.17668700E+00, 0.30965000E+00, -.34335300E+01, 0.16800000E+00, 0.36641300E-01, 0.28243100E+00, 0.10571700E+00, 0.81585400E-01, 0.13646200E-01, 0.11618900E+01, 0.60509000E-01, -.23549700E-01, -.11521800E+00, 0.38319500E+00, -.20734200E+00, 0.17821100E+00, 0.29384400E+00, 0.55108900E-01, -.34448000E+00, -.15618800E+00, -.24956900E+00, -.31026000E-01, 0.33951300E+00, 0.11515400E+00, 0.10194600E+00, -.15080700E+00, 0.71673300E-01, 0.14483300E+01, 0.28803500E-01, -.24234400E+00, 0.66486700E-02, -.35911500E+00, -.21796900E+00, -.11143700E-02, 0.96842300E+00, -.13305800E+00, 0.80363600E+00, -.69364700E-01, -.31252100E-01, -.80533200E-02, -.13645400E+00, 0.92027500E-02, -.55038000E-01, 0.23864700E-01, -.13331400E+00, -.10460700E+00, 0.15700500E+00, 0.60041600E-01, 0.65328900E-01, 0.82454100E-01, 0.71264300E-01, 0.10559000E+01, -.37542800E+00, -.52808400E-01, 0.93473200E-01, 0.50645700E+00, -.31883300E+00, -.42388100E+00, -.66990800E-01, -.94773100E-01, -.42035100E+00, 0.36898200E-02, 0.70122300E-01, -.26966000E-01, 0.98715700E+00, 0.57649700E-01, 0.25007400E+00, -.10477400E+00, -.13482500E+00, 0.12033900E+01, -.12881800E+00, 0.14395300E+00, 0.17817200E+00, 0.10612000E+00, 0.34500600E-01, 0.72510200E+00, 0.14292700E-01, 0.40909500E+00, 0.33740800E+00, 0.14488000E-01, -.14415200E-01, -.80340100E-01, 0.17719400E+00, -.27458200E-01, -.38849300E+00, 0.64420600E-01, 0.49440400E+00, -.31481500E+00, 0.79985000E+00, 0.27405700E+00, -.12778700E+01, -.13104900E+00, -.19583800E+00, 0.87272400E-02, 0.27483500E-01, 0.39133600E+00, 0.53986600E+00, 0.64349000E+00, -.56447600E+01, 0.80020800E-01, -.79476500E+00, -.99763200E-01, -.31022800E+00, 0.28820500E+00, 0.48557000E+00, 0.35815700E-02, 0.51212200E-01, -.41305300E-02, 0.47986100E-01, 0.21672400E+01, -.83836600E-01, 0.18370200E+00, -.11247600E+00, -.37266900E+01, 0.13663900E+01, 0.40921200E-01, 0.10911800E-01, 0.27571200E-01, -.49508100E-02, -.64572600E-01, 0.41279500E+00, 0.24688600E-01, 0.98835700E-02, -.95582600E-01, -.10828600E+00, -.20347000E+00, 0.67722300E-01, 0.18347100E-01, 0.30117400E-01, -.38809400E-01, -.25318100E+00, 0.10303000E+00, -.41894300E-01, 0.18170200E+00, -.27329000E+00, -.87474000E-01, -.27143300E-01, -.13653800E+00, 0.80447000E-03, 0.24348000E-01, -.56097100E-01, 0.29485500E+00, -.41202800E+00, -.47678400E+00, 0.25792200E-01, -.11826400E+00, -.67955300E-01, -.26206600E-01, 0.15771700E+00, -.45299700E-01, -.11391700E+01, 0.57785700E-01, 0.53144700E-01, 0.26547000E+00, 0.85802200E-01, 0.70880600E+00, -.27413700E+00, 0.20294200E+00, 0.22746700E+00, 0.24573100E+00, 0.37288900E-01, -.45239800E-01, 0.28571400E+01, 0.15547100E+01, -.50642600E+01, 0.11337500E+02, 0.12445300E+02, -.57241300E+01, 0.21121400E+01, -.16912400E+02, -.81994600E+01, 0.46198300E+01, 0.22268100E+02, 0.39050900E+01, 0.18734500E+02, 0.21987600E+01, 0.27988600E+00, -.40205800E+00, -.40532900E+01, 0.65293100E+01, -.38161900E+02, 0.54392500E+02, -.26865200E+02, -.28996700E+02, -.28130800E+02, -.76885200E+01, -.22701100E+01, -.15609700E+02, -.47115300E+01, -.12073300E+02, -.55861700E+01, 0.29098600E+02, 0.71505100E+00, -.25070000E+00, 0.20608200E-01, -.10457800E+00, 0.34796000E+00, -.52728800E+00, 0.29929400E+01, 0.12454000E+00, 0.12437600E+00, 0.29008300E+01, -.40577500E+01, 0.73876900E+00, 0.16684800E+00, -.15266300E+01, -.37568000E+01, 0.43023400E+01, -.40642400E+00, -.20202000E+00, -.52534300E-04, -.97777300E+01, -.32457400E-01, -.29746900E+01, 0.34042700E+01, -.66126300E+00, 0.37250900E+01, 0.19555900E+01 },
        { 0.48064600E+02, -.10140600E+01, -.17614700E+01, -.56680300E+01, 0.44433900E+01, -.54769600E+01, 0.60161500E+00, -.76008300E+00, 0.92928600E+00, -.44174100E+01, 0.38407100E-01, -.36521600E+01, -.74779500E-02, 0.78974700E-01, 0.33801200E-01, 0.25050900E+00, -.32432400E+01, -.98581900E-02, -.21574300E-01, -.12983000E+01, -.44532700E+00, -.20132000E+00, -.10633400E+02, 0.10134000E+01, -.14211200E+00, -.10957200E+00, 0.39791300E+00, -.27933200E+01, -.12259700E+01, 0.25872200E+01, -.40154600E-01, -.25202400E+01, 0.28897500E-02, -.19699600E+01, 0.17037200E+01, 0.10795600E+01, 0.49791100E+00, 0.60453100E+01, -.38408000E+00, 0.17796200E+01, -.92999900E+00, -.30201800E+01, 0.10368500E+01, 0.30494400E+01, -.19604300E+01, 0.90795900E-01, -.50000600E+00, -.12453300E+00, 0.99620900E+00, -.34052300E+00, -.52876700E-01, 0.48702000E+01, -.74314000E-01, -.46832500E+00, 0.17505400E+01, 0.87020500E+00, 0.16102600E+00, -.93159500E+00, -.15193300E+01, 0.22349300E+00, 0.12266600E+01, 0.69577800E+00, -.83729500E+00, -.14468700E+00, -.99181000E-01, -.22015700E+00, 0.10591400E+01, -.18338500E-01, -.24922300E+01, 0.39365000E-02, 0.36650900E-01, 0.25496000E+00, -.21366500E+00, -.61172800E+00, 0.28312600E+01, 0.23707400E+01, -.63697000E+00, -.21047500E+01, 0.16674800E+01, -.15473500E+01, -.16827600E+00, -.10813400E+00, 0.56903300E-02, 0.95506800E+00, -.29426300E+01, -.20619100E+02, -.13794800E+01, -.87028000E+00, 0.40667800E+00, -.31970400E+01, -.33090600E+00, 0.23565700E+00, -.25123100E+01, 0.76234800E+00, -.67900600E+00, 0.14241100E+01, -.90885200E+00, 0.32662200E+00, -.14792800E+01, -.92898300E+00, -.11525700E+00, 0.23574100E+01, -.72893800E+00, -.33971500E+00, -.16322800E+00, 0.11094200E+01, 0.11473800E+00, -.81250800E+01, -.23237200E+00, 0.10584200E+00, -.26142900E+01, -.11529400E+00, 0.15420100E-01, 0.37586800E-01, -.30052800E+00, -.85570400E-01, -.47711200E+00, 0.15324500E+02, -.81378000E+00, -.22167200E+01, 0.60593800E+00, 0.27918500E+00, -.12496000E+00, -.92967500E+00, -.27330900E-02, 0.24851600E+01, 0.85428000E-01, 0.51603700E+00, -.54037200E+00, -.81264000E+00, -.15465100E+02, 0.38991000E+00, 0.25918300E+01, -.50174400E-01, 0.15794000E+01, -.83996200E+00, 0.37789100E+00, 0.37480600E+00, -.27334800E+01, 0.20268800E+01, -.12567500E+01, 0.24750600E+01, -.22770000E-01, -.18492400E+01, -.28514700E-02, -.67283800E+00, -.16943100E-01, -.38640700E+00, 0.93309300E-01, 0.25716400E+01, 0.31791900E+00, 0.50229500E+00, -.21667800E+01, -.48290500E+00, -.15162800E+00, -.17089500E+00, 0.29280300E+00, 0.72612500E-01, 0.23286300E+01, 0.15361500E+00, -.23814900E+00, 0.10318600E+01, 0.27127800E+00, -.82803800E-01, 0.13596300E+00, 0.90123300E-01, 0.13320200E+00, -.50291800E+00, -.24262300E+00, 0.34918000E+00, 0.85034800E+00, 0.34577800E+00, -.12863900E+01, 0.63786100E+00, -.69745400E+00, -.11905100E+01, -.10223300E-01, 0.13020700E+00, 0.80458000E+00, 0.13801800E+01, -.10072300E+00, -.26942400E+01, 0.18106200E+00, 0.31200300E+00, -.80476400E+00, 0.14638100E-03, -.63100100E+00, -.39433800E+00, -.10120600E+00, -.19322900E-01, -.17305000E-02, 0.32701000E+00, 0.52236000E+01, 0.10116800E+01, -.28755700E-01, 0.80018900E+00, 0.46283800E+01, 0.53178000E+00, 0.21423800E+01, -.40953200E-01, -.11317300E+01, -.51120500E-01, -.94371800E-01, -.17172900E+00, 0.57828200E+00, -.23075200E+00, 0.12701700E+00, -.10567400E+01, -.10424800E+01, 0.15775200E-01, 0.96566200E-01, -.25224500E+00, -.14778700E+00, 0.42540700E+00, -.37804600E+00, -.91629700E+00, -.51599700E+00, -.34744900E+00, -.10614500E+00, 0.14875400E-01, 0.40070900E+00, -.84492900E-01, 0.18080100E+01, 0.43467400E+00, -.14708000E+01, 0.38733800E+00, 0.36660900E+01, -.19759100E+00, 0.36113200E+00, -.43309600E-01, -.19927600E+01, -.30734100E+00, 0.14510300E+00, 0.10630700E+01, -.52515500E-01, 0.80800200E+00, 0.22187700E+01, -.76514200E-01, 0.18005900E+00, -.15197000E+01, 0.20624300E-01, -.69026000E+00, -.20295300E+01, 0.27879500E+00, -.15240500E+01, 0.66143100E-01, -.64313000E+02, -.18886600E+03, 0.13317600E+03, 0.15330000E+03, 0.69504100E+02, -.15581800E+03, -.80306600E+02, 0.67947400E+02, -.40019500E+02, -.11331400E+03, -.34038700E+02, 0.99836800E+01, 0.71045300E+01, -.19466000E+02, 0.55939600E+02, 0.64463600E+01, 0.97451300E+01, -.14560300E+03, -.59642600E+02, 0.24469100E+02, -.35502500E+02, 0.30238200E+02, 0.43175500E+02, 0.79712200E+02, -.47868200E+02, -.69299600E+02, 0.37096700E+02, 0.83545900E+02, 0.24135600E+03, 0.12066800E+01, 0.21255500E+00, 0.42008200E+01, -.68485500E+00, -.30616800E+01, 0.31776100E+01, 0.12082300E+02, -.28335900E+00, -.42350600E+01, -.33818300E+01, 0.61420500E+01, 0.17113200E+02, 0.28049800E+01, 0.19070800E-02, -.15677400E+02, -.80594500E+01, 0.70202500E+00, 0.10110800E+01, 0.29410800E+01, -.14566000E+01, -.36836100E+01, -.11746700E+02, 0.12369600E+02, -.31295200E+02, -.34172300E+01, -.17565500E+02 },
        { -.17244800E+01, 0.60026600E-01, 0.72054000E-01, 0.42438500E-02, -.22040900E+00, 0.51519400E+00, -.27685600E+00, 0.17781700E+00, 0.16626400E+00, 0.42339900E+00, -.38582000E-01, -.20490300E+00, 0.45276200E-01, -.41204300E-03, 0.82671500E-01, 0.83579800E-01, 0.43350800E-01, 0.88689100E-01, 0.60765500E-01, 0.43000200E-01, 0.40595500E-02, -.45925100E-01, -.32537600E-01, 0.29784500E-01, -.50161600E-01, 0.70159000E-03, -.72036200E-01, 0.17324100E+00, 0.18275200E+00, -.15374300E+00, 0.24426600E+00, -.16415800E+00, -.34976900E-01, -.78094100E-01, -.43351500E+00, 0.72214100E-01, -.51796600E-01, 0.84782400E+00, -.70027500E-01, 0.19598800E+00, -.83342300E-01, -.26070400E+00, -.16659000E+00, 0.51101000E+00, 0.15321800E+00, 0.41299400E-03, 0.66835900E-01, -.91310400E-03, -.85562800E-01, 0.67367900E-02, 0.14226800E+00, 0.11393000E+00, 0.31043200E-01, 0.14570600E-01, 0.70206400E+00, -.19745800E+00, 0.77925300E-02, -.18735400E+00, -.46004100E-01, 0.20898600E-01, -.55371500E-01, -.34196900E-02, -.99957700E-02, 0.13031700E-01, -.11814200E+00, -.20806500E-01, -.23938400E+00, 0.72629500E-02, 0.80998700E-01, -.11851800E-02, -.10140900E-01, -.27842200E-01, 0.38386400E-01, 0.33833700E-01, -.18761800E+00, -.85984800E-01, -.40311400E-01, -.76488300E+00, -.19005200E+00, 0.31697800E+00, 0.53509800E-02, -.14928500E+00, -.40176400E-01, -.10819100E+00, 0.27321600E+00, -.85735200E+00, 0.20303300E+00, -.15730200E-01, -.31881700E-02, 0.19390900E+00, -.69196200E-01, 0.18428800E-02, 0.44848100E+00, -.15219500E-01, -.32991500E-02, 0.20102700E+00, 0.96832400E-01, -.15447600E+00, 0.10514100E+00, -.13257000E+00, 0.44038800E-01, 0.14144000E+00, -.51303100E-01, -.20798600E+00, 0.61866200E-01, 0.19157000E+00, -.93891100E-02, -.10251300E+01, 0.89497700E-02, -.11192400E-01, -.10284500E+01, 0.36510200E-01, -.10049400E+00, 0.37881300E-02, 0.78716200E-01, -.56307400E-02, -.16433800E-01, -.28837100E+00, -.52207100E-01, -.27364300E+00, 0.33567600E-01, -.36630100E-02, -.87102700E-02, -.78760700E-01, 0.34680200E-02, 0.13449800E+00, -.63810300E-01, -.17648300E+00, -.22190800E-01, -.41832000E-01, 0.87460900E+00, -.14554800E+00, 0.42774400E-03, 0.10978600E-02, 0.64530100E+00, -.67168900E-01, -.15409700E-01, 0.50345800E-01, 0.28077600E+00, -.32901700E+00, -.86252100E-01, 0.20594200E+00, -.23153400E-02, -.38222000E-01, -.60142400E-02, -.53621600E-01, -.61217800E-02, 0.30461300E+00, 0.32041800E-01, -.25381300E+00, -.74484500E-01, -.65196300E-01, 0.28678500E-01, -.93687400E-01, -.10283400E+00, 0.75029600E-02, -.24850900E-02, 0.23411200E-01, 0.15286100E+00, -.32621100E-01, -.28634500E-01, 0.46116100E-01, -.44384600E-02, -.88241500E-02, 0.20805300E-01, 0.14478600E-01, -.39759200E-02, -.20191700E-01, 0.41595500E-01, -.20392600E-01, -.33418700E-01, 0.50351400E+00, 0.97079500E-01, -.51030000E+00, 0.53083900E-01, 0.64789300E-01, 0.13343600E-01, 0.53988800E-02, 0.48139700E-01, -.17865800E+00, -.12451000E+00, 0.90234700E+00, 0.18075900E-01, 0.34108100E-01, -.64019500E-01, 0.32087100E+00, 0.57851600E-01, -.10254900E-01, -.92501400E-02, 0.10812900E-01, -.25150700E-02, 0.51883100E-01, 0.43851400E+00, 0.24812800E+00, 0.50450000E-01, 0.40855400E-01, 0.11960200E-01, 0.71940700E-01, 0.44680000E-01, 0.38507700E-02, -.19135900E+00, 0.12698800E-02, -.21028400E-02, -.81087800E-01, -.31853700E-02, 0.22060700E-01, -.31683400E-01, 0.69356800E-01, -.59135700E-01, 0.19910100E-01, 0.98101600E-02, -.47727700E-01, 0.89985700E-02, 0.61527900E-02, -.24813300E-02, -.82172100E-02, 0.10482200E-01, 0.43912300E-03, 0.44927400E-01, 0.55317900E-02, -.23096300E-01, -.11172700E-01, -.91562200E-02, -.25809500E-01, 0.80290300E-01, 0.70949500E-02, -.24255600E+00, 0.15684200E-01, 0.52580400E-01, 0.28478300E-01, 0.11884300E+00, 0.28153700E-01, -.12031500E-01, -.15676000E+00, 0.10129400E-02, -.48431600E-01, -.17102900E+00, 0.38050400E-01, 0.37308800E-02, 0.55987600E-01, -.12658100E-01, 0.22963000E-02, -.31023600E-01, 0.15251600E-01, -.13555200E+00, 0.75426300E-02, -.15751800E-01, -.10248200E+02, 0.11824500E+01, 0.45318700E+01, 0.37746300E+01, -.88580700E+01, -.59256400E+01, -.21391800E+02, 0.10926300E+02, 0.76262300E+01, 0.10661500E+02, 0.27842200E+01, 0.17200300E+00, 0.37357100E+01, -.60882300E+00, 0.13564200E+02, 0.92882500E+00, 0.28052900E+01, 0.73239600E+01, -.42377600E+01, -.13219300E+01, -.38395000E+01, -.67891800E+00, 0.67426600E+01, 0.51710500E+00, 0.14345100E+01, 0.36775000E+01, 0.74806100E+01, -.63845600E+01, 0.35058200E+00, 0.14475600E+00, 0.42963900E+00, 0.38798200E-01, -.20467800E+00, 0.35055000E+00, 0.51024100E+00, 0.20903900E-01, -.43670700E+00, -.11594200E+01, 0.97348300E+00, -.35694100E+00, 0.18959300E+00, 0.47263500E+00, -.38887000E+00, -.99225600E+00, 0.19775800E-01, 0.91210800E-01, 0.25925900E+00, -.25544900E+01, -.25657400E+00, -.27367600E+00, 0.46478200E+00, -.10342000E+01, 0.76206700E+00, -.24812500E+01 },
        { 0.28824800E+01, -.17080100E+00, -.12110000E+00, 0.41111700E-01, 0.44926200E+00, -.19684400E+01, 0.17120800E+01, -.15830300E+01, -.35484200E-01, -.81056900E+00, 0.63141600E-01, 0.13387100E+01, -.16574200E+00, -.32434400E-01, -.10909500E+00, -.42482800E+00, -.91565800E-01, -.54144000E-01, 0.36685000E+00, -.10958500E+00, -.75810100E+00, 0.19862000E+00, 0.28975400E+01, -.13902100E+00, 0.41055700E+00, 0.14042800E+00, -.17358100E-01, 0.11735400E+00, -.59462200E+00, 0.13914800E+01, -.18741600E+00, -.20497400E+01, 0.62234900E-01, -.25396300E+00, 0.40672000E+01, 0.22827300E+00, 0.37437000E+00, 0.19256700E+01, -.77855900E-01, 0.26493400E+00, -.54442500E+00, 0.12815700E+01, -.42856200E-01, -.25024000E+00, 0.60884900E+00, 0.85562800E-01, -.40977700E-01, -.78842400E-01, -.46245400E+00, 0.27365900E-01, 0.17140400E+00, 0.39822800E+01, -.18711800E+00, -.44635600E+00, -.17264800E+01, 0.24130000E+00, 0.77134400E-01, 0.42930200E+00, -.13835000E+01, 0.15966700E+00, -.98386900E-01, -.61677600E-01, -.74792800E-01, -.16682500E+00, -.28051500E+00, -.87663900E-01, -.10274200E+01, 0.12777200E-01, -.92343100E+00, -.35462400E-02, 0.14001900E+00, 0.75197300E-01, 0.73341700E-01, -.11442900E+00, 0.70191500E+00, 0.73680700E-01, 0.31943800E+00, 0.24730200E+00, 0.21602000E+00, -.67470200E+00, -.58560000E-01, 0.11738200E+01, -.15520200E+00, 0.17483600E+00, -.10908600E+01, -.88800100E+01, -.28843100E+00, -.92228700E-01, 0.50804200E+00, -.87383000E+00, 0.23766700E+00, -.37872700E-01, -.62367000E+00, 0.17354100E+00, -.24907500E+00, 0.47148200E+00, 0.15649800E+00, 0.44971200E+00, -.21476300E+00, 0.20811300E+00, -.28769900E-01, 0.28758900E+00, -.23774900E+00, -.14007600E+00, 0.66122200E-01, 0.62510600E+00, -.40327100E-01, -.42804000E+01, -.20236000E+00, 0.12147900E+00, -.14792300E+01, 0.47074400E-01, -.40806500E+00, 0.69561200E-02, -.33661800E+00, -.94019700E+00, -.39812500E-01, -.53015800E+00, 0.17826200E+00, 0.16595900E+00, -.77431700E-01, -.84518700E-01, -.45521300E-01, -.51348000E+00, 0.10113000E-01, -.78931100E+00, -.20909200E+00, 0.27810400E+00, -.18173500E+00, -.15304900E+01, -.40088900E+00, -.67247400E+00, -.53778400E-01, -.16639300E-01, 0.40326500E+00, 0.86337100E+00, 0.15027300E-01, -.17367900E-01, 0.11104800E+01, -.96031400E+00, -.46154600E+00, 0.53705100E+00, -.93635800E-01, 0.12694200E+00, 0.34679700E-02, -.18638100E-01, -.88366300E-03, 0.16747800E+00, -.38683500E-01, -.24087000E+00, 0.77431100E-01, -.16948700E+00, 0.45453400E+00, -.29155000E-01, -.23492200E+00, 0.42994400E-01, -.78780300E-01, 0.65722100E-01, 0.48880900E+00, -.22712700E+00, -.36704800E+00, 0.76316400E-02, 0.98074500E-02, 0.56624400E+00, 0.38490400E-01, -.16907100E+00, -.78914000E-02, 0.54695000E+00, 0.45494200E-02, -.26220100E+00, 0.28756600E+00, 0.40139500E-01, -.13292300E+00, 0.82227300E+00, -.24551500E+00, 0.19941800E+00, 0.42258900E-02, -.77667500E-02, 0.33933400E-01, -.83572300E+00, -.22473800E+00, 0.29298700E+01, 0.77022000E-01, 0.39442100E+00, -.27333300E+00, 0.30162700E+00, 0.10905600E+00, 0.40576100E+00, -.38421400E-02, 0.58906500E-01, -.53165700E-02, 0.32686800E-01, 0.16914700E+01, -.51535600E+00, 0.50514200E-01, 0.11700400E+00, -.15140700E+01, 0.45953000E+00, -.16172400E+00, -.59580400E-01, -.64529300E+00, 0.56734200E-03, 0.35863000E+00, -.12873800E+00, 0.83199600E-02, -.72957200E-01, 0.80974100E-01, 0.61720100E+00, 0.45611600E+00, -.16834400E-01, -.87222200E-02, 0.17603200E+00, 0.13170600E-01, 0.26773500E+00, -.15383000E+00, 0.27189600E+00, -.36585200E-01, 0.16194100E+00, 0.17286900E+00, 0.59104000E-01, -.11005900E-02, -.48595100E-01, 0.32392600E+00, 0.54641600E-01, -.95864500E-01, 0.32143800E+00, 0.16074000E+00, -.17234500E-01, -.62242900E-01, 0.46944000E-01, 0.15867800E+00, -.30279900E-01, 0.19972600E-01, 0.60262800E+00, -.18677100E-01, 0.21191200E+00, -.25144800E+00, 0.92149000E-01, 0.87618800E-01, 0.60888100E+00, -.21965800E-01, -.49379900E-01, 0.46699900E+00, -.26364800E-01, -.13420500E+00, 0.40485200E-02, 0.39428700E-01, -.92404900E+00, -.51240400E+02, -.63108200E+02, -.38101400E+01, 0.13700100E+01, 0.31407000E+02, -.99719300E+02, 0.50362900E+02, 0.10537000E+03, 0.49582300E+02, -.32840200E+02, -.49231100E+01, 0.30741300E+02, -.74367500E+01, 0.68206200E+02, -.90627300E+01, 0.84852500E+02, -.19282100E+02, 0.88006800E+01, 0.55560300E+02, 0.88153800E+01, 0.12249200E+02, 0.36476900E+02, 0.24103300E+02, 0.40613200E+02, 0.97156500E+01, 0.33248600E+02, -.10965700E+03, -.58394900E+00, 0.79146200E+00, 0.92202700E+00, 0.30564000E+00, -.62084200E+00, 0.13121100E+01, -.36510900E+01, 0.13908000E+00, -.74889400E+00, -.32369400E+01, 0.18007100E+01, -.73616400E+01, 0.14993800E+00, 0.35563200E+01, 0.52441700E+01, -.18044600E+01, 0.37029400E+00, 0.68098500E+00, 0.20423700E+00, 0.10862700E+01, 0.13804100E+00, 0.42040300E+01, -.42777300E+01, 0.66198600E+01, -.30579800E+01, -.29787300E+01 },
        { 0.15007400E+02, -.30973400E+00, -.45512800E+00, 0.28852500E+01, 0.15123700E+01, -.12060400E+01, -.94807600E+00, -.17093400E+01, 0.89967100E+01, -.13738800E+00, 0.36196500E-01, 0.98634300E+00, 0.21983400E-01, 0.16184300E+00, 0.14795500E+00, -.67203300E-01, 0.81954800E+00, 0.31436800E+00, 0.58184900E+00, -.85958500E+00, 0.14644000E+00, -.22424200E+00, 0.94242900E+01, 0.10389000E+01, -.27726500E+00, -.32277800E+00, -.19973700E+00, -.18969400E+01, -.69467400E+00, -.41184800E+00, 0.20824800E+00, 0.79058600E+00, 0.90734400E-01, -.10918600E+01, 0.45248100E+01, 0.34909800E-01, 0.30551600E+00, 0.82107700E+00, 0.78659800E-01, 0.30622900E+00, -.23102000E+00, -.15095200E+01, -.61205500E-01, 0.70545600E+00, -.82500700E+00, 0.18755800E+00, -.10069200E+00, -.39236600E-01, 0.95282600E+00, -.16691600E+00, -.59983200E+00, -.58853900E+01, -.77329300E-01, -.66230400E+00, 0.24627100E+01, 0.31268900E+00, 0.13756400E-01, -.23008700E+00, -.14104000E+00, 0.23218100E+00, 0.69499900E+00, -.87469300E-01, -.47990700E+00, 0.26689300E+00, 0.54292600E+00, 0.34168900E-01, 0.70047800E-01, -.59640200E-02, 0.42328700E-01, -.66822100E-02, -.13781000E+00, 0.41411500E+00, 0.27537200E+00, -.61222500E-01, 0.13672600E+01, 0.93407800E-01, -.19591900E+00, -.37085600E+01, 0.35171600E+00, 0.59577000E+00, 0.81740600E-02, -.36572400E+00, 0.13243300E-01, 0.12930600E+00, -.16573900E+00, -.10093400E+02, -.47397600E-01, -.24157500E+00, 0.63377800E+00, -.68963300E+00, -.28326100E+00, 0.79654400E-01, 0.13667200E+01, 0.24647900E+00, -.64029100E-01, 0.28430000E+00, 0.33436800E+00, 0.48381800E+00, 0.64822800E+00, -.19601400E+00, 0.28881900E-01, -.38805500E+00, -.23938500E-01, -.39188500E-01, 0.20973600E-01, -.39949700E+00, -.27792200E-02, 0.85822700E+00, 0.19824200E+00, -.89175900E-01, 0.17013100E+01, -.88590100E-01, 0.18138400E+00, -.11792200E-03, -.36711300E+00, 0.94513100E+00, -.60505100E-01, 0.61705100E+01, -.28086500E+00, 0.11599200E+01, -.14325900E-02, 0.57646900E-01, -.19324400E-01, -.32912600E+00, -.38316600E-01, 0.19083800E-01, 0.49144800E-01, -.64819300E+00, -.41207800E+00, -.14644500E+01, 0.71214600E+00, 0.28048500E+00, 0.50643500E+00, -.44832500E-01, -.42545700E+01, -.12870500E+01, 0.12588200E+00, 0.45930100E+00, 0.44517200E+00, -.81734800E+00, 0.21725800E+00, -.90673800E-01, 0.11674100E+00, -.14545000E+00, 0.12084800E-01, 0.20923500E+00, 0.45540900E-01, 0.88631000E+00, -.23921800E+00, 0.23283400E+00, 0.19092900E+00, -.23354400E+00, 0.42036300E+00, -.28758900E+00, 0.13048300E+00, 0.29215200E-03, -.42321000E-01, -.31807900E-01, 0.49323100E+00, 0.44278300E+00, -.71440400E+00, 0.27977200E+00, 0.17673900E+00, -.69475100E+00, -.43586200E-01, 0.81438600E-02, 0.55096300E-01, -.14736400E+01, -.66078900E-01, 0.54103500E+00, 0.15761900E+00, 0.23536200E+01, 0.53567400E-01, -.40529600E+00, -.27341900E+00, 0.26185300E-01, 0.74876100E-01, 0.45899300E-01, 0.43352200E+00, -.37894500E+00, -.56869200E+00, 0.16771200E+00, 0.20493100E+00, 0.17871800E+00, 0.25520500E+00, 0.21630300E+01, 0.88517600E-01, 0.18879000E+00, -.12799900E-01, -.56336400E-01, -.59314000E-02, 0.18389000E+00, 0.33246100E+01, 0.20771600E+00, 0.57473000E+00, 0.92148900E-01, 0.52966700E+00, 0.44193100E+00, -.13467900E+00, 0.65917600E-01, 0.64047200E+00, -.27110400E-01, -.51428800E+00, -.22802000E+00, -.10225600E-01, -.34078500E-01, -.26772600E+00, 0.76626800E+00, -.17305600E+00, -.10759300E+00, -.19003300E-02, -.42001900E+00, -.12314300E+00, -.68558400E+00, 0.33844800E+00, -.24727500E+00, -.63088100E+00, 0.72621700E+00, 0.51309900E+00, 0.15537700E+00, 0.17977200E+00, -.43914100E-01, 0.13661600E+01, 0.12170200E+00, -.11813900E+01, -.97165900E+00, 0.47408400E+00, -.52561600E+00, 0.28095300E+00, 0.14041800E+00, -.34031200E+00, -.36336900E+00, 0.18337800E-01, 0.37916200E+00, -.21361900E-01, -.57212000E+00, -.55717900E+00, 0.16123800E-01, -.17528000E+00, -.19114200E+00, 0.48029800E-01, -.23658100E+00, -.16088300E+01, -.45635800E-02, 0.12504400E+01, -.39852500E-01, -.17289600E+00, 0.83102500E+00, -.12581100E+01, -.66960500E+02, -.43883300E+02, 0.11298800E+02, -.62523700E+02, 0.94463600E+02, -.48367000E+02, 0.89580700E+01, -.47206500E+02, -.16677400E+02, -.65425700E+01, -.11319800E+02, 0.33325500E+02, -.34845700E+02, -.66206900E+01, 0.16707100E+03, -.12884300E+03, 0.62624200E+02, 0.45578700E+02, 0.65543300E+02, 0.63884700E+01, -.36355600E+02, 0.80366200E+02, 0.70066200E+02, 0.90041800E+02, -.37144100E+02, 0.87502800E+02, -.13391300E+01, -.98635800E+00, 0.67292600E+00, 0.30797400E+00, -.14801700E+01, 0.88688300E+00, -.12062300E+02, -.33297900E+00, -.54447500E+00, -.45904800E+01, 0.63267100E+01, -.86131100E+01, 0.21847400E+01, 0.20137400E+01, 0.12501700E+02, -.64893500E+01, 0.17549600E+01, -.39804200E+00, 0.17754300E+01, 0.16571800E+02, -.21237600E+01, 0.13122800E+02, -.12287200E+02, -.28067800E+01, -.45224800E+00, -.28089600E+01 },
        { -.19017600E+02, 0.60342800E+00, 0.69849500E+00, 0.26869800E+01, -.16655100E+01, 0.44960200E+01, -.37431500E+01, 0.15844100E+01, 0.71808900E+00, 0.36820200E+01, -.46348200E-01, -.57899600E+00, -.86115900E-01, -.20321800E+00, -.37213600E+00, 0.48825400E+00, -.98202900E+00, -.18736300E+01, -.15284500E+01, 0.51859100E+00, -.52973800E+00, -.32296100E-01, -.14471700E+02, -.17540600E+01, -.33988800E+00, -.93629500E-01, 0.18825200E+00, -.56758400E+00, 0.55274900E+00, -.22755600E+01, -.11921900E+00, 0.65198400E+00, -.82828900E-01, -.23450300E+00, 0.52242100E+00, 0.48143700E-01, -.11780500E+00, -.29259100E+01, -.34958100E+00, 0.12113700E+01, -.32465400E+00, 0.15658000E+00, 0.64889100E+00, -.27631200E+00, -.77542100E+00, -.27816800E+00, -.50518500E+00, 0.11745200E-01, 0.35906000E+00, 0.49259400E-01, 0.94525400E-01, -.28345700E+01, 0.30020000E+00, 0.31064400E+00, -.21894900E+01, 0.49732200E+00, 0.40252100E-01, -.27059700E+00, 0.34259000E+00, -.14690000E+00, 0.30137000E+00, -.34312800E-01, -.81433800E+00, 0.35121600E-01, 0.56240400E+00, -.36575100E+00, -.51555100E-01, 0.50320700E-01, -.15999000E+01, 0.90195500E-02, 0.34575600E+00, -.32887700E-01, -.92674000E-01, 0.13379600E+00, 0.11888000E+00, 0.26807400E+00, -.88343000E-01, 0.30869600E+01, -.59663100E+00, -.10390200E+01, -.25726400E-01, 0.10935800E+01, 0.12998700E+01, 0.24827600E+00, -.55643000E+00, 0.27515600E+01, -.10430400E+00, 0.57448300E-01, 0.49802300E+00, 0.33973100E+00, -.41316000E-01, 0.38472900E-01, -.35826700E+00, 0.86938000E-01, 0.36363900E+00, -.74720600E+00, 0.46041100E-01, -.78180600E-01, -.12835600E+01, 0.56942200E-01, -.34034300E-01, 0.19479600E+00, -.50137900E-01, 0.79790500E-01, -.13654900E+00, -.19475900E+00, 0.44823200E-01, -.10928200E+01, -.27917300E-01, -.44675400E-01, -.20555800E+01, -.60859900E-01, -.28524400E+00, 0.92005100E-02, 0.41656200E+00, -.48244000E+00, 0.28149900E-01, 0.31385700E+01, 0.32885400E+00, 0.81542800E+00, -.13376500E+00, 0.30437500E+00, 0.46336000E-01, 0.13754800E+01, 0.20592600E-01, -.28105400E+00, 0.10473400E+00, 0.77192500E+00, 0.48662200E+00, 0.20000400E+01, 0.14751500E+01, 0.63496300E-01, -.12826500E+01, -.96989200E-01, 0.27481600E+00, 0.95421600E+00, -.16621400E+00, -.40450800E+00, -.10961400E+01, -.63369500E-01, -.77801600E-01, 0.54650200E+00, 0.32094300E-01, -.32544700E+00, -.25380000E-01, -.22043100E+00, -.25516500E-01, 0.35244400E+00, 0.42232200E+00, -.47475800E+00, -.31903700E+00, 0.13125800E+01, -.14360700E+01, 0.10929100E+00, 0.56372100E+00, -.16803200E+00, 0.17315200E+00, -.85466200E-01, -.78449000E+00, 0.28344300E+00, 0.11234600E+01, -.26714100E+00, 0.60942000E-01, -.49359300E+00, -.14568500E-01, 0.44079300E+00, 0.59074300E-01, -.42970600E+00, -.14231800E+00, 0.53415400E+00, 0.75955100E+00, 0.19694400E+01, -.61100400E+00, 0.17456200E+01, -.61102500E+00, -.63052700E+00, -.13596400E+00, 0.57121500E-01, 0.12374500E+01, 0.74394800E+00, -.34570400E-01, -.59853700E-01, -.61896100E-01, -.71672700E+00, -.15618300E+00, 0.53578400E-01, -.33552100E-01, 0.75923600E+00, -.25890700E-01, -.13176300E+00, 0.70434400E-02, 0.15662500E+00, 0.31294500E+01, 0.53785000E+00, 0.89768000E+00, 0.24572700E+00, 0.30044800E+01, -.77972900E+00, 0.19382200E+00, 0.86089200E-02, -.60905800E+00, -.34102800E-01, 0.10228400E+00, -.23536700E+00, 0.39859300E+00, 0.69583000E-02, -.88446500E-01, 0.15837400E+00, 0.41518300E-01, 0.80394100E-01, -.77460100E-02, -.62378000E-02, -.17794400E+00, -.64160000E+00, 0.16261200E+00, 0.62868100E-01, 0.90332900E-01, 0.20724700E+00, 0.23400400E+00, 0.90782300E-01, -.14921000E+00, -.43362900E-01, 0.70453600E+00, 0.55373400E-01, -.85481700E+00, 0.14886200E+01, 0.38020000E+00, 0.75360600E-01, 0.28375100E+00, -.20732700E+00, 0.18632900E+00, 0.56546800E+00, 0.55676500E-01, -.68772400E+00, 0.91472800E-01, 0.26183800E+00, 0.29355800E+01, 0.18388000E-02, 0.43037300E+00, -.76712200E+00, 0.21571200E+00, 0.23826400E+00, 0.27939000E+00, 0.17032200E+00, 0.97836000E-01, 0.34491300E-01, 0.27849200E+00, -.56700000E+00, 0.83345700E+00, 0.21031400E+00, 0.34612200E+02, 0.24658900E+01, -.33462700E+02, -.23638000E+02, 0.14013600E+02, 0.90042200E+01, 0.12060300E+02, 0.71997200E+02, 0.28061000E+02, -.28263000E+02, -.49115800E+02, -.65854800E+02, 0.36499500E+02, -.67921700E+02, 0.32207200E+02, -.18010800E+02, -.48277700E+02, -.15818900E+02, -.11842200E+02, -.24362900E+02, -.22789200E+02, -.13848100E+02, -.14733000E+02, -.25112100E+02, 0.10622000E+03, -.26931600E-01, -.11181000E+00, -.26253200E+01, -.59780300E+00, 0.16176600E+01, -.32994400E+01, 0.52195800E+01, 0.19462800E-01, 0.26072800E+01, 0.52451400E+01, -.58102800E+01, 0.57693200E+01, -.29677600E+01, -.49611800E+01, -.61467200E+01, 0.58316200E+01, -.14473100E+01, -.18286500E+01, -.28847800E+01, -.63850800E+01, 0.24894400E+01, -.60656400E+01, 0.52625200E+01, 0.86971000E+01, 0.85204500E+01, 0.68430400E+01 },
        { -.18010200E+01, 0.97464200E-01, 0.96083000E-01, -.36938200E+00, -.22629900E+00, 0.12844400E+01, -.69405600E+00, 0.62326100E+00, 0.43457000E+00, 0.71241500E+00, -.32588500E-01, -.18916800E+00, 0.10289600E+00, 0.56476300E-01, -.77288200E+00, 0.16236100E+00, 0.73130400E+00, 0.16490500E+00, 0.18224000E+00, -.39271000E+00, 0.14384200E+00, -.27520600E-01, -.50014300E+01, -.19657900E+00, -.27278000E+00, -.10700100E+00, 0.15408900E-01, -.37772400E-01, 0.42533900E-02, -.13480900E+01, 0.17181500E+00, -.29117700E+00, -.79722000E-01, -.38679200E-01, -.77440800E+00, -.20457800E-01, -.96635100E-01, 0.13495800E+01, -.11321900E+00, 0.56363000E+00, -.17460800E+00, -.33832700E+00, -.68595900E+00, 0.11436800E+01, 0.92830000E-01, -.15432300E+00, -.23473400E+00, 0.12013000E-01, 0.90348300E+00, -.67027300E-01, 0.88362800E+00, -.39206900E+01, 0.12185900E+00, 0.75260900E-01, 0.53348000E+00, 0.45955800E+00, -.36220100E-01, -.20165200E+00, 0.39641900E+00, 0.62597200E-01, 0.12875200E+00, -.77550100E-01, -.16575600E+00, 0.83929300E-02, 0.12713700E+00, -.11239500E+00, -.21967300E+00, 0.13065300E-01, -.31728900E+00, -.80759100E-03, 0.11286600E+00, 0.10862100E-01, 0.24421000E-01, -.26113700E-01, 0.53810800E+00, 0.10694300E+00, 0.10904000E+00, 0.48845000E+00, -.38706300E-01, -.21312200E+00, -.87875600E-02, 0.34479300E+00, 0.13721500E+00, 0.12116200E-01, -.43492700E+00, -.19812600E+01, -.11447100E+00, -.33117200E-01, 0.29868300E+00, -.85057200E-01, 0.90472800E-01, 0.23048100E-01, -.49030100E-01, 0.94513800E-01, -.38681900E-03, -.16859300E+00, 0.34158400E+00, 0.33383200E+00, 0.44135900E+00, 0.73255300E-01, 0.47260800E-02, -.25061600E+00, -.72823800E-02, -.64266000E-01, -.31407800E-03, -.30620700E+00, 0.43919300E-01, 0.19153900E+01, -.23561600E+00, 0.82449000E-01, 0.29065500E+00, 0.40095200E-02, -.21326700E+00, 0.13227900E-02, 0.25684400E-01, -.11574700E-01, -.26206800E-01, 0.71907500E+00, 0.14533200E+00, 0.38196800E+00, 0.30297600E-03, 0.21708000E-01, -.56713600E-02, -.10825600E+00, 0.21121000E-02, 0.11487200E+00, -.10814500E+00, 0.22372600E+00, -.55694700E-01, -.72785300E+00, 0.52095300E+00, -.33089100E+00, -.10328200E+00, -.26713800E-01, -.44598200E+00, 0.39476300E+00, 0.17064800E-01, -.60453300E-01, 0.69706300E+00, -.35112900E+00, -.31899600E+00, 0.26511000E+00, -.45677200E-01, 0.23427600E+00, 0.77099200E-02, 0.51361000E-02, 0.37059600E-02, -.21695900E+00, -.68892400E-01, 0.62794400E-01, 0.11698800E+00, -.11354100E+00, -.90165300E-01, 0.10678400E-01, -.97465000E-01, -.62458800E-01, -.25967700E-01, 0.19934200E-01, -.58340900E+00, -.55866700E-01, 0.13395900E+00, -.10365700E+00, -.30948500E-01, -.33068700E-01, -.10085600E+00, -.81200300E-01, 0.69170900E-01, 0.24648200E+00, -.22593400E-01, -.31030000E+00, -.26032000E-02, -.45374500E+00, -.37676600E-02, 0.33199800E+00, 0.81311500E-05, 0.23003000E+00, 0.14126100E-01, -.11355200E-01, -.48936400E-01, -.92661600E-01, -.98939500E-01, 0.11232200E+01, 0.12655600E+00, 0.38317800E-01, -.11246900E+00, -.32876900E-01, 0.60923400E-01, 0.75181200E-01, 0.37012200E-03, 0.10298700E-01, -.28649500E-02, -.32700600E-01, 0.23828400E+00, -.10190200E-01, 0.10797400E+00, 0.66149700E-01, -.43193300E+00, 0.32721700E+00, -.53487600E-01, -.26359000E-01, -.31163700E+00, -.47979700E-02, 0.85947200E-01, -.18382700E+00, 0.12398600E-02, -.17460700E-01, 0.35236800E-01, 0.16985400E+00, 0.27379200E+00, -.26610200E-01, -.36255900E-02, -.18391900E-01, -.20150900E-01, 0.17687000E+00, -.17478700E-01, 0.63880900E-01, -.13828900E+00, 0.11120700E+00, 0.11944900E+00, 0.23292200E-01, 0.25075400E-01, -.16546800E-01, -.12395400E+00, 0.21112100E-01, -.10071400E+00, 0.19393300E+00, -.51521700E-01, 0.29055100E-01, 0.59775000E-01, 0.46932300E-01, 0.18430300E+00, -.14666200E-01, 0.11455600E-01, 0.34984400E+00, -.20639500E-01, -.80978100E-02, -.16819200E+00, 0.28383200E-01, -.15184400E+00, 0.23610600E+00, -.25906700E-01, -.77222600E-01, 0.45595900E+00, -.27338100E-01, -.15071000E+00, -.49594600E-02, -.15061400E-01, -.10531100E+01, 0.55124200E+00, -.68780900E-02, 0.21873400E-01, -.44617200E+01, 0.11906700E+02, -.26446400E+02, 0.12485600E+02, 0.22292900E+02, 0.13219600E+02, 0.30467800E+01, 0.38713500E+01, -.41538800E+00, 0.12803500E+01, 0.17184900E+02, 0.18479300E+01, 0.60592500E+01, -.54499900E+01, 0.21341300E+01, -.59138400E+01, 0.32504800E+01, -.23245400E+01, -.65959200E+01, 0.59005700E+01, 0.29482100E+01, 0.91732300E+01, -.50509700E+01, -.21419900E+01, 0.16982700E+00, 0.10191000E+00, 0.19363600E+00, 0.98947900E-01, -.16523100E+00, 0.28342800E+00, 0.36608900E+00, 0.43100400E-01, -.25432200E+00, -.19221500E+00, -.16677100E+00, 0.17268700E+01, 0.21348000E+00, 0.35754900E+00, -.52272900E+00, 0.15334600E+00, 0.21289200E-01, -.77976900E-01, 0.16461400E+00, 0.42814800E-01, -.15236600E+00, -.41345800E+00, 0.37944200E+00, -.32656800E+01, 0.29454900E+00, -.41842600E+00 },
        { 0.25152600E+01, -.16391200E+00, -.14538200E+00, -.12819600E+01, 0.73672600E+00, -.30943200E+01, 0.17669500E+01, -.17206900E+01, 0.97644800E+00, -.12167600E+01, -.62016100E-02, 0.20451300E+01, 0.15876300E+00, 0.12019200E+00, 0.47140800E+00, -.39766800E+00, 0.25693300E+00, 0.63403600E+00, 0.66224800E+00, -.99574500E+00, -.14924600E+01, 0.39161900E+00, 0.73258000E+01, -.15307100E-01, 0.23359700E+00, -.75970800E-01, -.53603900E-01, 0.34460300E-01, -.12108300E+01, -.26398400E-01, -.41846300E+00, -.27622200E+01, 0.12092700E+00, -.55674000E+00, 0.34607200E+01, 0.38628100E+00, 0.49313700E-01, 0.36114400E+01, -.36337100E-01, -.99123300E-01, -.50471800E+00, 0.13063700E+01, -.10510500E+01, 0.11752900E+00, 0.76197400E+00, 0.29309800E+00, 0.42796300E-01, -.25180300E-01, 0.25393200E+00, -.12130700E+00, 0.16891300E+01, -.15628300E+01, 0.68286200E-01, 0.43570700E-01, -.13683500E+01, 0.34915600E+00, -.12779700E+00, 0.31606800E-01, -.49790300E+00, 0.16237300E+00, -.25494300E-01, -.19861300E+00, 0.79066300E+00, -.52100300E+00, -.13442100E+01, 0.10288100E-01, -.89030400E+00, -.10273100E-01, -.15723400E+01, 0.15636300E-03, 0.87249700E-01, 0.17710800E+00, 0.58856700E-01, -.22205800E+00, -.25611600E+00, 0.16282100E+00, 0.79342500E+00, 0.34474600E+01, 0.17768100E+00, 0.25839400E+00, -.21568200E-01, 0.60804800E+00, -.23238600E+01, -.67883000E-01, -.86090600E+00, -.30107200E+01, 0.89324300E-01, 0.83298100E-01, 0.42116700E+00, 0.46595400E+00, 0.58292800E+00, -.27590600E-01, -.91484900E+00, 0.18432000E+00, -.15138400E+00, 0.30117300E+00, -.41270700E+00, 0.32999400E+00, 0.24462100E+00, -.93915200E-01, 0.50440900E-01, 0.64134000E+00, -.27936000E+00, -.43891100E-01, 0.31615500E-01, 0.26073300E+00, -.61605100E-01, -.14186300E+01, 0.20045200E+00, -.69266100E-01, 0.90807900E+00, -.48422000E-01, -.82834100E-01, -.11495100E-01, -.60641900E+00, -.13952900E+00, -.45358900E-01, -.49625200E+01, 0.33818700E-02, -.80572500E+00, 0.22691800E+00, -.77703500E-01, -.16682200E-01, -.45045300E+00, 0.82829200E-03, 0.95070400E+00, 0.40429400E-01, -.24699000E-01, -.32619700E+00, 0.47204400E+00, -.15730300E+01, -.60158000E-01, 0.45675800E+00, 0.65193500E-01, 0.37230300E+01, -.13744100E+01, -.73817700E-01, 0.33317000E+00, 0.46335100E+00, -.88432800E+00, -.18588400E+00, 0.50505500E+00, -.17300900E-01, -.20494100E+00, 0.94187500E-03, -.31719500E+00, -.20687100E-01, 0.35450400E+00, 0.16542700E+00, -.13425200E+01, -.13542100E+00, 0.17246500E+00, -.80263900E+00, -.59789700E-01, 0.44283200E-02, -.63969100E-01, -.53831200E-01, 0.32302100E-01, -.13346800E+00, 0.31561600E+00, 0.46021100E+00, -.20840500E+00, 0.68275300E-01, 0.35895100E-01, 0.52610100E-01, -.90200300E-01, -.37900900E-01, 0.28007900E+00, -.18581600E-01, 0.11278200E+00, 0.61666300E+00, -.15641600E+01, -.55655500E+00, 0.58958800E-01, -.36048400E+00, -.22751900E+00, 0.16932600E+00, -.22647900E-01, -.36411200E+00, -.75871900E+00, 0.32607500E+00, 0.16518400E+01, -.32361000E+00, -.23223300E+00, 0.29761600E+00, -.17541900E+01, -.43007200E-01, 0.26161900E+00, -.10861300E-01, -.82659100E-01, 0.15447100E-02, 0.43729100E-01, 0.52880300E-01, -.36610800E+00, 0.77135500E-01, 0.69061500E-01, -.72899400E+00, -.49734900E+00, -.54147400E+00, -.43011200E-01, -.31047900E+00, 0.22067700E-01, 0.11095100E+00, 0.65894400E+00, 0.14362700E+00, 0.57042300E-01, 0.82702000E-01, -.42083500E-04, 0.30206300E+00, 0.55087500E-01, 0.35098100E-02, -.22099400E-01, 0.11480100E-01, -.17870900E+00, -.43655200E-01, 0.40777800E-01, -.37773900E-01, -.94408700E-01, -.63762200E-01, -.20553900E-01, -.74489700E-01, 0.20408300E-01, 0.32396200E+00, 0.96639200E-03, 0.71126600E+00, 0.84152800E+00, 0.43017600E+00, 0.29120300E+00, -.41236200E-01, -.30616500E-01, 0.87939500E-01, -.11090900E+00, 0.69012400E-02, 0.23853300E+00, -.26164400E-01, 0.11024900E+00, -.95597200E-01, -.12534200E+00, -.48810900E+00, -.12573600E-01, -.16385900E+00, 0.95205200E-01, -.93986900E-01, 0.36381600E-01, -.44446900E+00, 0.59278900E-01, 0.12232700E+00, 0.60775100E+00, 0.14279200E+00, -.36135500E+00, 0.17241000E-01, 0.49674100E+00, -.54760400E+02, 0.59344500E+02, -.27589600E+02, -.14859400E+03, -.29921500E+02, -.71583400E+01, -.18783600E+01, -.18382000E+02, -.20199700E+02, -.36221000E+02, 0.41574400E+00, -.14494000E+01, -.21896700E+02, 0.12957300E+02, 0.28247900E+02, 0.11558300E+02, 0.12665000E+02, 0.23496900E+02, -.17373100E+02, -.23655000E+02, -.24581200E+02, 0.25112600E+02, 0.22474800E+02, -.15161200E+00, 0.22346100E+00, -.14570100E+00, -.84250100E-01, -.12391000E+00, -.45746400E+00, -.20510200E+00, -.51653200E+00, -.20382600E+00, -.46766400E+01, 0.58766300E+01, -.25603400E+01, -.12355800E+01, -.12346000E+01, 0.96763100E+00, -.59533800E+01, -.30982400E+00, -.56836500E+00, -.62974900E+00, 0.11365800E+01, 0.57396600E+00, 0.25327100E+00, -.48669500E+00, 0.94815700E+00, -.32511400E+01, -.45631800E+01 },
        { -.44335800E+02, 0.10789200E+01, 0.17075900E+01, -.19374000E-01, -.37227200E+01, 0.58723800E+01, 0.17413700E+01, -.20825500E+00, -.29879700E+01, 0.35030800E+01, -.26024700E+00, 0.27259400E+01, 0.24691300E+00, 0.18049700E+00, -.11192300E+01, 0.61490900E+00, 0.21129000E+01, 0.79014900E+00, -.84335500E+00, 0.36682600E+01, 0.11992100E+01, 0.27903900E+00, 0.11653300E+02, -.23494400E+01, 0.44950700E+00, 0.15868900E+00, 0.84180000E+00, 0.33441800E+01, 0.21945200E+00, 0.87606300E+00, 0.79884900E-01, 0.53728400E+01, 0.93928000E-01, 0.32498300E+01, -.51326100E+01, -.13911500E+01, -.57099000E+00, -.60574400E+01, 0.20221900E+00, -.17985000E+01, 0.16343300E+01, 0.26557100E+01, -.23884300E+00, -.23638900E+01, 0.11094600E+01, -.21008800E+00, 0.96419700E+00, 0.81660400E-01, -.17629100E+01, 0.67170500E+00, 0.31819300E+00, 0.52101100E+01, -.65464500E-01, 0.17713100E+00, -.13948500E+01, -.86869600E+00, -.59898900E-01, -.45328900E+00, 0.14336200E+01, -.54097400E+00, -.12252700E+01, 0.63829900E+00, 0.67423700E+00, -.70512400E-02, 0.39445100E+00, -.83190600E-01, 0.23176300E+01, 0.21734600E-01, 0.26482100E+01, 0.89256700E-02, 0.15558500E+00, -.55850900E+00, 0.69714600E-01, 0.60571500E+00, -.27487300E+01, -.16066300E+01, 0.13531500E+01, -.30256200E+01, 0.13494500E+00, 0.31772400E+01, 0.24393500E+00, 0.41369800E+00, -.43236900E+00, -.21885300E+01, 0.45506600E+01, 0.33217100E+02, 0.10087800E+01, 0.70421700E+00, -.35461200E+01, 0.30879500E+01, 0.11624400E+01, 0.43671400E-02, -.25338200E+01, -.79590600E+00, 0.46426900E+00, -.16521200E+01, -.12370700E+01, -.18335600E+01, 0.16609100E+00, 0.57732500E+00, 0.54630200E+00, -.66596800E-01, 0.40796200E+00, -.15429500E+01, 0.11049400E-01, 0.25277900E+00, -.12849800E+00, 0.94448500E+01, -.15837400E+00, -.19544800E+00, 0.19892700E+01, 0.26122000E+00, -.65617300E+00, -.30020000E-01, 0.48252900E-01, 0.14025800E+01, 0.28691400E+00, -.15609500E+02, 0.92839500E+00, -.20622100E+01, 0.30432000E+00, -.17293100E+00, 0.41546400E-01, 0.10914900E+01, 0.37801000E-01, 0.97435400E+00, -.22072500E+00, -.54531200E+00, 0.88213800E+00, 0.34926800E+01, 0.10076800E+02, -.72333800E+00, -.16898300E+01, 0.18578800E+00, 0.37390400E+01, 0.77861400E+00, -.49463800E+00, -.16950300E+00, 0.32739600E+01, -.20562100E+01, -.49391400E+00, -.19946000E+01, -.60724500E-01, 0.12555100E+01, 0.10893500E-01, -.27966700E+00, -.59537400E-01, 0.79524700E+00, 0.27358700E+00, -.51102200E+01, -.60260200E+00, -.11667500E+01, 0.35815300E+01, 0.61077900E+00, 0.47526900E+00, 0.49074100E+00, 0.27551900E+00, -.45799100E-01, -.17163700E+01, -.34700900E+00, 0.11981400E+01, -.45930000E+00, 0.33546600E+00, -.14318100E+01, -.83314100E-01, 0.34037700E+00, -.55993000E+00, -.86196300E+00, 0.17974000E-01, -.19808200E+00, -.65440600E+00, 0.71915700E+00, 0.63528300E+00, 0.20231100E+00, -.12370000E+00, 0.10626500E+01, -.10799400E+00, -.19928500E+00, -.20852300E+01, -.36488600E+01, 0.76333800E+00, -.23098500E+01, -.78759400E+00, 0.64524600E+00, 0.22352400E+00, -.64488700E+00, 0.91993200E+00, -.16407900E+00, 0.21498900E-01, 0.35377600E-01, -.77622100E-02, -.22265300E+00, -.46104100E+00, -.96633700E+00, -.19170000E+00, -.96643700E-01, -.42209300E+01, -.12853000E+00, -.44214100E+00, -.12245100E+00, -.97415200E+00, -.38008100E-02, 0.85525400E+00, -.12651200E+01, -.44101800E-01, 0.57496400E+00, 0.16448100E+00, 0.79727500E+00, 0.54412700E+00, -.47446800E+00, -.76162000E-01, 0.63738100E+00, 0.36036200E+00, 0.26139500E+00, 0.72352700E-01, 0.23778300E+01, 0.46416900E+01, -.25837400E+01, -.13291000E+01, -.31738400E+00, -.85657400E+00, 0.99296500E-02, 0.17372200E+01, -.39781300E-01, 0.40036900E+01, 0.32965200E+01, -.13782000E+01, 0.17779200E+01, 0.24883500E+00, -.43646300E+00, -.74229600E+00, 0.61029800E+00, 0.12075500E+00, 0.83615600E-02, -.62168100E-02, -.32199000E+00, -.24535100E+01, 0.96378900E-01, -.15203200E+01, -.22998700E-01, 0.28895800E+00, -.19277600E+01, 0.15061500E+00, 0.11023000E+00, -.25613200E+01, 0.22598900E+00, 0.35294400E+00, -.29463700E+01, -.16903500E+01, -.13379500E+01, -.82575500E+00, -.45913000E+01, -.92924100E+00, -.58364200E+03, 0.28980000E+03, 0.52639400E+03, 0.28943100E+03, -.94446200E+02, 0.37652200E+02, 0.79803500E+02, 0.43502500E+01, 0.35609500E+03, 0.18086900E+01, 0.10496700E+04, -.33679000E+03, 0.16126100E+03, 0.19049800E+03, 0.17997300E+03, 0.49584000E+02, 0.39845800E+02, 0.98910100E+02, 0.86251300E+02, 0.21563600E+03, 0.38010200E+02, -.13639700E+03, 0.15972500E+01, 0.97402300E+00, 0.70895500E+01, 0.21641100E+01, -.54351000E+01, 0.10834400E+02, -.26902000E+02, -.67481800E-01, -.76643100E+01, -.24702100E+02, 0.25684300E+02, -.23768100E+02, 0.76461200E+01, 0.23468800E+02, 0.29214300E+02, -.27229000E+02, 0.12726700E+01, 0.14001500E+01, 0.10397800E+02, 0.33799500E+02, -.88911900E+01, 0.30268000E+02, -.27236600E+02, -.29622800E+02, -.75859500E+00, -.31662400E+02 },
        { 0.12425500E+02, -.56100600E+00, -.25889300E+00, -.34997500E+00, 0.13047400E+01, -.34905800E+01, 0.15250500E+01, -.29250200E+01, 0.49679600E+01, -.24104900E+01, -.39935500E-01, 0.28078600E+01, -.20395200E+01, -.17351000E+00, -.25694700E+00, -.29316300E+00, 0.58365400E+00, 0.37774000E+00, 0.21301200E+01, 0.43790700E+00, -.92914300E+00, 0.85425000E+00, -.41632600E+01, -.23900000E+01, 0.45143200E+00, -.37683800E+00, 0.40798200E+00, -.10383300E+01, -.18727800E+01, 0.11268400E+01, -.34724400E+00, 0.35133300E+00, 0.55551700E-01, -.13464200E+01, 0.12925200E+02, -.26455000E-01, 0.13919100E+00, 0.46630500E+01, -.59002700E+00, 0.81113600E+00, -.22532100E+00, -.28982700E+00, 0.14789100E+00, 0.16847100E+01, -.49606300E+00, 0.55996100E+00, 0.68333900E-01, -.28344400E-01, -.30868000E+00, -.16605600E+00, -.85014700E+00, 0.99865300E+01, -.86317300E+00, -.11984600E+01, 0.33038400E+01, 0.15953000E+00, -.11321000E+00, -.58484100E-01, -.85990900E+00, 0.20615500E+00, 0.75476200E+00, 0.10311700E+01, -.85814500E+00, 0.32363100E+00, 0.12765100E+00, -.79915800E-01, 0.27997300E+00, 0.19149000E-01, 0.24671800E+01, -.19216100E-01, 0.46006700E-01, -.20624100E+00, 0.57194900E+00, -.47095900E+00, 0.21027500E+00, -.14684000E+01, 0.20108500E+00, -.21029500E+02, 0.25870600E+01, -.51730500E+00, -.89453900E-01, 0.92309900E-01, -.37396700E+01, 0.19781100E+01, -.27955000E+01, -.19562400E+02, -.33418600E+00, -.40942800E+00, 0.12441700E+01, -.24091700E+01, 0.17767000E+01, -.15750200E+00, -.25357900E+01, 0.94754800E+00, 0.21341200E+00, 0.13382600E+01, -.19391500E-01, -.24903400E+00, -.32232200E+01, 0.88488700E+00, 0.75948800E-01, 0.63597500E+00, -.49685300E+00, 0.19160300E+00, 0.24132800E+00, 0.15968900E+01, 0.55741300E-01, -.12651400E+01, 0.32121000E+00, -.20488700E-01, 0.25751700E+00, 0.16026500E+00, 0.27403300E+00, 0.52223400E-02, -.12423700E+00, 0.24745600E+00, 0.72162300E-01, -.30377500E+01, 0.85602500E+00, -.31581100E+01, 0.26413000E+00, -.34519000E+00, 0.12414700E+00, 0.20479600E+00, 0.23396600E-02, 0.11898800E+01, 0.14260800E+00, -.24714800E+01, -.44203000E+00, 0.28334600E+01, 0.81067400E+00, 0.10577000E+01, 0.56554900E+00, -.17891200E-01, -.18491100E+01, 0.15959200E+01, 0.22335900E+00, -.32146800E+00, -.87543200E+00, 0.87046100E+00, -.18209200E+01, 0.46350200E+00, -.79147500E-01, -.72763500E+00, 0.91742600E-01, -.47515100E-01, 0.22541000E-01, -.32544800E+00, -.63180600E+00, 0.20136700E+01, 0.48799500E+00, -.11695700E+01, 0.27535100E+01, -.86465800E-01, -.41660100E-01, 0.27934700E+00, 0.54988100E+00, -.20997100E-01, 0.30167400E+01, -.36565400E+00, -.15494900E+01, 0.77741400E+00, 0.50248100E+00, -.13047200E+01, 0.26501200E+00, 0.47604000E+00, -.50324400E+00, -.80102000E+00, -.61356400E-01, 0.44731800E+00, -.10704200E+00, 0.22496800E+01, 0.70530200E-01, 0.24316800E+01, 0.53632300E+00, 0.43332100E+00, -.31265700E+00, -.17685000E+00, -.89926800E+00, -.20088500E+01, -.13918500E+00, 0.63294000E+01, -.50606100E+00, 0.13927700E+01, 0.37446500E+00, 0.12038100E+01, -.23784300E-01, 0.12731000E+01, -.24547200E+00, -.63150500E-01, 0.93575100E-03, -.31453000E+00, -.17385500E+00, -.12677700E+01, -.68656800E-01, -.29001100E-01, -.32498700E+00, 0.20577300E+00, -.76608700E-01, 0.32079600E+00, 0.31647000E+00, -.16035100E-01, 0.30824400E+00, -.44298300E+00, -.14354200E-01, -.69944700E-01, 0.29442600E+00, -.45149800E+00, 0.66601500E-01, -.22210400E+00, 0.77309600E-02, 0.32366800E-01, -.61061100E-02, 0.14262300E+00, -.52528600E-01, 0.24720600E+00, 0.20371100E+01, -.18225200E+00, -.27290300E+00, -.57171200E-01, -.10013500E+00, -.24782900E+00, 0.15904400E+01, 0.72033300E-01, 0.47852400E-01, -.47300700E+00, 0.10091400E+00, 0.14513200E+00, -.64747700E+00, -.38238000E+00, -.98173200E+00, 0.18748300E+00, 0.65413100E-01, 0.37022700E+00, 0.95881000E-02, 0.21882400E+00, -.17565600E+01, -.63351300E-01, 0.13690300E-01, 0.64554500E+00, 0.16213000E+00, 0.16707300E+00, -.11550500E+01, 0.60349300E-01, 0.72842200E+00, 0.23145600E-01, 0.15357100E-01, -.40969800E-01, -.38878800E+00, -.11719700E+00, -.63597600E-02, -.20414500E+00, 0.45651200E-01, 0.67983300E-01, 0.42220400E+02, 0.13668400E+02, -.29590900E+00, -.49570600E+00, -.13893600E+01, 0.63661200E+01, 0.62775800E+01, -.19819900E+02, 0.24821600E+01, -.34182100E+02, -.21736300E+02, 0.14105800E+02, 0.10780300E+02, 0.11392000E+02, 0.64876600E+01, 0.10618500E+02, -.37713800E+01, -.83985200E+01, -.10350500E+02, 0.10660500E+02, 0.19107700E+02, 0.18396400E+00, 0.24870100E+00, -.25341600E+00, -.28793500E+00, 0.34515800E+00, -.30089800E+00, 0.28208000E+01, 0.18284100E+00, 0.44131800E+00, -.57487700E+01, 0.61192300E+01, 0.83946200E-01, 0.29219400E+00, -.23341100E+00, -.29621600E+01, -.61258700E+01, -.11808100E+00, 0.12606400E+01, -.46533500E+00, 0.17295800E+01, 0.38449500E+00, -.27639400E+01, 0.26839400E+01, -.61548900E+01, 0.22394400E+01, -.46549100E+01 },
        { -.32001800E+02, 0.88743000E+00, 0.11687300E+01, -.17525700E+01, -.23703100E+01, 0.41758600E+01, 0.15351200E+01, 0.49475000E+00, -.53325400E+01, 0.18478700E+01, -.22654300E+00, 0.96674200E+00, 0.45105500E+00, 0.16489500E+00, -.84451700E+00, 0.55914100E+00, 0.12640100E+01, 0.91062600E+00, -.17903200E+00, 0.25302800E+01, 0.11238800E+01, -.13507400E+00, 0.12938400E+02, -.70568400E+00, 0.62318500E+00, 0.23102500E+00, 0.85240600E+00, 0.35832100E+01, 0.58779900E+00, -.63473200E+00, -.62284400E+00, 0.39576900E+01, -.72453700E-01, 0.20058900E+01, -.27937300E+01, -.57712900E+00, -.38113600E+00, -.61662800E+01, 0.43255200E+00, 0.40033900E+00, -.45113200E+00, -.61672400E+00, 0.10063400E+01, -.79880500E-01, -.25742600E+01, 0.22978400E+00, 0.50227500E+00, 0.78710600E-01, -.10874500E+01, 0.10207200E+00, -.22328400E+01, 0.14412700E+02, -.37624400E+00, 0.30688400E+00, -.47474300E+01, -.48106400E+00, -.44166400E-01, 0.94091700E+00, 0.67851600E+00, -.51900300E+00, -.11550100E+01, 0.89180900E+00, 0.18185500E+01, -.26937000E+00, -.24613200E+00, 0.12288100E+00, 0.36915800E+01, 0.16227800E-01, 0.10095100E+01, 0.14865500E-01, -.54874100E-01, -.11292100E+00, -.26552500E+00, 0.30193400E+00, -.18478000E+01, -.21458800E+00, -.28916200E+00, 0.40963100E+01, -.24856700E+01, 0.20030100E+01, 0.13113800E+00, 0.30761300E-01, -.58176400E+00, -.11863900E+01, 0.26457500E+01, 0.14323100E+02, 0.75159400E+00, 0.56636600E+00, -.20104800E+01, 0.26336000E+01, 0.38342200E+00, -.27975800E-01, -.19495500E+01, -.30158500E+00, 0.37399900E+00, -.12387900E+01, -.77074100E+00, -.13188300E+01, -.24076000E+01, 0.95327200E+00, 0.26749700E+00, -.24477900E+00, 0.11112500E+00, -.73913300E+00, 0.81753300E-01, 0.97610600E+00, 0.72435600E-01, 0.95857200E+01, -.44028700E+00, 0.76533700E-01, -.11881700E+01, -.13457000E-02, -.16243500E+01, -.13456000E-01, 0.27160200E+00, -.32752300E+00, 0.33397300E+00, -.51664900E+01, 0.42744400E+00, -.14126000E+01, -.37666100E+00, -.32391200E+00, 0.22762200E-01, 0.23143800E+00, 0.60786500E-02, -.33539300E+00, 0.38188700E-01, -.18976400E+01, 0.14096200E+00, 0.55586300E-01, 0.63940800E+01, 0.88171600E+00, -.33243300E+00, 0.32076700E-01, 0.58614100E+00, 0.15378600E+01, 0.20029900E+00, -.18307300E+00, 0.51720200E+00, 0.14610000E+00, 0.83412000E+00, -.28896900E+00, 0.11434100E+00, 0.74923300E+00, 0.76994800E-01, 0.44644500E-02, 0.22101300E-01, 0.33246600E+01, -.26171000E+00, -.19011900E+01, 0.53699300E-01, -.19918600E+01, 0.41986700E+01, 0.38255100E+00, 0.17858700E+00, 0.50784400E+00, -.22665900E-01, 0.22879700E-02, -.12302800E+01, -.36453700E+00, 0.57613600E+00, 0.10185500E+00, 0.24497100E+00, -.77331200E+00, 0.92523400E-01, -.59339700E+00, -.65090500E+00, -.19479100E+01, 0.39186900E+00, 0.81897300E+00, -.18835300E+01, 0.24596500E+01, 0.19567400E+01, 0.15510800E+00, -.77740100E+00, 0.45627300E+00, -.21148900E+00, -.17733100E-01, -.99579500E+00, -.17703900E+01, 0.91032700E+00, -.33272700E+00, -.29237400E-01, 0.10447800E+01, -.63845500E-01, 0.62985400E+00, -.65414500E+00, 0.98485500E+00, -.11033200E+00, -.38179900E+00, 0.24430500E+00, -.28810000E+00, 0.31963500E+01, -.37019600E+01, -.18935500E+01, 0.42334300E+00, -.16984500E+01, 0.77349300E+00, 0.18942700E+01, -.12120800E+00, -.12101800E+01, -.49352700E-01, 0.12038200E+01, -.11736100E+01, -.17587100E+00, -.37381900E+00, 0.31485100E+00, -.27294500E+00, 0.55157400E-01, -.19686600E+00, -.34305300E-01, 0.41701500E+00, -.14199000E+00, 0.12795300E+01, -.15712100E+00, -.19648700E-01, 0.32405100E+01, -.88720500E+00, -.53090600E+00, -.14512400E-01, -.40191900E+00, -.72204400E-01, 0.83925000E+00, -.59995100E-01, 0.10442200E+01, 0.31330600E+01, -.94911200E+00, 0.71872300E+00, -.52518200E+00, -.23028400E+00, 0.13181200E+01, 0.46171600E+00, 0.97906800E-01, 0.15840400E+01, -.22082500E-01, 0.12365400E+01, -.38680500E+01, 0.71061800E-01, -.41978200E+00, 0.19677600E+01, 0.16329800E+00, -.94995400E-01, -.47316000E+01, 0.42936600E+00, 0.19260700E+01, 0.22880300E+00, 0.69393400E+00, 0.53402800E+00, -.13334500E+01, -.10453600E+01, 0.10357200E+01, -.20016000E+01, 0.17468500E+01, -.37152700E-01, 0.19788600E-02, 0.29837500E+03, -.10549300E+01, -.15672600E+03, -.64738700E+02, 0.11140800E+03, 0.53321100E+02, 0.40452600E+02, -.65869000E+02, 0.62261100E+03, -.23919800E+03, 0.11694500E+03, 0.16349000E+03, 0.12374300E+03, 0.38359900E+02, 0.26885100E+02, 0.12901200E+03, 0.79486700E+02, 0.66263900E+02, 0.32732200E+02, -.18079600E+03, -.23813900E+01, 0.24630000E+00, 0.30649300E+01, 0.41427200E+00, -.25540200E+01, 0.51011300E+01, -.27010500E+02, 0.11461900E+01, -.20561200E+01, -.41837500E+01, 0.38352700E+01, -.33895300E+02, 0.47586400E+01, 0.15494900E+02, 0.32451100E+02, -.69772600E+01, 0.25899000E+01, 0.40859200E+01, 0.59473400E+01, 0.38183600E+02, -.55509900E+01, 0.30524200E+02, -.28894800E+02, -.83193200E+00, -.44264600E+01, 0.91855100E+00 },
        { 0.12323100E+02, -.33239500E+00, -.42801100E+00, 0.24622000E+01, 0.18540200E+01, -.41398100E+01, 0.21929600E+01, -.29327100E+01, 0.41311500E+01, -.32092300E+01, 0.11205000E+00, 0.36716700E+01, 0.25882700E+00, 0.87206300E-01, 0.11807000E+01, -.85961500E+00, 0.13645600E+01, 0.98038400E+00, 0.16288500E+01, -.16326500E+01, -.18886300E+01, 0.32489600E+00, 0.16312300E+02, 0.12295000E+01, 0.35572400E+00, 0.27856200E+00, -.84929000E+00, 0.10948800E+01, -.17072400E+01, -.32507600E+00, -.14792800E+01, -.17056200E+01, 0.17355300E+00, 0.68895700E+00, 0.37514600E+01, 0.17320600E+00, 0.48827200E+00, 0.20718200E+01, 0.10566000E+00, 0.52061100E+00, -.52222700E-01, -.28748200E+01, -.14513300E+00, 0.14441900E+01, -.41381600E+00, 0.30391900E+00, 0.70397300E+00, -.97715900E-01, -.61971800E+00, -.96357100E-01, 0.28693700E+00, 0.94035600E+01, -.58555100E+00, 0.30277400E-01, 0.42571100E+01, -.93813900E+00, 0.36625400E-01, -.59119000E+00, -.20791100E+01, 0.28585000E+00, -.16227800E+00, 0.56039400E+00, 0.67140900E+00, 0.50645100E-01, 0.96286400E-01, 0.40921700E+00, 0.11068000E+01, -.16805700E-02, 0.21060700E+01, -.12516400E-01, -.25452100E+00, 0.50945800E+00, 0.32893500E+00, -.13261000E-01, -.37299400E+00, -.14659900E+01, -.94343700E-01, -.63508800E+01, -.10989300E+01, 0.16054600E+01, -.10844200E+00, 0.17051700E+00, -.34725300E+01, -.79871900E-01, 0.31135800E+00, -.95381800E-01, 0.81341200E+00, -.45870700E-01, -.27639300E+00, -.15387400E+00, 0.12158800E+01, -.19015500E+00, -.13565000E+01, -.12581100E+00, -.20691800E+00, 0.13722500E+00, 0.63352300E+00, 0.25067000E+00, 0.94491300E+00, 0.60963300E+00, 0.27918500E+00, -.91580900E+00, -.13986400E+01, -.18161400E+01, 0.59246800E+00, 0.77304300E+00, 0.76089200E+00, 0.65554600E+01, -.10786200E+00, 0.22485000E+00, 0.30855100E+00, 0.27231400E+00, 0.30371800E+00, 0.57855500E-01, 0.10561900E+01, 0.19712000E+00, 0.16413600E+00, -.12550900E+02, 0.40546200E+00, -.27068900E+01, 0.28747900E+00, -.52779200E+00, -.53527200E-01, 0.62356500E-01, 0.11147400E+00, 0.18884000E+00, -.13542900E+00, -.35206800E+01, 0.77458200E-01, -.66676000E+00, 0.11734800E+02, 0.79122900E+00, -.38113700E+00, -.18716600E-01, 0.33268500E+01, 0.24674300E+01, -.16814000E+00, -.49006400E+00, -.35661900E-01, -.13298300E+00, -.10162900E+01, 0.31348800E+00, -.17802000E+00, 0.59215700E+00, 0.20946000E-01, -.10556100E+00, -.15314900E+00, 0.31704800E+01, -.27226700E+00, -.27726200E+01, -.39277000E+00, -.88216100E+00, 0.27036500E+01, 0.89614000E-01, 0.36500500E-01, 0.56548800E+00, -.25960900E-01, 0.23891700E+00, -.38481100E+00, -.91082700E+00, 0.12225900E+01, 0.59029500E-01, 0.24231000E+00, -.71557400E+00, 0.90941200E-01, 0.11017700E+01, -.43646900E+00, -.99236900E-01, 0.20238500E+00, -.82314700E-01, -.76613600E+00, 0.98267900E-02, 0.51010900E+00, -.37516400E+00, 0.86352200E+00, 0.65420900E+00, -.18605700E+00, -.11432600E+00, -.98721600E+00, -.11668400E+01, -.29778200E+00, 0.15013900E+01, -.46376100E+00, 0.75447900E+00, 0.11681100E+00, 0.91928000E+00, -.22459400E+00, -.69491600E+00, 0.16174500E-01, -.18101200E+00, -.29433100E-01, 0.11386400E+00, -.10809800E+01, -.19086300E-01, -.26600500E+00, -.17392500E+00, 0.22191500E+01, -.65127100E+00, 0.16211500E+00, 0.52730700E-01, 0.32043800E+00, 0.70109400E-02, 0.27091500E+00, -.13250000E+01, -.92597100E-01, 0.57238900E-01, 0.13748000E+00, -.33422200E+00, -.28976200E+00, -.22561300E+00, -.22111900E-01, -.12017800E+00, 0.18633500E+00, 0.36647200E+00, 0.27494700E-01, 0.21217300E+00, 0.58127700E+00, 0.58528700E+00, 0.42158600E+00, 0.15262600E+00, -.74551600E-01, 0.88542100E-02, 0.14752500E+01, -.16542600E+00, 0.12731400E+00, 0.27337300E+00, -.12348300E+00, 0.22892500E+00, -.49416000E+00, -.35125600E+00, -.34791500E+00, 0.80580000E-01, -.44110800E-02, 0.12428800E+01, -.13082800E-01, -.15445200E+00, -.24567800E+01, -.13911200E+00, -.65085400E+00, 0.99199600E+00, 0.15114000E-01, 0.76103600E-01, -.59960100E+00, -.17895600E-02, 0.66147500E+00, 0.90325100E-02, -.42915900E-01, -.32442200E+00, -.27587400E+00, -.15513000E+00, -.15984200E+00, -.56515600E+00, 0.99849300E-01, 0.16027800E+00, -.82972900E-02, -.21880800E-01, 0.38781800E+01, 0.37024700E+01, -.61781600E+01, 0.13782900E+02, 0.11484000E+01, -.26125500E+02, 0.22592300E+00, -.64339300E+02, -.68442500E-01, 0.43628900E+00, 0.53025900E+01, 0.54484300E+00, 0.70121300E+01, 0.13075300E+02, -.17288400E+02, -.13580000E+02, -.18764500E+02, 0.12699000E+02, -.11553900E+02, 0.30060200E+00, 0.38555900E+00, -.29080900E+00, -.33019700E+00, 0.54503900E+00, -.53818800E+00, 0.35983100E+01, 0.40296000E+00, 0.34667400E+00, 0.91154200E+00, -.12114600E+01, 0.31406500E+01, -.22741300E+00, -.46493100E+00, -.36005400E+01, 0.10675400E+01, -.39895700E+00, 0.11898800E+01, -.74537200E+00, -.15876200E+01, 0.71247000E+00, -.40606800E+01, 0.34634600E+01, 0.14107000E+01, 0.39827600E+01, 0.17897500E+01 },
        { -.30528800E+02, 0.71506700E+00, 0.12148200E+01, 0.15198700E+01, -.29429900E+01, 0.53139400E+01, 0.22387300E+00, 0.99650900E+00, -.20701100E+01, 0.41520200E+01, 0.14504600E-01, -.93123200E+00, -.47617100E-01, 0.30332400E-01, -.30661300E+00, 0.35405600E+00, 0.77778200E+00, 0.59178200E+00, -.34420100E+00, 0.21926000E+01, 0.14874000E+01, -.51014100E+00, 0.13904700E+02, 0.79235700E+00, 0.43765900E+00, 0.27278800E+00, -.77567600E-01, 0.31532200E+01, 0.30684500E+01, -.96905700E+00, 0.59589000E+00, 0.31413900E+00, -.25089200E+00, 0.35094800E+01, -.45241700E+01, -.14742100E+01, 0.78499300E-01, -.45428800E+01, 0.44214500E+00, -.14904100E+01, 0.13380400E+01, 0.15682600E+01, -.49718000E+00, -.90161400E+00, 0.47778800E+00, -.33403100E+00, 0.54492100E-01, 0.48339800E-01, -.13684700E+01, 0.26012200E+00, -.11028400E+01, 0.76198100E+01, -.13434800E+00, 0.25713300E+00, -.38513100E+01, 0.26355700E+00, 0.20920600E+00, 0.94974100E+00, 0.73888800E+00, -.45902300E+00, -.65219800E+00, 0.10370000E+01, 0.51818800E+00, 0.15238500E+00, 0.13852000E+00, 0.67112100E-01, 0.12254200E+01, 0.69071200E-02, -.14286500E+00, 0.90343400E-02, -.15947500E-01, 0.12263300E+00, -.13355700E+00, 0.25656000E+00, 0.75233800E+00, -.12538700E+01, -.68738400E+00, -.22292800E+01, -.73682800E+00, -.47048400E+00, 0.66144400E-01, 0.12192700E+01, 0.94588500E+00, -.19178100E+00, -.17913900E+00, 0.22830500E+01, -.41227500E+00, -.23196900E-01, -.86007400E+00, -.93443700E+00, 0.47840200E+00, 0.90906400E-01, -.31953600E+01, -.29270900E+00, 0.70554500E-01, -.14320500E+01, -.87840300E-01, -.33911600E-01, -.58458700E+00, 0.94185200E+00, 0.25685500E-01, -.76543100E+00, 0.40058300E+00, 0.30390200E+00, -.52065800E-01, -.59960000E+00, -.46285900E-01, 0.53801200E+01, 0.31672700E-01, -.20478100E-01, -.10348000E+01, 0.15480000E+00, -.53521900E+00, -.10915500E-01, 0.26388900E+00, -.20754100E+00, 0.41429900E+00, -.62183600E+01, 0.84229000E+00, 0.68767300E+00, -.10001100E+01, -.21836000E+00, 0.22966700E-01, 0.88665500E+00, -.11795700E-01, 0.49560200E+00, 0.13832900E+00, -.18704500E+01, -.17194900E+00, 0.70912900E+00, 0.11638200E+02, 0.82887500E+00, -.20281700E+00, 0.70959000E-01, 0.88637000E+01, -.81875500E+00, -.90205800E-01, -.47238300E+00, -.75040000E+00, 0.10625500E+01, 0.45516700E+00, -.17235100E+00, -.41869600E-01, 0.33228000E+00, 0.13321700E+00, 0.43484100E-01, -.17283800E-01, 0.99232600E+00, 0.35017200E+00, -.18260500E+01, -.18291100E+00, -.17464400E+01, 0.47846600E+01, 0.21825200E+00, 0.18845200E+00, 0.34168900E+00, -.10165600E-01, 0.13032900E-01, -.35998800E+00, -.57572500E+00, 0.85892600E+00, -.24503100E-01, 0.24548300E+00, -.88870500E+00, 0.15640100E+00, -.34654900E-01, -.44152300E+00, -.55983300E+00, 0.17297200E+00, 0.83312900E+00, -.96328500E-01, 0.25362400E+01, 0.74435100E+00, 0.22179500E+01, -.16523200E+00, 0.20589500E+00, -.22662700E+00, 0.54810000E-02, -.22678600E+00, -.21721800E+01, 0.73206000E+00, -.29835500E+01, -.19135700E+00, 0.67480000E+00, -.26409100E+00, 0.75801600E+00, -.57686000E+00, 0.69414200E+00, -.16308500E+00, -.13620500E+00, -.15527700E-02, -.19861900E+00, 0.88651400E+00, 0.27606400E+00, -.72137600E-01, -.91529700E-01, 0.18506400E+01, 0.12852300E+01, 0.80515500E-01, 0.29844300E-02, 0.96487600E+00, -.72425200E-01, -.13620800E+00, -.12996200E+01, 0.17833700E+00, -.36489200E-01, 0.42601800E+00, -.13442700E+01, 0.41720100E+00, -.41174500E+00, -.64224700E-02, -.44792600E-01, -.21199900E+00, -.29802800E+00, 0.22294300E+00, -.10790600E+00, -.28952600E+01, 0.82213600E+00, 0.85115500E+00, 0.18909200E+00, 0.55683700E-01, 0.56098400E-01, -.19719500E+01, -.21857400E-01, -.23553800E+00, 0.19823900E+01, -.10737100E+01, 0.53468200E+00, 0.64079000E+00, 0.47467000E-01, 0.16275200E+01, 0.31555500E+00, 0.88198700E-01, 0.94657900E+00, -.10767200E+00, -.25124400E+00, 0.89680900E+00, -.59183000E-01, -.15085700E+01, 0.34930500E+00, 0.14320800E+00, 0.15420400E+00, 0.93050500E+00, 0.41459600E-01, 0.33438200E+00, 0.44055600E-01, -.15442900E+00, -.25666100E+01, 0.81742800E+00, 0.43875100E+00, 0.11768800E+01, -.12981700E+01, -.11380800E+01, -.16405600E+00, -.58786000E-01, -.69870200E+00, -.50990800E+00, -.21861400E+03, -.73247300E+02, 0.88440200E+02, 0.35368700E+02, 0.10316300E+03, -.85967300E+02, 0.52656000E+03, -.34391900E+03, 0.16848600E+03, 0.20446700E+03, 0.18399300E+03, 0.67439400E+02, 0.46177300E+02, 0.12418600E+03, 0.46268400E+02, 0.58533700E+02, 0.50858900E+02, -.21233700E+03, -.63711100E+00, 0.26553000E+01, 0.44393700E+01, 0.12258100E+01, -.32086500E+01, 0.62331500E+01, -.24130100E+02, 0.99362700E+00, -.46017200E+01, -.73624100E+01, 0.80591200E+01, -.25595800E+02, 0.16276800E+01, 0.16218000E+02, 0.31674600E+02, -.10682600E+02, 0.10286500E+01, 0.23884200E+01, 0.60669400E+01, 0.42969700E+02, -.52880600E+01, 0.27006400E+02, -.26241800E+02, -.88570500E+01, -.18289600E+02, -.11677000E+01 },
        { 0.64602200E+01, -.23058100E+00, -.22175200E+00, -.10304500E+00, 0.71936600E+00, -.16142600E+01, 0.18808800E+01, -.79122600E+00, -.10392800E+01, -.14391000E+01, 0.10163900E+00, 0.28754600E+00, -.21172000E+00, 0.18022900E-01, -.44564700E+00, -.48818000E+00, -.58356200E-01, 0.29067400E-01, 0.50060700E+00, 0.86258600E-01, 0.13897400E-01, 0.16856400E-02, -.67307600E+00, -.21338000E+00, 0.12036000E-01, -.27828800E-01, 0.31423900E-01, -.22718500E+00, -.28765200E-01, -.47882400E-01, 0.84452000E-01, -.24936400E+00, -.15580000E-01, -.16113500E+00, 0.64661100E+00, 0.60922200E-01, -.44736000E-01, 0.14195800E+00, -.39444300E-01, -.38536500E-01, -.15083900E+00, 0.26726900E+00, -.84975000E-01, -.35748900E-01, -.32947100E+00, 0.11777800E+00, -.19667500E-01, 0.14729800E-01, 0.24412000E+00, -.29989000E-01, -.37933300E+00, -.51040600E+00, -.77515000E-01, -.11503100E+00, -.98319700E+00, 0.13127400E+00, -.26029700E-01, 0.46242600E+00, 0.32342400E+00, -.30030700E-01, -.72872300E-01, -.94903200E-01, 0.74809700E-01, -.24570000E-01, -.59813500E-01, 0.10956000E+00, -.21504100E+00, -.74171000E-02, -.17200500E+00, 0.93030700E-03, -.84864700E-01, 0.92913500E-01, 0.81885300E-02, 0.22973600E-01, -.49868900E+00, 0.33637000E-01, 0.15800700E-01, 0.11841500E+01, -.23424400E-01, 0.69371000E-01, 0.56680300E-02, 0.19704800E-01, 0.11222100E+00, 0.15477700E+00, -.74540400E-01, -.31806700E+01, 0.92397700E-01, 0.91939100E-01, 0.43529400E+00, 0.58341800E-01, -.44796900E-01, -.20620700E-01, 0.11468300E+01, 0.48886800E-02, 0.80151100E-01, 0.52193500E-01, 0.49878300E-01, -.10918900E+00, -.51373500E+00, 0.38899300E+00, 0.19274000E-01, -.30935300E+00, 0.10714400E+00, 0.19837400E+00, -.52955900E-01, 0.22603800E+00, -.81127800E-01, 0.29902700E+00, -.13994100E+00, 0.72805400E-01, 0.16880200E+01, -.43756300E-02, -.15490700E+00, -.12149700E-01, -.36783900E+00, -.46740000E+00, 0.70124700E-01, 0.63165900E+00, -.63173500E-01, 0.44954000E+00, -.16949900E+00, -.25563600E-01, 0.27789600E-01, 0.16925600E+00, -.17967600E-01, -.10026000E+00, 0.14304600E+00, 0.51430300E-01, -.22656700E+00, 0.56736400E+00, -.28161600E+00, 0.57361500E+00, -.72639600E-01, 0.95375200E-01, 0.17889700E+01, -.15683700E+01, 0.11331700E-01, 0.14020200E+00, 0.33322900E+00, 0.26520100E+00, 0.30323600E+00, -.43776500E+00, 0.42677700E-01, 0.74979700E-01, 0.41323900E-01, 0.45794400E-01, 0.24187500E-01, -.24035600E+00, 0.40666700E-01, 0.82316800E+00, 0.19447900E+00, -.26585200E+00, 0.60122000E+00, 0.74013600E-01, 0.22114500E-01, -.36308500E-01, 0.19029700E-01, -.15426800E-01, -.69552500E+00, 0.21570200E+00, -.74959300E-01, 0.26563400E+00, 0.80402800E-01, -.71646900E-01, 0.40804400E-01, -.58607900E+00, 0.35779200E-01, 0.30127000E-01, -.54985100E-01, 0.14243900E+00, 0.78935900E-01, -.71518400E+00, 0.47747900E-01, 0.46621900E+00, 0.21967000E+00, -.20047000E-01, 0.12149400E-01, 0.34663900E-01, 0.10634400E+00, 0.46814200E+00, 0.41968600E+00, -.27424800E+01, 0.15494400E+00, -.29424300E+00, 0.76092000E-01, -.49616600E+00, 0.15177800E-01, 0.21779300E+00, -.92027800E-02, -.42191900E-01, 0.27295200E-02, -.12644000E+00, -.17522700E+00, 0.11016000E+00, 0.21580500E+00, -.42658100E-02, -.87247000E-02, 0.46522100E+00, 0.24064400E-01, -.11523800E-01, -.50745500E+00, -.16117800E-01, 0.48417100E+00, -.40143400E+00, 0.13244200E+00, -.48017100E-02, 0.58892400E-01, -.24272700E+00, 0.19065400E+00, 0.36627900E-01, -.17820900E-01, 0.16297500E+00, -.80389100E-01, 0.64455700E-01, 0.82216900E-02, 0.15600200E-01, -.54924300E+00, 0.25772800E-01, 0.97362100E-01, 0.43695300E-02, -.50811300E-02, 0.22055600E-01, -.65600100E+00, 0.28665600E-01, 0.42378800E-02, 0.34328100E+00, -.14947100E+00, 0.10876100E-01, 0.29432500E+00, 0.38949100E-01, 0.16539200E+00, -.80101800E-01, 0.48147300E-01, -.20305500E+00, -.82841000E-02, -.15612800E+00, 0.12085500E+01, -.19402700E-01, 0.81496600E-01, -.44780400E+00, 0.12774200E+00, -.60644100E-01, 0.29599400E+00, -.29606000E-01, -.13701800E+00, -.21190800E-01, -.68953900E-01, -.12297600E+00, -.11612000E+00, 0.66705800E-01, 0.23927500E+00, -.36388600E+00, -.50778200E+00, -.33992200E-01, -.21969200E-01, 0.64743700E-01, -.98878000E-01, 0.18953900E+00, 0.11250900E+02, -.14611100E+02, -.42844400E+01, 0.43591600E+01, 0.45973900E+01, -.11487900E+03, 0.44274400E+02, -.20841300E+02, -.18876500E+02, -.23189300E+02, 0.45548400E+01, 0.27612400E+02, -.46873700E+02, -.15876700E+02, -.31426200E+02, 0.22517700E+02, 0.74421500E+02, -.60845000E-01, -.32544300E+00, -.64310900E+00, -.12279500E+00, 0.32890900E+00, -.76742900E+00, 0.41208200E+01, -.22137800E+00, 0.67345500E+00, -.27046300E+01, 0.29787000E+01, 0.39933300E+01, -.81469300E+00, -.24322000E+01, -.58684000E+01, -.22521200E+01, -.80579400E+00, 0.58191600E-01, -.61607100E+00, -.11778500E+01, 0.78410600E+00, -.49465400E+01, 0.46633700E+01, -.39837300E+01, -.54873400E+01, -.24810000E+01 },
        { 0.42697100E+01, -.14982900E+00, -.18848600E+00, -.39261200E+00, 0.78810500E+00, -.22539800E+01, 0.19714300E+01, -.22329800E+01, 0.19591300E+01, -.18323100E+01, -.15681600E-01, 0.26909300E+01, 0.31779300E+00, 0.93380700E-01, 0.58577600E+00, -.36546200E+00, 0.85188200E+00, 0.88711000E+00, 0.96216900E+00, -.10893100E+01, -.16636000E+01, 0.34726200E+00, 0.10640200E+02, 0.27042100E+00, 0.36591300E+00, -.27218100E+00, 0.13609300E+00, -.37535300E+00, -.17105800E+01, -.12680100E+01, -.10174500E+01, -.15411400E+01, 0.93911800E-01, -.12329000E+01, 0.42245000E+01, 0.65441100E+00, -.19504200E-01, 0.19819300E+01, 0.12209000E+00, 0.98694300E+00, -.13540900E+01, -.45353900E+00, -.34960300E+00, 0.42034200E+00, -.89687200E+00, 0.30136400E+00, 0.31118400E-01, -.64093500E-03, 0.10074400E+01, -.18072400E+00, 0.10891400E+01, -.32906100E+01, 0.11459000E+00, 0.19957600E+00, -.69437000E+00, 0.50264800E+00, -.14236800E+00, 0.47292500E-01, 0.42626100E-01, 0.16326000E+00, 0.38063800E-01, -.33448000E+00, 0.39078400E+00, -.25197800E+00, -.54977700E+00, -.21149800E+00, -.31973200E+00, 0.67659800E-03, -.94255600E+00, 0.23885100E-03, 0.95926300E-01, 0.40382300E-01, -.88238600E-01, -.16152900E+00, 0.45685100E+00, 0.61128900E+00, 0.89839800E+00, 0.81131100E+01, -.12647000E+01, 0.48974700E+00, 0.21614200E-01, 0.13421500E+01, -.16770200E+01, -.42806000E+00, -.47722900E+00, -.41145800E+01, 0.39273900E+00, 0.34700700E+00, 0.82704000E+00, 0.18985300E+01, 0.52420700E+00, 0.20026200E-01, -.46127100E+00, 0.41062300E+00, -.99954000E-01, -.17470100E+00, -.46745500E+00, 0.53656800E+00, -.86608400E+00, 0.16762900E+00, 0.40386600E-01, 0.36141900E+00, -.39292700E-01, 0.22108100E+00, 0.38319100E-01, -.13070000E+00, -.11045700E+00, -.19366200E+01, 0.46212900E+00, -.27060300E+00, 0.31617000E+01, -.22754200E+00, 0.17097500E+00, -.22160100E-01, -.13049800E+01, 0.67592400E+00, -.58330200E-01, -.40363000E+01, -.42717800E+00, -.11825100E-01, 0.14994100E+00, -.10985000E+00, 0.41595300E-01, -.54975000E+00, -.22002800E-02, 0.86089200E+00, 0.36261400E+00, 0.16880800E+00, -.32467800E+00, -.27007800E+00, -.40662900E+01, 0.10415400E+01, 0.15679700E+00, 0.20736900E-01, -.27791500E+00, -.58200400E+00, -.39611200E-01, 0.19693100E+00, -.13490100E+00, -.25787000E+00, 0.45242100E+00, 0.13479400E+00, 0.12289500E+00, 0.20712400E-01, 0.80683400E-02, -.21157700E+00, 0.28896100E-02, -.45661100E+00, 0.74130700E-01, -.30982500E+00, 0.22367900E-01, -.76130700E-01, 0.75137700E-01, -.71518300E-01, 0.73463900E-01, -.12117500E+00, -.79078200E-01, -.87268600E-02, -.10627300E+01, 0.45285000E+00, 0.43085000E+00, -.28993300E+00, 0.16489800E+00, 0.14778600E+00, 0.71672000E-01, -.15061300E+00, 0.13546900E-01, -.49976400E+00, -.10970800E+00, 0.86939300E-01, 0.25196500E+00, -.29470400E+00, -.30875900E+00, -.68905300E+00, -.19432200E+00, -.27236300E-01, 0.10629800E+00, -.77815600E-01, -.31309000E+00, -.10683300E+00, -.26749200E+00, 0.12936600E+01, -.16530000E+00, 0.21351500E+00, 0.26549400E+00, -.68942400E+00, 0.13023300E+00, 0.46220300E-02, 0.21493400E-01, 0.28840300E-01, 0.20770300E-02, 0.63542200E-01, 0.54945200E+00, -.15917200E+00, 0.13026000E+00, 0.19580600E+00, 0.43298300E-01, -.92614300E-01, 0.13899100E-01, -.59894600E-01, 0.11859600E+00, 0.60259000E-02, -.38811100E+00, 0.74444700E+00, 0.39090400E-01, -.13423600E-01, -.26803100E-01, 0.13442500E+00, 0.20235700E+00, -.47773200E-01, 0.97526000E-02, -.13454200E+00, -.45514200E-01, -.28351300E-01, 0.13752500E+00, -.47953100E-01, -.48743800E+00, 0.30884500E+00, 0.27511200E+00, 0.55935000E-01, 0.75305500E-01, -.17631400E-02, 0.34947800E+00, 0.45572200E-01, 0.21765500E-01, -.41052300E+00, 0.42080200E+00, -.95293200E-01, -.10787600E+00, -.86836900E-01, -.86508900E+00, 0.57296900E-01, 0.41153900E-01, 0.33336500E-01, -.89763700E-02, 0.40021800E+00, 0.11626100E+01, -.57163800E-01, 0.13812300E+00, -.76093300E-01, 0.23898600E+00, 0.19231300E+00, 0.10106500E+01, -.10998500E+00, -.14552000E+00, -.15687600E-01, -.18348000E+00, -.51591000E-01, 0.22855600E+00, 0.16296300E+00, 0.29153000E-01, -.20953500E+00, -.47242600E+00, -.19485700E-01, -.12434000E-01, 0.30413800E-01, -.92252400E-01, -.79484300E-01, -.40380800E+00, -.10970800E+02, 0.11792500E+01, 0.12270800E+02, -.32868000E+01, -.11402100E+03, 0.17114000E+02, -.79614100E+01, -.13909400E+01, -.65029500E+01, 0.13041600E+02, 0.32593800E+02, -.48964200E+02, -.41007600E+02, -.68131800E+02, 0.28771900E+02, 0.50613800E+02, 0.67931800E+00, 0.58451700E+00, -.62003500E+00, 0.82296300E-01, 0.88808400E+00, -.11757300E+01, 0.74292400E+01, -.28995200E+00, 0.55918100E+00, -.47221800E+01, 0.36238600E+01, 0.65898500E+01, -.54296700E+00, -.27085700E+01, -.90598000E+01, -.37564000E+01, -.12018900E+01, 0.19850300E+00, -.15597400E+01, -.48239900E+01, 0.15838100E+01, -.87165600E+01, 0.76056200E+01, -.67435600E+01, -.47595100E+00, -.13538900E+01 },
        { 0.29751400E+02, -.58882200E+00, -.11220800E+01, -.36154000E+01, 0.30761800E+01, -.58140400E+01, 0.18165700E+00, -.35976700E+01, 0.63050500E+01, -.44659700E+01, -.21522900E+01, 0.55353500E+01, 0.11286500E+01, 0.22849500E+00, 0.21953300E+00, -.42907500E+00, 0.34108200E+00, -.19123300E+00, 0.12600200E+01, -.17242600E+01, -.37404000E+01, 0.22320900E+01, 0.21901600E-01, -.27931200E+01, 0.45532700E-01, -.56406000E+00, 0.10540800E+01, -.29061600E+01, -.67201800E+01, 0.39056700E+01, -.30615600E+00, 0.90667900E+01, 0.12087500E+01, -.17152700E+01, 0.50722800E+01, 0.63976300E+00, -.68418600E-01, 0.58867500E+01, -.40088200E+00, 0.14526200E+01, -.76751900E+00, -.12762100E+01, 0.13399200E+01, 0.19978600E+01, -.75329500E+00, 0.89823500E+00, 0.59500900E+00, 0.61220000E-03, -.62458100E-01, -.31816100E+00, 0.11031900E+01, 0.17360600E+01, 0.17543100E+00, -.47864200E+00, 0.54211800E+01, -.18987300E+00, -.13329100E+00, -.43366200E+00, -.53010600E+00, 0.48016200E+00, 0.30690500E+00, -.27095200E+00, 0.91040900E+00, -.24609200E+00, -.15155200E+01, 0.30440200E+00, -.36226700E+01, -.32248600E-01, -.25653500E+01, -.11471000E-01, -.34281200E+00, 0.46846400E+00, 0.56857700E+00, -.23634400E+00, -.49386900E+00, -.46868100E+00, 0.25084200E+01, 0.30180400E+01, -.71657600E+00, 0.16200300E+01, 0.10728600E+00, 0.30529500E+01, -.26988900E+01, -.13228700E+01, 0.23176700E+01, -.20510600E+02, -.10130200E+01, 0.29157900E+00, -.11948000E+01, -.19851000E+01, -.58571600E-01, -.99505400E-01, 0.18331900E+01, -.10007000E+00, -.51782600E+00, 0.30307800E+01, 0.62336700E+00, -.63850000E+00, 0.65921600E+01, -.89387700E+00, -.11778200E+00, -.30164700E+00, -.20202200E+00, -.41152100E+00, 0.51756000E+00, 0.89769800E+00, -.22061700E+00, -.23141000E+01, 0.32042700E+00, -.37945500E+00, -.49154600E+01, -.25514900E+00, -.27307300E+00, 0.11837300E-01, -.93137300E+00, 0.36239100E+01, -.73098200E+00, -.30473300E+01, -.70186100E+00, -.42078700E+01, 0.71435400E+00, 0.12607400E+00, -.91345800E-01, -.84770300E+00, -.30308200E-02, -.29109500E-01, -.69250000E+00, -.14064800E+01, 0.91205200E+00, 0.58964900E+00, -.77672600E+01, -.68018800E+00, 0.29726600E+00, -.30932400E+00, -.17531800E+02, 0.30863300E+01, -.10148900E+00, 0.26735300E+00, -.22444000E+01, -.21578000E+01, 0.50332400E+00, -.30631100E+00, -.27379600E-01, 0.16412100E+01, -.21091000E-01, -.15125500E+00, 0.42311600E-01, -.43405400E+00, -.14087900E+00, -.57090600E+01, 0.58773300E-01, 0.14110600E+00, 0.32864700E+00, -.10810100E+00, 0.43942900E+00, -.11385400E+00, -.45271700E+00, 0.76226400E-01, -.72838200E+00, 0.55520000E+00, -.16822400E+01, -.34280400E+00, -.45180300E-01, 0.11961500E+01, -.61252500E+00, -.13151800E+01, 0.21066800E-03, -.67519700E+00, 0.98897200E-01, -.12464600E+01, -.59120100E+00, 0.28098600E+01, 0.61453300E+00, -.79309300E+00, -.10470100E+01, 0.11435900E+01, 0.21368500E+00, -.21787900E+00, -.81132000E+00, -.85555900E+00, -.12772900E+01, 0.82174100E+01, 0.85360900E-01, 0.76002500E+00, 0.79562000E-02, -.39131100E+00, 0.19759300E+01, -.31130500E+00, 0.82584400E-01, 0.21563000E+00, -.28012600E-01, 0.34073800E+00, 0.31476600E+01, -.10353800E+01, 0.13591300E+01, 0.21033100E+00, -.27360300E+01, -.35241000E+00, -.13367600E+01, -.16905700E+00, -.16110300E+01, 0.52395600E-01, -.31231700E+00, 0.75013700E+00, -.16719000E+00, 0.28885000E+00, -.13811900E+00, 0.19332700E+00, 0.24100000E+00, -.27861400E+00, 0.11873200E+00, -.55932400E+00, 0.81434400E-01, -.44397400E+00, 0.58351600E-01, -.48640500E+00, -.25335800E+01, 0.10000400E+00, 0.24187700E+00, 0.77280900E-01, 0.30522300E+00, -.11430000E+00, -.12269800E+01, -.36686700E-01, 0.54428800E+00, -.92751100E+00, -.10719700E+01, 0.13007900E+00, 0.18111700E+01, 0.77528100E+00, 0.18593100E+00, -.63535300E-01, 0.85428200E-01, 0.42495500E+00, -.14813400E+00, -.10182400E+01, 0.36052500E+01, 0.30093300E+00, -.97495100E+00, -.30093900E+00, -.41881800E+00, -.12910300E+01, 0.62679500E+00, 0.85159700E-01, -.17718600E+01, 0.27972000E-01, -.54929300E+00, 0.90480100E+00, -.10068100E+01, 0.39532100E+00, 0.14499000E+01, -.39813700E+00, 0.11027300E+01, 0.42429400E+00, -.20793000E+00, 0.81350400E+00, 0.53020500E+00, 0.18796200E+00, 0.40878500E+01, 0.25963200E+01, 0.79621500E+02, 0.10258000E+03, -.75413600E+01, 0.78766500E+02, 0.64676600E+02, -.37936100E+02, -.12143300E+03, -.45016100E+02, -.10881400E+03, -.25453700E+03, 0.26621800E+03, 0.16365700E+03, 0.30882300E+03, -.22757700E+03, -.41893300E+03, -.22480400E+01, -.18545300E+01, 0.47468100E+01, 0.18143900E+01, -.22157300E+01, 0.60949200E+01, -.21009100E+02, 0.25115200E+01, -.47548400E+01, 0.46691500E+02, -.44440800E+02, 0.31616500E+01, 0.36399400E+01, 0.10939000E+02, 0.25894500E+02, 0.45053100E+02, 0.83936800E+01, -.24398400E+01, 0.62166900E+01, 0.87842600E+01, -.65791300E+01, 0.24623300E+02, -.21326100E+02, 0.57942100E+02, -.59759100E+01, 0.26666800E+02 },
        { 0.14139000E+01, -.19357700E+00, -.85569700E-01, -.13706100E+01, 0.58990400E+00, -.33525600E+01, 0.17794500E+01, -.21533200E+01, 0.19138300E+01, -.27074800E+01, 0.57143200E-01, 0.12265900E+01, 0.19070100E+00, 0.22221900E+00, 0.57818100E+00, -.31777300E+00, 0.71927500E+00, 0.90147600E+00, 0.63770000E+00, -.11070800E+01, -.15637400E+01, 0.29172500E+00, 0.96395800E+01, 0.27813900E-01, 0.14197100E+00, -.16320700E+00, 0.11406500E-01, -.13256600E+00, -.14723400E+01, -.48098400E+00, -.63996800E+00, -.22500500E+01, 0.10756100E+00, -.33231900E+00, 0.37426500E+01, 0.11700700E+00, -.72656900E-02, 0.28146100E+01, -.13667000E+00, 0.45819800E+00, -.49420900E+00, 0.94637800E+00, -.57358000E+00, -.11378200E+00, 0.41193500E+00, 0.21933600E+00, 0.27097500E-01, -.10404000E-01, 0.56273300E+00, -.94908400E-01, 0.11035400E+01, -.19220400E+01, 0.17344400E+00, -.19203000E+00, -.15745800E+01, 0.69243300E+00, -.83665800E-01, -.11682600E+00, -.57670500E-01, 0.97353700E-01, 0.39149100E-01, 0.18893000E-01, 0.18073500E+00, -.18276700E+00, -.94382000E+00, -.22551100E+00, 0.48138200E+00, 0.58801800E-03, -.90401300E+00, -.50136800E-03, 0.13260200E+00, -.56546700E-01, 0.39767400E-02, -.16214600E+00, -.27335800E+00, 0.10436800E+00, 0.71579400E+00, 0.38696500E+01, -.16513400E+00, -.17757200E+00, -.11235500E-01, 0.38671700E+00, -.15457400E+01, 0.32552800E+00, -.79054700E+00, -.35276700E+01, 0.11018100E-01, 0.10091400E+00, 0.85539900E+00, 0.53630100E+00, 0.42488900E+00, -.16638200E-01, -.43873900E+00, 0.22271200E+00, -.13295300E+00, 0.24623000E+00, -.18920300E+00, 0.26536400E+00, -.16838300E+00, -.10384000E+00, -.79183800E-01, 0.52657700E+00, -.15166900E+00, 0.23455000E+00, 0.11878000E+00, 0.57399200E+00, -.62250200E-01, -.39611300E+01, 0.26664000E+00, -.53734800E-01, -.46416900E+00, -.10780200E+00, -.57759000E-01, -.70983200E-02, -.37916100E+00, -.36065800E+00, -.15578900E+00, -.17379700E+01, -.44988900E+00, -.85100600E+00, 0.32007200E+00, -.38106200E-01, 0.20385400E-02, -.50511400E+00, -.26167600E-02, 0.13086700E+01, 0.20044300E+00, 0.26922700E+00, -.32148600E+00, 0.95994900E+00, -.53019700E+01, 0.43458000E+00, 0.57002000E+00, 0.65963100E-01, 0.24130300E+01, -.17569500E+01, -.35469100E-01, 0.44945500E+00, -.13274700E+00, -.30479700E+00, 0.10345200E+00, 0.48833900E+00, 0.43809100E-01, -.42060700E+00, -.14480200E-01, -.28177600E+00, -.13284200E-02, -.62652600E+00, 0.12078200E+00, -.73243000E+00, -.46925400E-01, -.14327000E+00, -.17409900E+00, -.18708300E+00, -.48094200E-02, -.80291300E-01, 0.95444200E-02, -.81280800E-03, 0.27567200E+00, 0.35292800E+00, 0.52745800E-01, 0.49086700E-01, 0.95643400E-01, 0.85161600E-01, -.22482400E-01, -.92500900E-01, 0.30770300E-01, -.56235400E+00, -.91673900E-01, 0.95086300E-01, 0.35202800E+00, -.79676700E+00, -.42224000E+00, -.56370500E+00, -.37199800E+00, -.13437600E+00, 0.15446900E+00, -.36729700E-01, -.50567400E+00, -.52833500E+00, 0.25543000E+00, -.11511500E+01, -.33528500E+00, -.38825700E+00, 0.33311300E+00, -.15572600E+01, 0.11168800E+00, 0.72014400E-01, -.14466400E-01, -.30568000E-01, 0.14243900E-02, 0.77239300E-01, 0.12671000E+01, -.10584600E+00, 0.30392500E+00, 0.86867400E-01, -.11761600E+01, -.11182300E+00, -.58110500E+00, -.23299900E-01, 0.18587000E+00, 0.39639200E-02, -.54071700E-01, 0.59889700E+00, 0.16595200E+00, -.64749400E-01, -.34859800E-01, 0.47139000E+00, 0.25429000E+00, 0.76443300E-01, 0.87545000E-02, -.83445200E-01, -.51299700E-01, -.35206700E+00, 0.43060300E-01, -.11625300E+00, -.55509100E+00, -.27444900E-02, 0.63264900E-01, -.40640100E-02, -.57750200E-01, 0.53766300E-01, -.62460900E+00, -.43509500E-01, 0.55216100E+00, 0.43444500E+00, 0.29698000E+00, 0.17201600E+00, -.77393400E-01, -.76338100E-01, -.14561200E+00, 0.46901400E-01, -.14182900E-01, -.59263600E+00, 0.22007000E-01, 0.19079700E+00, 0.87660700E+00, -.36413700E-01, 0.20170600E+00, -.35909200E+00, 0.11654400E+00, 0.21532100E+00, 0.36957900E+00, -.41736900E-02, -.76346800E+00, 0.16272200E-01, 0.11305900E+00, 0.10995200E+01, -.11665000E+00, -.10163100E+00, -.19042100E+00, 0.11491900E+00, 0.10320900E+00, 0.12906400E+00, 0.32862100E-01, -.22152300E+00, -.25489300E-01, -.94783400E-01, -.16489500E+01, -.57603100E+00, -.23043000E+00, 0.22861300E+02, -.29154900E+01, -.24709100E+03, 0.10947300E+03, -.52114100E+02, -.37805700E+02, -.57894000E+02, -.33660700E+01, 0.20163800E+02, -.43880500E+02, -.21145900E+02, -.73207100E+02, 0.19138900E+02, -.34004200E+01, -.19635700E+00, 0.37976400E+00, -.12591300E+01, 0.52839300E-02, 0.15136700E+01, -.16654300E+01, 0.77509100E+01, 0.49481600E-01, 0.14906400E+01, 0.72071000E+01, -.83664200E+01, 0.70589100E+01, -.19503600E+01, -.34979100E+01, -.91219400E+01, 0.88080400E+01, -.96951900E+00, -.41678300E-02, -.17549000E+01, -.88449500E+01, 0.19114800E+01, -.88490500E+01, 0.82368600E+01, 0.88330900E+01, -.56048400E+01, 0.85737100E+01 },
        { 0.42445700E+01, -.10861000E+00, -.16644900E+00, -.20596400E+00, 0.76070800E+00, -.15816100E+01, 0.12821100E+01, -.15772100E+01, 0.13352800E+01, -.94681000E+00, -.19235400E-01, 0.14169600E+01, 0.26782600E+00, 0.46569100E-01, 0.54109300E+00, -.30273400E+00, 0.40202400E+00, 0.59063100E+00, 0.89674700E+00, -.87960000E+00, -.12683000E+01, 0.27620900E+00, 0.86970400E+01, 0.55972800E+00, 0.41341500E+00, -.17803200E+00, 0.11160400E+00, -.17438400E+00, -.12060000E+01, -.14146300E+00, -.77363700E+00, -.17661500E+01, 0.95469700E-01, -.79289500E+00, 0.26090700E+01, 0.46693000E+00, 0.91741800E-01, 0.23423800E+01, 0.32478000E-01, 0.39308000E+00, -.67477200E+00, -.35003300E+00, -.52771000E+00, 0.63822300E+00, 0.49515200E-04, 0.26379500E+00, 0.19884400E+00, -.25415600E-01, 0.52817200E+00, -.13892300E+00, 0.86322200E+00, 0.31509300E+00, -.25779500E+00, -.70156800E-01, 0.10752900E+01, -.33805500E-01, -.11028200E+00, 0.10765700E+00, -.52626900E+00, 0.20164900E+00, 0.29894000E+00, -.33536500E+00, 0.69236500E+00, -.35861300E+00, -.54628000E+00, 0.17828200E+00, -.10344300E+01, -.26645000E-01, -.64821900E+00, -.21213100E-02, -.98081300E-01, 0.58144400E+00, 0.23233300E+00, -.23944500E+00, -.52425000E-01, 0.47990300E+00, 0.76959400E+00, 0.28200300E+01, 0.29145300E+00, 0.42960300E+00, -.37941700E-01, 0.13113600E+01, -.19159400E+01, -.11911600E+00, -.43711700E+00, -.83056100E+01, -.16032500E-01, 0.45979200E-01, -.11775100E+00, 0.88815500E-01, 0.90563900E+00, -.78918500E-01, -.13366400E+01, 0.24635300E+00, -.14514500E+00, 0.48300300E+00, -.15653200E+00, 0.42804200E+00, -.32438100E+00, 0.22135300E+00, 0.72706400E-01, 0.55277800E+00, -.42990900E+00, 0.19216900E-01, 0.64775600E-01, 0.11158400E+00, -.25761300E-01, 0.18398300E+00, 0.28495700E+00, -.65499100E-01, 0.16715300E+01, -.94703300E-01, 0.50849500E-01, -.16238200E-01, -.39586200E+00, -.28129000E+00, 0.12036900E+00, -.60831300E+01, -.50927000E-01, 0.11265000E+00, -.19528300E+00, -.17537200E+00, 0.25735500E-01, -.10091500E+00, 0.40117700E-02, -.12333600E+00, 0.18426500E+00, -.32440300E+00, -.18506600E+00, -.40467600E+00, 0.19972600E+01, 0.63094800E+00, -.14903100E+00, -.10141100E-01, 0.12242500E+01, 0.11264000E+00, -.24920100E-01, -.80413000E-01, 0.38465900E+00, -.81143500E-01, -.94781600E-01, 0.21396500E+00, 0.13395200E-01, 0.11525400E+00, 0.12264000E-01, -.52451800E-01, -.15199200E-01, 0.11886900E+01, 0.62237600E-01, -.15958600E+00, -.32260800E-01, 0.26135700E+00, -.59996600E-01, 0.15120500E+00, 0.51768200E-01, -.28065100E-01, -.89127000E-01, 0.25776100E-01, -.74688000E+00, -.34515600E-01, 0.50443300E+00, -.23420700E+00, -.54994800E-01, 0.12843300E+00, 0.12012500E-01, -.47928800E-01, 0.25795100E-01, 0.28653900E+00, 0.38343100E-01, 0.21487400E-01, 0.53171100E-01, -.14414300E+01, -.13276500E+00, 0.73469600E+00, -.31784600E+00, -.15291900E+00, -.14745000E-01, 0.16354300E-01, 0.51828100E-01, -.13754300E+00, 0.91209300E-01, 0.23786700E+01, -.33733200E-01, -.54045000E-01, 0.46982200E-01, -.94566400E+00, -.13736700E+00, 0.21914500E+00, 0.91358500E-02, -.33486100E-01, 0.14779800E-02, -.30538600E-01, -.59068100E+00, -.58591700E+00, -.22975000E+00, 0.44908100E-01, -.28720900E+00, -.27453700E+00, 0.18845500E+00, -.21509300E-01, -.47760100E+00, 0.19434200E-01, 0.18248000E+00, 0.37283400E+00, -.47221700E-01, 0.41201800E-01, 0.39715500E-01, -.31925100E+00, -.13945700E+00, 0.20274000E-01, 0.19370900E-02, 0.10528900E+00, 0.42264000E-01, 0.44051800E-01, -.67392700E-01, 0.12181600E+00, 0.77060300E+00, -.27618400E+00, -.25502200E+00, -.42406800E-01, -.38913900E-01, -.33136300E-01, 0.45684800E+00, 0.16267200E-01, 0.12247300E+00, -.18108500E+00, -.95129600E-01, -.32155600E-01, -.69038400E-01, 0.14963100E-01, 0.15713300E+00, -.75215800E-01, -.20197200E-01, 0.19805200E-01, -.89333100E-02, -.41592200E-01, -.10076500E+01, 0.42744800E-02, -.11248100E+00, 0.13179200E+00, -.13901300E+00, -.20995300E-01, -.55111200E+00, 0.70799900E-01, 0.24404500E+00, 0.24495000E-01, 0.93756300E-01, 0.20657000E-01, 0.48714400E-01, -.16022200E+00, 0.92341700E-01, 0.16180200E+00, 0.66704000E+00, -.60926600E-01, 0.20192400E-02, 0.16134400E+00, 0.51918800E-01, -.18457500E-01, 0.54953000E+00, 0.12063400E+00, 0.99527400E-01, -.47761600E+00, 0.33972300E+01, -.27435400E+02, 0.12643000E+02, -.58812900E+01, -.59787700E+01, -.67448300E+01, -.10148900E+01, 0.24189300E+01, -.60407900E+01, 0.18248000E+01, 0.16759400E+01, 0.15795900E+01, 0.11038000E+02, 0.25800000E-02, -.20468200E+00, 0.74156900E-01, -.63140100E-01, 0.12107500E+00, -.71680500E-01, 0.13063200E+01, 0.93541400E-01, -.18728500E-01, 0.23160600E+00, -.67642500E-01, 0.11169900E+01, -.17564500E+00, -.51304200E+00, -.12512800E+01, 0.31545300E+00, -.86410300E-02, 0.19810200E+00, 0.68888600E-01, -.24175200E+00, 0.44255800E-02, -.12361200E+01, 0.14825800E+01, -.78932500E-01, -.82224300E+00, -.41462700E+00 },
        { -.25436700E+02, 0.69410000E+00, 0.88567200E+00, 0.12197500E+01, -.36134000E+01, 0.79377600E+01, -.26056500E+01, 0.56176300E+01, -.10056700E+02, 0.58360500E+01, -.11923100E-01, -.47626800E+01, -.90870700E+00, -.11935200E+00, -.20897000E+01, 0.89623800E+00, -.12709100E+01, -.17998100E+01, -.30382600E+01, 0.30261200E+01, 0.39655000E+01, -.73496300E+00, -.27187800E+02, -.19825600E+01, -.98640800E+00, 0.10679200E+01, -.29744200E+00, 0.32813400E+01, 0.44493500E+01, 0.21418800E+01, 0.24039700E+01, 0.22746300E+01, -.24795600E+00, 0.32572800E+01, -.12241500E+02, -.13613200E+01, -.35191200E+00, -.51179800E+01, 0.51642200E+00, -.38457200E+01, 0.19037400E+01, 0.45760900E+01, -.40248800E+00, -.32799400E+01, 0.21329600E+01, -.41181400E+00, -.73194800E+00, 0.60810800E-01, -.16430100E+01, 0.19559000E+00, -.12278300E+01, 0.16778000E+01, 0.64494200E+00, 0.52028100E+00, -.69874000E+01, -.39272100E+00, 0.13005300E+00, 0.14764200E+01, 0.92964700E+00, -.56228200E+00, -.16495000E+01, -.10421600E-01, 0.30225800E+00, -.28124700E-01, -.34504300E-01, 0.13095900E-01, -.15335300E+01, 0.70336600E-01, -.31943800E+01, 0.22428300E-01, 0.32164200E+00, -.15326500E+01, -.11731900E+01, 0.62759600E+00, 0.46871700E+00, -.34101900E+00, -.14413200E+01, 0.60644400E+01, -.33202600E+01, -.11781300E+01, 0.14681500E+00, -.16393800E+01, 0.58094200E+01, -.13779800E+01, 0.14149400E+01, 0.23771100E+02, 0.12997600E+00, 0.42136200E+00, -.64987300E-01, 0.23363700E+01, -.25247500E+01, 0.29603000E+00, 0.15555500E+01, -.54377300E+00, 0.62772900E+00, -.22806500E+01, -.10871200E+01, -.85582100E+00, 0.36319400E+00, -.96519400E+00, -.12066200E+00, 0.53106100E+00, 0.88684200E+00, 0.32589200E+00, -.51442900E+00, -.26857900E+00, -.17520700E+00, 0.37551900E+00, -.73841400E+00, 0.10614900E-01, -.40420700E+01, 0.10016200E+00, -.79674300E+00, 0.14833400E-01, 0.19929200E+00, 0.19174900E+00, -.11447100E+00, 0.49202800E+01, 0.11852600E+00, -.24323600E+01, -.20906700E-01, 0.52750200E+00, -.28228300E-01, -.44540100E+00, -.20985400E-01, 0.20705700E+00, -.52934200E+00, 0.21900200E+01, 0.71876200E+00, -.12052900E+01, -.50735400E+01, -.20113500E+01, -.93467700E-02, 0.13361900E+00, -.24607700E+01, -.23890500E+01, 0.11644500E+00, 0.74361700E+00, 0.85589100E+00, -.37720900E+00, 0.15524900E+01, -.39569900E+00, 0.17424900E+00, 0.99922500E+00, 0.37195400E-01, -.12290800E+00, 0.88152300E-01, -.38328100E+01, 0.25177200E+00, -.14431800E+01, 0.43520000E+00, -.69384200E+00, -.23610500E+01, -.11487800E+00, -.42252000E+00, -.48227800E+00, -.32015100E+00, 0.62289700E-01, -.18967400E+01, 0.20486300E+00, -.89981500E+00, -.50905000E+00, -.10963200E+00, 0.66432000E+00, -.34405800E+00, -.63269800E+00, 0.59331300E+00, 0.44576200E+00, -.26874100E+00, -.66028800E+00, 0.85201200E+00, 0.11090700E+01, -.55825500E+00, 0.12324800E+01, -.12904100E+01, -.95731300E-01, 0.22572100E+00, 0.85823100E-01, 0.88181500E+00, 0.16115500E+01, 0.91930400E+00, -.53160500E+01, 0.79967900E+00, -.81500200E+00, -.36552000E+00, -.10696400E+01, -.74051900E-01, -.72739900E+00, -.33983800E-01, 0.82038500E-01, 0.72644200E-02, 0.24200900E+00, 0.76208300E-01, 0.17884400E+01, 0.10287600E+01, 0.25760800E+00, 0.42653700E+01, -.49228200E+00, -.92652400E-01, 0.14861800E-01, 0.18731200E+00, 0.13863300E-01, -.69313000E+00, 0.59655500E+00, 0.57593700E-01, -.71070200E-01, -.16065500E+00, -.16487000E+00, -.51277300E+00, 0.75934900E-01, 0.11840600E+00, -.14930600E+00, 0.35408800E-01, -.64948400E+00, 0.25081800E-01, -.40567500E+00, -.22796200E+01, -.12868700E+00, 0.91950900E-02, -.19413600E-01, 0.13205100E+00, 0.62649500E-02, -.24420400E+01, -.10701000E+00, 0.69876800E-01, 0.71883700E+00, -.51370300E+00, -.29188700E+00, 0.12486400E+01, 0.63347800E+00, 0.20522200E+01, -.28567800E+00, -.16705700E-02, -.45698300E+00, -.48621600E-01, -.45981600E+00, 0.23298800E+01, 0.17315700E+00, 0.19409000E-01, -.61257900E+00, -.13372800E+00, -.64193400E+00, 0.54992300E+00, -.73762300E-02, -.11141600E+01, -.32338300E-01, 0.68996600E-01, 0.26091700E+00, 0.10578200E+00, 0.11266300E+00, 0.22790800E+00, 0.16823600E+00, 0.31130000E-01, -.15024000E+00, -.13237200E-01, 0.68667600E-01, 0.26488800E+00, 0.22691900E+00, 0.20643700E+01, 0.38888700E+00, -.27334900E+00, 0.19181400E+01, 0.16967200E+01, 0.86299200E+03, -.26434100E+03, 0.12181400E+03, 0.76166400E+02, 0.13421300E+03, -.46732400E+02, -.19029000E+03, 0.27808600E+03, 0.14231500E+03, 0.33749200E+03, -.17096100E+03, -.30523800E+03, -.19788000E+01, -.15055800E+01, 0.47760300E+01, 0.13497600E+01, -.52831200E+01, 0.73999300E+01, -.40150600E+02, 0.94148400E-01, -.54834300E+01, 0.12300700E+02, -.91930900E+01, -.24840300E+02, 0.57162300E+01, 0.16275700E+02, 0.48237000E+02, 0.73724200E+01, 0.68047800E+01, -.43972200E+01, 0.73249900E+01, 0.23846000E+02, -.80557300E+01, 0.45396600E+02, -.42158300E+02, 0.16981300E+02, 0.10297000E+02, -.29953500E+00 },
        { -.55011600E+00, 0.24962000E-01, 0.20705100E-01, 0.26299700E+00, -.10964400E+00, 0.18923100E+00, -.13230000E+00, 0.16410700E+00, -.13293600E+00, 0.12395600E+00, 0.32598300E-02, -.89674300E-01, -.10447600E-01, -.66581100E-02, -.11653100E-01, 0.24510300E-01, -.52815600E-02, -.59750100E-01, -.71553800E-01, 0.73565800E-01, 0.66549200E-01, -.68480400E-02, -.99795500E+00, -.46978200E-02, -.89206900E-02, 0.12472600E-02, 0.32468700E-02, 0.67224700E-01, 0.14095100E+00, -.63663300E-01, 0.50719200E-01, 0.13404800E+00, -.74615800E-02, 0.51538000E-01, -.16993400E+00, -.32007900E-01, -.52889000E-02, -.26792000E+00, 0.23930200E-01, -.54275500E-01, 0.37821900E-01, 0.94518100E-02, -.48489100E-02, -.64583300E-01, 0.34423600E-03, -.12468000E-01, -.10483100E-01, 0.14037700E-02, -.11677400E-01, 0.86832800E-02, -.84388600E-01, -.14347000E+00, -.25989200E-02, -.34834700E-03, -.96284700E-01, -.18901900E-01, 0.42030500E-03, -.49815600E-03, 0.40441300E-01, -.12932400E-01, -.33710800E-02, -.14285500E-01, -.35891700E-01, 0.15995800E-01, 0.33480900E-01, -.23781100E-02, 0.63717600E-01, 0.76632200E-03, 0.79053700E-01, 0.28973000E-03, 0.34267600E-02, -.48661500E-02, -.10416300E-02, 0.91833100E-02, 0.33673000E-03, -.40346600E-02, -.20310100E-01, 0.48832100E-02, -.64134300E-02, -.14392200E-01, 0.27478000E-02, -.26609500E-01, 0.82343700E-01, 0.54214200E-02, 0.25853000E-01, 0.59414700E+00, 0.64762400E-03, 0.69856400E-02, -.27908000E-04, 0.22312200E-01, -.19839500E-01, 0.52318000E-02, 0.25968400E-01, -.92603200E-02, 0.15382500E-01, -.70912700E-01, 0.13939800E-01, -.96273600E-02, -.19505800E-01, 0.15622100E-01, 0.12408900E-02, -.43326200E-01, 0.11627100E-01, -.31527800E-02, 0.31252000E-02, -.16056300E-01, 0.64205300E-02, 0.18371100E+00, 0.28530400E-02, -.22260400E-02, -.66317900E-01, 0.11803400E-02, -.48377100E-02, 0.56039200E-03, 0.46267200E-01, -.32114000E-02, 0.89901400E-02, 0.68440300E-01, 0.16005300E-01, 0.39935600E-01, -.11327500E-01, 0.70961200E-02, 0.28019300E-02, 0.68349100E-01, 0.45402200E-04, -.41356100E-01, 0.52384600E-02, 0.12161500E-01, 0.24758800E-01, 0.12844500E+00, 0.11445100E+00, 0.77959900E-02, -.37286000E-01, 0.46071100E-03, 0.25999700E-01, -.17540700E-01, -.50310400E-02, -.39308300E-02, -.45129300E-01, 0.14907700E-01, 0.34917500E-01, -.43124100E-02, -.30262100E-03, 0.23076400E-01, 0.13816300E-02, 0.55009100E-03, 0.19992000E-02, 0.65843900E-01, 0.84530900E-02, -.46739900E-01, -.69452400E-02, -.34894500E-02, 0.30018500E-01, 0.10270800E-01, 0.18180500E-01, 0.60719400E-02, 0.79609600E-03, -.29869000E-02, -.15213500E-01, -.12832900E-01, 0.26867300E-01, -.11191100E-02, -.44803900E-02, -.17049900E-01, -.55090100E-02, 0.16794500E-01, -.17746300E-02, -.29903000E-01, 0.53542400E-02, 0.16515400E-01, -.22759000E-01, -.55762700E-01, 0.17385400E-01, 0.52081000E-01, -.69361400E-02, -.51691300E-02, -.43847700E-02, 0.15465500E-02, -.72634600E-02, -.16066700E-01, 0.23200600E-01, 0.95427400E-02, -.66092200E-02, -.32713800E-01, 0.12880700E-01, -.50499500E-01, -.68393100E-02, 0.37928500E-01, -.14339800E-02, -.12507600E-01, 0.30374300E-03, -.51296400E-02, 0.40992600E-01, -.29092600E-01, 0.36360500E-01, -.13508700E-02, 0.87466500E-01, -.32489100E-01, -.31430500E-01, -.28127500E-03, -.34343700E-02, -.13222500E-02, 0.20812300E-01, -.22001300E-04, 0.84541200E-02, -.11726000E-01, -.42507800E-03, 0.32734700E-01, 0.27328200E-01, 0.67941500E-02, -.14639300E-02, 0.87066700E-02, -.90798400E-02, -.40589200E-01, 0.81200400E-02, 0.85015700E-02, 0.40881200E-01, -.11808700E-01, -.98615800E-02, -.53876700E-02, -.13563500E-01, 0.22360800E-02, -.68490400E-01, -.38498000E-02, 0.46785000E-01, 0.21755700E-01, -.91563600E-01, 0.74735300E-02, 0.16520400E-01, 0.83934300E-02, 0.90727900E-01, -.19454500E-01, -.25101100E-02, -.55598700E-01, -.10926000E-02, -.43738500E-01, -.78226200E-02, 0.40365800E-02, 0.20867400E-01, -.32579000E-01, 0.58052900E-02, 0.11115300E-01, -.21381100E-01, -.42637900E-02, 0.36684800E-01, -.16558600E-02, -.71552400E-02, -.35013200E-01, -.46563700E-02, -.12553300E-02, -.83739500E-02, 0.73907100E-01, 0.42896100E-01, -.58011600E-02, -.16092400E-02, 0.29712000E-01, 0.61188000E-02, -.19889900E-01, -.65724600E-02, 0.25327000E-01, 0.15008900E-02, -.20441300E-02, -.39046900E-01, -.71789500E-02, -.64365800E+01, 0.30406900E+01, -.81393400E+00, 0.32676900E+01, -.15834100E+00, -.13971600E+01, 0.15079900E+01, 0.37529100E+00, 0.62638600E+01, -.13961900E+01, 0.90748600E+01, 0.44522300E-01, -.32371700E-01, 0.27103600E-01, 0.12678900E-02, -.42322700E-01, 0.23603100E-01, -.24930700E+00, 0.97780600E-01, -.15670000E-01, -.12523100E+01, 0.15406100E+01, -.67487300E-01, -.48385700E-01, 0.55538100E-01, 0.22871900E+00, -.14223300E+01, -.29071900E-01, -.54775000E-01, 0.91864600E-01, 0.61390400E+00, -.91333900E-01, 0.27002700E+00, -.21913100E+00, -.15852700E+01, -.66426000E-01, -.16375200E+01 },
        { -.13023600E+02, 0.60330200E+00, 0.25758300E+00, -.45136200E+00, -.11326000E+01, 0.23035700E+01, -.16857700E+01, 0.12641600E+01, -.20371400E+00, 0.15621500E+01, -.14938100E+00, -.30328000E+01, 0.10258400E+01, 0.69552200E-01, 0.86712300E+00, 0.64017000E+00, -.81598700E+00, 0.14365100E+00, -.66718000E+00, 0.68882800E+00, 0.28549200E+00, -.42928600E+00, 0.62360200E+01, 0.87157200E+00, -.10765300E+00, 0.12088400E+00, 0.11463200E+00, 0.94529400E+00, 0.12153800E+01, 0.67480100E+00, 0.46874500E+00, 0.17424200E+01, -.40406200E-02, 0.73043000E+00, 0.11228800E+01, -.37043900E+00, 0.60807900E-02, -.95261000E-01, -.34404400E-01, -.27748200E+00, 0.73040800E+00, -.22235900E+00, 0.91399000E+00, -.69872000E+00, 0.80041100E+00, -.59929800E+00, -.26820100E+00, 0.59725600E-02, -.63593600E+00, 0.67046500E-03, 0.26263600E+00, 0.53993100E+01, -.85665400E-01, 0.29873200E-01, 0.89328200E+00, 0.27024200E+00, 0.49746700E+00, 0.53658000E+00, 0.42214800E+00, -.55328400E-01, -.15877400E+00, -.28196500E+00, 0.50226800E+00, 0.17079000E-01, 0.51102300E+00, 0.33055100E+00, 0.93628600E+00, -.42128200E-01, 0.20701800E+00, 0.45444900E-02, -.19582400E+00, 0.53521000E+00, 0.19943000E+00, -.84113200E-01, 0.89061500E-01, -.10431800E+01, 0.54260900E-01, -.62135300E+01, 0.95289000E+00, -.77828500E+00, -.29684300E-01, 0.73785800E+00, 0.64463000E+00, 0.13619000E+00, 0.45053500E+00, 0.22308700E+01, -.35729500E+00, -.10317300E+00, -.10929500E+01, -.10100100E+01, 0.12915400E+00, -.36431600E-01, -.29469000E+01, -.27338000E+00, 0.18658100E+00, 0.35078100E+00, -.54584900E+00, -.43990700E-01, -.35053500E+00, -.61548000E+00, -.39942500E+00, 0.74318300E+00, -.25525400E+00, -.27705500E+00, 0.17318600E-01, 0.42015700E+00, 0.65608200E-01, -.17119500E+01, 0.30997900E+00, -.18498600E+00, -.26289000E-02, -.80552600E-01, 0.33583600E+00, 0.79420500E-02, -.69278400E-01, 0.37056600E+00, -.90695500E-02, -.10365100E+01, 0.15781200E-01, -.41350400E+00, -.76402200E-01, 0.10731000E-01, -.20287400E-01, 0.10556500E+00, 0.21061800E-01, 0.86009000E+00, 0.15577900E+00, 0.20023500E+00, -.61026300E-01, 0.18763100E+01, -.73181700E+00, 0.17915400E+00, 0.19316600E+00, -.44819900E-01, 0.11212300E+01, -.20499400E+00, -.42876300E-01, -.90828000E-01, -.60583200E+00, 0.36106900E+00, 0.82796100E-02, -.11491000E+00, 0.63809400E-01, -.24288000E+00, 0.11852600E-01, -.73952100E-01, -.29767300E-01, 0.53801300E-01, 0.68420500E-01, 0.12615000E+01, -.19668500E-01, 0.80409300E-01, -.56757200E-01, -.11981400E+00, -.11101100E+00, -.42112300E-01, 0.94507700E-01, 0.51011900E-02, 0.13821300E+01, -.10313100E+00, -.68441500E+00, 0.18539700E+00, -.21923400E-02, 0.18738800E+00, -.54982200E-01, 0.23363800E+00, 0.84873500E-01, 0.76304200E-01, -.11983500E+00, -.73286700E-01, 0.17910100E+00, 0.30001200E+00, -.19109500E+00, -.66807100E+00, -.78811800E-01, 0.51263300E-01, 0.34177100E-01, 0.80938900E-01, -.11106300E+00, -.86957400E+00, -.12648800E+00, 0.27663900E+01, -.13433100E+00, 0.48116500E+00, -.16088900E-02, 0.75009600E+00, 0.49116000E+00, 0.33044000E+00, -.37754500E-02, 0.14687400E+00, -.60230900E-03, 0.52255100E-01, 0.76474300E+00, -.16339700E+00, 0.51319100E+00, -.20480200E-01, -.82536900E+00, 0.14823500E+00, -.10751600E+00, 0.47359600E-01, -.42061100E+00, 0.21773700E-01, -.25133700E+00, 0.79018300E-01, -.49955000E-01, 0.28854200E+00, -.16326000E+00, 0.34410700E+00, -.41802500E+00, 0.12152200E-01, -.18474900E-01, 0.11664000E+00, 0.11154200E+00, -.10326400E-01, -.16293500E+00, 0.10234000E+00, 0.24274600E+00, 0.19501000E-01, -.53637900E-01, 0.14587800E-01, -.24908600E-02, -.72283300E-01, 0.92372400E+00, 0.14154000E-01, -.31503400E+00, -.89043200E+00, 0.45682200E+00, -.26558800E+00, -.26902100E+00, 0.99806500E-02, -.22531300E+00, -.24652900E+00, -.24445400E-01, 0.30863500E+00, 0.40200200E-01, 0.10861800E+00, -.36450900E+00, 0.65525500E-01, 0.57916300E+00, 0.41149400E+00, -.14478100E-01, -.67828600E-01, -.48349700E+00, 0.14352900E+00, 0.63069400E-01, -.39084800E-01, 0.32030900E-01, -.17195600E+00, -.13319100E+00, 0.72180600E-01, -.30297400E-01, 0.40429700E-01, 0.56265000E-02, 0.22177400E-01, 0.70908500E-01, -.36790700E-01, 0.10022800E+00, 0.51336400E-01, 0.29000700E+00, -.27002300E+00, -.71298100E-01, 0.23888600E+00, 0.28541000E+00, 0.79651300E-01, 0.54803500E+00, 0.44039600E+02, 0.63276000E+01, -.26115500E+01, 0.79788300E+00, -.22710500E+01, 0.25397100E+01, -.55026700E+01, -.10885900E+02, -.15574100E+01, -.44112600E+02, -.19714200E+00, 0.23603800E+00, -.92557200E-01, 0.75399800E-01, 0.19174400E+00, -.24845700E-01, 0.32529200E-01, 0.34209200E-01, 0.16199900E+00, 0.29775800E+01, -.32334300E+01, 0.44863000E+00, -.21541700E-01, 0.19900200E+00, 0.25946400E+00, 0.29098300E+01, 0.24658300E+00, 0.76465600E-01, -.34260700E+00, -.48330800E+00, 0.31348200E+00, -.69276500E-01, -.88783700E-01, 0.46330600E+01, 0.12549000E+00, 0.41153200E+01 },
        { 0.19225400E+02, -.48329200E+00, -.11273500E+01, 0.12391000E+01, 0.12056000E+01, -.31541600E+01, 0.31088300E+01, -.19855000E+01, -.12794500E+01, -.15741500E+01, 0.36389300E+00, 0.87004100E+00, -.68092900E+00, 0.75577700E+00, -.19820000E+01, -.65381000E+00, -.77155400E-01, -.10564800E+01, -.37935600E+00, 0.19179600E+00, 0.10556200E+01, 0.11366700E+00, -.13914400E+02, -.13556000E+01, -.74360500E+00, 0.82096700E-01, -.49044600E+00, 0.24367700E+00, 0.12466700E+01, 0.15682300E+01, 0.16810800E+01, 0.17340500E+01, -.12967300E+00, 0.29269500E+00, 0.75519100E+01, -.94411900E+00, 0.50766800E+00, -.44892800E+00, -.93121400E-01, -.16533000E+01, 0.11158700E+01, 0.57807400E+01, 0.22410200E+00, -.19741000E+01, 0.18690500E+01, -.69520600E+00, -.11337000E+01, -.82643700E-01, -.27708200E+00, -.29137600E+00, 0.35323200E+01, -.46106000E+01, 0.49054300E+00, -.10042300E+01, -.99585400E+01, 0.27179200E+01, -.94006500E-01, 0.38822000E+01, -.70994200E+00, 0.10583500E+00, 0.55826700E+00, -.41387600E+00, 0.71631300E+00, -.72076400E+00, -.10449000E+01, 0.81290900E+00, -.54967600E+01, 0.30307200E-01, -.87445500E+01, 0.14806200E-01, -.96559500E-01, 0.44348100E-01, -.97082600E+00, -.76208000E+00, 0.30052300E+01, 0.44928100E+01, 0.38475300E-01, 0.16952500E+02, -.24248000E+01, -.36407400E+01, -.11749300E+00, 0.11688000E+01, 0.27263300E+01, -.41099100E+01, -.43163500E+01, -.17367800E+02, -.11374000E+01, 0.14209100E+00, 0.16421000E+01, -.17583900E+00, 0.10009000E+01, 0.80873000E-01, -.57407100E+01, 0.72541300E+00, 0.76902400E+00, -.29786300E+01, -.16727200E+01, -.17413200E+01, -.58431800E+01, 0.51261400E+00, 0.46765800E+00, 0.28185500E+01, -.41072200E-01, -.22440500E+01, -.82254400E+00, 0.38684900E+00, -.15493100E+00, 0.60339300E+01, -.17880600E+01, 0.19689400E-01, 0.29171100E+01, -.12877300E+00, -.29904200E+00, 0.60331400E-02, -.24905300E+00, -.60195500E+00, 0.15533600E+00, -.73913400E+01, 0.50414600E+00, 0.44150600E+01, -.29692400E+00, -.77778200E-01, 0.40972400E-03, 0.41699700E+00, 0.60446600E-01, 0.41988500E+00, 0.37714800E+00, 0.39356700E+00, 0.42055400E-01, -.11359600E+01, 0.74994400E+01, 0.10577700E+01, -.54434100E+00, 0.13112600E+00, 0.58448500E+01, 0.45325100E+00, -.26723900E+00, -.45284900E+00, -.48500900E+00, 0.39544500E+00, 0.10373900E+01, -.71435100E+00, -.81445600E-01, 0.62927400E+00, 0.47763400E-01, 0.15992600E+00, -.10338300E+00, 0.39875200E+01, 0.87759600E-01, 0.20503000E+01, -.14444300E+00, -.83531400E-01, 0.15274000E+01, -.15852500E+00, -.16558000E+00, 0.56295800E+00, -.60820300E+00, 0.77587400E-01, 0.93822000E+00, -.29697900E-01, 0.30946000E+00, -.12094400E+00, 0.26726600E+00, -.46795500E+00, 0.37275000E+00, 0.45122600E+00, -.23222700E+00, 0.39969000E+00, 0.92513100E-02, 0.56357100E-01, 0.48633400E+00, 0.56495500E+00, -.18608400E+00, 0.51952600E-01, -.12159100E+00, 0.16332900E+00, 0.13371800E-01, -.11949600E-02, 0.34053600E+00, -.86919400E+00, -.49478700E+00, 0.31544900E+01, 0.57744200E-01, 0.52448400E-01, -.23205500E+00, 0.10103300E+01, -.16235300E+00, -.12991100E-01, 0.39365100E-01, -.14953700E+00, -.79182400E-02, 0.31392100E+00, 0.22594800E+01, -.46626600E-01, 0.35923900E+00, 0.16727700E+00, 0.12023200E+01, -.75922000E+00, -.42380200E+00, -.35356600E-01, -.48112900E+00, 0.20476900E-01, 0.26431800E+00, 0.24702800E+00, 0.28967100E-01, -.22015800E+00, -.10492400E+00, 0.16506500E+01, 0.21721100E-02, 0.25353400E+00, 0.11217000E-01, 0.63093100E+00, 0.21595300E+00, 0.36601200E+00, -.28374200E+00, 0.54900700E+00, 0.11904300E+01, 0.49617800E+00, -.41148800E-01, 0.58520400E-01, -.20252500E-01, -.19785400E-01, 0.25486700E+00, -.90262100E-01, 0.69990000E+00, -.67131700E+00, 0.16130000E+00, -.31130100E+00, -.63155200E+00, 0.11028900E+00, -.22108800E-01, -.37162400E+00, -.75094900E-01, -.83585300E+00, 0.12862900E-01, 0.18836300E+00, -.15055000E+01, 0.34295200E+00, 0.13531600E+01, 0.65860500E+00, 0.15155700E+00, -.21751600E-01, -.90363700E+00, -.97714600E-01, 0.83662000E+00, -.47438000E-01, 0.51746600E-01, 0.11699900E+01, -.27929400E-03, 0.35331700E+00, -.40289000E+00, -.86305600E+00, -.76561800E-02, -.32428700E-01, 0.56001800E-01, 0.15960800E+00, 0.16030800E+00, -.19779200E+00, 0.73726200E+00, 0.32209100E+00, -.36806900E+00, -.31066600E-01, 0.15668200E+01, 0.26417700E+00, -.52424000E+01, -.67693300E-01, 0.14171500E+03, -.55256200E+01, -.24496700E+02, -.61865600E+02, 0.60122700E+02, 0.17248400E+02, 0.54682600E+02, -.60401300E+02, -.12224700E+03, 0.36063100E+00, -.64583900E-02, -.73386900E+00, 0.76817200E+00, 0.83739700E+00, 0.10598700E+00, -.91725300E+01, 0.11763500E+01, 0.10057200E+01, 0.44757900E+00, 0.20338000E+01, -.62006000E+01, -.47501300E-01, 0.23916000E+01, 0.10582100E+02, -.86665800E+00, 0.14473300E+01, 0.89714600E-01, 0.97195800E-01, -.32731500E+01, -.29700000E+00, 0.99467300E+01, -.91225100E+01, 0.25331300E+01, -.17808100E+01, -.64581300E+01 },
        { -.72758700E+01, 0.19802000E+00, 0.27978400E+00, 0.44230100E+00, -.11060100E+01, 0.23909700E+01, -.10394900E+01, 0.10871500E+01, -.83372200E+00, 0.18832900E+01, 0.26540500E-02, -.78646200E+00, -.24297000E+00, -.88984900E-01, -.22907700E+00, 0.29469000E+00, 0.12085300E+00, 0.20060700E+00, 0.95793100E-01, 0.13397500E+01, 0.15598700E+01, -.24762100E+00, -.63949600E+01, -.82159400E+00, -.22448100E+00, -.42922000E-02, -.14130500E+00, -.13713100E+00, 0.16068500E+01, 0.71676300E+00, 0.67751600E+00, 0.31727100E+01, -.13984400E+00, 0.81721300E+00, -.28491400E+01, -.75251500E+00, -.15696500E+00, -.38093100E+01, 0.29593600E-01, -.42150600E+00, 0.81142000E+00, 0.10595500E+01, 0.57561000E+00, -.10733000E+01, 0.17823100E+00, -.36674800E+00, 0.63400800E-01, 0.35051200E-01, -.74509500E+00, 0.26860200E+00, -.18118200E+01, 0.12939700E+01, 0.19964300E+00, -.51651000E+00, -.22767000E+01, 0.43622000E+00, 0.13219600E+00, 0.23758900E+00, 0.91871600E+00, -.75793700E-01, -.89995900E+00, -.15025600E+00, -.10944300E+01, 0.39861600E+00, 0.13498100E+01, -.28222300E+00, 0.16802800E+01, -.29564100E-02, 0.22008000E+01, -.40554000E-02, 0.35494600E-03, -.26909400E+00, 0.30088000E-01, 0.21468200E+00, 0.22351500E+00, -.73421700E+00, 0.10277700E-01, -.44444600E+01, 0.70479500E+00, 0.26301100E+00, 0.48239100E-01, -.17650200E+01, -.76086200E+00, 0.72752600E+00, 0.64501600E+00, 0.85339400E+01, 0.22482900E+00, -.86157600E-01, -.10263000E+00, -.12988100E+00, -.16029500E+00, 0.34690800E-01, 0.16311000E+01, -.39026200E+00, -.45974100E-01, -.28990900E+00, -.31932700E-01, -.39502800E+00, 0.17516800E+01, -.31659900E+00, -.23446900E-01, -.10430300E+01, 0.57318600E+00, 0.52485000E-01, 0.25521600E-01, -.30514100E+00, -.10186800E+00, -.83066700E+00, 0.29314400E+00, -.13146000E+00, 0.12471500E+01, -.68561900E-01, 0.12622100E+00, -.15914200E-01, -.19383800E+00, -.51296000E+00, 0.15183300E+00, -.47703900E+01, 0.24832900E+00, 0.55609500E+00, -.20046100E+00, 0.56703100E-01, 0.18713000E-01, 0.22642800E+00, -.43897600E-02, -.72967900E+00, -.86618300E-01, 0.33032300E+00, 0.62608500E-04, -.59336900E+00, 0.51296700E+01, -.20996600E+00, -.58269600E+00, 0.69927900E-01, 0.31429200E+01, -.16060800E+00, -.12670000E+00, -.10793400E+00, 0.18072400E+01, -.73876800E+00, -.12105500E+00, -.49071400E+00, -.46057100E-01, -.16433200E+00, 0.44799800E-01, -.43763300E-01, -.51003900E-01, -.58699800E+00, 0.29239300E+00, 0.30836600E+00, -.19324800E+00, 0.43162300E+00, 0.12906600E+01, 0.69788700E-01, 0.20131600E+00, -.47020000E-01, -.25070100E-01, -.31490500E-01, -.22936600E+01, 0.15713100E+00, 0.11641100E+01, -.32559500E+00, 0.20755400E+00, -.15464000E+00, 0.17904800E+00, -.11403100E+00, 0.33670800E-02, 0.47241700E+00, -.19438400E+00, -.14840500E+00, 0.28094000E+00, -.29924500E+01, -.41521600E+00, 0.12298300E+01, 0.59250100E+00, -.29581500E+00, 0.59972400E-01, 0.11754200E+00, -.23947400E+00, 0.12098700E+01, 0.78452400E+00, -.37750600E+01, 0.33570400E-01, -.30438900E+00, 0.24920800E+00, -.23610000E+01, -.60297200E+00, -.43993400E+00, -.52317500E-01, -.11966800E+00, 0.13355700E-01, -.13884500E+00, -.27342900E+01, -.39550600E+00, -.58138500E+00, -.73380100E-01, 0.52989500E+00, -.40585600E+00, -.43690400E+00, 0.59409300E-02, 0.10229800E+01, 0.15271800E-01, -.23103200E+00, 0.31090600E+00, -.53287300E-01, -.12946800E+00, 0.21819400E+00, -.65708500E+00, -.33548200E+00, -.12884800E+00, 0.13002900E-02, -.27600200E+00, 0.73115700E-01, -.43472900E+00, -.15715400E-02, -.27503000E+00, 0.51888500E+00, -.11597300E+00, -.26408700E+00, -.90755900E-01, 0.55093900E-01, 0.83477200E-01, -.78105100E+00, -.90267000E-01, 0.81440900E+00, 0.71452800E-01, -.53484100E+00, 0.27275000E+00, -.43715700E+00, -.31457500E+00, -.11156500E+01, 0.64380900E+00, -.20123900E-01, -.12411500E+01, -.29323300E-01, 0.42254900E+00, 0.15399500E+01, -.58615600E-01, 0.13765000E+00, -.41325600E+00, 0.26271400E+00, 0.19040000E+00, 0.70727800E+00, -.62106100E-01, -.29829300E+00, -.20956000E-01, -.79279400E-01, -.87780800E+00, 0.83731100E-01, -.15030500E+00, 0.26425800E+00, -.26474800E+00, -.77177800E+00, 0.15414000E-01, -.10598800E-01, -.44341100E-01, -.89462500E-01, 0.56200800E-01, 0.81783600E+00, -.93346800E-02, 0.15699700E-01, -.15249800E+00, 0.66260400E+00, 0.20962900E-01, 0.96052600E+01, 0.27858700E-01, 0.26444300E+00, 0.29703100E+01, 0.18938100E+02, 0.31385500E+02, -.51013100E+01, -.24869000E+02, -.10929400E+03, 0.36931500E+02, -.68226700E+02, -.74825000E+00, 0.13265000E+01, -.84398500E+00, -.31091600E+00, 0.24855200E+00, -.54527300E+00, 0.41038400E+01, -.15205700E+01, 0.72924200E+00, 0.58665700E+01, -.10024400E+02, -.25907600E+01, 0.32674500E+00, -.82503300E+00, -.40621000E+01, 0.75635600E+01, -.22762900E+00, 0.78123200E+00, -.19085700E+01, -.32545600E+01, 0.16915700E+01, -.44718300E+01, 0.30661600E+01, 0.83730300E+01, 0.18942500E+01, 0.15681500E+02 },
        { -.30175800E+01, 0.11063300E+00, 0.11507900E+00, 0.26169500E+00, -.46748800E+00, 0.92655300E+00, -.83224900E+00, 0.69011900E+00, -.88424500E-01, 0.58668400E+00, -.73909900E-01, -.69921400E+00, 0.99882300E-01, -.17422600E-01, 0.52655000E+00, 0.21902100E+00, -.11466000E+00, 0.78390300E-01, -.86381800E-01, 0.34782600E+00, 0.37390500E+00, -.11016200E+00, 0.10369000E+01, 0.12424000E+00, -.69639800E-01, 0.19684000E-01, -.28955200E-01, 0.38050700E+00, 0.56145400E+00, 0.92016800E-01, 0.20529000E+00, 0.10699200E+01, 0.93108900E-03, 0.41221900E+00, -.26309100E+01, -.12335600E+00, -.73064400E-01, -.11832100E+01, 0.12242800E+00, -.33978400E+00, 0.32931800E+00, -.12952800E+00, 0.22199900E+00, -.41503900E+00, 0.14907800E+00, -.88271200E-01, 0.76759500E-01, 0.12226400E-01, -.11567200E+00, 0.35853900E-01, -.20674300E+00, 0.43947800E-01, 0.10386100E-01, 0.14141100E+00, 0.47415200E+00, -.25516100E+00, -.15616900E-01, -.17103200E+00, 0.21109100E+00, -.41125300E-01, 0.15487000E-01, -.41945700E-01, 0.17115300E+00, 0.80218000E-02, 0.45847100E-01, 0.11201600E+00, 0.15565500E+00, 0.51689500E-04, -.97900000E-01, 0.23611100E-02, -.52475900E-01, 0.19229700E+00, 0.66927400E-01, 0.44126700E-02, 0.55900900E-01, -.12194500E+00, 0.42500700E-01, -.89969700E+00, -.34368800E+00, 0.25947300E+00, 0.16368900E-01, 0.64198300E-01, 0.36709200E+00, -.17608300E+00, 0.61346900E+00, 0.10403700E+01, 0.43805800E-01, 0.42872300E-01, -.23515000E+00, 0.12442100E+00, 0.50211500E-01, 0.55765300E-02, 0.26005300E+00, -.53198400E-01, 0.11632200E+00, 0.43410000E-01, 0.39620300E-01, -.25496200E+00, -.17523000E+00, -.12145700E+00, -.31168200E-02, 0.15809100E+00, -.78529800E-01, -.34541600E-01, -.85567200E-02, 0.71791200E-01, 0.94021000E-02, 0.27201900E+00, -.38397200E-02, -.16812800E-01, -.62859800E+00, -.17407900E-01, 0.14251100E-01, 0.37115400E-02, 0.12658200E+00, 0.24618500E+00, -.51453200E-01, -.23016400E+00, -.56836100E-01, -.39115000E+00, 0.45335700E-01, 0.89852000E-03, -.40705500E-02, -.66987600E-01, -.15882100E-02, 0.12025500E+00, -.20719900E-01, -.19265400E-01, 0.92159300E-01, 0.15038400E+00, -.84396200E+00, -.85853400E-02, 0.17838300E+00, -.23731300E-01, 0.12331200E+00, 0.22475800E+00, 0.94168700E-02, -.74956300E-01, -.49549400E+00, 0.51483200E+00, -.23179800E+00, -.40247400E-01, 0.37164800E-03, -.32511900E-01, -.10110400E-01, 0.24365100E-01, 0.10338800E-01, -.23304500E+00, -.10075000E+00, 0.27490300E+00, 0.48344700E-01, 0.13484700E+00, -.56119100E+00, -.12084700E-01, -.81028600E-01, -.61441800E-01, -.68504300E-01, 0.14417600E-01, -.86691500E-01, 0.43475400E-01, -.71000700E-01, -.95069200E-01, -.24394100E-01, 0.57300800E-01, 0.40407400E-01, -.67805600E-01, -.13792400E-01, 0.28844300E+00, 0.62376600E-01, -.14583800E+00, -.40011900E-01, 0.19249300E+00, -.37855300E-01, 0.61069700E+00, -.31171500E-02, 0.33487500E-01, -.28093300E-01, -.14272000E-01, 0.99165800E-01, -.23921400E+00, -.33238300E+00, 0.19652700E+01, 0.29079900E-01, 0.18570800E+00, -.97079700E-01, 0.64766900E+00, -.15936200E-01, -.16402800E+00, -.73980200E-02, 0.40052300E-01, 0.32762500E-03, 0.25515400E-01, -.75462900E+00, 0.44420100E+00, -.45599700E-01, 0.22220400E-01, 0.15969400E+01, -.57836800E+00, 0.30650900E+00, 0.36121500E-01, 0.19228600E+00, -.14951700E-02, -.52163600E-01, -.88481100E-01, -.54073500E-01, -.54973400E-02, -.37421400E-01, 0.61472200E-01, -.41552600E+00, 0.21471300E-01, -.21204100E-02, 0.97976800E-01, 0.55275200E-01, 0.16553700E+00, -.13062800E+00, 0.63870400E-01, -.10858100E+00, 0.56585300E-01, 0.15636400E-01, 0.18273500E-01, 0.28651600E-01, -.89528300E-02, 0.89102100E-01, 0.11015700E-01, -.14500700E+00, 0.50237600E-02, 0.23880100E+00, -.39488800E-01, -.68319600E-01, 0.81733800E-02, -.34324000E-01, -.40994300E-01, 0.31002300E-02, 0.19935100E+00, 0.23610500E-02, 0.11108200E+00, -.15135200E-01, 0.59670600E-01, 0.18311900E+00, 0.29326100E+00, -.23457900E-01, -.18771700E-01, 0.20048200E-01, -.10133100E-01, -.42994200E-01, -.81319000E-04, 0.33990100E-01, -.66662300E+00, 0.31909900E+00, -.10362300E-01, -.28093600E-01, -.11710200E+00, -.46126400E-01, 0.14659000E-01, 0.72192200E-02, -.52207400E-01, 0.31695200E-01, 0.28291200E-02, -.15109200E+00, -.84339900E-01, -.80057700E-03, 0.60539500E-01, 0.18089800E-01, 0.13552600E-01, 0.18746100E+00, 0.94409300E-02, 0.44525600E-01, -.88242000E-01, 0.66001300E+01, 0.10745900E+02, -.72232300E+01, -.41617300E+01, -.23329500E+02, 0.10072700E+02, -.24581700E+01, -.70834200E-01, 0.21987000E+00, -.24525900E+00, -.67913400E-01, 0.10283900E+00, -.20053300E+00, 0.10185100E+01, -.25573000E+00, 0.23608500E+00, 0.46785300E+00, -.10555000E+01, -.60313000E+00, 0.10979800E-01, -.39790500E+00, -.11352100E+01, 0.75217900E+00, -.21974600E+00, 0.17565900E+00, -.41122300E+00, -.10309500E+01, 0.39389500E+00, -.10659700E+01, 0.94448100E+00, 0.64731200E+00, 0.31374900E+00, 0.27609800E+01 },
        { 0.22025600E+02, -.59295800E+00, -.75937300E+00, 0.11725100E+01, 0.24027500E+01, -.43693000E+01, 0.12244900E+01, -.13314500E+01, 0.14521000E+01, -.34174300E+01, 0.55672000E-01, 0.32996400E+01, -.23779100E+00, -.72778900E-01, 0.95394800E+00, -.68061600E+00, 0.57202200E+00, 0.26880800E-01, 0.51928900E+00, -.11571500E+01, 0.19746400E-01, 0.59714700E+00, 0.16920600E+01, -.91005700E+00, 0.48844800E-01, -.21240100E+00, 0.46423200E+00, -.25517800E+01, -.27431100E+01, 0.49585600E+00, -.16668800E+01, 0.85108500E+00, 0.25999700E+00, -.61263000E+00, 0.15199700E+01, -.10261200E+00, -.15924700E+00, -.20523300E+01, -.34770000E+00, -.51707000E+00, 0.42205600E+00, 0.78248000E+00, 0.74834100E+00, -.11522500E+01, -.11850600E+01, -.21131000E+00, -.35809600E+00, 0.67061700E-01, 0.12264000E+01, -.17057300E+00, -.45578200E+00, -.20244400E+01, -.14452500E-01, 0.48367700E+00, 0.66185200E+00, 0.84060700E+00, -.16741200E-01, 0.13026500E+01, 0.12946400E+01, 0.68804800E-01, -.30780500E-04, -.69180900E-02, 0.10569300E+01, -.36911400E+00, 0.55149900E-01, -.10487600E+00, 0.52274700E-02, -.91836400E-01, -.15961300E+01, 0.29833800E-02, -.21269800E+00, 0.21857400E-01, -.22561100E+00, -.23431600E+00, -.26343000E+00, 0.17583900E+00, 0.66975000E-01, 0.70000900E+00, 0.29681000E+01, -.25151300E+01, -.93668600E-01, 0.57593400E+00, -.77846000E+00, 0.10219400E+01, -.24858200E+01, 0.22346000E+01, -.93037000E+00, -.30372800E+00, -.22641900E-01, -.10347600E+01, 0.12482000E+00, -.14371000E-03, -.37716200E+01, 0.17274200E+00, -.89386400E-01, -.58305000E+00, -.10311000E+01, 0.86299200E+00, -.61016000E+00, -.24477200E+00, -.11681300E+00, 0.70050500E+00, 0.13110800E+00, 0.37353500E+00, -.79772900E-01, -.88304400E+00, -.44776600E-01, 0.16486800E+01, 0.20970400E+00, -.11324100E+00, -.18892900E+00, -.14078700E+00, 0.40041400E+00, -.11532500E-01, 0.42038900E+00, -.74966100E-01, 0.84987000E-01, -.38710100E+00, 0.13982800E+00, 0.65934700E+00, -.33414100E+00, 0.76234000E-01, 0.59095700E-01, 0.63856400E+00, -.71087100E-02, 0.90015300E-01, 0.25196800E+00, 0.12598100E+01, -.37485100E-01, 0.11276300E+01, -.11528500E+01, 0.12324400E+00, -.25051700E+00, -.13458200E+00, 0.29290600E+00, -.12460600E-01, 0.51726100E-01, -.24907100E+00, -.12507300E+01, 0.51158200E+00, 0.12610500E+01, 0.15862300E+00, 0.21291400E+00, 0.29596400E+00, -.14848700E-01, -.14289600E+00, 0.16520300E-01, -.13925800E+01, 0.22939200E+00, 0.67438200E+00, 0.75103500E-03, 0.76257200E+00, -.18283300E+01, 0.25626400E+00, -.22332000E+00, -.34024200E+00, -.16459500E+00, -.22976300E-01, -.18386700E+01, -.12756800E+00, -.58533100E+00, -.65415200E+00, 0.21452600E+00, -.19734800E+00, 0.50263300E-01, -.22456000E+00, 0.11654800E+00, 0.61662400E+00, -.25415300E+00, -.87704000E+00, 0.74391300E+00, -.20404300E+01, -.53615100E+00, 0.12164700E+01, 0.16893500E+00, 0.24761300E+00, 0.50096700E-01, -.51384400E-02, -.91049400E+00, -.70238000E+00, -.95098000E+00, 0.97079400E+01, -.18130600E+00, 0.15742700E+01, 0.20534100E+00, -.37841300E+00, -.42088700E+00, -.77613500E+00, 0.10671100E-01, -.60556000E-01, 0.40738800E-02, -.19261400E+00, -.32892500E+01, -.90645700E+00, -.59991200E+00, 0.21929900E+00, 0.32313500E+01, -.16139400E+01, -.62142200E+00, -.10037700E+00, -.49557500E+00, -.42243300E-03, 0.19753400E+00, -.49523900E+00, -.42234600E-01, -.31047900E-01, 0.27043400E+00, 0.63424800E+00, 0.10604300E+01, -.10567100E+00, -.37694600E-01, -.40894500E-01, 0.68383400E-01, 0.39485400E+00, -.27679700E+00, 0.74673900E-01, -.31769300E+00, 0.36653200E+00, -.20677100E-02, 0.92687600E-02, 0.30627300E+00, 0.12487600E-01, -.20022300E+00, 0.16163100E+00, -.73227000E+00, 0.72154500E+00, 0.11609300E+01, -.92762900E-01, 0.17512500E+00, 0.13635900E+00, -.18987400E+00, -.28004500E+00, 0.92228300E-01, 0.22130800E+01, -.10872400E+00, 0.89869900E-02, -.83938700E-01, -.16318300E+00, -.13277000E+01, 0.56001900E+00, -.42196000E+00, -.46111200E+00, -.11393700E+01, -.27810600E-01, 0.18579800E+00, 0.38559600E+00, 0.81478300E-01, -.20189000E+01, 0.47541000E+00, -.15513500E+00, 0.54253300E+00, 0.34743000E+01, 0.48875500E+00, -.25353000E+00, -.87855400E-02, -.32494200E-01, -.67705900E-01, 0.40128700E+00, 0.34961200E+00, -.36237800E-01, 0.36837600E+00, -.93675800E+00, -.11888100E+01, -.12069500E+00, 0.32908100E+01, 0.75804900E-01, 0.43523500E+00, 0.94867500E+00, 0.32290700E+01, 0.45353600E+02, -.73050600E+02, -.62336500E+01, 0.72098300E+02, 0.38198300E+02, 0.18621200E+03, 0.48263800E+00, -.20534500E+01, 0.53857200E+00, -.13198000E+00, -.28394800E+00, 0.43750900E+00, 0.81877800E-01, -.77132300E-01, -.61809700E+00, -.26033700E+02, 0.32550900E+02, 0.44611200E+01, 0.29753700E+00, -.34439900E+00, -.17603600E+01, -.30540100E+02, -.65539900E+00, 0.49586100E+00, 0.18828200E+01, 0.11545500E+02, -.13263500E+01, -.55928600E+00, 0.13985100E+01, -.19682700E+02, -.32464300E+01, -.35425000E+02 },
        { -.31436800E+02, 0.87642600E+00, 0.11824400E+01, 0.16995200E+01, -.39137400E+01, 0.88925000E+01, -.20931600E+01, 0.22788900E+01, -.40739900E+01, 0.84731000E+01, -.12769700E+00, 0.13216700E+01, -.66392000E+00, -.44100700E+00, -.58724900E+00, 0.33565000E+00, 0.10031400E+01, 0.53317500E+00, -.26156900E+00, 0.46520700E+01, 0.36575500E+01, 0.49669300E+00, -.13273200E+02, -.31077600E+01, 0.45223900E+00, 0.70513500E-01, -.79747900E+00, 0.12403400E+01, 0.46036600E+01, 0.46739700E+01, 0.27680800E+01, 0.28440400E+01, -.34883200E+00, 0.12515300E+01, -.74408400E+01, -.14128200E+01, -.27010000E+00, -.39869700E+01, 0.20928100E+00, -.38513900E+01, 0.11684200E+01, 0.72336300E+01, -.94491000E+00, -.30379200E+01, 0.14089100E+01, 0.19392100E+00, 0.55585300E+00, 0.41474100E-01, -.34194000E+01, 0.44807400E+00, -.48798000E+01, 0.14433200E+02, 0.26326100E+00, -.46012300E+00, -.10274200E+02, -.73860000E+00, 0.87023000E-01, 0.29384000E+01, 0.89212000E-01, -.88662600E-01, -.30437200E+01, 0.97297600E-01, 0.10304800E+01, -.13141800E-01, -.18544200E+01, -.50429600E+00, -.11555400E+01, 0.78969600E-02, 0.99752700E+00, -.10572700E-01, 0.12899000E+00, 0.26982500E+00, 0.67297100E+00, -.11193900E+00, 0.18196800E+01, -.76794400E+00, -.12669300E+01, -.15898400E+02, 0.31676700E+01, -.48877000E+00, 0.27893000E-01, -.13642100E+01, 0.10589000E+01, 0.11858700E+01, 0.13116600E+01, 0.13078900E+02, 0.73159500E-01, -.31582500E+00, -.15994700E+01, -.80989800E+00, 0.14478700E+01, -.72109800E-01, 0.63309900E+00, -.75514000E+00, 0.42191400E+00, 0.60866700E+00, 0.83273400E+00, -.12935900E+01, 0.14397900E+01, 0.66885600E+00, -.10689300E+00, -.98648600E+00, 0.31242900E+00, 0.85742700E-01, -.24072700E+00, 0.34153800E-02, -.11911000E+00, -.86526300E+01, -.14616200E+00, 0.22416800E+00, 0.53824600E+01, 0.11054700E+00, 0.71576600E+00, -.11786600E-01, -.15560100E+01, -.51260900E+00, -.34971900E+00, 0.44810800E+01, -.83204500E-01, 0.45170700E+01, 0.24293100E+00, -.24899900E+00, -.59481100E-01, -.78176700E+00, 0.71433300E-02, -.87300300E+00, -.17091700E+00, 0.46298800E+00, -.42114500E+00, -.23880700E+01, -.42740900E+00, -.54877900E-02, -.35235200E+00, 0.16599300E+00, -.10526700E+01, 0.23246300E+01, 0.19009800E+00, -.15764800E+00, 0.43151500E+01, -.12648300E+00, -.33451400E+01, -.52496900E+00, -.34265600E+00, -.15867200E+01, -.26302600E-01, 0.69225800E-01, -.31997100E-01, -.30371100E-01, -.85517500E+00, 0.63770400E+01, 0.46908600E+00, -.31230500E-01, -.99525200E-01, -.11384500E+01, -.57323000E+00, 0.45606800E+00, 0.52640700E+00, -.40541100E-01, 0.64787500E+01, -.10197200E+00, -.24143600E+01, 0.18897000E+01, 0.16037600E+00, -.82077700E+00, 0.22275900E+00, 0.72702300E+00, -.20950600E+00, 0.41356700E+00, -.71090800E-01, 0.38188800E+00, 0.77387000E+00, -.10089900E+01, -.10874400E+01, 0.14097800E+01, 0.42711400E+00, -.91254200E+00, -.15894300E+00, -.16778100E-01, 0.34394600E+00, 0.10124600E+01, -.22113900E-02, -.14485300E-01, -.23645300E+00, -.94651400E+00, 0.56713900E+00, -.15335700E+01, -.21044300E-01, 0.75192300E+00, 0.52232800E-01, -.19935300E+00, 0.14991800E-02, -.86950500E-01, -.79942700E+00, -.12330900E+01, 0.16768000E+00, -.10418000E+00, -.82211900E+00, -.70838000E+00, -.11124900E+01, -.28692100E-01, -.52717500E+00, 0.25834600E-01, 0.33090600E+00, 0.94030700E+00, 0.26987200E+00, -.79540900E-01, 0.10077800E+00, 0.13229100E+00, 0.88036800E+00, 0.94608100E-01, -.63018700E-01, -.16502400E+00, -.78752900E-01, -.28484600E+00, 0.31647300E+00, 0.27020200E+00, 0.22023600E+01, 0.38380100E+00, 0.22420500E-01, 0.43211000E-01, -.30432300E+00, 0.52010300E-01, 0.42668700E-01, -.21228700E+00, 0.17515800E+01, -.50951500E+00, -.16976900E+01, 0.19210100E+00, -.17530300E+01, -.65469600E+00, -.17601800E+01, 0.13266100E+01, -.50498000E-01, -.39539100E+01, 0.32340800E+00, 0.87183500E+00, 0.19005100E+01, 0.22165000E+00, 0.25094200E+01, 0.47230200E+00, 0.10891900E+01, 0.21075300E+01, 0.15119200E+01, -.10059200E+00, 0.14434300E+01, -.93556000E-01, -.16597400E+00, 0.74598300E+00, 0.15185000E+01, 0.97955900E+00, 0.92953100E+00, -.75775100E+00, -.91976700E+00, -.23885700E+00, 0.13440800E+00, 0.54522000E+00, -.37910400E+00, -.54823900E+00, -.38567300E+00, -.38298400E+00, -.23690800E+00, 0.11268700E+01, -.73184900E+00, -.24033300E+00, 0.24264300E+01, 0.90460200E-01, -.13287800E+00, 0.22077700E+01, -.84775700E+01, -.26813600E+00, -.76306100E+02, -.10899200E+02, 0.70766900E+02, -.23619400E+02, 0.86639700E+02, 0.22445100E+01, -.11021500E+01, 0.16243800E+00, 0.11336600E+00, 0.24566400E+00, 0.76097100E-01, 0.22940400E+01, 0.16441500E+01, 0.31629500E+00, -.14374000E+02, 0.20206500E+02, -.11431900E+02, -.65787400E+00, -.17054400E+01, -.31723200E+01, -.16091000E+02, -.97424900E+00, 0.25282400E-02, 0.13245600E+01, -.66989700E+01, -.86015800E+00, -.15464200E+01, 0.51709100E+01, -.21268500E+02, -.20252600E+01, -.20276700E+02 },
        { -.80288500E+01, 0.21423700E+00, 0.30122200E+00, 0.48609400E+00, -.12598100E+01, 0.27760800E+01, -.12381900E+01, 0.15068700E+01, -.14829200E+01, 0.28462200E+01, -.38216200E-02, -.94253800E+00, -.28059600E+00, -.13887500E+00, -.33592900E+00, 0.26758400E+00, -.24966600E+00, -.47019000E-01, -.54386000E-02, 0.15130200E+01, 0.13892700E+01, -.86620100E-01, -.83381800E+01, -.95033700E+00, -.57252000E-01, 0.11069600E+00, -.15835800E+00, 0.19007500E+00, 0.23006900E+01, 0.16665700E+01, 0.11307400E+01, 0.19407100E+01, -.15157400E+00, 0.11800900E+01, -.33217100E+01, -.84534600E+00, -.11851000E+00, -.21153500E+01, 0.12552100E+00, -.13627200E+01, 0.94600800E+00, 0.13874900E+01, 0.45860600E-01, -.10899300E+01, 0.54845100E+00, -.20824400E+00, -.59180300E-01, 0.33829600E-01, -.12609400E+01, 0.18849100E+00, -.25298600E+01, 0.46422800E+01, -.71488800E-02, -.26874300E+00, -.23525600E+01, -.21050800E+00, 0.13353000E+00, 0.46847500E+00, 0.52563800E+00, -.10525200E+00, -.12646400E+01, 0.38509000E-01, -.63741200E+00, 0.30286900E+00, 0.28141000E+00, -.32040500E+00, 0.18489900E+01, -.20128100E-02, 0.18451400E+01, -.36430800E-02, 0.15473300E-01, -.25852900E+00, -.63437200E-01, 0.17915600E+00, 0.64441200E+00, -.78589600E+00, 0.44059900E-01, -.33908700E+01, 0.29477800E+00, -.44347600E-02, 0.26725000E-01, -.16551300E+01, -.10850100E+01, 0.71789600E+00, -.10890400E+00, 0.41616600E+01, 0.46460200E-01, -.19498100E+00, 0.30194600E+00, -.61896700E+00, -.37055500E+00, 0.68701800E-01, 0.10273600E+01, -.29250800E+00, -.61304000E-01, -.25866400E+00, -.27544700E+00, -.19252400E+00, 0.19005100E+01, -.73400900E+00, -.34976700E-01, -.69410800E+00, 0.57109300E+00, 0.11506800E-01, 0.31469800E-02, -.40168700E+00, -.75330600E-01, -.96340800E-01, 0.29791300E+00, -.17144100E+00, 0.32145000E+00, -.77659700E-01, 0.40907100E-01, -.10250500E-01, 0.84600200E-02, -.31971800E+00, 0.13259100E+00, -.38504200E+01, 0.34262800E+00, -.52976500E-01, -.10598400E+00, 0.10263600E+00, 0.38097500E-02, 0.22556200E+00, -.75306900E-02, -.60615200E+00, -.12180500E+00, 0.31631000E+00, 0.56464600E-01, -.63116100E+00, 0.37537200E+01, -.54267200E+00, -.39608600E+00, 0.24094300E-01, 0.21333800E+01, -.11879900E+00, -.12498100E+00, -.85521500E-01, 0.85052700E+00, -.74066500E+00, 0.60618200E-01, -.23779500E+00, 0.11959000E-01, -.19514600E+00, 0.53005700E-01, 0.71786100E-02, -.34066200E-01, -.92928000E+00, 0.37333700E+00, -.70438200E+00, -.28493400E+00, 0.78586600E+00, -.22200300E+00, 0.14083400E+00, 0.14042800E+00, -.17575900E+00, -.10132600E+00, -.21500300E-01, -.24473100E+01, 0.22846600E+00, 0.10004900E+01, -.51103600E+00, 0.13907500E+00, -.18451900E+00, 0.15123500E+00, -.10703200E+00, 0.10539100E+00, 0.66117100E+00, -.19330100E+00, -.16537400E+00, 0.56950100E+00, -.11035900E+01, -.38228500E+00, 0.91239000E+00, 0.64355300E+00, -.14598200E+00, 0.67011800E-01, 0.13488300E+00, 0.25037900E+00, 0.96445400E+00, 0.40709700E+00, -.17778900E+01, 0.21337100E+00, 0.75270600E-01, -.69764800E-01, -.92426300E+00, -.29190600E+00, -.32346700E+00, -.58672900E-01, -.27271800E-01, 0.82941500E-02, -.53452700E-01, -.11610600E+01, 0.12735000E+00, -.34709400E+00, 0.18057800E-01, 0.40631500E+00, -.14188900E+00, -.86645200E-01, -.42245500E-02, 0.64968500E+00, -.98065400E-03, -.12270400E+00, -.18030500E-01, 0.16123500E-01, -.43140700E-01, 0.15525600E+00, -.32008400E+00, -.99862200E-01, -.10619300E+00, -.14677200E-01, -.10430600E+00, 0.28948100E-01, -.63126700E-01, -.45625200E-01, -.43945600E-01, 0.49917000E-01, -.93623900E-01, -.12717800E+00, -.54981900E-01, 0.62598300E-01, 0.50767100E-01, -.67004000E+00, -.84674100E-02, 0.40156700E+00, 0.75746200E+00, 0.30830100E+00, 0.32798100E+00, -.16283000E+00, -.14941500E+00, -.59551800E+00, 0.18535000E+00, 0.26146200E-01, -.93672300E-01, -.27407000E-01, 0.26895400E+00, 0.13902400E+01, 0.83711400E-02, 0.22303200E+00, -.33389300E+00, 0.17074600E+00, -.31758400E+00, 0.64050100E+00, -.96281700E-01, -.80062400E+00, -.36323900E-01, -.19834600E-01, -.42476400E+00, 0.15119400E+00, -.12332700E+00, -.20300700E+00, -.84812200E+00, -.98133800E+00, 0.11730600E+00, -.18661500E-01, -.21278300E+00, -.12529100E-01, 0.15154500E+00, 0.11782600E+01, -.34268100E+00, -.18743000E+00, 0.76908500E-01, 0.29839900E+00, 0.15121900E+00, -.20513300E+01, -.27038400E-01, -.87503600E-01, -.48969500E+00, -.76867700E+00, -.40226800E+00, -.24301400E-01, -.24958400E+02, -.52522400E+02, 0.48772900E+01, -.46538500E+01, -.45763700E-02, 0.45008600E+00, -.89347500E+00, 0.12479900E+00, 0.71131500E+00, -.71779900E+00, -.17324600E+01, -.42218800E+00, 0.98735300E+00, -.41389400E+01, 0.41683800E+01, -.33543100E+01, -.36053100E+00, -.54169100E+00, 0.17002300E+01, -.51839000E+01, -.22673500E+00, 0.16356200E+00, -.76679500E+00, 0.22374400E+01, 0.76948800E+00, 0.15264700E+01, -.21718600E+01, 0.10258100E+01, 0.31288400E+00, -.12172400E+00 },
        { 0.37716300E+02, -.10762800E+01, -.12817600E+01, 0.31110300E+01, 0.40014900E+01, -.75942200E+01, 0.29003100E+01, -.21697400E+01, 0.10855900E+01, -.59553400E+01, 0.35613500E+00, 0.64370900E+01, -.86639100E+00, -.10188400E+00, 0.33440900E+01, -.15817900E+01, 0.22159000E+01, 0.13929800E+01, 0.17565800E+01, -.20237100E+01, 0.12440800E+01, 0.36194400E-01, 0.23022200E+02, 0.53849100E+00, 0.34626900E+00, -.22570500E+00, -.22329700E+00, -.31888900E+01, -.23668500E+01, 0.78356800E+00, -.22531500E+01, -.20398900E+01, 0.24799000E+00, 0.12044800E+01, -.80738800E+01, -.79756100E+00, -.63502000E+00, -.63407700E+01, -.19866000E+00, -.20814800E+01, 0.13918500E+01, 0.29829000E+01, -.20443600E+00, -.30252300E+01, -.39788800E+00, -.73125800E+00, 0.35701500E+00, 0.13555000E+00, 0.38073400E+00, 0.37271300E+00, -.12192900E+01, -.66681700E+01, -.24246700E+00, 0.87637100E+00, -.25122900E+01, 0.91337500E+00, -.42225700E-01, 0.19043700E+01, 0.33973700E+01, -.50205200E+00, -.34444800E+00, 0.82984700E-01, 0.22356800E+01, -.52863100E+00, 0.25544500E+00, 0.57342600E+00, 0.33600200E+01, -.19846800E+00, 0.27923000E+01, 0.13583600E-01, -.88636400E+00, 0.92305800E+00, -.23513000E+00, -.51105800E-01, -.24196200E+01, 0.75771400E-02, -.77521900E+00, -.90276000E+00, 0.42378400E+01, -.22907100E+01, -.13126300E+00, 0.21650900E+00, -.59813900E+00, 0.16263500E+01, -.18537300E+01, 0.10400700E+02, -.52497300E+00, -.58643600E+00, -.60221800E+00, -.73820900E+00, 0.39376200E+00, -.84634100E-01, -.18828200E+01, 0.48717900E-01, -.36675000E+00, -.46599600E+00, -.53510600E+00, 0.11846100E+01, 0.14034800E+01, 0.47468100E+00, -.18004200E+00, -.62550100E+00, -.27541200E+00, 0.72813300E+00, -.30547800E+00, -.10038800E+01, -.63802600E-01, 0.36980200E+01, -.78825100E+00, 0.41767800E+00, 0.17922300E+01, 0.12121400E-02, -.21534500E-01, -.31572400E-01, 0.23006100E+00, -.43657700E+00, -.16973300E+00, -.30432800E+01, -.16008500E+00, -.23790600E+01, 0.38464700E+00, -.10324000E+00, -.52654800E-01, -.65473000E+00, -.41602100E-01, -.17071700E+01, -.41777400E+00, -.10565800E+01, 0.55337900E+00, -.30902400E+01, -.16895700E+00, -.34595300E+00, 0.21094500E-01, -.42940100E-01, -.28278300E+01, 0.29759300E+01, 0.21160100E+00, -.26796800E+00, -.38649700E+00, 0.10759400E+01, -.59962700E+00, 0.95513500E+00, 0.29398600E-01, 0.19833900E+00, 0.12530300E-01, -.18068900E+00, 0.67970800E-01, -.12029100E+01, -.19077000E+00, -.24378200E+00, 0.30811900E+00, -.26321200E+00, -.99493000E+00, 0.15449500E+00, -.30825100E+00, -.66561500E-01, -.36401800E+00, -.24546100E-01, -.68074800E+00, -.15222300E+00, -.23735500E+00, -.73456400E+00, 0.89007400E-01, 0.41288300E+00, 0.41270900E+00, -.22362100E+00, -.20250200E+00, 0.11002700E+01, 0.38652400E-01, -.48199800E+00, 0.13023600E+01, -.15616200E+00, -.10110400E+01, 0.60028800E+01, -.70152800E-01, 0.11127200E+00, -.54285300E-01, -.10947700E+00, 0.24996500E-01, -.20233900E+01, -.14553400E+01, 0.12785700E+02, -.18954400E+00, 0.14480200E+01, -.21084800E-01, 0.14869600E+01, -.83166800E+00, 0.46345200E+00, -.68464500E-01, -.11214300E+00, 0.99776100E-03, -.11248000E+00, -.16854500E+01, -.22844600E+00, -.24086000E+00, 0.39693400E-01, 0.63108800E+01, -.21279900E+01, -.51113200E+00, -.14099500E-01, 0.19692900E+01, -.73377300E-01, -.36645200E-01, -.55959800E+00, 0.10299300E+00, -.31275300E+00, 0.26880500E+00, 0.56967700E+00, 0.12040200E+01, -.21037000E+00, -.67600700E-01, -.82185700E-01, -.23527900E+00, 0.17781800E+00, 0.12537500E+00, 0.21097500E+00, -.10718300E+01, 0.11486100E+01, 0.74994400E+00, 0.16583300E+00, 0.17947300E+00, 0.20489000E-01, -.44185100E+00, 0.17378200E+00, -.82265000E+00, 0.16051700E+01, 0.90213000E+00, 0.40080300E-01, -.38238700E+00, -.97295200E-01, 0.19043200E+00, 0.19691900E-01, 0.10702500E+00, 0.25501300E+01, -.94757300E-01, 0.12989200E+00, -.84583600E+00, -.41507400E+00, -.20956600E+01, 0.54418400E+00, -.38190800E+00, 0.60964700E+00, 0.21720900E+00, -.14261400E+00, 0.95806900E+00, 0.13809500E+00, 0.75226500E-01, -.20623200E+01, 0.18154300E+01, -.17140400E+00, 0.10916600E+00, 0.40962900E+01, 0.20614300E+01, -.39627000E+00, -.30820600E-01, 0.20548400E+00, -.54491200E-01, -.28788700E+00, -.22774300E+01, 0.26467400E-01, 0.44638800E+00, -.99634700E+00, -.26915500E+01, -.45907300E+00, 0.21228800E+02, 0.44841500E-01, 0.35288800E+00, 0.34427300E+01, -.28297900E+01, 0.59532800E+00, 0.86895000E+00, -.22254000E+01, -.68202600E+02, 0.72396000E+01, 0.12306700E+03, -.58572100E+00, -.11170700E+00, -.19447300E+01, 0.14234800E+00, 0.16397800E+01, -.17358000E+01, -.73030300E+01, -.15273000E+01, 0.16893000E+01, 0.98948200E+00, -.10730600E+01, 0.95440100E+01, -.12144800E+01, -.13231300E+01, 0.66188800E+01, -.17210600E+01, -.13546900E+01, -.55291300E-01, -.67771700E+00, 0.18624900E+02, 0.86586800E+00, 0.62076800E+01, -.82796800E+01, 0.12402400E+02, -.87358700E+00, 0.99421600E+01 },
        { -.11472500E+01, 0.10180500E+00, 0.50267900E-01, 0.29995100E-02, -.14816900E+00, 0.10997800E+01, -.91736200E+00, 0.98688200E+00, -.12893900E+00, 0.92856400E+00, -.49977500E-01, -.43076500E+00, 0.75678000E-01, 0.12386700E-01, -.39001600E-01, 0.19250400E+00, 0.74741000E-01, -.10004000E-01, -.10995500E-01, 0.72875600E-01, 0.52849700E+00, -.89273000E-01, -.26706100E+01, 0.40021600E-01, -.25686300E+00, -.52856300E-01, -.54888100E-01, 0.19165500E+00, 0.47881500E+00, -.66285800E+00, 0.12994800E+00, 0.62511700E+00, -.15834100E-01, 0.44728600E+00, -.22587700E+01, -.21090200E+00, -.12820200E+00, -.65723300E+00, 0.91368300E-01, -.41267900E+00, 0.47024700E+00, -.32893600E+00, -.16639800E+00, -.21240600E-01, 0.23175800E+00, -.90982500E-01, -.90641800E-01, 0.24494600E-01, 0.24776200E+00, -.61639000E-01, 0.14997200E+00, -.12053200E+01, -.32767100E-01, 0.11921000E+00, 0.10586000E+00, -.35959200E-01, -.53500200E-01, 0.35293500E-01, 0.46831300E+00, -.54188900E-01, 0.17294000E+00, -.44624200E-01, 0.29295900E+00, 0.53964300E-01, 0.13841400E+00, 0.99309700E-01, 0.17278800E+00, -.19736900E-02, 0.47713200E-01, 0.30478600E-02, -.94224800E-02, 0.21315100E+00, 0.11486100E+00, -.10331400E-01, 0.25857000E+00, -.31858500E+00, -.78783400E-01, -.34777700E+01, 0.31322100E+00, 0.42479600E-01, 0.10935900E-01, -.44292500E-01, 0.73704900E+00, -.41955500E-01, 0.39989100E+00, 0.24172100E+01, -.12514700E+00, -.54188700E-01, -.38885600E+00, -.16186900E+00, 0.51804200E+00, 0.29952300E-01, -.14756800E+00, -.19245000E+00, 0.26162900E+00, -.11536200E+00, 0.41681000E+00, -.41885200E+00, 0.23212400E-01, 0.61809900E-02, -.86944400E-01, 0.29887500E-02, -.74758000E-01, -.23037700E-01, 0.19024100E-01, -.25613300E-01, 0.77354100E-01, 0.63229300E+00, -.27944900E-01, 0.28189700E-01, -.66793700E+00, -.27872900E-01, -.10902600E+00, 0.63395700E-02, 0.21999600E+00, -.11516800E+00, -.32805700E-01, 0.38813400E+00, 0.63284300E-01, 0.73209300E-01, 0.24205200E-01, 0.11341000E-01, -.12929000E-01, 0.94112400E-01, 0.69833400E-02, 0.24070500E+00, 0.24614800E-01, 0.72272800E-01, 0.11629500E-01, 0.62530300E-01, -.25136700E+00, -.68234400E-01, 0.11464200E+00, -.83784200E-01, 0.10289000E+01, 0.89060300E-01, 0.42284000E-01, -.68871700E-01, -.40373500E+00, 0.39988200E+00, -.16500900E+00, 0.30158300E+00, -.50255700E-01, 0.10983100E+00, -.10542000E-01, -.40081400E-02, 0.35172600E-02, -.10871200E+00, -.43580200E-01, -.15237900E+00, 0.30218200E-01, 0.33894300E-01, 0.39218700E-01, 0.93111600E-02, -.13643900E+00, -.19860600E-02, -.42092300E-01, 0.29688200E-01, 0.79834700E-01, -.24611600E-01, -.24876800E+00, -.46209900E-01, 0.67301000E-01, 0.12744700E-01, 0.70844600E-01, -.11387300E+00, -.12904400E-01, 0.47291200E+00, -.25161400E-01, -.16468900E+00, 0.21510000E+00, -.40968400E+00, -.13807500E+00, 0.62212800E+00, 0.37041200E-01, 0.92961600E-01, 0.13554400E-01, 0.12926200E-01, -.15174400E-01, -.35522300E+00, -.63610400E-01, 0.15170000E+01, 0.57666000E-01, 0.17646300E+00, -.77750600E-01, 0.42981300E-01, 0.68698700E-01, 0.18371200E+00, 0.47306300E-02, 0.25479900E-01, -.12398800E-02, 0.12627800E-01, 0.63002500E+00, -.25364700E+00, 0.12095500E+00, 0.70625100E-01, -.29693600E+00, 0.12100200E+00, -.62323300E-01, -.31514900E-01, -.45914200E+00, 0.33103300E-02, 0.23002300E+00, -.69327700E-01, 0.40752400E-01, -.24775000E-01, 0.19839800E-01, 0.39484400E+00, 0.16458600E+00, 0.21064900E-01, -.34075600E-02, 0.18063400E+00, 0.31748400E-01, 0.15719700E+00, -.12434100E+00, 0.13908400E+00, 0.27616800E-01, 0.10075000E+00, 0.68079600E-01, 0.27766700E-01, -.21284500E-02, -.28754000E-01, 0.22323100E+00, 0.21367800E-01, 0.12988500E-01, 0.92694600E-01, 0.12747400E+00, -.68071300E-01, -.43205100E-01, 0.39767000E-01, 0.70567000E-01, -.71691300E-01, 0.15276400E-01, 0.26233500E+00, -.74808000E-02, 0.10896400E+00, -.18675200E+00, 0.50564400E-01, 0.14422900E+00, 0.30866200E+00, -.76334200E-02, 0.37074700E-01, 0.19093300E-01, -.18896500E-01, 0.72726300E-01, 0.17900400E-02, 0.12542200E-01, -.87560200E-01, 0.34288800E+00, 0.13842400E-01, -.54373800E-01, -.24980400E+00, 0.39730700E-01, -.30464800E-01, 0.17136000E-01, 0.53548300E-01, 0.45105500E-02, -.29732500E-01, 0.16313000E-01, 0.14421600E+00, -.81713200E-02, 0.17948400E-01, 0.39289400E-01, 0.23091900E-01, 0.50639400E+00, 0.13915300E-01, 0.23714600E-01, -.61036800E-02, 0.19110100E+00, 0.67579100E-01, -.70788700E-01, -.11545300E+00, -.13028700E-01, -.34852400E+01, -.43239400E+01, 0.94656200E-01, 0.34584200E-02, -.70319300E-01, 0.22705100E-01, 0.10294800E+00, 0.26737800E-01, -.34069200E+00, 0.45985100E-02, 0.16009200E+00, -.26510500E+00, 0.46141500E+00, -.18001700E+01, 0.82599800E-02, 0.23937600E-01, 0.45097900E+00, -.31389300E+00, 0.71282900E-01, -.50440500E-01, 0.18748000E-01, -.60689300E+00, -.66803400E-02, 0.51442900E+00, -.24501600E+00, -.65812400E+00, -.19706400E-01, -.32535800E-01 },
        { -.46316400E+02, 0.12493200E+01, 0.15447600E+01, 0.14696400E+01, -.57916600E+01, 0.11428500E+02, -.12244500E+01, 0.63377900E+01, -.12081500E+02, 0.82482600E+01, -.62846300E-01, -.51204500E+01, -.57595600E+00, -.32757100E-01, -.23861600E+01, 0.10366500E+01, -.12591500E+01, -.27389700E+00, -.35308700E+01, 0.54662600E+01, 0.47399900E+01, -.92564700E+00, -.14748800E+02, -.48461000E+00, -.16695400E+00, 0.10530100E+01, -.71657000E-01, 0.62037000E+01, 0.71642600E+01, 0.21599900E+01, 0.31122800E+01, 0.73797800E+01, -.45126800E+00, 0.49018400E+01, -.15566700E+02, -.19812500E+01, -.55158600E+00, -.11262000E+02, 0.20364300E+01, -.44771300E+01, 0.19509100E+01, 0.15525200E+01, 0.57371900E+00, -.47198800E+01, 0.21010800E+01, -.87501100E+00, 0.81011000E+00, 0.12050800E+00, -.26227900E+01, 0.51220100E+00, -.48139400E+01, 0.11799700E+02, -.12244400E+00, 0.12331100E+01, -.47763000E+01, -.29184600E+01, 0.22511800E+00, 0.19798300E+01, 0.15779600E+01, -.10052400E+01, -.22408100E+01, 0.82363800E+00, 0.11256800E+01, 0.54656900E+00, 0.49389600E+00, 0.51798700E+00, 0.40576000E+01, -.35958900E-01, 0.38872300E+01, 0.18779500E-01, -.34439200E+00, -.48464100E-01, -.47200200E+00, 0.34669300E+00, -.10448700E+01, 0.16879000E+00, -.16420000E+01, 0.27914700E+01, -.67687500E+00, -.73622800E+00, 0.59170100E-01, -.11674500E+01, 0.14322600E+01, -.10348400E+01, 0.13034500E+01, 0.39142200E+02, -.33512500E+00, 0.17304300E+00, -.34634500E+01, -.64370400E-01, -.96733500E+00, 0.95163500E-01, -.21930900E+01, -.12536700E+01, 0.38476200E+00, -.26192300E+01, -.50063200E+00, -.25038300E+01, -.41911600E+00, 0.59510000E+00, 0.21787800E+00, -.36157500E+00, 0.14047100E+00, -.20245000E+01, -.89693600E-01, 0.94343700E+00, 0.31967600E+00, 0.66060300E+01, -.90826100E+00, 0.32512300E+00, -.73795200E+01, 0.51438800E+00, -.76055100E+00, 0.53176800E-01, 0.26863300E+01, -.92406800E+00, 0.40770200E+00, 0.50052100E+01, 0.14693200E+01, -.22704000E+01, -.65608800E+00, 0.22259200E-01, -.27979500E-01, 0.24512900E+01, 0.38814000E-01, -.29754500E+01, -.59930900E+00, -.91415100E+00, 0.16486400E+01, 0.20260900E+01, 0.61048200E+01, -.11493000E+01, -.40392600E+00, 0.62220500E-01, 0.55488700E+01, 0.26557600E+01, 0.12957800E+00, -.46937400E+00, -.15355300E+01, 0.10664100E+01, 0.79911800E+00, -.46944000E-01, -.24193800E+00, 0.19794200E+01, 0.69458900E-01, -.15952800E+00, 0.33102900E-01, 0.36111000E+01, -.77001500E-01, -.37198200E+01, -.23152100E+00, -.19477500E+01, 0.14517300E+01, 0.47096700E+00, -.81612200E-01, 0.70134700E+00, 0.96591200E-01, 0.58605700E-01, 0.10668600E+01, -.14534200E+01, 0.68907000E+00, 0.28671100E+00, -.30380200E+00, -.62156500E+00, -.18783300E-01, 0.10406800E+01, -.36797100E+00, 0.13705300E+01, 0.43334800E+00, -.85894000E+00, -.18098500E+01, -.30741700E+01, 0.66139500E+00, 0.48971800E+01, -.39864600E+00, 0.30571100E-01, -.15004100E+00, 0.21967500E+00, -.24178200E+00, 0.10855400E+01, 0.33201800E+01, -.88901000E+01, 0.95020900E+00, -.17718000E+01, -.94299500E+00, -.24377400E+01, -.17196700E+01, -.66982600E+00, -.11428400E+00, -.21447900E+00, -.91026500E-01, -.27914500E+00, -.40447700E+01, -.14232200E+00, -.86151000E+00, 0.47339500E-01, 0.36688300E+01, 0.80476600E+00, 0.42846300E+00, 0.94983400E-01, 0.84166800E+00, -.42738800E-01, 0.96929800E+00, -.14173800E+01, -.25196300E+00, -.42527500E+00, 0.43246900E+00, -.13770100E+01, -.90704600E+00, -.38629800E-01, 0.47969500E-01, 0.45770200E+00, -.10098400E-01, -.14465600E+00, -.51341300E+00, 0.23286400E+00, 0.29816300E+01, -.87488100E+00, -.10435900E+01, -.25455500E+00, -.15220300E+00, -.23517600E-01, 0.17818000E+00, 0.13574000E+00, 0.43182700E+00, 0.36309600E+00, -.14331800E+00, -.26186100E+00, -.17918400E+00, 0.32886500E+00, 0.23943800E+01, -.10413800E+01, -.14719700E+00, 0.40797200E+00, -.86481600E-01, -.68395700E+00, -.23981600E+01, 0.20887100E+00, 0.88830100E+00, 0.54379900E+00, -.24862000E+00, -.62085500E+00, -.42224100E+01, 0.10814500E+00, 0.61169200E+00, -.58884700E-02, 0.54691800E+00, 0.17973500E+01, -.18278100E+00, -.39705900E+00, 0.58887900E-02, 0.18565600E+01, 0.20061600E+01, -.42044600E+00, -.78636400E-01, 0.10326200E+01, 0.18567300E+00, -.72303000E-01, 0.53283200E+01, 0.19964300E+01, -.71949400E+00, -.14554400E+00, 0.43009600E+01, 0.93437700E+00, -.25454600E+01, -.13013600E+00, -.59036300E+00, -.52117200E+01, -.14779300E+01, -.18772300E+01, -.13327400E+01, 0.14277300E+01, -.39243600E-01, -.78707800E+00, -.28237700E+03, -.17590700E+01, 0.59579600E+00, -.20310100E+01, -.12113500E+00, 0.41392100E+00, 0.19371400E+01, 0.11694800E+01, -.29682000E+01, 0.26289600E+01, 0.11528500E+01, 0.33699000E+01, -.28257500E+02, 0.13911300E+01, 0.37922700E+01, 0.19177900E+01, -.36455200E+01, 0.25128800E+01, 0.74381800E+00, 0.60614200E-01, 0.37059000E+01, 0.58240900E-01, 0.34241700E+00, 0.19182800E+01, 0.21666400E+02, -.12974600E+01, 0.30505400E+01 },
        { -.49399000E+01, 0.13600300E+00, 0.15977400E+00, 0.10064700E+01, -.80750000E+00, 0.72898400E+00, -.15049800E+00, 0.39242700E+00, -.80903200E+00, 0.19032900E+00, -.30878700E-02, -.73788900E+00, -.85685500E-02, 0.37592400E-02, 0.29804800E+00, 0.21505900E+00, -.53373700E-01, -.59236300E-01, -.28471100E+00, 0.58951600E+00, 0.23325300E+00, -.65737900E-02, -.18288700E+01, 0.22577200E+00, 0.29274000E-01, 0.43051300E-01, -.10297700E+00, 0.73468400E+00, 0.81124100E+00, 0.54431200E-01, 0.39395500E+00, 0.61983700E+00, -.25134000E-01, 0.35342400E+00, 0.15835000E+00, -.23044400E+00, 0.13912400E+00, -.88145500E+00, 0.22207000E+00, -.48375900E+00, 0.21811600E+00, 0.61567000E+00, -.12078500E+00, -.70866600E+00, 0.47801500E+00, -.10694600E+00, -.29253100E-01, -.20310100E-01, -.59734800E-01, 0.67841200E-01, -.25906900E+00, -.22418300E+01, -.34432000E-01, -.95054700E-01, -.38683700E+00, 0.51742900E-01, -.25893900E-01, -.21252600E-01, -.17481200E+00, 0.21954500E-01, -.37893900E-01, -.37474700E-01, -.15263300E+00, 0.93660600E-01, 0.26095300E+00, -.21367600E-01, 0.40662700E+00, 0.16196200E-01, -.53953800E-01, -.14799800E-03, 0.81611500E-01, 0.79056000E-01, 0.74657700E-01, -.37780900E-01, 0.77815800E+00, -.32507800E+00, -.10160700E+00, -.23410100E+01, -.28161700E+00, -.36182200E-01, 0.10071400E-01, 0.18736100E+00, 0.36676800E+00, -.10234900E-01, 0.21128500E+00, 0.11523000E+01, -.84347000E-02, 0.56326100E-01, 0.39605900E-01, 0.23821000E+00, -.12592500E+00, 0.11737500E-01, 0.26674400E+00, 0.90664000E-02, 0.57155400E-01, -.29403700E+00, -.35514800E-01, 0.25769100E-01, -.97270000E-01, -.29984000E-03, 0.79751400E-02, -.86558600E-01, 0.54716700E-01, -.43839000E-02, 0.11145200E-01, -.73163300E-01, 0.12092600E-01, 0.13072200E+01, 0.52568200E-01, -.22286900E-01, 0.91532900E-01, -.25730800E-01, -.40274600E-01, -.39675000E-02, 0.14269600E+00, 0.16124300E-01, 0.30013500E-01, -.53916300E+00, -.30743200E-01, 0.66319900E+00, -.10412600E+00, 0.19852700E-02, 0.28477800E-01, 0.25874200E+00, 0.11199700E-02, 0.25638100E-01, 0.81196200E-01, 0.17587100E+00, -.25421700E-01, 0.11003500E+01, -.20655700E-01, 0.12933300E+00, -.72223200E-02, 0.27713200E-01, 0.12060700E+01, -.35909700E+00, -.68669800E-01, -.30184000E-01, -.16971500E+00, 0.91547500E-01, 0.12533500E+00, -.21212300E+00, 0.28576000E-01, -.10680500E+00, 0.20080200E-02, 0.17132700E-01, -.72004100E-02, 0.39157300E+00, 0.11661300E+00, -.75742700E-01, -.10012800E+00, 0.16366300E-01, 0.13953500E+00, 0.20651200E-01, 0.58419500E-01, -.23281900E-01, 0.19209800E-01, -.20554700E-01, 0.92977900E-01, 0.46926800E-01, 0.12034600E+00, -.64446400E-01, 0.27703200E-01, -.21064600E+00, 0.32995600E-01, -.30205700E-01, -.76002100E-01, 0.15183600E+00, 0.20659000E-01, 0.19937400E+00, 0.19867700E+00, 0.92526200E+00, 0.48451800E-01, 0.69530000E+00, -.12510100E+00, -.69288300E-01, -.41987200E-01, 0.86765100E-02, 0.24579200E+00, -.11164500E+00, 0.38961100E-01, 0.80272400E+00, -.23664400E-01, 0.31399600E+00, -.96010300E-02, 0.22947000E+00, 0.10949100E-01, 0.10706100E+00, -.18652600E-02, 0.25157400E-01, 0.15218500E-02, -.90953200E-03, 0.12081100E+00, -.24823300E+00, 0.32398100E-01, -.11239400E-01, 0.61291900E+00, 0.55846800E-01, 0.16542100E+00, 0.17118600E-01, 0.35559400E+00, -.23035100E-02, -.75886000E-01, 0.54417900E-01, -.51207600E-02, 0.18681400E-02, -.44931300E-03, -.88205100E-02, -.51184800E-02, -.84191000E-02, -.71652800E-02, 0.97386200E-01, -.47536200E-02, -.98226300E-01, -.14510400E-01, 0.20252400E+00, 0.30848600E+00, -.19666400E+00, -.79752500E-01, -.26397100E-01, -.10516700E+00, -.23337600E-01, 0.30477400E+00, 0.47381000E-02, -.39316900E-01, -.38985200E+00, -.12958900E+00, -.92893100E-01, -.41737000E-02, 0.96837800E-02, 0.48381400E-01, -.18561200E+00, -.11977200E-01, 0.24795700E+00, 0.38092800E-01, -.15766300E+00, 0.62870900E-01, 0.25591100E-02, 0.16984600E+00, 0.90050700E-01, 0.75739800E-01, -.28957100E-02, -.71098400E-01, -.58872900E-01, 0.36167500E-01, -.15988000E-02, -.18588500E-01, -.37824500E+00, 0.20212500E+00, 0.41603500E-01, 0.24310800E-01, 0.32145100E+00, -.23041200E-01, -.41586300E-01, -.19780200E-01, 0.11040300E+00, 0.15408800E-01, -.43939000E-01, 0.32765900E+00, 0.45335300E-01, -.17087700E-01, -.76654300E-01, -.23629300E-01, -.38608300E-01, 0.39679300E+01, 0.21763500E-02, 0.18941900E-01, 0.52547400E-01, -.18049500E+00, -.10537700E+00, 0.64759800E-01, 0.20469900E+00, -.48679700E-01, -.40632900E+00, 0.47420200E-01, -.41741400E+00, -.16888600E+00, 0.23759300E+00, -.93421300E-01, -.18777400E+00, 0.32496800E+00, -.60866900E+00, -.13288700E+00, -.29604500E+00, 0.55839900E+01, -.58096300E+01, 0.35849800E+01, 0.16410800E+00, 0.51119600E+00, 0.66393200E+00, 0.53462100E+01, 0.19949500E+00, -.14490300E+00, 0.21465800E+00, 0.78738600E+01, -.24401500E+00, 0.45951500E+00, -.79276100E+00, 0.64686000E+01, 0.26995700E-01, 0.57586200E+01 },
        { -.66781000E+01, 0.17937900E+00, 0.24833300E+00, -.16423200E-01, -.91030300E+00, 0.18583500E+01, -.23686300E+00, 0.96366000E+00, -.16127400E+01, 0.13178800E+01, -.74709600E-02, -.50603000E+00, -.30538500E-01, -.37915300E-02, -.35465900E+00, 0.23311700E+00, 0.13127200E+00, 0.77438100E-01, -.45068200E+00, 0.85206200E+00, 0.86154300E+00, -.10888300E+00, -.88537200E+00, 0.31614400E-01, 0.54987900E-01, 0.34009700E-01, 0.13577200E+00, 0.68122400E+00, 0.10664200E+01, 0.13763700E+00, 0.39693000E+00, 0.96738300E+00, -.64992700E-01, 0.60676800E+00, -.23974900E+01, -.31205400E+00, -.10477500E+00, -.16520100E+01, 0.17907300E+00, -.63888600E+00, 0.39090200E+00, 0.39283900E+00, 0.10226000E-01, -.55455500E+00, 0.18737100E+00, -.60206200E-01, 0.14690800E-01, 0.21606500E-01, -.46585200E+00, 0.93025700E-01, -.50549900E+00, 0.67182700E+00, 0.46444600E-01, 0.10939400E+00, -.57362500E+00, -.28766500E+00, 0.21088700E-02, 0.24074500E-01, 0.29747000E+00, -.12104600E+00, -.19849500E+00, 0.26912900E-01, -.15365600E-01, 0.54287700E-01, 0.12312600E+00, -.30167700E-02, 0.20867500E+00, 0.64226300E-02, 0.42735800E+00, 0.23071200E-02, 0.31005700E-01, -.68611500E-01, -.16923300E-01, 0.73750500E-01, 0.67557500E-01, 0.89375900E-01, -.18540700E+00, -.56676800E+00, 0.33139100E-01, 0.35765100E+00, 0.43739000E-01, -.29482900E+00, 0.74066300E+00, -.38086300E+00, 0.76133000E+00, 0.54739000E+01, 0.11420900E+00, 0.77784600E-01, -.51045700E+00, 0.45251300E+00, -.15019000E+00, 0.32125200E-01, 0.18325800E+00, -.12867400E+00, 0.37030600E-01, -.40210200E+00, 0.25600900E-01, -.13616200E+00, 0.17518600E+00, 0.16829800E+00, 0.31849900E-01, -.47703400E+00, 0.22537700E+00, 0.86887000E-02, 0.28225100E-02, -.24869700E+00, -.19715700E-02, 0.22311800E+01, -.79276000E-02, -.21368700E-01, 0.29706300E+00, 0.29684000E-01, -.23338300E-01, -.27009900E-02, 0.11903800E+00, 0.26826200E+00, 0.67891900E-01, -.10573600E+01, 0.12577900E+00, 0.50888700E+00, -.98306400E-01, -.17015600E-01, 0.13160200E-01, 0.19523700E+00, -.42942600E-02, -.49858700E+00, -.46507500E-01, 0.30607400E-02, 0.57414900E-01, 0.30312900E+00, 0.17678100E+01, -.19806700E+00, -.13364400E+00, 0.16780000E-01, 0.11458600E+00, 0.32712900E+00, -.44291800E-01, -.11667100E+00, 0.15460400E+00, -.21489700E-01, 0.62978200E-01, -.29754700E+00, -.24367400E-01, 0.19661300E+00, 0.61395700E-02, 0.86947000E-01, 0.10729600E-01, 0.22045500E+00, 0.25157000E-01, -.16722400E+00, -.37424800E-01, -.63043000E-01, 0.42565100E+00, 0.12171400E+00, 0.73065000E-01, 0.51298000E-01, -.14576400E-02, -.17942500E-01, -.20944500E+00, -.14149800E+00, 0.91538900E-01, -.59046400E-01, -.44246400E-01, 0.65677900E-02, -.87443900E-02, 0.25689000E-01, -.38563200E-01, 0.10152500E+00, 0.51336500E-01, -.43937900E-01, -.17598300E+00, -.46494200E+00, 0.17169300E+00, 0.54799200E-01, 0.58928000E-01, 0.96907900E-01, -.15935600E-01, -.81951300E-02, -.15913200E+00, -.30752800E+00, 0.12264500E+00, 0.57923500E+00, -.27743300E-01, -.64784600E-01, -.14983000E-02, -.63678800E-01, -.74354500E-01, 0.68873900E-01, -.57139000E-02, -.30150300E-01, 0.33226500E-02, -.64719900E-01, -.58674800E+00, -.13773700E+00, -.52573000E-01, -.52855400E-01, 0.51750400E-01, -.80190500E-01, -.57609900E-01, 0.76293600E-02, 0.17163500E+00, -.10584300E-02, 0.31286400E-01, -.74869600E-01, -.44909100E-01, 0.12833500E-01, 0.25792300E-01, -.16268100E-01, 0.72580500E-01, 0.26500500E-02, -.10156000E-01, 0.78091000E-01, 0.41984000E-03, 0.58007600E-02, -.96963300E-02, 0.76461300E-01, 0.88887600E-01, -.36100300E-01, -.26893800E-01, -.88851900E-02, -.54776800E-01, 0.94678000E-02, -.17226800E+00, -.24456000E-01, 0.16266800E+00, -.14207800E-01, -.33336700E+00, 0.57921400E-02, -.78099300E-01, -.20442000E-01, 0.12997100E+00, 0.15505200E-02, -.97293700E-02, -.76799400E-01, 0.78431200E-02, -.92606500E-01, -.13536200E+00, -.20785700E-01, -.17316800E-01, 0.26810400E-01, -.28575500E-01, 0.44405500E-01, 0.45843200E-01, -.14629600E-01, 0.11051300E+00, -.47251800E-02, -.46283900E-01, -.15526200E+00, 0.17585900E-01, -.92009900E-01, 0.10026300E-02, 0.17054000E+00, 0.10215500E+00, -.29580700E-01, -.37203300E-02, 0.84601000E-01, 0.21889400E-01, -.19555500E-01, 0.13838300E+00, 0.16297800E+00, 0.41653100E-01, -.10668300E+00, -.68249900E-01, -.46628900E-02, 0.22305800E+01, 0.61001500E-02, 0.28034300E-01, 0.43515500E-02, 0.33612000E+00, 0.43886700E-01, -.33668400E-01, -.56701800E-01, 0.18059200E-01, 0.58407400E-01, 0.61725500E-02, -.38109600E+00, 0.23572300E+00, -.12599400E-01, -.71904400E-01, -.42838100E-01, -.85560600E-03, -.96321800E-01, -.22612200E+00, -.72169200E-02, 0.22585100E+01, -.24251500E+01, 0.46268800E+00, -.12330000E+00, 0.70601000E-01, 0.12430400E+00, 0.23091500E+01, -.39414800E-01, -.51398900E-02, -.76284200E-01, 0.26982000E+01, 0.66882300E-01, 0.70223100E-01, -.14060500E+00, 0.20762600E+01, -.60666000E-01, 0.23065200E+01 },
        { 0.56427900E+02, -.17110500E+01, -.19479900E+01, -.14620700E+01, 0.63507900E+01, -.14322800E+02, 0.26681800E+01, -.51367000E+01, 0.13411200E+02, -.12161400E+02, 0.20373400E+00, 0.99239400E+00, 0.80020400E-01, 0.54374100E+00, 0.22380100E+01, -.46604500E+00, 0.15633700E+00, 0.11165200E+01, 0.27329200E+00, -.78910600E+01, -.68158900E+01, 0.68600300E-01, 0.35129200E+02, 0.50975700E+01, 0.38334300E+00, -.64745800E+00, 0.12940700E+01, -.61398700E+01, -.99272500E+01, -.16810900E+01, -.30047300E+01, -.10588700E+02, 0.44981700E+00, -.56402200E+01, 0.12835200E+02, 0.33142700E+01, 0.68178900E+00, 0.19258500E+02, -.17431100E+01, 0.64616700E+01, -.37246300E+01, -.32674300E+01, -.26999400E+01, 0.10212700E+02, -.11085500E+01, -.42639700E+00, -.69278900E+00, -.16199200E+00, 0.14690300E+01, -.13774000E+01, 0.10768200E+02, -.51865300E+01, 0.11676300E+01, -.18985200E+01, 0.55507500E+01, 0.44736000E+01, 0.33031200E+00, -.14773200E+01, -.28273700E+01, 0.59858600E+00, 0.17865200E+01, 0.10314500E+00, 0.13875900E+01, -.22649300E+01, 0.61358300E+00, 0.16197600E+01, -.85853000E+01, -.62891800E-01, -.12946800E+02, 0.19979500E-01, -.26211300E+00, 0.56005600E+00, -.57664500E+00, -.20746400E+01, 0.26433400E-01, 0.45175200E+01, -.19280300E+01, 0.42576100E+01, 0.11427100E+01, -.53069200E+01, -.47089100E+00, 0.10773100E+02, 0.73824500E+00, -.13789100E+01, -.64733900E+01, -.32653300E+02, -.37295600E+00, 0.11742900E+00, 0.55916400E+00, 0.15439600E+01, 0.92290500E+00, -.26323300E+00, -.79376200E+01, 0.20508600E+01, 0.21748700E+01, 0.79772700E+00, 0.29735400E+00, 0.31995600E+01, -.89812800E+01, 0.95493000E+00, 0.19595100E+00, 0.77085200E+01, -.41489500E+01, 0.11174200E+00, 0.39150100E+00, 0.21396200E+01, 0.32680000E+00, -.57611700E+01, -.12220100E+01, 0.46423700E+00, -.13106400E+02, -.45105600E-01, -.19979800E+01, 0.69853400E-01, 0.18743700E+01, -.11422700E+01, -.65920500E+00, 0.18139500E+02, -.91584600E+00, -.73879500E+01, 0.11355200E+01, 0.62007800E+00, 0.80396900E-02, -.42504100E+00, 0.71508300E-01, 0.29309700E+01, -.85162000E-01, 0.36496900E+01, -.43731200E-01, 0.36344800E+01, -.15053400E+02, -.10076900E+01, 0.72710700E+00, 0.11067600E+00, 0.52695100E+01, -.20830000E+01, 0.41059100E-01, 0.11948500E+01, 0.28277600E+01, -.19276300E+01, -.33290600E+01, 0.35490700E+01, -.81221300E-01, -.28052700E+01, -.17953800E+00, -.92863200E+00, -.81422900E-01, -.18757600E+01, -.61673600E+00, -.16666100E+01, -.89931000E+00, -.12177900E+01, -.23145800E+01, -.21542800E+01, -.39915700E+00, 0.41950000E+00, 0.12631200E+01, -.23844200E+00, 0.87891900E+01, 0.26416100E+00, -.30576100E+01, 0.18987000E+01, -.13738100E+00, -.79621800E+00, -.37002200E-01, 0.26074500E+01, -.34832400E+00, -.20176000E+00, -.11401600E+00, -.11589600E+00, 0.12093100E+01, 0.19659900E+02, -.89625900E+00, 0.40325900E+00, 0.17521500E+01, -.20630300E+00, -.86577400E+00, -.22307800E+00, 0.60558000E+00, -.21696800E+01, -.60683900E+00, -.48122300E+01, -.11064500E+01, -.89716100E+00, -.73697300E+00, 0.45165000E+01, 0.11854100E+01, 0.10021400E+01, -.69612100E-01, 0.19937900E+00, -.12638100E-01, 0.39771100E+00, 0.79952200E+01, 0.16046900E+01, 0.12969300E+01, 0.22794200E+00, -.30364600E+00, 0.16175600E+00, -.10034800E+01, -.59649200E-01, 0.84985200E-01, -.97555100E-01, -.68718500E+00, -.57581700E+00, 0.82585900E+00, 0.26208400E+00, -.23910700E+00, 0.16797900E+01, 0.10046700E+01, -.16815900E+00, 0.29251000E-02, -.41437100E+00, -.35929900E+00, -.36276700E+00, 0.61169300E+00, 0.58091800E+00, -.99086200E+00, 0.22422300E+01, 0.14161100E+01, 0.42713700E+00, 0.12799600E+00, 0.21451300E-01, -.18904300E+01, 0.15701200E+00, 0.12820300E+01, 0.32466700E+01, 0.23007000E+01, 0.80105100E+00, -.15903400E+01, 0.46797200E-01, -.13027000E+01, -.43457700E+00, 0.31007400E+00, -.15319600E+01, 0.72252800E-01, 0.11025600E+01, 0.37014300E+01, -.23538800E+00, 0.61201100E+00, -.23035100E+01, -.40327900E+00, 0.61578100E+00, 0.72579500E+00, 0.16549100E+00, -.42421600E+00, 0.25748100E-01, 0.37763600E+00, -.56355900E+00, 0.13884400E+01, -.31635500E+00, 0.17322600E+00, 0.12157500E+01, 0.13977300E+01, -.31733200E+00, 0.13360100E+00, 0.56194500E+00, 0.28937900E+00, -.41201400E+00, -.16469300E+01, 0.42425800E+01, 0.45257700E+00, 0.32607100E-01, -.16915900E+01, 0.54157800E+00, -.13734400E+02, 0.99602000E-01, -.82264400E+00, -.32906100E+01, 0.24247500E+01, 0.80825700E+00, -.84258500E+00, -.40700500E+00, 0.19344700E+01, 0.56971100E+01, 0.11453000E+00, -.88088700E+01, 0.10597600E+01, 0.35295600E+01, -.19811600E+01, -.50474600E+01, 0.35087700E+01, 0.10015200E+02, 0.12515100E+01, -.27877900E+01, 0.29212600E+02, -.33471900E+02, -.31817800E+02, 0.23085100E+01, 0.17242200E+01, -.97406800E+01, 0.35114200E+02, 0.89281500E+00, 0.81604000E+00, 0.27963800E+01, 0.28814800E+02, -.32641100E+01, -.81088400E+01, 0.10165400E+02, 0.22464300E+01, 0.32214800E+01, 0.28639300E+02 },
        { -.18350700E+01, 0.26396800E-01, 0.23272400E-01, -.21479600E+00, -.30715800E+00, 0.30055800E+00, 0.36539400E+00, -.97774800E-01, -.47654500E+00, 0.24080700E+00, 0.25380000E-01, -.31004300E+00, -.56078400E-01, 0.57535900E-01, -.13061700E+00, 0.42959000E-01, -.89425400E-01, -.12900000E-01, -.17117100E+00, 0.30418000E+00, 0.26810800E+00, -.45353200E-01, -.59334000E+00, -.61603600E-01, -.36985800E-02, 0.45364900E-01, -.25947500E-01, 0.24090500E+00, 0.28480400E+00, 0.59124400E-01, 0.15532900E+00, 0.84020100E-01, -.37017200E-01, 0.93587700E-01, -.46761400E+00, -.81635500E-01, -.33332000E-01, -.29716500E+00, 0.79813700E-01, -.21361900E+00, -.13351800E-02, 0.27847400E+00, -.94564400E-01, -.16975200E+00, 0.15302500E+00, -.62322600E-01, -.39050600E-03, 0.45053800E-02, -.88262000E-01, 0.96851400E-02, -.90142800E-01, -.11055300E+00, 0.70186700E-02, 0.44771100E-01, -.26693700E+00, -.40589600E-01, 0.11014600E-02, 0.31688100E+00, 0.95290100E-01, -.25629300E-01, -.17198600E+00, 0.14851500E-01, 0.12995200E+00, 0.33489200E-02, 0.56058600E-01, 0.74977800E-02, -.23428700E+00, -.28746600E-03, 0.14721900E+00, 0.74429800E-04, -.57046400E-02, -.10007400E+00, -.65993000E-01, 0.60161700E-01, 0.26467500E-01, 0.95601100E-02, -.10020500E+00, -.37333200E+00, 0.79159800E-01, 0.61556100E-01, 0.52960300E-02, -.17996900E+00, 0.16198900E-01, -.57175100E-01, 0.74105800E-01, 0.13588400E+01, 0.36942000E-01, -.75192200E-02, -.13279100E+00, 0.12111500E+00, -.40371900E-01, 0.69353400E-02, 0.86482100E-01, -.25574800E-01, 0.24829400E-01, -.84858600E-01, -.69201500E-01, -.77664400E-01, -.18239000E-01, 0.18846700E-01, 0.10600300E-01, 0.53039800E-02, 0.33891900E-01, 0.20696900E-01, -.44482800E-01, 0.36864400E-02, -.96640600E-02, -.10935700E+00, -.27256200E-01, 0.99221700E-02, 0.34619800E+00, 0.16048700E-01, 0.13689800E-01, -.96168100E-03, -.10371200E+00, -.13747100E-01, 0.22131400E-01, 0.76057100E-01, 0.71366100E-01, -.31697700E-01, -.54255900E-01, -.19128200E-01, 0.28512200E-03, -.66443700E-01, -.64553000E-03, -.82695800E-01, -.17717300E-01, 0.83587100E-01, -.35908900E-01, -.84837400E-01, 0.22459700E-01, -.63990100E-01, 0.28909300E-01, 0.21841700E-01, -.11246600E+00, 0.51390400E-01, 0.17550100E-01, 0.11878500E-01, 0.24472100E+00, -.35942800E-01, -.11360200E+00, -.99799900E-01, -.71316300E-02, -.56156200E-01, 0.26411400E-02, 0.45160700E-01, 0.36912500E-02, -.28897000E-01, -.51055200E-01, 0.18581500E+00, 0.24015700E-01, -.73175000E-01, 0.62537900E-01, 0.31607100E-02, -.15973400E-01, 0.27447400E-01, 0.41663500E-02, -.43389800E-02, 0.47443700E-01, -.25685800E-01, -.10501900E-01, 0.27358000E-01, -.12781500E-01, 0.25706100E-01, 0.24913100E-02, 0.24151600E-01, -.12243700E-01, 0.52177200E-02, 0.13421900E-01, -.37831500E-01, -.89701300E-01, 0.26226600E-01, 0.50655100E-01, 0.22573500E-02, 0.31591400E-01, 0.26700400E-01, -.15465900E-01, -.35678900E-02, 0.48385600E-02, 0.43771000E-01, -.24182400E-01, 0.51431300E-01, 0.28203300E-02, 0.59397800E-01, -.16093900E-02, 0.13261200E+00, -.19098600E-01, -.24930800E-01, 0.14579700E-02, 0.31171600E-01, 0.45643400E-03, -.16080000E-01, -.25609800E+00, -.11704000E-01, -.89242900E-01, -.59849000E-02, 0.40575300E-01, 0.43799900E-01, 0.10072900E+00, 0.67426400E-02, -.25929400E-01, 0.19079400E-02, 0.37945500E-01, 0.58553700E-02, -.33328500E-01, -.11988600E-01, 0.46102300E-02, -.12589700E+00, -.31396900E-01, 0.91112400E-02, 0.27782800E-02, 0.32228500E-01, 0.49058400E-02, 0.96447100E-01, 0.10486300E-01, 0.14034400E-01, 0.14097700E+00, -.95365300E-01, -.49225900E-01, -.12933200E-01, -.10392700E-01, -.42269500E-02, -.61790300E-01, -.10322300E-01, 0.37490800E-01, -.13794600E+00, -.15304400E+00, -.49449200E-01, -.46243300E-02, 0.14176900E-01, -.42733000E-02, 0.35178100E-02, -.32236100E-02, -.29313500E-01, 0.45247800E-02, 0.42019000E-02, -.88607900E-01, -.15793900E-01, 0.50549000E-02, -.37438700E-01, -.15044300E-01, 0.64277600E-02, -.57327400E-01, 0.42482400E-02, 0.49879500E-01, 0.23114400E-03, 0.16062400E-01, -.89190000E-01, 0.47457300E-02, -.54025100E-01, -.20662400E-01, 0.10582000E+00, 0.47873600E-01, -.15900900E-01, 0.91384500E-03, 0.23692000E-01, 0.87763500E-02, -.98612600E-02, 0.38269000E-02, 0.92188400E-02, 0.16854700E-01, -.89967400E-01, -.39403000E-01, -.11009300E-01, 0.94765000E+00, 0.15788500E-02, 0.18109200E-01, 0.11331900E-01, 0.22769100E+00, 0.35917400E-01, -.19216500E-01, -.34736000E-01, 0.12609200E-01, 0.54714500E-01, -.19940400E-02, -.97742000E-01, 0.10878900E+00, 0.36937700E-02, 0.10373000E+00, -.26717200E-01, 0.17009600E-01, 0.16582900E+00, -.10672600E+00, 0.70902600E-02, 0.13556500E+00, -.16344000E+00, 0.10349400E+00, 0.34424700E-01, -.21990400E-01, -.16723000E+00, 0.16873100E+00, -.12852400E-01, -.91153500E-01, 0.13597100E-02, 0.18429400E-01, -.30425500E-02, -.16775800E+00, 0.19790500E+00, 0.28792300E-01, 0.67199500E-01, 0.13483000E+00 },
        { 0.26648700E+02, -.73227800E+00, -.91980700E+00, 0.32247200E+00, 0.33857800E+01, -.54270200E+01, 0.29512800E+01, -.22999300E+01, 0.63857400E+00, -.38140800E+01, 0.32247300E+00, 0.53350800E+01, -.53334600E+00, 0.11913300E-01, -.94615000E+00, -.13528000E+01, 0.15473100E+01, 0.79954800E-01, 0.84830000E+00, -.27476900E+01, -.10530100E+01, 0.51760500E+00, -.22224400E+01, -.84919200E+00, -.27539200E-02, -.33690100E+00, 0.22856500E+00, -.33173900E+01, -.39321000E+01, -.14668400E+01, -.18532200E+01, -.48011000E+01, 0.10997100E+00, -.12009900E+01, 0.70574400E+01, 0.14061500E+00, 0.40116500E-01, 0.35293700E+01, -.72326300E+00, 0.13753200E+01, -.86556000E+00, 0.73069900E+00, -.15619400E+01, 0.21337100E+01, -.88631300E+00, 0.80022500E-01, -.54262200E+00, -.54898200E-02, 0.15294800E+01, -.14540400E+00, 0.16782200E+01, -.24767600E+01, -.17721500E+00, -.37053300E+00, -.30500000E+01, 0.19395200E+01, 0.21188300E-01, 0.99726500E+00, 0.35588200E+00, -.18490700E-01, 0.41752100E+00, 0.35968200E+00, -.48280200E+00, -.75017100E-01, 0.10887400E+00, -.42855600E+00, 0.43216300E+00, -.41296500E-01, 0.82343700E+00, -.31026700E-02, 0.11072400E+00, -.81547900E+00, -.48103900E+00, -.82908000E-01, -.76093000E+00, 0.93295800E+00, -.35327500E+00, 0.39773700E+01, 0.28170700E+01, -.23009300E+01, -.11525900E+00, 0.13088600E+00, -.82404500E+00, 0.10529900E+01, -.36019800E+01, -.26224100E+01, -.83367200E+00, -.46385700E+00, 0.93436800E+00, -.13352400E+01, 0.38473200E+00, 0.53509700E-03, -.22123500E+01, 0.35699200E+00, -.36148300E+00, -.66133300E+00, -.20131000E+00, 0.11016000E+01, 0.11300500E+00, 0.44403800E+00, -.93379100E-01, -.50673300E-01, 0.28341000E+00, 0.49879600E+00, -.25863600E+00, -.10284900E+01, -.13007700E+00, 0.70482100E+00, -.55532600E+00, 0.20733100E+00, 0.20199300E+01, -.33173900E-01, -.30314900E+00, -.19584600E-01, -.18040600E+00, -.12316200E+01, 0.73250500E-01, 0.21136300E+01, 0.95795000E-01, 0.43867100E+00, -.63779200E-01, -.80868400E-02, 0.50755500E-02, -.15399300E+00, -.33787900E-02, -.24668600E+00, 0.77286500E-02, 0.24941800E+00, -.26193400E+00, -.13335800E+01, 0.79083300E+00, -.26149300E+00, -.61139400E+00, -.14631900E+00, -.41463200E+00, 0.40212900E+00, 0.51216800E-01, -.71121800E-02, 0.35800300E+00, -.11225600E+01, 0.46420800E+00, 0.12418400E+01, -.10617100E+00, 0.18310700E+00, -.25369700E-01, -.13316700E+00, -.85221700E-02, 0.25687100E+00, 0.18527000E+00, -.36574700E+00, -.43169500E-01, 0.87828100E-01, 0.78362300E+00, 0.40188400E-01, -.10667000E+00, -.30521600E-01, -.98115900E-01, -.21083800E-01, -.85027700E+00, -.31685900E+00, -.81789700E-01, -.64963900E-01, 0.16940200E+00, -.26877900E-01, 0.44261800E-01, -.14513500E+00, 0.49257100E-01, 0.61931500E-01, -.23347100E+00, -.48905000E+00, 0.50527700E+00, -.30912800E+01, -.52646200E+00, -.45038300E-01, 0.41574800E+00, 0.63168300E-01, 0.18354200E+00, -.14949200E-01, -.10109800E+01, 0.16937600E+00, -.20913600E-01, 0.14712700E+00, -.64875200E-01, -.52597700E-01, 0.20376500E+00, -.21979400E+01, -.43516900E+00, -.17318900E+00, 0.18685100E-01, -.16381900E+00, 0.12648600E-02, -.44792700E-01, 0.71859600E+00, -.10026700E+01, -.10548000E+00, 0.10971800E+00, -.20633200E+01, 0.29282800E+00, -.15312700E+01, -.13676300E+00, -.61300600E+00, 0.41488000E-02, 0.71575200E-01, -.32489400E+00, 0.18703900E+00, -.40558300E-01, 0.29977800E+00, 0.50521700E+00, 0.18502200E+01, -.13416200E+00, -.28447800E-01, -.58544600E+00, -.71947000E-01, -.35699200E+00, 0.18546900E+00, -.42554900E+00, -.65299000E+00, 0.33515600E+00, 0.69171900E-01, -.27668400E-01, 0.30718000E+00, 0.85081700E-01, -.13677700E+01, 0.42301500E-01, -.12315300E+00, 0.14940900E+01, 0.18018000E+00, 0.24354400E+00, 0.42035400E+00, 0.54686200E-01, -.60776400E-02, 0.29539300E+00, 0.88708200E-01, 0.59810000E+00, -.14035300E+00, -.34919100E+00, 0.25075300E+00, -.22548800E+00, -.17320400E+01, 0.23841400E-01, -.22008000E+00, 0.19475300E+00, -.11587900E+01, 0.78476500E-01, 0.41995500E+00, 0.87908000E-01, -.91395100E-02, 0.11241400E+01, -.21658100E+00, 0.65462600E-01, 0.10987100E+00, 0.35283700E+00, 0.44722000E+00, -.14129900E+00, 0.31351700E-01, -.56802000E-01, -.20381500E+00, -.24090100E-01, -.10925200E+01, 0.23267300E+00, 0.21530900E+00, -.39617500E+00, -.91764700E+00, -.15558000E+00, -.20056900E+01, 0.28362800E-01, 0.61938600E-01, 0.25000500E+01, -.59771000E+01, 0.43494500E+00, 0.42164400E+00, -.20070300E+01, 0.48770900E+00, 0.11886100E+01, -.30726400E+00, -.10899800E+01, -.58519600E+00, -.32516400E+00, -.55791300E+01, -.13683800E+01, 0.11522700E+01, -.12017000E+00, -.50772400E+00, 0.59394400E+00, -.25984900E+01, 0.46351200E+01, -.20901200E+02, 0.80602900E+00, 0.10993000E+01, 0.58059100E+00, -.34269800E+01, 0.24218300E+00, -.27470600E+00, 0.10623600E+01, 0.16717400E+02, -.11246100E+01, 0.13878700E+01, 0.32755100E+00, -.68628900E+01, 0.52884400E+00, -.23832600E+01 },
        { 0.29906700E+01, -.12233200E+00, -.14673800E+00, -.48272300E+00, 0.42560000E+00, -.14652300E+01, 0.56303400E+00, -.95504300E+00, 0.16348900E+01, -.58565500E+00, 0.25435800E-02, 0.96121000E+00, 0.86675600E-01, 0.72281000E-01, 0.17387700E+00, -.14594400E+00, 0.76674600E-01, 0.19255500E+00, 0.19670000E+00, -.34819000E+00, -.36371900E+00, 0.82362700E-01, 0.33966600E+01, 0.47588100E-01, -.57068000E-01, -.11686200E+00, -.79708300E-01, -.43115100E+00, -.68203700E+00, -.88381400E-01, -.29954800E+00, -.35285200E+00, 0.59473600E-01, -.42298000E+00, 0.17033000E+01, 0.11549500E+00, 0.45531400E-01, 0.67080100E+00, 0.30525000E-01, 0.72651300E-01, -.11796400E+00, 0.40207700E-01, -.22827400E-01, -.31337000E+00, 0.33591500E+00, 0.63101400E-01, 0.11288200E+00, -.13309400E-01, 0.46103400E+00, -.32786400E-01, 0.67059400E+00, -.15682400E+01, 0.19374500E-01, 0.16041700E+00, 0.29923500E+00, -.30265200E-01, -.40708000E-01, 0.15891000E+00, -.16791300E+00, 0.88263000E-01, 0.39146200E-01, -.11046200E+00, 0.31628100E+00, -.28977700E-01, -.25971300E+00, 0.17178100E-01, -.11562600E-01, -.55405600E-02, 0.10262400E+00, -.20454100E-02, -.26676100E-01, 0.53526700E-01, 0.54556300E-01, -.37968000E-01, -.17446900E+00, -.33192600E-01, 0.20073100E+00, 0.58799200E+00, -.15008600E-01, 0.13141600E+00, -.83992600E-02, -.95144900E-01, -.64798200E+00, 0.58396300E-01, -.21942800E+00, -.15269800E+01, 0.70956800E-01, 0.36679900E-02, 0.28249300E+00, 0.14384300E+00, 0.70137700E-01, -.68565800E-02, 0.71176800E-02, 0.67617900E-01, -.36450900E-01, 0.13871900E+00, -.22244300E-01, 0.57939400E-01, 0.80997300E-01, -.93975000E-01, 0.92344300E-02, 0.54757900E-01, -.65538000E-01, -.12390300E+00, 0.23218000E-01, 0.73121100E-01, 0.15437600E-01, 0.16568200E+00, 0.23009300E-01, -.18135300E-02, 0.26987800E-01, -.40992900E-02, -.17255600E-01, 0.35041300E-03, -.18314900E-01, 0.72913600E-01, -.38781900E-01, 0.33923600E+00, -.27953200E-01, 0.18438000E+00, 0.96607300E-01, -.27115900E-03, -.76188600E-02, -.29283400E-01, -.11556600E-02, 0.36389200E+00, 0.15256300E-01, -.19851600E+00, -.76548500E-01, -.13192500E-01, 0.12008400E+00, 0.74001200E-01, 0.11197000E+00, -.86554600E-02, 0.80157700E+00, -.26375700E+00, 0.14101000E-01, 0.65286700E-01, -.14857000E-01, -.17536200E+00, -.80383500E-01, 0.27748300E+00, -.31324400E-03, -.97482100E-01, -.59517900E-02, -.89193300E-01, -.33575900E-02, 0.24853100E+00, 0.16407400E-01, -.42123300E+00, -.45993300E-01, -.65479900E-01, -.15501600E+00, -.38183900E-01, 0.63207700E-02, 0.28972400E-01, 0.37777300E-01, 0.19100000E-02, 0.19633600E+00, 0.33730400E-01, 0.86802400E-01, 0.82785400E-02, 0.41499000E-01, -.12471200E+00, 0.28929600E-01, 0.84907200E-01, -.50701400E-01, -.11497500E-01, 0.17030800E-02, 0.73239300E-01, 0.11969800E+00, 0.39361800E+00, -.85698800E-01, 0.20409200E+00, -.19913300E-01, -.41731500E-02, 0.36258000E-01, 0.80757600E-02, 0.12273900E-01, -.30879800E+00, 0.73062300E-01, -.14133600E+00, -.26715300E-01, -.39094700E-01, 0.46872300E-01, 0.63279600E-01, -.34478300E-01, 0.10769000E+00, -.13451600E-01, -.38799800E-01, -.46835000E-03, 0.19378400E-01, 0.52235300E+00, -.42360500E-01, -.25022200E-01, 0.64117100E-03, -.41197100E+00, 0.43251200E-01, -.11586000E+00, -.12762300E-02, 0.83272000E-01, -.36723900E-02, 0.14740200E-01, -.39076100E-01, 0.14385900E-01, 0.68237400E-02, -.22973400E-01, 0.17123100E+00, 0.16333400E-01, -.92075300E-02, 0.43691800E-03, -.33072300E-01, -.16786600E-01, -.14986000E+00, 0.19528100E-01, 0.11922100E-01, 0.10661600E-01, 0.54049100E-01, 0.37867000E-01, 0.16330800E-01, -.18477400E-01, -.42950300E-02, 0.35909300E+00, 0.18517600E-01, 0.21543500E-01, 0.12540600E+00, 0.17116400E+00, 0.34315300E-01, 0.34434900E-02, -.95722600E-02, -.55226500E-01, -.31483900E-01, 0.55783000E-02, 0.97832200E-01, -.70212700E-04, 0.21171200E-01, -.85350100E-01, -.24637000E-03, -.45366900E-01, -.13833700E-01, 0.93860000E-02, -.11592200E+00, -.11436900E+00, 0.50266100E-02, -.85135000E-01, 0.80153100E-02, 0.23372800E-01, 0.14761200E+00, -.12083200E+00, 0.29041700E-01, -.77190500E-01, -.19031600E+00, 0.14676400E-02, 0.48939900E-01, -.93364500E-03, -.58360000E-01, -.19713400E-02, 0.18639400E-01, -.47978300E-01, -.83954600E-01, -.50436400E-01, 0.45392900E-01, 0.89406800E-01, 0.19257500E-01, -.22931200E+01, -.12481800E-01, -.59890000E-01, -.27026600E+00, -.10277800E+00, -.82836900E-01, -.23332900E-01, 0.16892500E+00, -.47968700E-02, -.28312200E-02, 0.61192200E-02, 0.30054100E+00, -.44226300E+00, 0.42841300E-01, 0.53660800E+00, 0.36651800E-01, 0.16020500E+00, 0.14733100E+00, 0.31607700E-01, -.47987100E-01, -.17218400E+01, 0.18322900E+01, 0.16885900E+01, 0.63610800E-01, 0.16759900E+00, -.21421200E+00, -.18715900E+01, 0.56575500E-01, -.64480300E-02, 0.24870600E-01, -.29250600E+01, -.19111600E-01, -.28091500E+00, 0.12429000E+00, -.62127600E+00, 0.37031700E-01, -.17383500E+01 },
        { -.72218400E+01, 0.19380600E+00, 0.26738500E+00, 0.65697400E+00, -.12129100E+01, 0.27971100E+01, -.10698900E+01, 0.16938400E+01, -.26709100E+01, 0.26217800E+01, 0.39995600E-01, -.75744300E+00, -.33422100E+00, -.16528200E+00, -.49126500E+00, 0.17868400E+00, -.30277100E+00, -.26976400E+00, -.19857600E+00, 0.15977700E+01, 0.14977800E+01, -.76885000E-01, -.11685300E+02, -.13223100E+01, -.20433700E+00, 0.21997500E+00, -.29578000E+00, 0.37773100E+00, 0.22340100E+01, 0.14469300E+01, 0.63058400E+00, 0.26002400E+01, -.15364800E+00, 0.15044800E+01, -.42140800E+01, -.96561000E+00, -.19158900E+00, -.36343300E+01, 0.30232300E+00, -.15166600E+01, 0.11142600E+01, 0.84311900E+00, 0.69095600E+00, -.21134400E+01, 0.68133500E+00, -.16307100E+00, 0.79713400E-01, 0.46999000E-01, -.84496900E+00, 0.25532000E+00, -.24372600E+01, 0.53164200E+01, -.19494900E+00, 0.30694200E+00, -.16754500E+01, -.65651500E+00, 0.60171500E-01, 0.60786700E+00, 0.66036200E+00, -.21980800E+00, -.88133700E+00, 0.30803800E+00, -.61431500E+00, 0.61964900E+00, 0.18185900E+00, -.36033400E+00, 0.27893000E+01, 0.15703300E-01, 0.30712900E+01, -.38133700E-02, 0.23185800E-01, -.43771100E+00, -.15652700E+00, 0.41667300E+00, 0.89935300E-01, -.96293500E+00, 0.10241300E+00, -.52115900E+00, -.90018800E+00, 0.39295100E+00, 0.61776500E-01, -.24978300E+01, -.55948700E+00, 0.65802400E+00, 0.27763200E+00, 0.20474200E+01, -.11056600E+00, -.17511000E+00, 0.60927700E+00, -.88136300E+00, -.74169800E+00, 0.80353800E-01, 0.14817000E+01, -.28463500E+00, -.40535800E+00, -.18301700E+00, -.17049200E+00, -.50944400E+00, 0.16839100E+01, -.71196800E+00, -.13263400E+00, -.12032200E+01, 0.89440600E+00, 0.72640500E-01, -.30295800E-03, -.26012000E+00, 0.25392700E-01, 0.12671400E+01, 0.14478500E+00, -.50970600E-01, -.57200100E+00, -.17447300E-02, 0.41186300E-01, -.61412200E-03, 0.34759100E+00, -.59751300E-01, 0.83172400E-01, -.14493800E+01, 0.18161300E+00, -.28423600E+00, -.29634100E-01, 0.57814500E-01, -.63098000E-02, 0.23875000E+00, -.23151600E-03, -.24512200E-01, -.44330400E-02, 0.48556200E-01, 0.85233700E-01, 0.49219100E+00, -.58668200E+00, -.26550000E+00, 0.67207700E-01, -.52223200E-01, -.30605400E+00, 0.14302600E-01, -.19300700E-01, -.56805100E-01, -.80815800E+00, 0.62924200E-01, 0.14762500E+00, 0.96830600E-01, 0.20678400E-01, 0.76347000E-01, 0.54457900E-02, 0.35629000E-02, 0.15171800E-02, -.35143400E+00, 0.17281900E+00, -.87981600E+00, -.87187800E-01, 0.76956500E+00, -.53761700E+00, 0.36097100E+00, 0.22993100E+00, -.13286200E+00, -.79213700E-01, -.44726200E-02, -.18671400E+01, -.89086500E-02, 0.47104800E+00, -.37211300E+00, 0.59678600E-02, 0.22603400E+00, -.43096000E-02, -.81292700E-01, 0.14644100E+00, 0.28858700E+00, -.12633900E+00, -.28790200E+00, 0.22951700E+00, -.22311300E+01, -.51313400E+00, 0.13142400E+01, -.20841300E+00, -.15639600E+00, 0.76385000E-01, 0.49469600E-01, 0.15902000E+00, 0.59944500E+00, 0.18202800E+00, 0.52330700E+00, 0.13276400E+00, -.87280400E-01, 0.52437700E-01, -.11579800E+01, -.30047000E-01, -.21751900E+00, 0.17447500E-01, 0.28467500E-01, 0.65190100E-02, -.17800600E-01, -.17373200E+01, 0.19945200E+00, 0.20376400E+00, 0.13513000E-02, 0.12584300E+01, -.68367600E+00, -.87130000E-02, -.59182200E-02, -.43329600E+00, 0.23756000E-01, 0.32312900E-01, 0.82363800E-01, 0.58426500E-01, 0.23243700E+00, 0.78235100E-01, -.29648300E+00, 0.22179200E-01, 0.57638000E-01, 0.15568900E-02, 0.17475200E+00, 0.11200800E+00, 0.12491000E+00, -.15835500E+00, 0.11766300E+00, 0.96817300E-01, -.51599600E+00, -.35543900E+00, -.10775400E+00, -.29380700E-01, 0.15101800E-01, -.18695100E-01, 0.18565300E-02, 0.25419400E+00, 0.30699500E-02, 0.86216500E-01, 0.21871200E+00, 0.13127200E+00, -.19044200E+00, -.45948400E+00, 0.27731300E+00, -.18526100E-01, -.18001600E-01, 0.16945800E-03, 0.38299000E-01, -.36053000E+00, -.65804000E-01, -.40786600E+00, -.86554700E-01, 0.17984100E-02, 0.73214000E-01, 0.15254300E+00, 0.37006600E-01, -.43956700E+00, 0.47148500E-01, 0.12744600E+00, -.31856700E+00, -.90016000E-01, -.22610300E+00, -.11297900E+00, 0.13268700E+00, 0.13378000E+00, 0.18593400E-01, 0.24687300E-01, -.93716100E-01, -.49560400E-01, -.25559500E-01, -.10946800E+01, 0.23547100E-02, 0.97321000E-01, 0.19179600E+00, -.60982400E+00, -.79565100E-01, 0.63839300E+01, 0.44628900E-01, 0.26943400E+00, 0.11718700E+01, 0.10325800E+01, 0.45817200E+00, 0.10921900E+00, -.97258700E+00, 0.96421100E-03, -.58276500E-01, -.41122800E-01, 0.12563300E-01, -.86915300E+00, 0.22746400E-01, 0.24209900E+01, -.98181100E-01, 0.79144400E+00, -.62338800E+01, -.13342500E+00, -.28497200E-01, 0.25684300E+01, -.24503700E+01, -.50439000E+01, -.38661400E+00, 0.69705900E+00, 0.73870900E+01, 0.22382900E+01, 0.20115000E+00, 0.12155200E-01, 0.46015000E+00, 0.78150500E+01, -.27845300E+00, 0.68981400E+01, -.63326300E+01, 0.23951500E+01, -.12174500E+01, 0.28143500E+01 },
        { -.74787000E+01, 0.16775800E+00, 0.28775200E+00, 0.53657300E+00, -.67700500E+00, 0.89108400E+00, -.44997400E+00, 0.25190600E+00, 0.23580700E+00, 0.71755900E+00, 0.10955700E-01, 0.65770400E+00, 0.15895000E-01, -.58381600E-01, -.42230900E-01, 0.37651400E-01, 0.34646400E+00, 0.12618900E+00, -.16095700E+00, 0.10130400E+00, -.24911700E+00, 0.72237500E-01, 0.69671300E+00, -.14382300E+00, 0.10298700E+00, -.67040100E-01, 0.88947300E-01, 0.34399100E+00, 0.17100400E+00, -.91765400E+00, -.18275700E+00, -.21840800E-01, -.68601600E-02, 0.74332300E-01, 0.24598900E+00, -.10153200E-01, -.72400200E-01, -.93521600E+00, 0.16784200E+00, -.54043300E-01, -.16447500E+00, 0.21933700E+00, -.28921000E+00, -.34172700E+00, -.47650900E-01, 0.32460600E-01, -.35832700E-01, 0.95363700E-02, 0.19382800E+00, -.99209900E-02, -.40262800E-01, -.11102800E+01, -.22986100E-01, 0.42309100E-01, -.11515300E+01, 0.10201100E+00, -.49562400E-01, 0.17060400E+00, 0.24950800E+00, -.40837600E-01, -.22880200E-01, -.15061600E+00, 0.13149500E+00, -.26153200E-01, -.82149900E-02, -.16694700E-02, 0.20406200E+00, -.34769200E-04, 0.24625000E+00, 0.20899000E-02, 0.38651200E-01, 0.74988100E-02, -.15076300E-01, -.18238200E-01, -.17633500E-01, 0.96534900E-01, 0.18033500E+00, 0.21032700E+01, -.23860500E+00, 0.79747100E-01, 0.22757100E-01, 0.13495700E+00, 0.18655200E-01, -.17000700E+00, 0.27838100E-01, 0.40227800E+01, 0.12001300E+00, 0.17960200E+00, 0.13206500E+00, 0.73848700E+00, 0.26395000E+00, 0.23541500E-01, -.29216900E+00, -.50904400E-02, 0.79584300E-01, -.51524800E+00, -.24661800E-01, 0.44404900E-01, -.40617700E+00, 0.29521900E+00, 0.91912400E-02, -.18984800E+00, 0.22439700E-01, 0.75409200E-01, 0.32813900E-01, -.40413000E-01, 0.20809200E-02, 0.45631500E+00, 0.14636200E+00, -.61792500E-01, 0.51335500E+00, -.34780000E-01, 0.28192600E-01, -.41449300E-02, -.64350300E-01, 0.57187200E-01, 0.35416000E-01, -.16843200E+01, 0.14722600E-01, 0.10859300E+00, -.56573200E-02, 0.55641600E-02, 0.23188500E-01, 0.23223300E+00, -.98151200E-04, 0.33232900E-01, 0.94952500E-01, 0.48259400E-01, 0.74547400E-01, 0.60879600E+00, -.29820000E+00, 0.26536500E+00, -.10585400E+00, 0.22269900E-01, 0.89423200E+00, -.31138000E+00, -.54885800E-01, 0.13346900E-01, -.28998900E+00, 0.10946900E+00, 0.24008900E+00, -.74553900E-02, 0.27746100E-01, 0.13376700E+00, 0.80756000E-02, -.63109800E-01, 0.70756900E-02, 0.53887400E-01, 0.87302200E-01, -.49466600E+00, -.43620900E-01, -.38465200E-01, 0.10204400E+00, 0.71050900E-01, 0.10325800E+00, -.19860600E-01, -.21089900E-01, -.99665800E-02, -.53480800E+00, 0.25925600E-01, 0.33341000E+00, -.13578300E+00, 0.20955800E-01, -.52323500E-01, 0.99162100E-02, 0.73218000E-01, 0.73320100E-02, -.45560200E-01, -.18758500E-01, 0.78270200E-01, 0.54045700E-01, -.71735200E+00, -.93069000E-01, 0.28031200E+00, -.42091500E-01, -.57353500E-01, 0.16297700E-01, -.65187000E-02, -.62808000E-01, -.31453400E-02, 0.23211300E+00, -.90830100E+00, -.70304600E-01, -.20608500E+00, 0.11547000E+00, -.67013400E+00, -.17136800E-02, 0.16159800E+00, -.10651800E-02, -.59942200E-01, 0.26364100E-02, -.33087600E-01, -.11703400E-01, -.17955200E+00, 0.16114000E+00, -.18347500E-01, 0.21549300E+00, -.14913500E+00, -.11380600E+00, 0.84801100E-03, 0.18655100E+00, -.42840700E-02, -.14142500E-01, 0.17368700E+00, 0.66763100E-01, -.45141800E-01, 0.19167200E-01, 0.82707000E-01, 0.19178400E+00, 0.37761900E-01, -.67156000E-02, 0.22852900E-01, -.44375100E-01, -.13479600E+00, 0.39716200E-01, 0.18501800E-01, 0.17260800E-01, 0.48203400E-01, 0.26939500E-01, -.30994400E-02, -.56307500E-01, 0.17704800E-01, -.32097800E+00, -.22505400E-01, 0.27207600E+00, 0.18598300E+00, -.21974900E+00, 0.49638500E-01, -.63077000E-01, -.14709700E-01, 0.18154600E+00, -.25218700E-01, -.27467400E-02, -.24306100E+00, 0.36662300E-02, -.28755800E-01, 0.30552700E+00, -.70774500E-02, 0.15922700E+00, -.62126100E-01, 0.70097100E-01, 0.14958300E+00, 0.22674700E+00, -.35291600E-01, 0.98656800E-02, -.87516400E-02, -.49052000E-01, 0.21168100E+00, 0.83411700E-01, -.14528700E-01, -.32567300E-02, 0.14112500E+00, 0.87633100E-01, -.13402000E-01, -.16780100E-02, 0.78661000E-01, -.17290600E-02, -.75956900E-01, -.20149900E+00, 0.12086600E+00, -.33439100E-01, 0.12017300E+00, -.12085000E+00, -.24492200E-01, 0.17373200E+01, -.67184200E-03, -.10517400E-01, -.32963400E-01, -.20885100E+00, -.27749300E-01, 0.22951700E-01, 0.54244600E-01, 0.20938300E-03, -.21725000E-01, 0.59049700E-02, -.19436700E+00, 0.31162900E+00, -.87434300E-02, -.10691600E+01, 0.22524400E-01, 0.17087300E+00, -.22810000E-01, -.28003300E+00, -.25483900E-01, 0.17784700E+01, -.19879100E+01, 0.53821600E+00, 0.83382000E-01, 0.74050900E-01, -.52478500E-01, 0.18968900E+01, -.42464900E-01, 0.33633500E+00, -.77545000E-02, 0.15426400E+01, 0.70511700E-02, -.57518300E-01, -.62896900E-01, 0.15016200E+01, -.29801800E+00, 0.18145800E+01 },
        { -.14498400E+01, 0.94023700E-01, 0.60722800E-01, 0.44825000E+00, -.35594900E+00, 0.10745300E+01, -.66084600E+00, 0.85331900E+00, -.15812700E+01, 0.54994400E+00, -.10623900E+00, -.51747400E+00, -.82859700E-01, -.55599600E-01, -.16499100E+00, 0.12174700E+00, -.30539000E+00, -.44763500E+00, -.30700500E+00, 0.23979700E+00, 0.64781900E-01, 0.23305200E-01, -.66024800E+01, -.36147500E+00, -.56034700E-01, 0.28280800E-01, 0.83106100E-01, 0.15181800E+00, 0.35756300E+00, -.21167100E+00, 0.33066300E+00, 0.51718700E+00, -.25105600E-01, -.62697000E-01, -.13312600E+01, 0.13622800E+00, -.56558900E-01, -.29819700E+00, -.92502700E-01, 0.24910900E+00, -.12183800E+00, -.33385900E+00, 0.12192800E+00, 0.37729800E+00, -.44743800E+00, -.73602100E-01, -.75458800E-01, 0.12659400E-01, -.22590700E+00, 0.83705400E-02, -.32998000E+00, 0.73874900E+00, 0.28691200E-01, 0.42874500E-01, 0.22349900E-01, -.48437500E-01, 0.23579600E-01, -.20047900E+00, 0.12581100E+00, -.54295900E-01, -.64283700E-01, 0.11493500E+00, -.27444100E+00, 0.23675900E-01, 0.49970900E-01, -.71830600E-01, 0.15642800E-01, 0.14578600E-02, -.41301500E-01, 0.79337300E-03, 0.18903200E-01, -.10193100E+00, -.68509600E-01, 0.15174400E-01, 0.12163800E+00, 0.14361100E+00, -.20157100E+00, 0.13504200E+00, 0.71999400E-01, -.14337300E+00, 0.95565000E-03, -.17668700E-01, 0.47324700E+00, 0.39964000E-03, 0.82540400E-01, 0.67070300E+00, -.70861900E-01, -.18489300E-01, -.11381000E+00, -.85026300E-01, -.23228000E+00, 0.12027600E-01, 0.49900000E+00, 0.14644600E-02, -.11365600E-01, -.91825800E-02, 0.14541400E+00, 0.46052800E-01, 0.20622500E+00, 0.32585300E-01, -.24033500E-01, -.26062900E+00, 0.94438400E-01, 0.17314300E+00, -.14720700E-02, -.18488000E+00, 0.12099500E-01, 0.20352900E+00, -.57888300E-01, 0.49279200E-02, -.48675000E-03, -.31774100E-02, 0.68145300E-02, 0.30312800E-02, 0.10314100E-01, 0.10401000E+00, -.14598700E-01, 0.96127400E+00, -.16253500E-01, -.87978400E-01, 0.84079800E-02, 0.23236100E-01, 0.71666800E-02, 0.43130600E-01, -.50863100E-03, -.51617700E+00, -.36778900E-01, 0.29813000E+00, 0.11376500E+00, -.10393400E+00, -.97865200E+00, -.94000400E-01, -.98320500E-01, -.11508400E-02, -.16220800E+01, 0.38775500E+00, 0.13996800E-01, -.40541400E-01, -.25972900E-01, 0.96261800E-01, 0.29994600E-01, -.19038200E+00, 0.10864700E-01, 0.58345200E-01, -.61492500E-02, 0.56374300E-01, 0.85507500E-02, -.34122900E+00, -.24112300E-01, 0.28179600E+00, 0.36138800E-01, 0.19803300E+00, -.35230900E+00, 0.38284600E-01, 0.73398100E-02, -.35074400E-01, -.15046900E-01, -.70853500E-02, -.14037100E+00, -.44040100E-01, -.15076000E+00, -.63656300E-02, -.56608200E-01, 0.18286400E+00, -.38787000E-01, -.25841900E-01, 0.63359700E-01, 0.55428800E-01, -.92503300E-02, -.13105900E+00, -.73876100E-01, -.22422700E+00, 0.19079500E-01, -.21815700E+00, 0.36589300E-01, 0.57677400E-02, -.23565100E-01, -.12798500E-01, 0.24636900E-01, 0.33400200E+00, -.10277700E+00, 0.51085500E+00, 0.34969300E-01, -.87965300E-02, -.60866400E-01, -.15282200E-01, 0.55117600E-01, -.10101900E+00, 0.12681300E-01, 0.16048700E-01, 0.96908800E-03, -.31093700E-03, -.39774200E+00, 0.55031000E-01, 0.33546400E-01, 0.63989100E-02, 0.37861300E+00, -.11376200E+00, 0.10541300E+00, -.80665000E-03, -.16741400E+00, 0.58359900E-02, -.96185600E-02, 0.75321500E-01, -.23047600E-02, 0.12578300E-01, 0.26066200E-02, -.13994100E+00, -.25673600E-01, 0.38464700E-01, 0.11202600E-01, 0.22874800E-01, 0.19852600E-01, 0.14775800E+00, -.36553800E-01, -.26235300E-01, 0.82231300E-01, -.83940400E-01, -.74785400E-01, -.24425500E-01, 0.13900100E-01, -.31034900E-02, -.10673800E+00, -.18385100E-02, 0.54414600E-02, -.17591000E+00, -.31180800E-01, -.46639200E-01, -.35649500E-01, 0.28385800E-02, -.68012500E-01, -.21529900E-03, -.27043100E-02, -.12157500E+00, 0.20194900E-02, 0.17033700E-02, 0.51937000E-01, 0.30814700E-03, 0.94456800E-01, -.52121800E-01, -.16400500E-01, 0.77121500E-01, 0.85829200E-01, -.49103800E-02, 0.64683300E-02, -.62228800E-02, -.79835700E-02, -.37727500E-01, 0.71803200E-01, -.56168100E-01, 0.13171200E-02, 0.21365600E+00, 0.80025100E-01, -.25392500E-01, 0.40521600E-02, 0.88924400E-01, 0.29202500E-01, -.74226600E-01, -.64870800E-02, 0.11064600E+00, 0.67068400E-01, -.76251300E-01, -.16135500E+00, -.36985400E-01, 0.21687400E+01, 0.10979900E-01, 0.51113400E-01, 0.26916000E+00, 0.84605300E-01, 0.91874300E-01, 0.34031000E-01, -.17686700E+00, 0.20525400E-01, 0.61558700E-01, -.12596200E-01, -.14884800E+00, 0.30061600E+00, -.48067700E-01, -.87576000E+00, -.88908500E-01, 0.19262600E+00, -.20925800E-01, 0.41502300E+00, 0.11899900E+00, 0.92848500E+00, -.92014900E+00, -.41419200E+01, 0.39431600E-02, -.12784500E+00, 0.11579200E+00, 0.11384400E+01, -.55700700E-01, -.15142100E+00, 0.70179800E-01, 0.31387900E+01, -.99788800E-01, 0.28743300E+00, 0.10267000E+00, -.98377500E+00, 0.18342400E+00, 0.93231100E+00 },
        { 0.73701100E+01, -.23837700E+00, -.28394600E+00, -.61395700E+00, 0.75642400E+00, -.18372000E+01, 0.91033000E+00, -.92235700E+00, 0.12272600E+01, -.12844800E+01, 0.29500500E-01, 0.68097700E+00, 0.56843100E-01, 0.61595100E-01, 0.22434600E+00, -.16494800E+00, 0.18474300E+00, 0.33359300E+00, 0.48547600E+00, -.55324600E+00, -.39837500E+00, 0.87635100E-01, 0.34379600E+01, 0.12560600E+00, -.14336400E-01, -.66087300E-01, -.54062500E-01, -.51802400E+00, -.83241100E+00, 0.14322200E+00, -.29843700E+00, -.73969900E+00, 0.48054400E-01, -.32471800E+00, 0.16743300E+01, 0.95147200E-01, 0.51797000E-01, 0.14762300E+01, -.90907000E-01, 0.27615500E+00, -.19441500E+00, -.14604300E+00, -.11542000E+00, 0.33673400E+00, 0.37822000E-01, 0.86056600E-01, 0.37902300E-01, -.11914000E-01, 0.29291900E+00, -.55046400E-01, 0.51542700E+00, -.60042700E+00, -.40415900E-01, -.11314200E+00, 0.54725200E+00, 0.19836900E+00, -.23784000E-01, -.11155400E-01, -.14673800E+00, 0.86964100E-01, 0.16779900E+00, -.28965200E-01, 0.84148600E-01, -.41859600E-01, -.91377700E-01, 0.15633500E-01, -.21253600E+00, -.60729600E-02, -.62399400E-01, -.22063200E-02, -.25596200E-01, -.20230300E-01, 0.21654000E-02, -.51653800E-01, -.10569500E-01, 0.11415400E+00, 0.13170400E+00, -.41128000E+00, 0.26659100E+00, 0.11384000E+00, -.12845100E-01, -.13540100E+00, -.52275900E+00, 0.22421000E-01, -.21037500E+00, -.27414500E+01, 0.10629900E-01, -.29510500E-01, 0.18075600E+00, -.26076200E-01, 0.73397600E-01, -.20680900E-01, 0.30361900E-01, 0.10229400E+00, -.48870400E-01, 0.23119100E+00, -.29376800E-01, 0.12109800E+00, 0.74998900E-02, -.57666600E-01, -.14023500E-02, 0.17016700E+00, -.86598800E-01, 0.19130800E-01, 0.14381800E-01, 0.67746000E-01, -.14770200E-01, -.97453600E+00, 0.60566600E-01, -.21576700E-01, 0.43254600E+00, -.30503300E-01, 0.65764400E-01, -.25026300E-02, -.23487300E+00, 0.93139200E-01, -.41381500E-01, -.13712600E+00, -.94210400E-01, -.64487500E-01, 0.75667100E-01, -.20401700E-01, -.90794300E-02, -.27788100E+00, 0.25867500E-02, 0.29338800E+00, 0.17928800E-01, -.96719300E-01, -.13030600E+00, -.20844900E+00, -.52745300E+00, 0.45296300E-01, 0.13269000E+00, -.14923900E-01, -.41276400E+00, -.79060100E-01, 0.33545400E-01, 0.72751100E-01, 0.17029200E+00, -.11661300E+00, -.58891500E-01, 0.18203300E+00, 0.71338100E-02, -.94607400E-01, -.77459200E-02, -.26191900E-01, -.63480000E-02, 0.28030800E-01, -.52341800E-01, 0.47054100E-01, 0.10388100E-01, -.13640900E-01, -.21384500E+00, -.87430300E-01, -.60426100E-01, -.12298100E-01, -.13874000E-01, 0.88337600E-02, 0.21162600E+00, 0.89847400E-01, -.35717100E-01, 0.16190700E-01, 0.82681900E-02, 0.42207800E-01, 0.26861300E-02, -.36417000E-02, -.19805900E-02, -.11645700E+00, -.12872900E-02, 0.30860700E-01, 0.62085300E-01, 0.27157900E+00, -.58429000E-01, -.36459000E+00, -.87172000E-02, -.94121300E-02, 0.36005300E-01, -.12509400E-01, -.24449400E-02, 0.10109600E-02, -.14162900E+00, 0.34620000E+00, -.25117300E-01, 0.58622000E-01, 0.75059300E-01, 0.58927600E-01, 0.50726900E-01, -.96311900E-01, 0.87243600E-02, 0.29435400E-01, -.19722400E-02, 0.50999100E-01, 0.26638000E+00, 0.70336500E-01, -.39579000E-01, 0.84004900E-02, -.46487500E+00, 0.45266600E-01, -.27516200E-01, -.31364200E-02, -.36761400E-01, 0.56489500E-02, -.21848600E-01, 0.80904000E-01, -.28511600E-01, 0.46765900E-02, -.56349700E-01, 0.15009400E+00, 0.80299200E-02, 0.38747900E-01, 0.94558400E-02, -.52263400E-01, 0.10724800E-01, -.31065300E-02, 0.27814700E-01, -.34247300E-01, 0.86370400E-01, -.81268700E-01, -.29003700E-01, -.96687200E-02, 0.86789500E-03, -.88907000E-02, 0.17112000E+00, -.58699500E-02, 0.10051900E+00, -.93712000E-01, 0.53347500E-02, 0.21463100E-01, 0.17995100E-01, 0.24195100E-01, -.42432500E-01, -.40973500E-01, -.65224100E-04, 0.52271400E-01, -.57893900E-02, -.46998200E-04, -.30847000E+00, 0.98500700E-02, -.55200000E-01, 0.26935800E-01, 0.20287300E-02, -.86778500E-01, 0.50540300E-01, -.13713500E-01, -.10098100E+00, -.10927500E-02, -.23860900E-01, 0.11095700E+00, -.14849900E+00, 0.13556400E-01, -.13679200E+00, -.20176800E+00, -.10199300E+00, 0.52413100E-01, 0.33648100E-02, -.74355100E-01, -.40730400E-02, 0.98874300E-02, -.99250400E-01, -.56550400E-01, -.40929300E-01, 0.40896100E-01, 0.15270000E+00, 0.17704400E-01, -.20348400E+01, -.79522600E-02, -.36925000E-01, -.18039500E+00, -.24195900E-02, -.51165400E-01, -.32156400E-01, 0.11201800E+00, -.85785600E-02, 0.12755200E-01, 0.21461600E-02, 0.24420400E-01, -.34254700E+00, 0.10109400E+00, 0.19670300E+01, -.26350100E+00, 0.61232400E+00, 0.18412400E+00, -.87665100E-01, 0.11259400E+01, -.35478300E+01, 0.44283600E+01, 0.24333500E+01, 0.76991800E-01, 0.21625500E+00, -.22074000E+00, -.44859000E+01, 0.11651400E+00, 0.22872000E+00, -.47432700E-01, -.97787600E+00, 0.69571000E-01, -.22926800E+00, -.45418900E-01, -.32140400E+00, -.25515700E+00, -.34781900E+01 },
        { 0.41179400E+01, -.72811300E-01, -.15377900E+00, 0.15671000E+01, 0.11892900E+00, -.81959600E+00, -.24304700E-01, 0.42968600E-01, 0.39636500E+00, -.66324900E+00, 0.24714000E-01, 0.32170900E+00, 0.81424000E-02, 0.10761200E-01, 0.71475300E+00, -.12721900E+00, 0.24745000E+00, 0.17365700E+00, 0.20765000E+00, -.13064500E+00, 0.59176300E-01, 0.32579600E-02, 0.13658400E+01, 0.21257600E+00, 0.29250100E-01, 0.42821500E-02, -.35871300E-01, 0.11449000E+00, 0.57966700E-01, 0.18410800E+00, 0.30677900E-01, 0.21159600E+00, 0.29792200E-01, 0.20811300E+00, 0.10776700E+00, -.17135100E+00, 0.32029100E-01, -.35516700E+00, 0.54654200E-01, -.34352900E+00, 0.16623600E+00, 0.39001600E+00, -.21820900E+00, -.36059700E+00, 0.16865300E+00, -.29379200E-01, 0.13181100E-01, -.27446500E-02, -.77648200E-01, 0.42755800E-01, -.55219000E-01, -.39409300E+00, -.30154400E-01, -.68935000E-01, -.24461200E+00, 0.59612200E-01, -.12209900E-01, 0.75167200E-01, 0.28255400E-01, -.56399700E-02, 0.14127600E-01, -.34502600E-01, -.56276100E-01, -.13569600E-01, -.12473500E-02, 0.47477900E-01, -.82155100E-01, 0.12289800E-02, -.25547800E+00, 0.55707800E-03, -.10884700E-01, -.20518600E-02, -.30658000E-01, -.30652900E-01, 0.79076400E-01, 0.54762300E-01, 0.26140200E-01, 0.13263800E+00, -.10335800E+00, -.12256700E+00, 0.11501600E-02, 0.47684900E-01, -.10484600E-01, -.63806700E-01, -.12387200E+00, -.92561500E+00, -.18295300E-01, 0.44203500E-01, 0.16593600E+00, 0.33452000E-01, -.11327100E+00, -.73778500E-02, 0.18357400E+00, 0.58377000E-01, 0.15852500E-01, -.56201700E-01, -.55804500E-01, 0.31708400E-01, -.29335300E+00, 0.26189400E-01, 0.10386800E-01, 0.10821500E+00, 0.63518300E-01, 0.99168400E-01, -.52425900E-01, -.66069800E-01, -.68212200E-01, 0.37120900E-02, -.30692600E-01, -.13556200E-01, 0.21400800E+00, -.13353800E-01, 0.26083000E-01, -.62202000E-02, -.75047500E-01, -.29060300E-01, 0.26034700E-01, -.52075000E+00, -.34425600E-02, 0.11796900E+00, -.54526200E-01, -.48988300E-02, 0.78182700E-02, -.39988800E-02, -.27989900E-02, 0.61040800E-01, 0.38267700E-01, 0.81430300E-01, -.21106900E-01, 0.36661900E+00, 0.28107800E+00, 0.63602400E-01, -.46665100E-01, 0.13359100E-01, 0.27901100E+00, -.22316500E+00, -.21587700E-01, 0.25856400E-01, 0.12976800E+00, -.98458800E-01, 0.51869700E-01, -.91120200E-01, -.72298300E-03, 0.10482300E-01, -.23815500E-02, -.21678100E-02, 0.54675100E-03, 0.33614800E+00, -.19174200E-02, 0.27965500E+00, 0.24218200E-02, 0.44591700E-01, -.10267200E+00, -.19724800E-01, -.97291400E-02, -.11932600E-01, -.32440000E-01, -.12673900E-01, 0.13122400E+00, 0.41489000E-01, 0.42093600E-02, 0.17897300E-01, -.32730500E-01, -.12319900E-01, 0.19869800E-03, -.10759000E+00, -.31016800E-01, -.14526700E-01, 0.44704000E-01, 0.31511000E-01, -.62608900E-01, -.10297700E+00, 0.74632000E-01, 0.11826600E+00, 0.40843100E-02, -.20283900E-03, -.46661800E-02, -.79734400E-02, -.51038600E-01, -.11849400E+00, -.87400300E-01, 0.46404700E+00, -.19773900E-01, 0.75535800E-01, 0.35404700E-02, 0.73915900E-01, 0.89217600E-02, -.23018400E-01, 0.20677000E-02, 0.78070700E-02, -.32810300E-04, 0.11556400E-01, 0.94110700E-01, -.28090700E-01, 0.69147000E-01, 0.18913300E-01, 0.39175500E+00, -.98482800E-01, 0.18505100E-01, -.26461800E-02, -.88496600E-01, 0.96174700E-05, 0.57532800E-01, -.53313500E-01, 0.71026800E-02, -.42715300E-03, 0.76319600E-02, 0.96044400E-02, 0.82782200E-01, 0.18984900E-01, -.46875000E-02, 0.13858200E-01, -.78771700E-02, 0.45947400E-01, -.23895300E-01, -.60550000E-02, -.10326600E+00, -.96957400E-02, 0.72440500E-02, -.62339400E-03, -.35214300E-02, 0.34750500E-02, -.72937400E-01, 0.67316800E-02, -.49570300E-01, -.71044100E-01, 0.12152500E-01, -.31649500E-01, 0.48148700E-02, 0.19256600E-01, 0.44154500E-01, -.89706700E-01, -.11249700E-02, 0.47255100E-01, 0.42504900E-02, -.55210100E-01, 0.85051400E-01, 0.13863300E-01, 0.99448300E-01, 0.30940100E-01, 0.17398300E-01, -.48577000E-01, -.13037300E+00, -.16074800E-01, -.16254500E-01, -.82371200E-02, -.11524000E-01, -.98463600E-01, -.68329500E-02, -.16327600E-02, -.75699900E-02, 0.95558200E-01, -.11436200E-01, -.81733400E-02, -.44792700E-02, 0.32638700E-01, 0.78825500E-02, 0.45911500E-02, 0.18936100E+00, 0.49003100E-02, -.17760000E-01, 0.12904900E-01, 0.43544900E-01, 0.92847200E-02, 0.10401200E+01, 0.66810000E-02, 0.18012800E-01, -.91274500E-01, 0.30270100E+00, -.34416500E-01, -.79653100E-02, 0.82019500E-01, -.21923900E-01, -.13946100E+00, 0.16399300E-01, 0.16127900E+00, 0.11959900E-01, 0.12714800E-01, 0.26498900E+00, -.45474400E-01, 0.81925000E-01, 0.50038800E-02, 0.10535900E+00, 0.75995600E-01, -.16005900E+00, 0.33883000E+00, 0.41008300E+00, -.57790500E-02, 0.42316900E-01, 0.60071100E-02, -.32402400E+00, 0.32010900E-01, 0.17870000E-01, 0.15870200E-01, 0.20148800E-01, -.35761500E-02, -.27320800E-01, -.94091700E-02, 0.70653400E+00, -.46444700E-01, 0.11535400E+00 },
        { -.87453900E+01, 0.26875900E+00, 0.30801100E+00, 0.71757500E+00, -.99391800E+00, 0.21331300E+01, -.95843600E+00, 0.99615300E+00, -.13782500E+01, 0.14439500E+01, -.65104800E-02, -.93803000E+00, -.67332700E-01, -.31418100E-01, -.27689200E+00, 0.18111200E+00, -.82003500E-01, -.22404200E+00, -.33219300E+00, 0.74784700E+00, 0.60972100E+00, -.96418900E-01, -.25346300E+01, -.79256700E-01, 0.22363600E-01, 0.83287600E-01, 0.31129000E-01, 0.90569200E+00, 0.12688400E+01, -.48110600E-01, 0.42083200E+00, 0.12577400E+01, -.60532400E-01, 0.63588500E+00, -.17302900E+01, -.29842500E+00, -.62616400E-01, -.20479500E+01, 0.23089300E+00, -.73970400E+00, 0.44984000E+00, 0.19648200E+00, -.59680100E-02, -.61176400E+00, 0.12868500E+00, -.58506100E-01, 0.17563200E-01, 0.16234100E-01, -.54528600E+00, 0.10606700E+00, -.73711800E+00, 0.36638500E+00, 0.46979800E-02, 0.10631000E+00, -.51910400E+00, -.42576600E+00, 0.68798500E-03, -.56629700E-01, 0.21998400E+00, -.10736800E+00, -.18814100E+00, -.13746700E+00, -.13344600E+00, 0.78919800E-01, 0.23759100E+00, 0.54398100E-01, 0.27858600E+00, 0.60422600E-02, 0.48599400E+00, 0.26460200E-02, 0.13710100E-01, 0.40013100E-01, 0.16170700E-01, 0.11709900E+00, -.92624400E-01, -.33440200E+00, -.48913500E-01, 0.48097500E-01, -.31926400E+00, 0.14806800E+00, 0.30997000E-01, -.33208200E-01, 0.35634600E+00, -.13700500E+00, 0.39169300E+00, 0.57607600E+01, 0.11857600E+00, 0.71936200E-01, -.32284800E+00, 0.21283900E+00, 0.32200400E-01, 0.34580800E-01, -.29630700E+00, -.18006300E+00, 0.24075400E-01, -.41549500E+00, -.67565200E-01, -.28663500E+00, 0.21762000E+00, 0.27042800E-01, 0.77977500E-01, -.25210900E+00, 0.17700200E+00, -.23499400E+00, -.12242000E-01, -.17236500E+00, -.97182500E-02, 0.24022700E+01, -.81897200E-01, -.45178400E-02, -.45231700E+00, 0.70544500E-01, -.12944900E+00, -.19040700E-03, 0.42600100E+00, 0.78197800E-01, 0.70644600E-01, -.15539500E+01, 0.89910300E-01, -.32183800E+00, -.19707600E-01, -.28574300E-03, 0.75154300E-02, 0.44751300E+00, -.48556900E-02, -.19755400E+00, -.47471100E-01, -.13452700E+00, 0.19686300E+00, 0.92643700E+00, 0.17426800E+01, -.18895100E+00, -.21490700E+00, 0.15878100E-01, 0.16474500E+01, -.33642800E+00, -.10705700E+00, -.35757200E-01, -.31610000E+00, -.97936500E-01, 0.41910400E+00, -.32494200E+00, 0.52008500E-02, 0.38678100E+00, 0.39863100E-04, -.68785800E-02, 0.12806300E-01, 0.23163900E+00, 0.15502000E+00, -.81653300E+00, -.12400000E+00, -.20997900E+00, 0.57930700E+00, 0.11064200E+00, -.15891600E-01, 0.17751100E-01, -.36628000E-01, 0.14837000E-02, -.16546400E+00, -.12596200E+00, -.61803500E-01, -.31917800E-01, -.11244300E-01, 0.20841300E-02, 0.62819200E-02, -.93328700E-01, -.11210000E-01, 0.31588700E+00, 0.25263400E-01, -.13391200E+00, -.13082400E+00, -.46715700E+00, 0.11909700E+00, 0.57438000E+00, 0.99233800E-02, 0.79845200E-01, -.25518700E-01, 0.17556800E-01, -.17914400E+00, -.32889100E+00, 0.28236600E+00, -.97564800E+00, 0.19537100E-01, -.44497900E-01, -.64616800E-01, -.10123400E+00, -.74240600E-01, 0.12604400E+00, -.20580900E-01, -.34690400E-01, 0.26996700E-02, -.89121600E-01, -.48988900E+00, -.13609700E+00, -.17676700E-01, -.27031800E-01, 0.38703400E+00, 0.29234900E-02, 0.14525000E-01, 0.60238200E-02, 0.18276800E+00, -.87171400E-02, -.39577100E-01, -.14148000E+00, 0.91036400E-02, 0.98415700E-02, 0.78191300E-01, -.24489100E+00, -.10413100E+00, -.10002000E+00, -.71490000E-02, 0.49075200E-01, -.64953400E-02, -.55294500E-01, -.27323900E-01, 0.42620800E-01, -.44392100E-01, 0.33239500E-01, 0.43753900E-02, 0.37446200E-02, -.54844900E-02, 0.51535600E-02, -.14367700E+00, 0.55829700E-02, -.80363700E-01, 0.93969300E-01, -.17693300E-01, -.75923600E-02, 0.13181300E-01, -.17281100E-01, 0.47411400E-01, 0.43571800E-01, -.86180900E-03, -.44995900E-01, 0.57147400E-02, -.12294900E-01, 0.32309000E+00, -.28617800E-02, 0.51503900E-01, -.15780200E-01, 0.32418700E-02, 0.54596600E-01, -.55177600E-02, 0.13307100E-01, 0.53200900E-01, 0.78649200E-03, 0.22432700E-01, -.14088700E+00, 0.15104800E+00, -.10911800E-01, 0.13273700E+00, 0.10439100E+00, 0.39138500E-01, -.36531200E-01, -.35124400E-02, 0.62360300E-01, 0.14459500E-02, -.31954300E-02, 0.15919500E+00, 0.34916400E-01, 0.27130500E-01, -.24359300E-01, -.90654600E-01, -.92654000E-02, 0.15589500E+01, 0.66853600E-02, 0.26703800E-01, 0.14508800E+00, -.11267100E+00, 0.17609600E-01, 0.33020500E-01, -.73619900E-01, -.42178800E-02, -.40942800E-01, 0.32569400E-02, 0.62917600E-01, 0.34159600E+00, -.98657700E-01, -.15950000E+01, 0.20642000E+00, -.58367500E+00, -.16768400E+00, -.96326000E-01, 0.87027400E+00, -.36970200E+00, -.12135500E+01, 0.64077900E+01, -.48553800E-01, 0.15450200E+00, -.11720900E+00, -.30187100E+00, 0.75755900E-01, 0.25536800E+00, -.90291300E-01, -.49801700E+01, 0.15245200E+00, -.44051000E+00, -.17344500E+00, 0.25786100E+01, -.31848000E+00, 0.86790700E-01 },
        { 0.92717000E+01, -.21943800E+00, -.33301900E+00, -.54845100E+00, 0.86601600E+00, -.11630700E+01, 0.22950100E-01, -.11180400E+00, -.16936400E+00, -.92064000E+00, -.14902700E-02, 0.51250900E-01, -.61355900E-01, 0.19851400E-01, 0.63083100E-01, -.90059300E-01, -.15755100E+00, -.16221200E+00, -.56309100E-01, -.36977400E+00, 0.16073300E+00, -.43565700E-02, -.13257100E+01, -.47413200E-01, -.18535100E+00, 0.21757400E-01, -.14088200E+00, -.10278600E+01, -.68076000E+00, 0.67956400E+00, -.24090800E+00, -.28987500E+00, 0.25984100E-01, -.18591700E+00, -.50727200E+00, 0.12193200E-01, 0.24983800E-01, 0.11764400E+01, -.35108300E+00, 0.30797000E+00, 0.23435200E+00, -.30984300E+00, 0.26152800E+00, 0.61566500E+00, 0.10236900E+00, -.61459200E-01, 0.32412900E-01, -.79164300E-02, -.23185100E+00, 0.10428300E-01, 0.34292300E+00, 0.24963100E+01, -.10217500E+00, -.31181300E-01, 0.14209700E+01, 0.55441000E-01, 0.44347800E-01, -.19808600E+00, -.25660200E+00, 0.50982500E-01, 0.17861800E+00, 0.11129000E+00, -.13988000E+00, 0.57438400E-01, 0.31512500E+00, 0.56918600E-01, -.26543500E+00, 0.46892400E-02, 0.82532000E-01, -.23916200E-02, -.36923600E-01, -.15666900E+00, -.80747100E-02, 0.27889000E-01, -.22738300E+00, -.34726400E+00, -.32947700E+00, -.42000900E+01, 0.31715300E+00, -.24822100E+00, -.28472000E-01, -.70083900E-01, 0.25527400E+00, 0.13355200E+00, 0.14551600E-01, -.15594100E+01, -.46810100E-01, -.14971700E+00, -.24409700E+00, -.69307500E+00, -.14402300E+00, -.46676300E-01, -.10482200E+00, -.67191500E-01, -.19180200E-01, 0.44487400E+00, 0.89077100E-01, -.13305400E+00, 0.19044300E+00, -.13009500E+00, -.17897200E-01, 0.11207500E+00, -.54644500E-01, -.15854700E+00, 0.77795800E-02, 0.97611000E-01, 0.33592500E-01, -.71653900E+00, -.15922200E+00, 0.70980100E-01, -.13632700E+01, 0.58535000E-01, -.30511400E-01, 0.94227000E-02, 0.27510100E+00, -.83534700E-01, -.51357300E-01, 0.12234400E+01, 0.77549200E-01, -.20679600E+00, 0.85524000E-01, 0.80375800E-01, -.31652200E-01, -.10858000E+00, 0.14740400E-01, 0.22757200E+00, -.17949300E+00, -.29106300E+00, 0.77365500E-01, -.40731600E+00, 0.14219100E+01, -.54070500E+00, 0.72542000E-01, -.48136800E-01, -.43030200E+00, 0.91304800E+00, 0.44215700E-01, -.15094000E+00, -.55918000E-02, 0.84417400E-02, -.35818200E+00, 0.35215800E+00, -.55044100E-01, -.20654200E+00, -.13109600E-01, 0.44564400E-01, -.28441700E-01, 0.11628400E+00, -.10291400E+00, 0.28296800E+00, -.40150700E-01, 0.18062600E-02, 0.18259400E+00, -.11626200E+00, -.10584700E+00, 0.55972800E-01, 0.34642700E-01, 0.21456600E-01, 0.74542700E+00, -.14254200E+00, -.31233000E+00, 0.17995900E+00, -.30719600E-01, 0.11312200E+00, -.63801000E-02, 0.87968100E-01, -.42572400E-01, 0.11927200E+00, 0.26762900E-01, -.10174200E+00, -.53068300E-01, 0.10796900E+01, 0.78549500E-01, -.63405800E+00, 0.19415100E+00, 0.12429900E+00, -.18539800E-01, -.20631600E-01, 0.96969800E-01, 0.43115000E-01, -.39634100E+00, 0.14584000E+01, 0.13947300E-02, 0.28640000E+00, -.16596900E+00, 0.71244100E+00, 0.14402900E+00, -.17346000E+00, 0.85003400E-02, 0.45212800E-01, -.59857700E-02, 0.51989300E-01, 0.33336500E+00, -.16220200E-01, -.23917800E+00, -.55885400E-01, -.10251800E+01, 0.16069000E+00, 0.13884700E+00, 0.87034700E-02, 0.59035500E-01, 0.35004700E-02, -.45978500E-01, -.13639400E+00, -.92366300E-01, 0.44952900E-01, -.58590600E-01, 0.92236300E-01, -.15436100E+00, -.48405900E-01, -.32904600E-02, -.86443500E-01, 0.35105700E-01, 0.98455800E-01, 0.20607300E-01, 0.19771600E-02, -.34029100E-01, -.12402900E-01, 0.42315600E-01, 0.17000700E-01, 0.35085100E-01, -.12762100E-01, 0.53579000E+00, 0.14543100E-01, -.24932500E+00, -.13183000E+00, 0.37236000E+00, 0.76550500E-02, -.60487600E-01, -.50997500E-01, -.48442100E+00, 0.51843900E-01, 0.15262400E-01, 0.33381500E+00, 0.13610700E-01, 0.85427000E-01, -.22111700E+00, -.24055100E-01, -.16516300E+00, 0.11954100E+00, -.25256100E-02, -.52602000E-01, 0.52711200E-01, 0.13991300E-01, -.41599800E-01, 0.94951100E-02, 0.13486500E-01, -.15720200E+00, -.76824100E-01, 0.90096600E-01, -.51273400E-01, -.41461200E+00, -.25836600E+00, 0.71878100E-01, 0.11350500E-01, -.15405000E+00, -.12916000E-01, 0.35721300E-01, -.41213500E+00, -.29905900E+00, 0.33630000E-01, -.16853000E+00, -.31247800E+00, -.12403600E+00, -.33189700E+01, -.91842000E-03, -.12584100E-01, 0.14182200E+00, -.15054100E+00, 0.24043600E-01, 0.59985700E-01, -.45625000E-01, -.31211700E-01, -.70541200E-01, -.34959600E-01, 0.24926000E+00, -.69255600E+00, 0.20524000E-01, 0.10901000E+01, -.57225800E-01, 0.28437900E+00, 0.13739200E+00, -.92832700E+00, 0.56135700E-01, -.17854200E+00, 0.63970100E+00, 0.97529700E-01, 0.17472000E+00, -.13289700E+00, -.24118700E+00, -.63755300E-01, -.26895300E-01, 0.59782600E-01, -.14983900E-01, 0.19679300E+01, -.50840700E-02, -.60355800E-01, -.63442300E-01, 0.21576100E+00, 0.53600200E+00, -.20736400E-01 },
        { -.21689400E-01, -.56543900E-01, -.18586900E-01, -.19153500E+00, 0.21598000E+00, -.12491800E+01, 0.56624300E+00, -.10197800E+01, 0.17402700E+01, -.54435600E+00, 0.19036900E-01, 0.13093900E+01, 0.22189900E+00, 0.11673700E+00, 0.32411800E+00, -.18963200E+00, 0.45712500E+00, 0.38856100E+00, 0.32412600E+00, -.33449800E+00, -.38644700E+00, 0.11284100E+00, 0.76116800E+01, 0.39658500E+00, 0.85746300E-01, -.21207300E+00, -.61823400E-01, -.98820300E-01, -.26019600E+00, -.49565900E+00, -.28929700E+00, -.89329100E-01, 0.46423300E-01, -.26298900E+00, 0.17428900E+01, -.24723400E-01, -.22691200E-02, 0.98006300E-01, 0.14929900E+00, -.13679500E+00, 0.38062300E-01, 0.13742300E+00, 0.80091800E-02, -.87117600E+00, 0.68337800E+00, 0.59816000E-01, 0.32569100E+00, -.78551400E-02, 0.15679800E+00, 0.18295100E-01, 0.42213700E+00, -.21709300E+01, 0.13602300E+00, 0.46826100E+00, 0.18722100E+00, -.31190600E+00, -.37577200E-01, 0.35173900E+00, -.13267900E+00, 0.47947700E-01, -.12627800E+00, -.13636300E+00, 0.45453000E+00, 0.38912400E-01, -.25270300E+00, 0.94532000E-01, 0.72298500E-02, -.92383600E-02, 0.77890500E+00, -.25937700E-02, -.79945700E-01, 0.28690900E-01, 0.92050900E-01, 0.40573600E-01, -.85098600E+00, -.33156700E+00, 0.32366000E+00, 0.14710700E+01, -.26646800E+00, 0.37999500E+00, 0.87164700E-02, -.32981600E+00, -.62609400E+00, -.14923300E+00, 0.13242400E+00, 0.26204900E+01, 0.30921700E+00, 0.12880900E+00, 0.27474900E+00, 0.67772000E+00, 0.30234100E-01, -.78399000E-02, 0.92851400E-01, -.66912000E-01, 0.17000600E-02, -.11303900E+00, 0.67057600E-01, -.31627000E-01, 0.35993400E+00, -.32891600E-01, 0.47026700E-01, -.23924500E+00, -.37265800E-01, -.30805100E+00, 0.84921400E-01, 0.46904600E-01, 0.55059400E-01, 0.16280600E+01, -.18044300E-01, 0.24128800E-01, -.20480400E+00, 0.59830300E-01, -.19999500E-01, 0.27283500E-02, 0.26563100E+00, 0.82830300E-01, 0.11319300E-01, -.77142000E+00, 0.10480500E+00, 0.15720900E+00, 0.11931400E+00, -.28687400E-01, -.90493700E-02, 0.11483500E+00, 0.36591900E-02, 0.17077000E+00, -.61588500E-01, -.59894900E+00, 0.10828000E+00, -.37731000E+00, 0.26606000E+01, 0.32493700E-02, -.15454200E+00, 0.82872400E-02, 0.15406400E+01, 0.60063200E+00, -.26673400E-01, -.92963500E-01, 0.78456700E-01, -.25376800E+00, -.12467900E-01, 0.28685800E+00, -.36142000E-01, -.34700300E-01, 0.14280500E-01, -.11454900E+00, -.15285100E-01, 0.33771000E+00, 0.78488900E-03, -.63254700E+00, -.13498600E+00, -.28980100E+00, 0.61285200E+00, 0.81839800E-02, 0.57837300E-01, 0.16671300E+00, 0.99623800E-01, -.10565500E-01, 0.16525400E+00, -.35487200E-02, 0.43459600E+00, 0.57634600E-02, 0.15695700E+00, -.48539600E+00, 0.12145300E+00, 0.18504700E+00, -.24506000E+00, -.13904500E+00, 0.45817100E-01, 0.13772100E+00, -.38273900E-01, 0.39064700E+00, 0.90579600E-01, 0.38556200E-01, 0.10673200E+00, 0.96471100E-01, 0.11433700E-01, -.98366000E-02, -.18106000E+00, -.64160100E+00, 0.27746300E-01, 0.40510700E+00, -.89401600E-01, 0.82148700E-01, 0.83610900E-01, 0.16717500E+00, -.42094300E-01, 0.13477800E+00, -.18374700E-01, -.66335900E-01, -.18111700E-02, -.29588200E-01, 0.48377100E+00, -.31423300E+00, -.21423700E+00, -.22491500E-01, -.10433100E+01, 0.13392300E+00, -.10062300E+00, -.99759300E-02, 0.17729900E+00, -.90586500E-02, 0.13409800E+00, -.14955000E+00, -.37519300E-01, -.20850800E-01, -.38123000E-02, 0.30775900E+00, 0.11187100E+00, -.29968700E-01, -.16602300E-01, -.10228200E-02, -.35409200E-01, -.86114000E-01, 0.21048300E-01, 0.50788900E-01, -.35033500E-01, 0.12545000E+00, 0.96672800E-01, 0.28752500E-01, -.21549300E-01, 0.10294600E-01, 0.22146100E+00, 0.20886100E-01, 0.11391700E+00, 0.25157400E+00, 0.19908300E+00, 0.77864900E-01, -.58858900E-01, -.39380200E-01, -.12764700E+00, -.61717400E-02, 0.10165800E-01, 0.15572500E+00, -.36897400E-02, 0.47744400E-01, -.69122100E-01, -.75449900E-02, -.76273600E-01, 0.18813200E-01, 0.37067500E-01, -.10523200E+00, -.95210600E-01, -.28395500E-02, -.82652300E-01, 0.11831300E-01, 0.51985800E-02, 0.41730800E-01, -.16866600E+00, -.20960000E-02, -.76867000E-01, -.27830200E+00, -.45299800E-01, 0.57875300E-01, -.36814300E-02, -.34574000E-01, -.11928400E-01, 0.13670400E-01, -.13612700E+00, -.20769900E-01, -.29128500E-01, 0.22626500E-01, -.65376500E-01, -.10564900E-01, -.11644800E+01, -.73655100E-02, -.34990000E-01, -.17238200E+00, -.46590100E-01, -.48334700E-01, -.11731400E-01, 0.10379000E+00, -.21952000E-04, 0.21266600E-02, 0.11661600E-02, 0.61735800E+00, -.17730800E+00, 0.12370200E-01, -.11903300E+00, 0.13819800E+00, 0.37704200E+00, -.87688500E-01, -.12096000E+00, -.62573900E+00, 0.30637800E+00, -.12738700E+01, -.38899400E+00, -.49358000E+00, 0.63949300E+00, 0.10350500E-01, 0.85189200E-01, 0.49740100E-01, 0.10430400E+00, 0.40113000E-01, -.34334000E+01, 0.20988200E-01, -.32102500E-01, -.89478600E-02, -.26174700E+00, 0.38462100E-01, 0.47825300E-01 },
        { 0.39352000E+01, -.11660700E+00, -.13126600E+00, -.12421900E+00, 0.60867200E+00, -.13587100E+01, 0.53059900E+00, -.82955500E+00, 0.12875800E+01, -.12608200E+01, -.14471600E-01, 0.33316900E+00, 0.38125000E-01, 0.52852700E-01, 0.19291600E+00, -.10355700E+00, 0.57999500E-01, -.80996300E-02, 0.42650500E+00, -.66972400E+00, -.73443100E+00, 0.86010900E-01, 0.30205600E+01, 0.91747600E-01, -.77768400E-02, -.62717100E-01, 0.17756400E+00, -.16016500E+00, -.14638500E+01, -.65690500E+00, -.53565200E+00, -.11105300E+01, 0.80426400E-01, -.43336300E+00, 0.30207200E+01, 0.32856100E+00, 0.75179100E-01, 0.18209200E+01, -.30465200E+00, 0.80005000E+00, -.19284400E+00, -.75965900E+00, -.21397700E+00, 0.12166400E+01, -.15060900E+00, 0.65590900E-01, -.39270300E-01, -.23212100E-01, 0.17422800E+00, -.62202000E-01, 0.11700000E+01, -.17873200E+01, -.38466200E-01, -.15082000E+00, 0.23764100E+01, 0.12136000E+00, -.38325500E-02, -.70248800E+00, -.35718800E+00, 0.10639200E+00, 0.42107200E+00, 0.42576400E-01, 0.13949600E-01, -.18043800E+00, -.59426000E-02, 0.74405200E-01, -.36123300E+00, -.51032200E-02, -.27255000E+00, -.17138200E-02, -.53175200E-02, 0.63164500E-01, 0.10057600E+00, -.18268400E+00, -.14756400E+00, -.32505700E+00, -.80700700E-01, -.34608100E+01, 0.62405300E+00, -.54816900E+00, -.53474800E-01, 0.91309600E+00, -.60146000E+00, 0.20531300E+00, -.74691100E+00, 0.68838500E+00, 0.13519200E+00, -.82468500E-02, 0.20288700E-01, -.39528500E-01, 0.41834800E+00, -.58154800E-01, -.12432900E+01, 0.60497400E-01, 0.32282700E+00, -.88798800E-01, -.53014700E-01, 0.77324200E-01, -.65708100E+00, 0.12599200E+00, 0.10047300E+00, 0.38502500E+00, -.27395500E+00, -.16767800E+00, 0.30353200E-01, -.24522400E-01, 0.29466700E-01, 0.10984200E+01, -.21665500E-01, -.34412700E-01, -.84362500E+00, 0.29678400E-01, -.16144400E+00, 0.12800900E-02, 0.33138500E+00, -.72337800E-02, 0.19848500E-01, -.10102000E+01, 0.22463500E+00, 0.14586700E+00, 0.82313300E-01, 0.40456000E-01, 0.12459200E-01, 0.35046100E+00, 0.15353500E-01, 0.19863200E+00, -.35979300E-01, -.16596500E+00, 0.17128400E+00, 0.63697500E+00, 0.24392700E+01, -.23488100E+00, -.40974900E+00, -.16036600E-01, 0.41056600E+00, 0.34567400E+00, 0.23601400E-01, -.57971000E-01, 0.62139600E+00, -.24183300E+00, -.58208600E+00, 0.29910800E+00, -.28248900E-01, -.62591700E+00, -.28988700E-01, 0.17240900E+00, -.24475300E-01, 0.33437300E+00, 0.10297400E-01, 0.39306700E+00, -.28062000E+00, 0.97053400E+00, -.86765900E+00, -.15633100E+00, -.22384300E+00, -.51960900E-01, -.30223900E-01, 0.97629500E-02, 0.10209000E+01, 0.15828900E+00, -.40880100E+00, 0.16878400E+00, -.22511100E-02, 0.29946900E-01, 0.29490500E-01, -.10481800E+00, 0.55919800E-02, 0.14280600E+00, 0.20786900E-01, 0.35776500E-01, 0.20412400E+00, 0.63390500E+00, -.23037900E-01, -.19274200E+00, 0.23188600E-01, 0.58719200E-01, 0.47771600E-01, 0.25805800E-02, 0.23326600E+00, -.18766400E+00, -.20548900E+00, 0.93900000E+00, 0.11021400E+00, 0.81933500E-01, -.12530300E+00, 0.52889900E+00, 0.10233100E+00, 0.77272100E-01, 0.10829300E-01, 0.34231100E-01, -.31508600E-02, 0.58925100E-01, 0.75438300E+00, 0.30247500E+00, 0.19993700E-02, 0.12974500E-01, -.49582400E+00, 0.16235700E+00, -.40280000E-02, 0.38794400E-02, 0.22197200E+00, -.87480900E-02, 0.90794800E-01, -.61393600E-01, -.68937000E-02, -.11660100E+00, -.21592600E-01, 0.39606800E+00, 0.19570900E+00, 0.34270300E-01, -.27126600E-01, 0.40370200E-01, -.26280700E-01, 0.94426400E-02, -.10981400E-01, 0.10020600E+00, -.10745500E+00, 0.15584200E+00, 0.63563600E-01, 0.12289500E-01, -.63703500E-02, 0.15282300E-01, -.61499400E+00, -.19377700E-01, -.11715100E+00, 0.80021000E+00, -.12392800E+00, -.11083100E-01, 0.60622900E-01, 0.87687200E-01, 0.51173200E+00, -.40298800E-01, 0.35089900E-01, 0.90962100E-01, -.12468800E-02, -.11319400E+00, 0.11468200E+00, -.53339300E-01, -.20955700E+00, -.17892100E+00, -.16704800E+00, 0.24850700E+00, 0.10703200E+00, 0.15039100E-01, 0.12667500E+00, -.11954400E-02, 0.24702100E-01, 0.10739000E+00, 0.18262500E+00, 0.20124500E-01, 0.73115200E-01, 0.19100000E+00, 0.18608300E+00, -.48693100E-01, 0.20007100E-01, 0.28909800E-01, -.23726100E-02, -.53215500E-01, -.51223300E+00, 0.22948600E-03, 0.35487900E-01, 0.14237600E+00, -.49817300E+00, -.41466500E-01, -.37824900E-01, 0.18474600E-01, -.22623100E-01, 0.15190500E+00, -.22247700E+00, 0.12632600E+00, 0.52216200E-01, -.22585800E+00, 0.11610400E+00, 0.31401500E+00, -.16659000E-01, -.49846300E+00, -.40112900E+00, 0.55055400E-01, -.10117800E+00, 0.99490900E-01, 0.21930700E+00, 0.23438100E+00, 0.41843700E+00, -.25849800E+00, -.13126700E+00, -.28123000E+00, 0.20529200E+00, 0.32192600E+00, -.14247000E+00, -.12227100E+01, 0.11802900E+00, -.30901800E-01, -.23967600E+00, -.83143400E-01, -.12957500E+01, 0.62589600E-01, -.60398700E-01, 0.11056700E+00, -.44240600E+00, 0.24162700E+00, -.52564000E-01 },
        { 0.39150100E+02, -.11318200E+01, -.13570400E+01, 0.24032200E+01, 0.43395800E+01, -.79125000E+01, 0.39763400E+01, -.27405400E+01, 0.56067000E+00, -.58512200E+01, 0.47472700E+00, 0.69159000E+01, -.10154600E+01, 0.96239700E-02, 0.11394200E+01, -.18977800E+01, 0.28944300E+01, 0.11398000E+01, 0.22534200E+01, -.21415900E+01, 0.14441900E+01, -.37305600E-02, 0.14614300E+02, 0.25221800E+00, 0.21632500E+00, -.34690600E+00, -.20174600E+00, -.29767600E+01, -.21604200E+01, 0.12512600E+00, -.24365400E+01, -.34845400E+01, 0.19335300E+00, 0.14615800E+01, -.73305700E+01, -.90487700E+00, 0.12181300E+00, -.66488100E+01, -.20201400E+00, -.13406800E+01, 0.13376600E+01, 0.35311000E+01, -.53386000E+00, -.21620300E+01, 0.10404300E+00, -.77486100E+00, -.40253600E+00, -.97074800E-03, 0.78737800E+00, 0.31824600E+00, -.98113300E+00, -.73172100E+01, -.25555400E-01, 0.37525400E+00, -.97393400E+01, 0.20729000E+01, -.15547800E-01, 0.24437000E+01, 0.11331100E+01, -.56690800E+00, 0.41172200E+00, 0.48338700E+00, 0.13566100E+01, -.19751600E+00, 0.13459800E+01, -.42734900E-01, 0.45869200E+01, -.74008200E-01, 0.23370800E+01, 0.18072400E-01, -.28218200E+00, 0.61273500E+00, -.77429700E+00, 0.45004000E-01, 0.12764000E+01, 0.12672300E+01, -.22410600E+01, 0.56890200E+01, 0.11636000E-01, -.22505400E+01, -.12826500E+00, -.99127900E+00, -.15583800E+00, 0.24057900E+01, -.32519400E+01, 0.43878000E+01, -.27882800E+00, -.51884100E+00, 0.15703300E+01, -.81343600E+00, 0.14604100E+00, -.17706400E-01, 0.33814600E+00, 0.41236800E+00, -.23085200E+00, -.21644300E+01, 0.88991400E+00, 0.26327300E+01, 0.28562600E+01, 0.11095400E+01, -.59159600E-01, -.19228900E+01, -.12605500E+00, 0.17049700E+01, -.92014000E+00, -.30149700E+01, 0.11422100E+00, 0.16349500E+02, -.14125600E+01, 0.71034400E+00, 0.12135500E+02, 0.33195800E-01, 0.44517400E+00, -.40458700E-01, -.27227400E+00, 0.12137900E+00, -.11951100E+00, 0.20328800E+01, -.35055100E+00, 0.81123600E-01, 0.45715300E-01, 0.10492900E+00, -.13643700E+00, -.92825700E+00, -.34054200E-01, 0.51194400E+00, -.15855100E+00, 0.17979700E+00, 0.37863000E+00, -.15502400E+01, -.13852600E+01, -.61410500E-01, 0.37867200E+00, 0.81079800E-01, -.36302100E+01, 0.10994800E+01, 0.19034800E-01, -.14126800E+00, 0.42919600E+00, 0.10088700E+00, -.47022300E+00, -.22908900E+00, 0.13320300E+00, -.67179600E+00, 0.29164200E-01, 0.17914900E-01, -.40536200E-01, -.57585500E-01, -.15941000E+00, 0.39485700E+01, 0.20417200E+00, 0.35443800E+00, -.12463800E+01, -.13873100E+00, 0.30141500E+00, 0.18103600E+00, 0.45800200E+00, -.20005100E+00, 0.36461400E+01, -.18621200E+00, -.13149300E+01, 0.14516500E+00, -.55802000E+00, -.17231800E+01, -.74286100E+00, 0.16637000E+01, 0.39794200E+00, -.74621600E+00, -.13136700E+00, 0.17932400E-01, -.88630000E+00, -.14709400E+01, 0.58246900E+00, -.57626900E+01, 0.55468500E-01, 0.59277100E-01, 0.95799200E-01, 0.12756800E+00, -.14321700E+00, 0.11151100E+01, 0.10704900E+01, -.83871400E+01, 0.19524400E+00, -.10711700E+01, -.43480500E-01, -.10073100E+01, 0.71733100E+00, 0.10553300E-01, 0.40101900E-01, 0.22081300E-01, 0.72772600E-02, -.12268200E+00, 0.13561800E+01, -.11178900E+00, 0.24064100E+00, -.75330700E-01, -.65254100E+01, 0.22764300E+01, -.27804700E-01, -.47084400E-01, -.20835600E+01, 0.44683600E-01, 0.13261100E+00, 0.44790700E-01, -.66078200E-01, 0.31735500E+00, -.18537200E+00, -.30708100E-01, -.29820500E+00, 0.21794800E+00, 0.72612300E-01, -.98926700E-01, 0.33159300E-01, -.17286200E+00, -.13254600E+00, -.38739900E+00, -.13152900E+00, -.62439500E+00, -.41668300E+00, -.84497500E-01, -.75184000E-03, 0.18660900E-01, -.43719800E+00, -.19322700E-01, 0.51587000E+00, -.68658100E+00, -.58816800E+00, 0.22207900E-01, 0.80552300E-01, 0.97233500E-01, 0.12978500E+00, -.93422800E-01, -.40663700E-01, -.13974600E+01, -.14832800E-01, 0.19104700E-01, 0.74714600E+00, 0.29105400E+00, 0.13507700E+01, -.31405500E+00, 0.21582600E+00, -.61579300E+00, -.54218000E+00, 0.54213100E-01, -.70461800E+00, -.29500400E+00, -.11789800E+00, 0.10766500E+01, -.12699100E+01, 0.18207900E-01, -.38384600E-01, -.25874600E+01, -.12222300E+01, 0.22999700E+00, 0.13949500E-02, -.16610900E+00, -.79540900E-01, 0.27498700E+00, 0.10309200E+01, 0.52897000E+00, -.19205800E+00, 0.47903700E+00, 0.14672600E+01, 0.28216800E+00, -.13518700E+02, -.33716700E-01, -.30315500E+00, -.29426500E+01, 0.41330700E+01, -.17373400E+00, -.79290100E+00, 0.16678800E+01, -.66771700E+00, 0.33078100E+00, -.58032200E-01, -.46383000E+00, -.46222900E+00, 0.23662900E-01, -.27293000E+01, 0.21907100E+00, 0.82956700E+00, -.12664100E+00, 0.25738300E+01, -.26780100E+01, -.15074900E+01, -.44589000E+01, -.10176900E+01, -.60485600E+00, -.15076900E+00, -.57389000E+00, -.26306000E+01, 0.31385200E+00, -.81628700E+00, 0.31358300E+00, 0.12963000E+01, -.26218600E+00, 0.74942800E-01, -.10247700E+00, 0.63847300E+01, 0.93608500E+00, 0.13087300E+01 },
        { 0.50108600E+01, -.17533900E+00, -.16013800E+00, -.22289800E+00, 0.45564100E+00, -.12311600E+01, 0.46834900E+00, -.52919100E+00, 0.17119200E+01, -.82651100E+00, 0.50356700E-01, 0.13297700E+00, 0.29491900E-01, 0.67173900E-01, 0.16439200E+00, -.99970900E-01, 0.43498000E+00, 0.59739800E+00, 0.54902900E+00, -.33310200E+00, 0.14359100E-01, -.41009500E-01, 0.59974700E+01, 0.63807400E+00, 0.94275200E-01, -.53886300E-01, -.62683000E-01, -.20328900E-01, 0.27482800E-01, 0.39380500E+00, 0.72394200E-01, 0.37104600E-01, 0.21716000E-01, -.16732200E+00, 0.98554600E+00, -.51706000E-01, 0.88567500E-01, 0.52810700E+00, 0.12018700E+00, -.32621900E+00, 0.67860400E-01, 0.29010700E-01, -.13295000E+00, -.20651500E+00, 0.17283600E+00, 0.11900800E+00, 0.12645000E+00, -.12201100E-01, 0.56738600E-01, -.12157700E-01, -.13382400E+00, -.12308600E+01, 0.30133600E-01, -.15771500E+00, 0.34445500E+00, -.14880600E+00, -.32262900E-01, -.11646200E+00, -.15487400E+00, 0.76351400E-01, 0.88055900E-01, -.22715300E+00, -.65993200E-01, 0.48402300E-01, -.22396200E-01, 0.20855600E-01, -.39161400E-01, -.17823200E-02, 0.28006900E+00, -.20548000E-02, -.33936900E-01, 0.11454800E+00, 0.12648600E+00, 0.12499200E-01, -.19014700E+00, 0.30287300E-01, 0.24642500E+00, 0.25355900E+00, -.19733600E-01, 0.57001700E+00, 0.15888300E-01, -.15243000E+00, -.26215100E+00, -.14893300E+00, 0.43201000E+00, -.11270100E+01, 0.15914800E+00, 0.45204600E-01, -.14990000E-01, 0.32715600E+00, 0.27215600E-01, -.77787500E-03, 0.30292000E+00, 0.19663100E-01, -.48592300E-01, 0.15465800E+00, -.46625200E-02, -.67723600E-02, 0.22684600E+00, -.42021500E-01, 0.36179000E-01, -.12512400E+00, -.34790200E-01, -.91602600E-01, 0.25533600E-01, 0.12162200E+00, 0.16347900E-01, 0.10094800E+01, 0.17389700E-01, 0.20069100E-02, 0.93741300E+00, 0.12061300E-01, 0.56081800E-01, -.64341600E-03, -.10884400E+00, 0.26018800E+00, 0.16040100E-02, 0.26417100E+00, -.85676000E-01, -.30099800E+00, 0.21850300E-01, -.24122100E-01, -.90833200E-03, -.78096100E-01, -.86305400E-02, 0.74617700E-01, 0.11335900E-01, -.13777300E+00, -.94176100E-01, 0.16361000E+00, -.72077900E-01, 0.12125400E+00, 0.19197900E+00, 0.32182000E-01, 0.39808200E+00, -.80876700E+00, 0.14365100E-02, 0.15888800E+00, 0.23128700E+00, 0.44542400E-01, 0.15698700E+00, -.15785000E+00, 0.37146800E-01, 0.13131600E-01, 0.13656900E-01, 0.14697100E-01, 0.10667600E-01, -.10953200E+00, -.25017400E-01, -.21258100E-01, 0.40378600E-01, -.33366600E+00, 0.54340100E+00, -.41598100E-01, -.19274700E-01, 0.22915700E-01, 0.58267600E-02, -.14197000E-02, 0.83858800E-01, 0.65732800E-01, -.44567300E-02, 0.60133500E-01, 0.56844700E-01, -.14833600E+00, -.16365800E-03, -.62467600E-01, -.33079900E-01, -.24164100E+00, 0.39578000E-02, 0.88187200E-01, -.21404700E-01, 0.29309500E+00, -.97243800E-02, 0.92546400E+00, -.14334500E+00, -.10188300E+00, -.42155000E-01, 0.20393300E-01, -.75672500E-02, -.49702500E-01, 0.13799800E+00, -.11557800E+01, 0.51495800E-01, 0.10163700E+00, 0.11093800E+00, 0.12036500E+00, -.10961900E+00, -.60850000E-01, -.93411300E-02, -.80967100E-03, 0.30830100E-03, -.11165800E-01, -.28104000E+00, -.25254300E-01, -.34690700E-01, -.11839000E-01, 0.63468000E+00, 0.88999500E-01, 0.18991900E-01, 0.86537300E-02, 0.13182500E+00, -.12845200E-03, -.31072900E-01, -.12206900E+00, -.22959600E-01, -.44430800E-01, 0.31231700E-01, -.17197900E+00, -.55082300E-01, -.42931500E-01, 0.14078100E-01, -.57624500E-01, 0.89352000E-02, -.27745400E-01, 0.32140900E-01, -.66012300E-01, 0.97115400E-01, 0.25874100E-01, -.20452400E-02, -.24215200E-03, 0.26435600E-01, -.88120600E-02, -.13778900E+00, -.21482200E-01, 0.15122600E+00, -.15144500E+00, -.21823700E+00, -.15625200E-01, 0.10481700E+00, 0.10026000E+00, 0.30947100E+00, -.12559900E+00, -.11310400E-01, -.44230900E-01, -.25945800E-01, -.52665700E-01, -.46898300E+00, 0.49661300E-01, 0.34902600E-01, 0.86697000E-01, 0.17584600E-01, -.26785000E-01, -.14797700E+00, -.21183200E-01, 0.78165000E-01, -.62456900E-02, -.24369500E-01, 0.21118200E+00, -.94129300E-01, 0.27180000E-01, -.77930000E-01, 0.10708900E-01, 0.29937600E-01, -.11313100E-01, -.30294900E-02, 0.86267800E-02, -.30073900E-02, 0.81541400E-02, 0.13478700E+00, 0.72765500E-02, -.62516500E-01, 0.44049300E-01, 0.20751900E+00, 0.39313300E-01, -.72195600E+00, -.11461900E-01, -.38707300E-01, -.24466100E+00, -.14778400E+00, -.10512300E+00, -.38043500E-01, 0.17105700E+00, -.19639500E-01, -.37602300E-01, 0.26920900E-01, 0.40882100E+00, -.19363000E-01, 0.70740000E-02, 0.28046700E+00, 0.84518800E-02, -.30159600E-01, -.77792000E-01, -.63727200E-01, -.85080100E-02, 0.49785700E+00, -.10450100E+01, -.20023800E+00, -.95565900E-01, 0.64502800E-01, -.13054000E+00, -.27189500E-01, 0.26882700E+00, -.58367300E-01, 0.89540500E-02, -.27243000E+01, 0.10712400E-01, 0.11381400E-01, 0.48810400E-02, -.42048500E-01, 0.56342600E-01, 0.10086200E+00 },
        { -.12518100E+02, 0.30653900E+00, 0.44011700E+00, 0.64370500E+00, -.13688900E+01, 0.22550500E+01, -.47739100E+00, 0.10878600E+01, -.15776800E+01, 0.16862000E+01, -.29307100E-02, -.85768100E+00, -.78844200E-01, -.17557500E-01, -.34641100E+00, 0.21014900E+00, 0.79585800E-02, -.12187600E+00, -.53891900E+00, 0.94384300E+00, 0.73072000E+00, -.13920300E+00, -.20405500E+01, -.14235300E+00, -.26838500E-01, 0.10073400E+00, -.88856600E-03, 0.11587600E+01, 0.14056600E+01, -.12347300E+00, 0.56184800E+00, 0.12643700E+01, -.68444300E-01, 0.79951700E+00, -.24590200E+01, -.36539800E+00, -.10420400E+00, -.24112600E+01, 0.27275200E+00, -.75284200E+00, 0.43892100E+00, 0.48389900E+00, -.11139600E-01, -.88907400E+00, 0.38668500E+00, -.13230000E+00, 0.73540100E-02, 0.18198400E-01, -.42451900E+00, 0.11197600E+00, -.72247300E+00, 0.34562800E+00, 0.17494800E-01, 0.11744800E+00, -.10319500E+01, -.42688200E+00, 0.90223900E-02, 0.80201500E-01, 0.31408900E+00, -.15931700E+00, -.30359000E+00, -.13999500E-03, -.84360300E-01, 0.10014900E+00, 0.34108400E-01, -.34995800E-01, 0.61930500E+00, 0.68316800E-02, 0.82537700E+00, 0.28331900E-02, 0.38410400E-01, -.87282600E-01, -.35772800E-02, 0.11836700E+00, -.39114800E+00, -.15800600E+00, -.15282700E+00, 0.25691700E+00, -.79203200E-01, 0.24232300E-02, 0.27769700E-01, -.29932000E+00, 0.60915400E+00, -.16794400E-01, 0.60262100E+00, 0.75121500E+01, 0.72454400E-01, 0.89976800E-01, -.30959000E+00, 0.33291700E+00, -.16704300E+00, 0.26151300E-01, 0.32421100E+00, -.19965600E+00, 0.14122200E+00, -.56167500E+00, 0.13510500E+00, -.23913600E+00, 0.15889600E+00, 0.13188500E+00, 0.10807600E-01, -.49757000E+00, 0.84468900E-01, -.11703800E+00, 0.47856900E-01, -.10716100E-02, 0.85566400E-01, 0.20083000E+01, -.34853100E-01, 0.23657900E-01, -.93849100E+00, 0.51991000E-01, -.97904900E-01, 0.75379000E-02, 0.50702200E+00, -.14046500E+00, 0.93908000E-01, -.86513600E+00, 0.27312400E+00, 0.11673600E-01, -.10270700E+00, 0.34273000E-01, 0.18816100E-01, 0.64393600E+00, 0.80801100E-02, -.58885700E+00, -.40274900E-01, 0.43108000E-01, 0.25786900E+00, 0.12328800E+01, 0.18022800E+01, -.11071500E+00, -.33712700E+00, 0.24798100E-01, 0.16054100E+01, -.79580400E-02, -.79467600E-01, -.90838200E-01, -.21809000E+00, 0.98879100E-01, 0.15989400E+00, -.13889000E+00, -.32400200E-01, 0.27158800E+00, 0.74791400E-02, -.15042200E-01, 0.22537100E-02, 0.53461200E+00, 0.80717900E-01, -.77334500E+00, -.10268400E+00, -.49949200E-01, 0.32079200E+00, 0.14949200E+00, 0.16083800E+00, 0.80783400E-01, 0.25120100E-01, -.11309300E-01, -.43397800E+00, -.15893000E+00, 0.47561400E+00, -.90301300E-01, -.33204500E-01, -.15528600E+00, -.75638000E-02, 0.19735200E+00, -.44762200E-01, -.11652600E-01, 0.50143300E-01, 0.34787800E-01, -.20730400E+00, -.89902800E+00, 0.10258500E+00, 0.75792000E+00, 0.29826300E-01, 0.13496900E-01, -.42304400E-01, 0.12587200E-01, -.16547100E+00, -.27652600E+00, 0.42908900E+00, -.51130900E+00, -.94458800E-01, -.32748800E+00, 0.37474300E-01, -.61777700E+00, -.14081600E+00, 0.23572500E+00, -.17051300E-01, -.91889100E-01, 0.29980500E-02, -.75660400E-01, -.32893400E+00, -.17153100E+00, 0.19963300E+00, -.21408400E-01, 0.98365600E+00, -.30737000E+00, -.16113600E+00, 0.12993900E-01, 0.25755300E+00, -.11594000E-01, -.56398900E-03, -.68977600E-01, 0.43773100E-01, -.25419300E-01, 0.53140600E-01, 0.30035400E-01, 0.14182300E+00, 0.30399300E-01, -.94117100E-02, 0.10797100E+00, -.35799700E-01, -.21771900E+00, -.73889200E-02, 0.80195100E-01, 0.20852400E+00, -.42640600E-01, -.50999200E-01, -.16023100E-01, -.11137700E+00, 0.18866700E-01, -.30860000E+00, -.35320400E-01, 0.27074300E+00, 0.22211300E+00, -.45103100E+00, 0.35006600E-01, -.88384000E-01, -.39890500E-01, 0.38806300E+00, -.21801100E-01, -.20416400E-01, -.33266500E+00, 0.12857000E-01, -.14282300E+00, 0.52964200E-01, -.28919500E-01, 0.92002600E-01, -.15712800E+00, -.40350500E-01, 0.10347900E+00, -.12118000E+00, 0.87015600E-02, 0.10641700E+00, -.56691500E-03, 0.15966900E-01, 0.92752700E-01, 0.56965100E-01, -.17574800E+00, 0.41186900E-01, 0.53640900E+00, 0.42452100E+00, -.44845600E-01, -.62002600E-02, 0.14852100E+00, 0.61867000E-01, -.67072300E-01, 0.10847200E-01, 0.81112300E-01, 0.40472900E-01, -.96273800E-01, -.19154400E+00, -.36218400E-01, 0.40839600E+01, 0.36834600E-02, 0.29412400E-01, -.86896900E-01, 0.50992300E+00, 0.59321700E-01, -.61274400E-01, -.34761700E-01, 0.40864700E-01, 0.15777400E+00, 0.50119700E-02, -.84995300E+00, 0.63012700E+00, 0.87701200E-02, -.95824900E+00, 0.11463100E+00, 0.38957800E+00, -.55084400E-01, 0.19600100E+01, -.49672000E+00, -.39178800E+00, 0.76666800E+00, 0.13140000E+00, -.46036600E+00, -.33915400E+00, 0.30050100E-01, 0.26334000E-01, -.11260000E+00, -.71827900E+00, -.10677100E-02, 0.19318300E+01, -.24734700E-01, 0.36821500E-01, 0.80050500E-01, -.50318700E-01, 0.88898600E+00, -.53147600E-01 },
        { 0.35041300E+01, -.16512400E+00, -.14507700E+00, -.89729300E+00, 0.49868600E+00, -.17536200E+01, 0.50924900E+00, -.88874600E+00, 0.11596200E+01, -.15702100E+01, 0.15597400E-01, 0.60984500E+00, 0.79745900E-01, 0.78441300E-01, 0.22145300E+00, -.13415700E+00, 0.41838100E+00, 0.33688900E+00, 0.37026500E+00, -.66304400E+00, -.66048000E+00, 0.96098700E-01, 0.45666700E+01, 0.77129700E-01, 0.65801500E-01, -.70637700E-01, 0.80835400E-01, -.44435900E+00, -.95659000E+00, 0.16363800E+00, -.41979900E+00, -.86740000E+00, 0.50163300E-01, -.18605900E+00, 0.15879000E+01, 0.22727300E-01, 0.34302600E-02, 0.15249800E+01, -.16497800E+00, 0.38090000E+00, -.20414000E+00, -.94405600E-01, -.20372500E+00, 0.41302300E+00, -.46088800E-01, 0.10176600E+00, 0.37111800E-01, -.43078000E-02, 0.13329100E+00, -.58675500E-01, 0.19203700E+00, 0.93093700E-01, -.25507500E-01, -.22827100E+00, 0.22031000E+00, 0.27431900E+00, -.19676800E-01, -.95005900E-01, -.47688900E-01, 0.44057800E-01, 0.16318400E+00, 0.24844000E-01, 0.16129100E-01, -.21022100E-01, -.63885400E-01, -.41106700E-02, 0.90705500E-01, -.34211800E-02, -.37716300E+00, -.19521100E-03, -.75649700E-02, 0.11797300E+00, 0.44140300E-01, -.46888400E-01, -.26710300E+00, 0.86072600E-01, 0.30301200E+00, 0.17444000E+01, -.11166500E+00, 0.33779900E-01, -.13504900E-01, 0.42828100E+00, -.46189300E+00, -.91823100E-01, -.25824500E+00, -.17833800E+01, 0.15145300E-01, 0.55609000E-01, 0.15136400E+00, 0.15888500E+00, 0.21730200E+00, -.23195300E-01, -.38989000E+00, 0.90288900E-01, -.79442900E-01, 0.13882500E+00, -.10629700E-01, 0.15084000E+00, -.14097300E+00, 0.41533600E-01, 0.80988600E-02, 0.22750100E+00, -.12166700E+00, 0.90516700E-02, 0.38267300E-01, 0.59342700E-01, -.34088000E-01, -.12353200E+01, 0.83291500E-01, -.32185600E-01, -.55581400E-01, -.36522300E-01, 0.84981400E-02, -.35470100E-02, -.10083400E+00, -.39086900E-01, -.27582800E-01, -.92978400E+00, -.13147800E+00, -.16669000E+00, 0.92898700E-01, -.81646800E-02, -.47568200E-02, -.46240000E-01, 0.39445800E-02, 0.31197800E+00, 0.47991100E-01, -.10365200E+00, -.10530200E-01, 0.25872200E+00, -.81743900E+00, 0.11003800E+00, 0.59286000E-01, -.22006600E-01, 0.48520600E+00, 0.38588500E-01, -.42274900E-01, 0.60135900E-02, -.26900000E+00, -.52001700E-01, 0.21969000E-01, 0.19926200E+00, 0.14157600E-01, 0.24764800E-02, -.74617400E-02, -.13937900E+00, -.10373700E-01, 0.18795500E+00, 0.59088000E-01, -.38220100E+00, -.57297300E-01, -.12155500E+00, 0.21686000E+00, -.40006300E-01, 0.20887100E-01, -.78068400E-03, 0.36281400E-01, 0.25261400E-02, 0.11104900E+00, 0.95077600E-01, 0.19193000E+00, 0.71655300E-02, 0.62143300E-01, -.93329700E-01, 0.28078700E-01, 0.39950000E-01, -.38361100E-01, -.10949500E+00, -.26852500E-01, 0.53035100E-01, 0.72930000E-01, 0.79821200E-01, -.11602400E+00, -.12645400E+00, -.67382600E-01, -.30704200E-01, 0.28508500E-01, -.69254300E-02, -.10205400E+00, -.20264500E+00, -.38438400E-01, -.60846600E+00, -.86840100E-01, 0.76507900E-01, 0.50443700E-01, 0.71946700E-02, 0.69935100E-01, -.61740200E-01, -.92167400E-03, 0.24584500E-01, -.98739900E-03, -.93931500E-03, 0.12544700E+00, 0.14485700E+00, -.53562900E-01, 0.21896800E-01, -.48680800E+00, 0.13565500E+00, -.18818700E-01, -.11902200E-02, 0.61987400E-01, -.27818600E-02, 0.12644700E-01, 0.43046700E-01, -.19832800E-01, -.54504800E-01, -.16505600E-01, 0.14716800E+00, -.14635000E-02, -.16656700E-01, -.79002100E-02, -.27473500E-01, -.15474800E-01, -.50102100E-01, 0.26067100E-01, -.71488200E-02, 0.20032600E-01, -.53621900E-01, -.21873500E-01, -.12317200E-01, 0.97958500E-02, 0.81185400E-02, -.13851500E-02, 0.14501700E-01, 0.32567700E-01, 0.11784300E+00, 0.14718600E+00, 0.43163500E-01, 0.36396100E-01, -.39196100E-02, -.10879400E+00, -.18559000E-02, 0.11626500E-01, 0.84230400E-01, -.50977800E-02, 0.39287200E-01, 0.24070800E-01, 0.68474000E-02, -.73860900E-01, 0.43002500E-02, 0.26386700E-01, -.98073100E-01, -.10336600E-01, 0.13901000E-02, -.12006700E+00, 0.99493600E-02, 0.10634500E-01, 0.33655600E-01, -.97347400E-01, 0.22531700E-01, -.49057400E-01, -.26613500E+00, -.91771900E-01, 0.51010900E-01, -.85199100E-03, -.69400700E-01, -.17809000E-01, 0.29130100E-01, -.61138400E-01, -.16351400E-01, -.35817700E-01, 0.30462500E-01, 0.10496900E+00, 0.17217400E-01, -.20865700E+01, -.72480900E-02, -.46265400E-01, -.18544400E+00, -.13258200E+00, -.62303700E-01, -.23249600E-01, 0.10637500E+00, 0.10551700E-01, 0.15000500E-01, 0.90667800E-02, 0.18956400E+00, -.67591200E+00, 0.51740500E-01, 0.62740000E+00, -.10595000E-01, 0.43503800E+00, 0.50023700E-01, -.47119600E-01, -.68024700E-01, 0.13932400E+00, 0.60143200E-01, -.40101400E-01, 0.11087200E+00, 0.12780900E-01, -.41927500E-01, 0.37497300E-05, -.10143300E+00, 0.58604100E-01, 0.23200300E+00, -.70546100E+00, -.10822400E+00, 0.19641300E-01, 0.66020700E-02, 0.13715700E-01, -.61743700E-01, 0.18816200E-01 },
        { -.83557400E+02, 0.20695100E+01, 0.31453800E+01, 0.39887200E+01, -.85762500E+01, 0.14863600E+02, -.41743600E+01, 0.74477800E+01, -.95667100E+01, 0.11065600E+02, -.23738300E-01, -.48681200E+01, -.51055400E+00, -.40853800E+00, -.19308800E+01, 0.13166000E+01, 0.32023700E+00, -.16856600E+00, -.26169600E+01, 0.53767000E+01, 0.37544600E+01, -.10603100E+01, -.11870300E+02, -.85893100E+00, 0.17514800E+00, 0.67915200E+00, 0.19428100E+00, 0.71630100E+01, 0.85875400E+01, -.10868100E+01, 0.27081900E+01, 0.69036900E+01, -.43197800E+00, 0.46335400E+01, -.16164400E+02, -.19699600E+01, -.71392000E+00, -.15545900E+02, 0.19023400E+01, -.50962300E+01, 0.25628300E+01, 0.38344400E+01, -.62540400E+00, -.63109800E+01, 0.27355500E+01, -.82990100E+00, -.10576600E+00, -.34911800E-01, -.25506000E+01, 0.72031200E+00, -.50986100E+01, -.19968400E+01, 0.14644800E+00, 0.89064700E+00, -.85263300E+01, -.23071900E+01, -.51918600E-02, 0.12321800E+01, 0.21977700E+01, -.10833200E+01, -.16451400E+01, -.70069000E-01, -.25560200E+00, 0.55478300E+00, 0.68170100E+00, -.13996700E+00, 0.36714600E+01, 0.35795000E-01, 0.46571200E+01, 0.48748500E-01, 0.35008500E+00, 0.64162800E-01, 0.72770000E-01, 0.85413900E+00, -.16974800E+01, -.10571900E+01, -.29613800E+00, 0.25776800E+01, 0.36888500E+00, 0.24373300E+00, 0.11771700E+00, -.17728600E+01, 0.28787400E+01, -.44229200E-01, 0.33552400E+01, 0.51272800E+02, 0.65137800E-01, 0.57617400E+00, -.30373200E+01, 0.11314900E+01, 0.46507200E+00, 0.33240500E+00, -.49855800E+00, -.16387800E+01, 0.72424700E+00, -.38812500E+01, 0.52466600E+00, -.20772200E+01, 0.82341300E+00, 0.14065800E+01, 0.17498200E+00, -.30907000E+01, 0.41834200E-01, -.11475000E+01, 0.45729600E-01, 0.30294500E+00, 0.61868600E+00, 0.11946800E+02, -.42643700E+00, 0.23611200E+00, -.26284800E+01, 0.42455600E+00, -.34632400E+00, 0.47135300E-01, 0.27292300E+01, -.10962000E+01, 0.68645300E+00, -.69995500E+01, 0.19234100E+01, -.13450300E+01, -.68904300E+00, 0.23752600E+00, 0.70369900E-01, 0.42721700E+01, 0.21047000E+00, -.33957400E+01, -.35737300E+00, -.39492800E+00, 0.19815300E+01, 0.60456700E+01, 0.11201500E+02, -.53597200E+00, -.15859500E+01, 0.22333100E+00, 0.13360600E+02, -.24824100E+00, -.37628700E+00, -.85903900E+00, -.25706700E+01, 0.31544400E+01, 0.76371900E+00, -.12142500E+01, 0.11346600E-01, 0.17220600E+01, 0.11778100E+00, -.13403300E+00, -.73602400E-01, 0.17804300E+01, 0.59701300E+00, -.44657500E+01, -.41866600E+00, -.76146100E+00, 0.19668400E+01, 0.11906800E+01, 0.65428800E+00, 0.37383600E+00, 0.34880400E-01, 0.10415500E+00, -.46048900E+01, -.12066100E+01, 0.37228500E+01, -.94887000E+00, -.12181200E-01, -.14610600E+01, 0.78100100E-01, 0.13935100E+01, -.62317400E-01, 0.12736200E+01, -.11331200E+00, 0.28301200E+00, -.61976100E+00, -.60916800E+01, 0.24660300E+00, 0.65612500E+01, 0.36139600E+00, -.12402600E+00, -.31906400E+00, 0.26507800E+00, 0.29093700E+00, 0.39270400E+00, 0.36284400E+01, -.97285500E+01, 0.11214100E+00, -.22998900E+01, 0.35815200E-02, -.40880500E+01, -.99381600E+00, 0.18243200E+01, -.11470500E+00, -.51205000E+00, 0.40233200E-01, -.79102700E+00, -.50523700E+01, -.84030100E+00, 0.69522400E+00, -.17303000E+00, 0.70984000E+01, -.10225900E+01, -.14092300E+00, 0.13036500E+00, 0.20169000E+01, -.82217300E-01, 0.58555300E+00, -.64611400E+00, 0.12619200E+00, -.58243900E+00, 0.50010300E+00, -.59353900E+00, -.49651400E-01, -.71269500E-01, -.89730900E-01, 0.10134000E+01, -.19926500E+00, -.13119800E+01, -.92282200E-01, 0.12976400E+01, 0.29683800E+01, 0.37010900E-01, -.39644600E+00, -.12918300E+00, -.71923800E+00, 0.11407400E+00, -.10101500E+01, -.96091900E-01, 0.74707800E+00, 0.23755800E+01, -.12976800E+01, -.11531200E+00, -.94567700E+00, -.40075100E+00, 0.24936900E+01, -.11161800E+00, -.97907200E-01, -.79431100E+00, 0.15356800E+00, -.50223800E+00, 0.22261300E+01, -.34650500E+00, 0.10304500E+01, -.72408700E+00, -.22478300E+00, 0.49529700E+00, -.10148300E+01, 0.81071900E-01, 0.10698900E+01, -.28638400E-01, 0.22900600E+00, -.72214100E+00, 0.15121900E+01, -.13200300E+01, 0.93555800E+00, 0.37896400E+01, 0.26913600E+01, -.56764600E+00, -.12541500E+00, 0.12544700E+01, 0.44571000E+00, -.16851400E+00, 0.32482000E+01, 0.67495600E+00, 0.20650100E+00, -.12729300E+01, -.95487600E-01, 0.12657500E-02, 0.28151500E+02, -.27685800E-01, 0.11362000E+00, -.12707800E+01, 0.24473900E+01, -.17729500E+00, -.43945200E+00, 0.63555600E+00, 0.67716800E-01, 0.27555300E+00, 0.13951400E+00, 0.22764200E+01, 0.58653600E+01, -.52867600E+00, -.13633200E+02, 0.18914400E+01, -.34994700E+01, -.28154800E+01, 0.10392800E+02, -.46986300E+01, 0.33785700E+01, -.17952300E+02, -.29304400E+01, -.71340300E+01, -.27608100E+01, -.91993200E+00, -.44436100E+00, 0.53027500E+00, 0.62162200E+01, 0.39478600E+01, -.53451900E+02, 0.22047100E+00, -.15030700E+00, -.16107500E+00, -.77467600E+00, 0.24223400E+01, 0.17814800E+01 },
        { -.36464300E+01, 0.15935100E+00, 0.14585500E+00, 0.70299900E+00, -.50625600E+00, 0.16566100E+01, -.49115000E+00, 0.10372700E+01, -.15203000E+01, 0.13560800E+01, 0.42165300E-01, -.81897700E+00, -.68911000E-01, -.58167900E-01, -.22131700E+00, 0.16235500E+00, -.29152800E+00, -.22489700E+00, -.32577000E+00, 0.51948200E+00, 0.58939200E+00, -.11524900E+00, -.35469500E+01, 0.74850300E-01, -.16860200E-02, 0.93881100E-01, -.22094100E-02, 0.56869900E+00, 0.10767600E+01, -.66335100E-01, 0.39041000E+00, 0.77047700E+00, -.71606700E-01, 0.38554200E+00, -.16807600E+01, -.98179100E-01, -.12191100E-01, -.14263200E+01, 0.19679500E+00, -.36338500E+00, 0.20308300E+00, -.73111200E-01, 0.12385200E+00, -.20813400E+00, -.13394800E+00, -.77210700E-01, -.42315200E-01, 0.10188300E-01, -.37402500E+00, 0.60066400E-01, -.33098700E+00, 0.41151500E+00, 0.60960000E-01, 0.15592600E+00, -.48054700E+00, -.22119400E+00, 0.21988200E-01, -.11552100E+00, 0.87829800E-01, -.87720200E-01, -.98113500E-01, -.37526000E-01, -.20984900E+00, 0.12201300E-01, 0.14594400E+00, 0.20198000E-01, 0.63676200E-01, 0.57331600E-02, 0.14564100E+00, 0.23556100E-02, 0.27807300E-01, -.10460400E+00, -.87125600E-01, 0.58826500E-01, 0.13583500E+00, -.50456800E-02, -.18961100E+00, -.12395300E+00, -.19044600E+00, 0.71577800E-01, 0.22298500E-01, -.23184900E+00, 0.62684000E+00, -.16469100E+00, 0.32414300E+00, 0.28756600E+01, 0.48523300E-01, 0.29792100E-01, -.18997100E+00, 0.16882600E+00, -.15493700E+00, 0.28378800E-01, 0.40817400E-01, -.98693100E-01, 0.58929500E-01, -.27551600E+00, -.64829900E-01, -.14536000E+00, 0.42183500E-01, 0.77153600E-02, 0.10339000E-01, -.19671100E+00, 0.15975000E+00, 0.19579300E-01, -.28661300E-01, -.95472000E-01, 0.11754800E-01, 0.15171200E+01, -.67480500E-01, 0.92745300E-02, 0.27905400E-01, 0.26713800E-01, -.76094800E-01, 0.37130000E-03, 0.12467100E+00, 0.71778500E-01, 0.39607600E-01, -.22946800E+00, 0.85850300E-01, 0.24635800E+00, -.53622400E-01, -.49250900E-02, 0.79833700E-02, 0.67585000E-01, -.32282300E-02, -.23217700E+00, -.30624400E-01, 0.11044300E+00, 0.31174900E-01, -.87031000E-01, 0.91981900E+00, -.15826700E+00, -.80208200E-01, 0.23553600E-01, -.14458800E+00, 0.11051600E-01, -.28021600E-02, -.29987100E-01, 0.18738800E+00, 0.58831500E-01, -.33735300E-01, -.21398200E+00, -.26122500E-01, 0.67985200E-01, 0.78405500E-02, 0.10361700E+00, 0.99857900E-02, -.14324300E+00, -.66545600E-02, 0.11614500E+00, 0.25062100E-01, 0.50279500E-01, 0.11747000E-01, 0.81177600E-01, 0.85373400E-02, 0.10484900E-01, -.28376900E-01, -.18674900E-02, -.19331600E+00, -.12129200E+00, -.77461600E-01, -.34696100E-01, -.51394200E-01, 0.78773400E-01, -.26484700E-01, -.24097800E-01, 0.22850400E-01, 0.14061400E+00, 0.26047500E-01, -.71674900E-01, -.76318000E-01, -.38826400E+00, 0.11659000E+00, 0.52619900E-01, 0.47425000E-01, 0.53143200E-01, -.19746600E-01, 0.51800900E-03, 0.38331000E-02, 0.79029600E-01, 0.83751800E-01, 0.32247200E+00, 0.43805400E-01, -.82324800E-01, -.47429600E-01, -.13349100E+00, -.72022100E-01, 0.27159500E-01, -.14087600E-02, -.28965300E-01, 0.13706800E-02, -.21412700E-01, -.28651600E+00, -.83445700E-01, -.84038300E-02, -.13030600E-01, 0.38659700E+00, -.13627900E+00, 0.85774900E-01, -.26448500E-02, -.92858700E-01, 0.47532300E-03, 0.34058600E-01, -.71886800E-01, 0.18654600E-01, 0.49905500E-01, 0.27283800E-01, -.13769100E+00, 0.29673300E-01, 0.15130500E-01, -.32397700E-03, 0.44365100E-01, 0.47797000E-02, 0.11611900E+00, -.41812400E-01, -.17231500E-01, 0.65266300E-01, -.15532900E-01, -.25135000E-01, 0.43888800E-02, -.19870600E-01, -.37688700E-02, -.49172300E-01, -.11558000E-01, 0.37716900E-01, -.14476100E-01, -.15642400E+00, -.25076400E-02, -.28098600E-01, -.32953200E-02, 0.92918700E-01, 0.17224900E-01, -.54724200E-02, -.67075100E-01, 0.34066400E-02, -.29032200E-01, -.46838800E-01, 0.92871300E-05, 0.50825000E-01, 0.15943400E-01, -.14295800E-01, 0.56920400E-01, -.19473000E-01, 0.46642000E-02, 0.72952400E-01, -.34998400E-02, 0.38544300E-02, -.78228400E-01, 0.59369200E-01, -.49579400E-01, 0.41197600E-01, 0.12166200E+00, 0.67049100E-01, -.27846000E-01, 0.86190700E-03, 0.68644100E-01, 0.13617300E-01, -.24421300E-01, 0.61205000E-01, 0.65490600E-02, 0.30306200E-01, -.22914800E-01, -.99636600E-01, -.16855400E-01, 0.16920100E+01, 0.68856600E-02, 0.36057800E-01, 0.15486800E+00, 0.70552900E-01, 0.49504800E-01, 0.23000800E-01, -.81866600E-01, -.83493400E-02, -.97633100E-02, -.71059700E-02, -.20715600E+00, 0.65568800E+00, -.46659100E-01, -.51477100E+00, 0.53853600E-02, -.52951700E+00, -.38915700E-01, -.59889200E-01, 0.62395900E-01, -.11172600E+00, -.77239800E-01, 0.73474400E-01, -.80790200E-01, 0.34593600E-01, 0.38171500E-01, 0.53612700E-03, 0.57961300E-01, -.95482600E-01, -.50727700E+00, -.79343500E-02, 0.92719700E-01, -.79647600E-02, -.53819800E-02, -.18668300E-01, 0.47295200E-01, 0.44046900E-02 },
        { 0.47345500E+01, -.95324600E-01, -.12274900E+00, 0.13961600E+01, 0.27807300E+00, 0.50721000E-01, -.66180200E+00, 0.21474400E+00, 0.14595200E+01, 0.19356500E+00, 0.59710200E-02, 0.15635000E+00, -.23501900E+00, -.24371000E-01, 0.68835800E-02, 0.39819500E-01, 0.52020800E-01, -.12026500E+00, -.20292800E-01, -.20962600E-01, 0.27800300E+00, -.77051300E-01, -.29834200E+01, -.13803800E+00, -.20002400E+00, 0.69319100E-02, -.11446800E+00, -.70809900E+00, -.34724000E-01, 0.11733900E+00, 0.13879800E+00, 0.10105300E+01, -.32196500E-02, 0.10738700E+00, 0.58934100E-01, -.16926900E+00, 0.26005000E-01, -.61326600E+00, -.22152000E-01, 0.81912900E-01, 0.24194500E+00, 0.69328600E-01, 0.20954300E+00, -.15008100E+00, 0.17708200E+00, -.15801300E+00, 0.12242100E-01, -.31539600E-02, -.56484200E-01, 0.29295600E-01, 0.33696100E-01, -.81460600E+00, 0.12249600E+00, -.24621200E+00, -.39770600E-01, 0.36666800E+00, 0.60339000E-01, 0.13132400E-01, 0.13265400E+00, -.12571200E-01, 0.66623400E-01, 0.10345700E+00, -.42435900E+00, 0.12057800E+00, 0.62032000E+00, 0.25830900E-01, 0.15933700E+00, -.16163900E-02, 0.32386200E+00, -.11234000E-02, -.25083600E-01, -.39062500E-01, -.10073100E-01, 0.16797700E-01, 0.16129400E+00, -.10123700E+00, -.13491400E+00, -.18677600E+01, 0.31351000E+00, -.15430500E+00, -.86132100E-02, -.31629000E+00, 0.56774100E-01, 0.25064100E+00, -.25590700E+00, -.13972000E+01, -.14966100E+00, -.83204700E-01, 0.13355700E+00, -.58591800E+00, -.74873500E-01, -.49187300E-03, 0.14551100E+00, 0.39427000E-02, 0.45782200E-01, 0.10855400E-01, 0.85684100E-01, -.36897100E-01, -.94595100E-01, 0.16987200E-01, -.18870600E-01, -.89037500E-01, 0.28667200E-01, 0.70754800E-01, 0.13022500E-01, 0.54752700E-01, 0.24012800E-01, 0.33910500E+00, -.48235300E-01, 0.29005200E-01, -.36211200E+00, 0.18225500E-01, -.56597600E-01, 0.27723700E-02, 0.10589600E+00, 0.14462500E-01, -.89956100E-02, 0.11710300E+01, 0.52833600E-01, -.10336200E+00, 0.17512600E-01, 0.38287800E-01, 0.51259600E-02, 0.39970700E-01, 0.79591200E-03, 0.16381400E-01, -.24523400E-01, 0.18160300E+00, 0.30305600E-01, 0.44767300E-01, -.87377600E-01, -.87104500E-01, 0.57429800E-01, 0.25100300E-01, 0.20409200E-01, -.31898500E+00, 0.55358600E-02, 0.83873200E-01, 0.27893600E+00, -.42293900E-01, -.19863000E+00, -.19552800E-01, -.12230600E-01, -.12246400E+00, 0.40608500E-02, 0.92481100E-02, -.75780300E-02, -.10882000E-01, -.49463100E-01, 0.28538200E+00, 0.15022900E-01, -.28861200E-01, 0.88035500E-01, -.64333500E-01, -.15359800E-01, 0.25062800E-01, 0.33896700E-01, -.76000200E-02, 0.27203900E+00, 0.37028700E-02, -.10030900E+00, 0.54727500E-01, 0.21326400E-01, -.11770100E+00, 0.21922900E-01, 0.54426000E-01, -.36496800E-01, 0.42930800E-02, -.48241100E-02, 0.43559900E-01, 0.47119000E-01, 0.37032300E+00, -.35592700E-01, 0.19463200E+00, 0.46698300E-01, -.48561700E-01, -.31361900E-01, -.69903900E-02, -.20275600E-02, 0.40452800E-01, 0.60476900E-01, -.37905300E+00, -.24068600E-01, -.42453200E-01, 0.23868400E-01, -.53929900E-01, -.17089900E-01, 0.64083500E-01, -.72886700E-02, -.17931800E-01, 0.87663900E-04, -.18061500E-01, 0.27382600E-01, -.12201900E+00, -.26774900E-01, -.13150400E-01, -.23272600E+00, 0.35696200E-01, -.11357500E+00, 0.61638700E-02, 0.10009600E+00, -.13477500E-02, 0.29026500E-01, 0.19126600E-01, 0.23839500E-01, -.30797100E-01, 0.26655700E-01, 0.19316000E-01, 0.65275800E-01, -.21179000E-01, -.90743100E-02, -.74700700E-02, -.87773500E-02, -.44933100E-01, 0.23717400E-01, 0.43854900E-01, 0.14048400E+00, 0.32355600E-01, 0.15921500E-01, 0.55035100E-02, -.24570400E-01, 0.62544400E-03, -.18463200E-01, -.14395900E-01, 0.11535200E+00, 0.10752000E+00, -.43875200E-01, 0.33822800E-01, -.13334700E+00, -.52655500E-01, -.16995400E+00, 0.95722900E-01, 0.10473500E-01, -.21759700E+00, 0.10806700E-01, 0.87680400E-01, 0.28977600E+00, 0.11541900E-02, 0.13719900E+00, -.59611400E-01, 0.67412700E-01, 0.83578200E-01, 0.94265500E-01, -.73285900E-02, 0.50463200E-01, -.47829400E-02, -.14560500E-01, -.81364800E-01, 0.74898800E-01, 0.21052800E-01, 0.78633500E-01, -.13088100E-01, -.69818100E-01, -.16213300E-01, 0.51487200E-02, 0.41500900E-01, -.15680300E-01, -.18802000E-01, 0.14631000E+00, 0.11041700E+00, 0.42045100E-02, -.28528700E-01, 0.11161500E+00, 0.96524100E-02, 0.80329800E+00, 0.52764700E-02, 0.43734500E-03, 0.52049900E-01, -.21971500E+00, -.17346600E-01, 0.12822900E-03, 0.35642600E-01, 0.29667600E-01, 0.10185500E+00, 0.64566200E-02, -.11177100E+00, 0.58003700E-01, 0.12763600E-01, -.26050600E+00, 0.17918000E-01, -.57395800E-01, -.94928100E-01, 0.59284800E-01, -.10282300E+00, -.38799100E-01, 0.66081700E-01, -.69574900E-01, -.23434400E-01, -.31836700E-02, -.12991600E+00, -.22619900E-03, 0.40850100E-01, 0.42123400E-01, 0.50906400E-01, 0.44116500E-02, 0.80238200E-02, 0.10986400E+00, -.61297200E-01, 0.43331700E-01, -.25182700E-01, -.91274000E-02 },
        { 0.50187200E+02, -.14904200E+01, -.17989500E+01, -.15530900E+01, 0.61194600E+01, -.13884400E+02, 0.34737500E+01, -.42492600E+01, 0.68132300E+01, -.12189700E+02, 0.27388800E+00, 0.22595300E+01, -.15563700E+00, 0.35904600E+00, 0.94167800E+00, -.81518300E+00, -.68512500E+00, -.75937800E+00, -.46775400E+00, -.70289500E+01, -.60578500E+01, -.61090400E-01, 0.17588900E+02, 0.36847000E+01, 0.13213200E-01, 0.17480100E+00, 0.53664000E+00, -.22274800E+01, -.72843500E+01, -.40629200E+01, -.35620800E+01, -.78791100E+01, 0.42638400E+00, -.29935000E+01, 0.12540700E+02, 0.26548900E+01, 0.69175500E+00, 0.11100700E+02, -.59186800E+00, 0.50945100E+01, -.30281100E+01, -.46011600E+01, 0.20408700E+00, 0.45167200E+01, -.99065300E+00, 0.56658200E-01, -.38385900E+00, -.14397600E+00, 0.39668400E+01, -.10523500E+01, 0.94578500E+01, -.63968300E+01, 0.30942600E+00, 0.42687600E+00, 0.66268000E+01, 0.20087300E+01, -.10467500E+00, -.14055800E+01, -.31660000E+01, 0.34752500E+00, 0.36699500E+01, -.94171700E-02, 0.11645700E+01, -.11598800E+01, 0.18797500E+01, 0.17435700E+01, -.62561000E+01, 0.20764500E-01, -.94420200E+01, 0.31105000E-01, -.11287900E+00, 0.11365700E+01, -.36390300E+00, -.67539300E+00, -.33896100E+01, 0.36366500E+01, -.21235500E+00, 0.25893800E+02, -.46830100E+01, -.63474300E+00, -.25783300E+00, 0.81811400E+01, 0.34762900E+01, -.28813600E+01, -.24197000E+01, -.33531300E+02, -.44669900E+00, 0.42120700E+00, 0.51496400E+00, 0.14107800E+01, 0.28946400E+00, 0.13674300E-01, -.52226100E+01, 0.17246400E+01, -.20448800E+00, 0.12076300E+01, 0.62982800E+00, 0.20777500E+01, -.71185600E+01, 0.12589400E+01, 0.26740300E+00, 0.42659800E+01, -.31947000E+01, -.10325400E+01, 0.10614400E+00, 0.15385700E+01, 0.82166800E+00, 0.10371600E+02, -.17332200E+01, 0.89928000E+00, -.10620400E+02, 0.52661100E+00, -.12236000E+01, 0.10029600E+00, 0.28280500E+01, 0.46939100E+00, -.21377400E+00, 0.14144500E+02, -.53190400E+00, -.79485400E+01, 0.82030900E+00, 0.18948000E+00, -.85507400E-01, -.41340300E+00, 0.11389000E+00, 0.38144300E+01, 0.80267500E-01, 0.75092700E-01, 0.26953300E+00, 0.36200800E+01, -.15284200E+02, 0.16646500E+00, 0.25865300E+01, -.29891500E-01, 0.25699400E+00, -.42247300E+01, -.12707700E-02, 0.13104700E+01, -.53929600E+01, 0.10838500E+01, 0.49754000E+00, 0.21352300E+01, -.12054500E+00, 0.20459600E+01, -.18130500E+00, -.73216300E+00, 0.20542600E+00, 0.36637600E+01, -.56708400E+00, -.50411100E+01, 0.41748900E+00, -.22765500E+01, -.18560500E+01, 0.21751200E+00, 0.97775000E-01, 0.40380100E+00, 0.14343000E+00, 0.25205100E+00, 0.31357900E+01, -.12744700E+01, -.75602100E+00, 0.45648600E+00, -.55924300E+00, 0.10912900E+01, -.54447300E+00, 0.11770400E+01, -.14046100E+00, -.17471500E+01, 0.78805200E+00, 0.13804600E+00, -.16814800E+01, 0.39005800E+01, 0.71663400E+00, -.44041100E+01, -.18359400E+01, 0.96745200E+00, -.17061300E+00, -.58612200E+00, -.12608200E+01, -.64729600E+01, -.23846600E+01, 0.11337500E+02, -.10316000E+01, 0.65684000E+00, -.68983000E+00, 0.58529700E+01, 0.13858100E+01, 0.70049600E+00, 0.18905900E+00, 0.92339900E-01, -.14713000E-01, 0.45221200E+00, 0.58087600E+01, 0.19151200E+01, 0.21925500E+01, 0.21477300E+00, 0.27773000E+01, -.38880200E+00, 0.10116900E+01, -.21252900E-01, -.33544700E+01, -.33570500E-01, 0.50832900E+00, -.85045300E+00, 0.20628400E+00, 0.44016900E+00, -.55234700E+00, 0.15451000E+01, 0.87202600E+00, 0.49155000E+00, 0.36545100E-01, 0.38900400E+00, -.17481200E+00, 0.12282500E+01, -.12239300E+00, 0.10061800E+00, -.25602900E+01, 0.61986400E+00, 0.84430900E+00, 0.26105000E+00, 0.22647100E-01, -.14253000E+00, 0.11986800E+01, 0.19978200E+00, -.17916600E+01, -.30361300E+00, 0.66763700E+00, -.77521100E+00, 0.12258400E+01, 0.74471400E+00, 0.28732000E+01, -.14197200E+01, 0.39816600E-01, 0.24764000E+01, 0.95644400E-01, -.11586400E+01, -.40687400E+01, 0.26481600E+00, -.91512800E-01, 0.18652200E+01, -.11229600E+00, 0.69656400E+00, -.38111600E+00, 0.80401100E-01, 0.78235400E+00, 0.68932300E-01, 0.15337700E+00, 0.25745000E+01, 0.44599000E+00, 0.88740800E+00, -.32339800E+00, -.50539800E-01, 0.11096200E+01, -.16766400E-01, 0.10521700E+00, -.11794100E+00, -.22578900E+00, -.25999300E+00, -.46291400E+01, -.17499300E+01, -.25141100E+00, 0.20133100E+01, -.39167600E+01, -.50984000E+00, -.17469300E+02, 0.53984700E-02, -.34143200E+00, 0.85078800E+00, -.46340500E+01, 0.25172700E+00, 0.10917600E+01, -.10499200E+01, -.51080200E+00, -.17546300E+01, -.14712600E+00, 0.20365000E+01, -.60893600E+00, -.20548800E+00, 0.29724300E+01, -.17179400E+00, 0.18841300E+01, 0.18587100E+01, -.11322800E+01, 0.48953800E+00, -.13733400E+00, -.40761700E+00, 0.27840700E+00, 0.47082800E+00, -.17154900E-01, 0.11915200E+01, 0.11190900E+00, -.75425600E+00, -.16597500E+01, -.67761200E+00, -.28102300E-01, -.58129700E+00, -.13921600E+02, -.22978700E+01, 0.11408600E+01, 0.51167300E+00, -.40299900E-01 },
        { -.48822700E+02, 0.13453700E+01, 0.17291900E+01, -.10648100E+01, -.60947200E+01, 0.98141700E+01, -.56353400E+01, 0.43869300E+01, -.19631800E+01, 0.65638200E+01, -.64250600E+00, -.89083900E+01, 0.85022600E+00, -.11344600E+00, 0.23361600E+01, 0.24178600E+01, -.30719600E+01, -.29931000E+00, -.20691800E+01, 0.41106300E+01, 0.70987000E+00, -.63670000E+00, 0.26479600E+01, 0.95009000E+00, -.11658100E-01, 0.19712800E+00, -.17498600E+00, 0.36235600E+01, 0.53632200E+01, 0.99102600E+00, 0.41509500E+01, 0.70787600E+01, -.26683000E+00, -.45488700E+00, -.53825700E+01, 0.51411500E+00, -.57942100E+00, -.10613200E+01, 0.87719300E+00, -.62159100E+00, -.30033600E+00, -.56099600E+00, 0.13931500E+01, -.23338300E+01, 0.12403600E+01, -.96780900E-01, 0.11325800E+01, 0.86643600E-01, -.14768900E+01, 0.23755000E+00, -.81568300E+00, -.89071600E+01, 0.37583500E+00, 0.18562800E+00, 0.80687000E+01, -.23735300E+01, -.16036900E+00, -.24046000E+01, 0.14339800E+01, 0.56799100E-01, -.53349000E+00, -.85138700E+00, -.33004600E+00, 0.20341300E+00, -.41473500E+00, 0.69105200E+00, -.49385800E+00, -.26917200E-01, 0.15689700E+01, -.50624700E-02, -.37088500E+00, 0.95376300E+00, 0.12573800E+01, 0.96320800E-01, -.26684000E+01, -.23373600E+01, 0.18394700E+01, -.95539500E+01, 0.60058600E+00, 0.28057800E+01, 0.17173100E+00, 0.77600200E+00, 0.13615500E+01, -.15240700E+01, 0.56593300E+01, 0.54171700E+01, 0.60108900E+00, 0.45883000E+00, -.27759400E+01, 0.10276800E+01, -.39058200E+00, 0.63452300E-02, 0.24527200E+01, -.81387000E+00, 0.33111500E+00, 0.29010900E+01, 0.55624300E+00, -.15286400E+01, 0.16135700E+00, -.90052300E+00, -.12569300E+00, -.34526500E+00, -.21497000E-01, -.71293000E-01, 0.64859200E+00, 0.16534500E+01, -.15823300E+00, -.75755400E+01, 0.54068300E+00, -.18967900E+00, -.65394100E+01, -.24318900E-01, 0.17868200E+00, 0.39750400E-01, 0.18359900E+00, 0.17084400E+01, -.39170000E+00, 0.44845300E+01, 0.17780900E+00, -.32846100E+01, 0.11882600E+01, 0.17468400E+00, -.36381500E-01, -.53803900E+00, -.75048000E-01, -.20114900E+01, -.85432300E+00, -.14266300E+01, 0.74853700E+00, -.35223500E+01, -.58353600E+01, -.94299200E+00, 0.87089400E+00, -.96728500E-02, -.94050200E+01, 0.13861000E+01, 0.30567000E+00, 0.31118100E+00, 0.32101800E+00, 0.13091600E+01, -.13937600E+01, -.84512600E+00, 0.35172800E-01, 0.91799100E+00, 0.16011300E-01, 0.22092500E+00, 0.20670600E+00, -.44572000E+01, -.10084200E+01, -.20271000E+01, 0.84511200E+00, -.81216600E+00, -.32043200E+01, 0.15129200E+00, -.46053600E-01, -.46127400E+00, -.10561800E+00, 0.16812800E+00, -.35357700E+01, 0.95888100E+00, 0.15034900E+01, -.68866600E+00, 0.34871000E-01, -.39032000E+00, 0.28154300E+00, -.48378800E+00, -.51949700E-01, 0.77456600E+00, 0.51677200E+00, 0.18454700E+00, -.37665100E+00, 0.17180800E+01, 0.26408500E-01, 0.61322700E+01, 0.10863200E+00, -.49013300E-01, -.35155700E+00, -.69842800E-01, 0.17489300E+01, -.48978200E+00, -.74322000E+00, 0.41782300E+01, 0.39207400E+00, -.78560700E+00, -.47692300E-02, 0.41871900E+01, -.39903000E+00, 0.68926100E+00, -.11866900E+00, -.27059900E-01, -.77704000E-02, -.10698000E+00, -.52260600E+01, 0.43684200E+01, 0.71792100E+00, -.84505900E-01, 0.13835500E+02, -.28973700E+01, 0.30771500E+01, 0.36039000E+00, 0.16399000E+01, -.12163800E+00, 0.21014400E+00, -.95254400E+00, 0.88727300E-01, 0.12218000E+00, -.42711700E+00, -.24383800E+01, -.27188800E+01, 0.67965500E-01, -.84017600E-01, 0.46320300E+00, -.32592300E+00, 0.64605500E+00, 0.30995100E+00, 0.31872600E+00, 0.38017000E+00, -.30718500E+00, 0.21947700E+00, -.44851800E-02, -.41208900E+00, -.66569400E-01, -.43038000E+00, -.35156000E-01, 0.96464400E+00, -.16637600E+00, -.13903600E+01, 0.30124100E+00, 0.15844100E+00, 0.10462300E-01, 0.85081600E+00, -.60395500E-01, -.80140400E-02, -.15878600E+01, 0.68921500E-01, 0.17699300E-01, -.70753800E-01, 0.16351400E+00, 0.10121700E+01, -.13228000E+01, 0.40236600E+00, -.43082900E-01, 0.44594200E+01, -.26660700E+00, -.12141500E+01, 0.29838700E-01, -.25661800E+00, -.18231500E+01, 0.10019700E+01, -.14131500E-01, -.51468900E+00, 0.99488800E+00, -.92276300E+00, 0.17751100E+00, -.43216400E-01, 0.17655500E+00, 0.37148700E-01, -.11593000E+00, 0.19254600E+01, -.10663900E+00, -.35952500E+00, 0.58451600E+00, 0.12369600E+01, 0.19804900E+00, -.35653100E+01, -.18378600E-01, -.40081900E+00, -.11974600E+01, -.11225300E+01, -.87329500E+00, 0.46066500E-01, 0.16125400E+01, -.99815800E+00, -.25905500E+01, -.29225600E+00, 0.39674400E+01, -.50319600E+00, -.43560300E+00, -.42596000E+01, 0.85713300E+00, -.88018400E+00, -.55748500E+00, 0.13992100E+01, 0.14358800E+01, -.40844200E+01, 0.10779300E+02, 0.11341500E+01, -.92952100E+00, 0.54639500E+00, 0.26920900E+00, 0.12880100E+00, 0.75783300E+00, -.76567100E+00, 0.53833000E+00, 0.52247200E-01, 0.49360700E+00, -.32650500E+01, -.26616800E-02, 0.13355800E+02, 0.28457800E-01, -.22622300E+01 },
        { 0.71764700E+01, -.23584500E+00, -.27721800E+00, -.54126600E+00, 0.80548700E+00, -.22121200E+01, 0.35642300E+00, -.89973000E+00, 0.18186400E+01, -.13142100E+01, 0.37089800E-01, 0.78024100E+00, 0.45069300E-01, 0.36219000E-01, 0.30772600E+00, -.19751000E+00, 0.99778000E-01, 0.25183400E+00, 0.35923900E+00, -.87895700E+00, -.63276900E+00, 0.74674100E-01, 0.23010300E+01, 0.12109500E+00, -.83043300E-01, -.92794300E-01, -.99909500E-01, -.88112000E+00, -.11419000E+01, -.13373100E+00, -.51851800E+00, -.10380600E+01, 0.70434800E-01, -.67238300E+00, 0.19182300E+01, 0.22968400E+00, 0.63764300E-01, 0.16355400E+01, -.14565100E+00, 0.50347700E+00, -.34611700E+00, -.31685000E+00, -.18984100E+00, 0.45693200E+00, -.70261800E-01, 0.64814400E-01, -.33764100E-01, -.14789800E-01, 0.57802100E+00, -.87675900E-01, 0.54256800E+00, -.15702400E+01, -.10272200E+00, -.14081100E+00, 0.71319800E+00, 0.37425700E+00, -.33089600E-01, -.73779300E-01, -.11147000E+00, 0.13105800E+00, 0.29812600E+00, -.12618400E+00, 0.69011100E-02, -.62586400E-01, -.82409300E-01, -.88407500E-02, -.78464200E-01, -.65344200E-02, -.31308300E+00, -.21659700E-02, -.94373100E-02, 0.23210600E-01, 0.99003300E-02, -.98174600E-01, 0.67294400E-01, 0.78734800E-01, 0.19306900E+00, -.22139500E+00, 0.30681100E+00, -.26574100E+00, -.33460700E-01, 0.20620200E+00, -.68966200E+00, 0.26560600E+00, -.67088700E+00, -.39491900E+01, -.13850200E+00, -.76256500E-01, 0.35861900E+00, -.43029100E+00, 0.15144900E+00, -.30206000E-01, -.30436700E+00, 0.13182500E+00, -.64961100E-01, 0.32015200E+00, -.17854900E-01, 0.19541500E+00, -.14999700E+00, -.91508000E-01, -.41094200E-01, 0.33570200E+00, -.13409000E+00, 0.10974400E+00, 0.15931000E-01, 0.12933400E+00, -.23383700E-01, -.23551000E+01, 0.12564800E+00, -.35466700E-01, -.11603100E+00, -.54840100E-01, 0.10468800E+00, -.12162800E-02, -.17034000E+00, -.68170700E-01, -.70730000E-01, 0.90042500E+00, -.15422700E+00, -.16788800E+00, 0.12189500E+00, 0.53622500E-01, -.13594300E-01, -.16375200E+00, 0.35952300E-02, 0.60693100E+00, 0.69522300E-01, 0.70736600E-01, -.98850900E-01, 0.78136100E-01, -.22147500E+01, 0.13813700E+00, 0.25602600E+00, -.19204400E-01, 0.42780800E-02, -.24750000E+00, 0.32508300E-01, 0.88668500E-01, -.24247700E+00, 0.83214100E-01, -.88238300E-01, 0.38045000E+00, 0.27124600E-01, -.21960700E+00, -.92877600E-02, -.11255100E+00, -.93283500E-02, -.13469200E+00, 0.10934000E-01, 0.61019400E-01, 0.10318800E-01, 0.71909200E-01, -.38581300E+00, -.10673700E+00, -.11467300E-01, -.55842200E-01, 0.31662000E-01, 0.72436200E-03, 0.17826100E+00, 0.14191700E+00, -.10697600E-01, 0.63513700E-01, 0.41282600E-01, 0.97577300E-02, 0.13330600E-01, 0.56425700E-01, 0.50375600E-01, -.13983200E+00, -.81219400E-01, 0.78753300E-01, 0.21485600E+00, 0.40071900E+00, -.25425900E+00, -.11294700E+00, -.82261000E-01, -.12367300E+00, 0.39113500E-01, 0.10597500E-01, 0.18816500E+00, 0.31986600E+00, -.62992700E-01, -.92153400E+00, 0.21767800E-02, 0.46092700E-02, 0.24160300E-01, -.29826000E-01, 0.12288000E+00, -.23913900E-01, 0.94145400E-02, 0.31545600E-01, -.13164100E-02, 0.71111800E-01, 0.74548400E+00, 0.13817300E+00, 0.11602400E+00, 0.58462600E-01, -.43272900E-01, 0.57345100E-01, 0.46551800E-01, -.11599900E-02, 0.35746000E-02, -.60425700E-03, -.89661900E-01, 0.16840100E+00, 0.47074200E-01, -.37473800E-01, -.53436900E-01, 0.18521800E+00, -.26152500E-01, 0.16363800E-01, 0.25292000E-02, -.65966400E-01, -.14278400E-01, -.10479700E+00, 0.41815400E-01, -.17498000E-01, 0.10019800E+00, -.56149300E-01, -.18544700E-01, -.84666000E-02, 0.16649800E-02, -.28279300E-02, 0.25345600E+00, 0.18325800E-01, -.32709100E-01, 0.72132500E-01, 0.25764900E+00, 0.10279700E-01, 0.69248200E-02, 0.93251000E-02, -.79824700E-01, -.64341200E-01, 0.65920700E-02, 0.79971400E-01, 0.26063900E-02, 0.30012600E-01, 0.14907600E-02, 0.19308200E-02, 0.30206500E-01, -.35412500E-01, 0.34410300E-01, -.42820900E-01, -.36748300E-01, -.46667100E-02, -.86840700E-01, 0.12140300E-02, 0.20518600E-01, 0.23466000E+00, -.81770500E-01, 0.79275600E-01, -.10076500E+00, -.14511700E+00, -.70093800E-01, 0.41568100E-01, 0.41454100E-02, -.75900200E-01, -.17460500E-01, -.60299100E-02, -.22821500E+00, -.20683800E+00, -.63239400E-01, 0.10266300E+00, -.41169100E-01, -.17684100E-01, -.19665400E+01, -.10083300E-01, -.46409000E-01, -.10694000E+00, -.34811900E+00, -.71789400E-01, 0.27707600E-01, 0.13210900E+00, -.24537500E-01, -.51209900E-01, -.70562800E-02, 0.37483700E+00, -.71034300E+00, 0.19090500E-01, 0.23633400E+00, 0.16436600E-01, 0.46752200E+00, -.30033600E-03, 0.26752900E+00, -.53911200E-01, 0.13407500E+00, -.14590800E+00, -.70825900E-01, 0.85619200E+00, 0.82217000E-01, -.13946800E+00, -.26406800E-01, 0.17482000E+00, 0.23809100E+00, 0.14137400E+00, 0.35120500E-01, -.96848300E-01, 0.37683800E+00, -.32124300E-01, -.62471100E-03, -.47403000E+00, -.11868200E-01 },
        { 0.43241200E+01, -.85663700E-01, -.14833700E+00, 0.16183600E+01, 0.14562800E+00, -.88675200E+00, 0.59406400E-02, 0.34287600E-02, 0.50127300E-01, -.83275100E+00, 0.30693000E-01, 0.62299200E+00, -.51474700E-01, -.21562500E-01, 0.82961300E+00, -.14580500E+00, 0.27150400E+00, 0.10088200E+00, 0.14924800E+00, -.14381900E+00, 0.14372700E-01, 0.63849600E-01, 0.46585900E+00, -.32787700E-01, 0.23740800E-02, -.90410600E-02, -.51820400E-01, -.66741900E-01, -.17970100E+00, 0.66175800E-02, -.13794700E+00, 0.59432000E-01, 0.22287700E-01, 0.19467300E+00, 0.15451200E-01, -.14373400E+00, 0.75384300E-02, -.41933900E+00, -.16059600E-01, -.88635900E-01, 0.10642600E+00, 0.42733200E+00, -.81002600E-01, -.25458400E+00, 0.13881500E+00, -.24055400E-02, 0.45815700E-01, -.62044700E-02, 0.29704600E-01, 0.60321300E-01, 0.45408800E-01, -.55563200E+00, -.85742300E-02, -.24098600E-01, -.39214500E+00, 0.13418700E+00, -.24279700E-01, 0.40638800E-01, 0.10644400E-01, -.11839700E-01, 0.57678500E-01, 0.27327300E-01, -.58924100E-01, 0.50308100E-02, 0.48134800E-01, -.26911900E-01, 0.18499200E+00, 0.35973100E-03, 0.19518900E-01, 0.35402000E-03, 0.21764000E-01, -.72565300E-01, -.66351300E-01, -.21469800E-01, 0.10946000E+00, 0.10405000E+00, -.58096200E-01, 0.48564900E+00, 0.94305000E-02, -.22493500E+00, -.54347700E-02, -.17240000E-01, -.11485300E+00, 0.84522500E-01, -.31770800E+00, 0.25192700E+00, -.58667500E-01, -.45915800E-02, 0.17375100E+00, 0.27453600E-01, -.35144000E-01, -.62490800E-03, -.11353000E+00, 0.67876600E-01, 0.41347400E-02, -.20110300E+00, -.35714700E-01, 0.15297500E+00, -.55323200E-01, 0.23314100E-01, 0.52717700E-02, 0.31945800E-01, 0.67905400E-01, 0.13242600E+00, -.60699700E-01, -.24948800E+00, -.30688400E-01, 0.81336400E+00, -.29891100E-01, 0.12931400E-02, 0.43433700E+00, -.15164400E-01, 0.47006900E-01, -.63651200E-02, 0.23596000E-01, 0.13781100E-01, 0.17581000E-01, -.10142400E+00, -.10818600E-02, 0.79332600E-01, -.28275100E-01, 0.10545300E-01, 0.72016200E-02, 0.30682200E-01, -.29243500E-03, 0.20914800E+00, 0.49075500E-01, 0.12402800E+00, -.19913100E-01, 0.38210600E+00, 0.12051700E+00, 0.38303100E-01, -.43109100E-01, -.10006200E-01, 0.14866600E+00, -.10830800E+00, -.17251400E-01, 0.40445000E-02, 0.13971700E-01, -.92548100E-01, 0.48211400E-01, 0.18014700E-01, -.48414100E-02, -.18100700E-01, -.10204700E-01, -.15103000E-01, -.57416200E-02, 0.27643100E+00, 0.67485900E-02, 0.22923700E+00, -.30123100E-01, 0.10430400E+00, -.15732700E+00, -.25868700E-01, -.12753500E-01, -.10242100E-01, -.10922100E-01, -.26593400E-01, 0.29206600E+00, -.62302700E-02, -.11638500E+00, 0.19998200E-01, -.46318700E-01, -.77856100E-02, -.17598500E-01, -.12571700E-01, -.11864800E-01, -.52918300E-01, 0.36963900E-02, -.70671700E-01, -.16768200E-01, -.29057100E+00, -.27786500E-01, -.12437900E+00, 0.19257400E-01, -.53540300E-02, 0.12386800E-01, -.13570300E-01, -.17496100E+00, -.56707900E-01, -.12849500E+00, 0.59592600E+00, -.50847300E-01, 0.11659200E+00, 0.13305800E-01, -.13802800E+00, -.30831200E-01, -.15741500E+00, 0.78107400E-02, 0.42632700E-02, 0.92494700E-03, 0.28553600E-01, 0.59404100E-01, -.15941700E+00, -.38268500E-01, 0.28272400E-01, 0.87365700E-01, -.14326900E+00, -.10865500E+00, -.14130400E-01, -.42913100E-01, 0.78152500E-02, -.46811400E-01, 0.16948500E-01, -.13066900E-01, -.35320900E-02, 0.25613800E-01, 0.79546700E-01, 0.15570600E+00, -.31223500E-02, 0.59000600E-03, -.72793800E-01, 0.17871900E-01, -.87422300E-02, -.21814800E-01, -.58446200E-01, -.61731000E-01, -.31110400E-03, -.23451500E-01, -.66781300E-02, 0.33565200E-01, 0.88381300E-02, -.39377600E-01, 0.22753600E-02, -.92962200E-01, -.34106100E-01, 0.91753400E-01, -.20972400E-01, 0.13940800E-01, 0.17393000E-01, -.27738400E-01, -.46347500E-01, -.24197800E-02, 0.15570500E+00, -.49075700E-02, -.63345600E-01, -.40453700E-01, -.48629200E-02, -.69549900E-01, 0.14105800E+00, -.28024900E-01, -.25069900E-01, -.39773200E+00, 0.23386700E-02, 0.66845900E-01, -.40211700E-02, 0.67095400E-02, 0.64849000E-01, -.62559400E-01, -.60544100E-02, -.10774200E-01, 0.78237600E-01, 0.84745100E-01, -.13294000E-01, 0.10503300E-02, 0.11024700E-01, 0.59766800E-02, -.19283900E-01, -.69122400E-01, -.98613700E-02, 0.71920600E-02, -.21757200E-01, -.44736300E-01, -.99203100E-02, 0.85424900E+00, 0.17163600E-02, 0.25647200E-01, 0.11211300E+00, -.76406600E-01, 0.12239700E-01, 0.23760500E-01, -.90753000E-01, 0.41229000E-01, 0.15239200E-01, 0.12987900E-01, -.42123100E-01, 0.90693600E-02, 0.12612500E-01, 0.29793500E+00, -.39574400E-01, 0.32493800E-01, 0.34835500E-01, -.10697600E+00, 0.11524700E+00, 0.68907000E-01, 0.69413600E+00, 0.99305600E-02, 0.73706600E-01, 0.12412600E-01, 0.26164300E-01, -.22884000E-01, -.79156400E-01, -.71316200E-02, -.73866000E-01, -.11609100E-02, 0.34339600E-02, 0.10553800E+00, -.25044100E-02, -.48787700E-01, 0.32032000E-01, -.18344300E+00 }
    },
    {
        { 0.10781300E+07, -.52942500E+06, -.43419800E+06, -.53086500E+06, -.13630400E+06, -.10454400E+06, -.83082400E+05, 0.25562800E+06, -.19405700E+06, -.10777900E+06, -.39295700E+06, -.31581800E+06, 0.15405800E+06, 0.11909400E+06, 0.15651300E+06, 0.14845400E+05, 0.35191600E+04, 0.39314200E+05, -.77435900E+05, 0.56794400E+05, 0.77227300E+04, 0.11701700E+06, -.92178900E+06, 0.45477900E+06, 0.30772300E+06, 0.45663400E+06, 0.11603600E+06, 0.10887000E+06, 0.58611000E+05, -.23350200E+06, 0.14100100E+06, 0.11134100E+06, 0.35448900E+06, 0.44597100E+06, -.22087800E+06, -.20607700E+06, -.22032900E+06, -.40700600E+05, -.19557400E+05, -.51514700E+05, 0.93939800E+05, -.11382800E+06, -.26041500E+05, -.16088200E+06, -.40782700E+06, 0.20299000E+06, 0.13414200E+06, 0.20197300E+06, 0.56500300E+05, 0.57612900E+05, 0.34804900E+05, -.85894500E+05, 0.96588300E+05, 0.51823700E+05, 0.15666400E+06, 0.64137600E+06, -.31883400E+06, -.14637400E+06, -.31685600E+06, -.87932400E+05, -.84320100E+05, -.56608000E+05, 0.13141300E+06, -.16119200E+06, -.76158700E+05, -.25210800E+06, -.46438400E+06, 0.22937000E+06, 0.15477800E+06, 0.23134900E+06, 0.46922800E+05, 0.47693500E+05, 0.37280400E+05, -.11589800E+06, 0.73006600E+05, 0.49169100E+05, 0.18001700E+06, -.46656100E+06, 0.22771800E+06, 0.16792800E+06, 0.23113900E+06, 0.23154900E+05, 0.10500100E+05, 0.56240100E+05, -.11134100E+06, 0.86578600E+05, 0.16418100E+05, 0.18399500E+06, 0.69079300E+06, -.33841000E+06, -.22645200E+06, -.33760700E+06, -.88044600E+05, -.42437200E+05, -.63010600E+05, 0.15550600E+06, -.12067000E+06, -.55877200E+05, -.25266400E+06, 0.75774000E+06, -.37620900E+06, -.28811700E+06, -.37370100E+06, -.80612900E+05, -.70902600E+05, -.68806700E+05, 0.17784000E+06, -.14809600E+06, -.72414700E+05, -.28155200E+06, 0.29746100E+06, -.14588000E+06, -.87154000E+05, -.14837200E+06, -.21541800E+05, -.14586400E+05, -.36285500E+05, 0.58049700E+05, -.69637900E+05, -.16137500E+05, -.12127600E+06, -.46477700E+06, 0.23039400E+06, 0.94211600E+05, 0.23040400E+06, 0.84607600E+05, 0.92619100E+05, -.15056700E+04, -.12011800E+06, 0.70016600E+05, 0.87414000E+05, 0.19370100E+06, -.71383300E+06, 0.35114400E+06, 0.22912800E+06, 0.35406000E+06, 0.76627900E+05, 0.62798300E+05, 0.66650300E+05, -.16023600E+06, 0.13506200E+06, 0.64343500E+05, 0.28060500E+06, 0.67892000E+06, -.33272300E+06, -.19211900E+06, -.33772600E+06, -.88498800E+05, -.67279700E+05, -.48623500E+05, 0.14133200E+06, -.16522000E+06, -.69552400E+05, -.27107900E+06, 0.84537000E+06, -.41760700E+06, -.28883700E+06, -.42036200E+06, -.99021000E+05, -.98030700E+05, -.57218500E+05, 0.21690300E+06, -.12279500E+06, -.10082600E+06, -.32306700E+06, -.48129200E+06, 0.23862400E+06, 0.19611200E+06, 0.23411600E+06, 0.66420800E+05, 0.69926800E+05, 0.26508100E+05, -.13488300E+06, 0.58034900E+05, 0.67080200E+05, 0.17852200E+06, 0.48433300E+06, -.23609300E+06, -.78264000E+05, -.24026400E+06, -.35947600E+05, 0.15800300E+05, -.80747100E+05, 0.64403600E+05, -.15047700E+06, 0.63353000E+04, -.17939400E+06, -.49153700E+06, 0.24095000E+06, 0.12473100E+06, 0.24486600E+06, 0.60826800E+05, 0.41993100E+05, 0.41844200E+05, -.95492300E+05, 0.13304600E+06, 0.43974500E+05, 0.19534000E+06, 0.60461900E+06, -.29944800E+06, -.97940800E+05, -.29819400E+06, -.11715700E+06, -.13690200E+06, 0.40975900E+04, 0.14651100E+06, -.11646500E+06, -.12189700E+06, -.26251200E+06, -.29250800E+06, 0.14553900E+06, 0.10547500E+06, 0.14497200E+06, 0.15872700E+05, -.10176600E+04, 0.44826800E+05, -.54605700E+05, 0.81141200E+05, 0.65638800E+04, 0.10598600E+06, 0.31973200E+06, -.15461200E+06, -.46259100E+05, -.15916300E+06, -.91038300E+04, 0.29859200E+05, -.62559000E+05, 0.33950800E+05, -.10390900E+06, 0.20324600E+05, -.12354000E+06, 0.70244900E+06, -.34591800E+06, -.25346100E+06, -.34759800E+06, -.81217100E+05, -.54009800E+05, -.59818000E+05, 0.14803300E+06, -.16879100E+06, -.58878800E+05, -.27055700E+06, -.68898500E+06, 0.33996400E+06, 0.23530300E+06, 0.33701900E+06, 0.98419600E+05, 0.85439900E+05, 0.43096900E+05, -.16889200E+06, 0.10146700E+06, 0.85075700E+05, 0.25198300E+06, 0.49498700E+06, -.24222900E+06, -.17900100E+06, -.24407000E+06, -.60142500E+05, -.60040800E+05, -.34538300E+05, 0.10579600E+06, -.97757000E+05, -.53950400E+05, -.19315400E+06, -.19027500E+06, -.14002600E+05, -.12149300E+06, -.14628400E+05, -.93016400E+05, -.88498300E+04, -.30357500E+05, -.43327300E+05, 0.11626100E+06, -.11747700E+06, -.53797500E+05, 0.79162500E+05, -.11300200E+06, 0.43108500E+05, -.50353300E+05, -.24427900E+05, -.78828700E+04, 0.12515900E+06, -.60340400E+05, -.13318300E+06, -.89697400E+05, -.14999700E+06, 0.76717500E+05, 0.61846400E+05, 0.14123500E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22600100E+00, 0.16731900E+05, -.80743000E+05, -.39395900E+04, 0.10299100E+06, 0.23678900E+06, -.11838600E+06, -.91524500E+05, -.90272700E+05, 0.19890500E+06, 0.16029400E+05, -.55691900E+05, 0.20997000E+05, 0.22924600E+05, 0.28515500E+05, -.19210900E+05, -.66895100E+05, 0.38982700E+05, 0.15236100E+05, 0.46328300E+05, -.54189200E+05, 0.15910800E+05, 0.16664900E+06, -.93503700E+05, 0.40759500E+05, -.81294500E+05, -.87315800E+05, -.17284200E+06, 0.63609300E+05, 0.83213100E+05, 0.22003400E+05, -.14319900E+06, -.73830600E+05, 0.65900300E+05, -.31290400E+05, -.32770100E+05, -.34232400E+05, 0.39437100E+05, 0.95558600E+05, -.47179900E+05, -.10401700E+04, -.40279900E+05, 0.77290800E+05, -.17140200E+05, 0.21427400E+06, -.10692300E+06, -.53274500E+04, -.10620600E+06, -.40361200E+05, -.50375800E+05, -.48758500E+04, 0.50466600E+05, -.55302800E+05, -.40577000E+05, -.98895200E+05, -.37674300E+06, 0.18733600E+06, -.63026400E+05, 0.18653100E+06, 0.73935500E+05, 0.91663900E+05, 0.86343500E+04, -.77918700E+05, 0.10848700E+06, 0.72119100E+05, 0.18387700E+06, 0.85791500E+05, -.47124600E+05, 0.15213900E+05, -.42494900E+05, -.35342300E+05, -.82346300E+05, 0.28125200E+05, 0.39929200E+05, 0.96012700E+04, -.67664200E+05, -.41326700E+05, -.57681500E+05, 0.19576500E+05, 0.35598600E+05, 0.29868200E+05, -.30392600E+05, -.98616900E+05, 0.54347800E+05, 0.24881700E+05, 0.57817600E+05, -.79631700E+05, 0.15004200E+05, 0.71459800E+05, -.22173300E+05, -.95923300E+05, -.39476100E+05, 0.71444800E+05, 0.17651800E+06, -.98520400E+05, -.57915800E+05, -.85077200E+05, 0.14680400E+06, -.17287200E+05, -.19054100E+06, 0.95832400E+05, 0.82771500E+05, 0.92790900E+05, 0.46200500E+05, 0.84719800E+05, -.16591600E+05, -.63115500E+05, 0.15944700E+05, 0.67885000E+05, 0.82010300E+05, -.13012100E+05, 0.10627100E+05, -.53235800E+05, 0.63356000E+04, 0.21440300E+05, 0.68978900E+05, -.31902000E+05, -.25343900E+05, -.13678700E+05, 0.56443700E+05, 0.16796400E+05, 0.24406600E+06, -.12055000E+06, -.99579400E+04, -.12108000E+06, -.60829000E+05, -.73909800E+05, 0.94048100E+04, 0.61651300E+05, -.46561600E+05, -.62687900E+05, -.10824400E+06, 0.87824000E+05, -.53294500E+05, 0.77495200E+05, -.42545400E+05, -.60716900E+05, -.14935600E+06, 0.62977400E+05, 0.70011600E+05, 0.25252600E+05, -.12353100E+06, -.57134100E+05, -.11624600E+06, 0.74559800E+05, -.60812500E+05, 0.57290700E+05, 0.71068000E+05, 0.13348000E+06, -.52502400E+05, -.55968500E+05, 0.66396600E+04, 0.10847200E+06, 0.62567800E+05, -.15837900E+06, 0.86647400E+05, -.20620000E+05, 0.78086200E+05, 0.71005700E+05, 0.15046600E+06, -.52834800E+05, -.74783300E+05, -.20740400E+05, 0.12478100E+06, 0.70024900E+05, 0.16815600E+06, -.82524800E+05, -.93610600E+05, -.80941700E+05, -.34814900E+05, -.51214500E+05, 0.35709400E+04, 0.55365600E+05, -.92897600E+04, -.43552000E+05, -.62042800E+05, 0.16751800E+06, -.65628700E+05, -.25823800E+06, -.84675100E+05, 0.64092300E+05, 0.18242000E+06, -.11070900E+06, -.25930800E+05, -.75782200E+05, 0.14899000E+06, -.32858400E+05, 0.92260400E+05, -.58000700E+05, 0.58292900E+05, -.45697200E+05, -.52840900E+05, -.10003800E+06, 0.36336500E+05, 0.36700800E+05, -.14321800E+05, -.80178100E+05, -.52135000E+05, -.44082500E+06, 0.21852600E+06, -.57258800E+05, 0.21842700E+06, 0.88774000E+05, 0.10497600E+06, 0.20635000E+04, -.90577800E+05, 0.11793400E+06, 0.86724400E+05, 0.20636800E+06, 0.94135900E+04, -.46125400E+04, -.20098900E+05, -.40889600E+04, -.11216200E+05, -.29678700E+05, 0.12202000E+05, 0.79921000E+04, 0.46825400E+04, -.22233800E+05, -.10528000E+05, 0.17052500E+06, -.70670600E+05, -.12597200E+06, -.85600600E+05, 0.35313600E+05, 0.12176300E+06, -.83847100E+05, -.18059400E+05, -.75188300E+05, 0.10067800E+06, -.55185700E+05, 0.14626100E+05, 0.13604000E+04, -.97137700E+05, -.90603700E+04, 0.73876100E+05, 0.16319700E+06, -.77267100E+05, -.30551600E+05, -.39763800E+05, 0.13237600E+06, 0.10981200E+05, 0.10602500E+06, -.58352600E+05, 0.42007700E+05, -.49421600E+05, -.67017800E+05, -.13991300E+06, 0.61846800E+05, 0.84583500E+05, 0.30135600E+05, -.11964000E+06, -.56419400E+05, -.67310300E+05, 0.40001700E+05, -.36655600E+05, 0.32008100E+05, 0.42921100E+05, 0.10317500E+06, -.51602300E+05, -.65420900E+05, -.19625700E+05, 0.89343200E+05, 0.43295000E+05, 0.22132700E+05, -.15730100E+05, 0.69931700E+05, 0.40115600E+04, 0.94337500E+05, 0.71391100E+05, 0.92440600E+05, 0.22352900E+05, -.64442500E+05, 0.39863600E+05, 0.12048200E+06, -.47998700E+05, -.50414100E+05, -.29142300E+05, -.18130100E+05, 0.10457700E+05, 0.10579100E+06, -.72616500E+05, -.57556400E+04, -.24285800E+05, 0.13951900E+06, 0.54658100E+05, -.50329200E+05, 0.34433000E+04, -.16119100E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39679200E-01, 0.90780900E-01, 0.73493400E+05, 0.89863100E+03, 0.64407800E+05, 0.85929100E+05, -.12843600E+06, -.72200700E+05, -.62215800E+05, 0.84115100E+05, -.49375400E+04, -.68516000E+05, 0.34220800E+05, -.18400100E+04, 0.34103900E+05, -.52541900E+04, -.77999000E+04, 0.18279500E+05, -.38236400E+04, 0.23676000E+05, -.59455900E+04, 0.30942000E+05, -.33666700E+05, 0.16870300E+05, -.92607100E+05, 0.16362200E+05, -.58144000E+05, -.82071000E+05, 0.11874600E+06, 0.66060200E+05, 0.78680500E+05, -.79812400E+05, 0.22918300E+05, 0.54282600E+05, -.26898400E+05, -.88601000E+04, -.26850600E+05, 0.24607900E+04, 0.38953200E+04, -.22224900E+05, 0.58345200E+03, -.22633400E+05, 0.36392800E+04, -.24009900E+05, -.12318200E+06, 0.61380200E+05, 0.32835800E+05, 0.61378200E+05, 0.12812100E+05, 0.12633500E+05, 0.26552000E+05, -.65301900E+03, 0.41038500E+05, 0.10675500E+05, 0.47748800E+05, 0.19643800E+06, -.97679200E+05, -.22391600E+05, -.97799500E+05, -.22829300E+05, -.22757300E+05, -.34361300E+05, 0.10584100E+05, -.66025800E+05, -.18908700E+05, -.81407600E+05, -.73824400E+05, 0.36836500E+05, -.22011200E+05, 0.36818400E+05, -.12394400E+05, -.19082400E+05, 0.41333100E+05, 0.14448600E+05, 0.43229300E+05, -.18555100E+05, 0.33483700E+05, -.10881100E+06, 0.54366500E+05, -.40376800E+04, 0.54169100E+05, -.80372500E+04, -.11948500E+05, 0.31654900E+05, -.95023500E+03, 0.41056400E+05, -.94254900E+04, 0.50215300E+05, 0.14231100E+04, -.90304900E+03, 0.86323200E+05, 0.14040400E+03, 0.49781500E+05, 0.74039200E+05, -.93089000E+05, -.53336000E+05, -.53496200E+05, 0.68850500E+05, -.60907000E+04, 0.16536900E+06, -.82182300E+05, 0.88796100E+04, -.82117400E+05, 0.15220700E+05, 0.31489500E+05, -.70637100E+05, -.65344400E+04, -.72204200E+05, 0.28455900E+05, -.72888800E+05, 0.74987700E+05, -.37433000E+05, 0.14177700E+04, -.37454200E+05, -.25710000E+04, -.14647900E+04, -.19320400E+05, -.62456900E+03, -.29233200E+05, -.96107700E+03, -.31339800E+05, 0.82987000E+05, -.42122400E+05, -.15120600E+06, -.41711300E+05, -.81741800E+05, -.11454800E+06, 0.12475900E+06, 0.83174600E+05, 0.52849100E+05, -.11074400E+06, -.18775900E+05, -.11366000E+06, 0.56759500E+05, -.24179400E+05, 0.56514900E+05, -.10132900E+05, -.19289300E+05, 0.59396400E+05, 0.19590500E+05, 0.62069200E+05, -.19521700E+05, 0.47785100E+05, -.26551900E+05, 0.12653400E+05, 0.11152400E+06, 0.13466000E+05, 0.64282800E+05, 0.92246300E+05, -.10851700E+06, -.50256000E+05, -.45400500E+05, 0.86800600E+05, -.17677500E+04, 0.66387700E+05, -.33063900E+05, 0.69049300E+05, -.32935800E+05, 0.42663100E+05, 0.61493100E+05, -.96235000E+05, -.48960600E+05, -.75159900E+05, 0.59846200E+05, -.33363200E+05, -.64332600E+05, 0.31554900E+05, -.16471700E+05, 0.31450600E+05, -.16274100E+05, -.28283600E+05, 0.43268800E+05, 0.60580000E+04, 0.35000700E+05, -.25809000E+05, 0.29627500E+05, 0.14902800E+06, -.75448200E+05, 0.34612600E+05, -.74305800E+05, -.94616000E+04, -.68687700E+04, -.37891300E+05, -.10013800E+05, -.60526900E+05, -.54282200E+04, -.63376800E+05, -.30453700E+05, 0.15687900E+05, -.59587500E+05, 0.15127900E+05, -.28702100E+05, -.44101400E+05, 0.59440800E+05, 0.19146000E+05, 0.36499400E+05, -.41118200E+05, 0.21104300E+05, -.88707800E+05, 0.45209500E+05, 0.14751000E+06, 0.44804800E+05, 0.76575400E+05, 0.10208500E+06, -.12917400E+06, -.87524200E+05, -.55550500E+05, 0.10288000E+06, 0.19813500E+05, -.10966900E+06, 0.54637500E+05, 0.48934000E+04, 0.54694200E+05, -.82420900E+03, -.90223100E+04, 0.27252400E+05, -.41777600E+04, 0.39917600E+05, -.65085300E+04, 0.47568300E+05, 0.14672300E+06, -.74019300E+05, 0.26755500E+05, -.73284500E+05, 0.40172400E+04, 0.14691100E+05, -.47492700E+05, -.15887300E+05, -.61831900E+05, 0.11172400E+05, -.62498400E+05, -.27501500E+05, 0.13789100E+05, 0.83838500E+05, 0.14147700E+05, 0.53235500E+05, 0.71661300E+05, -.96754700E+05, -.50186800E+05, -.37471300E+05, 0.69772000E+05, 0.32873900E+04, -.90224700E+04, 0.41965100E+04, -.69474600E+05, 0.36926500E+04, -.48823000E+05, -.67465500E+05, 0.97630500E+05, 0.58596100E+05, 0.56139500E+05, -.65759400E+05, 0.78798800E+04, 0.30664000E+05, -.14938400E+05, 0.29094700E+05, -.14956400E+05, 0.34257900E+05, 0.43697200E+05, -.79205700E+05, -.49295900E+05, -.48967300E+05, 0.43688800E+05, -.13506100E+05, -.10707700E+05, 0.27516300E+05, 0.22394600E+04, 0.17521100E+05, 0.13602000E+05, 0.56854800E+05, 0.51405400E+05, 0.26445200E+05, -.60404600E+04, -.11180700E+05, 0.27968500E+05, -.39598700E+05, -.25275300E+05, -.37708900E+05, 0.26912600E+05, 0.23593500E+05, 0.31661300E+05, -.19774400E+05, 0.39635100E+05, -.36761100E+05, 0.24993000E+05, 0.12653100E+05, -.28985700E+04, 0.20336700E+05, 0.55617200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.87809300E-01, 0.22550600E+00, 0.38620100E+00, -.64525800E+04, 0.41327400E+05, -.64432700E+05, 0.74042800E+05, 0.87044100E+05, 0.59451700E+05, -.54509400E+05, -.91329900E+05, -.62110300E+05, 0.30177800E+05, 0.20578200E+05, 0.32100600E+05, -.53187300E+04, 0.21717200E+05, -.60343200E+04, -.30024200E+05, -.12792100E+04, 0.17543300E+05, 0.55597000E+05, -.10192800E+06, 0.51477300E+05, 0.27543000E+05, 0.54019800E+05, 0.22646900E+03, 0.59984100E+05, -.44731200E+05, -.67612900E+05, -.15210700E+05, 0.49257000E+05, 0.99847000E+05, -.14423800E+05, 0.81565400E+04, 0.63394700E+04, 0.50564200E+04, 0.27236400E+05, -.11754200E+05, 0.14286000E+05, 0.98288400E+04, 0.12502700E+05, -.70483400E+04, -.33128000E+05, -.73546700E+04, 0.28553500E+04, 0.15618300E+04, 0.51918700E+04, -.28351700E+05, 0.75965600E+04, -.17696500E+05, -.34123300E+05, -.12880100E+05, 0.30678800E+04, 0.39207600E+05, 0.33843000E+05, -.14641600E+05, 0.78519800E+04, -.19942700E+05, 0.42757800E+05, -.13364400E+05, 0.19132100E+05, 0.43730000E+05, 0.71569500E+04, -.60954000E+04, -.66694700E+05, -.81411900E+05, 0.39777200E+05, 0.10600600E+05, 0.41279200E+05, 0.50622700E+04, 0.33115900E+05, -.15943500E+05, -.38824400E+05, -.15812700E+04, 0.26107200E+05, 0.66641200E+05, -.10158600E+06, 0.50612700E+05, 0.30133000E+05, 0.52401300E+05, -.53448400E+04, 0.33369200E+05, -.96421800E+04, -.47246500E+05, 0.18456400E+04, 0.26538000E+05, 0.80674800E+05, -.60003400E+05, 0.29012000E+05, 0.29986200E+05, 0.23778400E+05, 0.30389400E+05, -.43459300E+05, 0.60644000E+05, 0.52671600E+05, 0.59626500E+05, -.37282500E+05, -.32786900E+05, 0.64054000E+05, -.29784700E+05, -.25203000E+05, -.36041000E+05, 0.31586000E+05, -.24514900E+05, 0.23370100E+05, 0.52959700E+05, 0.13942200E+05, -.16330800E+05, -.85681900E+05, 0.36521100E+05, -.18572000E+05, 0.38703600E+03, -.18512800E+05, 0.66313300E+04, -.25838000E+05, 0.18774900E+05, 0.37945400E+05, 0.71260700E+04, -.20602800E+05, -.43408600E+05, -.89158600E+05, 0.41087400E+05, 0.43721400E+05, 0.46123900E+05, 0.20283300E+04, 0.35644300E+05, -.31969300E+05, -.44514900E+05, -.48496000E+04, 0.32442500E+05, 0.54695400E+05, -.50882200E+05, 0.24953100E+05, 0.64673400E+04, 0.27560600E+05, -.15528300E+05, 0.51987500E+05, -.44422600E+05, -.74121300E+05, -.30088300E+05, 0.42443000E+05, 0.81514800E+05, 0.39727200E+05, -.22918400E+05, -.38678800E+04, -.21217500E+05, 0.21614500E+05, -.41377500E+05, 0.38706100E+05, 0.36809200E+05, 0.10689000E+05, -.32154600E+05, -.57699000E+05, 0.11873900E+06, -.58109700E+05, -.22095600E+05, -.60958200E+05, -.89267800E+04, -.57870600E+05, 0.35814300E+05, 0.63755700E+05, 0.86073700E+04, -.46783500E+05, -.10458700E+06, -.51877600E+05, 0.22789500E+05, 0.25204500E+05, 0.31066300E+05, -.16920100E+05, 0.13539300E+05, -.93539200E+04, -.29906900E+05, -.97025400E+04, 0.97451800E+04, 0.50646200E+05, -.99573000E+05, 0.45041000E+05, 0.71299800E+05, 0.48264600E+05, 0.34941600E+05, -.36391100E+05, 0.55072000E+05, 0.43434400E+05, 0.49264000E+05, -.30249300E+05, -.18010800E+05, -.13017100E+05, 0.89373900E+04, -.11416300E+05, 0.72127600E+04, -.22650900E+05, 0.23714700E+05, -.22946300E+05, -.18268800E+05, -.51549500E+04, 0.17000900E+05, 0.36705900E+05, 0.13167300E+06, -.61190100E+05, -.31781900E+05, -.69146100E+05, 0.46800200E+04, -.45847800E+05, 0.35322400E+05, 0.55399700E+05, -.97616700E+04, -.39822100E+05, -.77052500E+05, -.52237200E+04, 0.19972700E+04, 0.43171600E+04, 0.36387700E+04, -.16472200E+05, 0.58652000E+04, -.10092300E+05, -.16801500E+05, -.60535000E+04, 0.27083900E+04, 0.31794300E+05, -.69343800E+05, 0.31358600E+05, 0.51806900E+05, 0.34117800E+05, 0.23594300E+05, -.24062600E+05, 0.45311400E+05, 0.44667100E+05, 0.39165900E+05, -.21287200E+05, -.12660300E+05, 0.18030100E+05, -.89004500E+04, 0.30321100E+04, -.11927200E+05, 0.25177000E+05, -.43378500E+05, 0.43442600E+05, 0.40063700E+05, 0.20934800E+05, -.34047300E+05, -.60293300E+05, -.12267100E+05, 0.45849400E+04, -.67382200E+04, 0.12033800E+05, -.22188100E+05, 0.44447000E+05, -.53322900E+05, -.68274000E+05, -.39794900E+05, 0.38601900E+05, 0.64376300E+05, 0.37855300E+05, -.16433800E+05, 0.88183100E+03, -.21623100E+05, 0.15227800E+05, -.41664500E+05, 0.47422700E+05, 0.71439900E+05, 0.25172200E+05, -.36873200E+05, -.64178000E+05, -.26646500E+04, 0.10779200E+05, 0.16048500E+05, 0.60556100E+05, -.42326800E+05, -.26517600E+05, -.32445500E+05, 0.61101100E+05, -.20580000E+05, -.12769000E+05, -.32105800E+05, -.20264500E+05, 0.18997500E+05, -.31321400E+05, -.22543100E+05, 0.66702100E+05, -.27426700E+05, 0.16551400E+05, -.32608400E+05, 0.16741100E+05, -.41496000E+05, -.16638300E+05, 0.26488900E+05, -.58680100E+04, -.73962500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21078900E+00, -.11212000E+00, 0.14183800E+01, 0.92439600E+00, -.91118700E+05, -.29467500E+04, 0.91325200E+05, 0.26232300E+04, -.49635000E+05, -.85389000E+04, 0.61769600E+05, 0.12105700E+06, -.59600200E+05, -.42547400E+05, -.60483200E+05, -.52423400E+03, -.34683800E+05, -.69876700E+04, 0.35012600E+05, 0.35009200E+04, -.30985500E+05, -.76222900E+05, 0.12007800E+06, -.60763000E+05, -.45372900E+05, -.59797600E+05, 0.50936700E+05, 0.70508900E+04, -.99234800E+05, -.56474500E+04, 0.52333600E+04, 0.10881900E+05, -.88181500E+05, -.28773900E+05, 0.13019000E+05, 0.53577000E+04, 0.14437100E+05, -.14702400E+05, 0.26027700E+05, 0.66549500E+04, -.86413300E+04, -.12044600E+05, 0.23041800E+05, 0.44324000E+05, 0.14826100E+06, -.73047300E+05, -.99656600E+05, -.74120500E+05, 0.15122100E+05, -.13928600E+05, -.30981600E+05, 0.19299300E+05, -.19125200E+05, -.12950900E+05, -.72771600E+05, -.17540300E+06, 0.84233000E+05, 0.13520400E+06, 0.87707100E+05, -.28818100E+05, 0.17466300E+05, 0.35030700E+05, -.30442300E+05, 0.12288700E+05, 0.17261200E+05, 0.93834000E+05, 0.16090100E+06, -.79498100E+05, -.54458900E+05, -.80375900E+05, -.28125800E+04, -.28781300E+05, -.31788200E+05, 0.26316700E+05, -.61949600E+04, -.24580700E+05, -.89199500E+05, 0.19728600E+06, -.98292500E+05, -.69363200E+05, -.98576800E+05, -.17604400E+04, -.48647300E+05, -.18526200E+05, 0.45461700E+05, -.56783100E+04, -.43410600E+05, -.11643700E+06, 0.70952700E+05, -.34177300E+05, -.35328600E+05, -.35398400E+05, -.67640000E+05, -.87655100E+04, 0.51940200E+05, 0.15388700E+05, -.49645800E+05, -.92396500E+04, 0.74864100E+04, -.26766900E+06, 0.13056100E+06, 0.96616200E+05, 0.13379100E+06, -.25344900E+05, 0.14456000E+05, 0.63463300E+05, -.49007400E+05, 0.26227400E+05, 0.11726700E+05, 0.14874700E+06, -.90902000E+05, 0.45512600E+05, 0.39576200E+05, 0.45426800E+05, 0.99243600E+03, 0.32729400E+05, 0.50511800E+04, -.25043000E+05, -.13043200E+04, 0.29110600E+05, 0.53754100E+05, -.81445100E+05, 0.45998200E+05, 0.51145200E+05, 0.40736800E+05, 0.10027800E+06, 0.10086500E+06, -.12002300E+06, -.61609600E+05, 0.42421700E+04, 0.96427000E+05, 0.15064300E+05, 0.15513800E+06, -.76948300E+05, -.79183300E+05, -.77462800E+05, 0.15676600E+05, -.46702900E+05, -.30994600E+05, 0.40559300E+05, 0.17764700E+05, -.41077900E+05, -.98868200E+05, 0.13076800E+06, -.60436700E+05, -.64388600E+05, -.65392000E+05, -.10094600E+06, -.68559900E+05, 0.86370100E+05, 0.39063100E+05, -.32331000E+05, -.65901700E+05, -.18267000E+05, -.19562800E+06, 0.96442400E+05, 0.63463400E+05, 0.97617600E+05, -.19785900E+05, 0.18322200E+05, 0.78809500E+05, -.16765000E+05, 0.43166800E+04, 0.12862700E+05, 0.11692900E+06, 0.17313700E+06, -.81695800E+05, -.64705800E+05, -.86560000E+05, 0.13944500E+05, -.67632300E+04, -.40663400E+05, 0.47044400E+05, -.17843600E+04, -.50534100E+04, -.88349700E+05, 0.56826300E+05, -.21109800E+05, -.27997300E+05, -.28393900E+05, -.25472400E+05, 0.48271000E+05, -.11457000E+05, 0.13002200E+05, -.37507200E+05, 0.45154700E+05, 0.10793600E+05, -.70157600E+05, 0.31189400E+05, 0.29617600E+05, 0.35083300E+05, 0.59416000E+05, 0.29174500E+05, -.41035400E+05, -.18923000E+05, 0.22267600E+05, 0.27967900E+05, 0.39536400E+04, 0.11730500E+06, -.65695200E+05, -.23244400E+05, -.58599800E+05, -.11969900E+06, -.10654700E+06, 0.13078600E+06, 0.72826900E+05, -.13765400E+05, -.10258200E+06, -.29570400E+05, 0.11984600E+06, -.59073300E+05, -.36075300E+05, -.59936800E+05, 0.70262500E+04, -.91280000E+04, -.20642900E+05, 0.11916000E+05, -.25595000E+05, -.92792900E+04, -.72483100E+05, -.32854300E+05, 0.21541600E+05, -.15519300E+05, 0.16427500E+05, -.16050500E+05, 0.29480600E+05, 0.11731600E+05, 0.15348400E+05, 0.31687000E+04, 0.28225700E+05, 0.35367700E+05, 0.11448700E+06, -.57444200E+05, -.64947000E+05, -.57197800E+05, -.82567900E+05, -.33676200E+05, 0.71243000E+05, 0.36147300E+05, -.38377100E+05, -.35999400E+05, -.31246900E+04, 0.37022400E+05, -.15978400E+05, -.15297700E+05, -.18527700E+05, 0.63152300E+05, 0.15939000E+05, -.76409900E+05, -.22133500E+04, 0.19463700E+05, 0.16981400E+05, -.49839400E+05, -.74040600E+05, 0.33494000E+05, 0.28493100E+05, 0.37018900E+05, -.47097900E+05, -.55776100E+04, 0.67634100E+05, 0.11592400E+05, 0.48098700E+04, -.74524800E+04, 0.58168600E+05, 0.50075500E+04, 0.66978700E+04, -.11331300E+05, -.64374900E+05, 0.38611100E+04, 0.76778500E+04, 0.41346800E+04, -.75202600E+05, 0.20764700E+05, 0.17331000E+05, -.30129100E+04, 0.46966900E+05, 0.44417900E+05, 0.54010600E+05, 0.77514800E+04, -.78242900E+05, -.23484400E+05, -.13259300E+05, -.18688200E+04, 0.38859600E+05, 0.11938200E+05, -.56550800E+03, -.10456400E+05, 0.88993600E+04, 0.67559200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11586500E+01, 0.24005600E+01, 0.16913900E+01, -.23837500E+01, 0.41094300E+01, -.10562700E+07, 0.47585900E+06, 0.77329400E+06, 0.86195600E+06, -.90408300E+06, -.50853600E+06, -.34012000E+06, 0.16382400E+06, 0.20218000E+06, 0.16975800E+06, 0.72348300E+05, 0.42561400E+06, -.15526300E+06, -.28923000E+06, -.23973000E+06, 0.36008300E+06, 0.32932400E+06, -.10970600E+07, 0.55354800E+06, 0.44090000E+06, 0.54690400E+06, 0.20093000E+06, 0.82663200E+06, -.18782000E+06, -.65055500E+06, -.42242200E+06, 0.69998500E+06, 0.72134500E+06, -.19122600E+06, 0.10568300E+06, 0.77363500E+05, 0.95268100E+05, -.14483100E+05, -.43342300E+06, 0.19368600E+06, 0.94784300E+05, 0.25960700E+06, -.36009600E+06, -.16449900E+06, -.92191400E+06, 0.45290300E+06, 0.36723200E+06, 0.46089000E+06, -.31122000E+05, 0.20308300E+06, 0.12399700E+03, -.37451400E+06, 0.55893600E+05, 0.16718200E+06, 0.55776300E+06, 0.13528000E+07, -.65114300E+06, -.36433400E+06, -.67643500E+06, 0.46697800E+05, -.32220100E+06, -.20347200E+04, 0.50672900E+06, -.10469600E+06, -.26301600E+06, -.85430300E+06, -.91578300E+06, 0.45128100E+06, 0.31686200E+06, 0.45739100E+06, 0.17056400E+06, 0.49819500E+06, -.10827300E+06, -.41505500E+06, -.17163800E+06, 0.42300200E+06, 0.55017200E+06, -.62633000E+06, 0.31062000E+06, 0.31616600E+06, 0.31272800E+06, 0.12331900E+06, 0.61911400E+06, -.20565500E+06, -.43047800E+06, -.29436200E+06, 0.52186700E+06, 0.50196100E+06, -.68959600E+06, 0.33526100E+06, 0.23736000E+06, 0.34427700E+06, 0.13712900E+05, -.77672100E+06, 0.46247800E+06, 0.44677800E+06, 0.79966100E+06, -.66603300E+06, -.29801200E+05, 0.14404500E+07, -.69620300E+06, -.79877300E+06, -.71993500E+06, -.20898300E+05, -.47250700E+06, 0.32105400E+05, 0.61554100E+06, 0.11443400E+06, -.38593600E+06, -.87834000E+06, 0.25953400E+06, -.12982000E+06, -.28765500E+05, -.12960400E+06, -.45184300E+05, -.39920000E+06, 0.18903800E+06, 0.31154200E+06, 0.18284400E+06, -.34034600E+06, -.28199100E+06, -.66906300E+06, 0.29600500E+06, 0.30279800E+06, 0.33443600E+06, -.49629500E+05, 0.13833600E+06, 0.10738100E+06, -.25458000E+06, -.83686400E+05, 0.10962000E+06, 0.37215600E+06, -.68487700E+06, 0.33791500E+06, 0.23136000E+06, 0.34172700E+06, 0.10893800E+06, 0.81648500E+06, -.34735200E+06, -.70018300E+06, -.46684100E+06, 0.70250800E+06, 0.63918500E+06, -.96130900E+05, 0.12206600E+05, 0.10715100E+06, 0.48120900E+05, 0.11033600E+06, -.40618400E+06, 0.11732700E+06, 0.21337300E+06, 0.28878800E+06, -.31630500E+06, -.20986000E+06, 0.13636600E+07, -.67222800E+06, -.51212400E+06, -.68050700E+06, -.26929600E+06, -.81906200E+06, 0.17042900E+06, 0.66728000E+06, 0.35004000E+06, -.69659800E+06, -.82163000E+06, -.12871200E+07, 0.60776300E+06, 0.72600200E+06, 0.64350000E+06, 0.73451500E+05, 0.31309100E+06, 0.34472200E+05, -.50114300E+06, -.95597700E+05, 0.26596400E+06, 0.62671000E+06, -.15066900E+07, 0.69989800E+06, 0.94179900E+06, 0.75321100E+06, 0.28452200E+05, -.79871100E+06, 0.65764000E+06, 0.22233200E+06, 0.74198600E+06, -.68898900E+06, 0.21970500E+06, 0.10336800E+06, -.23479500E+05, -.12221400E+06, -.51715200E+05, -.72246100E+05, 0.32473000E+06, -.11900600E+06, -.12010600E+06, -.18156400E+06, 0.25440500E+06, 0.14638900E+06, 0.11428200E+07, -.51988200E+06, -.20287800E+06, -.57177800E+06, 0.85814800E+05, -.17678900E+06, -.16721500E+06, 0.33207800E+06, -.85434900E+05, -.13594700E+06, -.62400400E+06, -.22727000E+06, 0.10767100E+06, 0.21171400E+06, 0.11372900E+06, -.24512200E+05, 0.17090300E+06, -.59607400E+05, -.13399700E+06, -.48849100E+05, 0.13716600E+06, 0.27077800E+06, -.10894000E+07, 0.50720100E+06, 0.50897000E+06, 0.54469900E+06, 0.97635600E+04, -.58373600E+06, 0.49546200E+06, 0.20572500E+06, 0.54832100E+06, -.50577300E+06, 0.20084300E+06, -.44667700E+06, 0.22511000E+06, 0.31195500E+06, 0.22302600E+06, 0.59525300E+05, -.59365000E+06, 0.24571800E+06, 0.18698300E+06, 0.45618200E+06, -.47519100E+06, -.15044600E+06, -.40868000E+06, 0.18586800E+06, 0.13098800E+06, 0.20445000E+06, 0.10124500E+05, 0.62906500E+06, -.26130500E+06, -.64566200E+06, -.49950500E+06, 0.55186700E+06, 0.48349300E+06, 0.35717200E+06, -.15325900E+06, -.48989400E+05, -.17858100E+06, 0.26660700E+05, -.48390200E+06, 0.22805100E+06, 0.52878100E+06, 0.32163100E+06, -.43010800E+06, -.43751400E+06, -.46726200E+05, -.40777500E+05, -.10514000E+06, 0.35309200E+06, -.45449100E+06, -.49482400E+06, -.53706900E+06, 0.32328300E+06, 0.51250300E+05, -.17277800E+06, -.51789900E+06, 0.32098600E+05, 0.42102900E+05, -.91621300E+05, -.17170100E+06, 0.39051700E+06, -.37307600E+06, 0.36261900E+06, -.21620700E+06, 0.26515300E+05, -.65587300E+06, -.24230500E+06, 0.30048500E+06, -.11882500E+06, 0.87915600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11857400E+00, 0.80426600E-01, 0.36327500E+00, -.11485900E+00, 0.12169500E+00, 0.70988200E-01, 0.96980600E+05, 0.15523300E+06, 0.36985500E+05, -.10939500E+05, -.11364500E+05, -.25517700E+05, 0.12752700E+05, 0.31765400E+04, 0.12763100E+05, -.26035300E+04, -.18564100E+05, -.26975400E+04, -.30098800E+05, 0.80891800E+04, -.14346500E+05, 0.25080000E+04, 0.18924000E+05, -.90729900E+04, -.99843800E+04, -.94263900E+04, 0.13022500E+05, -.62088500E+04, -.72099100E+05, -.10689100E+06, -.25758400E+05, -.85157900E+03, -.14916500E+05, 0.88798900E+05, -.44181000E+05, -.47424600E+05, -.44389100E+05, 0.58215900E+04, 0.27370700E+05, -.13713600E+05, 0.29327300E+05, -.30847600E+05, 0.21040100E+05, -.21329400E+05, 0.10967800E+06, -.54999800E+05, -.55692600E+05, -.54837500E+05, -.48157400E+04, 0.26143100E+03, -.57640600E+05, -.61475600E+05, -.51263700E+05, 0.74647800E+03, -.26372100E+05, -.95946000E+05, 0.48493200E+05, 0.51417000E+05, 0.47972900E+05, 0.49367200E+04, 0.32099200E+04, 0.56230900E+05, 0.67483700E+05, 0.45188900E+05, 0.20242200E+04, 0.24635500E+05, 0.29044300E+05, -.14366800E+05, -.14339900E+05, -.14512000E+05, 0.11548000E+03, -.13214000E+05, -.27980200E+05, -.45518500E+05, -.12595200E+05, -.10332400E+05, -.16974100E+05, -.69495700E+04, 0.34944300E+04, -.76474600E+04, 0.34803000E+04, -.32841200E+04, -.25329400E+05, -.15982200E+05, -.52236500E+05, -.61068200E+03, -.19848200E+05, -.58249100E+04, -.24758500E+04, 0.97128700E+03, 0.16949800E+05, 0.12470200E+04, 0.63587200E+04, 0.38205100E+04, 0.66862900E+05, 0.11629300E+06, 0.26852500E+05, -.57251800E+04, -.15474500E+05, -.31239600E+05, 0.16154800E+05, 0.17409200E+05, 0.15612800E+05, 0.19354300E+04, 0.95658500E+04, 0.40089400E+05, 0.61179700E+05, 0.18169700E+05, 0.50089600E+04, 0.15594300E+05, -.41051500E+05, 0.20607700E+05, 0.23062200E+05, 0.20522100E+05, 0.11039200E+05, 0.98450400E+04, 0.28338900E+05, 0.47998300E+05, 0.20000000E+05, 0.61393500E+04, 0.21840300E+04, -.57052600E+04, 0.19933100E+04, 0.95755500E+04, 0.28541000E+04, 0.26094200E+05, 0.32360900E+05, -.61462100E+05, -.59428300E+05, -.17807300E+05, 0.31923100E+05, 0.29694600E+04, 0.79356900E+05, -.39687300E+05, -.43764500E+05, -.39664900E+05, -.12811000E+05, -.12798600E+05, -.66381500E+05, -.10105700E+06, -.41152800E+05, -.62353500E+04, -.11142400E+05, 0.12696200E+06, -.64242200E+05, -.54388200E+05, -.63482400E+05, -.21706000E+05, -.14432100E+05, 0.20778600E+05, 0.43043500E+05, -.28814200E+05, -.15912700E+05, -.41142800E+05, -.33835000E+05, 0.16628500E+05, 0.15043900E+05, 0.16889200E+05, -.73494400E+04, 0.13525600E+05, 0.58562700E+05, 0.89134000E+05, 0.22448800E+05, 0.86854400E+04, 0.22613800E+05, 0.47205100E+01, -.79468500E+03, -.37412500E+04, -.40638200E+00, 0.19306300E+04, -.16353200E+04, -.13327400E+05, -.14595200E+05, 0.11418800E+04, -.29650300E+02, -.38123700E+04, -.76589500E+05, 0.37158800E+05, 0.32672000E+05, 0.38298300E+05, 0.24125100E+05, 0.22208700E+05, 0.71356400E+05, 0.13257300E+06, 0.53516200E+05, 0.11623000E+05, 0.42914600E+04, -.91004700E+05, 0.46099900E+05, 0.33955200E+05, 0.45503400E+05, 0.10315500E+05, -.26345800E+03, -.39043700E+04, -.25350000E+05, 0.25358000E+05, 0.18407100E+04, 0.27518900E+05, -.46125500E+04, 0.34456800E+04, 0.45211400E+03, 0.23196600E+04, -.30961900E+05, -.38951800E+05, 0.76155900E+05, 0.73071200E+05, 0.24837900E+05, -.37431600E+05, 0.10070400E+04, 0.12892500E+05, -.65501200E+04, -.86149700E+04, -.64493700E+04, -.48916700E+04, -.12022200E+05, -.14059200E+05, -.35250500E+05, -.79508200E+04, -.83337900E+04, -.89664100E+04, -.13883400E+06, 0.68642500E+05, 0.78245000E+05, 0.69417600E+05, 0.24472600E+05, 0.16186200E+05, 0.87761600E+05, 0.13242500E+06, 0.75926800E+05, 0.78115400E+04, 0.20903200E+05, 0.12785000E+06, -.63833300E+05, -.71184500E+05, -.63915900E+05, -.91785500E+04, 0.68160400E+04, 0.21510600E+05, 0.68330600E+05, -.27670500E+05, 0.43574900E+03, -.44216600E+05, 0.83276000E+05, -.42031500E+05, -.43783500E+05, -.41639600E+05, 0.73779800E+03, 0.14678400E+05, -.96308900E+05, -.11833400E+06, -.59690300E+05, 0.19503700E+05, -.12521500E+05, -.15702100E+06, 0.78964600E+05, 0.75797900E+05, 0.78512800E+05, 0.26364400E+04, -.17728500E+05, 0.11444300E+06, 0.13333000E+06, 0.85194800E+05, -.20684700E+05, 0.32812900E+05, 0.10206400E+05, 0.25219800E+05, 0.35906500E+05, 0.16248800E+05, -.45908800E+05, -.96474600E+04, -.16750600E+05, 0.14876700E+05, -.29502400E+05, 0.11218400E+05, -.23226100E+05, 0.17255400E+05, 0.19241500E+05, 0.77404300E+04, -.63042000E+05, 0.14204100E+05, -.25787000E+05, -.10408200E+05, -.68433400E+05, 0.18570800E+05, -.23969200E+05, -.21382500E+05, 0.46971500E+05, 0.13602900E+05, 0.14948700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.69013600E-01, 0.27523900E+00, 0.30811100E+00, 0.29134800E-02, -.95176000E-01, 0.43836700E-01, 0.52819700E+00, -.51134100E+05, -.19936300E+05, -.13581700E+04, -.50272100E+04, 0.28724700E+05, -.14700600E+05, -.23442000E+05, -.14351100E+05, -.87788600E+04, -.10056300E+05, 0.57176300E+04, 0.25023200E+05, 0.52402900E+04, -.86886600E+04, -.61820700E+04, 0.10024800E+05, -.61672600E+04, 0.59750100E+04, -.49621900E+04, 0.16332300E+04, 0.41468200E+04, -.13048300E+04, 0.44337700E+05, 0.11492500E+05, 0.53590800E+04, -.13845200E+04, -.56665700E+05, 0.27740100E+05, 0.30913800E+05, 0.28341100E+05, 0.65783800E+04, 0.32934200E+04, 0.91790200E+04, -.14791400E+05, 0.13043400E+05, 0.41078100E+04, 0.13222600E+05, 0.31466700E+05, -.15316100E+05, -.76117600E+04, -.15731500E+05, -.60017500E+04, -.96665600E+04, 0.12305600E+05, 0.37387300E+05, 0.51416800E+04, -.87876100E+04, -.16768100E+05, -.71864900E+05, 0.34623900E+05, 0.14175900E+05, 0.35934300E+05, 0.10401200E+05, 0.13373400E+05, -.80539800E+04, -.46568200E+05, 0.44818200E+04, 0.12602600E+05, 0.31866600E+05, 0.30014000E+05, -.15658900E+05, -.95990500E+04, -.14990600E+05, -.48211700E+04, -.60338000E+04, 0.48074300E+04, 0.30933400E+05, 0.48659600E+04, -.49722400E+04, -.10804200E+05, 0.31978200E+05, -.15945000E+05, -.25938500E+05, -.15972300E+05, -.12363500E+05, -.14551200E+05, 0.12366000E+05, 0.39937900E+05, 0.11035400E+05, -.12563900E+05, -.76879900E+04, 0.30273200E+05, -.14489900E+05, -.59618600E+04, -.15118800E+05, 0.19055900E+04, 0.70310200E+03, -.32134300E+04, -.27592800E+05, -.19329700E+05, 0.15499200E+03, -.15984700E+05, -.77033700E+05, 0.37189100E+05, 0.46463800E+05, 0.38508400E+05, 0.80860800E+04, 0.11527800E+05, 0.41673600E+04, -.39032200E+05, 0.48181500E+04, 0.10154500E+05, 0.26476800E+05, -.27155400E+05, 0.12898800E+05, 0.65177000E+04, 0.13572700E+05, 0.31600700E+04, 0.68015700E+04, -.57931400E+04, -.24902400E+05, -.17144100E+04, 0.67147900E+04, 0.15021400E+05, -.51429100E+05, 0.27598400E+05, 0.26576400E+05, 0.25718000E+05, 0.15473600E+05, 0.17040500E+05, -.17121100E+05, -.40832000E+04, 0.73279200E+04, 0.19471600E+05, 0.16355800E+05, 0.42253600E+05, -.21135200E+05, -.93255100E+04, -.21103200E+05, -.53785800E+04, -.10371800E+05, 0.96468000E+04, 0.50919000E+05, 0.83064400E+04, -.96849200E+04, -.22324500E+05, -.87470000E+04, 0.61809500E+04, 0.73155300E+04, 0.43721100E+04, -.63266300E+04, -.10721200E+05, 0.26730000E+05, 0.20983700E+04, 0.75870900E+04, -.11758700E+05, -.24925400E+04, -.28820600E+05, 0.15569700E+05, 0.39409000E+04, 0.14368500E+05, 0.18124000E+04, 0.10608400E+04, -.15925900E+04, -.45856100E+05, -.88969600E+04, -.29109600E+03, 0.88738000E+04, 0.46841300E+05, -.21575300E+05, -.32004000E+05, -.23419400E+05, -.36750700E+04, -.84922300E+04, -.66320000E+04, 0.17777100E+05, -.12536100E+04, -.64125300E+04, -.17726800E+05, 0.20079100E+05, -.74441500E+04, -.24044500E+05, -.10036100E+05, 0.16114100E+05, 0.14236500E+05, -.29072900E+05, -.47506000E+05, -.21730400E+05, 0.14308600E+05, -.10625500E+05, 0.22453600E+05, -.12576100E+05, -.12259500E+05, -.11226200E+05, -.84117400E+03, 0.21102700E+04, -.14948600E+05, 0.18712800E+04, -.87989900E+04, 0.28696100E+04, -.31893200E+04, 0.32346400E+05, -.18710500E+05, -.40232100E+05, -.16166200E+05, -.18936100E+05, -.21234700E+05, 0.20876700E+05, -.32826500E+04, -.35311700E+03, -.22912300E+05, -.56368900E+04, 0.31600500E+05, -.15492100E+05, -.24138400E+05, -.15802300E+05, -.64131700E+04, -.57471200E+04, 0.11668500E+04, 0.17791100E+05, -.37876600E+04, -.61963800E+04, -.71789200E+04, 0.74082100E+05, -.35267100E+05, -.24193800E+05, -.37041300E+05, 0.15351200E+05, 0.20242000E+05, -.40756700E+05, -.41702800E+05, -.38684200E+05, 0.17206800E+05, -.29151600E+05, -.23828000E+05, 0.11602000E+05, 0.78263100E+04, 0.11921600E+05, -.40196200E+04, -.10932200E+05, 0.23732000E+05, -.91190600E+04, 0.81824300E+04, -.10642800E+05, 0.26539300E+04, -.29703500E+05, 0.15791300E+05, 0.15050900E+05, 0.14847700E+05, 0.12166300E+04, -.13312400E+04, 0.87380000E+04, 0.38039200E+05, 0.23720300E+05, 0.39054500E+03, 0.97451700E+04, 0.53335900E+05, -.27400900E+05, -.29166400E+05, -.26670200E+05, -.63690400E+03, 0.55915200E+04, -.23828000E+05, -.46398900E+05, -.32262400E+05, 0.32158500E+04, -.14601600E+05, -.46658800E+04, -.66246500E+04, -.31580800E+04, -.39678800E+04, 0.14041000E+05, 0.47004900E+04, 0.94863000E+04, -.45820200E+04, 0.11540800E+04, -.16052200E+04, 0.14366400E+05, -.13761300E+05, 0.23398700E+04, -.54461800E+04, 0.17916700E+05, -.50932500E+04, 0.69077700E+04, -.61827400E+04, 0.15493200E+05, 0.34243200E+04, 0.20685500E+05, 0.13399600E+05, -.17609300E+05, -.35366100E+04, -.42698400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11442400E+00, 0.33135400E-01, -.60022900E+00, -.17635700E+00, -.26464100E+00, 0.29112400E-01, -.22513500E+00, 0.13249400E+00, -.48953400E+05, 0.13335200E+05, -.12231000E+05, 0.28026100E+05, -.13703000E+05, 0.70316100E+04, -.14002600E+05, 0.33382700E+04, 0.83092000E+04, -.97744400E+04, 0.32488500E+04, 0.26035300E+04, 0.26006100E+04, -.14206600E+05, 0.53509800E+05, -.26745600E+05, -.26340600E+05, -.26683800E+05, -.98256300E+04, -.34067900E+04, -.38829400E+04, 0.15565400E+05, 0.36394800E+05, -.15914300E+05, -.16858800E+05, 0.75929400E+05, -.37641900E+05, -.42936800E+05, -.37946200E+05, -.11023500E+05, -.14336400E+05, -.29701200E+04, 0.71741100E+04, -.37799500E+05, -.60513100E+04, -.36360900E+05, -.74258900E+05, 0.36740400E+05, 0.16378900E+05, 0.37132700E+05, 0.16216200E+05, 0.21959500E+05, -.88241900E+04, -.24927500E+05, 0.30477900E+05, 0.14927800E+05, 0.41255700E+05, 0.10447800E+06, -.51943400E+05, -.20117400E+04, -.52238500E+05, -.25103500E+05, -.30706000E+05, 0.86415600E+04, 0.26809700E+05, -.46485900E+05, -.20010000E+05, -.57959300E+05, 0.23465400E+05, -.11555000E+05, -.61733000E+04, -.11712100E+05, -.32396500E+04, 0.28788000E+04, -.70025000E+04, 0.54542900E+04, 0.17724300E+05, -.36666100E+04, -.82266000E+04, 0.39521100E+05, -.19606100E+05, 0.74130900E+04, -.19746200E+05, 0.41360100E+04, 0.12132900E+05, -.15973700E+05, 0.15106200E+04, 0.49659900E+04, 0.36051800E+04, -.18923400E+05, -.77533800E+05, 0.38495100E+05, 0.19853800E+05, 0.38787100E+05, 0.23877200E+04, -.78515600E+03, 0.92290600E+04, -.12880400E+05, -.10302600E+05, 0.10051700E+05, 0.25409800E+05, 0.33059500E+05, -.16101000E+05, -.44072100E+05, -.16543200E+05, -.16333200E+05, -.35256100E+05, 0.13030300E+05, 0.23469300E+04, -.37510000E+05, -.19839400E+05, -.20799000E+05, 0.55764100E+04, -.26076600E+04, 0.66101300E+03, -.27953500E+04, -.14415100E+04, -.77668900E+04, 0.74418700E+04, 0.53708600E+04, -.11067800E+05, -.29529200E+04, -.77981600E+04, 0.31558600E+05, -.15591300E+05, -.22076000E+05, -.15775800E+05, -.59312800E+04, -.50897700E+04, 0.10972600E+05, 0.20688000E+05, 0.28878400E+05, -.12350300E+05, -.63125600E+04, 0.70149200E+04, -.34731300E+04, -.11967300E+05, -.34787500E+04, 0.10962500E+04, 0.94298300E+04, -.11527300E+05, -.25395600E+04, 0.29719100E+05, -.85498700E+03, 0.67469700E+04, 0.28884200E+05, -.14140700E+05, -.16949400E+05, -.14445000E+05, -.79488900E+04, -.13301200E+05, -.90079800E+04, -.45854000E+04, -.36941500E+05, -.13492400E+04, -.16611600E+05, -.55618900E+05, 0.27514700E+05, 0.20770300E+05, 0.27752900E+05, 0.10944500E+05, 0.24431800E+04, 0.65975800E+04, -.16102700E+05, -.32444100E+05, 0.13817400E+05, 0.19542200E+05, -.89149800E+04, 0.45475700E+04, 0.27694300E+05, 0.44608700E+04, 0.66964900E+04, 0.14146000E+05, -.11389200E+04, 0.86224600E+04, 0.29056300E+05, 0.66344700E+04, 0.53301200E+04, -.67750100E+04, 0.35158000E+04, 0.30314700E+05, 0.33940900E+04, -.94293000E+04, -.91613300E+04, 0.19948900E+05, 0.23899700E+05, -.14914700E+04, -.22761000E+04, -.73417400E+04, -.50319600E+05, 0.24822300E+05, 0.24692800E+05, 0.25161600E+05, 0.12572100E+05, 0.18183000E+05, 0.36995900E+04, -.27626200E+04, 0.32873900E+05, 0.84166000E+04, 0.25231300E+05, 0.42100600E+05, -.21243900E+05, 0.33998400E+05, -.21027900E+05, 0.64464700E+03, 0.44536500E+04, -.19560100E+05, -.93952400E+04, -.57006700E+05, 0.12163100E+05, -.30806200E+05, 0.52225900E+04, -.29283800E+04, 0.21679900E+05, -.26166700E+04, 0.95570000E+04, 0.23194800E+05, -.14301600E+05, -.17254100E+04, 0.22750700E+04, 0.14514800E+05, 0.78082200E+03, -.52379700E+05, 0.26280200E+05, -.13436100E+04, 0.26190600E+05, -.92102300E+04, -.20069900E+05, 0.30500100E+05, 0.21006600E+05, 0.19895900E+05, -.12623900E+05, 0.15682500E+05, 0.49332200E+05, -.24549600E+05, -.15966700E+05, -.24649500E+05, -.35420900E+04, -.22456500E+04, -.12124600E+05, 0.52834500E+03, -.41991300E+05, 0.73493900E+04, -.27167800E+05, 0.53772900E+05, -.26712100E+05, -.29213400E+05, -.26890300E+05, -.45529100E+04, -.33633700E+04, -.64569100E+04, 0.57341200E+04, 0.19772800E+05, -.11598100E+05, -.13107400E+05, -.38406600E+04, 0.16624300E+04, 0.86350200E+04, 0.19231900E+04, -.46953300E+03, -.51710300E+04, 0.11257800E+05, 0.15535600E+05, -.19340200E+05, 0.12537000E+04, -.10324900E+05, 0.90564000E+04, 0.17094500E+05, 0.36309400E+04, -.46172000E+04, 0.71774600E+04, 0.14731200E+04, -.58240800E+04, 0.23448300E+03, -.14461300E+04, 0.62823500E+01, -.82746100E+04, 0.66147500E+04, 0.12223300E+05, 0.22606600E+04, 0.19095800E+05, -.28811600E+04, -.50877100E+04, 0.27386900E+04, 0.16566100E+05, 0.10410500E+05, -.16804900E+05, -.35353700E+04, -.15132500E+05, 0.96909100E+04, -.79732600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.63655500E+00, -.47208800E+00, -.63837800E+00, 0.20764900E+01, -.32844500E+00, -.28188600E+00, -.14887900E+01, -.16821700E+01, 0.32796800E+01, -.42463000E+05, 0.22799100E+05, -.45835700E+05, 0.22168700E+05, -.80838700E+05, 0.22968500E+05, -.25917500E+05, -.53769300E+05, 0.36211300E+05, 0.17878200E+05, 0.40770300E+05, -.30097200E+05, 0.21441800E+05, -.33664500E+04, -.33131100E+03, 0.38299200E+05, 0.19161700E+04, -.12879500E+05, -.66797400E+05, 0.43113400E+05, 0.26375700E+05, 0.10065800E+05, -.21602200E+05, -.29204400E+05, 0.35135500E+05, -.18769900E+05, 0.12512800E+05, -.17527400E+05, -.17389000E+05, -.24223100E+04, -.10474300E+05, 0.13595300E+05, -.98162000E+04, -.20459600E+05, 0.26580800E+04, 0.11469600E+06, -.56343700E+05, 0.56086100E+05, -.57339200E+05, -.14357200E+05, -.35535100E+05, 0.14147200E+05, 0.42495600E+05, -.25100100E+05, -.17455800E+05, -.73264300E+05, -.27607300E+06, 0.13576300E+06, -.15784600E+06, 0.13804400E+06, 0.41635100E+05, 0.78715700E+05, -.14886200E+05, -.64577400E+05, 0.84030900E+05, 0.44603300E+05, 0.16777300E+06, 0.26743700E+05, -.14601700E+05, -.24693000E+04, -.13298400E+05, -.10708300E+05, -.50886100E+05, 0.31957900E+05, 0.28931400E+05, 0.10658300E+05, -.25710000E+05, -.29476200E+05, -.55986800E+05, 0.27971800E+05, -.96860100E+05, 0.28068900E+05, -.34212000E+05, -.77720700E+05, 0.56472600E+05, 0.34973300E+05, 0.54628500E+05, -.43433100E+05, 0.23351300E+05, 0.13781200E+06, -.67636100E+05, 0.34215600E+05, -.68823600E+05, 0.31292800E+05, 0.47377500E+05, -.32617700E+05, 0.39223200E+05, -.40508200E+05, 0.25100900E+04, -.48836500E+05, 0.14603400E+06, -.75394600E+05, 0.72137500E+05, -.73056500E+05, 0.17466300E+05, 0.11443700E+06, -.77056900E+05, 0.11839700E+04, -.88109700E+05, 0.65938800E+05, -.38683800E+05, -.10558800E+06, 0.51536000E+05, 0.87020700E+04, 0.52770800E+05, 0.15573800E+05, 0.30786200E+05, -.42729600E+04, -.16972700E+05, 0.24440900E+05, 0.12675300E+05, 0.56134600E+05, -.32754400E+05, 0.18880100E+05, 0.37866600E+05, 0.16392800E+05, -.24336800E+05, -.60801900E+05, 0.17837300E+05, -.15635900E+05, -.59416400E+02, -.33040500E+05, -.25362300E+04, 0.14644700E+06, -.73287000E+05, 0.14941600E+04, -.73115000E+05, -.29582500E+05, -.57468300E+05, 0.15164400E+05, 0.30713600E+05, -.27179800E+05, -.20048900E+05, -.86337100E+05, 0.75738900E+05, -.35557200E+05, -.34062500E+05, -.37876100E+05, 0.15444000E+05, 0.63071800E+05, -.27910200E+05, 0.10591200E+05, -.11032600E+05, 0.22762400E+05, -.15636400E+05, -.40014800E+04, 0.42417000E+04, -.16604400E+05, 0.18111100E+04, 0.97469900E+04, 0.71946400E+05, -.48245700E+05, -.30883700E+05, -.18124200E+05, 0.29353800E+05, 0.32768900E+05, -.10296100E+06, 0.53997400E+05, -.74116600E+05, 0.51486700E+05, -.40177400E+04, -.61117100E+05, 0.38345600E+05, 0.22575300E+03, 0.66150500E+05, -.36478600E+05, 0.35455600E+05, -.18696800E+06, 0.97052500E+05, -.68816500E+05, 0.93500500E+05, 0.59921900E+05, 0.28834700E+05, -.32267300E+04, -.29153400E+05, 0.76443900E+05, -.32709100E+04, 0.92543100E+05, -.27215400E+05, 0.12012900E+05, 0.28463200E+05, 0.13611000E+05, -.18633800E+05, -.57918300E+05, 0.25383500E+05, -.43699100E+04, -.31634500E+04, -.26141900E+05, -.33145900E+04, -.26677900E+06, 0.12997100E+06, -.19353900E+06, 0.13342500E+06, 0.23611800E+05, 0.43059800E+05, 0.26297100E+05, -.20277500E+05, 0.11439500E+06, 0.18503500E+05, 0.15308400E+06, -.17668800E+06, 0.89228100E+05, -.44186300E+05, 0.88333700E+05, -.17924200E+05, -.76404800E+05, 0.64043800E+05, -.24872600E+05, 0.70191100E+05, -.46780700E+05, 0.63243900E+05, 0.10627700E+06, -.50729500E+05, 0.81156300E+05, -.53139600E+05, 0.65504900E+05, 0.83542500E+05, -.61835900E+05, 0.22114300E+04, -.43230600E+05, 0.46662200E+05, -.59036400E+05, -.23063300E+05, 0.10966200E+05, -.45427400E+05, 0.11568600E+05, -.10166300E+05, 0.10652600E+02, 0.47245600E+04, 0.77534900E+04, 0.19757800E+05, -.27341100E+05, 0.31535400E+05, 0.55455500E+04, -.16040800E+04, 0.21677900E+05, -.27912700E+04, -.21522200E+05, -.29984000E+05, 0.11879100E+05, 0.54510100E+04, -.47169600E+04, 0.27756500E+04, -.17394700E+05, -.90454400E+05, 0.44442100E+05, -.96726500E+04, 0.45218200E+05, 0.17989600E+05, 0.18578100E+05, -.63954800E+04, -.25165200E+05, 0.15264400E+05, -.26214200E+04, 0.46614900E+05, -.24658700E+04, -.14586000E+05, 0.15273700E+05, 0.43181900E+04, -.18728300E+03, 0.82399500E+04, 0.31140400E+05, 0.11846900E+05, -.22340300E+05, 0.13997200E+05, 0.51831100E+05, -.33585800E+05, -.59781000E+05, -.15156300E+05, -.38741000E+05, 0.58255800E+04, 0.45845000E+05, -.38678100E+05, -.29951200E+05, -.32595700E+05, 0.68026500E+05, 0.27812800E+05, 0.73083100E+04, 0.12177400E+05, 0.11527600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11924400E+01, -.13682700E+01, -.35999400E+01, -.32225100E+00, -.26174200E+01, -.38570700E+00, -.45238300E+00, -.34752400E+01, -.13149500E-01, 0.57564700E-01, 0.21592600E+06, -.25319600E+05, 0.11424400E+05, -.71719500E+05, 0.12674100E+05, -.13396900E+05, -.32819600E+05, 0.19548000E+05, 0.12733300E+05, 0.24373800E+05, -.27274600E+05, -.61381900E+05, 0.12114000E+06, -.64442800E+05, 0.26636100E+04, -.60567400E+05, -.69518100E+04, -.23815300E+05, 0.44837500E+03, 0.20501000E+05, -.39135500E+05, -.19832200E+05, -.21047600E+06, -.26853800E+05, 0.11987900E+05, 0.38529300E+05, 0.13410300E+05, -.13516400E+05, -.11106200E+05, 0.14116500E+05, 0.10205900E+05, 0.27880900E+04, -.35424900E+04, 0.10847500E+06, 0.49779500E+05, -.23968900E+05, 0.57683100E+05, -.24891400E+05, 0.29918400E+03, -.50560500E+04, 0.47178200E+04, 0.23782100E+05, -.12011600E+05, -.50516300E+04, -.95396300E+05, -.22004900E+06, 0.10687700E+06, -.11929000E+06, 0.11003000E+06, 0.16501200E+05, 0.29977700E+05, 0.73684600E+04, -.45116200E+05, 0.71609100E+05, 0.25984500E+05, 0.21403500E+06, 0.75125600E+05, -.40022100E+05, -.56239500E+04, -.37553900E+05, -.32367400E+04, -.21622000E+05, 0.49928600E+04, 0.19239700E+05, -.16837900E+05, -.17752400E+05, -.12272300E+06, 0.67787100E+04, -.33793400E+04, -.99372200E+05, -.33648800E+04, -.20561600E+05, -.44014900E+05, 0.23514600E+05, 0.29004700E+05, 0.22721600E+05, -.37398000E+05, -.96350300E+05, 0.25158800E+05, -.10856200E+05, 0.72544400E+05, -.12566800E+05, 0.39338100E+05, 0.47967300E+05, -.19487000E+05, 0.78816100E+04, -.18017600E+05, 0.38904200E+05, 0.12159700E+06, 0.43875600E+05, -.25185300E+05, 0.73181600E+05, -.21934100E+05, 0.64410400E+04, 0.48137900E+05, -.21680100E+05, 0.11002000E+05, -.32251000E+05, 0.41127700E+05, 0.94748700E+05, -.13668700E+06, 0.66218400E+05, 0.17947200E+05, 0.68343200E+05, 0.78895800E+04, 0.10685700E+05, 0.11397200E+05, -.24624300E+05, 0.34999000E+05, 0.11398500E+05, 0.12815500E+06, -.22337200E+05, 0.15784600E+05, 0.27545300E+05, 0.11172100E+05, -.33028900E+05, -.61378600E+05, 0.29734900E+05, -.71220700E+04, 0.97833300E+04, -.41363400E+05, -.24573600E+05, 0.18270600E+06, -.91610600E+05, -.91339700E+04, -.91340200E+05, -.14566100E+05, -.21600500E+05, -.86069400E+04, 0.37208300E+05, -.43456100E+05, -.21100200E+05, -.23181300E+06, -.46801400E+05, 0.27886200E+05, 0.39772700E+05, 0.23403000E+05, 0.25238200E+05, 0.38748900E+05, 0.43123500E+04, 0.10576100E+05, 0.17063800E+05, 0.31926700E+05, 0.10309400E+06, -.11591600E+06, 0.62310600E+05, 0.16716200E+04, 0.57946300E+05, 0.17636700E+04, 0.26451500E+05, -.38192200E+04, -.20779700E+05, 0.33667000E+05, 0.21450600E+05, 0.20576400E+06, -.12819400E+06, 0.68610900E+05, -.29461700E+05, 0.64092900E+05, 0.27647600E+04, -.29333000E+05, 0.25766800E+05, -.22961500E+05, 0.49406800E+05, -.20395300E+05, 0.60281600E+04, -.20789300E+06, 0.11017300E+06, -.41625700E+05, 0.10394200E+06, 0.51691300E+05, 0.34603700E+05, 0.15608400E+04, -.49937500E+05, 0.67597000E+05, 0.31307400E+05, 0.25686600E+06, 0.41323300E+05, -.23972700E+05, -.18909200E+05, -.20663900E+05, -.20824300E+05, -.33512700E+05, -.19417100E+04, -.83857900E+04, -.17246100E+05, -.27098800E+05, -.83737000E+05, -.21723500E+06, 0.10243000E+06, -.15355500E+06, 0.10858700E+06, 0.24914000E+05, 0.39249900E+05, 0.86520900E+04, -.18333300E+05, 0.79549500E+05, 0.25461400E+05, 0.14589800E+06, -.19768000E+05, 0.10614200E+05, -.84886600E+05, 0.98901600E+04, -.13704800E+05, -.37668300E+05, 0.15650900E+05, -.46995300E+04, 0.21419700E+05, -.34396600E+05, -.50581200E+05, 0.98112600E+05, -.44875900E+05, 0.56110300E+05, -.49059100E+05, 0.65813700E+05, 0.88845100E+05, -.62271100E+05, -.16041100E+05, -.47766500E+05, 0.67368600E+05, 0.50527700E+05, -.12704100E+06, 0.62626800E+05, 0.10343800E+05, 0.63505900E+05, 0.66385000E+04, 0.66866200E+03, 0.25771400E+05, 0.17517100E+04, 0.39805100E+05, 0.75220200E+04, 0.18174200E+06, -.13153100E+05, 0.88913100E+04, 0.24421900E+05, 0.65717600E+04, -.18268500E+05, -.29526800E+05, 0.21240600E+05, 0.99962800E+04, 0.21294400E+04, -.20814300E+05, -.12736500E+06, -.17865100E+05, 0.74918800E+04, -.35964300E+05, 0.89176400E+04, 0.13111400E+05, 0.22129900E+05, -.25043500E+05, -.29532200E+05, -.92636200E+04, 0.14408100E+05, 0.11504300E+06, 0.11309300E+04, 0.13144200E+04, 0.29856000E+05, -.25632800E+04, -.10869100E+05, -.18429600E+05, -.91001600E+03, 0.59314100E+04, -.26975100E+05, 0.16669400E+04, 0.32739900E+05, -.20834500E+05, -.49354900E+05, -.61132700E+04, -.35532800E+05, -.71216900E+03, 0.28757600E+05, -.42793200E+05, -.32787800E+05, -.26146100E+05, 0.38229900E+05, 0.38855200E+05, 0.77186000E+04, -.14914300E+04, -.10216100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.93814800E-01, -.35480900E-01, -.46096200E+00, -.14944200E+00, -.10596300E+00, 0.53434200E-01, -.22343600E+00, -.31833600E+00, 0.16327400E+00, 0.32501700E-01, 0.39750600E-01, 0.18412000E+05, -.91548200E+04, 0.18738100E+04, -.92180500E+04, 0.36059200E+04, 0.94077100E+04, -.68075400E+04, 0.56670500E+03, -.91940200E+04, 0.81298000E+04, -.85069300E+04, 0.17739800E+05, -.79689100E+04, -.83120500E+04, -.89104200E+04, 0.14127700E+04, 0.57715800E+04, -.36754500E+04, 0.11283000E+04, -.31731600E+04, 0.42731900E+04, -.10446700E+05, -.21196600E+04, 0.14346500E+04, -.39028400E+03, 0.10567300E+04, 0.15184600E+04, -.28725000E+03, 0.12662700E+04, 0.11590800E+04, 0.11757400E+04, -.11637100E+04, -.60477800E+03, -.65545500E+04, 0.30221900E+04, -.28364400E+04, 0.32761600E+04, 0.30281000E+04, 0.27501600E+04, -.19909100E+04, -.35948700E+04, 0.16242200E+04, 0.23682500E+04, 0.22794000E+04, 0.11672500E+05, -.49394200E+04, 0.95855700E+04, -.58388400E+04, -.57679000E+04, -.45310500E+04, 0.21759300E+04, 0.43853300E+04, -.32204000E+04, -.40998000E+04, -.46197100E+04, 0.11274100E+05, -.53823200E+04, -.19016400E+04, -.56509000E+04, 0.14862900E+04, 0.55995200E+04, -.37917500E+04, -.25553400E+03, -.44082200E+04, 0.46058900E+04, -.65821800E+04, 0.23065100E+05, -.11553400E+05, 0.20884000E+04, -.11551300E+05, 0.44526000E+04, 0.11893400E+05, -.87260500E+04, 0.47729700E+03, -.11039300E+05, 0.10265100E+05, -.10460100E+05, -.73022800E+04, 0.31952100E+04, -.38551800E+04, 0.36336000E+04, -.12757500E+04, -.61914300E+03, -.60905000E+03, -.33581400E+04, -.40811100E+03, 0.15528600E+03, 0.32843100E+04, -.73800700E+04, 0.46022400E+04, -.34382500E+04, 0.36960600E+04, -.41940500E+04, -.85534300E+04, 0.47736300E+04, 0.16202000E+04, 0.34503500E+04, -.71198600E+04, 0.73565400E+04, -.17414200E+04, 0.11958800E+04, 0.15738700E+04, 0.87460700E+03, -.15334900E+04, -.26138600E+04, 0.15037100E+04, 0.26604300E+03, 0.87725100E+03, -.24310800E+04, -.10521000E+03, 0.26734500E+04, -.28032400E+04, -.67145400E+04, -.13402600E+04, 0.89200000E+03, 0.19058900E+04, 0.84291800E+03, 0.48642200E+03, 0.52422300E+04, -.17916200E+03, -.12329500E+04, 0.22452600E+04, -.11539600E+04, -.36446300E+04, -.11442500E+04, 0.31492300E+04, 0.51951700E+04, -.24566800E+04, -.76829200E+03, -.80775200E+03, 0.43467100E+04, -.20010200E+03, -.63859500E+04, 0.18353100E+04, 0.26561200E+04, 0.31936000E+04, -.37979000E+04, -.63726400E+04, 0.28802100E+04, -.94054500E+03, 0.86465600E+03, -.53339100E+04, 0.22354000E+04, -.21484100E+05, 0.10191200E+05, 0.67155800E+04, 0.10775800E+05, -.12101200E+04, -.69187800E+04, 0.48177300E+04, -.10173000E+04, 0.55603300E+04, -.53448900E+04, 0.12915800E+05, -.27460400E+02, -.13673300E+04, 0.71216200E+04, 0.13522400E+02, 0.20144900E+04, 0.56297400E+04, -.21254300E+04, -.16959600E+04, -.13697400E+04, 0.40297400E+04, -.38092600E+04, 0.13064700E+05, -.84899500E+04, 0.48048400E+04, -.65342900E+04, -.28466100E+04, 0.41240500E+03, -.13606700E+04, 0.38666300E+03, -.41688000E+04, -.43275100E+03, -.10734500E+05, 0.26700700E+04, -.28308600E+03, -.11059200E+04, -.13350700E+04, 0.36108600E+04, 0.59786600E+04, -.29127700E+04, -.15008300E+03, -.55493300E+03, 0.51220300E+04, -.26118700E+03, 0.11597300E+05, -.38430500E+04, 0.13001700E+05, -.57975600E+04, -.12798200E+04, -.42355100E+03, -.26805600E+04, 0.22952600E+04, -.10708900E+05, 0.12774000E+04, -.60975500E+04, 0.15250300E+05, -.77912100E+04, -.61370100E+03, -.76248400E+04, 0.23274600E+04, 0.42636400E+04, -.37637500E+04, 0.10877600E+04, -.50235300E+04, 0.39576500E+04, -.80759200E+04, -.83696200E+04, 0.28391800E+04, -.53782100E+04, 0.41856700E+04, -.23853200E+04, -.33791600E+04, 0.29906100E+04, -.56462100E+03, 0.29745100E+04, -.25449800E+04, 0.12484300E+04, 0.40116500E+04, -.18259100E+04, 0.24671400E+04, -.20088400E+04, 0.12764200E+04, 0.76274400E+03, -.95255900E+03, 0.59163100E+03, -.24624700E+04, -.24129200E+03, -.44665500E+04, 0.14308500E+04, -.14183200E+04, -.13369400E+04, -.71106100E+03, 0.10564600E+04, 0.20098400E+03, 0.51686400E+03, 0.11478800E+04, 0.12143800E+04, -.57972000E+03, -.13455000E+04, -.15151400E+04, 0.14784000E+04, 0.32226800E+04, 0.76271500E+03, -.46747300E+03, -.17682600E+03, 0.88160300E+03, 0.19716400E+04, -.44317300E+03, 0.35010500E+03, -.16898100E+03, 0.88167100E+03, 0.34202500E+03, -.17355900E+04, -.16158200E+04, 0.47108600E+03, -.41219300E+03, -.16998500E+04, -.83758500E+03, 0.15470600E+04, 0.21560800E+03, -.43124100E+04, 0.25838800E+04, 0.31710100E+04, 0.19466400E+04, 0.27337100E+04, -.12156000E+04, -.40249000E+04, 0.11401600E+04, 0.23625000E+04, 0.16939900E+04, -.48027500E+04, -.94552100E+03, -.37690500E+03, 0.23297600E+03, -.45118600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11672300E+00, -.28119900E+00, -.61582800E+00, -.18309400E+00, -.51756300E+00, -.65728900E-01, -.18493600E-01, -.46783600E+00, -.10174600E+00, -.10257400E+00, 0.62342100E-01, 0.23107200E+00, 0.28621200E+03, -.50600300E+04, -.21278200E+02, 0.18031500E+04, -.10346600E+04, 0.91851700E+03, 0.19083500E+04, 0.12289100E+04, -.92382000E+03, -.14448700E+04, -.21706400E+05, 0.99071900E+04, 0.64709100E+04, 0.10763700E+05, 0.14111100E+04, -.96427600E+03, 0.62139900E+04, -.12130400E+03, 0.69411300E+04, -.10734700E+04, 0.71437900E+04, -.62334900E+04, 0.27199600E+04, 0.49853300E+04, 0.31034300E+04, -.15076400E+04, -.10351800E+04, 0.17387600E+04, -.11043800E+03, 0.12671700E+04, -.34935100E+03, 0.28145700E+04, 0.73328800E+04, -.33802300E+04, 0.31738200E+04, -.36695600E+04, -.99836700E+03, -.71751900E+03, -.74214700E+03, 0.16616700E+04, -.21900700E+04, -.63284400E+03, -.36369100E+04, -.20644400E+05, 0.93406700E+04, -.44860400E+04, 0.10318400E+05, 0.29404600E+04, 0.27067000E+04, 0.19528800E+04, -.31946900E+04, 0.65645000E+04, 0.23930400E+04, 0.10249700E+05, -.16855100E+05, 0.83396000E+04, 0.32647000E+04, 0.83991400E+04, 0.15463500E+04, 0.33201500E+03, 0.37802100E+04, -.80784700E+03, 0.55668700E+04, 0.19791300E+03, 0.63162300E+04, -.22294000E+04, 0.10390300E+04, -.66119900E+04, 0.10825000E+04, 0.20059100E+04, -.16558200E+04, 0.24930500E+04, 0.39491300E+04, 0.30058900E+04, -.13955200E+04, -.12662900E+02, -.44733400E+03, 0.78581500E+03, 0.46372900E+04, 0.18991500E+03, 0.40399900E+04, 0.33625100E+04, -.12220500E+04, 0.95062600E+03, -.11152700E+04, 0.28867300E+04, -.28450500E+04, 0.84195700E+04, -.52286700E+04, 0.72338800E+04, -.41949800E+04, -.21832800E+04, 0.31449800E+04, -.19388300E+04, 0.18302800E+04, -.43784000E+04, 0.30341200E+04, -.13224900E+04, -.67927100E+04, 0.34663100E+04, 0.41657100E+04, 0.34050600E+04, -.12035800E+03, 0.81603400E+03, 0.68513800E+03, -.12205600E+04, 0.90117300E+03, 0.66456600E+03, 0.18644400E+04, -.93551500E+03, 0.21776400E+04, -.24557500E+02, 0.46127900E+03, -.34276500E+04, -.47911800E+04, 0.28995000E+04, 0.60263400E+03, 0.25921200E+04, -.40451900E+04, 0.13625200E+02, 0.16979500E+04, -.80009400E+03, -.72159000E+03, -.89218900E+03, -.31893900E+02, -.13308500E+04, 0.63719500E+03, 0.52377800E+03, 0.74403100E+03, -.12051100E+04, 0.11397200E+03, -.11735000E+04, 0.20719300E+04, 0.19846600E+04, 0.58902200E+03, 0.20286800E+04, 0.36190200E+04, -.67626600E+03, 0.35605900E+02, -.30715600E+03, 0.31125200E+04, -.13944700E+03, 0.29004200E+05, -.14148600E+05, -.67324200E+04, -.14429700E+05, -.25273700E+04, -.31487000E+03, -.66884400E+04, 0.19263000E+04, -.90161700E+04, -.49379900E+02, -.10315400E+05, -.11926700E+05, 0.74445000E+04, -.18773800E+04, 0.59613700E+04, 0.20154500E+04, -.13509600E+04, 0.16034600E+04, -.26210100E+04, 0.38790300E+04, -.12773700E+04, 0.19655200E+04, -.10472400E+05, 0.73967900E+04, 0.11500400E+04, 0.52303100E+04, 0.58679500E+04, 0.20320500E+04, -.27918500E+03, -.29725900E+04, 0.26114100E+04, 0.16577500E+04, -.84621300E+03, 0.21601900E+04, -.22625900E+04, -.13286500E+04, -.10810500E+04, -.18459200E+04, -.28136000E+04, 0.36707700E+03, 0.11671300E+03, -.38070800E+03, -.23999900E+04, -.45889600E+03, -.12499200E+05, 0.40202000E+04, -.75971100E+04, 0.62400500E+04, 0.45136600E+04, 0.37517200E+04, -.72659300E+03, -.23984500E+04, 0.20251800E+04, 0.31532100E+04, 0.64383400E+04, -.46863000E+03, 0.47220400E+03, -.81802000E+04, 0.23738000E+03, 0.30571900E+03, -.30652500E+04, 0.13415400E+04, -.29086700E+03, 0.16236000E+04, -.28927600E+04, 0.79380100E+03, 0.71519500E+04, -.21298900E+04, 0.61533900E+04, -.35751600E+04, 0.51068400E+04, 0.49260000E+04, -.42989900E+04, -.13612900E+04, -.42600100E+04, 0.36089200E+04, -.87155700E+04, -.66820100E+04, 0.32441800E+04, 0.31489500E+04, 0.33287000E+04, 0.50893700E+03, 0.49865100E+03, 0.12992400E+04, -.40166400E+02, 0.10927400E+04, 0.87274500E+03, 0.19496900E+04, -.86421200E+03, 0.11642200E+04, 0.17344300E+03, 0.43990200E+03, -.21684000E+04, -.15364800E+04, 0.12175600E+04, 0.31583500E+03, 0.31971600E+03, -.12425400E+04, 0.11984100E+04, -.90806800E+03, -.62083300E+03, 0.36142900E+03, 0.45958200E+03, 0.13085600E+04, 0.14043500E+04, -.17271800E+04, -.21605900E+04, -.18950200E+04, 0.80600300E+03, -.15045900E+04, 0.72976500E-01, 0.49704900E+03, -.14958300E+04, 0.57015500E+03, -.13273700E+04, -.69115000E+03, 0.60009800E+03, -.65049700E+03, 0.12459100E+04, 0.86109200E+01, 0.12383700E+04, -.17050600E+04, -.28097600E+04, -.13860400E+04, -.15923700E+04, -.68611100E+02, 0.98884200E+03, -.25478100E+04, -.14888200E+04, -.15094900E+04, 0.17295600E+04, 0.22093200E+04, 0.29909700E+03, 0.36232700E+03, 0.94124500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15828200E+00, 0.97517100E-01, 0.15948600E+01, 0.13490000E+01, 0.68342300E+00, -.14066000E+00, -.31276900E+00, -.33900500E+00, -.81006200E-01, 0.38187100E+00, 0.29292700E-01, 0.59924300E+00, 0.68747800E+00, 0.51917700E+05, 0.11404400E+02, 0.60156000E+04, 0.16232700E+05, -.60086900E+04, -.73335600E+04, -.62825300E+04, 0.12142700E+05, -.13121000E+04, -.25780700E+05, 0.13587000E+05, 0.10293500E+04, 0.12936600E+05, 0.10431200E+05, 0.28121400E+05, -.15478500E+05, -.95782100E+04, 0.46666200E+04, 0.22850800E+05, 0.21571600E+05, 0.49315100E+04, -.23202600E+04, -.21667600E+05, -.24593000E+04, 0.10324000E+05, 0.13356000E+05, -.10768200E+05, -.29708600E+04, 0.24387300E+04, 0.86307800E+04, 0.54681000E+04, -.67545500E+05, 0.33633700E+05, -.35469500E+05, 0.33774300E+05, 0.17889700E+04, -.65203900E+03, 0.10644800E+05, -.13999500E+05, 0.19547500E+05, 0.11126700E+04, 0.32779300E+05, 0.21799500E+06, -.10875900E+06, 0.68173700E+05, -.10899500E+06, -.18514400E+05, -.19661500E+05, -.22462700E+05, 0.36092100E+05, -.73566400E+05, -.17628800E+05, -.10367200E+06, -.14413800E+05, 0.76213300E+04, 0.56361000E+04, 0.72211300E+04, 0.30698000E+04, 0.14080800E+05, -.64198300E+04, -.59844500E+04, 0.14874600E+04, 0.11375000E+05, 0.10266200E+05, -.25248100E+04, 0.13391700E+04, 0.65749900E+05, 0.12797900E+04, 0.87489700E+04, 0.24643000E+05, -.10734200E+05, -.13720300E+05, -.94880600E+04, 0.18855900E+05, -.31679500E+03, -.16484000E+05, 0.79765500E+04, -.42973100E+05, 0.82601700E+04, -.25285800E+05, -.40472700E+05, 0.19209700E+05, -.16309400E+04, 0.14364600E+05, -.32607300E+05, 0.12997700E+05, -.58781700E+05, 0.29625300E+05, -.63024200E+05, 0.29383200E+05, 0.18299500E+04, -.24548900E+05, 0.15779800E+05, -.16902600E+04, 0.36205700E+05, -.22680600E+05, 0.29608600E+05, 0.66175000E+05, -.33014600E+05, -.10004200E+05, -.33091900E+05, -.55810400E+04, -.11620100E+05, -.49193500E+04, 0.10608200E+05, -.17745300E+05, -.96892300E+04, -.30016000E+05, 0.30447600E+05, -.15230700E+05, -.17432400E+05, -.15220300E+05, 0.24860400E+05, 0.42060100E+05, -.30503800E+05, 0.85311300E+03, -.18938300E+05, 0.32569100E+05, -.96753300E+04, -.81192600E+05, 0.40709500E+05, 0.15543700E+04, 0.40619000E+05, 0.11105800E+05, 0.19502900E+05, 0.27524700E+04, -.13377000E+05, 0.20456500E+05, 0.16281500E+05, 0.39136200E+05, 0.16207400E+05, -.80649000E+04, -.59155700E+04, -.81048000E+04, -.16981600E+05, -.31392300E+05, 0.99929100E+04, 0.24159900E+04, -.27927500E+04, -.24738500E+05, -.17923700E+04, 0.15442200E+05, -.85523000E+04, -.77552400E+04, -.77575700E+04, -.56151600E+04, -.24197700E+05, 0.14180000E+05, 0.65931100E+04, -.84215000E+03, -.19724500E+05, -.16171500E+05, 0.11459700E+06, -.57228100E+05, 0.16727100E+05, -.57297700E+05, -.77477600E+04, 0.10525500E+05, -.17985500E+05, 0.15461300E+05, -.45341200E+05, 0.87455500E+04, -.48041700E+05, 0.14464600E+06, -.72262800E+05, 0.10119400E+05, -.72320200E+05, -.36276700E+05, -.33825600E+05, -.23081600E+04, 0.29434400E+05, -.49208500E+05, -.27701300E+05, -.57436800E+05, -.20275300E+05, 0.10057700E+05, -.42646100E+04, 0.10138100E+05, 0.12722300E+05, 0.23880300E+05, -.46230300E+04, -.17209700E+04, 0.68386800E+04, 0.18390600E+05, 0.42767400E+04, 0.13154800E+06, -.65796500E+05, 0.12000000E+06, -.65769800E+05, -.25696400E+05, -.30575900E+05, 0.45788800E+04, 0.14671400E+05, -.43768300E+05, -.23658400E+05, -.70787700E+05, -.46030500E+03, -.70111300E+02, 0.79165300E+05, 0.22874600E+03, 0.76032100E+04, 0.25224800E+05, -.93850300E+04, -.56834600E+04, -.10127300E+05, 0.22746900E+05, -.84408400E+04, -.48980600E+05, 0.24614300E+05, -.51158200E+05, 0.24489800E+05, -.32806000E+05, -.55406100E+05, 0.33343800E+05, 0.50992100E+04, 0.23814900E+05, -.42328800E+05, 0.33090600E+05, 0.50606900E+05, -.25270800E+05, -.36218100E+03, -.25297400E+05, -.54245500E+04, -.45826700E+04, -.52222600E+04, 0.34870100E+04, -.13461200E+05, -.58208900E+04, -.16069100E+05, -.79672200E+04, 0.40529800E+04, -.10732300E+05, 0.39793800E+04, 0.13215600E+05, 0.20619900E+05, -.11911300E+05, -.48663600E+04, 0.33976200E+04, 0.16173200E+05, 0.76592200E+04, 0.22046800E+05, -.11061300E+05, 0.18007400E+05, -.11026800E+05, -.49815800E+04, -.79783800E+04, 0.72152700E+04, 0.84497600E+04, -.68306600E+03, -.58956900E+04, -.11457400E+05, -.39579700E+04, 0.25850400E+03, -.10942500E+05, -.39980200E+04, 0.65284500E+04, 0.18746100E+05, 0.27090600E+04, -.41823400E+04, 0.12540200E+05, -.64267100E+04, -.17165800E+05, 0.13688900E+05, 0.33644700E+05, 0.78133100E+04, 0.15289700E+05, -.32335200E+04, -.14589200E+05, 0.29741300E+05, 0.13610900E+05, 0.16463600E+05, -.20139900E+05, -.21389500E+05, 0.13166500E+04, -.46158300E+03, 0.22979700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12221700E+00, 0.23562400E-01, 0.66785700E-02, 0.12122900E+01, -.62896400E+00, -.10035000E+00, 0.45836900E-01, -.22109300E-01, 0.35649100E+00, 0.10142900E+00, 0.23336800E-01, -.22304300E+00, 0.54269100E+00, 0.26249400E+00, 0.27649800E+02, -.68153500E+03, 0.23427300E+04, -.14860500E+04, -.21644000E+04, -.21366500E+04, 0.25670700E+04, 0.12457900E+04, 0.30035400E+05, -.13586200E+05, -.67831300E+04, -.14870500E+05, -.49293500E+04, -.19909600E+04, -.37976600E+04, -.21653200E+03, -.63797700E+04, -.12251100E+04, -.14235100E+05, -.67193800E+04, 0.34388100E+04, 0.38974400E+04, 0.33906000E+04, 0.17589300E+04, -.10186200E+04, 0.23795200E+04, 0.24133500E+04, 0.26874800E+04, -.14231700E+04, 0.58268400E+03, 0.37946300E+04, -.19290800E+04, -.10738100E+04, -.18912500E+04, 0.33079300E+03, 0.13442100E+04, -.20959000E+04, -.15720500E+04, -.22058100E+04, 0.88236600E+03, -.13024300E+04, -.14765800E+05, 0.74697400E+04, 0.21287300E+04, 0.73865600E+04, -.41442100E+02, -.29611200E+03, 0.32776900E+04, 0.77031600E+03, 0.65342100E+04, -.30060400E+03, 0.58717100E+04, 0.15303500E+05, -.71318600E+04, -.22307900E+04, -.76083200E+04, -.18487500E+04, 0.34616300E+03, -.30262000E+04, -.14276000E+04, -.54896300E+04, 0.60872100E+03, -.70751900E+04, 0.73390200E+03, -.79304500E+02, 0.88298100E+02, -.32666200E+03, -.10937100E+04, 0.27351500E+04, -.21338700E+04, -.34304700E+04, -.27705000E+04, 0.30445000E+04, 0.93003100E+03, -.36647000E+04, 0.14250900E+04, 0.28051900E+04, 0.18810400E+04, 0.16173900E+03, 0.45044200E+04, -.29810400E+04, -.38364900E+04, -.32939700E+04, 0.41762200E+04, 0.30405800E+04, -.85591900E+04, 0.45643700E+04, 0.48392800E+04, 0.42531700E+04, 0.30181500E+04, -.42736000E+03, 0.22051800E+04, 0.31778100E+04, 0.28259300E+04, -.54552000E+03, 0.25965200E+04, -.38548900E+04, 0.19466300E+04, -.23933700E+04, 0.19130500E+04, 0.63242500E+03, 0.44010400E+03, 0.29431900E+03, 0.81726600E+03, 0.18285800E+04, 0.27961500E+03, 0.22293800E+04, 0.89186600E+03, -.95310900E+03, -.16044600E+04, -.43711100E+03, -.70366600E+03, -.13862700E+04, 0.96038300E+03, -.26676500E+04, 0.39477200E+04, -.13043700E+04, -.11748400E+04, 0.99464800E+04, -.47947700E+04, 0.12877000E+04, -.49084600E+04, -.16092100E+04, -.61565800E+03, -.10977400E+04, -.10684900E+04, -.32111200E+04, -.44578600E+03, -.50133400E+04, -.37481200E+04, 0.16448000E+04, 0.23594200E+04, 0.18690800E+04, -.22534800E+03, -.24312800E+04, 0.25349700E+04, 0.15559200E+04, 0.12919800E+04, -.24430300E+04, -.56875600E+03, -.33451100E+05, 0.15541800E+05, 0.71174100E+04, 0.16609600E+05, 0.47868200E+04, 0.16570900E+04, 0.45957100E+04, 0.32035700E+03, 0.82639300E+04, 0.95190100E+03, 0.16049900E+05, -.42779700E+04, 0.18122700E+04, 0.64364200E+03, 0.21443400E+04, -.15585900E+04, 0.11478900E+04, -.21885500E+03, -.25009300E+04, 0.16871200E+04, 0.82216100E+03, 0.25811000E+04, -.58638500E+04, 0.25767500E+04, -.16823100E+04, 0.29438500E+04, -.17734200E+04, 0.36413300E+04, -.17962100E+04, -.44386100E+04, 0.17836800E+04, 0.30714800E+04, 0.33838600E+04, 0.46663400E+04, -.21293200E+04, -.16829100E+04, -.23303900E+04, 0.31379700E+03, 0.20050400E+04, -.25275700E+04, -.12403700E+04, -.19876300E+04, 0.21045500E+04, -.45797300E+02, -.77924900E+04, 0.44982900E+04, -.32588500E+04, 0.39285500E+04, 0.18728700E+03, 0.83734800E+03, 0.67320400E+03, 0.38180900E+04, -.74904400E+03, 0.89960500E+03, 0.46979000E+04, 0.12159700E+05, -.60784200E+04, -.78397600E+04, -.60882100E+04, -.19980100E+04, -.13414500E+04, -.13912300E+04, -.61337700E+03, -.35171200E+04, -.78579200E+03, -.46571700E+04, -.27325400E+04, 0.12162500E+04, -.98529400E+02, 0.13664600E+04, -.10579900E+04, 0.37176100E+04, -.23254300E+04, -.29681500E+04, -.47148700E+03, 0.33742500E+04, 0.29213200E+04, -.66097200E+04, 0.34191600E+04, 0.12762500E+04, 0.33329300E+04, 0.99587100E+03, -.14201000E+04, 0.23752500E+04, 0.21499700E+04, 0.23231800E+04, -.16924200E+04, 0.64956400E+03, 0.15027000E+04, -.82772500E+03, 0.12332900E+04, -.76162900E+03, -.82493200E+02, -.24029400E+04, 0.18766800E+04, 0.21197400E+04, 0.10348200E+04, -.24720100E+04, -.22759200E+04, -.38413900E+04, 0.21081700E+04, -.10154100E+04, 0.19196000E+04, -.78814600E+02, 0.15943800E+04, -.91238200E+03, 0.36807700E+03, -.44155100E+03, 0.19157500E+04, 0.35622800E+04, 0.12280700E+04, 0.17722500E+03, 0.20344700E+04, 0.66446700E+03, -.59386800E+03, -.10402400E+04, -.55167900E+03, 0.38826900E+04, -.23661700E+04, 0.12138300E+04, -.32257300E+03, 0.46980400E+02, -.98138100E+03, 0.22794400E+03, -.42928500E+03, 0.25872000E+04, -.77568800E+03, -.23320000E+04, -.86306900E+03, 0.54330600E+01, 0.51975600E+03, 0.19673900E+04, -.22104900E+03, 0.32756800E+03, -.58734300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15400300E+00, -.91431400E-01, -.44535100E+00, -.20712700E+00, -.20959200E+00, -.26543600E-01, -.20103300E+00, -.41802100E+00, 0.42823200E+00, 0.10269200E+00, 0.12317600E-01, 0.29400100E+00, -.97892900E+00, -.11103500E+00, -.45513700E+00, 0.30437600E+04, 0.20760900E+04, -.38261800E+02, 0.37637400E+03, -.19860700E+04, 0.14938500E+04, -.17739500E+04, -.25149700E+05, 0.11872400E+05, 0.11389000E+04, 0.12595000E+05, -.40776000E+03, 0.46913500E+03, 0.54816200E+04, 0.84570800E+03, 0.91212000E+04, -.34848200E+03, 0.11493300E+05, -.40519600E+04, 0.15401600E+04, 0.14815200E+04, 0.20349300E+04, -.38664600E+04, 0.87004100E+03, 0.11703000E+03, -.15050300E+03, 0.21169200E+04, 0.61845100E+03, 0.65900300E+04, -.74048300E+04, 0.40680200E+04, 0.10297500E+04, 0.37037400E+04, 0.12739400E+04, -.42486800E+03, 0.23198500E+04, -.48916100E+03, 0.65932200E+03, 0.20545800E+03, -.42610700E+02, 0.19432000E+05, -.10855900E+05, 0.37741400E+04, -.97168200E+04, -.22211700E+04, -.11325900E+04, -.30029300E+04, 0.31435300E+04, -.46979300E+04, -.14821300E+04, -.22706300E+04, -.29166300E+05, 0.14306600E+05, 0.20341500E+04, 0.14586600E+05, 0.17586400E+04, 0.27088300E+04, 0.41031900E+04, -.37799600E+04, 0.75739500E+04, 0.21722600E+04, 0.12387300E+05, -.46313300E+04, 0.23484800E+04, -.12550600E+04, 0.23147000E+04, 0.35714100E+04, 0.29131400E+04, 0.12841500E+04, 0.15355700E+04, -.80094300E+03, 0.21449100E+04, 0.77833800E+03, -.27219600E+04, 0.18833200E+04, -.16909100E+04, 0.13645800E+04, 0.22285000E+04, -.22742800E+04, 0.15380100E+04, 0.55740400E+03, -.32719100E+03, -.16988600E+04, -.95240000E+03, 0.10787600E+05, -.65091900E+04, -.49775100E+04, -.53986100E+04, -.88802000E+04, -.17310200E+04, -.11063100E+04, 0.32739000E+04, 0.29947300E+03, -.18588800E+04, 0.38614800E+04, 0.22770700E+04, -.13871400E+04, 0.70032500E+04, -.11404100E+04, -.11367000E+04, -.23215900E+04, 0.10378200E+04, 0.16509600E+04, 0.55166800E+03, -.19515900E+04, -.16506200E+04, 0.55661500E+04, -.11275600E+04, -.29828800E+04, -.27827600E+04, -.20497100E+04, 0.39015200E+03, -.15152300E+04, 0.36444800E+04, 0.95433200E+03, -.42241400E+03, -.30801900E+03, -.10272800E+05, 0.51794000E+04, -.41853900E+04, 0.51420400E+04, 0.64676100E+03, 0.28778200E+04, 0.27125100E+02, -.33585300E+04, 0.85756700E+03, 0.22687600E+04, 0.55068000E+04, 0.15714400E+04, 0.76222000E+03, 0.42071200E+04, -.78705700E+03, -.15985900E+04, -.20329300E+04, 0.21662600E+04, 0.14187200E+04, -.75945400E+03, -.13578400E+04, 0.18804000E+04, 0.39196000E+05, -.19083100E+05, -.30013200E+04, -.19610800E+05, -.12903200E+04, -.22269000E+04, -.66018300E+04, 0.30369900E+04, -.11938100E+05, -.14297200E+04, -.17062300E+05, -.22909100E+04, 0.27015600E+04, 0.33485100E+04, 0.11473300E+04, 0.34913500E+04, 0.48608600E+03, -.11022300E+03, -.15134500E+04, -.15129900E+04, 0.30427500E+03, -.15202200E+04, 0.13385000E+05, -.44273300E+04, 0.46268400E+04, -.66896800E+04, 0.44376100E+04, -.43422700E+04, -.40540600E+03, 0.25387400E+04, -.53306800E+04, -.38145600E+04, -.94541300E+04, -.15126700E+04, -.42767500E+03, -.50131200E+04, 0.75734200E+03, 0.10763200E+04, 0.15899600E+04, -.11660800E+04, -.92606400E+03, 0.85861900E+03, 0.11249800E+04, -.19100600E+04, 0.10084300E+05, -.72538400E+04, 0.12457200E+05, -.50292400E+04, 0.35330500E+04, -.10820400E+04, -.11787200E+03, -.24554700E+04, -.72008100E+04, -.78854700E+02, -.73974200E+04, -.93020800E+03, 0.76888300E+03, 0.33458100E+04, 0.46224200E+03, 0.62494400E+04, 0.83719600E+03, 0.48482700E+03, -.89754100E+03, -.14727700E+04, 0.12138100E+04, -.69664700E+04, 0.36884400E+04, -.29309100E+03, 0.29032400E+03, -.18434300E+04, 0.22972000E+04, -.38279400E+04, -.24467900E+03, -.10173100E+04, -.18149100E+04, -.34754200E+04, -.54963700E+04, 0.49385200E+04, -.26426800E+04, 0.35099900E+04, -.24612900E+04, -.24243300E+04, -.14493400E+04, 0.15099100E+04, 0.20564300E+04, -.15741000E+04, -.98412200E+03, 0.30058800E+03, -.22970300E+04, 0.19434900E+04, -.29362600E+04, 0.11483400E+04, -.23622300E+04, 0.14416600E+04, 0.10849200E+03, 0.86787700E+03, 0.23641500E+04, 0.90466900E+03, 0.43727700E+04, 0.54828400E+04, -.36122800E+04, 0.48164200E+04, -.27375400E+04, 0.80625000E+03, -.10440700E+04, -.12158900E+04, -.22078500E+04, -.20788700E+04, -.12514300E+04, -.58511400E+04, -.10417200E+04, 0.10262600E+04, -.33713900E+04, 0.21966700E+04, -.94416600E+03, 0.20208500E+04, 0.10813400E+04, 0.11806800E+04, 0.31319800E+04, -.16341300E+04, -.18319200E+04, -.15203900E+04, 0.29637300E+04, -.21253800E+04, 0.96985200E+03, 0.21804900E+04, -.84774600E+03, 0.19656000E+04, 0.72847900E+03, 0.16008700E+04, -.21618900E+04, -.74165700E+03, 0.82257000E+03, 0.54300200E+03, 0.21461400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16193500E+00, 0.22659500E+00, -.90305900E+00, 0.57168200E+00, -.12963400E+01, -.22301300E+00, -.41498700E+00, -.44948500E+00, 0.12813700E+01, 0.32667900E+00, 0.12406000E+00, -.17657200E+01, 0.12411300E+01, 0.82081900E+00, -.98313600E+00, 0.48950100E+00, 0.10985500E+05, -.68896600E+04, -.10318800E+05, -.11655200E+05, 0.12021700E+05, 0.43371700E+04, 0.11088500E+06, -.50945400E+05, -.22505600E+05, -.55437600E+05, -.13632200E+05, -.18403800E+05, -.67758500E+04, 0.11744500E+05, -.20131500E+05, -.15229800E+05, -.56235100E+05, -.88572200E+04, 0.57894000E+04, 0.75756200E+04, 0.44307000E+04, 0.48172900E+04, -.43503100E+04, 0.56872300E+04, 0.52923500E+04, 0.50473000E+04, -.60904300E+04, -.54707600E+04, -.52169600E+03, -.64404300E+03, 0.12081700E+05, 0.26115100E+03, 0.42909100E+04, 0.44164900E+03, -.34841600E+04, -.50290400E+04, -.43861800E+04, -.11235500E+04, -.19735800E+04, -.38195800E+05, 0.22282500E+05, -.30611800E+05, 0.19097600E+05, -.50516600E+04, 0.75472400E+04, 0.53405400E+04, 0.17051900E+04, 0.22463900E+05, 0.60646600E+04, 0.20638100E+05, 0.76042300E+05, -.36597400E+05, -.34752200E+04, -.38019200E+05, -.67576400E+04, -.66775500E+04, -.83496100E+04, 0.56252500E+04, -.23660400E+05, -.50942300E+04, -.37467000E+05, 0.12462400E+05, -.59413900E+04, 0.49801500E+03, -.62314900E+04, -.10333100E+04, 0.10376300E+05, -.95050500E+04, -.12151400E+05, -.17155400E+05, 0.12344800E+05, -.70274700E+03, -.48245300E+04, 0.38801500E+03, 0.18131000E+05, 0.24125500E+04, 0.32279000E+04, 0.19678900E+05, -.13209800E+05, -.12281000E+05, -.13771800E+05, 0.15915500E+05, 0.25393100E+04, 0.42682800E+05, -.17895300E+05, -.11243500E+05, -.21342500E+05, 0.62661200E+04, 0.11218500E+05, -.77397900E+04, 0.17138700E+05, -.84139100E+04, 0.81899900E+04, -.15110000E+05, -.17586100E+05, 0.96673000E+04, -.13687300E+05, 0.87923700E+04, 0.86260100E+03, 0.32414500E+04, -.38155100E+03, -.60944800E+03, 0.94622000E+04, 0.93555700E+03, 0.83311200E+04, 0.29559400E+05, -.20436800E+05, -.11018100E+05, -.14779700E+05, -.86990700E+04, -.21006800E+05, 0.68244400E+04, 0.47457400E+04, 0.13155300E+05, -.20204900E+05, -.16438600E+05, 0.36968800E+05, -.18390900E+05, 0.88146100E+04, -.18483000E+05, -.25942800E+04, -.73521100E+04, 0.27532900E+03, 0.32365800E+04, -.11918000E+05, -.47235600E+04, -.17838900E+05, -.88570600E+04, -.50664000E+03, -.10551800E+04, 0.44282100E+04, -.15942300E+04, 0.58060600E+04, 0.72199800E+03, -.19861400E+04, 0.14199500E+04, 0.20087500E+04, 0.45385100E+03, -.13571000E+06, 0.64731000E+05, 0.20802400E+05, 0.67849800E+05, 0.15540500E+05, 0.18179500E+05, 0.10206000E+05, -.14692900E+05, 0.30418300E+05, 0.15335100E+05, 0.68999000E+05, -.36844300E+05, 0.13329800E+05, 0.31956800E+04, 0.18422500E+05, -.57972200E+04, -.54495400E+04, 0.50489800E+04, -.10394700E+05, 0.10236500E+05, -.65595200E+04, 0.12628200E+05, -.51205700E+05, 0.18459800E+05, -.15481400E+05, 0.25603400E+05, -.10462500E+05, 0.44873900E+04, 0.18484800E+04, -.12256700E+05, 0.24640200E+05, -.10603200E+04, 0.18056000E+05, 0.15035600E+05, -.36470900E+04, 0.22850700E+04, -.75175600E+04, 0.18597400E+04, -.41431900E+04, -.28465500E+04, 0.14419100E+04, -.56499000E+04, -.83564400E+03, -.21029900E+04, -.85091800E+05, 0.49979000E+05, -.22391100E+05, 0.42549200E+05, 0.46441700E+04, 0.20108000E+05, 0.21470700E+04, -.70136200E+04, 0.99607000E+04, 0.19749200E+05, 0.44427600E+05, -.20059200E+05, 0.94281800E+04, -.70498400E+04, 0.10028900E+05, -.51788900E+04, -.11668500E+05, 0.73574300E+04, -.74425100E+04, 0.74032200E+04, -.72000500E+04, 0.95706200E+04, -.88488200E+04, -.35472600E+03, 0.50119100E+04, 0.44246300E+04, -.30060500E+04, 0.12744400E+05, -.61239400E+04, -.37680900E+04, 0.34913300E+04, 0.82611700E+04, 0.28916200E+04, -.22688000E+05, 0.12029300E+05, -.76508200E+04, 0.11345800E+05, 0.15198900E+04, -.18320000E+04, 0.51718300E+04, 0.15706700E+04, 0.10054200E+05, -.50431700E+04, 0.27167400E+04, 0.17274200E+05, -.11128800E+05, 0.49206600E+04, -.86370600E+04, -.33087200E+04, -.15106900E+05, 0.73377500E+04, 0.88082800E+04, 0.16936400E+04, -.14281500E+05, -.13287500E+05, -.21959300E+05, 0.13807600E+05, -.12735700E+05, 0.10980800E+05, -.84252300E+03, 0.45322900E+04, 0.33228900E+03, 0.30342300E+04, 0.56660400E+04, 0.54913400E+04, 0.14367500E+05, 0.63413700E+04, -.38957500E+03, 0.89470700E+04, -.36125200E+04, 0.22951000E+04, -.44131400E+03, 0.33114600E+04, 0.42372900E+04, -.10111700E+05, 0.67976100E+04, 0.10711100E+05, 0.10458000E+04, -.11104400E+05, 0.24985300E+04, -.28115700E+04, -.39884600E+03, 0.13269600E+05, -.89332700E+04, -.23183900E+04, -.44587800E+04, 0.11614700E+05, 0.70859700E+04, -.34014600E+04, 0.62222800E+03, -.34523200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.44075900E+00, -.42847400E+00, -.45802900E+00, 0.48181100E+00, 0.43275300E+00, -.74554700E-01, -.91289700E+00, -.17247500E+01, 0.44909400E+00, 0.29294200E+00, -.11985000E+00, 0.17363300E+01, -.19759000E+01, -.62073300E+00, -.72734200E+00, -.17033100E+01, -.70867900E+00, 0.44850100E+04, 0.48164500E+04, -.81070500E+04, -.48541700E+03, -.43146100E+04, 0.27522800E+05, -.14271800E+05, 0.70607400E+04, -.13742700E+05, -.11010800E+05, -.12124400E+05, 0.14886400E+05, 0.28327400E+05, 0.19314000E+04, -.13564900E+05, -.21026800E+05, -.26595300E+05, 0.11930000E+05, 0.10315400E+05, 0.13306000E+05, -.95075100E+04, 0.39956300E+04, 0.33091500E+04, 0.43944500E+03, 0.12121400E+05, 0.38863300E+04, 0.20723500E+05, -.18489400E+05, 0.10315700E+05, -.51024000E+04, 0.92459300E+04, 0.12454000E+05, 0.85216800E+03, 0.62952800E+04, 0.12137000E+03, -.15380200E+04, 0.12064100E+04, 0.39117400E+04, 0.28398200E+05, -.17448700E+05, 0.95884300E+04, -.14199800E+05, -.22109300E+05, -.45768700E+04, -.49313300E+04, 0.56783100E+04, 0.57233200E+03, -.38247400E+04, -.33764700E+04, -.20456800E+04, 0.98564400E+03, 0.11772100E+05, 0.10257600E+04, -.40393600E+04, -.35706300E+04, 0.95703300E+04, 0.79909900E+04, -.29467200E+04, -.40139600E+04, -.59596900E+04, 0.39513300E+03, 0.19077100E+03, 0.14758900E+04, -.19845100E+03, -.25530300E+04, -.21686800E+04, 0.10787000E+05, 0.14410000E+05, -.88382200E+04, -.24633600E+04, -.42906700E+04, -.11309800E+05, 0.67772100E+04, 0.98692500E+04, 0.56584500E+04, 0.10288400E+05, -.28728600E+04, 0.44416800E+04, 0.30856300E+04, -.53002600E+04, -.10260800E+04, -.43176200E+04, -.19128800E+05, 0.65244800E+04, -.81364700E+04, 0.95599000E+04, -.16277400E+05, 0.26032500E+04, 0.30239400E+04, 0.90900800E+04, 0.25094200E+05, 0.24167000E+04, 0.26422500E+05, -.40857700E+05, 0.19708100E+05, 0.12992500E+05, 0.20427200E+05, 0.21611200E+04, -.14881300E+04, 0.75259100E+04, 0.18294300E+04, 0.20791600E+05, -.14114200E+04, 0.17191400E+05, 0.34464200E+05, -.12789300E+05, -.13338400E+05, -.17231800E+05, 0.33992200E+03, -.72968600E+04, -.26696200E+04, 0.12722300E+05, 0.45217600E+04, -.73185900E+04, -.14833600E+05, 0.46718900E+05, -.22973700E+05, -.12417200E+05, -.23354200E+05, -.41838100E+04, 0.73540300E+03, -.57023100E+04, -.29224700E+03, -.24062200E+05, -.19293000E+03, -.21486200E+05, 0.33670100E+04, 0.26797800E+04, 0.13193100E+05, -.16847400E+04, -.19402800E+05, -.84213300E+04, 0.10529700E+05, 0.88766800E+04, 0.14035800E+04, -.63414600E+04, 0.67604900E+04, -.20189800E+05, 0.10034400E+05, -.14200300E+05, 0.10083600E+05, 0.11207900E+05, 0.11340400E+05, -.15626300E+05, -.22543600E+05, 0.12194300E+04, 0.12350100E+05, 0.20510600E+05, -.72281000E+03, 0.47212400E+04, 0.73499000E+04, 0.36315300E+03, 0.97580900E+04, -.18130200E+04, -.69735200E+03, -.66338600E+04, -.10571900E+05, -.22911100E+04, -.87446400E+04, -.27503500E+04, 0.78075700E+04, -.59941600E+04, 0.13778200E+04, 0.15341100E+05, -.85673300E+04, 0.22738600E+04, 0.30842800E+04, 0.34165000E+04, -.91823600E+04, -.11682100E+05, 0.20827000E+04, -.43592500E+04, -.14546200E+05, -.10404200E+04, 0.15312600E+05, 0.56402700E+04, -.69227600E+04, -.54049600E+04, -.29243200E+04, 0.43099700E+04, -.79282700E+04, -.22248500E+05, 0.50951900E+04, 0.24219600E+05, 0.11136200E+05, -.88752500E+04, 0.42438200E+04, 0.52951700E+03, -.13915700E+05, -.93246700E+04, 0.46510900E+04, 0.91808000E+04, 0.21552300E+05, -.99600800E+04, -.23816300E+04, -.10778800E+05, 0.65007000E+04, -.28491500E+04, -.19468900E+04, -.21106600E+04, -.12008400E+05, -.24943700E+04, -.20451800E+05, 0.27066800E+04, 0.31805900E+04, -.81164100E+04, -.13526100E+04, 0.21958200E+05, 0.18349800E+04, -.56981500E+04, -.33963700E+04, -.63930000E+03, -.12124200E+04, -.14812500E+05, -.14624100E+05, 0.68995500E+04, -.79882200E+03, 0.73194500E+04, -.11360800E+05, -.37777500E+04, 0.11490300E+05, 0.87334200E+04, 0.87087100E+04, -.28018600E+04, 0.13587100E+05, 0.43329400E+04, 0.12752300E+03, -.45382700E+04, -.21666700E+04, -.99045700E+04, -.24337400E+04, 0.33339300E+04, 0.59826600E+04, 0.55791900E+04, -.26776500E+04, 0.50864500E+04, -.36336200E+04, -.61149500E+03, 0.10371600E+04, 0.18203500E+04, 0.87534600E+04, 0.55271000E+04, -.85333900E+04, -.11429300E+05, 0.58938400E+03, 0.21805300E+04, -.52976200E+04, 0.63096300E+03, 0.22729000E+04, 0.59652300E+04, 0.18119300E+04, -.85774300E+03, 0.20559100E+04, 0.20020800E+04, 0.54949000E+04, -.64137700E+04, -.20480400E+04, 0.15215000E+04, -.63126800E+04, 0.22633400E+04, -.42479100E+04, -.28960200E+04, 0.38490400E+04, 0.41500900E+04, 0.12073400E+04, -.37388900E+04, 0.17617000E+04, 0.36991300E+04, 0.38406100E+04, 0.15175600E+04, 0.12944300E+04, -.16110300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34950800E+00, -.15292600E+00, -.46302500E+00, 0.44039000E+00, -.54325500E+00, -.12085900E+00, -.70341400E+00, -.57207800E+00, 0.62898800E+00, 0.34197800E+00, 0.88811300E-01, 0.69961200E+00, 0.11604500E+00, 0.45112700E+00, 0.47394200E-02, -.62551300E+00, -.45359400E+00, 0.39044900E-01, -.55159300E+04, -.51658000E+04, -.11557100E+03, 0.20301800E+04, 0.34976600E+05, -.15997500E+05, -.86826800E+04, -.17472100E+05, -.57687700E+04, -.14978200E+05, 0.34814000E+04, 0.10605900E+05, 0.24909800E+04, -.14050100E+05, -.17109900E+05, -.19645800E+05, 0.10040400E+05, 0.83353000E+04, 0.98299800E+04, 0.35826600E+04, 0.73970200E+04, -.10994900E+04, 0.11280000E+04, 0.83196200E+04, 0.58979400E+04, 0.78289200E+04, -.16542600E+05, 0.82246200E+04, 0.82274000E+04, 0.82723200E+04, 0.39783800E+04, -.18821700E+04, 0.14387700E+05, 0.90125500E+04, 0.21031400E+04, -.20340300E+04, -.14509400E+04, 0.10522000E+05, -.45805400E+04, -.13583800E+05, -.52617200E+04, -.61663600E+04, 0.33920200E+04, -.15288900E+05, -.84009000E+04, 0.21869100E+04, 0.30611500E+04, 0.56255700E+04, 0.24088100E+05, -.11480100E+05, -.21774200E+04, -.12040100E+05, -.48014100E+04, -.95252000E+04, 0.37829700E+04, 0.55536600E+04, -.30234900E+04, -.88172700E+04, -.11478500E+05, 0.55858900E+04, -.27107100E+04, -.42780200E+03, -.27937900E+04, -.10508900E+04, -.28100000E+04, 0.15210600E+04, -.45590800E+04, -.68886000E+04, -.25620100E+04, 0.12522100E+03, -.78007800E+04, 0.34360400E+04, 0.10335500E+05, 0.39026200E+04, 0.28451700E+04, 0.40031700E+04, 0.39885100E+03, 0.33128000E+03, -.67292800E+04, 0.33380000E+04, -.62843000E+03, 0.63915800E+04, -.24719000E+04, -.45738800E+04, -.31994900E+04, -.55850600E+03, 0.10088700E+05, -.12692500E+05, -.14748600E+04, 0.22998100E+04, 0.84910300E+04, 0.83653700E+04, -.50148700E+04, 0.27672900E+04, -.22364000E+04, 0.25057200E+04, 0.83919600E+03, 0.33758800E+04, -.49940600E+04, -.14548700E+04, 0.22254600E+04, 0.24804900E+04, 0.29316500E+04, 0.24743900E+05, -.13928300E+05, -.56485400E+04, -.12371800E+05, 0.32839800E+04, -.19091300E+04, -.72747000E+04, 0.46064500E+04, 0.29877600E+04, -.20342200E+04, -.14690100E+05, 0.14466200E+05, -.71419300E+04, -.22503700E+04, -.72286000E+04, -.27446700E+04, -.80884700E+04, 0.85948700E+04, 0.58127100E+04, -.54983100E+03, -.70481400E+04, -.76074600E+04, -.65775100E+04, 0.18652600E+04, 0.96285800E+03, 0.32876900E+04, -.67894000E+04, -.20507800E+04, 0.94066600E+04, 0.45395200E+04, 0.77316900E+04, -.29272400E+04, 0.49291500E+04, -.43931100E+05, 0.20809200E+05, 0.82483900E+04, 0.21953100E+05, 0.85904200E+04, 0.17390800E+05, -.49446600E+04, -.11678200E+05, 0.70983800E+02, 0.16350800E+05, 0.21288300E+05, 0.53547600E+04, -.40359300E+04, -.51819800E+04, -.26759400E+04, -.32530500E+04, -.75605200E+04, 0.34465800E+04, 0.33390300E+03, -.26612500E+04, -.71591000E+04, -.71214900E+04, -.10515700E+05, 0.33900200E+04, -.88193500E+04, 0.52600300E+04, -.63899700E+03, -.11313300E+04, -.64202800E+03, 0.24100100E+04, 0.60097500E+04, -.24274900E+04, -.26991400E+04, 0.14787100E+05, -.62444400E+04, -.52783600E+04, -.73927200E+04, 0.29230800E+04, -.24634400E+04, -.41515500E+04, -.67361800E+03, -.84352000E+04, -.10895700E+04, -.76173200E+04, -.35967500E+05, 0.19993200E+05, 0.12755100E+04, 0.17994300E+05, -.50089800E+04, 0.22310000E+04, 0.63850400E+04, -.83621300E+04, 0.30560800E+04, 0.18975500E+04, 0.21918000E+05, -.87050100E+04, 0.43371500E+04, 0.14133500E+04, 0.43502000E+04, 0.14572000E+04, -.57746300E+04, 0.90063900E+04, 0.11519000E+03, 0.29749000E+04, -.45060700E+04, -.15278300E+04, 0.63217000E+04, -.43850600E+04, -.49897200E+04, -.31601800E+04, 0.35201200E+03, 0.17731100E+04, -.79896100E+04, -.16406300E+04, -.37731300E+04, 0.50432800E+03, -.47707700E+04, -.47705000E+04, 0.25484100E+04, -.76507800E+04, 0.23915500E+04, -.35481300E+04, -.12643500E+04, 0.76077000E+04, 0.76598800E+04, 0.76752800E+04, -.23945400E+04, 0.19258600E+04, 0.61961800E+04, -.38157200E+04, 0.10209500E+04, -.30981100E+04, -.11285500E+04, -.13508000E+04, 0.18457100E+04, 0.61470300E+04, 0.41987900E+04, -.19205100E+04, -.33650100E+04, -.80790500E+04, 0.47882100E+04, -.45454400E+04, 0.40428200E+04, -.14413300E+04, -.12795400E+04, -.38277800E+04, -.41143300E+04, 0.93261600E+03, -.12842400E+04, 0.69591400E+04, 0.29962600E+04, 0.75468100E+03, 0.63134600E+04, -.33804400E+04, 0.26096800E+04, 0.34284300E+04, 0.65766700E+04, -.11723700E+04, -.55879900E+04, 0.19471900E+04, 0.60869400E+04, -.23184900E+04, 0.52333200E+03, -.19869700E+03, -.31554100E+04, -.32691600E+04, 0.71223400E+04, -.24011600E+04, -.34874900E+04, 0.22667900E+04, 0.96129900E+04, 0.25432100E+04, -.63714400E+03, 0.98430000E+03, -.22412300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15852800E+00, 0.60095200E+00, -.14074000E+00, 0.11726500E+00, -.26440400E+00, -.64085100E-01, 0.14769700E-01, 0.77082300E-01, 0.23399800E-01, -.28819100E+00, 0.14180200E-01, -.89455700E+00, -.60306700E+00, -.40377200E+00, -.26878300E+00, 0.98183300E-01, 0.20535700E+00, 0.44053500E+00, -.13742900E+00, 0.63267900E+04, -.33292200E+03, 0.18296200E+04, -.19767900E+05, 0.99633600E+04, -.25580400E+04, 0.98920000E+04, 0.72413200E+04, 0.81861500E+04, -.60850600E+04, -.16710400E+05, 0.15414300E+04, 0.89932300E+04, 0.12105800E+05, 0.86456500E+03, -.37136200E+02, 0.36790800E+03, -.42877500E+03, 0.63415500E+04, 0.15508000E+04, -.34116200E+04, 0.10876000E+04, -.28229500E+04, 0.90428200E+03, -.25786500E+04, 0.20649900E+05, -.10606700E+05, -.43594600E+04, -.10324500E+05, -.83241600E+04, -.60048700E+04, -.92246800E+03, 0.13489200E+04, -.26343000E+04, -.42415400E+04, -.69384700E+04, -.14089300E+05, 0.81018100E+04, 0.15923700E+04, 0.70442600E+04, 0.13015200E+05, 0.80275800E+04, -.12691100E+04, -.86945800E+03, -.20456000E+04, 0.57237900E+04, 0.22943100E+04, -.11243500E+04, 0.55420100E+03, -.80251000E+04, 0.56433300E+03, 0.21695100E+04, 0.17132100E+04, -.21827500E+04, -.44851000E+04, 0.34745500E+04, 0.21159500E+04, 0.33688200E+04, -.55463100E+03, 0.54773500E+02, -.18813200E+04, 0.27688200E+03, 0.81667500E+03, 0.81313100E+03, -.13986700E+04, -.30409100E+04, 0.78609900E+04, 0.36477300E+03, 0.25451000E+04, 0.44142600E+04, -.24822700E+04, -.41369100E+04, -.22061400E+04, -.52324900E+04, -.45312600E+04, 0.20240400E+04, 0.37432000E+04, 0.32434300E+04, -.37913300E+04, -.79157800E+03, -.44200700E+04, 0.31214200E+04, 0.13305700E+05, 0.22082200E+04, 0.96584200E+04, 0.71109900E+04, -.43669600E+04, -.13545900E+04, -.10309900E+05, 0.45514100E+04, -.33456000E+04, 0.12038000E+05, -.57138900E+04, -.17996400E+03, -.60199000E+04, 0.47451400E+01, 0.20456100E+04, -.40859100E+04, -.63363200E+03, -.98959700E+04, 0.22479100E+04, -.66591500E+04, -.12995400E+05, 0.50373600E+04, 0.15047300E+04, 0.64977600E+04, 0.30554900E+04, 0.63630300E+04, -.50552600E+04, -.13243600E+05, -.58729000E+04, 0.70581400E+04, 0.40534600E+04, -.11285500E+05, 0.54994100E+04, -.20636400E+04, 0.56449800E+04, 0.66962600E+03, -.21649200E+04, 0.34404400E+04, -.76787000E+03, 0.10963500E+05, -.19139400E+04, 0.75463100E+04, 0.76280900E+04, -.53327700E+04, -.71489700E+04, -.38145700E+04, 0.73546600E+04, 0.14469300E+04, -.22510500E+04, 0.64960500E+03, -.14833800E+04, 0.79999100E+03, -.44931100E+04, 0.15165900E+05, -.74855600E+04, 0.78914100E+04, -.75894900E+04, -.69055900E+04, -.68971500E+04, 0.51516900E+04, 0.14096600E+05, -.36149700E+04, -.76853300E+04, -.11286300E+05, 0.15297200E+05, -.91048200E+04, -.11355800E+05, -.76478900E+04, -.52609100E+04, -.32305300E+04, 0.94191200E+02, 0.40650900E+04, 0.83498500E+03, -.11893100E+04, -.53176600E+04, 0.13099900E+05, -.87104600E+04, 0.41363700E+04, -.65488700E+04, -.34606300E+04, 0.18166300E+04, -.41152900E+04, -.21841100E+04, -.92777100E+04, 0.52693100E+04, -.65327500E+04, -.24608700E+04, 0.23962200E+04, 0.39495700E+04, 0.12308400E+04, -.73885500E+04, -.23389300E+04, 0.26388900E+04, 0.36097100E+03, 0.77213200E+03, -.17928200E+04, 0.21708700E+04, 0.55187400E+04, -.77095900E+03, -.74436000E+03, -.27541300E+04, 0.15381300E+04, -.38263000E+04, 0.60040500E+04, 0.13310700E+05, 0.79940400E+04, -.52400500E+04, -.49248800E+03, -.16239500E+05, 0.78894200E+04, 0.32742900E+04, 0.81186100E+04, -.39850900E+04, -.30138400E+04, 0.50126900E+04, -.47859600E+04, 0.97565300E+04, -.22244800E+04, 0.10961000E+05, 0.16748800E+04, -.23749600E+04, 0.53882400E+04, -.83710600E+03, -.60433200E+04, -.10414000E+03, -.18692600E+03, 0.13947200E+04, -.41304900E+04, 0.30655200E+04, 0.62239800E+02, 0.81000900E+04, -.39270300E+04, 0.28886600E+04, -.40469300E+04, 0.47116100E+04, -.66972200E+03, -.24683300E+04, 0.12553800E+04, -.41393000E+04, -.64085800E+03, -.54589700E+04, -.63462300E+04, 0.23604900E+04, 0.11922000E+04, 0.31731200E+04, 0.48627700E+04, 0.24670500E+04, -.30127900E+04, -.41481600E+04, -.17705300E+04, 0.23582700E+04, 0.20091700E+04, 0.20038600E+03, 0.69766900E+03, 0.42223600E+04, -.98529300E+02, -.20471400E+04, 0.26642900E+04, 0.10886300E+04, 0.48584400E+04, -.31605900E+04, 0.35960900E+04, 0.95770700E+03, -.98661700E+03, 0.24750100E+03, -.29132400E+04, -.24302000E+03, -.15647300E+04, 0.46553900E+04, 0.41075000E+04, -.18414000E+04, 0.28894800E+04, -.61304000E+03, -.16929500E+04, 0.14752900E+04, 0.73964300E+03, 0.12590900E+04, -.75766100E+03, -.12834200E+04, -.43006900E+04, 0.23730700E+03, -.80337100E+03, -.34545700E+03, 0.15293400E+03, -.15805400E+04, 0.16876700E+04, 0.40188600E+03, 0.19447800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.96346300E-01, -.17090100E+00, -.71822700E+00, -.11510200E+00, -.35991600E+00, 0.23655500E-01, -.24942900E+00, -.31746300E+00, 0.35965500E+00, -.10726600E+00, 0.66734100E-01, 0.67584100E+00, 0.17079100E+00, -.12908900E+00, 0.29438100E+00, -.14937800E+00, 0.59613600E-01, 0.28349400E+00, -.85188700E-01, 0.58335100E+00, -.77031000E+03, 0.77077800E+03, 0.65498000E+03, -.18149300E+03, -.23026200E+04, -.33728900E+03, 0.30036300E+02, -.33402400E+04, 0.18304700E+04, 0.41842100E+04, 0.18769600E+04, -.36111800E+04, 0.88435900E+03, 0.61878200E+03, -.14428300E+03, -.23492200E+03, -.31371300E+03, -.87770900E+03, 0.10407900E+04, -.87518800E+03, -.21381100E+04, -.70237400E+03, 0.13159400E+04, 0.72554000E+03, -.33756400E+04, 0.15754600E+04, 0.25943300E+04, 0.16871800E+04, 0.24452500E+03, -.85063900E+03, 0.18830600E+04, 0.15123300E+04, 0.11143200E+04, -.10232700E+04, -.17087800E+03, 0.36456100E+04, -.13797000E+04, -.50148000E+04, -.18223900E+04, -.53551100E+03, 0.14153300E+04, -.25676200E+04, -.23798400E+04, -.11028700E+04, 0.16540700E+04, 0.90205700E+03, 0.25741300E+04, -.12735800E+04, -.13865900E+04, -.12890500E+04, -.55556200E+03, -.24509900E+04, 0.11561600E+04, 0.28654900E+04, 0.78579600E+03, -.26198300E+04, -.46742200E+03, 0.79518400E+03, -.40987900E+03, -.14878300E+03, -.39710200E+03, 0.11049900E+02, -.49929400E+03, 0.16768100E+03, 0.54736500E+03, -.84398600E+02, -.14516500E+04, 0.35513600E+03, 0.23634100E+04, -.13250900E+04, -.71261300E+03, -.11832900E+04, -.88933700E+03, 0.23552200E+03, -.74069500E+03, -.82501000E+03, -.10577100E+04, -.54368600E+03, 0.27178900E+03, 0.85874700E+04, -.38916300E+04, -.25939100E+04, -.42914400E+04, -.12207600E+04, 0.22853000E+04, -.33216400E+04, -.24645000E+04, -.29818100E+04, 0.27937800E+04, -.24562900E+04, 0.20277300E+04, -.94201200E+03, -.59185000E+03, -.10129000E+04, -.13378200E+03, 0.36450900E+03, -.89364500E+03, -.69364500E+03, -.53299500E+03, 0.24109600E+03, -.33843500E+03, 0.23396100E+04, -.18503600E+04, 0.26556000E+03, -.11699400E+04, -.27720200E+03, -.10123600E+04, 0.31186600E+03, 0.24944400E+04, -.59685200E+03, -.12052000E+04, -.94114500E+03, -.19766100E+04, 0.97400500E+03, -.85583800E+02, 0.98556100E+03, 0.81254400E+02, -.13788100E+04, 0.16630600E+04, 0.20513200E+04, 0.13108700E+04, -.11616300E+04, 0.20129000E+03, 0.63772100E+04, -.38660100E+04, -.46808000E+04, -.31879600E+04, -.13296700E+04, 0.26459500E+04, -.28084600E+04, -.14468200E+04, -.20482300E+04, 0.19540100E+04, -.29518700E+03, -.20987800E+04, 0.10506300E+04, 0.26337100E+04, 0.10561700E+04, 0.53850400E+03, 0.39041300E+04, -.20058200E+04, -.47921900E+04, -.18384700E+04, 0.41783400E+04, -.62585300E+03, 0.55527800E+03, -.93101200E+03, -.15886500E+04, -.27853000E+03, -.38971000E+03, -.15756700E+04, 0.71800700E+03, 0.13331900E+04, 0.40655900E+03, -.21671100E+04, 0.51419100E+03, 0.74409500E+03, -.13324800E+04, -.25250800E+04, -.37340500E+03, -.88863800E+03, -.87102900E+03, -.15640200E+03, 0.98990000E+03, 0.71701500E+03, -.22568200E+04, 0.16363000E+04, -.26397700E+04, 0.18470300E+04, 0.29032100E+04, 0.13194000E+04, 0.84133300E+03, -.22950400E+04, 0.19912000E+04, 0.14860800E+04, 0.10578300E+04, -.18132000E+04, -.76630000E+03, -.49004300E+04, 0.33645300E+04, -.17033400E+04, 0.24439100E+04, 0.63294100E+03, 0.12837600E+04, -.11652100E+03, -.30005900E+04, 0.20140500E+04, 0.12550500E+04, 0.23971400E+04, -.77835500E+04, 0.38076600E+04, 0.21013000E+04, 0.38931600E+04, 0.14259600E+04, -.10031600E+04, 0.23346400E+04, 0.16326500E+04, 0.27652500E+04, -.12246000E+04, 0.16584100E+04, 0.29268200E+04, -.21412000E+04, -.77405300E+03, -.14638000E+04, -.79891600E+03, -.10343400E+04, -.37611600E+03, 0.94100300E+03, 0.11108200E+02, -.18412000E+04, 0.13758700E+03, 0.70815600E+04, -.34915200E+04, -.46398600E+04, -.35446200E+04, -.15946600E+04, 0.16402800E+04, -.24719600E+04, -.15359500E+04, -.18278900E+04, 0.11234800E+04, -.94400000E+03, 0.24171800E+02, -.36906400E+03, 0.41236400E+03, -.12029300E+02, -.27491600E+03, -.23402100E+03, 0.31951200E+03, 0.33246100E+03, 0.44694400E+03, 0.10835200E+03, -.29888100E+03, 0.55357100E+03, 0.11064400E+03, -.13016500E+04, -.27871400E+03, 0.28413200E+03, -.13865800E+04, 0.65325500E+03, 0.94937900E+03, 0.13213600E+04, -.16098800E+04, 0.12169500E+02, -.75754500E+02, -.36924100E+03, 0.44388500E+02, -.13074900E+04, 0.16145500E+04, 0.83148500E+03, 0.12649600E+04, -.23406200E+04, 0.18832000E+03, 0.29126600E+03, 0.21940300E+04, -.12785800E+03, -.75480100E+03, 0.11506300E+03, 0.57452600E+03, -.21858600E+04, 0.25791300E+04, 0.26230500E+03, 0.11235200E+04, -.44784500E+03, 0.22003200E+04, -.43726100E+03, -.85106300E+03, 0.39222900E+02, -.22538800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13851500E+01, 0.43212100E+00, 0.17439800E+01, 0.83693400E+00, 0.25526200E+01, 0.34561400E+00, -.58993900E+00, 0.19298000E+01, 0.69738000E+00, 0.13315500E-02, -.45202000E+00, -.10745500E+01, -.77833900E+00, -.78202100E+00, -.13996400E+01, 0.24645800E+01, 0.42985600E+00, -.13896400E+01, -.68094300E+00, -.21270800E+01, 0.47085700E+00, -.15544800E+05, 0.42019300E+05, -.15730200E+05, 0.27090800E+05, -.20943400E+05, 0.41632200E+04, 0.11642600E+05, -.12994300E+05, -.99463500E+04, -.37506000E+05, 0.14048300E+05, 0.86526100E+03, 0.32037100E+05, -.13999600E+05, -.11924900E+05, -.15989500E+05, 0.54006300E+04, 0.57301400E+04, -.10006400E+05, 0.14827100E+04, -.17434800E+05, 0.51456900E+04, 0.10497000E+05, 0.52198100E+05, -.27473700E+05, -.49335300E+04, -.26094800E+05, -.35377500E+04, -.81603300E+04, -.13353900E+04, 0.14027900E+05, -.57390300E+04, -.55667500E+04, -.10828500E+05, -.90060600E+05, 0.49784800E+05, -.24620400E+05, 0.45027300E+05, 0.60165000E+02, 0.19706800E+05, -.15663400E+04, -.20457400E+05, 0.20649000E+05, 0.13404300E+05, 0.39516100E+05, 0.26167900E+05, -.11218900E+05, 0.28803000E+05, -.13068200E+05, 0.17143400E+04, 0.47072500E+04, -.62896000E+04, -.61588300E+04, -.26640500E+05, 0.68692000E+04, -.92812000E+04, 0.24699400E+04, -.97551800E+03, 0.66157300E+04, -.12384100E+04, 0.13773400E+04, 0.31739200E+04, -.23999400E+04, -.44373400E+04, -.67747300E+04, 0.31141800E+04, -.18776600E+05, 0.13298700E+05, -.93586900E+04, 0.49726900E+04, -.66400000E+04, -.63696700E+04, -.52523400E+04, 0.40598900E+04, 0.17331500E+05, 0.13123100E+05, -.41164600E+04, -.48494900E+04, -.14038500E+05, 0.11986700E+05, 0.27836100E+05, 0.70041100E+04, 0.20256500E+05, 0.15079700E+05, -.11500000E+05, -.17807200E+05, -.12013400E+05, 0.10672000E+05, -.11448000E+05, -.23324600E+05, 0.12804700E+05, -.21665000E+05, 0.11655400E+05, 0.27062400E+03, 0.21135500E+04, 0.17694400E+04, 0.98677000E+03, 0.12203800E+05, 0.17759200E+04, 0.19208800E+05, -.77317200E+05, 0.30714500E+05, 0.98195100E+04, 0.38659400E+05, 0.12096400E+05, 0.11709100E+05, 0.46097600E+04, -.26403800E+05, -.43821200E+03, 0.13268400E+05, 0.66631900E+05, 0.22891800E+05, -.11408900E+05, 0.31208600E+05, -.11427500E+05, 0.49520600E+04, 0.51175800E+04, -.62090300E+04, -.92896900E+04, -.25502800E+05, 0.57047100E+04, -.15837000E+05, 0.59176700E+04, -.10113500E+05, -.11686500E+05, -.29631700E+04, -.48311600E+04, 0.21228400E+04, -.46605300E+04, 0.42862000E+03, 0.39428400E+03, 0.20551600E+04, 0.30798700E+04, -.43348100E+05, 0.17833400E+05, -.38957900E+05, 0.21624000E+05, -.33098000E+04, -.11741200E+05, 0.13238800E+05, 0.11512400E+05, 0.43616300E+05, -.15101800E+05, 0.35114600E+04, 0.53949800E+04, -.98995400E+04, -.19774500E+05, -.26916100E+04, -.13545000E+05, -.43660300E+04, 0.41645700E+04, 0.95872900E+04, 0.11726500E+04, -.78174600E+03, 0.30685800E+05, -.22566000E+05, 0.10342600E+04, -.11547900E+05, 0.11292000E+05, -.11608200E+05, 0.18744600E+05, -.43619700E+04, 0.45299400E+04, 0.73817500E+04, 0.20520300E+05, 0.60674300E+05, -.26094800E+04, 0.68645500E+04, 0.18758500E+05, 0.13080400E+04, 0.29460200E+04, -.54031600E+04, 0.57592300E+04, 0.64789700E+03, 0.52196200E+03, -.47613900E+04, -.99395500E+04, -.15874900E+05, 0.18398900E+05, -.62024100E+05, 0.79803100E+04, -.14019000E+05, -.39447000E+04, 0.25663800E+04, 0.16265700E+05, 0.36276600E+05, -.84952700E+04, -.20688900E+05, -.31856400E+05, 0.14875400E+05, -.75506500E+04, 0.15918800E+05, -.71853800E+04, -.84056900E+04, 0.12019700E+05, 0.11043800E+04, 0.19445400E+05, -.70929400E+04, 0.12737300E+04, -.47929500E+04, -.44760000E+04, 0.37465400E+04, 0.23991800E+04, 0.12910400E+04, 0.12552000E+05, -.25674300E+04, 0.88791500E+04, 0.14639100E+04, 0.14359700E+05, 0.24108000E+05, -.14089700E+04, 0.15567300E+04, -.17146500E+05, 0.73023100E+03, 0.16375500E+04, 0.78009800E+04, -.57999500E+04, -.12375300E+04, -.20842900E+04, 0.72594500E+04, 0.21782400E+05, 0.14307900E+05, -.10753900E+05, 0.71027600E+04, -.71541200E+04, 0.82917300E+03, -.31036800E+04, -.28087000E+04, -.53872000E+04, -.15090800E+05, -.14435200E+04, 0.11257400E+05, -.18353600E+05, 0.13249000E+05, -.17377600E+05, 0.91901600E+04, 0.84121200E+03, 0.14567200E+04, 0.39092400E+04, 0.84250200E+04, 0.14141400E+05, 0.18909200E+04, 0.28538900E+04, 0.21489400E+04, -.39507700E+04, 0.65818100E+04, -.21286100E+04, 0.17236900E+04, -.36117300E+04, 0.29958900E+04, 0.99154400E+02, -.54295600E+04, 0.23972000E+04, 0.48975400E+04, 0.82246200E+04, -.85810000E+04, 0.75213500E+04, -.82429200E+04, -.66006700E+03, 0.11694000E+04, -.69372100E+04, -.73199500E+04, -.52957000E+04, 0.82728500E+04, 0.16514400E+04, 0.16469600E+04, -.34981200E+04, -.35207800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54757600E+00, 0.21848000E+00, 0.10940400E+00, 0.80950200E+00, -.26837800E+00, -.94486700E-01, -.23466100E+00, 0.45291200E+00, 0.18100800E+01, 0.40323600E+00, 0.15992600E+00, -.29056100E+01, 0.14874600E+01, 0.11657000E+01, -.33556400E+00, 0.16068300E+01, 0.93259900E+00, -.19608700E+00, -.90193300E+00, 0.87233300E+00, -.18037600E+00, -.74607200E-01, 0.42621300E+05, -.18699400E+05, -.42735400E+04, -.21290900E+05, -.72325400E+04, -.16981400E+05, 0.53906800E+04, 0.11539800E+05, -.29743000E+04, -.15792200E+05, -.22006400E+05, -.24934200E+05, 0.13503100E+05, 0.14483400E+05, 0.12475700E+05, 0.64560500E+04, 0.70162000E+04, 0.28404200E+04, -.79493400E+03, 0.67768900E+04, 0.68866900E+04, 0.90851300E+04, 0.30346900E+05, -.15815800E+05, -.57650300E+04, -.15172200E+05, -.55575300E+03, -.17762900E+03, 0.18036400E+04, 0.15180100E+05, -.63137900E+04, -.26509900E+04, -.14131100E+05, -.83381500E+05, 0.44349500E+05, 0.24028100E+04, 0.41689800E+05, 0.40427000E+03, 0.67979700E+04, 0.15386800E+04, -.24073400E+05, 0.25599500E+05, 0.83364200E+04, 0.38901600E+05, 0.38171200E+05, -.18105800E+05, 0.68982600E+03, -.19080200E+05, -.55984200E+04, -.10364300E+05, 0.13370200E+04, 0.73829200E+04, -.91531800E+04, -.97241200E+04, -.18194200E+05, 0.27966500E+04, -.16035300E+04, 0.16485700E+04, -.13994000E+04, -.15458100E+04, -.29975000E+04, 0.19511100E+04, 0.24481800E+04, 0.76199900E+03, -.27240700E+04, -.78473500E+03, -.11039700E+05, 0.41905000E+04, 0.12833800E+05, 0.55222100E+04, 0.12472100E+04, 0.11052500E+05, -.36217700E+04, -.21211800E+04, -.56766300E+04, 0.95530800E+04, 0.17791900E+04, -.43646200E+05, 0.24476100E+05, 0.32933100E+05, 0.21818700E+05, 0.75757200E+04, 0.85430400E+04, -.24467200E+04, -.15524300E+05, 0.64539000E+04, 0.10458700E+05, 0.21511200E+05, -.18848000E+05, 0.10321500E+05, -.53097000E+04, 0.94218200E+04, 0.22944200E+04, 0.63513200E+04, -.17998400E+04, -.27121100E+04, 0.48626300E+04, 0.51318400E+04, 0.86782300E+04, -.78950600E+04, -.62253600E+03, 0.13136000E+04, 0.39477000E+04, 0.38229700E+04, -.10088400E+04, 0.38974400E+04, -.11273800E+04, 0.12011800E+05, -.15008200E+04, 0.18812500E+04, 0.29355300E+05, -.14808600E+05, 0.20960200E+04, -.14672200E+05, -.32882100E+04, -.10062900E+05, 0.37140100E+04, 0.52800500E+04, -.52152900E+04, -.88221800E+04, -.13783200E+05, -.46669400E+04, -.19169300E+04, -.28405800E+04, 0.23321800E+04, -.81576400E+04, -.12759600E+04, 0.53388600E+04, 0.29250000E+04, 0.39117600E+04, -.11544400E+04, 0.27113300E+04, -.60335100E+05, 0.28202800E+05, 0.47199900E+04, 0.30151300E+05, 0.99807200E+04, 0.18914200E+05, -.37682600E+04, -.12877100E+05, 0.97682600E+04, 0.17799300E+05, 0.29888200E+05, 0.20478000E+04, -.52678300E+04, -.12662200E+05, -.10221900E+04, -.34998100E+04, -.83944000E+03, 0.40852000E+03, 0.61769900E+03, 0.13336600E+04, -.28441400E+04, -.18964200E+04, -.21836700E+05, 0.48983300E+04, -.13572800E+05, 0.10921000E+05, -.97944900E+03, 0.15116300E+05, -.59355400E+04, -.45516000E+04, 0.82676300E+04, 0.10463400E+05, 0.57824700E+04, 0.13017500E+05, -.31750700E+04, 0.30477600E+04, -.65077600E+04, 0.47024200E+04, -.25652500E+04, -.32999400E+04, -.51256500E+03, -.62675900E+04, -.20392800E+04, -.57280600E+04, -.34212000E+05, 0.23161700E+05, -.29677300E+05, 0.17118900E+05, -.34801700E+04, 0.26801300E+04, -.33197900E+03, -.21261300E+04, 0.74945400E+04, 0.21212100E+04, 0.19917300E+05, 0.32496600E+05, -.16677600E+05, -.30958300E+05, -.16251100E+05, -.45966900E+04, -.80870100E+04, 0.26365300E+04, 0.12761700E+05, -.35031800E+04, -.88653800E+04, -.14163100E+05, 0.42578100E+04, -.62208900E+04, -.53357900E+04, -.21280800E+04, -.19513500E+02, 0.93000800E+04, -.10897900E+05, -.51266800E+04, -.43881700E+04, 0.66462300E+04, -.44181400E+04, -.11969000E+05, 0.65071200E+04, -.81740500E+04, 0.59921100E+04, -.37273100E+03, 0.52569300E+04, 0.35708800E+04, 0.31485300E+04, 0.60263800E+04, 0.38708400E+04, 0.48208600E+04, 0.11460700E+05, -.79323400E+04, 0.60114000E+04, -.57303400E+04, 0.28238500E+02, -.21655200E+04, 0.33533700E+04, 0.58980800E+04, -.54539700E+03, -.23265300E+04, -.61689400E+04, -.15068700E+05, 0.97917000E+04, -.11082000E+05, 0.75384700E+04, 0.14176600E+04, -.27382600E+04, -.28752800E+04, -.31106000E+04, 0.31365500E+04, -.23948600E+04, 0.81706900E+04, 0.52030800E+04, -.10296700E+04, 0.48505900E+04, -.54532900E+04, 0.34740600E+04, -.50315800E+04, 0.11284200E+04, -.25085800E+04, -.47443900E+04, 0.47195500E+04, 0.54564300E+04, 0.11718200E+03, -.40570500E+04, 0.23239200E+04, -.32385500E+04, -.49759600E+04, 0.19906200E+04, -.77423800E+04, -.36026100E+04, 0.35663100E+03, 0.11137600E+05, 0.54259500E+04, -.25300500E+04, -.38698600E+03, -.43878500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17546400E+00, -.25941700E+00, -.10212000E+01, -.13160500E+00, -.50030800E+00, 0.32800100E-01, -.37368300E+00, -.40050600E+00, 0.61762800E+00, -.13000900E+00, 0.86296800E-01, 0.75521900E+00, 0.92430200E-01, -.19391400E+00, 0.73574600E-01, 0.10670400E+00, 0.15673900E+00, 0.23436300E+00, -.17898500E+00, 0.67087000E+00, 0.12703100E+01, 0.49750100E-01, 0.16097800E+00, -.16437200E+04, -.37427700E+03, 0.50950100E+01, 0.13617000E+04, 0.70075500E+04, -.34982300E+04, -.35668000E+04, -.23617100E+04, 0.59335300E+04, 0.21546900E+04, -.26955800E+04, 0.92425300E+03, -.73249400E+02, 0.13500600E+04, -.41026100E+03, -.75016400E+03, 0.52425200E+03, 0.75917800E+03, 0.10716100E+04, -.84137500E+03, 0.23731600E+04, -.17922000E+04, 0.11784500E+04, -.45161800E+04, 0.89643500E+03, -.38967400E+03, 0.51336500E+03, -.92581200E+03, -.20113700E+04, 0.50243800E+03, 0.77803000E+03, 0.25965600E+04, 0.12599800E+05, -.71848600E+04, 0.94253500E+04, -.63001200E+04, 0.15788200E+03, -.24750400E+04, 0.80298800E+03, 0.44444000E+04, -.45803400E+04, -.23421400E+04, -.78944600E+04, -.38283200E+04, 0.10281800E+04, -.61798400E+03, 0.19149800E+04, 0.15010700E+04, 0.51052100E+04, -.19972600E+04, -.27348100E+04, -.48090300E+03, 0.43189600E+04, 0.32455200E+04, 0.41540400E+03, -.27053400E+03, -.46753600E+03, -.20794500E+03, 0.51198100E+03, 0.21149700E+04, -.11058300E+04, -.89445200E+03, -.10359700E+04, 0.16926600E+04, 0.98632900E+02, 0.15454200E+04, -.32596700E+02, -.26467800E+04, -.77174200E+03, 0.65649300E+02, -.13806100E+04, 0.42987700E+03, 0.86242600E+03, 0.50718700E+03, -.76553700E+03, 0.59324200E+03, -.89101100E+04, 0.33972900E+04, -.10516400E+04, 0.44538300E+04, 0.69217300E+03, -.13133000E+04, 0.32122100E+04, 0.28130300E+04, 0.40656500E+04, -.15464500E+04, 0.18138600E+04, 0.17053300E+04, -.11646600E+04, 0.23660100E+04, -.85312800E+03, -.76181600E+03, -.23531700E+04, 0.10650800E+04, 0.11720600E+04, -.24739200E+03, -.17139500E+04, -.94630300E+03, 0.21663700E+04, 0.53895500E+03, -.14676300E+03, -.10831000E+04, -.26319100E+03, 0.21511900E+04, -.21722900E+04, -.29593600E+04, -.23935300E+04, 0.20136300E+04, -.79191500E+03, -.32886200E+04, 0.16308900E+04, -.14805300E+04, 0.16457500E+04, 0.11397500E+04, 0.38578100E+04, -.17476900E+04, -.24142200E+04, -.88681900E+02, 0.30000700E+04, 0.22466600E+04, 0.34896500E+04, -.42901500E+03, 0.15918700E+04, -.17451600E+04, 0.73878700E+03, -.25559700E+04, 0.89339600E+03, 0.21028400E+04, -.79207900E+03, -.18284600E+04, -.10613000E+04, 0.19458100E+04, 0.78216300E+03, 0.30702100E+03, -.97603700E+03, -.20518000E+04, -.80287200E+04, 0.36439500E+04, 0.40211100E+04, 0.19975500E+04, -.68473700E+04, -.35228500E+04, 0.57856700E+04, -.14990100E+04, 0.13763500E+04, -.28923600E+04, -.22027800E+03, 0.94252000E+03, -.16268400E+04, -.58732100E+03, -.27254800E+04, 0.11665400E+04, -.50984700E+03, 0.93678300E+04, -.27758500E+04, 0.19268200E+04, -.46831900E+04, 0.14318800E+01, -.19664600E+04, -.12183200E+03, 0.75675200E+03, -.41490600E+04, -.87020300E+03, -.20227400E+04, -.43618700E+04, 0.11588800E+04, -.23916600E+04, 0.21811900E+04, -.49650800E+03, 0.22993000E+04, -.60907300E+03, -.18331500E+04, 0.12921100E+04, 0.16711800E+04, 0.14835500E+04, 0.13349900E+05, -.87679900E+04, 0.94856400E+04, -.66717000E+04, -.65562800E+03, -.37082900E+04, 0.85195800E+03, 0.48310900E+04, -.42322900E+04, -.32156300E+04, -.69909900E+04, 0.56031500E+04, -.25840700E+04, 0.21180200E+04, -.28023000E+04, -.45215700E+03, 0.53219000E+03, -.19202300E+04, -.23360000E+04, -.27015500E+04, 0.63426800E+03, -.26029900E+04, -.46865200E+03, 0.14240600E+04, -.78426900E+02, 0.23452400E+03, 0.10183500E+04, -.59831200E+03, 0.10085900E+04, 0.47765400E+03, -.21824700E+03, 0.16943100E+03, 0.14480300E+04, 0.34361600E+03, -.41319500E+03, 0.24261000E+04, -.16978800E+03, -.16412000E+03, -.20121300E+04, 0.94962200E+03, 0.14174000E+04, -.48528000E+03, -.15049700E+04, 0.10961900E+04, -.50348100E+04, 0.31478400E+04, -.16273100E+04, 0.25173500E+04, -.17970500E+02, 0.62568800E+03, -.21804000E+03, -.13178600E+04, 0.11651300E+04, 0.52404600E+03, 0.31246900E+04, 0.36316000E+04, -.25141100E+04, 0.37052700E+04, -.18148300E+04, 0.12413300E+03, 0.12143000E+04, -.52236400E+03, 0.68858200E+03, -.20491800E+04, 0.10695000E+04, -.21240200E+04, -.14670600E+04, 0.83349700E+03, -.85013500E+03, 0.18450800E+04, -.16099800E+04, 0.15108800E+04, -.14495100E+03, 0.18335600E+04, 0.78660800E+03, -.13910600E+04, -.21670700E+04, 0.17909500E+03, 0.16985200E+04, -.51765700E+03, -.14116600E+03, 0.21682000E+04, -.22439200E+04, 0.14269100E+04, -.55242300E+03, 0.60463400E+03, -.20133200E+04, -.94892400E+03, 0.14293200E+04, 0.62340400E+03, 0.13693400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16021800E+01, 0.28465200E+00, -.34773000E+01, 0.98678500E+00, -.21958700E+01, -.23243100E+00, -.18176300E+01, -.33146000E+01, 0.23827200E+01, 0.52746500E+00, 0.21607600E+00, 0.13816800E+00, -.34872200E+01, 0.45329700E-01, -.34357400E+01, 0.10367400E+01, -.94945000E+00, 0.46422500E+00, -.66091700E-02, -.35670600E+00, -.46768400E+01, -.96989100E-01, 0.19968400E+01, 0.89258900E+00, 0.99499500E+05, 0.14139000E+02, 0.12152800E+05, -.15470100E+05, 0.14343300E+05, 0.16926800E+04, 0.33126600E+04, -.11069900E+05, -.24492500E+05, -.21941700E+05, 0.11025200E+05, 0.15053200E+05, 0.10977300E+05, 0.98009200E+04, -.45388800E+04, 0.49069400E+04, -.36971300E+04, 0.18786100E+01, -.24552500E+04, -.24833600E+04, 0.15659800E+05, -.80261400E+04, 0.94733800E+04, -.78289200E+04, 0.81484800E+04, -.11513000E+05, -.85507900E+04, -.43298400E+04, -.45586400E+04, -.94453500E+04, -.98217000E+04, -.79254300E+05, 0.39280600E+05, -.50987400E+05, 0.39626800E+05, -.16706900E+05, 0.28796300E+05, 0.10051400E+05, -.46146200E+04, 0.28536800E+05, 0.22184000E+05, 0.41792500E+05, 0.19614500E+05, -.10702700E+05, 0.94795900E+05, -.98067600E+04, 0.22685600E+04, -.11987600E+05, 0.74782100E+04, 0.59016300E+04, -.64117300E+04, -.82528900E+04, -.24667100E+05, 0.19823400E+05, -.97011600E+04, 0.14236400E+05, -.99122900E+04, 0.67318500E+03, -.64124600E+04, 0.12893500E+04, 0.64713300E+04, -.35453000E+04, -.48057200E+04, -.11447000E+05, 0.15012000E+05, -.76047700E+04, 0.26476100E+05, -.75021400E+04, 0.54861700E+04, 0.12064600E+05, -.13440300E+05, -.34880600E+04, -.12289000E+05, 0.69093500E+04, -.11713800E+05, 0.53993400E+05, -.27085000E+05, -.25357800E+05, -.27000400E+05, 0.13369500E+05, 0.36573900E+05, -.12003800E+05, 0.23327800E+05, -.22198100E+05, 0.28969100E+05, -.13481700E+05, -.51629500E+05, 0.25715200E+05, -.35416900E+05, 0.25813700E+05, -.12985600E+04, 0.12034600E+05, -.43408800E+03, -.11950300E+05, 0.12548000E+05, 0.79756200E+04, 0.23712500E+05, 0.39875000E+05, -.19198400E+05, -.69368000E+04, -.19937100E+05, -.25647000E+04, -.33421700E+05, 0.74733300E+04, -.36438200E+04, -.39647100E+04, -.27202600E+05, -.27140000E+05, 0.30654900E+05, -.15442100E+05, 0.57741800E+05, -.15323300E+05, 0.99885900E+04, -.12534900E+05, 0.48731600E+04, 0.10316100E+05, -.23501700E+04, -.79288300E+04, -.18528500E+05, -.63300000E+04, 0.41383800E+04, -.18837000E+05, 0.31640500E+04, 0.13552700E+05, 0.38037500E+05, -.19787500E+05, -.15024500E+05, -.32189500E+04, 0.28125400E+05, -.57141900E+04, -.47728300E+04, 0.35146700E+04, -.14358100E+06, 0.23810300E+04, -.63535700E+04, 0.18058100E+05, -.16548500E+05, -.25162900E+04, 0.11706100E+02, 0.12604400E+05, 0.31521000E+05, -.22607400E+05, 0.11970600E+05, -.10284600E+05, 0.11305100E+05, -.11657200E+05, -.20506000E+05, 0.41572600E+04, -.95019500E+04, 0.85090400E+04, -.18554400E+05, -.78073300E+04, -.97788400E+05, 0.49895300E+05, -.40968200E+05, 0.48896300E+05, -.14413300E+05, -.42037900E+04, 0.63033800E+04, -.24679600E+05, 0.39102700E+05, -.89439200E+04, 0.26200600E+05, 0.26795300E+05, -.14192800E+05, 0.14350900E+05, -.13396900E+05, -.10426100E+05, -.26652200E+05, 0.90564400E+04, 0.12746300E+05, -.70544400E+04, -.19754300E+05, -.35473800E+04, -.16416400E+06, 0.81144100E+05, -.46440300E+05, 0.82090500E+05, -.11983100E+05, 0.37380500E+05, 0.91294200E+04, -.11561100E+05, 0.47554600E+05, 0.30169600E+05, 0.86961600E+05, -.68107300E+05, 0.34021100E+05, 0.90291200E+04, 0.34051600E+05, -.10705500E+05, -.24755800E+05, 0.16080400E+05, -.20283600E+05, 0.29653000E+05, -.18943700E+05, 0.36667500E+05, -.14160000E+05, 0.77165700E+04, 0.60814500E+04, 0.70804900E+04, 0.13364900E+05, 0.24901200E+05, -.93853800E+04, -.93391600E+03, 0.40306300E+04, 0.15986100E+05, -.72985900E+04, -.63636800E+05, 0.31822600E+05, -.10104200E+05, 0.31824200E+05, 0.74995600E+04, 0.81725300E+04, -.92480000E+03, -.14354500E+05, 0.16256600E+05, 0.48022600E+04, 0.16379900E+05, 0.14913500E+05, -.69268100E+04, 0.14725700E+05, -.74571200E+04, -.16275100E+04, -.20724400E+05, 0.58099200E+04, 0.13025100E+04, -.65522500E+04, -.15151600E+05, -.15299100E+05, -.41482200E+05, 0.20406200E+05, -.27470700E+05, 0.20743500E+05, 0.54895900E+04, 0.24022600E+05, -.20806300E+04, 0.22293200E+04, 0.65312800E+04, 0.18877100E+05, 0.21045000E+05, 0.68068600E+04, -.33736100E+04, 0.11807800E+05, -.17284600E+05, 0.63745600E+04, 0.56834800E+04, 0.10103200E+05, -.13861500E+05, -.11073700E+05, 0.77910000E+04, 0.25759000E+05, 0.11296500E+05, -.26816600E+05, 0.12072000E+05, -.95965900E+04, -.18987700E+05, 0.28396800E+05, -.89985400E+04, -.57728000E+04, -.16266500E+05, 0.28780000E+05, 0.10766800E+05, -.55913600E+04, 0.11566100E+03, -.51295000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19940600E+01, 0.36819500E-01, -.17016800E+01, 0.41824300E+01, 0.79836000E+00, -.24666800E+00, -.43052000E+01, -.83789500E+01, 0.14268300E+01, 0.72795400E+00, 0.30714700E+00, 0.42306500E+01, -.63653500E+01, -.24609200E+01, -.50209900E+01, -.44529100E+01, -.16625500E+01, 0.29755100E+01, -.39904700E-01, 0.12774200E+01, -.17441500E+01, -.49408500E+00, 0.71014200E+00, -.94456900E+00, 0.47426200E+00, -.37014200E+03, 0.57687900E+03, 0.40047000E+04, -.33021400E+04, 0.40185200E+04, -.20031200E+04, 0.22066200E+04, -.92716200E+04, 0.32806500E+05, -.16858600E+05, -.19205700E+05, -.16567700E+05, -.50711100E+04, -.41191900E+04, -.74722700E+04, -.28905500E+04, -.89629100E+04, -.45872500E+04, -.12538500E+05, -.37220800E+05, 0.18885800E+05, 0.19024800E+05, 0.18586100E+05, 0.47889800E+04, 0.33425800E+04, 0.71940500E+04, -.69380500E+04, 0.64433300E+04, 0.56483900E+04, 0.90181200E+04, 0.75908000E+05, -.39188000E+05, -.15816600E+05, -.37938900E+05, -.69409900E+04, -.87638400E+04, -.11824900E+05, 0.91674300E+04, -.20401900E+05, -.10655100E+05, -.26693400E+05, 0.45701700E+04, -.18622800E+04, -.16268600E+05, -.23526300E+04, -.12651200E+04, -.42712000E+02, -.58976600E+03, 0.44943200E+04, 0.37142200E+04, -.60401600E+03, -.50203300E+04, 0.30746300E+04, -.43659800E+03, -.39441000E+04, -.15192400E+04, -.17083800E+03, 0.10582800E+04, -.13981100E+04, 0.43270300E+03, 0.91983400E+03, 0.68232900E+03, 0.10324900E+03, -.12803600E+04, 0.92665100E+03, -.85048200E+04, 0.57589500E+03, -.70617500E+03, -.96403300E+04, 0.81696600E+04, 0.69232200E+04, 0.85686100E+04, -.84436700E+04, -.45640100E+04, 0.63683700E+05, -.32913500E+05, -.38348000E+05, -.31754100E+05, -.16410700E+05, -.21002400E+05, -.45014900E+04, 0.56099500E+04, -.80393400E+04, -.20644500E+05, -.90832400E+04, 0.71645400E+04, -.48039300E+04, 0.47001700E+04, -.35472000E+04, 0.16204600E+03, -.48440500E+04, 0.10940100E+04, -.46018700E+03, -.31388400E+04, -.38155600E+04, -.10165600E+05, 0.17441000E+04, 0.95960600E+03, -.10638100E+05, -.87759200E+03, -.20651400E+04, 0.14132200E+04, -.22379600E+04, 0.11563700E+05, 0.22282000E+04, -.56013500E+03, -.43599900E+04, 0.73586600E+04, -.29445100E+04, -.81991000E+04, -.37833500E+04, -.20898300E+04, 0.29396200E+04, -.23391400E+04, 0.45871800E+04, -.84231600E+03, 0.20386500E+04, 0.37537500E+04, -.30519400E+04, 0.34954100E+04, -.73766000E+04, 0.15505000E+04, 0.96424100E+04, 0.50995700E+04, -.53445600E+04, -.89320000E+04, 0.85444000E+02, 0.42509100E+04, 0.24165300E+04, -.48139000E+04, 0.18805500E+04, 0.13441900E+05, 0.26487100E+04, 0.32924400E+03, -.25289300E+04, 0.28503400E+04, -.60144600E+04, -.65349500E+03, -.98010600E+03, 0.10771500E+05, -.18751300E+05, 0.11366900E+05, 0.21907300E+05, 0.93469500E+04, 0.78796500E+04, 0.61966600E+04, 0.28061300E+04, -.11152900E+04, -.18816100E+04, 0.70980700E+04, -.12103000E+05, 0.20487700E+05, -.74379800E+04, 0.24561100E+05, -.10295800E+05, 0.32425800E+04, -.10314800E+05, 0.93194000E+04, 0.19116000E+05, -.51585100E+04, -.78929400E+04, -.38277600E+05, -.13377400E+05, 0.51806800E+04, 0.94796300E+04, 0.66702300E+04, -.71301600E+04, -.32574100E+04, 0.73245600E+04, 0.48635500E+04, 0.52651000E+04, -.25564700E+04, 0.53591100E+04, 0.24776000E+05, -.14949900E+05, 0.26768800E+05, -.12626000E+05, 0.51596300E+04, 0.42109200E+04, -.61721600E+04, -.17344600E+05, -.16337700E+05, 0.56377800E+04, -.90509400E+04, -.22432100E+05, 0.11295000E+05, 0.26761400E+05, 0.11268700E+05, 0.86305700E+04, 0.15912800E+05, -.17064100E+04, -.99089700E+03, 0.16318300E+04, 0.15287000E+05, 0.71513600E+04, -.60814400E+04, 0.50743100E+04, 0.45611200E+04, 0.30260400E+04, 0.18962400E+04, -.13724500E+05, 0.14895400E+05, 0.15289600E+05, 0.66990900E+04, -.10988600E+05, -.18720700E+05, 0.20104400E+05, -.10384000E+05, 0.46579800E+04, -.10198600E+05, 0.61781700E+03, 0.62923900E+03, -.58076500E+04, -.68120600E+04, -.77817400E+04, 0.29818900E+03, -.12868000E+05, 0.16345800E+04, 0.28708400E+03, -.80298600E+04, -.81447800E+03, 0.81002900E+03, 0.49268700E+04, -.68894200E+04, -.63496200E+04, -.13546200E+04, 0.38865400E+04, 0.95072600E+03, 0.63892200E+04, -.38681900E+04, 0.10821100E+05, -.32665800E+04, 0.45336600E+02, -.41655700E+04, 0.69163200E+04, 0.55028700E+04, 0.61249200E+03, -.31873200E+04, -.14822400E+05, -.14761700E+04, 0.85901500E+03, -.86347300E+03, 0.24012800E+04, 0.66374500E+03, -.16661700E+03, -.15404500E+04, 0.23526200E+04, 0.79446300E+03, -.20529900E+04, -.65971400E+04, -.27076000E+04, 0.72319300E+04, -.26190700E+04, 0.42235800E+04, 0.25264700E+04, -.17689200E+04, 0.56145500E+04, 0.53886400E+04, 0.19020900E+04, -.13484100E+05, -.64159500E+04, 0.54630200E+03, -.24121100E+03, 0.84078200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14761300E+00, 0.90286900E-01, 0.44187300E-01, -.13220300E+00, -.17672500E+00, 0.62728000E-02, 0.33369100E+00, 0.56918300E+00, 0.10723400E+00, -.12069500E-01, -.19703900E-01, -.63149000E+00, -.33736100E+00, 0.88866600E-01, -.25600100E+00, 0.38812500E+00, 0.33046000E+00, 0.34825200E-01, -.10810600E+00, 0.39440700E+00, 0.14539500E+00, 0.13825900E-01, 0.29842000E-01, 0.74626800E-01, -.30462000E-01, -.22626200E-01, -.31419200E+04, -.39189400E+04, 0.37943500E+04, 0.39344600E+04, 0.25695200E+04, -.34218200E+04, -.24881700E+04, -.56565200E+04, 0.25898500E+04, 0.34793000E+04, 0.28282400E+04, 0.26439000E+02, -.64375400E+02, 0.18461100E+04, 0.82112300E+03, 0.19304900E+04, 0.21677800E+03, 0.39691700E+03, -.86918300E+03, 0.60711200E+03, 0.14181600E+04, 0.43458700E+03, -.25888300E+03, 0.10575200E+04, 0.65614000E+02, 0.38582500E+03, -.12329700E+03, 0.50705800E+03, 0.50983900E+03, -.49163700E+04, 0.18018500E+04, 0.90847600E+03, 0.24581700E+04, 0.11529100E+04, -.96858000E+03, 0.10749700E+04, -.76801800E+03, 0.18580400E+04, -.18584700E+03, 0.98682500E+03, -.20782900E+04, 0.11710400E+04, -.16141600E+04, 0.10393300E+04, -.15502700E+04, -.21307100E+04, 0.25023100E+04, 0.25971500E+04, 0.24423500E+04, -.19119900E+04, -.24669300E+03, -.27949300E+04, 0.13470600E+04, -.24334900E+03, 0.13974500E+04, -.54311200E+03, -.72541500E+03, 0.12387000E+04, 0.91008100E+03, 0.17910300E+04, -.63598200E+03, 0.11526400E+04, -.34048700E+04, 0.18574800E+04, 0.59709500E+03, 0.17023300E+04, 0.19406400E+03, 0.10728300E+04, -.48535900E+03, -.20329300E+04, -.10884000E+04, 0.12104900E+04, 0.17121300E+04, -.46526200E+04, 0.17545000E+04, 0.48514600E+04, 0.23263400E+04, -.10816300E+03, -.21126500E+04, 0.15053800E+04, 0.66284200E+02, 0.12700800E+04, -.83129000E+03, 0.10543300E+04, -.21792100E+04, 0.10900100E+04, 0.10417500E+04, 0.10895700E+04, 0.16357100E+04, 0.13577600E+04, -.23956600E+03, -.40695400E+03, 0.12210000E+03, 0.11499300E+04, 0.89537000E+03, -.15880500E+04, 0.17666100E+04, -.11083400E+04, 0.79401400E+03, 0.52889600E+03, -.26774800E+03, 0.16280400E+04, 0.12679600E+04, 0.32449700E+04, -.48326600E+03, -.56666300E+03, 0.43147900E+04, -.21661800E+04, -.10530200E+04, -.21574000E+04, -.29636300E+04, -.26341900E+04, 0.11175100E+04, 0.20600800E+04, 0.25799000E+03, -.22888900E+04, -.27349500E+04, -.84395300E+04, 0.52146100E+04, 0.48572600E+04, 0.42197700E+04, -.52086900E+03, -.16595000E+04, 0.29319500E+04, 0.11341600E+03, 0.20361500E+04, -.90821800E+03, 0.10848000E+04, 0.11052900E+04, -.87063200E+03, 0.16310700E+04, -.55298800E+03, 0.30346300E+04, 0.42065400E+04, -.42909600E+04, -.44683000E+04, -.33426200E+04, 0.37079100E+04, 0.21929500E+04, -.23032900E+04, 0.20970900E+04, 0.41199700E+03, 0.11517600E+04, 0.13623200E+04, 0.13945700E+04, -.21644500E+03, -.96810300E+03, 0.10975500E+04, 0.67569000E+03, -.41750500E+03, 0.55633700E+03, 0.11403300E+04, 0.18224600E+04, -.27818400E+03, 0.21621100E+04, 0.17134100E+04, -.15297900E+04, -.23104400E+04, -.10673900E+04, 0.11886000E+04, -.17210200E+04, 0.69211400E+04, -.42362900E+04, -.35072400E+04, -.34605700E+04, 0.55284000E+03, 0.14736200E+04, -.25430000E+04, -.11067700E+03, -.19250400E+04, 0.90565300E+03, -.87870100E+03, 0.76663000E+03, -.16985900E+04, -.13795100E+03, -.38330500E+03, 0.70084200E+03, 0.92735400E+03, -.15809100E+04, -.97363800E+03, -.31242200E+04, 0.10243900E+04, 0.81318100E+03, 0.97828900E+04, -.47648300E+04, -.58224700E+04, -.48914400E+04, -.62601400E+03, 0.10201300E+04, -.18438700E+04, 0.12184700E+04, -.29724100E+04, 0.32900200E+03, -.18710400E+04, 0.16437700E+04, 0.20288800E+03, -.79743700E+03, -.82188000E+03, 0.30626000E+03, 0.33499000E+03, -.23362300E+04, -.37190300E+04, -.19917400E+04, 0.62526600E+01, -.12158500E+04, -.47259500E+04, 0.23258700E+04, 0.41442400E+04, 0.23629500E+04, 0.42397600E+03, 0.55772200E+02, 0.14863900E+04, 0.58545900E+03, 0.88681300E+03, 0.49486100E+03, -.51352300E+03, -.47963800E+03, 0.76813600E+03, 0.58533300E+03, 0.23983600E+03, -.21219100E+03, 0.17016700E+03, 0.11500600E+04, 0.17689400E+04, 0.10128400E+04, -.44198300E+01, -.12899100E+04, 0.10859600E+04, -.11625900E+04, 0.13619800E+03, -.54295700E+03, 0.73941700E+03, 0.44989000E+02, -.18629400E+04, -.23295400E+04, -.19790800E+04, -.19343300E+03, 0.42175800E+03, 0.29288000E+03, 0.21104800E+02, -.50726500E+02, 0.29467200E+03, -.50404300E+03, -.10844600E+04, -.75494800E+03, 0.12760700E+04, -.20888500E+02, 0.15927400E+03, -.99743700E+03, -.19457900E+04, 0.20205800E+03, -.10569200E+04, 0.50575700E+03, 0.92851100E+03, -.13617900E+04, -.69182500E+03, 0.10671200E+03, 0.19985500E+03, -.98760800E+03, 0.10654300E+04, -.39940000E+03, -.46996800E+01, -.51865300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10185700E+01, 0.11217800E+01, 0.64474600E+00, 0.56748800E-01, 0.38188000E+00, 0.24479100E+00, 0.18207900E+00, 0.17864800E+01, 0.12295400E+01, -.10236500E+00, -.46686700E+00, -.55945300E+01, -.17230000E+01, -.10439400E+00, -.48478200E+01, 0.29460200E+01, 0.29941500E+01, 0.23781800E+00, -.97912100E+00, 0.15163400E+01, 0.17677800E+01, -.35660200E+00, 0.15561400E+01, 0.14531700E+01, 0.14881000E+00, -.36284900E+00, -.21648200E+00, 0.30426200E+05, -.19475200E+05, -.26370500E+05, -.18521000E+05, 0.28617100E+05, 0.16641700E+05, 0.18667700E+05, -.10708900E+05, -.10638300E+05, -.93342300E+04, -.29106500E+04, -.83252500E+04, -.85921600E+03, 0.10455400E+05, -.61581500E+04, -.82477200E+04, -.37462300E+04, -.43493100E+05, 0.22644200E+05, 0.15137100E+05, 0.21746500E+05, 0.52851800E+03, 0.11959500E+05, 0.27129600E+04, -.17300300E+05, 0.10728400E+05, 0.14531200E+05, 0.23947600E+05, 0.74808300E+05, -.41389100E+05, 0.60884700E+03, -.37404400E+05, -.13626600E+04, -.23560400E+05, -.28308700E+04, 0.24507200E+05, -.22378400E+05, -.24223600E+05, -.42538100E+05, -.31915600E+05, 0.16913000E+05, -.57898600E+04, 0.15960700E+05, 0.23859400E+04, 0.17019500E+05, -.60229300E+04, -.19152500E+05, -.47607100E+03, 0.16522300E+05, 0.21628600E+05, -.15508500E+05, 0.82176500E+04, 0.13980900E+04, 0.77540600E+04, 0.13512000E+04, 0.65782000E+04, -.20996000E+04, -.87735000E+04, 0.63613700E+03, 0.58161500E+04, 0.50980300E+04, -.66822900E+04, 0.41985300E+04, -.12600200E+05, 0.33394400E+04, -.26065200E+04, -.89988700E+04, 0.78457000E+04, 0.63042400E+04, 0.12662500E+05, -.39843100E+04, 0.16724800E+05, -.27309500E+05, 0.10235300E+05, 0.13810400E+04, 0.13655200E+05, 0.93549600E+03, -.36999000E+05, 0.17284800E+05, 0.10739700E+05, 0.11285800E+05, -.34551700E+05, -.14340600E+05, 0.12322100E+05, -.69282200E+04, 0.34827600E+03, -.61615700E+04, -.63297300E+03, -.80892600E+04, 0.26491000E+04, 0.60265700E+04, -.26480500E+04, -.47100300E+04, 0.17763200E+04, -.50043500E+05, 0.31215900E+05, 0.86559500E+03, 0.25021600E+05, 0.70555200E+04, 0.20715500E+05, -.33504500E+04, -.19788100E+05, 0.19137400E+04, 0.20574600E+05, 0.33813700E+05, -.14058800E+05, 0.74112600E+04, 0.56564300E+04, 0.70292800E+04, -.81224200E+02, 0.16070900E+05, -.68237800E+04, -.13005700E+05, -.50521600E+04, 0.11935900E+05, -.55195200E+03, -.28564300E+05, 0.20703500E+05, 0.21530700E+05, 0.14282200E+05, 0.46677900E+04, -.24278600E+05, 0.15455700E+05, 0.88641200E+04, 0.12029200E+05, -.18572100E+05, 0.14249400E+03, 0.19796000E+05, -.11893000E+05, 0.65840900E+04, -.99034600E+04, -.24694200E+04, -.30414900E+05, 0.16722700E+05, 0.29471000E+05, 0.12210400E+05, -.29592400E+05, -.25832800E+05, -.11184700E+05, 0.11747500E+05, 0.23051400E+05, 0.55942100E+04, 0.17881700E+04, 0.16824200E+05, -.98814600E+02, -.47226000E+04, 0.69574700E+03, 0.20100500E+05, 0.27164000E+05, 0.22045200E+05, -.19453300E+04, 0.35077300E+05, -.11022900E+05, 0.34810500E+04, 0.83731200E+04, -.29066000E+04, -.29318300E+04, -.17956000E+05, 0.16668600E+05, 0.29703100E+05, 0.24095400E+04, -.62337600E+04, -.99557300E+04, -.12047800E+04, -.26593700E+04, 0.19080800E+05, -.83612400E+04, -.86993000E+04, -.14778400E+04, 0.15174200E+05, 0.46908600E+04, 0.88553800E+05, -.52699100E+05, 0.16342500E+05, -.44276700E+05, -.52737800E+04, -.18822800E+05, -.30533200E+04, 0.25417900E+05, -.19720400E+05, -.18560500E+05, -.53122200E+05, 0.48502400E+05, -.23736900E+05, -.33743600E+04, -.24251200E+05, 0.12175900E+04, 0.26734600E+05, -.19638000E+05, -.58776800E+04, -.19550800E+05, 0.22535900E+05, -.15915600E+05, -.11990700E+05, 0.12573200E+05, 0.21078200E+04, 0.59954100E+04, 0.17857700E+04, 0.12065800E+04, 0.51076100E+04, -.32442500E+04, -.21672100E+04, 0.65220200E+04, 0.34834300E+05, -.36463200E+04, 0.14197900E+04, 0.22089500E+05, 0.18227800E+04, 0.39076400E+04, -.77937500E+04, 0.47392900E+04, 0.78534100E+04, -.26853500E+04, -.35993400E+04, 0.13931800E+04, -.11563100E+05, 0.92556600E+04, -.39570400E+04, 0.57818200E+04, 0.31740900E+04, 0.76687300E+04, -.36641700E+04, -.39328400E+04, -.23066400E+04, 0.62621900E+04, 0.56459300E+04, 0.13628900E+05, -.10417500E+05, 0.12830000E+05, -.68141000E+04, -.17952900E+04, 0.12090700E+04, -.12526800E+04, -.21473400E+03, -.78661700E+04, 0.16121200E+04, 0.35219900E+04, -.38680400E+04, 0.10091200E+04, -.38399400E+04, 0.10311800E+05, -.94209900E+04, -.74975700E+04, -.11799200E+05, 0.14444900E+05, 0.36108400E+04, -.46523400E+04, -.23481000E+05, 0.96454300E+03, 0.10889300E+05, -.14381800E+04, 0.88983700E+03, 0.15324900E+05, -.23362100E+05, 0.48850700E+03, -.21136600E+04, 0.44075800E+04, -.29017900E+05, -.76214000E+03, 0.57720600E+04, -.92165100E+03, 0.32276700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.50063300E+00, -.37203500E+00, -.59934500E+00, -.45216500E+00, 0.19498300E+00, 0.60068400E-01, 0.45224600E+00, 0.13131400E+00, -.71338700E+00, -.39736600E+00, -.63889200E-01, 0.65685900E+00, 0.19310700E+01, -.70761800E+00, 0.27077000E+01, -.28529600E+01, -.11446600E-01, -.10502100E-01, -.55130200E+00, -.33792400E+00, 0.20243100E+01, 0.20397300E-01, -.60498400E+00, 0.84594000E+00, -.85028500E-01, -.10125000E-01, -.20375300E+01, 0.20708500E+00, -.50665500E+04, 0.30465300E+04, -.51770700E+04, -.18141300E+04, 0.11283400E+04, -.43065200E+04, 0.17419400E+04, -.16193400E+03, 0.21534000E+04, -.30763000E+04, 0.84931500E+04, -.15235900E+04, -.35388500E+03, 0.21986300E+04, 0.76587700E+04, 0.84271900E+04, -.26844000E+05, 0.13750400E+05, 0.55417700E+04, 0.13422000E+05, 0.68631900E+04, -.33384100E+04, 0.15845300E+05, 0.13293100E+05, 0.12477000E+05, -.39879900E+04, -.44028800E+04, 0.58852800E+05, -.30533300E+05, -.43973800E+04, -.29426300E+05, -.11052600E+05, 0.73055600E+03, -.18072100E+05, -.68772100E+04, -.24860200E+05, 0.24947300E+04, -.42391400E+04, 0.57657300E+04, -.22544200E+04, -.63496100E+04, -.28839000E+04, 0.46876900E+03, 0.12080300E+04, -.49102400E+04, -.85008900E+03, -.45542200E+04, -.14684800E+03, -.33985100E+04, 0.15152200E+04, -.11301400E+04, -.39742300E+04, -.75754500E+03, -.14001400E+04, -.87321000E+03, 0.85890200E+03, 0.35704700E+04, 0.51288700E+03, -.10750400E+04, 0.83637400E+03, 0.98367200E+03, -.25268100E+03, -.35102400E+04, -.49126800E+03, -.57599900E+03, -.12133500E+05, 0.85721000E+04, 0.67617000E+04, 0.34377800E+04, -.10673600E+05, -.62143400E+04, 0.22415900E+05, -.12175400E+05, -.20643500E+05, -.11208100E+05, -.15357100E+05, 0.23206200E+04, -.82148500E+04, -.55701400E+04, -.56473000E+04, 0.29236900E+04, 0.16333500E+05, -.66342800E+04, 0.35578900E+04, 0.94155900E+04, 0.33173300E+04, 0.72329400E+02, -.20382200E+04, 0.12209500E+04, -.25176400E+04, 0.21939600E+04, -.13966100E+04, 0.42748500E+04, 0.52617500E+04, -.10110600E+04, -.15490700E+04, -.26308100E+04, 0.29309400E+04, 0.39418400E+04, -.41218400E+04, 0.97676500E+04, -.60108300E+04, 0.31995700E+04, 0.11415500E+04, 0.81834400E+04, -.42655300E+04, -.10021100E+05, -.40916900E+04, 0.83879100E+03, 0.32085000E+04, -.29042900E+04, 0.27897500E+04, -.46118200E+04, 0.19888900E+04, -.56215000E+04, -.16718200E+05, 0.99908500E+04, 0.16751400E+05, 0.83590700E+04, -.36990100E+04, -.63334800E+03, 0.86768600E+04, 0.20864300E+04, 0.53233300E+04, 0.10665900E+04, 0.12817700E+05, -.63300300E+04, 0.19916200E+04, 0.25496200E+04, 0.31669700E+04, -.14994500E+04, -.28529600E+04, 0.96112900E+04, 0.11791500E+04, 0.96685400E+04, -.50792500E+03, 0.27526300E+04, 0.16920000E+05, -.68770400E+04, -.11680600E+03, -.84600100E+04, 0.52879500E+04, -.40468600E+04, -.14994100E+04, 0.44268700E+04, -.62990900E+04, -.40257200E+04, -.16737400E+05, 0.19918900E+05, -.75625400E+04, 0.25426400E+04, -.99593900E+04, 0.56584600E+04, -.13717900E+05, 0.35855100E+04, 0.10436200E+05, -.64575400E+04, -.12778100E+05, -.19159600E+05, 0.12643000E+05, -.76007400E+04, -.16491100E+05, -.63214700E+04, 0.22622600E+04, -.11753200E+04, -.40597000E+04, 0.28442600E+03, -.27053400E+04, -.22009400E+04, -.10843100E+05, 0.17470400E+05, -.10942200E+05, 0.18292100E+05, -.87352400E+04, -.17623900E+04, -.19555000E+04, -.17687100E+04, -.12905700E+05, -.44107200E+04, -.73608400E+03, -.11440200E+05, -.29018400E+05, 0.14718900E+05, 0.25172100E+05, 0.14509200E+05, 0.11115100E+05, 0.17164600E+04, 0.62601500E+04, 0.47231700E+03, 0.80920400E+04, 0.12611500E+04, -.47720600E+04, 0.10185100E+05, -.33051000E+04, -.98089200E+04, -.50925600E+04, 0.23351900E+04, -.13477700E+05, -.14557700E+04, -.50169100E+04, -.38958400E+04, -.12509200E+05, -.89624300E+04, -.22001100E+04, 0.10721900E+04, 0.47535600E+04, 0.11002000E+04, -.26525800E+04, 0.22017300E+04, 0.55555800E+04, 0.47289400E+04, 0.25538100E+04, 0.29862100E+04, 0.43091700E+04, -.26220200E+04, 0.21888700E+04, -.15674200E+04, 0.13109300E+04, -.38041500E+03, 0.77810900E+04, -.12935600E+04, 0.34783000E+04, 0.20296000E+04, 0.64679600E+04, 0.48220200E+04, 0.14423800E+05, -.83796800E+04, -.61939600E+03, -.72120100E+04, -.49350800E+02, -.57754900E+04, -.53339800E+04, -.11713400E+05, -.40583600E+04, -.56562400E+04, -.85504200E+04, -.25371900E+04, 0.18490600E+02, -.15550100E+04, 0.10636200E+04, 0.72102400E+03, 0.44066500E+04, 0.38172100E+04, -.94176200E+03, 0.13628100E+04, -.33985500E+04, 0.12239400E+04, -.20753600E+04, 0.50661800E+04, -.10956500E+04, -.63215700E+03, 0.15532400E+03, 0.31242500E+04, 0.76294300E+04, -.10489000E+04, 0.19500800E+04, 0.74082000E+03, -.32922300E+04, 0.86980900E+03, -.57107600E+03, -.77574400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31190100E+00, -.25854200E+00, 0.77807200E+00, 0.12959700E+01, 0.87577400E+00, -.86616400E-01, -.11417200E+01, -.99922400E-01, 0.11116900E+01, 0.39940700E+00, -.11884900E+00, 0.44735600E+00, -.15370900E+00, 0.17577300E+00, -.57532800E+00, 0.48320400E+00, 0.29294900E-01, -.26875800E+00, -.47262600E+00, -.10234600E+01, 0.43149500E+00, 0.87663800E-01, 0.76735400E-01, -.36095200E+00, -.25551000E-01, -.10028400E-01, -.58650700E+00, 0.10249600E+00, 0.10809300E+00, -.73786200E+04, -.59515000E+02, 0.63826500E+03, -.30638900E+04, 0.35360000E+04, -.17282400E+04, -.22277300E+04, -.17679900E+04, 0.34561300E+04, 0.61139500E+03, -.43863600E+04, -.39666600E+04, -.52544300E+04, 0.90506900E+03, -.64957600E+04, 0.22816200E+05, -.11429600E+05, -.11678200E+05, -.11408100E+05, -.32850700E+04, -.22100700E+04, -.48338000E+04, 0.14317600E+04, -.57657300E+04, -.15716200E+04, -.34630300E+04, -.18959700E+05, 0.96170800E+04, 0.11767900E+05, 0.94798700E+04, 0.53554600E+04, 0.26396700E+04, 0.34853300E+04, -.40031800E+04, 0.27344500E+04, 0.19911700E+04, -.12459900E+04, -.29424100E+04, 0.12428500E+04, -.45214900E+03, 0.14709600E+04, -.25062700E+02, 0.36398300E+03, 0.87392800E+03, -.25064700E+04, 0.14463700E+04, 0.43029400E+03, 0.19460500E+04, 0.45455800E+03, -.22768100E+03, -.71588200E+03, -.22726700E+03, 0.53602700E+03, 0.26461900E+03, -.10605500E+04, -.25733100E+04, -.25250000E+03, 0.32340800E+03, 0.22527300E+03, -.30027600E+04, 0.15181800E+04, 0.77905000E+03, 0.15015500E+04, -.40121400E+03, -.16007900E+02, 0.35506000E+03, 0.40755600E+04, 0.21008800E+04, -.97907700E+01, 0.30307100E+03, -.13230600E+05, 0.66894800E+04, 0.97509800E+04, 0.66152700E+04, 0.59246500E+04, 0.51116900E+04, -.24393500E+04, -.48470000E+04, 0.24388400E+03, 0.38274300E+04, -.25627600E+03, 0.64178200E+04, -.31721300E+04, -.18853900E+04, -.32088700E+04, 0.90202700E+03, 0.12778600E+04, -.21328300E+04, 0.14996900E+04, -.42776000E+04, 0.84584700E+03, -.57815900E+04, 0.11185700E+05, -.57079300E+04, -.32131800E+04, -.55928300E+04, -.23683300E+03, -.11267100E+04, -.21950200E+04, -.82547900E+04, -.32572000E+04, -.76983900E+03, -.97999000E+04, -.83534800E+03, 0.42121000E+03, -.24375100E+03, 0.41769800E+03, -.16544700E+04, -.19172600E+04, 0.16457800E+04, -.27564600E+04, 0.22343100E+04, -.10919100E+04, 0.36281200E+04, 0.21814500E+05, -.11110000E+05, -.13158600E+05, -.10907200E+05, 0.42217000E+04, 0.40810500E+04, -.10011600E+05, -.67957700E+04, -.97061600E+04, 0.31371000E+04, -.97596300E+04, 0.29572200E+04, -.11190200E+04, 0.23347700E+03, -.14781800E+04, 0.20167200E+03, 0.19674700E+03, -.16173900E+04, 0.60068400E+04, -.20328500E+04, -.20185000E+03, 0.29268300E+03, 0.78373000E+04, -.40513500E+04, -.57995600E+04, -.39187100E+04, -.15495900E+04, -.63994400E+03, 0.46109900E+03, 0.32547100E+04, -.39514300E+04, -.25447100E+03, -.45409500E+04, 0.23343700E+03, -.34386000E+03, 0.80632300E+03, -.11670400E+03, -.85910800E+03, 0.62922800E+03, 0.30410800E+04, 0.67440500E+04, 0.25186100E+03, 0.13905200E+04, -.64870100E+04, -.17295600E+05, 0.87923200E+04, 0.10371000E+05, 0.86477900E+04, -.35163300E+04, -.17729800E+04, 0.67622300E+04, 0.39845400E+04, 0.71928600E+04, -.16930300E+04, 0.94171800E+04, -.12516600E+05, 0.64271900E+04, 0.69184900E+04, 0.62582300E+04, 0.87432700E+03, 0.60405600E+03, 0.29780300E+04, 0.89429400E+04, 0.21995700E+04, 0.43947300E+02, 0.99178500E+04, 0.44555600E+03, -.27545300E+03, -.32168300E+04, -.22277300E+03, -.49288700E+04, -.47927700E+04, 0.36510700E+04, 0.10432300E+04, 0.53600600E+04, -.42453000E+04, 0.65505100E+04, -.70449400E+04, 0.33350000E+04, 0.56078900E+04, 0.35224600E+04, -.14973600E+04, 0.12260900E+04, 0.53424500E+04, 0.12288600E+05, 0.19480600E+04, 0.21255800E+04, -.12807800E+04, 0.64081300E+04, -.32267100E+04, -.14991000E+04, -.32040500E+04, 0.29129500E+04, 0.15135000E+04, -.61982800E+04, -.64174800E+04, -.71119400E+04, 0.87680400E+03, -.52720100E+04, -.40261200E+03, 0.97176600E+02, -.18878400E+04, 0.20126900E+03, 0.18386900E+04, -.72778700E+02, -.32073400E+04, -.72155500E+04, -.26856100E+04, 0.15033600E+03, -.12330800E+04, -.94033900E+04, 0.48180900E+04, 0.70397900E+04, 0.47016400E+04, -.89763500E+03, 0.27407300E+04, 0.47154400E+04, 0.13125100E+05, 0.16730400E+04, 0.27193900E+04, 0.34776600E+04, 0.92590800E+03, 0.10618000E+04, 0.11458000E+04, 0.76548900E+03, 0.75431900E+03, 0.16831400E+04, 0.14932400E+04, 0.17168000E+04, -.10524500E+04, 0.55698500E+03, -.52016100E+03, 0.56224600E+02, -.43573200E+03, 0.56459900E+01, 0.19917000E+04, 0.13236100E+04, -.18394000E+04, -.64188200E+03, 0.29431200E+04, 0.36492900E+01, 0.23245400E+04, -.19033500E+04, 0.35082600E+03, 0.95294500E+03, 0.20579600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.68887900E+00, 0.33217900E-01, 0.42248300E+00, 0.10568500E+01, -.11536700E+00, -.10039300E+00, -.38067100E+00, 0.12276000E+01, 0.26962200E+01, 0.66385600E+00, 0.13350500E+00, -.15914800E+01, 0.18059700E+01, 0.13878100E+01, -.25945400E+00, 0.38528300E+01, 0.27301700E+00, -.15375700E+01, 0.28010200E+00, -.10262900E+01, -.11680900E+01, -.77913000E-01, 0.37093300E+00, -.25896100E+01, -.68010600E-01, 0.66558900E-01, 0.50898000E-02, 0.13310500E+00, -.89306600E+00, 0.17927500E+00, 0.11621200E+05, -.11742300E+04, 0.31011200E+04, -.25727500E+05, 0.13514100E+05, 0.11140200E+05, 0.12863700E+05, 0.31560600E+04, 0.71010200E+04, 0.23788200E+04, 0.15306600E+04, 0.77508700E+04, 0.54907300E+04, 0.15359300E+05, 0.36755200E+05, -.18833700E+05, -.23500000E+05, -.18377600E+05, -.46849900E+04, -.96549700E+04, -.30922300E+04, 0.10567400E+05, -.78373900E+04, -.96915100E+04, -.11881800E+05, -.31509300E+05, 0.17529500E+05, 0.24968300E+05, 0.15754600E+05, 0.59239500E+04, 0.14370700E+05, 0.27617100E+04, -.71104400E+04, 0.49223500E+04, 0.13836500E+05, 0.12423400E+05, -.80389400E+04, 0.33075400E+04, 0.23301800E+04, 0.40196100E+04, 0.17510400E+04, 0.36502300E+04, -.92954100E+03, -.56045800E+03, 0.10106500E+05, 0.16012000E+04, 0.64761100E+04, 0.44825500E+04, -.24829600E+04, -.24279300E+04, -.22412900E+04, 0.21132100E+02, 0.26240200E+03, 0.16906600E+03, 0.25314000E+04, -.36320900E+03, -.16753800E+03, -.86542300E+03, 0.10975900E+04, -.98032000E+03, 0.41596600E+04, -.54884600E+03, -.60010300E+03, -.61255300E+03, -.17172400E+04, 0.25082500E+04, -.64269600E+04, -.50805600E+03, -.12777000E+04, -.24503500E+05, 0.13835000E+05, 0.16625300E+05, 0.12251700E+05, 0.97608000E+04, 0.24048600E+05, -.22692300E+04, 0.18596800E+04, 0.29479600E+04, 0.20985600E+05, 0.12762400E+05, -.68183300E+04, 0.38303000E+04, 0.53977800E+04, 0.34091400E+04, 0.49209000E+03, 0.20307400E+04, 0.49873600E+03, 0.13699200E+04, 0.41522500E+02, 0.18535000E+04, 0.16007600E+04, 0.19521300E+05, -.12527400E+05, -.89599100E+04, -.97606700E+04, -.25769300E+04, -.53274800E+04, -.96682200E+03, -.57203000E+04, 0.19896100E+03, -.49738800E+04, -.83061100E+04, 0.50147100E+04, -.27889300E+04, -.45120000E+04, -.25073500E+04, -.36851400E+03, -.23604800E+04, -.89945500E+03, -.26508000E+04, 0.48465400E+04, -.25409900E+04, 0.51240200E+03, 0.13288300E+05, -.94540200E+04, 0.22276900E+04, -.66441500E+04, -.60668100E+04, 0.54780500E+03, 0.11936400E+04, 0.53636500E+04, -.30144400E+04, 0.48275000E+03, 0.21303300E+04, 0.96166400E+04, -.35860800E+04, -.39904300E+04, -.48085600E+04, -.20179000E+04, -.39994200E+04, 0.10960600E+04, 0.19501600E+04, -.16576500E+05, -.13964700E+04, -.87426400E+04, 0.31501800E+05, -.18534600E+05, -.19587200E+05, -.15751600E+05, -.57269300E+04, -.87108900E+04, -.50602000E+04, 0.24316400E+04, -.87926200E+04, -.87858700E+04, -.12201600E+05, 0.22824800E+05, -.15487000E+05, -.12330300E+05, -.11412400E+05, -.45136900E+04, -.61358700E+04, -.44838600E+04, 0.18793600E+02, -.88907700E+04, -.57076500E+04, -.11719100E+05, -.46365900E+03, 0.24303500E+04, -.77921100E+04, 0.23183000E+03, 0.38347400E+04, -.11430400E+04, -.19990600E+04, -.22639200E+04, -.68328400E+03, -.11449400E+04, -.58273200E+04, -.21909800E+05, 0.14739400E+05, 0.14502500E+05, 0.10954900E+05, 0.22468800E+04, 0.37740100E+04, 0.29821800E+04, 0.70373500E+04, 0.94278100E+03, 0.33342000E+04, 0.91558300E+04, -.11477400E+05, 0.55294400E+04, -.26931000E+03, 0.57386800E+04, -.51479900E+04, -.18347300E+05, 0.85912300E+04, -.68004100E+04, 0.84209800E+04, -.15427900E+05, 0.23201400E+03, 0.52185300E+04, -.55859400E+04, 0.25429800E+03, -.26092600E+04, -.80149100E+03, -.18572900E+04, -.50985300E+04, -.24912800E+04, -.49107000E+04, -.69386000E+03, -.52968100E+04, -.48649200E+04, 0.26565400E+04, 0.52741200E+03, 0.24324600E+04, -.25879000E+04, -.11403200E+04, 0.39920400E+04, 0.70352600E+04, 0.31506800E+04, -.18837500E+04, 0.82009500E+04, -.74322000E+04, 0.21914100E+04, 0.71399400E+02, 0.37161100E+04, -.20750000E+04, -.28489400E+04, 0.34203500E+04, 0.17689200E+04, 0.56757400E+04, -.27612800E+04, 0.67159200E+04, -.26282000E+04, 0.28883900E+04, 0.32775400E+04, 0.13141200E+04, 0.27939000E+04, 0.53580600E+04, -.52616600E+04, -.86094800E+03, -.41902200E+04, 0.53241000E+04, -.22037300E+04, -.44273900E+03, 0.24038000E+04, 0.89561700E+02, -.24960600E+03, -.13141500E+04, 0.10842000E+05, 0.10295100E+05, -.90306300E+02, -.15826400E+03, -.99771900E+03, 0.64777200E+04, -.21731900E+03, -.19259700E+04, -.27601500E+03, -.32197900E+04, -.29918500E+03, 0.36852100E+04, 0.15099200E+04, -.34159500E+04, -.13325100E+04, 0.12723400E+05, -.86932400E+02, 0.25224700E+04, 0.28756000E+04, 0.98184800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34458100E+00, -.95910500E+00, -.14134400E+01, -.19996400E-01, -.94651000E+00, -.15288500E+00, 0.40143900E+00, 0.64407400E+00, -.40075800E+00, -.29517100E+00, -.17645200E-01, 0.12187400E+00, 0.27286700E+00, -.39022000E+00, 0.57519800E+00, -.24843000E+00, -.85945300E-01, -.56340400E+00, 0.62638100E+00, -.87815200E+00, -.13015600E+01, 0.17506100E+00, -.54120300E+00, 0.39793000E+00, -.11219300E+00, 0.87533600E-01, 0.11699400E+01, -.30756600E+00, -.51799300E+00, 0.56980100E-01, 0.10778600E+00, -.19929000E+04, 0.11354400E+04, -.77682400E+04, 0.37396600E+04, 0.43658100E+04, 0.38843000E+04, -.35161300E+04, 0.36790700E+04, 0.43418200E+04, 0.90280300E+04, 0.44005800E+04, 0.26895500E+04, 0.89526500E+04, -.25347900E+05, 0.12758000E+05, 0.12736600E+05, 0.12674000E+05, 0.51941300E+04, -.32955300E+03, 0.10025500E+05, 0.67728200E+04, 0.10718800E+05, -.53087000E+03, 0.12310500E+04, 0.33387700E+05, -.17190700E+05, -.14707500E+05, -.16693700E+05, -.86271600E+04, -.57983700E+03, -.94498900E+04, -.14091800E+04, -.12845200E+05, -.38757300E+02, -.11424900E+04, 0.25039000E+04, -.74659600E+03, 0.53707000E+02, -.12535300E+04, 0.22333500E+02, -.12143000E+04, -.74215000E+03, -.29781100E+04, -.20931600E+04, -.17895900E+04, -.33962800E+04, -.14567500E+04, 0.43227100E+03, -.12069000E+03, 0.72846600E+03, -.11980600E+04, -.73751400E+03, 0.20382400E+04, 0.32774000E+04, 0.13975900E+04, -.11314000E+04, -.84381100E+02, -.47756500E+04, 0.24272300E+04, -.11370100E+04, 0.23887800E+04, 0.22393000E+04, -.44886900E+04, 0.33398100E+04, 0.35992000E+04, -.11694700E+01, -.21770200E+04, 0.42417100E+04, 0.19678500E+05, -.10237100E+05, -.54664200E+04, -.98395100E+04, -.11090200E+05, -.32049000E+04, -.24848700E+04, 0.56929700E+04, -.79575000E+04, -.12556900E+04, 0.14932600E+04, -.15425200E+05, 0.79316500E+04, 0.70893800E+04, 0.77128600E+04, -.45390600E+03, -.50768500E+03, 0.22890300E+04, -.14223900E+04, 0.43937200E+04, 0.29252400E+03, 0.11428300E+05, -.60319500E+04, 0.38669400E+04, -.76899800E+04, 0.30160900E+04, -.25357700E+03, -.15795100E+04, 0.57895600E+04, 0.74698100E+04, 0.70425800E+04, -.25205900E+04, 0.67188300E+04, 0.11573400E+05, -.59535300E+04, -.56197800E+04, -.57866400E+04, 0.15304600E+04, 0.18581500E+04, -.20213300E+04, 0.98630600E+02, -.33918200E+04, 0.64391400E+02, -.11025900E+05, -.64071600E+05, 0.32954800E+05, 0.29181400E+05, 0.32035800E+05, -.39832300E+04, -.12995800E+05, 0.23277200E+05, 0.48625900E+04, 0.25542600E+05, -.81437900E+04, 0.25039600E+05, -.32355700E+04, 0.70318500E+03, -.25607500E+03, 0.16207300E+04, -.56167700E+03, 0.48076700E+03, 0.20694300E+04, 0.46653000E+04, 0.30762400E+04, 0.20070200E+04, 0.25445100E+04, -.57372600E+04, 0.36892200E+04, 0.35464100E+04, 0.28687500E+04, 0.49104500E+04, 0.42066300E+03, 0.25396800E+03, -.23377700E+04, 0.26224300E+04, -.13806900E+03, 0.18183100E+04, 0.80464500E+04, -.27746400E+04, 0.79973900E+04, -.40231000E+04, 0.64061700E+04, -.26244500E+04, -.39031900E+04, -.46760100E+04, -.47861100E+04, -.21925900E+04, 0.21177900E+04, 0.49414800E+05, -.25439200E+05, -.21982500E+05, -.24707400E+05, 0.27315400E+04, 0.82547400E+04, -.15977100E+05, -.22082800E+04, -.18860600E+05, 0.52570600E+04, -.21888900E+05, 0.69379500E+04, -.46211800E+04, 0.56497300E+04, -.34691000E+04, -.37597600E+03, 0.38031700E+04, -.67183100E+04, -.87140900E+04, -.72652600E+04, 0.40340200E+04, -.63453900E+04, -.11895500E+05, 0.59837000E+04, 0.50462100E+04, 0.59477400E+04, 0.69653000E+04, 0.31414500E+04, 0.59193000E+03, -.63500800E+04, 0.39971600E+04, 0.18686800E+04, -.40400000E+04, 0.61815700E+04, -.21368000E+04, -.23809100E+04, -.30908200E+04, 0.55720900E+04, -.38589700E+04, -.79014700E+04, -.13469600E+05, -.62027100E+04, -.29699900E+04, 0.24348000E+04, -.22212100E+05, 0.11141300E+05, 0.16592400E+05, 0.11106200E+05, -.17421600E+04, -.13524000E+04, 0.10987100E+05, 0.98676600E+04, 0.10325100E+05, 0.65537900E+03, 0.93874800E+04, -.48859300E+04, 0.29360800E+04, 0.26136400E+03, 0.24428100E+04, -.15865800E+04, 0.26078200E+04, 0.45203200E+04, 0.90949300E+04, 0.47309100E+04, 0.16425700E+04, 0.30080400E+04, 0.81176900E+04, -.47328000E+04, -.41779800E+03, -.40590700E+04, 0.16402300E+04, -.40761000E+03, -.97546500E+04, -.16464700E+05, -.77421000E+04, -.98260900E+03, -.16350800E+04, -.77223900E+03, 0.29242400E+03, 0.45105300E+02, -.71524300E+02, -.36040400E+04, 0.12877500E+04, 0.16130500E+04, -.53217800E+03, -.16034300E+03, -.22944100E+04, -.22724600E+04, -.77074700E+03, 0.13247200E+04, -.26084800E+03, -.25954100E+04, -.51217300E+03, -.11824700E+04, 0.94672500E+03, -.47797900E+04, -.22849600E+03, -.36064900E+04, 0.25826800E+04, 0.18083500E+04, -.24252800E+03, -.16895200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34553300E+00, 0.22895100E+00, 0.73253300E+00, 0.35003700E+00, 0.54686800E-01, 0.16258100E-01, 0.52805000E+00, 0.92198500E+00, -.90292000E+00, -.23554800E+00, 0.67497200E-01, 0.70677700E+00, 0.19385100E+01, 0.54029300E+00, 0.82384300E+00, -.11236100E+01, -.34411400E+00, -.37684000E+00, 0.42036500E+00, -.14669100E+00, -.52030600E+00, -.14421700E+00, 0.29003200E+00, -.33309400E+00, 0.13224600E+00, 0.12653500E+00, -.45926300E+00, 0.15340600E-01, 0.34560000E+00, 0.35130300E+00, -.31519800E+00, -.43913300E+00, 0.98899000E+04, -.48843800E+04, 0.25509600E+04, 0.40585800E+04, 0.24422500E+04, -.34827900E+03, 0.13203600E+04, 0.44390000E+04, 0.65257900E+04, 0.36699900E+04, 0.51206700E+03, 0.91834100E+04, 0.56943800E+02, -.12178000E+03, -.85405600E+03, -.28458800E+02, 0.88002400E+03, -.22403600E+04, -.65517100E+03, 0.14126900E+04, 0.18587900E+04, -.23338500E+04, 0.42549700E+03, -.74518900E+04, 0.39524600E+04, -.49556300E+04, 0.37259900E+04, -.34029600E+04, 0.53202400E+04, 0.17301300E+04, 0.19022300E+04, 0.27544500E+04, 0.43934800E+04, 0.82693500E+04, -.34018800E+04, 0.16043200E+04, 0.47230800E+04, 0.17004400E+04, 0.54759300E+03, 0.51275500E+02, -.33700800E+03, -.15347300E+04, 0.33480600E+03, 0.77130000E+02, 0.45208000E+04, -.41992900E+03, 0.22263500E+03, 0.14120700E+04, 0.20999300E+03, 0.49165000E+02, 0.39823700E+03, 0.57338400E+03, 0.10267400E+04, -.11234900E+04, 0.14448200E+03, -.67599900E+03, 0.42401000E+04, -.22400000E+04, -.54177700E+03, -.21197300E+04, -.33165500E+04, -.15622300E+04, -.21327400E+04, -.21794400E+04, -.24933000E+04, -.80557200E+03, 0.48474200E+04, 0.65074100E+04, -.29810100E+04, 0.37844600E+03, -.32537800E+04, 0.10239800E+03, 0.71073400E+04, -.60771800E+03, 0.51370800E+04, -.44392200E+04, 0.63405600E+04, -.68018600E+04, -.82889100E+04, 0.41555300E+04, -.67828500E+03, 0.41445400E+04, -.74076900E+03, 0.37247900E+03, 0.19141500E+04, 0.39953800E+03, 0.47990400E+04, 0.52066300E+03, 0.88973000E+04, -.10036800E+05, 0.45686400E+04, 0.20517400E+04, 0.50184400E+04, 0.25840700E+04, -.48794900E+02, 0.48729300E+04, 0.10524500E+04, 0.25150800E+04, -.18694700E+03, 0.12125600E+05, -.82872400E+03, 0.36113500E+03, 0.41419700E+04, 0.41439300E+03, 0.22527700E+04, 0.12494900E+04, -.19173600E+04, -.24763300E+04, -.21777400E+04, 0.70042900E+03, -.40397000E+04, -.26216000E+05, 0.12749100E+05, 0.14857100E+05, 0.13108000E+05, -.74613700E+04, -.72311700E+04, 0.10638700E+05, 0.59453600E+04, 0.11774000E+05, -.48237600E+04, 0.14654500E+05, 0.40569200E+04, -.18860800E+04, -.35067800E+04, -.20275200E+04, -.41059800E+03, -.60197900E+02, 0.40303100E+03, 0.16392100E+04, -.87956200E+03, -.20458800E+03, -.11041100E+05, 0.20695100E+04, -.14744000E+04, -.47674000E+04, -.10355600E+04, -.18935600E+04, -.28476300E+04, -.97974100E+03, -.13524900E+02, 0.29922100E+04, -.29574500E+04, 0.12255000E+05, -.16371500E+04, 0.21126900E+03, -.79758400E+04, 0.81861600E+03, -.30621900E+04, -.23252500E+03, -.52266400E+04, -.92737000E+04, 0.17433300E+03, -.33953000E+03, 0.22960700E+05, 0.26713000E+05, -.13064300E+05, -.12016000E+05, -.13356500E+05, 0.60460600E+04, 0.54537600E+04, -.94968700E+04, -.32492500E+04, -.10885600E+05, 0.38844500E+04, -.16340300E+05, -.29789500E+04, 0.20980800E+04, -.11094100E+05, 0.14894400E+04, -.33238100E+04, 0.45724900E+03, -.10907200E+04, 0.13123800E+04, 0.47942900E+04, 0.20167500E+02, -.54288900E+04, -.15056800E+05, 0.75367500E+04, 0.13492600E+04, 0.75283700E+04, 0.26601600E+04, -.47320600E+04, 0.24340100E+04, -.63641800E+04, 0.36789800E+04, -.37131200E+04, -.18655200E+04, -.69040100E+03, -.88396800E+02, -.41528600E+04, 0.34518800E+03, -.18955600E+04, 0.48000900E+02, -.66121000E+04, -.13540300E+05, -.13821500E+04, 0.47515000E+03, 0.14542900E+05, -.14539600E+05, 0.73357600E+04, 0.33444500E+04, 0.72698700E+04, -.15572500E+04, -.18648100E+04, 0.59226800E+04, 0.70409400E+04, 0.86061900E+04, -.84758700E+03, 0.13786300E+05, -.20148900E+04, 0.80973000E+03, 0.46620200E+04, 0.10073900E+04, -.68474300E+02, -.16047700E+04, 0.48937500E+04, 0.69714800E+04, 0.20338600E+04, -.13706700E+04, 0.31471800E+04, 0.25434500E+04, -.10457100E+04, -.75217400E+04, -.12718000E+04, 0.97994600E+03, 0.22249500E+04, -.61177500E+04, -.10511200E+05, -.18797300E+04, 0.18443000E+04, 0.17825000E+04, -.13245900E+03, -.12897100E+04, -.15469000E+04, -.21073800E+04, -.16236700E+04, 0.12031300E+04, 0.10803800E+04, -.26825700E+04, 0.15295400E+04, -.12295200E+03, 0.23246400E+04, 0.30077300E+04, -.28917500E+04, 0.25103800E+04, -.27064300E+04, -.24239100E+04, 0.21671400E+04, 0.22883000E+03, -.37365900E+04, -.17490600E+04, 0.24410700E+04, 0.25696000E+04, 0.53658600E+03, -.63402100E+03, -.12393500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13750000E-01, -.11282800E+00, -.79048200E+00, 0.45075400E-01, 0.16210800E+00, 0.49748700E-02, 0.20180900E+00, 0.20015300E+00, -.38113100E+00, -.78518500E-01, 0.60615400E-02, -.62469700E+00, 0.40009400E+00, -.14856800E+00, 0.10258900E+00, 0.37040700E+00, 0.45461900E+00, 0.65425700E-01, -.36875900E+00, 0.22863000E+00, 0.73994800E+00, -.35580700E-01, -.15922500E+00, -.15656800E+00, 0.21427000E-01, -.21504800E-01, 0.24769300E+00, 0.80957600E-01, 0.36588000E+00, 0.78283700E-01, 0.10764300E+00, -.15377400E+00, 0.20688400E+00, 0.21023800E+05, -.10101300E+05, -.76690900E+04, -.10512000E+05, -.15515900E+03, -.34603500E+04, -.32092800E+04, -.32323100E+03, -.56338100E+04, -.34286500E+04, -.11441100E+05, -.90783200E+04, 0.42150600E+04, 0.10132000E+05, 0.45391600E+04, 0.42567000E+03, 0.53334800E+04, -.20551200E+04, -.66750800E+04, 0.21311300E+03, 0.54825900E+04, 0.48388100E+04, -.29215700E+04, 0.24926900E+04, -.12385800E+05, 0.14607600E+04, 0.42691200E+03, -.63049200E+04, 0.34132300E+04, 0.33656100E+04, 0.49280200E+04, -.65678600E+04, -.21178200E+04, 0.26440500E+03, -.25732900E+03, 0.24740500E+04, -.13194500E+03, -.63198600E+03, -.14759700E+04, 0.12870900E+04, 0.34122200E+03, -.66339400E+03, -.93397500E+03, -.47978200E+02, -.18409300E+04, 0.94399700E+03, 0.15166800E+04, 0.92045000E+03, 0.61836300E+03, 0.35190600E+03, -.80886400E+03, -.27099300E+04, -.24388800E+03, 0.38932400E+03, 0.35711500E+03, -.38829800E+04, 0.16625100E+04, -.29218000E+03, 0.19413300E+04, 0.33853600E+03, 0.22838700E+04, -.50812800E+03, -.28812100E+04, 0.15569200E+04, 0.23898400E+04, 0.18093700E+04, 0.15058300E+05, -.66187000E+04, 0.74288900E+03, -.75291000E+04, 0.13806300E+04, -.10812400E+05, -.15819600E+04, -.42045900E+04, -.37077600E+04, -.94876000E+04, -.12969500E+05, 0.82117200E+04, -.40543800E+04, -.77315000E+04, -.41059100E+04, -.79230600E+03, -.97309800E+03, -.91849300E+03, 0.48767000E+03, -.14967200E+04, -.82790100E+03, -.39473900E+04, -.16310600E+05, 0.67992500E+04, -.17852700E+04, 0.81553000E+04, -.17340100E+04, -.13562600E+04, 0.45305300E+04, 0.32220900E+04, 0.73207700E+04, -.17782300E+04, 0.71807900E+04, -.77780500E+04, 0.38793300E+04, 0.75716500E+04, 0.38890100E+04, 0.59515100E+03, 0.85961300E+03, 0.13310900E+04, 0.27515500E+03, 0.13540800E+04, 0.76237200E+03, 0.39438700E+04, 0.88518100E+04, -.58135000E+04, -.63932300E+04, -.44259000E+04, 0.18271600E+04, -.13165100E+04, -.31264200E+04, -.15374400E+04, -.10978600E+04, -.16487100E+04, -.67607100E+04, 0.29691500E+03, 0.18286800E+03, -.85145900E+03, -.14893900E+03, 0.10462800E+04, 0.19214300E+04, -.20689200E+04, -.15977400E+04, -.20046800E+03, 0.14188700E+04, -.28494000E+03, -.20934800E+05, 0.91401300E+04, 0.62121000E+04, 0.10467600E+05, -.42526300E+03, 0.49226300E+04, 0.46137800E+04, 0.41088000E+03, 0.67125300E+04, 0.49714400E+04, 0.10355600E+05, -.11019400E+05, 0.35020200E+04, 0.64780800E+04, 0.55096700E+04, -.21616400E+04, 0.77379800E+04, 0.14211100E+04, 0.16930900E+04, 0.47002900E+04, 0.73966100E+04, 0.61766000E+04, -.99395900E+04, 0.60270300E+04, 0.96476500E+04, 0.49697900E+04, -.11362700E+04, 0.11826500E+04, 0.27651000E+04, 0.20552800E+03, 0.19184400E+04, 0.14277000E+04, 0.66394200E+04, 0.34989000E+04, 0.91911900E+02, -.12305400E+05, -.17494300E+04, 0.44551700E+03, -.31146100E+02, 0.32503600E+03, -.96332900E+03, 0.32749100E+01, 0.15648900E+03, -.14433800E+03, 0.35188200E+04, -.20388800E+04, -.75504400E+04, -.17594100E+04, -.12745900E+04, 0.73621600E+04, -.19171600E+04, 0.58452800E+04, -.20761500E+04, 0.59174900E+04, 0.47019600E+04, -.56825600E+04, 0.14033500E+04, 0.41544400E+04, 0.28412900E+04, -.28728100E+04, 0.13708300E+04, 0.38156800E+04, 0.41068000E+04, 0.41214100E+04, 0.18676400E+04, 0.39062600E+04, 0.14301100E+05, -.70829000E+04, -.36018100E+04, -.71505600E+04, 0.62038300E+03, 0.12644000E+04, -.48185300E+04, -.29891800E+04, -.32771900E+04, 0.59318800E+03, -.84155500E+04, 0.52989800E+04, -.33795700E+04, -.13424300E+04, -.26494600E+04, 0.80871300E+03, -.42801000E+03, -.18005400E+04, -.16138100E+04, -.17070300E+04, -.63250000E+03, -.34673100E+04, -.30043700E+04, 0.23480500E+04, 0.26751700E+03, 0.15022200E+04, -.25321400E+04, -.33505900E+04, 0.57704400E+04, 0.52721800E+04, 0.41950000E+04, -.24649000E+04, 0.26687600E+04, 0.14120500E+04, -.50650300E+03, 0.32125600E+03, -.44727000E+03, 0.90398400E+03, -.56867000E+04, -.48639000E+04, -.20683400E+03, -.21367000E+03, 0.12888500E+04, -.25525000E+04, 0.12765200E+04, 0.68083400E+03, 0.55444000E+03, 0.26057100E+04, -.39442600E+03, -.20897300E+04, -.28554300E+04, 0.27747400E+04, 0.76888300E+03, -.53299200E+04, 0.14265600E+03, -.10594300E+04, -.76326200E+03, -.79184200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.67830900E+00, 0.18080100E+00, 0.67324500E+00, -.14036700E+00, 0.66454200E+00, 0.44319300E-01, -.20198400E+00, 0.84005100E+00, -.83691400E+00, 0.86240500E-01, -.47240400E-01, 0.12091700E+01, 0.43432200E+00, 0.12087400E+00, 0.57348300E+00, 0.14410900E+00, -.82543400E+00, -.14174800E+01, 0.35668000E+00, -.23433500E+01, 0.10251800E+00, 0.12572100E+00, -.20516500E+00, -.13158800E+01, -.13499500E-02, -.79477100E-01, -.30824000E+00, 0.15668200E+00, -.50985700E+00, 0.35105600E+00, -.54671700E+00, 0.15042000E+01, -.22231000E+00, -.98201900E+00, 0.10656300E+04, -.37043300E+04, -.16391100E+00, 0.87100700E+04, 0.12356800E+05, -.11828600E+05, -.13945600E+05, -.78233700E+04, 0.11802300E+05, -.32383300E+04, 0.78418600E+05, -.39887200E+05, -.47432700E+05, -.39209400E+05, -.74184300E+04, -.14128000E+05, -.63665500E+04, 0.23752000E+05, -.12209300E+05, -.13160200E+05, -.22724000E+05, -.55988300E+05, 0.31240300E+05, 0.50800300E+05, 0.27994000E+05, 0.97923000E+04, 0.17129200E+05, 0.35553400E+04, -.24354100E+05, -.52667500E+03, 0.16369400E+05, 0.11251300E+05, -.33703700E+04, 0.20257400E+03, -.16955700E+04, 0.16864800E+04, 0.94269300E+03, 0.53347600E+04, -.43421400E+03, 0.29036500E+04, 0.98717700E+03, 0.34413900E+04, 0.83610800E+04, 0.55671300E+04, -.28121900E+04, -.34683900E+04, -.27836400E+04, 0.11496500E+04, 0.17688400E+04, -.24639600E+04, -.18947900E+04, -.30219900E+04, 0.16271600E+04, 0.12465800E+04, 0.12641300E+05, -.68505000E+04, 0.31883400E+04, -.63214000E+04, -.38804700E+04, -.94570100E+04, 0.48582800E+04, 0.14458300E+05, 0.25363300E+04, -.94128800E+04, -.18204600E+05, -.44295000E+05, 0.24802000E+05, 0.19282800E+05, 0.22147700E+05, 0.14129600E+05, 0.28883200E+05, -.84950400E+04, -.24384100E+05, 0.61929600E+04, 0.22870100E+05, 0.18885900E+05, 0.12151600E+05, -.57188800E+04, 0.23528200E+03, -.60760100E+04, 0.16151700E+04, 0.13657800E+03, -.25869100E+04, 0.26709900E+04, -.54112300E+04, -.60383800E+03, -.14876200E+05, 0.15474700E+05, -.12660100E+05, -.53334100E+03, -.77374400E+04, 0.32603900E+04, 0.23031200E+04, -.11020500E+05, -.14977800E+05, -.14187200E+05, 0.27142600E+04, -.15531700E+05, -.44425200E+04, 0.21400500E+04, -.42623200E+04, 0.22212100E+04, -.20972500E+04, -.36789000E+03, 0.77202400E+03, -.34192100E+04, 0.89683800E+03, 0.89588900E+03, 0.14788400E+05, 0.10458000E+06, -.57587600E+05, -.32329200E+05, -.52290200E+05, -.96149300E+03, 0.21775600E+05, -.30034500E+05, -.19788900E+04, -.39985200E+05, 0.17035300E+05, -.28689700E+05, 0.34251100E+04, 0.10390700E+04, -.68355700E+03, -.17149800E+04, -.12490600E+03, -.45065000E+04, -.92307000E+03, -.39025400E+04, -.18679700E+04, -.26228700E+04, -.73614600E+04, 0.52303500E+05, -.31059300E+05, -.26603200E+05, -.26152100E+05, -.63415400E+04, -.92881600E+04, -.54639300E+04, 0.13382000E+05, -.22220000E+05, -.75310800E+04, -.26566100E+05, 0.32639300E+05, -.23661200E+05, -.16637500E+05, -.16319700E+05, -.64534200E+04, -.93385200E+04, 0.61794100E+04, 0.25977100E+05, -.10895900E+05, -.65733300E+04, -.39282400E+05, -.77882300E+05, 0.43079500E+05, 0.19193600E+05, 0.38941100E+05, 0.38136400E+02, -.16343300E+05, 0.22406800E+05, 0.16517500E+04, 0.30409200E+05, -.13867400E+05, 0.25428600E+05, -.88920400E+04, 0.11159700E+05, 0.17479400E+05, 0.44460900E+04, -.41904400E+04, -.50816700E+04, 0.11579900E+05, 0.13819300E+05, 0.86068800E+04, -.46593100E+04, 0.12178200E+05, -.18297700E+05, 0.86909400E+04, 0.95708900E+04, 0.91488800E+04, -.96147400E+04, -.20564700E+05, 0.15623600E+05, 0.82644000E+04, 0.16992200E+05, -.16964800E+05, 0.10550300E+05, 0.63531100E+04, -.85905600E+04, -.27687500E+03, -.31765300E+04, -.35837500E+04, -.61523900E+04, 0.79272500E+04, 0.24623200E+05, -.28933300E+03, -.38076900E+04, -.21134500E+05, 0.35705300E+05, -.17671800E+05, -.19960100E+05, -.17852800E+05, 0.11197900E+04, 0.97718100E+04, -.14023300E+05, -.75021000E+04, -.18514100E+05, 0.66487000E+04, -.74435300E+04, -.25748900E+04, -.15707200E+04, -.40984500E+04, 0.12875600E+04, 0.26626100E+04, 0.37920300E+04, -.83914200E+04, -.15099100E+05, -.44655700E+04, 0.38174100E+04, 0.59966200E+04, -.38516400E+04, 0.50517700E+04, 0.57908300E+04, 0.19259800E+04, -.12817500E+04, -.18549900E+03, 0.71690500E+04, 0.21357200E+05, 0.58116300E+04, 0.82775600E+03, -.55831200E+04, -.26695600E+04, 0.26124400E+04, -.84778000E+02, 0.13970900E+04, 0.39861400E+04, 0.11033100E+05, 0.10561800E+05, 0.69439100E+03, 0.68039100E+02, -.24437100E+04, 0.81639900E+04, -.63888600E+03, -.44499700E+03, -.77264800E+03, -.11420500E+04, 0.13293600E+04, 0.41713700E+04, 0.67645900E+04, 0.15296900E+04, -.11246100E+04, 0.17543400E+05, -.97218500E+04, 0.24269200E+04, 0.26351100E+04, 0.50331700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16217600E+00, 0.36449400E+00, -.48206600E+00, 0.92900200E-01, -.76706500E+00, -.13322100E-01, 0.42929900E+00, 0.79457800E+00, 0.52112000E+00, 0.93632400E-01, 0.23996800E-01, 0.30171700E+00, 0.24720100E+00, -.42901600E-01, -.17500100E+00, -.18910000E+00, -.11342500E+00, 0.50840400E-01, 0.26477800E+00, 0.29295900E+00, -.91749400E-01, -.92885800E-01, -.43061100E+00, -.75311200E+00, -.16367800E+00, -.53143400E-02, 0.34079800E+00, -.13388500E+00, -.53636500E-01, 0.74384000E+00, -.13651500E+00, 0.28351900E+00, 0.40898100E+00, -.65928900E+00, 0.20344800E+00, 0.28471900E+04, -.21577300E+00, 0.31006400E+03, -.33951800E+04, 0.24225800E+04, 0.12337600E+04, 0.22200200E+04, -.28653100E+04, -.27366100E+04, -.37401200E+04, 0.18500300E+04, 0.92197400E+04, 0.18700100E+04, 0.41040800E+03, 0.52267400E+04, -.12031000E+04, -.45686500E+04, -.22162900E+04, 0.46433600E+04, -.19757800E+04, -.18374000E+05, 0.91768000E+04, -.67755900E+04, 0.91868500E+04, 0.22751900E+04, -.50612900E+04, 0.34159800E+04, 0.12485300E+04, 0.10967600E+05, -.44330800E+04, 0.97032300E+04, 0.85545400E+03, -.44991300E+03, 0.34378500E+04, -.42591600E+03, -.16274800E+03, -.40993000E+03, -.34259300E+02, -.91586000E+03, -.19912400E+04, -.11599000E+03, -.18309500E+04, -.22647200E+04, 0.12427300E+04, 0.51717100E+03, 0.11322600E+04, 0.35440400E+03, 0.53755900E+02, -.28935400E+03, -.16484800E+04, 0.30371500E+03, 0.30237400E+02, -.11011000E+03, -.58343100E+04, 0.29231400E+04, -.52188800E+03, 0.29160300E+04, 0.18317400E+04, 0.44538700E+04, -.25947500E+04, -.80995200E+04, -.89716800E+03, 0.44707700E+04, 0.31365100E+04, -.76914900E+04, 0.38365700E+04, 0.10317000E+05, 0.38460300E+04, 0.61229300E+03, -.11632400E+05, 0.45433400E+04, -.23228200E+04, 0.43127900E+04, -.89201200E+04, -.10054100E+04, 0.38445700E+04, -.20316400E+04, -.42544100E+04, -.19226100E+04, -.71829200E+03, 0.63014300E+03, -.15246700E+04, -.17171700E+04, -.51756200E+03, 0.73177400E+03, 0.10364400E+04, -.20322200E+05, 0.10198300E+05, 0.60160300E+03, 0.10161000E+05, -.70880200E+03, 0.12043700E+04, 0.39762100E+04, 0.23720200E+04, 0.88379000E+04, 0.11179000E+04, 0.10888700E+05, -.76562600E+04, 0.38998300E+04, 0.60852000E+04, 0.38280200E+04, 0.87078400E+03, -.37590200E+03, 0.26796400E+04, 0.25132800E+04, 0.15945900E+04, -.57799700E+03, -.19999700E+03, -.17112500E+04, 0.92587600E+03, 0.14984200E+04, 0.85565400E+03, 0.20520700E+04, -.34146000E+04, 0.24864400E+04, 0.30939500E+04, 0.18055800E+04, -.30761100E+04, -.70328400E+04, -.15138900E+04, 0.81212100E+03, -.26343500E+04, 0.75355400E+03, 0.42471700E+03, 0.67940000E+03, -.21047800E+03, -.14386500E+03, 0.16860000E+04, 0.35102700E+03, 0.19234000E+04, -.16839100E+05, 0.84586000E+04, 0.56273000E+04, 0.84201900E+04, 0.11292300E+04, 0.61037600E+04, 0.15985500E+04, -.30128200E+04, 0.55158300E+04, 0.53838200E+04, 0.89283100E+04, -.65929000E+04, 0.33405600E+04, 0.53632900E+04, 0.32963100E+04, 0.21904500E+04, 0.96260900E+04, -.42107600E+04, -.65212000E+04, 0.60838600E+03, 0.86990300E+04, 0.75583300E+04, 0.17997200E+04, -.94785000E+03, 0.12067900E+04, -.89986400E+03, -.16039100E+04, 0.19790000E+04, -.17332100E+04, -.23691500E+04, -.16719600E+04, 0.20257900E+04, 0.45528000E+04, 0.75185700E+04, -.38057100E+04, -.13148800E+05, -.37591500E+04, 0.12040400E+04, -.92922900E+03, -.12401300E+04, -.53084300E+03, -.16266300E+04, -.10482700E+04, -.38126600E+04, 0.27029600E+05, -.13520900E+05, -.16463100E+05, -.13514800E+05, -.12268300E+04, 0.73578200E+04, -.67028100E+04, 0.69585200E+04, -.10795900E+05, 0.53419900E+04, -.75658700E+04, 0.17078600E+04, -.83750500E+03, -.20925000E+03, -.85388600E+03, -.17487100E+04, 0.36245400E+04, -.30474700E+04, -.62875600E+04, -.12059900E+04, 0.30508900E+04, 0.54722100E+04, 0.27576200E+04, -.13900900E+04, 0.67099200E+03, -.13790300E+04, 0.12115300E+04, -.80143200E+03, 0.63187800E+03, 0.97897200E+03, 0.83786100E+03, -.47633500E+03, -.61912800E+04, 0.35970900E+04, -.17686400E+04, 0.12061500E+04, -.17983500E+04, -.11118300E+03, -.10623300E+04, 0.16488500E+04, 0.33941600E+04, 0.51760800E+03, -.12618700E+04, -.40930100E+04, 0.17847900E+04, -.86135700E+03, -.26258600E+04, -.89213700E+03, -.16718300E+04, -.17583800E+04, 0.35579400E+03, -.22344600E+04, 0.64498400E+03, -.15530600E+04, 0.42136500E+04, 0.11258700E+04, -.95785300E+03, -.20805000E+03, -.43679300E+03, -.26544700E+03, -.67051200E+04, -.49838200E+04, -.19475300E+03, 0.28159600E+03, 0.11382300E+04, -.32327300E+04, 0.87197300E+02, 0.76704500E+03, 0.77358800E+02, 0.14376600E+04, -.35860400E+03, -.37627000E+04, -.37832300E+04, 0.65070500E+03, 0.86592900E+03, -.51725700E+04, 0.28237400E+04, -.16367600E+04, -.10103900E+04, -.15206600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13376600E+01, 0.93794200E+00, 0.18879500E-01, 0.14928700E+01, 0.41058700E+00, 0.34885300E-01, -.12038900E+01, -.19493300E+01, 0.89936000E+00, 0.10552600E+00, 0.36866300E+00, -.32850900E+01, -.25231400E+01, 0.50122200E+00, -.11514700E+01, 0.28297600E+01, 0.61696900E+00, 0.75520600E+00, -.67735500E+00, 0.11624200E+01, -.21236100E+01, -.14289800E+00, 0.17917600E+01, 0.81606500E+00, 0.15863900E+00, 0.36087000E+00, -.17495600E+01, -.61077600E+00, -.71664100E+00, -.81384200E+00, -.22463800E+00, 0.76372400E-01, -.86146300E+00, 0.56289500E+00, -.16159100E+00, 0.45838200E+00, 0.70761800E+01, 0.13764200E+03, 0.31360000E+04, 0.26118200E+03, 0.47566800E+04, -.52014500E+04, 0.30435600E+04, -.22233200E+04, -.34518400E+04, 0.16990600E+04, 0.17814100E+04, 0.17266500E+04, -.93564100E+03, -.88405700E+04, 0.33629200E+04, 0.67340400E+04, 0.82580900E+04, -.84982400E+04, 0.61703800E+04, 0.30201000E+05, -.15530800E+05, -.11754400E+05, -.15102500E+05, 0.84224700E+03, 0.11518700E+05, -.56689400E+04, 0.16561900E+03, -.20349900E+05, 0.11210000E+05, -.18140300E+05, 0.24110700E+01, 0.63560000E+03, -.10329100E+05, -.46314600E+01, -.85129500E+03, -.83609300E+03, 0.35612200E+03, 0.51599600E+04, 0.74546800E+04, -.18586800E+04, 0.83300300E+03, 0.95811200E+02, -.13622600E+04, -.33756700E+04, -.57458000E+02, -.11746100E+04, -.14223800E+04, 0.20122800E+04, 0.37455200E+04, 0.19833400E+04, -.12781600E+04, 0.12357000E+03, 0.50138200E+04, -.25803200E+04, -.90573400E+03, -.25117200E+04, -.51881800E+04, -.11982300E+05, 0.50224200E+04, 0.11113600E+05, 0.39674100E+04, -.10215700E+05, 0.33076900E+04, 0.27732700E+05, -.14123500E+05, -.46483300E+04, -.13868100E+05, 0.21916700E+04, 0.15105000E+05, -.73743400E+04, 0.86775200E+04, -.20488700E+05, 0.14208900E+05, -.20254000E+05, -.13008400E+05, 0.77847200E+04, 0.59431700E+04, 0.65043400E+04, 0.46067700E+04, 0.42418400E+04, 0.13117300E+03, -.18838400E+04, -.24850300E+03, 0.37570900E+04, 0.78020200E+04, 0.54509600E+04, -.16303100E+04, -.93244500E+04, -.27268400E+04, 0.53006400E+04, -.34042100E+04, 0.31994700E+04, -.67214200E+04, -.58710700E+04, -.25096800E+04, -.19205700E+04, 0.19259800E+05, -.10523700E+05, -.62316500E+04, -.96346700E+04, -.53007000E+04, -.53939100E+04, -.97335100E+03, 0.37112100E+04, 0.66669700E+03, -.49618700E+04, -.13113100E+05, -.39987300E+05, 0.21045400E+05, 0.20529700E+05, 0.19992700E+05, -.25070400E+04, 0.28117300E+04, 0.44439800E+04, -.74793200E+04, 0.63388100E+04, 0.52463000E+04, 0.17095700E+05, 0.10498600E+04, -.20076900E+04, 0.87837800E+04, -.52065700E+03, -.59273100E+03, -.11837100E+04, 0.13178600E+04, -.18392200E+04, -.57730700E+04, -.88524600E+02, -.14663000E+04, 0.19352500E+05, -.87778700E+04, -.12124100E+05, -.96766100E+04, 0.47698500E+03, -.86534400E+04, -.12940100E+04, 0.51592800E+04, 0.27463300E+03, -.83961800E+04, -.39427800E+04, 0.13180100E+05, -.51282400E+04, 0.36592000E+04, -.65882600E+04, 0.22508100E+04, -.11302500E+05, 0.44074200E+03, -.12212900E+04, -.66550300E+04, -.93597200E+04, 0.41125400E+04, 0.29321000E+05, -.15599400E+05, -.15099100E+05, -.14659600E+05, 0.33655400E+04, 0.44993200E+03, -.50366700E+04, 0.56843800E+04, -.46052100E+04, -.19041600E+04, -.12998900E+05, -.14930300E+05, 0.60510400E+04, 0.14943500E+05, 0.74779400E+04, -.21437400E+04, 0.10046500E+05, -.44226500E+04, 0.25471700E+04, 0.29242700E+04, 0.82035400E+04, 0.46015100E+04, -.50248000E+05, 0.25072300E+05, 0.20808300E+05, 0.25121400E+05, -.14497400E+04, -.75630400E+04, 0.87200500E+04, -.17370800E+05, 0.21325400E+05, -.67455300E+04, 0.24823100E+05, -.48759200E+03, 0.13930800E+04, 0.30867300E+04, 0.24495200E+03, 0.26161900E+04, -.57585600E+04, -.22478000E+04, -.46709200E+04, -.50631700E+04, -.42589600E+04, 0.68056700E+04, -.23095800E+05, 0.11760700E+05, 0.17638300E+05, 0.11554100E+05, 0.29347400E+04, 0.30280500E+04, 0.13073600E+04, -.34866300E+03, -.82288400E+02, 0.46877500E+04, 0.95596300E+04, -.92741200E+04, 0.52144300E+04, 0.19818600E+04, 0.46389800E+04, 0.71806100E+03, 0.83850100E+03, 0.14188700E+04, 0.11378800E+03, -.52576600E+03, 0.14643000E+04, 0.17063200E+04, 0.69791000E+03, -.15970500E+04, 0.32019600E+04, -.34286100E+03, 0.36453600E+04, 0.80860400E+04, -.80105000E+04, -.52361800E+04, -.84296700E+04, 0.64603700E+04, 0.28518300E+04, -.17761100E+04, 0.46946400E+03, -.14516500E+04, -.77955100E+03, -.30499100E+04, 0.96532100E+04, 0.79772900E+04, -.10581900E+04, 0.12590500E+04, -.24704000E+04, 0.15992100E+04, -.25113700E+04, -.35487400E+04, 0.77518500E+02, -.14263700E+04, -.89033900E+03, 0.13940500E+04, 0.41022600E+04, -.12241300E+04, -.48786600E+04, 0.24779100E+04, -.66198400E+03, 0.21322400E+04, 0.57735000E+03, 0.21495500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17410300E+00, 0.73381700E+00, 0.10423400E+01, 0.38347400E-01, 0.74531000E+00, 0.72492500E-01, 0.24188900E+00, 0.60748500E+00, -.77907700E+00, -.16364900E+00, -.46419200E-01, -.66053000E+00, 0.79765500E+00, -.28372700E+00, 0.59028000E+00, 0.63735800E-01, 0.38343100E+00, -.24184200E+00, -.13079900E+00, -.29393700E+00, 0.11158900E+01, 0.24531100E-01, -.30562100E+00, 0.25243200E+00, 0.24572800E-01, -.54129800E-01, -.20047700E+00, 0.10899200E+00, 0.42666600E+00, 0.51394100E+00, 0.53137200E-01, -.68012500E+00, 0.60005900E-01, 0.14390600E+00, 0.93428800E-01, -.64473600E+00, -.68556500E-02, -.41629000E+04, -.66479900E+04, 0.62525400E+04, 0.91223600E+04, 0.61314200E+04, -.66789100E+04, 0.36477800E+04, -.51021600E+05, 0.25452400E+05, 0.28385500E+05, 0.25510800E+05, 0.59193700E+04, 0.97742200E+04, 0.70116700E+04, -.12024500E+05, 0.10085000E+05, 0.96395000E+04, 0.13237800E+05, 0.42782800E+05, -.21569900E+05, -.29401500E+05, -.21391500E+05, -.89641700E+04, -.14326800E+05, -.45680700E+04, 0.14591800E+05, -.44039200E+04, -.13596000E+05, -.90329500E+04, 0.36960600E+04, -.13159600E+04, 0.51322100E+04, -.18475800E+04, -.86845600E+03, -.28574800E+04, 0.38075700E+03, -.26546500E+04, -.34290900E+04, -.15285000E+04, -.62075300E+04, -.43738800E+04, 0.20351900E+04, 0.34863800E+04, 0.21868500E+04, -.69189600E+03, -.69225700E+03, 0.14737100E+04, 0.40326100E+03, 0.13617300E+04, -.58074200E+03, 0.32937300E+02, -.56180000E+04, 0.27438100E+04, 0.33105300E+04, 0.28086400E+04, 0.30184800E+04, 0.62693800E+04, -.86279400E+03, -.50387800E+04, -.20944000E+04, 0.72242000E+04, 0.44825500E+04, 0.13516400E+05, -.68746100E+04, -.10580300E+05, -.67581200E+04, -.84555700E+04, -.20895600E+05, 0.71008200E+04, 0.12091600E+05, 0.26165500E+04, -.18019900E+05, -.21319900E+04, -.56098800E+04, 0.28985300E+04, 0.30871900E+03, 0.28048600E+04, -.12444300E+04, -.10313500E+03, 0.15837100E+04, 0.11796500E+03, 0.37130700E+04, 0.52270100E+03, 0.68560300E+04, -.13878400E+05, 0.74896700E+04, 0.72398200E+03, 0.69391300E+04, 0.11244000E+04, 0.24482400E+04, 0.35217500E+04, 0.75271500E+04, 0.92370600E+04, 0.19369100E+04, 0.10983400E+05, 0.64512000E+03, -.39031500E+03, -.36140700E+03, -.32263300E+03, 0.19542000E+04, 0.68258300E+03, -.45126900E+03, -.46283500E+03, -.20302800E+04, -.38915400E+03, -.58900700E+04, -.50138800E+05, 0.25706600E+05, 0.20760400E+05, 0.25069400E+05, -.50968800E+04, -.18121800E+05, 0.22131200E+05, 0.10478000E+05, 0.23862100E+05, -.14618900E+05, 0.14437800E+05, -.53726500E+04, 0.17900700E+04, -.38825000E+04, 0.26854700E+04, 0.91306700E+03, 0.26857800E+04, 0.35568700E+03, 0.23223700E+04, 0.38656800E+04, 0.13529900E+04, 0.64039200E+04, -.30438800E+05, 0.15759200E+05, 0.18973600E+05, 0.15220100E+05, 0.48072500E+04, 0.68215300E+04, 0.31168200E+04, -.93547200E+04, 0.92762000E+04, 0.74732700E+04, 0.12401500E+05, -.24217600E+05, 0.12898900E+05, 0.14505300E+05, 0.12108800E+05, 0.44035300E+04, 0.58958300E+04, -.47944700E+03, -.11457500E+05, 0.67879500E+04, 0.62787400E+04, 0.18197300E+05, 0.32605200E+05, -.16829500E+05, -.13055800E+05, -.16302600E+05, 0.37161500E+04, 0.11256300E+05, -.13988900E+05, -.77373600E+04, -.15784400E+05, 0.98070400E+04, -.11021900E+05, 0.16543200E+05, -.90170700E+04, -.99553000E+04, -.82714600E+04, -.19509900E+04, -.29715300E+03, -.58374200E+04, -.72132600E+04, -.73717100E+04, -.27476900E+03, -.11232500E+05, 0.18843400E+05, -.95378700E+04, -.42379700E+04, -.94217200E+04, 0.53535600E+04, 0.16277000E+05, -.11662400E+05, -.27796100E+04, -.12336900E+05, 0.13412900E+05, -.10432100E+05, -.12253600E+04, 0.12399300E+04, -.21896700E+04, 0.61269900E+03, 0.33438300E+04, 0.58936800E+04, -.44892900E+04, -.12179800E+05, -.61098500E+03, 0.48425000E+04, 0.74903500E+04, -.21851300E+05, 0.10964200E+05, 0.78792400E+04, 0.10925700E+05, -.17890900E+04, -.68086300E+04, 0.12027300E+05, 0.94532600E+04, 0.14710000E+05, -.49055100E+04, 0.65853200E+04, 0.39460500E+04, -.16247800E+04, 0.20403100E+04, -.19729500E+04, -.10874300E+04, -.60129500E+03, 0.33882700E+04, 0.87168100E+04, 0.26022900E+04, -.12738500E+04, -.23508100E+04, 0.35935300E+04, -.22326300E+04, -.66486100E+04, -.17966400E+04, 0.19388300E+03, -.22600000E+04, -.40919400E+04, -.13893900E+05, -.18352400E+04, -.23965700E+04, 0.19808000E+04, 0.92001700E+03, -.68474900E+03, 0.44151700E+03, -.80067200E+03, -.32032700E+04, -.80177300E+04, -.77190100E+04, 0.11182700E+03, -.44035300E+03, 0.75323200E+03, -.68941100E+04, 0.99754000E+03, 0.18029900E+04, 0.64519500E+03, -.25475600E+04, -.54660900E+03, -.45466500E+04, -.39545100E+04, -.50801200E+04, 0.13841700E+04, -.12594000E+05, 0.46843300E+04, 0.25983100E+03, -.11281700E+04, -.30721100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39463900E+00, 0.35563200E+00, 0.10946300E+01, 0.67051100E+00, -.38917100E-01, -.14033600E+00, 0.22346700E+00, 0.17814400E+00, -.22549500E+00, -.26145600E+00, 0.48369100E-02, -.18200100E+01, -.11412600E+00, -.63924000E-01, -.97644300E+00, 0.13468400E+01, 0.11059900E+01, -.62749200E-01, -.20456800E+00, 0.33922100E+00, -.19038600E+00, -.43365900E-02, 0.49944600E-01, 0.81403500E+00, -.27043200E-01, -.33753200E-01, 0.41337900E-01, 0.82289700E-01, -.11310100E+00, -.10036200E+00, 0.39652100E+00, 0.91186500E-01, -.54880600E+00, 0.57935100E-02, -.63126200E+00, -.15010900E+01, -.52346900E-01, -.93660800E+00, -.87555000E+04, 0.47556400E+04, 0.39066900E+04, 0.63268400E+04, -.77034200E+04, -.32502000E+04, -.42950000E+05, 0.21420200E+05, 0.23630300E+05, 0.21475000E+05, 0.56348000E+04, 0.14103100E+05, 0.44615600E+04, -.12941900E+05, 0.74905700E+04, 0.13013600E+05, 0.92371700E+04, 0.25349700E+05, -.12735200E+05, -.19508200E+05, -.12675300E+05, -.66596500E+04, -.20280300E+05, -.50424900E+03, 0.12745000E+05, 0.55454100E+03, -.17743500E+05, -.47368000E+04, 0.44007100E+04, -.20903300E+04, 0.10332300E+05, -.21969600E+04, -.10691800E+04, -.14818400E+04, 0.44270300E+03, -.21355200E+04, -.63452500E+04, -.34112000E+03, -.61070600E+04, -.45962000E+04, 0.25239500E+04, 0.36355500E+04, 0.22973400E+04, 0.25484900E+03, 0.12856900E+02, -.11521700E+03, -.28617600E+04, 0.31050700E+03, 0.26688000E+03, 0.24696100E+03, -.79504200E+04, 0.39720800E+04, 0.74318500E+04, 0.39726500E+04, 0.36646000E+04, 0.12917700E+05, -.41384100E+04, -.13535200E+05, -.51332600E+04, 0.13503400E+05, 0.23099500E+03, -.11432600E+05, 0.56395400E+04, -.26988200E+04, 0.57167600E+04, -.25269500E+04, -.27468000E+05, 0.10322700E+05, 0.14680700E+04, 0.12007900E+05, -.23142600E+05, 0.41668200E+04, 0.83474600E+04, -.44158500E+04, -.63895100E+04, -.41743500E+04, -.17069600E+04, 0.82201700E+03, -.15548000E+04, -.22648000E+02, -.89873000E+02, 0.88525900E+03, 0.36506300E+03, -.22784400E+05, 0.11730500E+05, 0.37572200E+04, 0.11391800E+05, 0.30444700E+04, 0.62822100E+04, 0.11922800E+04, 0.55246300E+04, 0.11620900E+05, 0.51505300E+04, 0.14525400E+05, -.16863400E+05, 0.86180000E+04, 0.58539400E+04, 0.84311800E+04, 0.28394200E+04, 0.12715000E+03, 0.35725500E+04, 0.21364000E+03, 0.19166200E+04, -.22994800E+03, 0.22189100E+04, 0.23563000E+04, -.79936500E+03, 0.84636200E+04, -.11781500E+04, -.67762100E+04, -.15918000E+05, 0.11335100E+05, 0.15075600E+05, 0.63825700E+04, -.13866300E+05, -.11082600E+05, -.82050200E+04, 0.39619400E+04, -.92674800E+04, 0.40960400E+04, 0.22188400E+04, 0.24077100E+04, -.72716800E+03, -.55956200E+03, 0.63606600E+04, 0.12206500E+04, 0.75479800E+04, -.32068700E+05, 0.16386600E+05, 0.21290500E+05, 0.16035600E+05, 0.39858300E+04, 0.11158800E+05, 0.34519100E+04, -.85829600E+04, 0.76875900E+04, 0.11382300E+05, 0.12325100E+05, -.36407800E+05, 0.18657700E+05, 0.17300200E+05, 0.18203700E+05, 0.27756900E+04, 0.10964800E+05, 0.39545000E+04, -.67325600E+04, 0.10749700E+05, 0.10345100E+05, 0.18467100E+05, -.73339700E+04, 0.33600800E+04, -.42686900E+04, 0.36670300E+04, 0.48027000E+04, 0.93580500E+04, -.58974100E+04, -.11663500E+05, -.22377100E+04, 0.88107400E+04, 0.10254500E+05, 0.27357200E+05, -.14136800E+05, -.16003700E+05, -.13677600E+05, -.54311700E+04, -.62775600E+04, -.18197500E+04, -.16231800E+04, -.83053900E+04, -.50611600E+04, -.14715100E+05, 0.44478000E+05, -.22361100E+05, -.13272200E+05, -.22239100E+05, 0.42280400E+03, 0.20503400E+05, -.15178300E+05, 0.87597900E+04, -.20301900E+05, 0.16253700E+05, -.14912100E+05, -.32277900E+04, 0.19388100E+04, -.51633600E+04, 0.16140500E+04, -.14999300E+04, 0.94740400E+04, -.17343900E+04, -.80587600E+04, 0.16832900E+04, 0.69525400E+04, 0.10031700E+05, -.58996500E+04, 0.29065900E+04, -.39324300E+04, 0.29497500E+04, -.76070100E+03, -.61769400E+04, 0.78316500E+04, 0.69906100E+04, 0.10164300E+05, -.49648200E+04, -.35279100E+04, 0.89451000E+04, -.42685200E+04, 0.22363500E+04, -.44720400E+04, 0.76190700E+03, -.90844900E+03, 0.11817600E+04, 0.64001900E+04, 0.15423100E+04, -.18387100E+04, -.66457500E+04, 0.27992000E+04, -.15012500E+04, -.97998300E+04, -.13987100E+04, -.33046700E+04, -.59585700E+04, 0.17867700E+04, -.58791800E+04, 0.33866500E+04, -.60489800E+04, 0.73977600E+04, 0.12566200E+04, -.60218200E+03, -.29466400E+03, -.15323700E+04, -.10336400E+04, -.12865300E+05, -.12135800E+05, -.24555600E+03, 0.40956900E+03, 0.19562100E+04, -.84327700E+04, 0.20545400E+04, 0.32807700E+04, 0.12439800E+04, -.32089100E+03, -.10351000E+04, -.69796800E+04, -.58643900E+04, -.27215400E+04, 0.29479300E+04, -.13803000E+05, 0.39007000E+04, -.14182300E+04, -.10753400E+04, -.25923400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26466100E+00, 0.64517600E-02, 0.44991400E+00, 0.14323000E+00, -.32318600E+00, -.10370400E+00, 0.64789900E+00, 0.35384600E+00, -.11751700E+01, -.41773400E+00, 0.34443200E-01, -.32968200E-01, 0.27929300E+00, 0.95728400E-01, 0.52319900E+00, -.70894100E+00, -.31792400E+00, 0.33862700E+00, 0.11869100E+00, 0.63335800E+00, -.65919200E+00, -.12033700E-01, 0.10929600E+00, 0.16067900E+00, 0.53415400E-01, 0.11136500E+00, 0.56437300E+00, -.26313800E+00, 0.81703600E-01, -.17360600E+00, -.32634300E+00, 0.15772100E+00, 0.70918100E+00, 0.15965600E+00, 0.13495800E-01, 0.97831400E-01, -.19328300E-02, -.10952500E+00, -.41830700E+00, -.16164300E+04, -.42570000E+04, -.24050800E+04, 0.17022700E+04, -.42860900E+04, -.17265400E+05, 0.86010300E+04, 0.95104100E+04, 0.86326700E+04, 0.11191600E+04, 0.38094300E+04, 0.46060500E+04, -.13415400E+03, 0.52540300E+04, 0.26467200E+04, 0.54121700E+04, 0.18711900E+05, -.93920000E+04, -.90716000E+04, -.93561300E+04, -.20232800E+03, -.70326900E+04, -.49293700E+04, -.17263400E+04, -.65393400E+04, -.45781700E+04, -.88163300E+04, -.63087200E+03, 0.27479200E+03, 0.20706300E+04, 0.31697600E+03, -.70710000E+03, -.48205000E+03, 0.10369700E+04, 0.57846700E+03, -.16324900E+03, -.42949900E+03, 0.25195600E+03, -.12050100E+04, 0.68346600E+03, 0.70635000E+03, 0.60215000E+03, 0.28913700E+03, -.27686400E+03, -.26022600E+03, -.15556000E+04, 0.32922400E+02, 0.59133300E+02, 0.10310700E+03, -.40245600E+04, 0.20385400E+04, 0.28569100E+04, 0.20111500E+04, 0.27790600E+04, 0.41782500E+04, -.32081900E+03, -.21626200E+04, -.34029900E+03, 0.30324100E+04, 0.16779900E+03, -.88904400E+04, 0.43753900E+04, -.36803500E+04, 0.44454200E+04, -.21796900E+03, -.74218200E+04, 0.10456900E+04, -.67993300E+04, 0.16410100E+04, -.52407000E+04, 0.56860300E+03, 0.71751700E+04, -.36556600E+04, -.23253900E+04, -.35878700E+04, -.44040500E+03, -.51991700E+03, -.19446700E+04, -.14756900E+03, -.27932300E+04, -.77865400E+03, -.14211600E+04, 0.29534600E+04, -.12012500E+04, 0.18400400E+04, -.14768800E+04, -.89270700E+03, -.11195600E+03, -.16423200E+04, -.65194800E+03, -.20600800E+04, 0.57118200E+03, -.15835300E+04, -.72786300E+04, 0.37045600E+04, 0.18577700E+04, 0.36391000E+04, 0.40067400E+01, 0.52675200E+03, 0.28527500E+04, 0.87050400E+03, 0.25074900E+04, 0.98711500E+03, 0.37279000E+03, 0.19132300E+05, -.93209900E+04, -.41335900E+04, -.95661400E+04, 0.16531900E+04, 0.38587100E+04, -.54662100E+04, -.50487500E+03, -.71895000E+04, 0.27672800E+04, -.12364500E+05, -.13065700E+04, 0.70794200E+03, -.17734800E+04, 0.65034800E+03, 0.10619600E+04, 0.78156300E+03, -.10207400E+04, -.14854800E+04, 0.10964600E+03, 0.77306700E+03, 0.48303500E+03, -.35783700E+04, 0.20464100E+04, 0.52397300E+04, 0.17898600E+04, 0.88591900E+03, 0.20145700E+04, 0.11497500E+04, 0.32637200E+03, 0.84191300E+03, 0.18041400E+04, 0.26302900E+04, -.16747200E+05, 0.87001200E+04, 0.42128400E+04, 0.83735300E+04, 0.21146200E+04, 0.10470000E+04, 0.52094000E+04, 0.30038400E+04, 0.56340000E+04, -.54095900E+03, 0.96202300E+04, -.17101900E+05, 0.83401100E+04, 0.33739900E+04, 0.85509500E+04, -.15456600E+04, -.38868200E+04, 0.52547800E+04, 0.39614900E+03, 0.71277900E+04, -.30888300E+04, 0.11306600E+05, 0.26878200E+04, -.17027000E+04, -.17707400E+04, -.13434500E+04, -.14686300E+03, -.12340900E+04, -.15295800E+03, 0.69190000E+03, 0.29022100E+03, -.79432700E+03, -.72956200E+03, 0.14656600E+05, -.74201300E+04, -.47440800E+03, -.73283400E+04, -.75788200E+03, 0.65903400E+04, -.31731800E+04, 0.70423100E+04, -.28532400E+04, 0.45577100E+04, -.26229600E+04, -.14434300E+03, 0.28962500E+03, -.12205200E+04, 0.72240500E+02, 0.48728500E+03, 0.22795500E+04, 0.16438300E+04, 0.39517000E+04, -.14092600E+03, -.54184100E+03, 0.51670900E+04, 0.36342600E+04, -.18532800E+04, -.51321400E+04, -.18171600E+04, 0.53553200E+03, 0.29420100E+04, -.26643800E+04, -.34081000E+04, -.22913000E+04, 0.30285100E+04, -.42432700E+04, 0.20801000E+04, -.90560300E+03, 0.12569700E+04, -.10398300E+04, 0.48164200E+03, 0.19776300E+04, -.20360700E+04, -.21400000E+04, -.18570800E+04, 0.22234400E+04, -.33741100E+04, -.13994700E+04, 0.60109300E+03, -.11167500E+04, 0.70012900E+03, -.19574700E+04, -.40976500E+04, 0.32143000E+04, 0.46788900E+04, 0.20065700E+04, -.46921600E+04, 0.62551100E+04, 0.57421300E+03, -.10830400E+03, 0.54338600E+03, 0.39747400E+03, 0.18941100E+04, -.34524000E+04, -.28770300E+04, 0.72897400E+03, -.47968400E+03, 0.85613500E+03, -.10796000E+04, -.72436300E+03, 0.68792500E+03, -.61781700E+03, 0.11343100E+04, 0.52319500E+03, -.49016000E+03, -.13810600E+04, 0.14894400E+04, 0.95190100E+03, -.15295500E+04, 0.13240000E+03, -.13817800E+04, -.98680200E+02, 0.14443800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32811300E+00, 0.37830900E+00, 0.34250500E+00, 0.20988000E+00, 0.17757500E+00, 0.19419800E-01, -.13247000E+00, 0.90055500E-01, 0.25079100E+00, 0.99494000E-01, 0.71162900E-01, -.15761100E+01, -.43880200E+00, 0.43920000E+00, -.12734100E+01, 0.86136500E+00, 0.51915800E+00, 0.49698000E+00, -.19395400E+00, 0.83782800E+00, -.11258300E+01, -.31474700E-01, 0.48026300E+00, -.18078700E+00, -.44610000E-01, -.55284300E-01, -.28337100E+00, -.56331600E-01, 0.10698100E+00, 0.96136900E-01, 0.19483500E+00, -.19774800E+00, -.23391400E+00, 0.67642600E+00, -.20932600E+00, 0.17826400E+00, -.78308700E-02, 0.81560300E-01, 0.80770200E-01, -.47010900E+00, -.35152200E+04, -.38092600E+04, 0.12793100E+04, -.27756300E+04, 0.82073700E+04, -.41073200E+04, -.25844700E+04, -.41036900E+04, -.18077200E+04, -.15018600E+04, -.25605500E+04, 0.30097200E+04, 0.23889800E+03, -.24876300E+04, -.70370000E+02, -.86712800E+04, 0.42649300E+04, 0.26071300E+04, 0.43355500E+04, 0.31524000E+04, 0.29615900E+04, 0.16166500E+04, -.50686100E+04, -.12066400E+04, 0.39248700E+04, 0.91834800E+02, -.97745600E+03, 0.30989800E+03, -.18391300E+04, 0.48954100E+03, 0.19792800E+03, 0.11987100E+04, -.80677000E+03, 0.15586200E+04, 0.23756100E+04, 0.49769200E+03, 0.16300300E+04, 0.11547400E+04, -.61477300E+03, -.51711100E+03, -.57757000E+03, 0.27373400E+03, 0.21876600E+03, -.49314600E+03, 0.55059100E+02, -.19183100E+03, 0.21140300E+03, -.58179500E+03, 0.33908400E+04, -.16851200E+04, -.84956600E+03, -.16959700E+04, -.14108300E+04, 0.17447700E+04, -.20962200E+04, -.31319500E+03, -.18800800E+03, 0.17199800E+03, 0.20822200E+04, 0.57194900E+03, -.30768300E+03, -.19220000E+04, -.28587800E+03, 0.10064600E+04, 0.26655000E+04, 0.59995000E+03, -.22300500E+04, -.55081900E+04, 0.36062000E+04, -.50754000E+04, 0.23957000E+04, -.11303600E+04, -.16456700E+03, -.11980100E+04, 0.35920500E+03, 0.41256600E+03, -.45286200E+03, -.13701100E+03, -.18751900E+04, -.85652800E+02, -.37520000E+03, 0.39715200E+04, -.19099600E+04, 0.36721400E+04, -.19858400E+04, -.47296700E+03, -.11022900E+04, 0.92159400E+03, -.27125200E+04, -.37667100E+04, -.97657000E+03, -.25581800E+04, -.22702500E+04, 0.10561400E+04, 0.11022500E+04, 0.11350200E+04, -.62454600E+03, -.65639500E+03, 0.13561600E+03, 0.46906200E+03, 0.24312200E+04, 0.64356200E+02, -.28787600E+03, 0.20697700E+04, -.96149000E+03, -.34698000E+04, -.10348800E+04, 0.39554100E+04, 0.98409900E+04, -.83593600E+04, -.73625700E+04, -.56191700E+04, 0.86433100E+04, -.15664000E+04, 0.80658800E+03, -.19490400E+03, 0.19049000E+04, -.40485300E+03, -.30169600E+03, -.13328200E+04, 0.81152000E+03, -.12880200E+04, -.21296100E+04, -.64223200E+03, -.15328700E+04, 0.52729200E+04, -.25884900E+04, -.22314300E+04, -.26362500E+04, -.82522700E+03, -.94728900E+03, -.17999800E+04, 0.20388800E+04, 0.10614700E+04, -.23149300E+04, 0.12023100E+04, 0.45983100E+03, -.13426800E+03, -.34153200E+04, -.22995500E+03, -.13275600E+04, -.14555600E+04, 0.70870100E+03, 0.50095400E+03, 0.35086100E+03, -.36180900E+04, 0.48779600E+04, -.31935300E+04, 0.15290600E+04, 0.30700100E+04, 0.15967700E+04, -.21628100E+04, -.60481400E+04, 0.48181900E+04, 0.50224300E+04, 0.46152400E+04, -.55826600E+04, 0.26474100E+04, -.24562400E+04, 0.11401600E+04, -.16221400E+04, 0.12283600E+04, 0.17417800E+04, 0.17986300E+04, -.21441900E+04, 0.14117500E+04, 0.12694300E+04, 0.21097700E+04, 0.84203700E+03, -.54455700E+03, 0.31515500E+03, 0.18545200E+04, 0.27225100E+03, -.66168000E+03, -.23572400E+04, 0.44327800E+03, 0.44523700E+03, 0.23548600E+04, -.20970100E+04, 0.14955800E+04, -.22106400E+03, 0.15918700E+03, 0.84853500E+03, 0.11056700E+03, -.14110700E+04, -.15321300E+03, 0.11828300E+04, 0.25044000E+04, 0.84537000E+02, -.18484900E+04, 0.37260800E+04, -.66406300E+03, 0.33622200E+03, -.25059600E+03, 0.33201500E+03, 0.17383800E+04, 0.43715000E+04, -.52724600E+04, -.64671300E+04, -.47440400E+04, 0.42670000E+04, -.11010400E+03, -.24213300E+04, 0.12516600E+04, 0.19044200E+04, 0.12107700E+04, 0.59842300E+03, -.14296200E+03, -.10091400E+03, -.23370000E+04, -.17179700E+04, 0.75842700E+03, -.13111600E+04, -.11533300E+04, 0.51698500E+03, 0.72354600E+02, 0.57686000E+03, 0.24917900E+03, -.36521700E+03, 0.12943100E+04, 0.41957800E+04, -.10632000E+03, -.89241600E+03, 0.19273300E+04, -.25098800E+03, -.46390000E+03, -.68498800E+03, -.29680900E+03, 0.14495700E+04, 0.98655600E+03, 0.10310600E+04, -.54904000E+03, 0.69378900E+03, 0.61891200E+03, 0.20632800E+04, 0.76327100E+02, -.24573600E+04, 0.24877400E+03, 0.10458700E+04, -.36600500E+03, 0.18985100E+04, 0.30430500E+03, 0.22199400E+04, -.16077500E+04, 0.27065600E+04, -.68190700E+03, -.12378900E+04, 0.10806000E+03, 0.97269200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.79270300E+00, -.58768700E+00, -.10909100E+01, -.36510700E-01, -.68959300E-01, -.43820200E-01, -.53132600E+00, -.13882700E+01, -.64141400E+00, -.90267600E-01, 0.32939300E-01, 0.27020800E+01, 0.49960000E+00, -.73722300E+00, -.24912000E+01, -.33420300E+01, -.80516100E+00, 0.49066900E+00, 0.14007500E+00, 0.93142600E-01, -.73596100E+00, 0.28592300E-03, -.33965700E+00, -.19109300E+01, 0.68459400E-01, 0.34149600E-01, -.48814500E+00, 0.37741600E+00, -.12542300E+00, -.33052200E+00, 0.42726800E+00, 0.55226100E+00, -.57491000E+00, -.68460500E+00, -.56978500E+00, -.45048300E+00, -.11697500E-01, -.15721800E+01, 0.50168600E+00, -.64080700E+00, 0.12337600E+01, 0.69241100E+04, -.83143300E+03, 0.55319000E+04, -.23037300E+05, 0.11514900E+05, 0.51101900E+04, 0.11518700E+05, 0.54525200E+04, 0.98047100E+04, 0.44444400E+04, -.54099600E+04, 0.13914900E+04, 0.93703200E+04, 0.25100000E+03, 0.82641500E+04, -.37986900E+04, 0.20976800E+04, -.41320100E+04, -.91602700E+04, -.15299900E+05, -.76408200E+03, 0.48817400E+04, 0.65981600E+04, -.14143100E+05, 0.88572200E+04, 0.12237100E+04, -.11669000E+04, 0.12108500E+05, -.61249900E+03, -.33856300E+03, -.62436500E+03, 0.91854500E+03, -.51565300E+04, -.75258000E+04, 0.67283800E+03, -.29673500E+04, -.87648800E+03, 0.13356900E+04, 0.27803300E+04, 0.43836500E+03, 0.50001500E+03, 0.11524800E+04, -.10890100E+04, -.27381400E+04, -.17498000E+04, 0.90041500E+03, 0.53268500E+03, -.94141400E+04, 0.48107700E+04, 0.29369000E+04, 0.47074800E+04, 0.32225000E+04, 0.41833400E+04, 0.95178200E+03, -.59610200E+04, -.21598600E+04, 0.50700500E+04, -.38387500E+04, -.22519700E+05, 0.11380100E+05, -.10532800E+04, 0.11259800E+05, -.68872700E+04, -.15846000E+05, 0.36823200E+04, -.95807600E+04, 0.17881400E+05, -.14941200E+05, 0.25198700E+05, 0.56058000E+04, -.36552300E+04, -.33427300E+04, -.28027800E+04, -.35540100E+04, -.40739400E+04, 0.77407000E+03, 0.22260700E+04, 0.30987800E+04, -.29473300E+04, -.36825600E+04, -.11148700E+05, 0.50269200E+04, 0.50652200E+04, 0.55744200E+04, 0.12425000E+04, 0.68291300E+04, -.27395900E+04, 0.80479800E+04, 0.70044800E+04, 0.60823400E+04, 0.48979300E+04, -.11052900E+05, 0.61783500E+04, 0.13853000E+04, 0.55265100E+04, 0.46857400E+04, 0.59098600E+04, 0.16962500E+03, -.40343900E+04, -.30846400E+04, 0.44198700E+04, 0.81606600E+04, 0.23198500E+05, -.12191600E+05, -.62425900E+03, -.11599300E+05, -.60735300E+04, -.14016300E+05, 0.87306700E+04, 0.15424400E+05, 0.24483700E+04, -.12922800E+05, -.74537300E+04, -.39046200E+04, 0.31316400E+04, -.11362300E+05, 0.19535100E+04, 0.18200000E+04, 0.25006800E+04, -.19826700E+04, 0.18133300E+04, 0.63955700E+04, 0.99169900E+03, 0.42015700E+04, -.11462500E+05, 0.52710000E+04, 0.11077100E+05, 0.57311500E+04, 0.17126000E+04, 0.67526600E+04, 0.24959700E+04, -.19109300E+04, -.12186600E+04, 0.81662100E+04, -.13805700E+04, -.18587200E+05, 0.84648600E+04, 0.20823100E+04, 0.92936500E+04, 0.95193100E+03, 0.74333500E+04, 0.23882300E+04, 0.32789700E+04, 0.73135200E+04, 0.84743700E+04, -.42173800E+04, -.17621700E+05, 0.93383400E+04, 0.14075700E+03, 0.88108400E+04, 0.31304100E+04, 0.71257700E+04, -.33917200E+04, -.11088300E+05, -.89318900E+03, 0.71342100E+04, 0.52295500E+04, 0.22794900E+05, -.10676100E+05, -.99081000E+04, -.11397600E+05, -.53446600E+04, -.12246200E+05, 0.47245200E+04, -.16829400E+04, -.38937100E+04, -.10856700E+05, -.78563300E+04, 0.34160700E+05, -.17138900E+05, -.10533400E+05, -.17080300E+05, 0.61241500E+04, 0.11772000E+05, -.67837300E+04, 0.14308800E+05, -.15865400E+05, 0.95933300E+04, -.23748300E+05, -.31089300E+04, 0.85808400E+03, -.87900100E+04, 0.15544400E+04, -.16096300E+04, 0.21328900E+04, 0.19451200E+02, -.22547900E+04, 0.36956000E+04, 0.26267800E+04, -.52159200E+04, 0.60914600E+04, -.32066300E+04, -.99496600E+04, -.30457200E+04, -.27299700E+04, -.36106200E+04, 0.64296500E+04, 0.71194400E+04, 0.90203400E+04, -.40043100E+04, -.54722000E+02, 0.89579400E+04, -.48186600E+04, -.59745400E+03, -.44790500E+04, 0.98565900E+03, 0.37437200E+04, -.18480100E+04, 0.23920500E+04, 0.12000100E+04, 0.20930300E+04, 0.28504700E+03, 0.13310300E+04, 0.11603200E+03, -.54348600E+04, -.66566200E+03, -.37083600E+04, -.78874700E+04, 0.31954100E+04, -.37587700E+04, 0.54362700E+04, -.62465900E+04, -.27224200E+04, 0.16594700E+04, -.24129900E+03, 0.37773700E+03, -.52872600E+03, 0.11597200E+04, -.96618700E+04, -.91179700E+04, 0.55427800E+03, -.26379300E+03, 0.99045200E+03, -.44087600E+04, 0.31434000E+04, 0.62515800E+04, 0.10909800E+04, -.71363400E+03, -.12698200E+03, -.38184400E+04, -.15682800E+04, -.25513600E+04, 0.60787900E+04, -.60728300E+04, 0.62984100E+03, -.19975300E+03, -.74343600E+03, -.31640100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44596600E+00, 0.47126300E+00, 0.79646700E+00, 0.30665300E+00, 0.23756400E+00, 0.58139600E-01, 0.22091700E+00, 0.29697900E+00, -.96893400E-01, 0.11454000E+00, 0.75245800E-01, 0.43413200E+00, -.91888900E-01, 0.52321700E+00, -.33676700E+00, 0.76382400E-01, -.83085400E-01, 0.13865800E+00, -.18302200E+00, 0.30754100E+00, 0.58032000E+00, -.81476600E-01, 0.56114100E+00, -.56488200E+00, 0.28670900E-01, 0.35205400E-01, -.53023300E+00, 0.13430900E+00, -.16126700E+00, -.20425800E+00, 0.10648000E+00, -.49878600E+00, -.21449400E+00, -.45732300E+00, -.37631600E+00, -.35593800E-01, 0.13098100E-01, -.30444100E+00, -.80077000E-01, -.88013000E+00, -.11237500E+00, -.65362700E-01, 0.11984100E+04, -.16205600E+04, -.24751400E+05, 0.12323000E+05, 0.10951400E+05, 0.12375700E+05, 0.30688700E+04, 0.51859400E+04, 0.61176300E+04, 0.60208500E+03, 0.80833800E+04, 0.44266600E+04, 0.56127600E+04, 0.26961600E+05, -.13513200E+05, -.88625700E+04, -.13480900E+05, -.36943600E+04, -.94168800E+04, -.42556600E+04, 0.86209300E+03, -.92846500E+04, -.71734200E+04, -.86185900E+04, 0.56006000E+03, -.57640700E+03, 0.59953200E+04, -.27921800E+03, -.20315300E+03, 0.74982100E+03, 0.77416500E+02, -.11914500E+04, -.30107800E+04, 0.92547500E+03, -.91006900E+03, -.17646900E+04, 0.12409000E+04, 0.89811100E+03, 0.88211300E+03, 0.16736200E+03, 0.50567500E+03, -.18965000E+03, -.11894500E+04, -.14685800E+03, 0.53915500E+03, 0.78273300E+03, -.33615800E+04, 0.17004400E+04, 0.45877700E+04, 0.16802000E+04, 0.99030900E+03, 0.18671800E+04, 0.10241800E+04, -.12669800E+04, -.12762800E+04, 0.24375000E+04, -.24744200E+04, -.28542600E+04, 0.13668400E+04, -.50925900E+04, 0.14272300E+04, -.25970500E+04, -.97119700E+04, 0.79854500E+03, -.48208200E+04, 0.13950600E+04, -.79360200E+04, 0.26756900E+04, 0.42470700E+04, -.24572700E+04, -.76496300E+03, -.21237000E+04, -.68241000E+03, -.66510100E+03, -.69688200E+03, 0.68675800E+03, -.93841800E+03, -.47222900E+03, -.10203100E+04, -.52550300E+04, 0.28790700E+04, 0.14354900E+04, 0.26274300E+04, 0.12393300E+04, 0.15424200E+04, -.39804000E+03, 0.12290900E+04, 0.18518500E+04, 0.19351900E+04, 0.19056900E+04, -.69843000E+04, 0.37235000E+04, -.25295500E+03, 0.34920200E+04, 0.10854100E+04, 0.12206800E+04, 0.14816100E+04, -.93271700E+03, 0.10282300E+04, 0.10626500E+04, 0.19116500E+04, 0.56605400E+04, -.25646700E+04, 0.83422500E+04, -.28302700E+04, -.12968700E+04, -.16675800E+04, 0.32314700E+04, 0.55062300E+04, -.20657000E+03, -.84957200E+03, -.56091200E+04, -.38269700E+04, 0.24175000E+04, -.58320700E+04, 0.19119000E+04, 0.93681500E+03, -.53069100E+02, -.17967500E+03, -.14902500E+03, 0.30581400E+04, -.31344400E+03, 0.23249100E+04, -.72539000E+04, 0.38953300E+04, 0.71713400E+04, 0.36274500E+04, 0.22924800E+04, 0.27804900E+04, 0.16452800E+04, -.68540300E+03, 0.73207600E+03, 0.37051200E+04, 0.12595700E+04, -.17075800E+05, 0.88501400E+04, 0.78533900E+04, 0.85378600E+04, 0.24023800E+04, 0.48707400E+03, 0.60476500E+04, 0.31817900E+04, 0.42694700E+04, 0.12874800E+04, 0.38948800E+04, -.86538100E+04, 0.41131500E+04, -.58892300E+04, 0.43269100E+04, 0.10061600E+04, -.92638400E+02, -.65158300E+03, -.40345500E+04, 0.26504100E+04, -.48983200E+03, 0.63779300E+04, 0.13080700E+05, -.68755900E+04, -.23432900E+04, -.65401000E+04, -.30319200E+04, -.28104600E+04, 0.26673800E+03, 0.36317700E+03, -.36247800E+04, -.23151400E+04, -.44791500E+04, 0.12013200E+05, -.61145500E+04, 0.60323600E+03, -.60066300E+04, 0.85496300E+03, 0.87125400E+04, -.35355100E+04, 0.54995700E+04, -.30002000E+04, 0.62940200E+04, -.36518800E+04, -.15056400E+03, 0.26085000E+03, -.30528100E+04, 0.75319900E+02, -.69543800E+01, 0.12124500E+04, -.26104600E+03, -.12469600E+04, -.14955800E+04, 0.15219500E+03, 0.16402400E+04, -.59071900E+04, 0.28714400E+04, 0.12355800E+04, 0.29535800E+04, 0.30924400E+03, 0.14212100E+04, 0.29425800E+04, 0.19026000E+04, 0.32173700E+04, 0.24460800E+04, 0.89521000E+03, 0.18841400E+03, 0.54401400E+02, 0.18623600E+04, -.94096200E+02, 0.10453000E+04, 0.32355300E+04, -.11812500E+04, 0.20150700E+03, 0.26734000E+02, 0.28524000E+04, -.49738700E+03, 0.29964800E+04, -.14531300E+04, -.31961700E+04, -.14980300E+04, -.11337700E+04, -.39196300E+04, 0.33159400E+03, -.11219600E+04, -.39919600E+03, -.42224700E+04, 0.21905100E+04, -.28834900E+03, 0.25063900E+03, -.40093200E+03, -.14212400E+03, -.38488900E+03, -.44012400E+04, -.44057000E+04, 0.44797800E+03, 0.39955100E+03, -.25046100E+03, -.30730400E+04, 0.50977300E+03, 0.16056300E+04, 0.11849000E+03, -.77254900E+03, 0.12274000E+03, -.22539500E+04, -.28264900E+03, -.16170800E+04, 0.11522200E+04, -.44107100E+04, -.27701500E+02, 0.11498700E+03, 0.10713700E+03, -.30589500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.98258900E+00, -.19840200E+00, -.66030700E+00, 0.69882800E+00, -.14469900E+01, -.17074600E+00, 0.10822700E+00, 0.15373700E+01, 0.26204600E+01, 0.44293500E+00, -.53662200E+00, -.46599500E+01, 0.18313300E+01, 0.38125100E+00, -.10945700E+01, 0.19356400E+01, 0.22873200E+01, -.32336800E+00, -.50908900E+00, 0.98710600E+00, 0.18623200E+01, 0.12709800E+00, 0.69795800E-01, 0.14351500E+01, 0.61478500E-01, -.32117500E-01, 0.57857700E+00, 0.26102400E+00, -.47446300E+00, -.87279100E+00, -.76895300E+00, 0.43958600E+00, 0.14142200E+00, 0.17064700E+00, 0.58522700E+00, 0.42794600E+00, 0.42834900E-01, -.11385400E+00, -.89897000E-01, -.10526900E+01, 0.27520100E+00, 0.88951100E-02, 0.13814800E+01, -.16082500E+05, -.17780800E+05, 0.87711500E+04, 0.68101300E+04, 0.88904300E+04, -.33142400E+04, -.47305500E+04, 0.69278100E+04, -.11842300E+04, 0.50146600E+04, -.55260100E+04, 0.24206600E+05, 0.39474300E+05, -.20167400E+05, -.27794800E+05, -.19737000E+05, 0.40773700E+04, 0.36196900E+04, -.10545100E+05, 0.39655900E+04, -.12223700E+05, 0.52239400E+04, -.46264100E+05, 0.46126800E+04, -.13053200E+04, -.74443700E+04, -.23078500E+04, -.11760800E+04, -.33022000E+04, 0.86820800E+03, 0.41844800E+04, 0.39534600E+04, -.35811900E+04, -.61018700E+02, 0.16014800E+04, -.14688000E+04, -.45002100E+03, -.80027600E+03, -.10937800E+04, -.30014300E+04, 0.19540600E+04, 0.21655300E+04, 0.14261000E+04, -.21045400E+04, -.25033300E+04, -.55594500E+04, 0.26489500E+04, 0.12374000E+03, 0.27807900E+04, 0.25365000E+04, 0.11593200E+04, 0.18651200E+03, -.11840700E+04, 0.14373600E+04, 0.10648200E+04, 0.83521100E+04, 0.30548400E+05, -.15609600E+05, -.13497900E+05, -.15274400E+05, 0.52369600E+04, 0.13927200E+05, -.11407900E+05, 0.58769700E+04, -.87488900E+04, 0.13643800E+05, -.45058600E+05, -.66482300E+04, 0.39060200E+04, 0.10018500E+03, 0.33244200E+04, 0.15368100E+04, 0.14676600E+04, -.83053800E+03, -.31418300E+04, 0.12416500E+04, 0.67653600E+03, 0.56014900E+04, 0.32891200E+05, -.14938300E+05, -.50055900E+04, -.16445400E+05, -.29016700E+04, -.99236800E+04, 0.26259700E+04, 0.10055500E+05, -.76845500E+04, -.79233300E+04, -.17421700E+05, 0.14947000E+05, -.78782500E+04, -.20890400E+04, -.74732600E+04, -.31353300E+04, -.39568100E+04, 0.15643300E+04, 0.59227600E+04, -.19012600E+04, -.29969100E+04, -.12396500E+05, -.32959800E+05, 0.18039100E+05, 0.64798800E+04, 0.16479900E+05, -.29732900E+04, -.53952500E+04, 0.42834400E+04, -.71874500E+04, 0.11158100E+05, -.61707400E+04, 0.43252000E+04, 0.26925700E+04, -.32009700E+04, 0.55329100E+04, -.13433100E+04, -.61412600E+03, 0.84117700E+03, 0.41696400E+03, -.14142500E+04, -.41707900E+04, 0.16897900E+04, -.32963500E+04, 0.58128200E+04, -.14863100E+04, -.79920600E+04, -.29072600E+04, -.21986400E+04, -.10378200E+05, 0.52987600E+04, 0.28677900E+04, -.10797200E+04, -.10389500E+05, 0.72454500E+04, -.32965800E+05, 0.18540600E+05, -.14085300E+04, 0.16483000E+05, 0.17968200E+04, -.67476000E+04, 0.59978200E+04, -.53325800E+04, 0.17128000E+05, -.80003100E+04, 0.34770400E+05, 0.29657100E+05, -.16156700E+05, -.46904000E+04, -.14828600E+05, 0.12924400E+04, 0.47722600E+04, -.42132500E+04, 0.59097400E+04, -.10852600E+05, 0.49954200E+04, -.38496100E+04, -.45882900E+05, 0.20930000E+05, 0.54270500E+04, 0.22941000E+05, 0.46332000E+04, 0.10877100E+05, -.51110200E+04, -.13356500E+05, 0.12009100E+05, 0.81324200E+04, 0.21815000E+05, -.65590600E+05, 0.32447600E+05, 0.23818300E+05, 0.32795400E+05, -.27383700E+04, -.47664500E+04, 0.98077100E+04, -.11569100E+05, 0.23000300E+05, -.54794600E+04, 0.56541600E+05, -.64348600E+04, 0.48284100E+04, 0.30240300E+04, 0.32173600E+04, 0.25508400E+04, -.28834200E+03, 0.96438800E+03, -.19497800E+04, 0.45422000E+04, -.13561700E+04, 0.17164500E+05, -.16031900E+05, 0.81112100E+04, -.95582500E+03, 0.80159800E+04, -.72024800E+03, -.31746400E+04, 0.23855600E+04, -.17037600E+04, 0.70776000E+04, -.40123300E+04, -.17948200E+04, 0.63633600E+04, -.23049800E+04, -.11638000E+04, -.31818700E+04, -.18473600E+04, -.42027700E+04, 0.28196700E+04, 0.40761100E+04, -.78003700E+03, -.39909400E+04, -.12252000E+05, -.77467000E+04, 0.26350800E+04, -.51967400E+03, 0.38729600E+04, 0.45386800E+03, 0.38867500E+04, -.28711600E+04, -.53688200E+04, 0.17277000E+04, 0.25540600E+04, 0.15071300E+05, 0.23086200E+04, -.10478500E+04, 0.25745700E+04, -.32144100E+02, 0.17237300E+04, 0.40259000E+04, 0.41469800E+04, -.55460700E+03, -.25085400E+04, 0.15121600E+04, 0.58212300E+04, -.29624900E+04, -.27450700E+04, -.86934300E+03, 0.17620700E+04, -.37590800E+03, 0.79308800E+04, -.12609900E+04, 0.22937300E+04, -.83478300E+03, 0.50500900E+04, 0.33875700E+04, -.19372700E+04, -.15649300E+04, -.15293400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.95173800E+00, -.37459500E+00, -.51504000E+00, 0.16843200E+01, -.30392700E+00, -.20641900E+00, -.15652300E+01, -.56848400E+00, 0.35100100E+01, 0.88732400E+00, 0.65027000E-01, -.17195700E+00, 0.84134900E+00, 0.87612300E+00, -.52250900E+00, 0.60835300E+00, 0.14321200E+00, -.10344400E+01, -.35918100E-01, -.17715500E+01, 0.93437800E-01, -.46959800E-02, 0.41890200E+00, -.53046300E+00, 0.12540800E+00, -.59926500E-01, -.17294900E+01, 0.23232900E+00, -.44630500E+00, 0.91691100E+00, -.76496200E+00, 0.83734400E+00, 0.90660100E-01, -.21217900E+01, 0.10689700E+01, 0.11084700E+01, 0.35729800E-01, 0.81312800E+00, -.52059400E+00, -.95369600E+00, -.96051900E+00, -.63770500E+00, 0.83382700E+00, -.45012200E-01, -.51749500E+05, 0.25814800E+05, 0.14369200E+05, 0.25874700E+05, 0.32867000E+04, 0.11971000E+05, 0.61140900E+04, -.91895600E+04, 0.15883000E+05, 0.89240300E+04, 0.19300000E+05, 0.39501400E+05, -.19771600E+05, -.94484300E+04, -.19750800E+05, -.57339900E+04, -.17918900E+05, -.29577300E+04, 0.79152700E+04, -.96285000E+04, -.13972900E+05, -.13750100E+05, 0.26787800E+04, -.12460600E+04, -.47093800E+03, -.13385400E+04, -.20111200E+04, -.34590500E+04, 0.28422400E+04, 0.19054300E+04, 0.75951600E+03, -.26880500E+04, -.21421100E+04, -.19974400E+04, 0.13068000E+04, 0.26756000E+04, 0.99860500E+03, 0.28687700E+02, -.43453400E+03, 0.36558500E+03, -.10996700E+04, 0.58976700E+03, -.22059600E+03, 0.52338000E+03, -.49220100E+04, 0.24432200E+04, -.89822900E+03, 0.24604000E+04, -.34252900E+03, 0.75777300E+04, -.21092700E+04, -.44800100E+04, 0.65709600E+03, 0.55536200E+04, 0.27941700E+04, -.78604900E+04, 0.38990900E+04, -.96889500E+04, 0.39303600E+04, 0.12208300E+03, -.10507900E+05, 0.50778100E+03, -.47495200E+04, 0.34802700E+04, -.73172200E+04, 0.67530600E+04, 0.61820600E+04, -.34106400E+04, -.51506800E+04, -.30911700E+04, -.88538300E+03, -.22027200E+04, -.48267300E+03, 0.21207500E+04, -.96530500E+03, -.21197200E+04, -.17163700E+04, 0.58948100E+04, -.27727400E+04, 0.83795800E+04, -.29474900E+04, -.11436900E+03, 0.19271500E+04, -.18556500E+04, 0.85586800E+03, -.31557900E+04, 0.90797000E+03, -.20989600E+04, -.79929300E+04, 0.42121400E+04, 0.46495600E+04, 0.39963600E+04, 0.79000600E+03, 0.23514100E+04, 0.16332300E+04, -.14179100E+04, 0.28461300E+04, 0.22876000E+04, 0.21671900E+04, 0.21254900E+05, -.10362900E+05, -.35028700E+04, -.10627400E+05, -.56393000E+04, -.83968300E+04, 0.21833900E+04, 0.60157200E+04, -.30498000E+04, -.78640000E+04, -.11177800E+05, -.38112500E+04, 0.18185800E+04, 0.14135000E+04, 0.19040700E+04, 0.24944200E+04, 0.42969700E+04, -.31201200E+04, -.26237600E+04, -.23032500E+03, 0.34432300E+04, 0.24891000E+04, -.12878500E+05, 0.66337100E+04, 0.90241800E+04, 0.64392900E+04, -.15069800E+04, 0.36681900E+04, 0.27574800E+04, -.14458200E+04, 0.61242600E+04, 0.20589600E+04, 0.53434400E+04, -.29545700E+05, 0.15009600E+05, -.55938400E+04, 0.14772800E+05, -.36043700E+04, 0.59954400E+04, 0.35343600E+04, -.33382800E+03, 0.14949700E+05, 0.15497600E+04, 0.16255300E+05, -.16402400E+05, 0.80073800E+04, 0.40028700E+04, 0.82012000E+04, 0.38113700E+04, 0.50764900E+04, -.23346500E+03, -.48121200E+04, 0.31870000E+04, 0.49921700E+04, 0.87025700E+04, 0.10534000E+05, -.55048300E+04, -.11202700E+05, -.52667800E+04, -.35666500E+04, -.10308200E+05, 0.43543500E+04, 0.59105000E+04, -.37526900E+03, -.75955500E+04, -.51252800E+04, 0.19573700E+05, -.98638900E+04, -.75971500E+04, -.97868700E+04, 0.16188400E+04, 0.74672300E+04, -.28413300E+04, 0.83868300E+04, -.68388000E+04, 0.55462200E+04, -.10117600E+05, -.89304400E+04, 0.46245500E+04, -.77574000E+04, 0.44652500E+04, -.33205200E+04, 0.28425000E+04, -.63592100E+03, -.18623100E+04, 0.49132900E+04, 0.10041000E+03, 0.72844400E+04, 0.41039100E+03, -.22648400E+03, -.98042400E+04, -.20521100E+03, -.17997600E+04, 0.92342000E+03, 0.11034400E+04, 0.14070800E+04, 0.36041700E+04, -.36552500E+02, -.16418200E+03, 0.39928700E+04, -.18653600E+04, 0.11297900E+04, -.19963100E+04, 0.17795900E+04, 0.26113800E+04, -.13400400E+04, 0.92732300E+03, -.13044100E+04, 0.21051100E+04, -.31765500E+04, -.96825900E+03, 0.48509500E+03, -.46352500E+04, 0.48433300E+03, -.35103700E+04, -.93913000E+04, 0.43451700E+04, 0.31128200E+04, 0.32805800E+04, -.82888500E+04, 0.28505000E+04, 0.12817500E+04, -.12206700E+04, -.78114400E+03, -.14654000E+04, 0.20934300E+04, -.62898400E+04, -.81174700E+04, -.69195500E+03, 0.85634300E+03, 0.22745300E+04, -.23232300E+04, 0.22726100E+04, 0.16907800E+04, 0.15139800E+04, 0.53642900E+03, -.12824200E+04, -.10509400E+04, -.13014000E+04, -.26006700E+03, 0.39410600E+04, -.30420100E+04, 0.33850800E+03, -.94060700E+03, -.10875500E+04, -.14239400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.75817900E+00, -.29041600E+00, -.65034600E+00, 0.12591000E+01, -.92545000E+00, -.24831200E+00, -.71201600E+00, -.43416400E+00, 0.23893300E+01, 0.71017300E+00, 0.12780200E+00, -.19101800E+01, 0.15963600E+01, 0.10442700E+01, -.81820700E+00, 0.16412600E+01, 0.11666600E+01, -.47190300E+00, -.68875800E+00, 0.26528000E+00, 0.11811400E+01, 0.63370600E-02, 0.30597000E+00, -.37542100E+00, 0.51862200E-01, -.19225400E-01, -.11389500E+00, 0.15424700E+00, -.38192500E+00, 0.36141400E+00, -.69408800E+00, 0.10622700E+01, 0.17016400E+00, -.62578500E+00, 0.97405000E+00, 0.11941500E+01, 0.43711600E-01, 0.30307400E+00, -.36044100E+00, 0.89475900E-01, -.44966300E+00, -.40166000E+00, -.16772100E+00, -.28452500E+00, 0.78402800E+00, -.12886000E+03, 0.29789300E+04, 0.29237000E-01, -.21744400E+04, -.71916900E+04, 0.56135300E+04, 0.36223300E+04, -.15407000E+03, -.63247900E+04, 0.32675900E+04, 0.26801600E+05, -.13757800E+05, -.24185400E+05, -.13400500E+05, 0.12891900E+04, 0.73523800E+04, -.91908400E+04, 0.20218800E+04, -.98965900E+04, 0.70424700E+04, -.15072700E+05, -.11303400E+04, 0.80230400E+03, 0.19470400E+04, 0.56301500E+03, 0.10586000E+04, 0.94316900E+03, -.12051500E+04, -.16090200E+04, -.62041200E+03, 0.73733600E+03, 0.54591100E+03, 0.39976100E+04, -.19621800E+04, -.11144400E+04, -.19983200E+04, -.77068500E+03, -.11668100E+04, 0.57478700E+03, 0.21894400E+04, -.94810100E+03, -.10429800E+04, -.13058000E+04, -.55090300E+04, 0.26695000E+04, 0.42113100E+04, 0.27560600E+04, 0.96341400E+02, -.23623800E+04, 0.31387500E+04, 0.20534800E+04, 0.85882000E+03, -.55858900E+03, 0.27115300E+03, 0.35774700E+05, -.18175900E+05, -.13804900E+05, -.17887600E+05, 0.17519100E+03, 0.10272500E+05, -.11196800E+05, 0.45692500E+04, -.10789900E+05, 0.90341400E+04, -.15088100E+05, -.10057700E+05, 0.49659400E+04, 0.31452200E+04, 0.50292300E+04, 0.67432900E+03, 0.15094600E+04, 0.13292000E+04, -.98660300E+03, 0.37735000E+04, 0.17151800E+04, 0.28481300E+04, 0.13375700E+05, -.54063500E+04, -.55933500E+04, -.66876300E+04, 0.10327800E+04, -.41898100E+04, 0.23860600E+04, 0.82715800E+04, -.27951500E+04, -.23948500E+04, -.67643800E+04, 0.16111700E+05, -.80435300E+04, -.59553200E+04, -.80555500E+04, -.92291200E+03, -.26945300E+04, -.20030400E+04, 0.54958800E+03, -.67298200E+04, -.28070100E+04, -.48595300E+04, -.41504300E+05, 0.22087000E+05, 0.12750000E+05, 0.20752200E+05, -.20608600E+04, -.94169800E+03, 0.62304300E+04, -.51733700E+04, 0.13964400E+05, -.11354800E+04, 0.22835300E+05, 0.58647800E+04, -.34479000E+04, -.33119900E+04, -.29282900E+04, -.19236400E+04, -.25306100E+04, 0.19651200E+04, 0.31327700E+04, -.60570200E+03, -.20423800E+04, -.24881800E+04, 0.80215100E+04, -.27345400E+04, -.62200900E+04, -.40116300E+04, -.69470100E+03, -.89370800E+04, 0.42484000E+04, 0.30704700E+04, -.53379000E+04, -.67131200E+04, -.56345800E+04, -.25933600E+05, 0.14728000E+05, 0.90745600E+04, 0.12966900E+05, 0.18210000E+04, -.84942700E+04, 0.81387900E+04, 0.78591700E+02, 0.98054400E+04, -.56588400E+04, 0.59499900E+04, 0.30885900E+05, -.16571200E+05, -.87766100E+04, -.15443000E+05, 0.11505100E+04, 0.62544800E+03, -.43944200E+04, 0.45942000E+04, -.10512100E+05, 0.83538000E+03, -.16718800E+05, -.30281000E+05, 0.13415000E+05, 0.55141700E+04, 0.15139900E+05, 0.21125200E+04, 0.10669400E+05, -.61338300E+04, -.14520900E+05, 0.88990600E+04, 0.72260400E+04, 0.14798500E+05, -.66809800E+05, 0.33049700E+05, 0.29483400E+05, 0.33405000E+05, 0.16358100E+04, -.11489500E+04, 0.90660300E+04, -.11516600E+05, 0.25130500E+05, -.24377300E+04, 0.30549700E+05, -.56762500E+04, 0.41599000E+04, 0.42813900E+04, 0.28380300E+04, 0.15276500E+04, -.23109100E+04, 0.19762900E+04, -.16612700E+04, 0.15487700E+04, -.69757100E+03, -.23187000E+04, -.25885200E+05, 0.12881800E+05, 0.93125500E+04, 0.12942600E+05, -.58129200E+02, -.18773200E+04, 0.51920200E+04, -.94993600E+03, 0.96959500E+04, -.17351300E+04, 0.12969500E+05, 0.60195500E+04, -.22380700E+04, -.35979300E+03, -.30100700E+04, -.10048100E+04, -.14543400E+04, 0.10023200E+04, 0.21838300E+04, -.14574700E+04, -.17794300E+04, -.84469300E+03, -.62303200E+04, 0.23733200E+04, -.95974800E+03, 0.31146200E+04, 0.26372200E+04, 0.53009400E+04, -.37492200E+04, -.72562500E+04, 0.10793700E+04, 0.44549800E+04, 0.77046800E+02, 0.16450300E+04, -.31301700E+03, 0.18644500E+04, -.10331000E+03, 0.61894300E+02, 0.30585500E+04, 0.36364100E+04, -.49110400E+03, -.18556200E+04, 0.59115300E+03, 0.33000100E+04, -.53394600E+03, -.10901600E+04, 0.10902600E+03, -.10609200E+04, -.21033400E+03, 0.49740000E+04, 0.42202400E+02, -.29537100E+03, -.12365000E+04, 0.13516000E+04, 0.17203100E+04, 0.22363000E+02, -.92887000E+03, -.16321500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.55761200E+00, -.45446100E+00, 0.11563300E+01, 0.14726600E+01, 0.72632200E+00, -.95062600E-01, -.53417800E+00, 0.10065900E+01, 0.21129400E+01, 0.50763700E+00, -.14441800E-01, -.10239600E+01, 0.23003300E+01, 0.76198100E+00, 0.36969800E-01, 0.12466500E+01, 0.81580900E+00, -.87803700E+00, -.22149500E-01, -.16262500E+01, 0.73995100E+00, 0.55530000E-01, 0.73877600E-02, -.35565100E+00, -.16610100E+00, 0.21493400E-01, 0.12789200E+00, 0.72195700E-01, -.98593800E-01, 0.16060100E+01, 0.57590400E+00, 0.93051400E-01, 0.66901100E+00, 0.65062000E+00, -.22663100E+00, 0.45198100E+00, 0.42472700E-01, -.23064400E+00, 0.72420000E-01, -.41013300E+00, 0.24180500E+00, 0.34138500E+00, -.12755500E-02, 0.45568700E-01, -.19024400E+00, -.24800500E+00, 0.11542200E+05, 0.33232700E-01, -.18592100E+04, -.21830100E+04, 0.47184600E+04, 0.26933800E+04, -.15059900E+04, -.99928100E+03, -.18377600E+04, -.40572000E+03, 0.61542300E+02, -.13467500E+05, 0.20315600E+03, 0.27730200E+04, 0.38800900E+04, -.66875500E+04, -.31985300E+04, 0.13995100E+04, 0.23955600E+04, 0.10732000E+04, 0.58713100E+04, -.24536600E+04, -.29185400E+04, -.29380400E+04, 0.37708000E+03, -.18121700E+03, -.16884600E+04, -.45254700E+03, -.25791800E+04, 0.17794000E+02, -.24254100E+04, -.13102900E+04, 0.30313200E+03, 0.91543200E+01, 0.65568100E+03, -.80420100E+03, -.10084700E+04, 0.94592300E+03, 0.85269200E+03, 0.13589300E+04, -.65600400E+03, 0.12184500E+04, -.28457700E+04, 0.13736100E+04, 0.32900200E+04, 0.14246200E+04, 0.18275200E+04, 0.10939400E+04, 0.83239200E+03, 0.18791100E+04, 0.30675200E+02, 0.10297700E+04, -.13398300E+04, 0.11919900E+05, -.60305000E+04, -.25991900E+04, -.59602600E+04, -.97109400E+03, -.62602300E+04, -.39546000E+02, 0.26943900E+04, -.27573000E+04, -.62163700E+04, -.27134300E+04, -.40545000E+04, 0.23273400E+04, 0.19569300E+04, 0.20277000E+04, 0.49257400E+03, 0.10728600E+04, 0.12595800E+03, -.40023600E+03, 0.37127300E+03, 0.12633800E+04, 0.30069400E+03, -.15504700E+05, 0.80707500E+04, -.48973100E+04, 0.77526100E+04, 0.33064700E+03, 0.21128400E+04, 0.16391200E+03, 0.30164600E+03, 0.10116200E+05, 0.23772900E+04, 0.85677400E+04, 0.72546800E+04, -.38373100E+04, -.27505000E+04, -.36270100E+04, -.67725000E+03, -.18156000E+04, -.13184300E+03, 0.73194700E+03, -.17301300E+04, -.19673800E+04, -.14720300E+04, -.11239800E+05, 0.59456100E+04, 0.20946000E+04, 0.56198800E+04, 0.38701100E+04, 0.58104100E+04, 0.35213200E+03, -.61362000E+03, 0.12691200E+04, 0.33671700E+04, 0.57524400E+04, -.45327300E+04, 0.14391700E+04, 0.29199300E+04, 0.22709100E+04, -.12672600E+04, -.13163200E+04, 0.27026800E+04, 0.17894100E+04, 0.29884300E+04, -.12171500E+04, 0.19486700E+04, -.38197500E+04, 0.22199400E+04, 0.38033500E+04, 0.19105000E+04, -.10008900E+03, 0.82873300E+03, 0.53631800E+03, -.22969600E+04, -.92628400E+03, 0.20054600E+04, -.30741600E+04, 0.85101800E+04, -.37655800E+04, 0.10775400E+05, -.42549700E+04, 0.70803000E+03, 0.13932200E+04, -.18587200E+04, 0.18474300E+03, -.59121000E+04, 0.31469500E+04, -.10241800E+05, 0.25276700E+04, -.15563800E+04, 0.60756500E+03, -.12638700E+04, -.28862000E+04, -.54986200E+04, 0.12718000E+04, 0.69292800E+03, 0.72287500E+03, -.32466900E+04, -.19787200E+04, 0.23512900E+04, -.16138000E+04, 0.11826200E+04, -.11763600E+04, 0.35729000E+04, 0.57187600E+04, -.58274500E+04, -.82697400E+04, -.72390500E+04, 0.46572600E+04, -.23743100E+04, 0.95642200E+03, -.51819300E+03, 0.44094900E+04, -.47812800E+03, 0.99789500E+03, 0.61215600E+04, -.26975900E+04, -.12733100E+04, -.11241700E+04, 0.56609200E+04, 0.97639200E+03, 0.56200700E+04, -.23888300E+04, 0.25982200E+04, -.28101400E+04, 0.15415300E+04, 0.37543900E+02, -.72346000E+03, -.12102500E+03, -.38566800E+04, 0.40933300E+03, -.71906700E+04, -.21481800E+04, 0.11147700E+04, 0.46777300E+04, 0.10741400E+04, 0.44537200E+03, 0.20905900E+04, 0.96022400E+03, 0.76449900E+03, -.15243900E+04, 0.14584600E+04, 0.41246700E+03, 0.26638800E+04, -.11369700E+04, 0.66266500E+03, -.13322800E+04, -.12390700E+04, -.43523100E+03, 0.82715100E+03, 0.76376600E+03, -.33036300E+03, -.64809400E+03, -.29681300E+03, -.10634600E+04, 0.16565500E+03, -.18323700E+03, 0.53112300E+03, 0.16929200E+04, 0.47310800E+03, -.18712100E+04, -.36547900E+04, -.17600200E+04, 0.83243600E+03, -.17795300E+04, 0.22192400E+03, 0.30671500E+03, 0.11690600E+04, 0.75275100E+03, -.51980300E+03, -.10247500E+03, 0.22461600E+04, 0.43305700E+03, -.12467600E+04, 0.46506700E+02, -.13663100E+04, -.13430900E+04, 0.82512100E+03, -.94793500E+03, -.18837600E+04, 0.59512200E+03, -.95270500E+03, -.14589200E+04, -.13806600E+04, -.80651400E+03, -.32991300E+04, 0.70874100E+03, 0.12379300E+03, 0.21550300E+03, -.82436400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18335000E+01, -.58115600E+00, -.14960200E+01, 0.30319200E+01, -.74113000E+00, -.36408200E+00, -.28909600E+01, -.38983500E+01, 0.36534000E+01, 0.97022300E+00, 0.22860900E+00, 0.15000000E+01, -.13704900E+01, 0.24141100E+00, -.12953100E+01, -.21039100E+01, -.76949500E+00, 0.10495700E+01, 0.75564900E+00, -.19860100E-02, -.10191000E+01, -.24041100E+00, 0.88152500E+00, 0.75557500E+00, 0.23561000E+00, 0.33433600E+00, -.15363900E+01, -.19511500E+00, 0.99900400E-01, 0.63620300E+00, -.44729800E-02, -.98670200E+00, 0.42211600E+00, -.22992900E+00, -.57782300E+00, -.46306000E+00, -.25186400E-01, 0.50991900E+00, -.62715900E+00, -.89867600E+00, -.43005500E+00, -.25180300E+00, 0.13925300E+01, 0.14866900E+00, 0.56922300E+00, -.16705900E+00, 0.35852100E+00, 0.55126700E+01, 0.16943700E+04, -.40148500E+03, -.78389600E+03, 0.17083700E+03, -.70238300E+03, -.47679300E+03, -.43375600E+04, 0.43854300E+04, -.22026600E+04, 0.26878000E+04, -.21932500E+04, -.31214500E+03, 0.44499400E+03, 0.98048600E+03, 0.63385100E+03, -.16147500E+04, 0.75065100E+03, 0.27901400E+04, -.36761700E+04, 0.18636200E+04, -.10700600E+04, 0.18423500E+04, -.45916800E+03, 0.18613100E+03, 0.97160200E+03, 0.72713200E+03, 0.23877400E+04, -.58696100E+02, 0.53519300E+03, -.65910500E+03, 0.19063500E+03, -.19515100E+04, 0.32861700E+03, 0.34718500E+03, 0.12784300E+03, -.35895200E+03, -.73647000E+03, 0.49287500E+02, 0.44036400E+02, -.32179600E+03, -.74283300E+03, 0.40804600E+03, -.87113400E+03, 0.36829000E+03, 0.51783800E+03, -.46493200E+04, 0.19810200E+04, 0.15987400E+04, 0.11849900E+04, -.39337200E+04, -.77763300E+03, -.32076000E+04, 0.15758600E+04, 0.47060400E+04, 0.16043600E+04, 0.12462900E+02, 0.48820300E+03, 0.10801200E+04, -.88721600E+03, -.40184700E+03, 0.91867600E+03, 0.21599800E+04, 0.21996000E+04, -.94883800E+03, 0.44691300E+03, -.11005900E+04, 0.89011100E+03, 0.90946700E+03, -.14669800E+04, -.15936900E+04, -.16953900E+04, 0.84003100E+03, 0.14740600E+04, -.41769700E+04, 0.21707500E+04, -.37140800E+04, 0.20880700E+04, 0.11198500E+04, 0.23921900E+03, -.22824400E+02, -.34518600E+04, -.77934200E+03, 0.30320600E+03, 0.36190700E+04, -.26131600E+04, 0.12149500E+04, 0.34172300E+03, 0.13059800E+04, -.10394300E+04, -.74196000E+03, 0.18230600E+04, 0.26849700E+04, 0.21620100E+04, -.71736000E+03, -.24734600E+04, 0.11778100E+05, -.58509100E+04, 0.36774600E+03, -.58890600E+04, 0.12324900E+04, 0.20907700E+04, -.27670800E+04, 0.13572300E+04, -.47038300E+04, 0.26015900E+04, -.77719100E+04, 0.14348600E+04, -.80615600E+03, 0.24066300E+03, -.72554500E+03, 0.70151100E+03, 0.60603800E+02, -.99773700E+03, -.11903600E+04, -.18047400E+04, 0.14741400E+03, 0.20938100E+03, 0.52560800E+04, -.25883400E+04, -.26261900E+04, -.26286500E+04, 0.14439800E+04, -.23341800E+03, -.11350900E+04, 0.18456700E+04, 0.25485600E+02, -.23482900E+03, -.13876500E+04, 0.12134600E+05, -.60074600E+04, 0.28457700E+04, -.60675300E+04, 0.31715500E+04, -.14311900E+04, -.15215300E+04, 0.13056100E+04, -.60014600E+04, -.69961800E+03, -.27568200E+04, -.97513100E+04, 0.48324800E+04, -.52476700E+03, 0.48757100E+04, -.59737200E+03, -.11737500E+04, 0.18737200E+04, -.97087500E+03, 0.41947500E+04, -.15704600E+04, 0.58922300E+04, 0.43371400E+04, -.22596500E+04, 0.64386800E+04, -.21672900E+04, -.14370200E+04, 0.25482500E+03, 0.99129000E+03, 0.40360500E+04, -.12901600E+03, 0.21548600E+03, -.33627700E+04, 0.28676600E+04, -.14313200E+04, -.14384500E+04, -.14339800E+04, -.13919700E+04, -.12487500E+03, -.66563800E+03, -.21922300E+03, -.10880000E+04, -.37148200E+03, -.29072300E+04, 0.31774900E+04, -.15605800E+04, 0.54691700E+03, -.15885500E+04, 0.95102700E+03, -.16983400E+04, -.36560300E+03, 0.33998300E+03, -.22949600E+04, -.11160200E+04, 0.28734000E+04, 0.42731100E+04, -.21257300E+04, 0.19950500E+04, -.21366400E+04, 0.13697400E+04, 0.73130300E+03, -.12883500E+04, 0.12566800E+03, -.18318000E+04, 0.12328900E+04, -.32492200E+04, -.36789400E+04, 0.18517800E+04, -.76990300E+03, 0.18400900E+04, 0.94110500E+02, 0.10872400E+04, -.42847400E+03, -.13490000E+04, 0.98981500E+03, 0.98042700E+03, 0.13416800E+04, 0.26244100E+04, -.13944800E+04, 0.30899100E+04, -.13111100E+04, -.58762600E+03, 0.18216400E+04, -.94944900E+03, 0.50006600E+03, -.21468900E+04, 0.16123100E+04, 0.25837400E+04, -.76390700E+03, 0.69530900E+03, -.63370500E+03, 0.41832200E+03, -.94548800E+03, 0.10292100E+04, 0.62289400E+03, 0.68884200E+03, 0.64908000E+03, -.13478000E+04, -.10156700E+04, -.16374200E+04, 0.66710700E+03, -.84154600E+03, 0.26753800E+03, 0.57875600E+03, -.16853800E+04, 0.10107100E+04, 0.72186000E+02, -.53168500E+03, -.99792400E+03, -.57226100E+03, 0.70870700E+03, 0.55601100E+03, 0.10113500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.40277100E+00, -.22563600E+00, -.52473300E-02, 0.55397200E-01, 0.34389000E+00, -.16534500E-01, -.48538900E+00, -.90950500E+00, 0.38532500E+00, 0.11425600E+00, -.78741200E-01, 0.96789000E+00, -.26179500E+01, -.62703800E+00, -.14498100E+01, -.45342700E+00, -.25281400E+00, 0.40028500E+00, 0.20905800E+00, -.20536800E+00, -.79569000E+00, -.70880600E-02, 0.59358700E-01, 0.60388900E+00, 0.13997800E+00, 0.64852000E-02, 0.54464700E+00, 0.12179300E+00, 0.40107400E+00, 0.40482000E+00, -.10242300E-01, 0.16904700E-01, -.30876100E-02, -.86318300E-01, 0.72790900E-01, 0.58190500E-01, 0.30873200E-02, 0.14863800E+00, 0.23496400E+00, -.20050100E+00, 0.36162800E+00, 0.15756200E+00, -.29216400E+00, 0.84051900E-01, 0.48741800E-01, -.11115400E+00, -.98703500E-01, 0.25719300E-02, 0.26081000E+04, -.48343200E+03, -.65493400E+03, -.42549800E+03, -.97862100E+03, 0.14321300E+03, -.30029800E+04, -.13494300E+04, 0.70859100E+03, -.44110600E+03, 0.67484000E+03, -.27013400E+04, 0.12950000E+04, 0.51936800E+03, -.35878800E+02, 0.17088400E+04, 0.34841300E+03, 0.29316100E+04, -.35628900E+04, 0.17074600E+04, -.17002100E+03, 0.17804800E+04, 0.55485000E+03, 0.21987700E+03, 0.40740200E+03, -.72882500E+03, 0.72459700E+03, 0.26436200E+03, 0.17266500E+04, 0.16207900E+04, -.57949800E+03, -.10883600E+03, -.81017800E+03, 0.72872900E+02, -.41489900E+03, 0.10123000E+01, 0.56258200E+03, -.41199200E+03, -.24843400E+03, -.64869400E+03, 0.17349700E+04, -.88031800E+03, 0.33309000E+03, -.86675900E+03, 0.64607000E+03, -.15232800E+04, -.23970800E+03, -.68629500E+02, -.10699000E+04, -.16104600E+04, -.20257300E+04, 0.29874800E+04, -.14489100E+04, -.10786300E+04, -.14938700E+04, -.38546400E+03, 0.26311500E+04, -.15590800E+03, 0.13936400E+04, -.11402700E+04, 0.16492900E+04, 0.68384200E+03, -.25105800E+04, 0.10231000E+04, -.10547300E+03, 0.12554700E+04, -.46499900E+03, -.43305500E+03, 0.33413000E+03, -.10619600E+04, 0.40473300E+03, -.53547400E+03, 0.13053600E+04, 0.49816000E+04, -.26661800E+04, -.16051400E+04, -.24907000E+04, -.12604100E+04, -.30682000E+04, -.33679800E+03, 0.10887900E+03, -.10555800E+04, -.25569900E+04, -.23033900E+04, 0.17211400E+04, -.72301200E+03, 0.97718800E+03, -.86042700E+03, 0.57346500E+03, 0.76554300E+03, -.43763600E+03, 0.69352900E+03, -.35290400E+03, 0.86912100E+03, -.89236700E+03, 0.29066500E+04, -.15800100E+04, -.21248500E+04, -.14533200E+04, 0.13907000E+04, 0.38661500E+04, -.24806800E+04, -.10319500E+04, -.16000900E+04, 0.29814400E+04, -.18290300E+04, 0.44845700E+04, -.20357900E+04, 0.86683000E+03, -.22404500E+04, -.47205400E+03, -.19030100E+03, -.62339300E+03, 0.85616500E+03, -.13780900E+04, -.18455600E+03, -.22139600E+04, -.18733100E+04, 0.80942500E+03, -.47009700E+03, 0.93622900E+03, 0.47407400E+03, -.13888400E+04, -.15561900E+02, -.79175200E+03, 0.10844900E+04, -.10119400E+04, -.10534800E+04, 0.12878400E+04, -.84248200E+03, -.35346000E+04, -.64386700E+03, 0.82223300E+02, -.15294900E+04, -.55045900E+03, -.10384400E+04, -.46903000E+03, -.12488600E+04, -.23042300E+04, -.44637900E+03, 0.34412700E+03, 0.11578400E+04, 0.22317600E+03, -.91706100E+03, -.26721800E+04, 0.15585200E+04, 0.10556400E+04, 0.56314800E+03, -.20880500E+04, 0.52433800E+03, -.84621000E+04, 0.44502500E+04, 0.96674400E+03, 0.42307600E+04, -.35829300E+03, 0.23379000E+04, 0.14005500E+04, -.90620500E+03, 0.25380500E+04, 0.18924400E+04, 0.42837500E+04, -.22958500E+04, 0.11711500E+04, -.32370500E+03, 0.11479600E+04, -.13651400E+04, -.23007700E+04, 0.83655300E+03, -.96378900E+03, 0.56615600E+03, -.15732000E+04, 0.17062200E+04, 0.17991900E+04, -.10482000E+04, 0.19467400E+03, -.89964000E+03, 0.15184100E+04, 0.20945500E+03, -.54064600E+03, 0.24497200E+03, -.68797500E+03, 0.45735300E+02, -.16616200E+04, 0.54247200E+03, -.30375500E+03, -.78446500E+03, -.27121600E+03, 0.40373700E+03, 0.61018300E+03, -.59864000E+03, -.42093200E+03, -.20216200E+03, 0.39001800E+03, -.53047400E+03, -.15552000E+04, 0.71271400E+03, 0.52817000E+03, 0.77745600E+03, -.33074300E+03, -.11135600E+04, 0.50785000E+03, -.26356600E+03, 0.67853500E+03, -.76759200E+03, 0.86387300E+03, -.69763900E+03, 0.54549800E+03, -.22668800E+03, 0.34856700E+03, 0.41919000E+03, 0.23840000E+04, -.51654600E+03, -.36138600E+03, -.88247000E+03, 0.19793600E+04, 0.43733000E+03, -.86460300E+02, 0.10984500E+03, 0.62294200E+03, 0.61636300E+02, 0.37172200E+03, 0.11380300E+04, 0.12625200E+04, -.23002200E+03, -.59807100E+03, -.25509400E+03, 0.18172800E+04, -.62469700E+02, -.12788600E+04, -.41401500E+02, -.11991900E+03, -.23659100E+02, 0.19254900E+04, 0.36384700E+03, 0.24831900E+03, -.10577800E+04, 0.21139700E+04, 0.19824800E+03, -.26435800E+03, 0.40815700E+03, 0.31897200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39604500E+00, -.26308700E+00, -.81338500E+00, 0.40154700E+00, -.12778000E+00, -.32135600E-02, -.68054600E+00, -.10289600E+01, 0.20121500E+00, -.37385100E-01, 0.47468800E-01, 0.19857900E+01, 0.10635000E+01, -.46017000E+00, 0.20114700E+01, -.15841800E+01, -.11946800E+01, 0.75008000E-01, 0.17355300E+00, -.48484500E+00, -.22609600E+00, -.35001300E-02, -.10397400E+00, -.44016800E+00, 0.58205500E-01, 0.66523300E-01, -.25050900E+01, 0.12610000E+00, -.44011400E+00, -.11294300E+01, -.11939100E+00, 0.89204800E+00, -.45151900E+00, -.17459500E+00, 0.30643800E+00, -.18738400E+00, 0.12136300E-01, -.84029100E+00, 0.50630200E+00, 0.44417500E+00, 0.25968300E+00, 0.14022900E+00, -.70750600E+00, -.14418000E+00, 0.12119000E+00, 0.26226400E+00, -.17988500E+00, 0.68603800E-02, -.62287700E+00, -.35887100E+04, -.10696100E+04, -.17978500E+04, -.22446700E+04, -.28016400E+04, -.86547100E+03, 0.67264800E+04, -.35705200E+04, -.45086100E+04, -.33628300E+04, 0.12665400E+04, 0.54859200E+04, -.19223000E+03, 0.25386100E+04, 0.16785900E+03, 0.42555700E+04, -.33487400E+04, -.13877100E+04, 0.90864300E+03, -.22443500E+04, 0.69055400E+03, 0.24874100E+04, 0.39313400E+04, -.17900500E+04, 0.11852500E+03, 0.40696800E+03, 0.30222000E+04, 0.82637100E+03, 0.31826700E+04, -.23227300E+04, -.17002700E+04, -.15906400E+04, -.12008400E+03, -.36174100E+03, -.16362400E+03, 0.13179200E+04, -.41909200E+03, -.32784700E+03, -.10357200E+04, 0.12096300E+04, -.66121500E+03, 0.41953200E+03, -.60240000E+03, -.17370000E+04, -.29181800E+04, -.49634400E+02, 0.11578200E+04, -.40645900E+03, -.31096100E+04, 0.24285800E+03, 0.17010000E+05, -.86057400E+04, -.50853500E+04, -.85054200E+04, 0.29379600E+03, 0.95035800E+04, -.40682100E+04, 0.52627100E+04, -.53763100E+04, 0.74670200E+04, -.66688200E+04, -.29201300E+04, 0.21600000E+04, 0.27802400E+04, 0.14606700E+04, 0.12492700E+04, 0.13894500E+04, -.10459800E+03, -.11220000E+04, -.12320900E+03, 0.97671000E+03, 0.70031900E+02, 0.18219400E+05, -.86774600E+04, -.23060100E+04, -.91094000E+04, -.19372300E+04, -.53080800E+04, -.41818900E+03, 0.13677600E+04, -.39334400E+04, -.40804300E+04, -.78245300E+04, 0.56727500E+04, -.33242100E+04, -.24389700E+04, -.28359100E+04, -.14715400E+04, -.21017600E+04, -.38205900E+03, 0.14358600E+04, -.47764800E+03, -.13992600E+04, -.16067600E+04, -.10619400E+05, 0.57408600E+04, 0.38015400E+02, 0.53097300E+04, 0.26870500E+04, 0.56898200E+04, -.19748700E+04, -.54564600E+04, 0.11784200E+04, 0.48725000E+04, 0.57785000E+04, 0.47217900E+04, -.29215300E+04, 0.12363400E+04, -.23546400E+04, -.33258100E+04, -.53017400E+04, 0.21058600E+04, 0.14461200E+04, -.57029200E+03, -.41077500E+04, -.23734400E+04, 0.43899100E+04, -.18458200E+04, -.48987300E+04, -.21955900E+04, 0.45355300E+02, -.55666000E+04, 0.54278300E+03, 0.82692900E+03, -.40640900E+03, -.47288900E+04, -.47524100E+04, 0.66565500E+03, 0.27247500E+03, -.46308900E+04, -.33265800E+03, -.98051600E+03, -.63057300E+04, 0.12796100E+04, -.54721800E+03, 0.12079500E+04, -.53866100E+04, -.95703100E+03, 0.10140400E+05, -.54566900E+04, -.12770200E+04, -.50702600E+04, -.17442400E+04, -.32783300E+04, 0.28605400E+03, 0.40972300E+04, -.21176700E+04, -.29563300E+04, -.54495900E+04, -.21664900E+05, 0.10274600E+05, 0.59972800E+04, 0.10831500E+05, 0.35353300E+04, 0.63024900E+04, 0.87134600E+03, -.24977500E+04, 0.43434000E+04, 0.48522400E+04, 0.89338700E+04, -.22502300E+05, 0.11263200E+05, 0.77080200E+04, 0.11251300E+05, -.11682300E+04, -.59425300E+04, 0.45761400E+04, -.61543600E+04, 0.71208900E+04, -.45439000E+04, 0.12618100E+05, -.12445600E+04, 0.11123800E+04, 0.24558900E+04, 0.62213200E+03, -.10428000E+04, -.26023900E+04, 0.11533100E+04, 0.10875900E+04, 0.31811700E+03, -.20063600E+04, -.14310300E+04, -.71263300E+04, 0.36792300E+04, 0.38097100E+04, 0.35632300E+04, 0.52736500E+03, -.72013500E+03, 0.28305300E+02, -.26194600E+04, 0.11521100E+04, -.56388200E+03, 0.36243800E+04, -.24805000E+04, 0.14792300E+04, 0.10360200E+04, 0.12397700E+04, -.65643000E+03, -.20399500E+04, 0.10319900E+04, -.88903300E+03, 0.81304800E+03, -.13718200E+04, 0.11154500E+04, -.25051300E+04, 0.68837700E+03, 0.15932400E+04, 0.12517300E+04, 0.18793400E+04, 0.45040600E+04, -.89011300E+03, 0.59214000E+03, -.18372500E+04, 0.40092200E+04, -.78465500E+03, 0.28829200E+03, 0.73385100E+02, 0.25363000E+03, 0.20321700E+03, 0.20022500E+03, 0.41688100E+04, 0.36110300E+04, -.75255600E+03, -.27165000E+03, 0.13992400E+03, 0.36490700E+04, -.12780000E+04, -.22143800E+04, -.40735200E+03, 0.30489000E+03, -.99326400E+02, 0.41175400E+04, 0.15418500E+04, 0.10410400E+04, -.14116000E+04, 0.40787800E+04, -.35991500E+03, -.28355700E+03, 0.60154200E+03, 0.41536400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32534900E+00, -.16465900E+00, 0.14774400E+00, -.18517000E+00, -.45230700E+00, -.12583200E-01, 0.12836800E+01, 0.13428600E+00, 0.51753800E-02, 0.42244700E-01, 0.22378300E-01, 0.43307200E+00, 0.41890100E+00, 0.47817400E+00, 0.32333900E+00, -.19302500E+00, -.29116600E+00, -.14331000E+00, 0.54810900E+00, -.17672600E+00, -.13754000E+01, 0.10295200E+00, -.26740600E+00, 0.13305100E+00, -.47047900E-01, 0.60819100E-01, 0.82050300E+00, -.23335100E+00, -.31561800E+00, -.86609700E+00, -.13978100E+00, 0.79171200E+00, 0.21723000E-01, 0.23824500E-01, 0.45505000E-01, 0.39727900E+00, 0.68743200E-02, -.11205100E+01, 0.39736900E+00, -.55898000E+00, 0.46822500E+00, 0.12944200E+00, 0.26031300E+00, -.28275900E-01, 0.13130600E+00, -.13111200E+00, 0.50560800E-02, 0.36016700E-02, -.65588000E-01, 0.13423500E+00, 0.21562200E+04, 0.18082400E+04, -.35756500E+03, -.22237100E+03, 0.48932700E+04, 0.38849400E+04, -.20147800E+04, -.39362300E+04, -.19423400E+04, -.64399700E+03, -.21764200E+03, -.29856700E+04, -.97110800E+03, -.67830200E+03, 0.18786200E+03, -.75845500E+04, 0.14177600E+04, -.36015900E+03, -.88412200E+03, -.70990500E+03, -.93867500E+03, -.21714900E+04, 0.67416400E+03, 0.80411500E+03, 0.10624900E+04, -.19882300E+04, -.13947700E+03, -.66799600E+03, 0.12246000E+02, -.32654700E+02, 0.33424400E+03, -.56443300E+03, -.10395600E+04, 0.89366700E+03, 0.76291500E+03, 0.85922300E+03, -.90634100E+03, -.24337900E+02, -.17526100E+04, 0.85671000E+03, 0.12475000E+04, 0.87706400E+03, 0.38303600E+03, -.11389100E+03, 0.11854300E+04, 0.76732300E+03, 0.14417300E+04, 0.85372700E+02, 0.35736700E+04, -.17475800E+04, 0.80864400E+03, -.10517100E+04, 0.87365200E+03, 0.10646200E+04, 0.24785000E+04, -.17942800E+04, -.14847500E+04, 0.49679500E+03, 0.22495800E+04, -.35867800E+04, -.43863800E+04, 0.24903500E+04, 0.65874500E+03, 0.21933800E+04, 0.33588400E+03, 0.15114500E+03, 0.70129400E+03, -.57027900E+03, 0.11998900E+04, 0.31559200E+03, 0.17954800E+04, 0.18370600E+04, -.64219200E+03, 0.75464900E+03, -.91842900E+03, 0.59923900E+03, -.85053800E+03, 0.31591500E+03, 0.77993800E+03, -.89618600E+03, 0.95763200E+02, -.17949100E+04, 0.80969200E+04, -.42331100E+04, -.26693300E+04, -.40483100E+04, -.68651300E+03, -.13789400E+03, -.12882200E+04, 0.59353300E+03, -.22365500E+04, -.46252800E+03, -.28832200E+04, -.10597000E+05, 0.55406100E+04, 0.88447800E+04, 0.52984800E+04, 0.25641000E+01, -.16292600E+04, 0.98699200E+03, -.30794100E+04, 0.18538200E+04, -.11574300E+04, 0.31806600E+04, -.24896700E+03, -.50052300E+03, 0.63225100E+03, 0.12645000E+03, 0.54812500E+03, 0.18639100E+04, -.26804000E+03, -.34622200E+03, -.12088700E+04, 0.17359100E+04, -.24296600E+03, 0.11001900E+04, -.30896600E+03, -.15684100E+04, -.55009800E+03, 0.10040600E+03, -.19072700E+04, 0.14147800E+04, 0.99744800E+03, -.51818700E+03, -.14153800E+04, 0.12188600E+04, -.15521600E+05, 0.81295500E+04, 0.21775200E+04, 0.77608500E+04, 0.22226400E+04, -.14686900E+04, 0.50400300E+04, 0.28406800E+04, 0.68251000E+04, -.11372100E+04, 0.87237300E+04, 0.79268700E+04, -.41836600E+04, -.56859000E+04, -.39634500E+04, -.49689200E+02, 0.20028900E+04, -.93776500E+03, 0.19851000E+04, -.19164100E+04, 0.16117400E+04, -.25299000E+04, -.57016900E+04, 0.24850700E+04, -.18998300E+04, 0.28505300E+04, -.56489200E+03, 0.78079300E+03, -.21388600E+04, -.30996100E+04, 0.19071800E+04, -.46783500E+02, 0.31573200E+04, -.82993100E+04, 0.40926200E+04, 0.34813500E+04, 0.41496900E+04, -.73365300E+03, -.12212800E+04, 0.16805800E+04, -.21171900E+03, 0.34886000E+04, -.14690100E+04, 0.62787900E+04, -.27649600E+04, 0.16908400E+04, 0.25480200E+02, 0.13824300E+04, 0.22053500E+04, 0.92990000E+03, 0.61166000E+03, -.24402100E+03, 0.71918700E+03, 0.77545600E+03, 0.95675400E+03, -.12803600E+05, 0.64471400E+04, 0.24604200E+04, 0.64018200E+04, 0.94182600E+03, -.13525900E+04, 0.29415900E+04, -.51369300E+03, 0.40746800E+04, -.79404300E+03, 0.51050000E+04, 0.23031100E+04, -.10134800E+04, 0.62459600E+03, -.11517000E+04, -.32372600E+02, -.62829300E+03, 0.10696500E+03, 0.20063000E+03, -.10891200E+04, -.60410800E+03, -.13574300E+04, -.27633100E+04, 0.10639800E+04, -.13813200E+04, 0.13813900E+04, 0.63733900E+03, 0.11745000E+04, -.92332900E+03, -.19244500E+04, 0.29235500E+03, 0.87268400E+03, -.66798500E+03, 0.68298300E+03, -.26333900E+03, 0.91298400E+03, 0.49729700E+02, 0.16391100E+03, -.11144500E+04, -.27106100E+03, 0.14930600E+03, -.90781700E+03, 0.42124000E+03, 0.57433400E+03, -.32638500E+03, -.38197200E+03, 0.15392500E+02, 0.85932000E+03, 0.13660500E+02, 0.79324600E+03, -.64467500E+03, 0.10450100E+04, 0.11281000E+03, 0.92322600E+03, 0.10174300E+04, -.24633100E+03, -.46862900E+03, -.60289900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12605700E+00, 0.67461400E-02, -.52926700E+00, -.12140700E+00, -.26935200E+00, 0.62624200E-02, -.21459300E+00, -.12681700E+00, 0.70137600E+00, 0.18158800E+00, -.11587600E-01, 0.70656700E+00, -.45122800E-01, 0.17857800E+00, -.45752400E-01, -.74740400E-01, -.14565100E+00, -.13115200E+00, 0.13546800E+00, -.36622900E+00, -.46967000E+00, 0.71813300E-02, -.53821600E-01, 0.37591300E-01, 0.25003000E-02, 0.13146200E-01, 0.11515300E+00, 0.10215100E-01, 0.11329200E+00, 0.68613600E-01, 0.12063400E+00, -.28511700E+00, 0.25983100E-01, 0.17124500E+00, -.85167800E-01, -.13418800E-01, 0.48500500E-02, 0.21031300E+00, -.11950400E+00, -.96791200E-01, -.53284000E-01, 0.37438400E-01, -.17957200E+00, 0.56777300E-01, 0.24505300E-01, -.64840000E-01, 0.32907000E-01, -.10046500E-02, 0.29568100E+00, -.18011500E+00, 0.24992700E+00, 0.80566600E+03, 0.75037300E+03, 0.40177000E+03, -.22118300E+04, 0.11750500E+04, -.58485700E+03, 0.16970900E+04, -.58757200E+03, 0.38387000E+03, -.48219800E+03, 0.38072400E+03, -.24859600E+03, -.13498300E+04, -.93074400E+03, 0.21136700E+04, 0.19816500E+03, -.28470300E+03, 0.20453100E+04, -.98738100E+02, 0.76973000E+03, 0.19863500E+04, -.10365700E+04, -.83474400E+03, -.17318700E+04, 0.17970500E+04, -.41005200E+03, -.11292500E+03, 0.61534400E+02, -.11443400E+03, 0.56353100E+02, 0.25101400E+03, 0.66029000E+03, -.45981400E+03, -.51019900E+03, -.32047500E+03, 0.58372300E+03, 0.17074100E+03, 0.46061300E+03, -.21416800E+03, 0.10836200E+04, -.23057300E+03, -.13037000E+03, 0.66208700E+03, -.66042600E+03, -.11121700E+04, -.15121600E+04, 0.69932700E+03, -.10507500E+04, 0.46283200E+03, -.23016500E+03, -.20533200E+04, -.23136800E+03, -.14926600E+04, -.18471400E+04, 0.81003900E+03, 0.34504900E+02, 0.35723600E+03, -.26913400E+04, 0.21680300E+04, 0.27850900E+04, -.13824300E+04, 0.41887200E+03, -.13926100E+04, -.12997200E+03, 0.23925800E+03, -.47916600E+03, 0.24258800E+03, -.78947100E+03, 0.11618000E+03, -.12094200E+04, 0.18031900E+02, -.29643700E+02, 0.11332600E+04, -.90526100E+01, -.17850600E+03, 0.68695400E+03, -.61408600E+03, 0.33187200E+03, 0.40985300E+03, 0.57839000E+03, 0.34870100E+03, -.47430300E+04, 0.23653400E+04, 0.71874200E+01, 0.23714500E+04, 0.40504900E+03, -.77587500E+02, 0.63890400E+03, -.43586800E+03, 0.96367900E+03, 0.96358500E+02, 0.19133100E+04, 0.32566300E+04, -.16592600E+04, 0.50201100E+03, -.16283100E+04, 0.40142700E+03, 0.13400800E+04, 0.21324500E+03, 0.19535700E+04, -.10912700E+04, 0.12184900E+04, -.14233000E+04, -.13951300E+04, 0.97366500E+03, -.23666100E+04, 0.69688200E+03, -.53636100E+03, -.18113900E+04, 0.90446100E+03, 0.42775400E+03, 0.19504600E+04, -.16489600E+04, 0.94909300E+03, -.77505800E+03, 0.35568800E+03, 0.21220200E+04, 0.38766800E+03, 0.90246100E+03, 0.84013500E+03, -.65051300E+03, -.62417700E+03, -.46992100E+03, 0.12755200E+04, -.87840000E+03, 0.10579000E+04, -.57423200E+03, 0.82233400E+03, -.52897100E+03, 0.18199900E+03, -.82477600E+03, 0.48390700E+03, 0.30666100E+03, -.14026300E+04, -.27053900E+03, -.17165500E+04, -.41444300E+04, 0.20969600E+04, -.91074500E+03, 0.20722200E+04, -.12738400E+03, -.12080500E+04, 0.48540700E+02, -.16154800E+04, 0.16018700E+04, -.10622800E+04, 0.18131000E+04, 0.49136600E+04, -.24207900E+04, 0.83551800E+03, -.24567200E+04, 0.33883000E+03, -.71828700E+03, 0.61266500E+03, 0.61443000E+03, -.21303600E+04, -.23648300E+03, -.25547600E+04, 0.35859900E+04, -.17743500E+04, 0.13090300E+04, -.17930100E+04, 0.79835500E+03, 0.14859100E+04, -.84782300E+03, 0.54786500E+03, -.17092700E+04, 0.21893200E+04, -.29044500E+04, 0.59506600E+03, -.35038100E+03, -.44468600E+03, -.29751600E+03, -.10177800E+04, -.36749900E+03, 0.56386200E+02, -.51866100E+03, -.64034800E+03, -.46695500E+03, -.14219700E+03, 0.52537700E+03, -.26910900E+03, 0.60018800E+03, -.26269600E+03, -.10025400E+03, 0.26397400E+02, 0.29077700E+03, 0.39654400E+03, -.31705700E+03, 0.23805400E+03, -.51849700E+02, -.24896200E+03, 0.10393900E+03, 0.35155500E+03, 0.12453100E+03, 0.36340500E+02, 0.54720600E+03, -.18144700E+03, 0.26035800E+03, 0.51883700E+03, 0.42780800E+03, 0.19827200E+03, 0.21315400E+04, -.10267500E+04, -.47417600E+03, -.10656800E+04, -.16026900E+03, -.76536500E+03, 0.21383400E+03, 0.14627700E+03, -.34653300E+03, -.70080000E+03, -.50083300E+03, -.38440100E+03, 0.19586300E+03, -.61340000E+03, 0.71169500E+02, -.15384200E+03, -.13448900E+03, -.49037600E+03, 0.69186400E+02, 0.59326000E+03, -.24252500E+03, -.60547100E+03, 0.23095000E+02, 0.37772100E+03, -.10271400E+03, -.49245700E+03, 0.12397400E+03, -.44027500E+03, 0.44504700E+03, -.71946200E+03, 0.22926600E+03, -.78610600E+03, -.34499500E+03, 0.17634700E+02, 0.24649200E+03, 0.11506500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25721900E+01, -.66569800E+00, -.20088800E+00, -.18009200E+01, -.41481900E+00, -.11868400E+00, 0.10927800E+01, -.11905500E+01, -.21202700E+01, -.27191300E+00, 0.13589300E+01, 0.22378800E+01, 0.40299700E+01, 0.19549300E+01, 0.85994900E+01, -.52945600E+01, -.57022800E+00, 0.13091600E+01, 0.24336300E+00, 0.11512800E+01, 0.16569000E+01, -.14600100E+00, -.15488000E+01, -.32981500E+00, -.59213900E+00, -.10132200E+00, 0.24998600E+00, -.13542600E+01, 0.63192100E+00, -.15081200E+01, -.34997100E-02, 0.15843100E+00, -.37310100E+01, 0.27892300E+01, -.54973300E+00, -.11694000E+01, -.23383800E+00, -.22463900E-01, -.36401500E+00, -.52580600E+01, 0.13190100E+01, -.63021000E+00, 0.34996500E+01, -.22275600E+00, -.70653400E-01, -.51372300E+00, 0.46809600E+00, -.51075100E-01, 0.49797100E+00, 0.10267800E+01, 0.25640800E+01, -.76365800E+01, 0.88423000E+04, 0.24226900E+04, -.30111700E+05, 0.16049100E+04, -.43321900E+03, 0.14949200E+05, -.80612200E+03, 0.25449800E+04, -.33807300E+04, -.91865100E+03, 0.29941400E+04, -.11495400E+05, -.68684500E+04, 0.43811900E+05, -.97233200E+04, 0.34638800E+04, 0.22201800E+05, 0.48909000E+04, 0.82383700E+03, 0.94642100E+04, -.21909100E+04, -.54177200E+04, -.58424500E+04, 0.84908600E+04, -.68414200E+04, -.63428200E+04, 0.44332900E+04, -.36513300E+03, 0.31650400E+04, 0.37770200E+04, 0.63895700E+04, -.50387200E+04, -.94157000E+04, -.39494500E+04, 0.54328900E+04, -.11393200E+04, -.37621900E+04, 0.21020600E+04, -.48812500E+04, 0.18596900E+04, -.20180600E+04, 0.43632100E+04, -.57831200E+04, -.17295900E+05, -.82847100E+04, 0.52870600E+04, -.31118000E+04, -.32760900E+05, 0.16591500E+05, -.53198100E+04, 0.16384300E+05, -.15309900E+05, -.29458200E+05, 0.16354300E+05, -.50905500E+04, 0.80813700E+04, -.31023900E+05, 0.34999500E+05, 0.38649400E+05, -.20417500E+05, -.54382100E+04, -.19330100E+05, -.16499500E+04, 0.39995000E+04, -.90893300E+04, 0.32373500E+04, -.80210800E+04, 0.27080600E+04, -.37518200E+04, -.46228100E+05, 0.22124500E+05, 0.12545700E+05, 0.23111100E+05, 0.13851000E+05, 0.30262000E+05, -.70933000E+04, -.81942400E+04, 0.40602800E+03, 0.24436000E+05, 0.35928000E+05, -.68314800E+05, 0.34859200E+05, 0.14743400E+05, 0.34153200E+05, 0.37198100E+04, -.15922200E+04, 0.14080800E+05, -.28823300E+04, 0.14692700E+05, -.15826300E+03, 0.96368200E+04, 0.57006200E+05, -.29528200E+05, -.13164100E+05, -.28503200E+05, -.13740200E+05, -.10800700E+05, 0.53470100E+04, 0.30596700E+05, -.11429900E+05, -.72080200E+04, -.24910500E+05, -.12528300E+05, 0.86141400E+04, -.23511900E+05, 0.62086100E+04, 0.32350100E+04, -.53185700E+04, 0.10539800E+04, -.32581800E+04, 0.87362300E+04, -.52498800E+04, 0.15567500E+05, 0.15766500E+05, -.88466900E+04, 0.17885800E+05, -.78811800E+04, 0.68316000E+04, 0.16244700E+05, -.11303200E+05, 0.79916500E+03, -.12203700E+04, 0.15980900E+05, -.14967000E+04, 0.37625300E+05, -.20327900E+05, 0.12062000E+05, -.18814200E+05, 0.46820800E+04, 0.45680500E+04, -.15033900E+05, -.99458800E+04, -.24837400E+05, 0.42925100E+04, 0.35858000E+04, -.50165500E+05, 0.25988100E+05, 0.42031000E+04, 0.25083200E+05, 0.10575700E+05, 0.36083700E+04, -.13903700E+04, -.22800500E+05, 0.14567500E+05, 0.21964100E+04, 0.20760700E+05, 0.83154300E+05, -.40216500E+05, 0.19198800E+04, -.41568400E+05, -.76692000E+04, -.21236800E+05, 0.35612100E+04, 0.22797700E+05, -.10101300E+05, -.14717800E+05, -.52138800E+05, 0.55603600E+05, -.27604000E+05, 0.67448300E+04, -.27802800E+05, 0.16194200E+05, 0.24469000E+05, -.15730200E+05, 0.69758200E+04, -.25630100E+05, 0.27628100E+05, -.54022900E+05, -.23785600E+04, -.14289300E+03, -.15596600E+05, 0.11905800E+04, -.15029700E+05, -.46889700E+04, -.13262500E+04, -.12612100E+05, -.61433300E+03, -.67362600E+04, 0.33392800E+05, 0.38155200E+05, -.19264100E+05, -.15099800E+05, -.19078200E+05, -.21008100E+04, 0.78795000E+03, -.58518600E+04, 0.69700900E+04, -.94316700E+04, 0.24369500E+04, -.14354700E+05, 0.72473900E+04, -.42334600E+04, 0.39602700E+04, -.36194700E+04, 0.33438600E+04, 0.10181800E+05, -.29265400E+04, 0.71214100E+04, -.43396300E+03, 0.84985900E+04, -.71916300E+04, 0.20229300E+05, -.89096800E+04, -.75623200E+04, -.10107200E+05, -.84326400E+04, -.12815900E+05, 0.38730700E+04, 0.10351500E+04, 0.56058600E+04, -.12669800E+05, 0.16970600E+05, -.19158800E+04, -.14442200E+04, -.92824200E+04, -.27598100E+04, 0.10796100E+04, -.37083800E+04, -.72650800E+04, -.85051500E+02, 0.94030400E+04, -.11876200E+04, -.13427300E+05, 0.29412300E+04, 0.10161100E+05, 0.18389000E+04, -.26548900E+04, -.13154200E+04, -.14450900E+05, 0.25845800E+04, -.63055400E+04, 0.53586600E+04, -.16694200E+05, -.17171400E+04, -.19074900E+04, -.14507900E+04, -.16989000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54158700E+00, -.25076300E-01, -.49552600E+00, -.13137500E+00, -.73941500E+00, -.10637200E+00, 0.36861100E+00, 0.14839200E+00, -.60571700E+00, -.18731600E+00, 0.74498900E-01, -.11770000E+01, 0.93914600E+00, 0.15176300E+00, 0.58592100E+00, 0.18637400E+00, 0.35460000E+00, 0.15612500E+00, -.39301800E+00, 0.77791300E+00, 0.45405000E+00, -.20377200E-01, -.11629100E+00, -.16693100E+00, -.21054200E-01, -.27208400E-01, 0.40371100E+00, -.17550800E+00, -.18694500E+00, -.46569400E+00, -.29739200E+00, 0.69488600E+00, 0.11703300E+00, -.29525100E-01, 0.85445600E-01, 0.25641000E+00, -.18251300E-01, -.83893600E+00, 0.14253000E+00, 0.85598300E+00, -.30375100E+00, -.81969000E-01, -.21034300E+00, -.18653700E+00, -.14529100E+00, 0.33760500E+00, 0.45671600E+00, -.40773800E-02, -.36272100E+00, 0.17868500E+00, -.66402600E+00, -.19247800E+00, 0.74668100E-01, -.13543900E+04, 0.77298100E+04, -.17519600E+04, 0.89712900E+03, -.29976500E+04, 0.87610000E+03, -.12951100E+04, 0.11320300E+04, -.22958200E+03, -.15502900E+04, 0.50717000E+03, 0.26770700E+04, -.84328500E+04, -.75787600E+03, 0.52124700E+03, -.33194300E+04, 0.37806800E+03, -.17654500E+04, -.39470000E+04, 0.24216900E+04, 0.24532500E+04, 0.44191200E+04, -.37261100E+04, 0.18550700E+04, 0.55051700E+03, -.31443300E+03, 0.29987000E+03, -.27503200E+03, -.29202600E+03, -.75797900E+03, 0.62213500E+03, 0.80769000E+03, 0.41050900E+03, -.79242200E+03, -.56068600E+03, 0.21674700E+04, -.10939000E+04, -.48178300E+03, -.10830400E+04, -.12444000E+04, -.12628600E+04, 0.17973500E+04, 0.37727700E+04, 0.30702100E+04, -.14790300E+04, 0.33427800E+04, -.32572900E+01, -.28735100E+01, 0.33876800E+04, 0.15019300E+01, 0.26053300E+04, 0.45637600E+04, -.26539700E+04, -.16557500E+04, -.14514900E+04, 0.57507000E+04, -.83002000E+04, -.49861100E+04, 0.25271300E+04, -.67961300E+03, 0.24932100E+04, 0.45188400E+03, -.58505500E+03, 0.10124400E+04, -.28993400E+03, 0.12670100E+04, -.34217500E+03, 0.17406800E+04, 0.27827500E+03, -.10676000E+03, -.10215700E+04, -.13904300E+03, 0.14089000E+04, -.16550100E+04, 0.14448300E+04, -.16591500E+04, -.20015400E+04, -.13044200E+04, -.27795100E+04, 0.10306900E+05, -.51615900E+04, -.11773200E+04, -.51533000E+04, -.11988300E+04, 0.27540000E+03, -.17991000E+04, 0.64717600E+03, -.18544100E+04, -.11842800E+03, -.33860800E+04, -.98475500E+04, 0.49450900E+04, 0.19862700E+04, 0.49237800E+04, -.14629300E+04, -.37200000E+04, 0.10552000E+04, -.46581800E+04, 0.30728000E+04, -.23818400E+04, 0.32738200E+04, 0.37952900E+04, -.21221500E+04, 0.37875500E+04, -.18959600E+04, 0.13341800E+04, 0.36972200E+04, -.24511500E+04, -.16584600E+04, -.49127200E+04, 0.34519700E+04, -.31851400E+04, 0.25452800E+04, -.12466800E+04, -.47564700E+04, -.12729000E+04, -.13594200E+04, -.18134300E+04, 0.10367200E+04, 0.20938300E+04, 0.82868700E+03, -.26972600E+04, 0.34483900E+04, -.81448900E+04, 0.41059100E+04, -.40180700E+02, 0.40725000E+04, -.48243700E+03, 0.24969600E+03, 0.29447400E+04, 0.21660800E+04, 0.52319100E+04, -.86255000E+03, 0.80496500E+04, 0.10384400E+05, -.52096300E+04, -.83699200E+03, -.51922000E+04, 0.82834300E+03, 0.33671300E+04, -.14460600E+04, 0.33288100E+04, -.36773000E+04, 0.21675400E+04, -.36725500E+04, -.75705700E+04, 0.37413500E+04, -.34310100E+04, 0.37850000E+04, -.24272000E+04, 0.10239100E+04, -.82092800E+03, 0.17714600E+03, 0.37453400E+04, 0.46958800E+03, 0.58505400E+04, -.85373000E+04, 0.42364100E+04, -.12014700E+04, 0.42686800E+04, -.15321900E+04, -.38886000E+04, 0.29057700E+04, -.11883100E+03, 0.39125500E+04, -.45878200E+04, 0.79669900E+04, -.20701000E+04, 0.10736200E+04, 0.16176700E+04, 0.10350100E+04, 0.21040500E+04, 0.11832500E+04, 0.83049400E+03, 0.23481600E+04, 0.15095200E+04, 0.10359000E+04, 0.10646300E+04, -.49492500E+04, 0.24944400E+04, 0.96935200E+03, 0.24746400E+04, 0.20923200E+03, -.10382300E+04, 0.46870000E+03, -.15680500E+04, 0.15312200E+04, -.64765400E+03, 0.18598500E+04, 0.50559800E+02, -.14946800E+02, -.28833600E+03, -.25418000E+02, 0.78983600E+03, -.72310000E+03, -.42323400E+03, -.12943500E+04, -.13175200E+04, -.41950500E+03, -.87314300E+03, -.40201300E+04, 0.19480300E+04, 0.22557500E+03, 0.20098200E+04, 0.11658700E+03, 0.82708600E+03, 0.69875600E+02, 0.10694200E+04, 0.10834100E+04, 0.69429300E+03, -.12245300E+03, 0.41873300E+03, -.34470600E+03, 0.80864000E+03, -.52545100E+03, -.21297300E+03, -.20868300E+03, 0.51803600E+03, -.44564900E+03, -.76419800E+03, 0.50711000E+03, 0.10103300E+04, 0.40554400E+03, -.14317700E+04, 0.66014800E+03, 0.11027600E+04, -.60393400E+03, 0.74003900E+03, -.68036000E+03, 0.12652700E+04, -.92780900E+03, 0.18763400E+04, 0.19117400E+03, 0.30160200E+03, -.44336300E+03, 0.20944000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.89003900E+00, -.13609900E+01, -.27983100E+01, -.37108400E+00, -.22494200E+01, -.35310700E+00, -.64700400E-01, -.28486000E+01, -.25088400E+00, -.28459000E-02, 0.55733200E+00, 0.16795600E+01, -.16489900E+01, 0.13111900E+00, -.40237800E+00, -.11501200E+01, -.61352100E+00, 0.74143600E+00, 0.15558300E+00, 0.82710900E+00, -.14338000E+01, -.38375700E+00, 0.52794800E+00, 0.79650300E+00, 0.10649700E+00, 0.52335100E-01, -.45376800E+00, 0.60904400E-01, 0.30463100E+00, 0.99644000E+00, -.24099600E+00, 0.15258500E+00, 0.12072900E+01, -.41839000E+00, -.18132900E+00, 0.10936800E+01, 0.13110700E-01, -.26611200E+00, -.14438100E+00, 0.67582100E+00, 0.27419300E-01, -.28937600E-01, -.37147700E+00, 0.43615400E+00, -.36381200E+00, -.53285900E+00, 0.73965700E-01, 0.16626900E-02, 0.55868600E+00, -.71482600E+00, -.22130000E+00, 0.10134600E+01, -.19308400E+00, 0.58861800E-01, -.13520900E+05, -.17278900E+04, 0.89440100E+03, 0.21115200E+04, 0.86361400E+03, -.16983300E+03, 0.50863600E+03, -.98301000E+02, 0.91028500E+03, 0.14307200E+03, 0.32320900E+03, 0.19066100E+05, -.39271100E+04, 0.16889900E+04, 0.34531600E+04, 0.19662200E+04, 0.16704900E+04, 0.35062400E+04, -.27675100E+03, -.79152000E+03, -.76522200E+03, 0.30640500E+04, -.16181500E+04, 0.11299500E+04, -.26606500E+03, -.10167500E+04, -.56551700E+03, 0.66083500E+03, 0.13224800E+04, -.12222200E+04, -.10567100E+04, -.14410700E+04, 0.10217000E+04, -.49095400E+02, -.79806100E+03, 0.40794100E+03, 0.64054400E+03, 0.39709200E+03, -.19355000E+04, 0.54219200E+03, -.87786500E+03, -.19902700E+04, -.16752000E+04, 0.65784000E+03, -.63095000E+04, 0.44570100E+04, -.21868300E+04, -.23412600E+04, -.22281500E+04, -.59255600E+03, -.23331800E+04, 0.16663000E+03, 0.73767900E+03, -.11637700E+04, -.19680900E+04, 0.12182700E+05, 0.57405000E+04, -.31529800E+04, -.10933800E+04, -.28707300E+04, 0.70712200E+02, 0.37621100E+03, -.99815300E+03, 0.17675800E+04, -.82754600E+03, 0.27471400E+03, -.66138800E+03, -.14585500E+05, 0.71176700E+04, -.93209500E+03, 0.72925100E+04, 0.21952200E+04, 0.49471100E+04, -.35374900E+03, -.31983800E+04, 0.32424800E+04, 0.37133100E+04, 0.11376400E+05, -.10867900E+05, 0.56015600E+04, 0.33160300E+04, 0.54335800E+04, 0.54940000E+03, -.21959200E+03, 0.18696400E+04, -.19503600E+04, 0.17420900E+04, 0.23859600E+03, 0.11611400E+04, 0.18807500E+05, -.95513600E+04, -.17845100E+04, -.94037500E+04, -.30060000E+04, 0.13372300E+04, -.18755500E+04, 0.52311700E+04, -.50330400E+04, 0.14110700E+04, -.58144400E+04, 0.28498300E+04, -.94167000E+03, -.39097600E+04, -.14299500E+04, -.12847600E+04, -.33280000E+04, -.35722400E+01, 0.95611700E+02, 0.85122600E+03, -.29375000E+04, 0.18200200E+04, 0.21229600E+04, -.11954900E+04, 0.88799600E+03, -.10616100E+04, -.94174700E+03, 0.12646100E+04, -.96052600E+03, 0.10783500E+04, -.50873900E+03, 0.11156900E+04, -.49413200E+04, 0.11021600E+05, -.57238900E+04, 0.11747600E+04, -.55109200E+04, -.26976700E+04, 0.69255400E+03, -.34760900E+04, 0.75762100E+03, -.56334500E+04, 0.61544700E+03, -.96850900E+04, -.14610600E+05, 0.74389000E+04, 0.11025100E+04, 0.73053400E+04, 0.25046000E+04, -.17018800E+04, 0.19847100E+04, -.34909300E+04, 0.46979800E+04, -.15164100E+04, 0.46259300E+04, 0.10678300E+05, -.51151500E+04, -.44933400E+03, -.53383700E+04, -.91585600E+03, -.32122700E+04, 0.19599400E+04, 0.54829700E+04, -.49006400E+03, -.24508700E+04, -.83901300E+04, 0.17382500E+04, -.83547000E+03, 0.13517300E+04, -.86921700E+03, 0.22030500E+04, 0.22327800E+04, -.56927000E+03, -.20478500E+03, -.99699100E+03, 0.20893400E+04, -.11582600E+05, -.14827800E+04, 0.55993400E+03, -.15511700E+04, 0.74150800E+03, -.43371500E+04, -.19372400E+04, -.51466800E+03, -.17181700E+04, -.10587200E+03, -.14605600E+04, 0.38792300E+04, 0.67593300E+04, -.34319900E+04, -.33439300E+04, -.33797200E+04, -.12431300E+04, 0.20554300E+04, -.14590000E+04, 0.12445400E+04, -.15274100E+04, 0.16820200E+04, -.25057700E+04, 0.60226100E+03, -.37710700E+03, 0.45569600E+03, -.30074500E+03, 0.36673000E+02, 0.12866700E+04, -.20891000E+03, 0.63611900E+03, 0.36299300E+03, 0.84352400E+03, 0.56982300E+03, 0.27127600E+04, -.11190800E+04, -.16932400E+04, -.13557100E+04, -.50598400E+03, -.23065600E+04, 0.92429400E+03, 0.15952100E+04, 0.13843500E+04, -.19183800E+04, 0.48157100E+04, -.54663300E+03, 0.16174800E+03, -.14313000E+04, -.35451700E+03, -.14120900E+03, 0.45523500E+03, -.11139500E+03, -.38881300E+03, 0.14242300E+04, -.10933800E+03, -.95576800E+03, 0.75542900E+03, 0.13782200E+04, 0.39257300E+03, -.98962800E+03, -.26883000E+03, -.10643600E+04, 0.69075600E+03, -.12043200E+04, 0.35796600E+03, -.16939100E+04, -.94581600E+03, 0.28748800E+03, 0.21329100E+03, 0.19294000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.99210100E+00, 0.55898700E+00, 0.39776900E+00, -.58163000E+00, 0.16289200E+01, 0.37864700E+00, 0.14451200E+00, 0.91966600E+00, 0.25157700E-01, -.21921200E+00, -.51442000E-01, -.14840200E+00, -.16070100E+01, -.61525500E+00, -.57012300E+00, 0.13880200E+01, 0.12406600E+00, -.37590700E+00, -.71300400E+00, 0.31943500E+00, 0.77740700E+00, 0.34556300E-01, 0.78206500E+00, -.45755800E+00, 0.10455000E-01, -.37289600E+00, -.16524800E+01, 0.33922300E+00, -.40152400E+00, 0.65522800E+00, 0.35403200E+00, -.33212700E-01, -.60728800E+00, -.92517700E+00, -.16303600E+00, -.53370900E+00, -.60838700E-01, 0.29579800E+00, -.47951200E+00, -.13138500E+01, 0.97860700E-01, 0.76351100E-01, 0.15630600E+01, 0.22565000E+00, 0.64820100E+00, -.48341100E+00, 0.22777100E+00, -.14580300E-01, 0.10148200E+01, 0.73494400E+00, 0.10724000E+01, -.72938400E+00, 0.24656100E+00, 0.17136900E+00, 0.36222200E+00, 0.14832600E+05, -.73834500E+04, 0.48970500E+04, -.74165900E+04, 0.27202300E+03, -.23885500E+04, 0.84084600E+02, 0.42224300E+04, -.63408700E+04, -.14637400E+04, -.71594300E+04, 0.25582400E+04, -.11266100E+04, -.37096900E+04, -.12769400E+04, -.12254200E+04, -.16988300E+04, -.20208800E+03, -.34017900E+03, -.12694100E+04, -.10423800E+04, 0.18299900E+03, -.35104600E+04, 0.20073100E+04, -.13119300E+04, 0.17547200E+04, -.11182800E+03, 0.49776400E+03, 0.30441000E+03, -.29998400E+03, 0.13711800E+04, 0.45626700E+03, 0.23076500E+04, 0.28542900E+03, -.15429000E+03, -.47060000E+04, -.14446700E+03, 0.12045000E+04, -.42497000E+04, 0.16065600E+04, 0.78349800E+03, 0.70987300E+03, -.28957100E+04, -.16022800E+04, 0.40935300E+04, -.20239000E+04, -.21391500E+04, -.20464400E+04, -.24685800E+04, -.98749800E+04, 0.28531400E+04, 0.12030700E+04, 0.16260500E+04, -.70801900E+04, -.97538500E+02, 0.39963100E+04, -.22775100E+04, -.13829600E+03, -.19985500E+04, 0.69561100E+02, -.73033300E+03, -.11838500E+04, -.10001900E+04, -.20379900E+04, -.34545900E+03, -.17005500E+04, -.16188500E+05, 0.80207200E+04, -.98900300E+04, 0.80939900E+04, 0.83956100E+03, 0.28033800E+04, 0.21327200E+04, -.58510600E+03, 0.71451600E+04, 0.16849100E+04, 0.53972400E+04, -.41521900E+04, 0.22609100E+04, 0.42638000E+03, 0.20757300E+04, 0.30672400E+03, 0.49233100E+03, 0.17719000E+04, 0.19805200E+04, 0.19259700E+04, -.28620900E+02, 0.21380400E+04, 0.22270100E+04, -.11667500E+04, 0.86441600E+04, -.11135100E+04, 0.16102300E+04, -.36383200E+04, 0.14291400E+04, 0.18826200E+04, -.29202800E+02, -.26872200E+04, -.25226700E+04, -.55960300E+04, 0.26656400E+04, 0.23506700E+04, 0.27938300E+04, 0.15464300E+04, 0.21467500E+04, 0.42403100E+03, 0.32703100E+03, 0.28027900E+04, 0.12972400E+04, 0.12527600E+04, -.20428800E+03, 0.99597300E+02, 0.59862400E+04, 0.10443100E+03, 0.13511500E+04, 0.49786700E+04, -.13271300E+04, -.15426200E+03, -.33907100E+04, 0.37932700E+04, -.35336600E+03, 0.29074700E+05, -.14584000E+05, 0.10804700E+05, -.14537400E+05, 0.84756500E+03, -.21053300E+02, -.43368900E+04, 0.23920800E+04, -.13645000E+05, 0.66829600E+03, -.17471800E+05, -.44821600E+04, 0.22925100E+04, -.62238400E+04, 0.22411100E+04, -.10793400E+04, 0.29738300E+04, -.76485700E+03, -.13104700E+04, 0.15327300E+04, 0.20321600E+04, 0.35924500E+04, 0.24460100E+05, -.12164300E+05, 0.14530400E+05, -.12229300E+05, -.59602600E+03, -.30885800E+03, -.32245100E+04, 0.25810100E+04, -.11116400E+05, 0.16785200E+03, -.89720600E+04, 0.97256800E+04, -.49078200E+04, 0.20529100E+04, -.48629200E+04, 0.11206400E+04, 0.71945900E+04, -.44712200E+04, 0.23526400E+03, -.30921200E+04, 0.50765400E+04, -.61031700E+04, 0.42567400E+04, -.21396900E+04, -.22188000E+03, -.21282600E+04, 0.92622100E+03, -.41310700E+04, 0.29397400E+03, -.21888500E+03, -.27214500E+04, -.29083900E+04, -.40017100E+04, 0.95894300E+04, -.48578900E+04, 0.55724500E+04, -.47947600E+04, 0.13826700E+04, 0.16195500E+04, -.20579700E+04, 0.16976500E+04, -.36858800E+04, 0.12644400E+04, -.53459400E+04, -.45850100E+04, 0.22816500E+04, -.32835000E+04, 0.22928600E+04, 0.11047000E+03, 0.24109600E+04, -.44244900E+03, -.24566700E+03, 0.23512500E+04, 0.18906500E+04, 0.29628500E+04, 0.75484200E+04, -.36258200E+04, 0.53606300E+04, -.37736100E+04, -.48219600E+03, -.45400600E+03, -.17520200E+04, -.50333900E+03, -.27989800E+04, -.43764900E+03, -.38081500E+04, -.20080400E+04, 0.13390100E+04, -.13437100E+04, 0.84107700E+03, -.18715600E+04, 0.10728800E+04, 0.27614700E+03, 0.11394300E+04, 0.12077200E+04, -.25807900E+04, -.45031700E+04, -.13493900E+04, 0.35090400E+04, -.12055300E+04, 0.13893600E+04, 0.10137900E+04, -.40073300E+04, 0.19123700E+04, 0.88746900E+03, -.27385800E+03, -.64387400E+04, -.19097200E+04, 0.17748000E+04, 0.90946300E+03, 0.14448300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44705200E+00, 0.10704500E+00, 0.61701800E+00, -.62430800E-01, 0.85785700E+00, 0.87382500E-01, -.25957600E+00, 0.29030700E+00, -.85446900E+00, -.16621500E+00, -.76655900E-01, 0.15674000E+01, -.47022300E+00, -.53787600E+00, 0.57079200E+00, -.54776700E+00, -.96486600E+00, -.39081900E+00, -.10591900E+00, -.13094500E+01, 0.83087700E+00, -.17375400E-01, 0.28268700E-01, -.87348400E+00, 0.74209300E-01, 0.82902900E-02, -.25465000E+00, 0.14275800E+00, 0.25869100E+00, 0.11400300E+00, -.11431300E+00, -.18544600E+00, 0.24891300E+00, 0.67459100E-01, 0.20148400E+00, -.44536800E+00, -.90599800E-02, -.34617800E+00, 0.53142800E-01, 0.21567800E+00, 0.13373800E+00, 0.39192400E+00, -.34284900E+00, 0.95249000E-01, 0.10873100E+00, 0.87342200E-02, 0.41172600E+00, -.35757600E-02, 0.81626000E+00, -.63655000E+00, -.88574000E+00, -.17017300E+00, -.10524000E+00, -.20280800E+00, -.28774100E+00, 0.33781400E+00, -.16909000E+03, -.11153800E+04, -.26767300E+00, 0.14298400E+04, 0.67075900E+03, -.65742100E+03, -.14204200E+04, -.69421800E+03, 0.62754800E+03, -.39400800E+03, -.82331400E+02, 0.18070400E+03, 0.35269300E+04, 0.43419700E+02, 0.74146100E+03, 0.26817000E+04, -.64489700E+03, 0.82266400E+03, 0.41881600E+03, 0.17503000E+04, -.17319100E+04, -.38623500E+03, -.77925100E+03, -.10904200E+04, 0.19259400E+03, 0.16032300E+03, 0.51770700E+03, -.42615600E+03, -.72552000E+03, -.62038700E+02, 0.17226500E+03, -.68751500E+03, -.49167000E+03, 0.24896500E+03, 0.22760900E+04, 0.24425900E+03, -.19180300E+04, -.71511600E+03, 0.14666300E+04, 0.12566200E+04, 0.93572400E+03, -.14664700E+03, 0.26743400E+04, -.49519200E+04, 0.23385200E+04, 0.55041800E+04, 0.24762400E+04, -.19021700E+01, 0.43906200E+04, -.21584000E+04, -.38385900E+04, -.13516900E+04, 0.31318400E+04, -.16272500E+04, 0.18745600E+04, 0.37672400E+02, 0.18457300E+04, -.93770700E+03, 0.17060500E+04, 0.28049600E+04, -.13048100E+04, -.23667500E+03, -.90633100E+03, 0.23509500E+04, -.10467800E+03, 0.34620500E+04, -.11922300E+04, 0.29009100E+04, -.17312400E+04, 0.22960200E+04, 0.94221200E+03, -.26917900E+03, -.13854400E+04, -.43246300E+04, 0.14157000E+04, 0.60774600E+03, -.28604200E+03, -.48630800E+03, -.32382000E+04, 0.14272100E+03, -.20688500E+04, -.27062900E+04, 0.68456200E+03, 0.24817400E+03, 0.49078200E+03, -.21993100E+04, -.16005400E+04, -.15231000E+05, 0.80580200E+04, 0.84549500E+04, 0.76154900E+04, -.18175100E+04, -.46220900E+04, 0.50020300E+04, -.12112500E+04, 0.27601400E+04, -.15937100E+04, 0.45514900E+04, -.12203200E+04, 0.53908300E+02, -.45417900E+04, 0.60585400E+03, -.92420200E+03, -.29631500E+04, 0.90698900E+03, -.14425000E+04, -.17353200E+03, -.20204700E+04, 0.22408100E+04, 0.49975500E+04, -.21358200E+04, -.45487500E+04, -.24992100E+04, 0.20337300E+04, -.19620600E+04, 0.18723200E+03, 0.19309000E+04, 0.92300000E+03, -.11713700E+04, -.73441300E+03, -.14120500E+05, 0.76880800E+04, 0.40834800E+04, 0.70601500E+04, 0.39158700E+04, -.31826300E+04, 0.59040200E+04, 0.35173000E+04, 0.59274700E+04, -.21690200E+04, 0.11296100E+05, 0.11446300E+05, -.61325400E+04, -.73181400E+04, -.57231300E+04, 0.13260900E+04, 0.38118200E+04, -.42259800E+04, -.85210500E+02, -.23530000E+04, 0.15929900E+04, -.42595700E+04, -.24338600E+04, 0.55821000E+03, -.17757300E+04, 0.12176000E+04, -.45643700E+03, -.19340600E+03, 0.20549000E+03, 0.22632400E+04, 0.34459800E+04, -.65969700E+03, -.15815700E+04, -.48429000E+04, 0.24215800E+04, -.15826900E+02, 0.24213700E+04, -.43413000E+03, -.25714000E+04, 0.28985800E+04, 0.25127100E+04, 0.21790500E+04, -.18359400E+04, 0.44329500E+04, -.33457400E+04, 0.21464900E+04, 0.19622800E+04, 0.16729700E+04, -.90648100E+03, 0.36715000E+01, 0.16824000E+04, 0.85661300E+03, 0.83448300E+03, 0.39975500E+03, 0.57138700E+04, -.15870700E+05, 0.80980800E+04, 0.59480600E+04, 0.79353300E+04, 0.87298200E+03, -.34435700E+04, 0.33412000E+04, -.26697100E+04, 0.42592100E+04, -.13056500E+04, 0.59197900E+04, 0.21874500E+03, 0.11167100E+03, 0.12531200E+04, -.10907200E+03, 0.35642200E+03, -.10536400E+03, -.48157800E+03, -.11362900E+04, -.11067200E+04, 0.68702100E+02, -.12341900E+04, -.11842900E+04, -.11313200E+03, -.31765800E+03, 0.59270300E+03, 0.39572300E+03, 0.13316700E+04, 0.40707300E+03, 0.62313600E+03, -.86028700E+02, 0.82471000E+03, 0.18919500E+04, 0.24683400E+03, -.12350600E+02, -.54612500E+03, -.84676200E+01, -.49852100E+03, -.68136700E+03, -.71415000E+03, 0.17291000E+03, 0.56751400E+03, 0.25288000E+03, -.42457100E+03, -.98001700E+03, -.52482300E+03, -.91998400E+02, 0.83926800E+03, 0.67019700E+02, -.11735500E+04, -.73681000E+02, 0.19292900E+02, 0.92247200E+02, 0.74959900E+03, 0.17959600E+03, -.30307000E+03, -.15485200E+03, 0.12481200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12318100E+00, 0.29023400E-01, 0.67062800E-01, -.10620800E+00, -.20236200E+00, -.60344800E-01, 0.25716700E+00, 0.24557600E+00, -.26345800E+00, -.14995200E+00, -.33207200E-01, -.87836400E+00, 0.21208500E+00, -.45592200E-01, -.10616200E+00, -.24139400E+00, 0.29334500E+00, 0.26745800E+00, -.12877600E+00, 0.57032100E+00, 0.24231700E+00, -.25457700E-01, -.11066400E+00, -.39332000E+00, -.22079400E-01, -.30497100E-01, 0.51413500E+00, -.19146400E-01, 0.18642500E+00, 0.44267000E+00, 0.46923800E-01, -.46887400E-02, 0.10489900E+00, 0.11787400E-01, -.99450600E-01, -.81027200E-01, -.77793500E-02, 0.19650600E+00, 0.32838500E-01, 0.31585500E+00, -.41084400E-01, -.43844600E-02, -.33995100E+00, -.73853500E-01, -.46465900E-01, 0.16119400E+00, -.49439300E-01, -.26853500E-03, -.74611500E-02, -.29436300E+00, -.38649000E+00, 0.30709300E+00, -.49779700E-01, 0.51070900E-01, -.24035700E-01, -.12678400E-01, -.92626200E-01, 0.10594200E+04, -.54827600E-01, 0.68659800E+03, 0.39250200E+03, -.93503900E+02, 0.19619600E+03, -.47608100E+02, 0.27159900E+03, -.25291700E+03, -.72151200E+03, 0.30905000E+03, 0.55025300E+03, 0.36123900E+03, 0.43776800E+03, 0.14532900E+04, -.35360800E+03, 0.35127400E+03, 0.43639500E+03, 0.10257500E+04, 0.19968300E+02, -.76808200E+00, 0.25351900E+01, -.58456000E+03, 0.26949700E+00, 0.27812900E+03, 0.41224400E+03, -.28944700E+03, -.31649000E+03, -.56608700E+02, 0.24345000E+03, -.36177400E+03, 0.16147000E+04, -.80899200E+03, 0.41960100E+03, -.80767700E+03, -.10081300E+04, -.49032000E+03, -.18749700E+01, 0.15405200E+03, -.66283600E+01, -.63196900E+03, 0.36047900E+03, -.22155000E+04, 0.11199300E+04, 0.71159800E+03, 0.11078100E+04, 0.43572700E+03, 0.13436900E+04, 0.10326600E+03, -.53683900E+03, -.22087500E+02, 0.74445900E+03, -.58616100E+03, 0.19796600E+04, -.98823000E+03, 0.47808800E+03, -.98992500E+03, 0.49133800E+03, 0.10834600E+04, -.76160300E+03, -.19909700E+03, -.93400400E+03, 0.10238600E+04, -.42083000E+03, -.19966800E+04, 0.94838100E+03, 0.15093400E+04, 0.99829700E+03, 0.96311200E+03, 0.11369800E+04, -.10581200E+04, -.22254400E+04, -.97905700E+03, 0.14085500E+04, 0.12976700E+04, -.23825800E+04, 0.11787800E+04, -.89440800E+02, 0.11912300E+04, -.68805100E+03, -.13624500E+04, 0.91402900E+03, 0.51061600E+03, 0.11912800E+04, -.12316200E+04, 0.33137200E+03, 0.59894600E+04, -.30295900E+04, 0.21902600E+04, -.29947300E+04, 0.14170100E+03, 0.14106800E+04, -.14512900E+04, 0.71131700E+03, -.35304900E+04, 0.14786100E+04, -.31790000E+04, 0.76809200E+02, 0.41313900E+02, -.90656200E+03, -.39327200E+02, -.38383200E+03, -.14123600E+04, 0.34424200E+03, -.57754200E+03, -.24661100E+03, -.10234100E+04, 0.20603400E+03, 0.24796400E+04, -.12897100E+04, -.12380100E+04, -.12397500E+04, 0.21203000E+03, -.74778900E+03, -.39044300E+03, 0.60603300E+03, 0.21888200E+03, -.40471300E+03, -.21339400E+03, -.56907200E+03, 0.22050800E+03, -.52835200E+02, 0.28451300E+03, 0.63693200E+03, -.10413700E+04, 0.10557700E+04, 0.13805400E+04, 0.17956400E+03, -.67897400E+03, 0.24919200E+04, -.51237700E+04, 0.25949900E+04, -.20294500E+04, 0.25618900E+04, 0.14969400E+03, -.77386400E+03, 0.89080200E+03, -.78666300E+03, 0.27419000E+04, -.81708200E+03, 0.25285500E+04, 0.25029000E+04, -.11827200E+04, -.48092400E+03, -.12513100E+04, -.28065000E+03, -.10601100E+04, 0.92946700E+03, 0.23808000E+04, 0.23415600E+03, -.10231500E+04, -.17444400E+04, 0.10718600E+04, -.51037100E+03, 0.33065800E+03, -.53594500E+03, -.28839800E+03, -.79929200E+03, 0.28330200E+03, 0.46254100E+03, -.82537800E+03, -.27471000E+03, 0.25807900E+03, -.36605000E+03, 0.13104700E+03, -.39634800E+02, 0.18304600E+03, -.44809200E+03, -.24988000E+03, 0.14378200E+03, -.28528000E+03, -.23682400E+03, -.18424400E+03, 0.17463600E+04, -.26443300E+04, 0.13263600E+04, 0.56428100E+03, 0.13221500E+04, 0.43645700E+03, -.35760300E+03, 0.55130000E+03, -.11548600E+03, 0.21707200E+03, 0.55762700E+02, 0.14128700E+04, -.80800400E+03, 0.38269400E+03, 0.89784900E+03, 0.40406200E+03, 0.46470700E+02, -.78034200E+02, -.91848200E+02, -.65305900E+03, -.18997700E+03, 0.82906500E+02, -.82272500E+02, 0.10088700E+04, -.47086500E+03, -.64120000E+03, -.50431900E+03, 0.32655500E+03, 0.59054700E+03, -.19232200E+03, 0.26242100E+03, -.65578800E+03, 0.60464700E+03, 0.34771600E+02, -.38522100E+03, 0.54804400E+02, -.58953700E+03, -.40049500E+02, -.31171800E+03, 0.16182400E+03, 0.85635600E+02, -.62655000E+02, 0.60326800E+03, -.17020700E+03, -.65385600E+01, -.33375300E+03, -.17688500E+03, -.11822700E+03, -.12302000E+03, -.21276800E+02, -.21761700E+03, 0.39144800E+03, -.18263100E+03, -.15626900E+03, 0.37955200E+03, -.22442800E+03, 0.14981500E+03, 0.16757800E+03, 0.29968700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25590200E+01, 0.46084400E+00, -.12178600E-01, -.46672300E+01, -.98213600E+00, 0.32669400E+00, 0.40773500E+01, 0.58599900E+01, -.36322900E+01, -.12982400E+01, -.31352800E+00, -.37078100E+01, 0.37188300E+01, -.55869500E+00, 0.41692300E+01, 0.32210400E+01, 0.11230900E+01, -.20307800E+01, -.73603800E+00, -.92054500E+00, 0.22212300E+01, 0.19092100E+00, -.10765700E+01, -.71086200E+00, -.23587900E+00, -.59186800E+00, 0.33182600E+00, 0.20455700E+00, -.98847900E-01, -.23103300E+00, -.36157000E+00, 0.69914600E+00, 0.14816700E+00, -.11921200E+00, 0.44530800E+00, 0.75976500E+00, 0.36562500E-01, -.81709900E+00, 0.44513600E+00, 0.12355100E+01, -.12745000E+01, -.33985300E+00, -.10127500E+01, -.26105500E+00, -.52386600E+00, 0.90826000E-01, 0.28514100E+00, 0.66559900E-02, -.60068200E+00, -.82765600E+00, -.81588500E+00, -.15669700E+01, -.45886700E-01, -.61942700E+00, -.46392100E+00, -.11468600E+01, 0.20731300E+00, 0.22016000E+01, 0.59312900E+01, -.17357700E+04, -.63500900E+03, 0.40294700E+03, 0.16518700E+04, -.48416500E+03, -.37451400E+03, -.13108300E+04, 0.70453600E+04, -.36806800E+04, -.38051800E+04, -.35257900E+04, -.13909600E+03, -.14923700E+04, -.10822800E+04, -.69606600E+03, -.34188800E+04, -.69636600E+03, -.53799000E+01, 0.11878500E+04, -.33229400E+03, 0.44993400E+03, -.59322800E+03, -.66958700E+03, 0.46156300E+03, 0.30321100E+03, 0.15425200E+04, 0.37777100E+02, 0.60347400E+03, 0.24447400E+04, 0.65343200E+03, -.36366800E+03, -.27266800E+04, -.32460500E+03, -.80518900E+03, 0.19877900E+03, -.19466300E+03, 0.11363200E+04, -.64994300E+03, 0.81203400E+03, -.53317600E+04, 0.26491000E+05, -.13235400E+05, -.14818600E+05, -.13245900E+05, -.56830800E+04, -.96610700E+04, -.12631700E+04, 0.47056700E+04, -.10852800E+04, -.72466300E+04, -.17788200E+04, -.35937500E+04, 0.15259200E+04, -.17237700E+03, 0.17974700E+04, -.10242500E+04, -.35312500E+04, 0.16273300E+04, 0.19270500E+04, 0.21571400E+04, -.34142600E+04, -.37657700E+04, -.63227800E+04, 0.31586100E+04, -.10485300E+05, 0.31616700E+04, -.82181800E+03, -.39467400E+03, 0.48099400E+04, 0.55396900E+04, 0.82456400E+04, -.23183800E+04, -.14297900E+04, 0.63565300E+04, -.29938700E+04, -.12567600E+04, -.31778800E+04, 0.18496700E+04, 0.35575100E+04, -.24008200E+04, -.32143300E+04, -.37622600E+04, 0.35365600E+04, 0.47350600E+04, -.15078900E+05, 0.75546000E+04, 0.35641500E+04, 0.75394400E+04, -.29672300E+04, -.73649700E+04, 0.64643100E+04, 0.23801100E+03, 0.11110400E+05, -.64019100E+04, 0.10368700E+05, -.38753300E+04, 0.22318900E+04, 0.32024400E+04, 0.19435800E+04, -.24637900E+03, 0.92460100E+03, 0.12303500E+04, 0.20905700E+04, 0.37282100E+04, 0.30577800E+03, -.91461400E+03, -.10914900E+05, 0.55184900E+04, 0.10820000E+05, 0.54613300E+04, 0.67193100E+03, 0.56571900E+04, -.61573700E+03, -.25967500E+04, -.46007400E+04, 0.39257700E+04, -.37780500E+04, 0.14768500E+05, -.73221600E+04, 0.57448400E+04, -.73840800E+04, -.54355400E+04, 0.41191900E+02, -.36900500E+04, 0.19365900E+04, -.59326100E+04, -.87986700E+03, -.25098200E+05, 0.12594000E+05, -.63060100E+04, -.23732700E+04, -.62970500E+04, 0.14138500E+04, 0.43475400E+04, -.38170800E+04, 0.43166900E+03, -.78670900E+04, 0.33460400E+04, -.70494000E+04, 0.59294600E+04, -.29918900E+04, 0.70200500E+04, -.29656300E+04, 0.12756900E+04, 0.38538100E+04, -.51600700E+04, -.39848500E+04, -.70447500E+04, 0.40259300E+04, 0.25533600E+04, -.13396400E+04, 0.61795300E+03, 0.50571000E+04, 0.66992300E+03, 0.40044100E+04, 0.60735000E+04, -.15582300E+04, -.84225000E+03, 0.20173000E+04, 0.42734900E+04, -.25000200E+03, -.12602900E+04, 0.69134200E+03, -.17270400E+03, 0.63001400E+03, -.16901100E+04, -.33191700E+04, 0.63433600E+03, 0.16543100E+04, 0.92903000E+03, -.28326100E+04, -.12820100E+05, 0.41753200E+04, -.21386500E+04, 0.92174200E+03, -.20876000E+04, -.65435600E+03, 0.24368600E+04, -.19759000E+04, 0.31544600E+03, 0.88966000E+03, 0.85135400E+03, -.10395400E+04, 0.23524500E+04, -.11451600E+04, -.28401200E+04, -.11766200E+04, 0.61047100E+03, 0.15729300E+04, -.64403400E+03, 0.17867100E+04, 0.10756900E+04, 0.10344300E+04, 0.14531100E+04, 0.42860900E+03, -.12338400E+03, 0.11049800E+04, -.21505300E+03, -.40925000E+03, -.37388000E+04, 0.75998500E+03, 0.14489700E+04, 0.26754500E+04, -.36911500E+04, -.67219800E+04, -.35305000E+03, 0.33121700E+03, -.18796400E+03, -.20677900E+03, -.19258400E+03, 0.44838100E+03, 0.49015600E+03, -.53720000E+03, -.74747700E+01, -.30288000E+03, -.16286700E+04, 0.15971300E+04, 0.14455500E+04, 0.77314900E+03, -.45566800E+02, -.36629500E+03, 0.55659300E+03, 0.13537600E+04, -.23767800E+03, -.83934000E+03, -.38794900E+04, -.21299600E+04, 0.10732600E+04, 0.20882500E+03, 0.28085200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.61031900E+00, -.21713900E+00, 0.42758000E+00, -.45132400E-01, 0.36802100E+00, -.24629600E-01, -.71555000E-01, 0.77166700E+00, 0.41667500E-01, 0.24238500E+00, -.14940600E+00, 0.16102900E+01, 0.13252300E+01, 0.89849000E-01, 0.22027600E+01, -.88653100E+00, -.96638500E+00, -.16694200E+00, -.55754100E+00, -.82761800E+00, 0.68278900E+00, -.13591100E+00, 0.60496800E-01, -.81062400E+00, -.81578100E-02, 0.16133200E+00, -.17372800E+01, 0.16714000E-01, 0.52989100E+00, 0.12343400E+01, -.23302900E+00, -.80394100E+00, 0.14813000E+01, 0.38057000E-01, 0.22884100E+00, -.29362500E-01, 0.19690900E-01, 0.86854100E+00, -.43053400E+00, 0.11614400E+01, -.10735100E+01, -.19918900E+00, -.33423600E+00, -.69772100E-02, -.46053500E-01, -.25824200E-01, 0.22745400E+00, 0.19526900E-03, -.89298100E+00, -.12662100E+00, -.40444700E+00, 0.18603900E+01, -.20545100E+00, 0.29044000E+00, 0.44062300E+00, -.40167500E-01, -.45243200E+00, -.27442500E+00, -.80462700E-01, 0.32436600E+04, 0.83804800E+03, -.87838500E+03, -.85480900E+03, -.98345900E+02, 0.55060900E+03, -.16623400E+04, -.10572100E+04, 0.48165300E+03, 0.10412600E+04, 0.53221400E+03, 0.73403700E+02, 0.12234900E+04, 0.42005600E+02, 0.79395400E+03, 0.11059800E+04, 0.73631200E+03, -.37228300E+03, -.58027700E+03, 0.16904000E+03, -.12868800E+04, 0.28938800E+03, 0.35642900E+03, 0.52768700E+03, -.44303500E+03, -.79453600E+03, 0.14988900E+03, 0.25939400E+03, -.79713600E+03, 0.21116300E+03, -.92634300E+02, -.13942400E+04, -.10819900E+03, -.19170000E+03, 0.75247800E+02, -.65313600E+02, -.41531500E+03, 0.10236900E+04, -.18710500E+02, 0.34694500E+04, 0.16051800E+03, -.87114500E+02, 0.22016400E+04, -.79786700E+02, 0.65323500E+03, 0.33456000E+04, -.14258700E+04, -.16729600E+04, -.21038300E+04, 0.30163900E+04, -.47668300E+04, 0.32823300E+04, -.15061500E+04, 0.92115700E+03, -.16418300E+04, 0.78587600E+03, 0.14664200E+04, -.16798700E+04, -.99922100E+03, -.15735300E+04, 0.10018000E+04, -.46784100E+03, 0.55632500E+04, -.27690600E+04, 0.26334000E+04, -.27819800E+04, -.73232000E+03, -.27027000E+03, -.63203500E+03, -.96557900E+03, -.53373200E+04, -.20846200E+03, -.15970200E+04, -.29098000E+04, 0.13605900E+04, -.71858900E+03, 0.14544100E+04, -.13149600E+04, -.17142000E+04, 0.17324400E+04, 0.14801700E+04, 0.16722700E+04, -.11362300E+04, -.19543300E+03, -.46707400E+04, 0.23317900E+04, 0.25146400E+04, 0.23353600E+04, 0.24448500E+04, -.17366800E+03, 0.42167400E+03, -.90103700E+03, 0.47514200E+03, 0.96659900E+03, -.23123200E+04, -.87367400E+03, 0.45224400E+03, -.18899600E+04, 0.43000800E+03, -.27765000E+02, -.91754900E+03, -.22026100E+02, -.15363200E+04, -.80423000E+03, -.51182900E+03, 0.11871000E+04, 0.24341800E+04, -.12411900E+04, -.28042000E+04, -.12170400E+04, 0.92526200E+03, -.14874000E+04, -.30156200E+03, 0.10390000E+04, 0.15334600E+04, -.16818400E+04, 0.76646700E+03, -.35622900E+04, 0.17605900E+04, 0.54439700E+02, 0.17809600E+04, 0.26909900E+04, -.18796700E+04, 0.13206300E+04, 0.12543300E+04, 0.25745900E+04, -.23016000E+04, 0.78869100E+04, 0.39008100E+04, -.19484900E+04, -.27092800E+04, -.19503600E+04, -.19320600E+04, 0.20901800E+03, -.47450200E+03, 0.29550200E+03, -.62752500E+03, -.51340100E+03, 0.80423600E+03, -.17028700E+04, 0.85242100E+03, 0.18734900E+03, 0.85250200E+03, 0.21507400E+04, -.15545600E+03, 0.50242000E+00, 0.15860700E+04, 0.31930400E+04, -.15200900E+03, -.64390300E+03, -.38977500E+04, 0.19697900E+04, -.15995000E+03, 0.19487500E+04, -.16483900E+04, -.25951200E+04, 0.20759600E+04, 0.88879700E+03, 0.12628900E+04, -.20259600E+04, 0.54970300E+04, 0.89062100E+03, -.47295100E+03, 0.18284600E+04, -.44515200E+03, -.83953600E+03, -.61637800E+03, 0.59621400E+02, 0.53315900E+03, 0.14139000E+03, -.64486800E+03, 0.36560700E+04, -.51673100E+04, 0.26122500E+04, 0.15777100E+04, 0.25835800E+04, 0.15095400E+04, -.15004100E+04, 0.33777400E+03, -.15775700E+04, 0.15441500E+04, -.49983600E+03, 0.51676100E+03, -.13765800E+04, 0.67709800E+03, -.10864800E+03, 0.68881000E+03, -.46805000E+03, -.76880000E+03, 0.22962400E+03, -.45294000E+03, 0.71848000E+02, -.47201000E+03, -.92802900E+03, 0.14968300E+04, -.80036900E+03, 0.11446400E+04, -.74750400E+03, -.18630100E+03, 0.50550400E+03, 0.15097300E+03, 0.11241100E+04, -.61233600E+03, 0.20360100E+03, 0.22521900E+03, -.15928200E+03, -.17037100E+02, -.24622200E+03, 0.72007100E+03, -.42773900E+02, 0.70208000E+03, 0.62847700E+03, 0.86220500E+03, 0.28091100E+03, -.58690600E+02, 0.85253100E+03, -.16269200E+04, -.58782100E+03, -.94529600E+03, 0.51668700E+03, 0.75751600E+03, 0.55828200E+03, 0.39177700E+02, 0.19284000E+03, -.12762900E+03, 0.15848600E+04, 0.54160700E+02, -.29445000E+03, -.70640500E+02, 0.37753900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.23238500E+01, -.90563200E+00, -.67995600E-01, -.77385300E+00, -.25032700E+00, -.16224500E+00, 0.26813700E+00, -.29085400E+01, -.47056700E+01, -.70870600E+00, 0.12169600E+01, 0.34047900E+01, 0.10711500E+01, 0.55602200E+00, 0.23579400E+01, -.18719500E+01, -.16442700E+01, 0.11359200E+00, -.19180300E+00, -.65631400E+00, -.85974100E+00, -.52757900E+00, -.16403300E+00, -.21677500E+01, 0.10461400E+00, 0.24338400E-02, -.36754300E+00, -.85727600E-01, -.35915700E+00, -.12161400E+01, -.32400000E+00, 0.47606900E+00, -.54058800E+00, 0.12816400E+01, 0.12561600E+00, -.35781300E+01, -.12706900E+00, -.70465300E+00, 0.82816800E+00, -.11885000E+01, 0.13480200E+01, 0.33318500E+00, -.28469400E+00, -.12214200E+01, 0.63882800E+00, 0.16283400E+01, 0.13770100E+01, -.26139500E-01, 0.68887200E+00, -.15687800E+01, -.22930400E+01, -.68970300E+01, -.27015200E+00, -.15609400E+01, -.31212800E+00, -.39452700E+00, 0.22712600E+01, 0.12281400E+02, -.80637700E-01, -.36434100E+00, -.44382900E+04, 0.19124000E+04, 0.14410200E+04, 0.72855700E+03, -.36984400E+04, -.47777300E+04, 0.10907900E+05, -.55453600E+04, -.11332800E+05, -.54499500E+04, -.58740900E+04, -.14488800E+05, 0.19081400E+04, -.29355700E+04, -.36326600E+04, -.10701000E+05, 0.21272400E+04, -.46478900E+04, 0.23109600E+04, 0.10718500E+04, 0.23231100E+04, -.23354200E+04, -.33136500E+04, 0.26906300E+04, 0.18705100E+04, 0.26607200E+04, -.14666300E+04, 0.62371900E+04, -.19747000E+05, 0.99923200E+04, -.14635000E+05, 0.98699700E+04, 0.12148300E+05, -.14313100E+04, -.67839500E+03, -.46391200E+04, 0.36709900E+04, -.32465900E+02, -.45331300E+04, 0.33646900E+05, -.16970500E+05, -.94009700E+04, -.16822800E+05, -.72536300E+04, -.20761500E+05, 0.41225600E+03, 0.67788100E+04, -.19102000E+03, -.14245300E+05, -.25338400E+04, -.85415800E+04, 0.43248800E+04, -.42026800E+04, 0.42701200E+04, -.44882400E+04, -.11201100E+05, 0.34353800E+04, -.12554300E+03, 0.36538400E+04, -.11406900E+05, -.31954200E+04, 0.50098200E+04, -.19948800E+04, -.24084400E+05, -.25053900E+04, -.10861300E+05, -.94162900E+04, 0.12696900E+05, 0.17382100E+05, 0.12595600E+05, -.13091900E+05, -.10931200E+05, 0.11932500E+05, -.58898800E+04, 0.17476900E+04, -.59670000E+04, 0.61648300E+04, 0.13621600E+05, -.35639300E+04, -.63423400E+03, -.55448200E+04, 0.13043700E+05, 0.57036100E+04, -.46173500E+05, 0.23360500E+05, -.10506100E+05, 0.23086800E+05, 0.36242700E+04, -.15166800E+05, 0.10373600E+05, -.91894800E+04, 0.32001200E+05, -.14698800E+05, 0.27353300E+05, -.91644600E+04, 0.46511500E+04, 0.11046500E+05, 0.45746500E+04, 0.55551600E+04, 0.14487600E+05, -.13171300E+04, 0.53628700E+04, 0.48889700E+04, 0.10915800E+05, -.24866000E+04, -.25172700E+05, 0.13022700E+05, 0.15676200E+05, 0.12589000E+05, 0.12949800E+04, 0.12105300E+05, 0.14109300E+04, -.34201500E+04, -.21796000E+04, 0.65107800E+04, -.23331800E+04, 0.42114200E+05, -.20515200E+05, 0.37429600E+04, -.21057300E+05, -.38588100E+03, 0.11557700E+05, -.18775100E+05, -.87765600E+04, -.15718100E+05, 0.60336600E+04, -.49679900E+05, 0.38911700E+05, -.19737800E+05, 0.12926700E+05, -.19455800E+05, -.52888100E+04, 0.10168300E+05, -.62779000E+04, 0.86472200E+04, -.23808300E+05, 0.89783500E+04, -.19394600E+05, -.51375800E+04, 0.19124100E+04, 0.16862500E+05, 0.25701100E+04, 0.65489600E+04, 0.86163200E+04, -.10280500E+05, -.14317600E+05, -.84981400E+04, 0.95254100E+04, 0.14499500E+05, 0.15470000E+04, -.96987200E+03, -.69090000E+04, -.77365800E+03, 0.16971700E+04, 0.11589400E+05, -.60847600E+04, -.60359100E+04, 0.11754300E+04, 0.79737500E+04, 0.31988600E+04, 0.75969900E+04, -.34420900E+04, -.34337100E+04, -.37982900E+04, 0.22117300E+04, -.44217700E+04, -.15622500E+04, 0.29613000E+04, 0.18874500E+02, -.53674700E+04, -.25262500E+05, 0.31121900E+05, -.15636600E+05, -.34750800E+04, -.15561000E+05, 0.41744200E+03, 0.71928500E+04, -.94259900E+04, 0.33331600E+03, -.37917600E+04, 0.26450900E+04, -.11523200E+05, 0.45736900E+04, -.21310100E+04, -.10893300E+05, -.22860900E+04, -.14205300E+03, 0.41622400E+04, -.95665400E+02, 0.65496700E+04, 0.45274800E+04, 0.21225700E+04, 0.31285100E+04, -.14553100E+04, 0.48473300E+03, 0.11519500E+05, 0.72884000E+03, -.64628100E+04, -.85519200E+04, 0.25482500E+04, 0.22805100E+04, 0.46742700E+04, -.86824100E+04, -.82567400E+04, 0.26915100E+04, -.40776300E+03, 0.31484200E+04, 0.18962300E+04, 0.29853100E+04, 0.12585600E+03, 0.23603100E+03, 0.23201100E+04, -.34816000E+04, -.36415400E+03, -.36137000E+04, 0.12009300E+03, 0.52272200E+04, -.11643800E+04, 0.48616300E+04, 0.18344500E+04, -.12263400E+04, -.80095700E+03, 0.55697400E+04, 0.19280700E+04, -.85571800E+04, -.75275400E+03, -.63887400E+03, -.14000900E+04, -.14754600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12229500E+01, 0.98284500E+00, -.13109100E+01, 0.13689400E+00, -.77930100E+00, 0.62980000E-01, -.69276000E+00, -.89192000E+00, 0.19638000E+01, 0.56395700E-01, 0.35163600E+00, -.30201000E+01, -.24196300E+01, 0.13012700E+01, -.45855100E+01, 0.22416800E+01, 0.13727700E+01, 0.98391100E+00, -.45556300E+00, 0.18721400E+01, -.32610700E+01, -.80065800E-01, 0.20345000E+01, 0.88120600E+00, 0.40115400E-01, -.19642000E+00, 0.38157700E+00, -.39281100E+00, -.38842900E+00, 0.17635300E+00, 0.13964900E+00, -.22000100E+00, -.70853400E+00, 0.23439200E+00, -.11329500E+01, 0.12191700E+01, -.26806800E-01, -.21621700E+00, -.85316500E+00, 0.48752300E-01, -.39296900E+00, -.79028200E+00, 0.36500900E+00, -.19848500E+00, -.25536400E+00, 0.92212400E-01, -.20942200E+00, -.84822600E-02, 0.11180200E+01, -.42760300E+00, 0.14339600E+01, 0.46076400E+01, 0.31596200E+00, 0.21873100E+01, 0.36525700E+00, -.10117000E+01, -.16844700E+00, 0.15085700E+00, 0.52576200E-01, 0.12210700E-01, 0.23676500E+00, 0.15451000E+04, 0.32657400E+04, -.20027000E+03, 0.55491600E+03, 0.16562700E+03, 0.72659300E+04, -.32478100E+04, -.69474500E+04, -.36365500E+04, 0.18603100E+04, 0.41227800E+04, -.32576200E+04, -.49888500E+03, -.40427700E+04, 0.35620400E+04, -.10587200E+04, 0.33462000E+04, -.14702500E+04, -.10338000E+04, -.16723700E+04, -.31221900E+03, -.38426400E+02, 0.26546100E+03, 0.20896500E+04, -.25885900E+03, 0.35658100E+02, 0.89253600E+03, 0.61007900E+04, -.30972200E+04, 0.35325600E+04, -.30478100E+04, 0.23968500E+04, -.47229900E+03, 0.29904200E+03, 0.46612300E+04, -.16964600E+04, -.16269100E+03, -.11034800E+05, 0.11468100E+05, -.56792200E+04, 0.55851100E+03, -.57345000E+04, 0.10177500E+04, 0.42043100E+04, -.24948700E+04, 0.24754500E+04, -.32241900E+04, 0.55833300E+04, 0.12116800E+04, -.53329300E+04, 0.24062100E+04, 0.33331500E+04, 0.26671200E+04, 0.64566700E+03, 0.86942300E+03, 0.70985500E+03, -.58659100E+03, 0.86839100E+03, 0.13816700E+04, -.13882200E+04, -.30815500E+04, 0.13606100E+04, -.33956200E+04, 0.15411200E+04, -.22924600E+04, -.34356200E+04, 0.24641200E+03, -.48856600E+03, 0.41854500E+04, -.29120000E+04, 0.13718200E+03, 0.55631000E+04, -.26494700E+04, -.16420200E+04, -.27810700E+04, -.45164200E+03, -.23162300E+04, -.42425200E+03, 0.60874000E+03, -.50673600E+03, -.26876800E+04, 0.26325500E+04, 0.35027200E+05, -.17591200E+05, -.58633700E+04, -.17513600E+05, 0.18451900E+04, 0.96255300E+04, -.81094200E+04, 0.74995100E+04, -.11895400E+05, 0.57189300E+04, -.79404300E+04, -.69099400E+04, 0.29958700E+04, 0.75042900E+04, 0.34617400E+04, -.20147600E+04, -.47560300E+04, 0.36523300E+04, 0.13550400E+04, 0.44022000E+04, -.40535200E+04, 0.13129000E+04, -.50811600E+04, 0.24556800E+04, -.21486800E+04, 0.25424900E+04, -.14927300E+04, -.31111800E+04, 0.16828100E+04, -.20294400E+04, -.70753000E+03, -.22219300E+04, -.42172200E+04, 0.65767000E+04, -.34199300E+04, -.25446500E+04, -.32881700E+04, -.11178300E+04, -.45400700E+03, -.19196500E+04, 0.54541700E+03, -.29118600E+04, 0.13340100E+04, -.18833600E+05, -.27756700E+05, 0.13960700E+05, 0.41474200E+04, 0.13878300E+05, -.12789800E+04, -.78799800E+04, 0.69083300E+04, -.43429500E+04, 0.95637100E+04, -.48788800E+04, 0.75495600E+04, -.59025700E+04, 0.31486400E+04, 0.10160600E+04, 0.29502300E+04, 0.18709000E+04, 0.19083300E+04, 0.19736800E+04, -.15160300E+04, -.11301200E+04, 0.76546200E+03, 0.44716700E+04, -.77432800E+04, 0.38906100E+04, -.17311300E+04, 0.38717600E+04, -.68603300E+03, -.23337300E+04, 0.17884000E+04, -.10122100E+04, 0.47666600E+04, -.47958400E+04, 0.24004100E+04, 0.10093800E+05, -.50986600E+04, 0.45604300E+04, -.50470800E+04, 0.38324500E+04, 0.19713500E+04, -.42126900E+04, 0.50096200E+03, -.41550000E+04, 0.34482200E+04, -.17077200E+05, 0.70941000E+04, -.35857000E+04, -.30780500E+04, -.35469800E+04, -.14392100E+03, 0.33321400E+04, -.83900200E+03, 0.44734500E+04, -.20435700E+04, 0.11925500E+04, -.79843200E+03, -.60458100E+04, 0.29968300E+04, -.16369000E+04, 0.30223900E+04, -.21204500E+04, -.14826900E+04, 0.10442300E+04, -.23716700E+04, 0.16348600E+04, -.12422300E+04, 0.62726100E+04, 0.25525500E+04, -.11100600E+04, 0.13868400E+04, -.12771700E+04, 0.21003100E+04, 0.29949700E+04, -.30857700E+04, -.32269100E+04, -.39774400E+04, 0.36550300E+04, -.54720400E+04, -.22279900E+04, 0.19456800E+04, 0.73162200E+03, 0.12861600E+04, -.21724500E+04, 0.27129200E+04, 0.24379000E+04, 0.64641400E+03, -.83864500E+03, -.20129200E+04, 0.25253300E+04, -.16906800E+04, -.20736700E+04, -.15659100E+04, -.50304000E+04, 0.11548600E+04, 0.27613800E+04, 0.53171700E+03, -.43299200E+04, -.21449200E+04, 0.23575900E+04, -.73582200E+03, 0.28310500E+04, 0.19549600E+04, 0.12854000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16255800E+01, -.18714600E+01, -.11039400E+01, 0.21522900E+01, -.96449200E+00, -.43522000E+00, -.72110700E+00, -.37994900E+00, 0.13438600E+00, 0.94934900E-01, -.17865100E+00, 0.15517500E+01, 0.28153600E+01, -.61746800E+00, 0.28729800E+01, -.29205200E+01, -.13835500E+01, -.35629500E+00, -.62652500E+00, -.19991000E+01, 0.65649500E+00, 0.17031200E-01, -.96177900E-01, -.10587600E+00, 0.20663800E+00, -.25170100E-01, -.66017300E+00, -.97391000E-01, 0.73449100E+00, 0.56915600E+00, -.12056800E+01, -.92988300E-01, 0.12807500E+01, 0.69584400E+00, -.82567500E+00, -.10235400E+01, -.10215500E+00, -.24213900E+01, 0.26277500E+00, -.15088200E-01, -.14553800E+01, -.26790200E+00, 0.76718500E+00, -.56869000E+00, -.47324900E+00, 0.91900200E+00, 0.14187300E+01, -.29616400E-01, -.97269200E+00, -.21444200E+01, -.24783800E+01, -.29529300E+01, -.16867000E+00, 0.44825100E+00, -.59926000E-01, -.13266700E+01, 0.14663900E+01, 0.37019400E+01, -.12792000E+00, 0.42467400E+00, 0.59036700E+00, 0.33358300E-01, 0.38806100E+04, 0.12243300E+04, -.45447600E+03, 0.23456700E+04, -.47655900E+04, 0.22324000E+04, -.16018600E+04, 0.23841800E+04, 0.21580900E+04, 0.46944700E+04, -.49795400E+03, 0.67243200E+03, 0.12262800E+04, 0.38117100E+04, 0.23767300E+04, 0.19202500E+04, -.79035500E+03, -.93166000E+02, -.96042300E+03, 0.11375100E+04, 0.12074800E+04, -.94529500E+03, -.70958200E+03, -.14339300E+04, 0.85239100E+03, -.15699500E+04, 0.77037200E+04, -.38638600E+04, 0.38856300E+04, -.38528800E+04, -.24464300E+04, 0.30339500E+03, -.11288500E+04, 0.15099500E+04, -.12954200E+04, -.12128900E+04, 0.11106400E+04, -.16002700E+04, 0.83875200E+03, -.98294000E+04, 0.80031900E+03, 0.10096400E+04, 0.43774200E+01, 0.37453000E+04, 0.45101700E+04, 0.59207800E+04, -.14349800E+04, -.40081400E+03, 0.56159000E+04, -.29713400E+04, -.70112200E+03, -.28082000E+04, 0.12416700E+03, 0.25854700E+03, -.16620000E+04, 0.50372300E+03, -.13123900E+04, 0.62589600E+03, 0.27329100E+03, -.10459500E+05, 0.50819700E+04, 0.27099200E+04, 0.52296100E+04, 0.24312600E+04, 0.20708700E+04, -.27437300E+04, -.75070200E+04, 0.37011600E+01, 0.30578200E+04, 0.31237300E+04, -.91195800E+04, 0.46422900E+04, 0.43622300E+04, 0.45595900E+04, -.44012300E+03, -.12689900E+04, 0.31166300E+04, 0.58889900E+03, 0.21565900E+04, -.13367400E+04, 0.27585100E+03, 0.50535700E+05, -.25361600E+05, -.13330400E+04, -.25267800E+05, -.64785100E+03, 0.94735900E+04, -.10302600E+05, 0.11391200E+05, -.15594100E+05, 0.62982600E+04, -.27324500E+05, 0.56746300E+04, -.25476900E+04, 0.18726500E+04, -.28399400E+04, -.18939400E+04, -.48271800E+04, 0.13431700E+03, -.10083000E+04, -.16106900E+04, -.39375700E+04, -.31212700E+04, -.24423100E+04, 0.11008100E+04, 0.45438400E+04, 0.12239500E+04, -.98254000E+03, -.59402400E+03, -.19542300E+04, -.23074100E+04, -.28117600E+04, 0.57430300E+03, 0.70404200E+04, 0.15439600E+04, -.93781400E+03, -.79541300E+04, -.77205200E+03, -.38882400E+04, -.14700600E+04, -.20490100E+04, 0.80331600E+03, -.17528100E+04, -.11354500E+04, 0.10071400E+05, -.39759300E+05, 0.19970700E+05, 0.24869700E+03, 0.19879700E+05, 0.10896900E+04, -.86517700E+04, 0.89039500E+04, -.73992300E+04, 0.13168200E+05, -.56439300E+04, 0.20827900E+05, 0.36248100E+04, -.16180900E+04, -.51204800E+04, -.18119900E+04, -.21595600E+04, -.24791100E+04, 0.31274700E+04, 0.77787000E+04, 0.23376800E+04, -.24429100E+04, -.33648800E+03, 0.92322700E+04, -.45609100E+04, 0.32479700E+04, -.46161800E+04, -.16800600E+03, 0.56592200E+03, -.26915100E+04, -.85771300E+03, -.42832900E+04, 0.15598100E+04, -.89048700E+04, 0.17540500E+04, -.10111800E+04, -.26798700E+04, -.87696100E+03, -.37842500E+03, 0.20351000E+04, -.26704300E+04, -.14040800E+04, -.17216900E+04, 0.88814600E+03, 0.62110900E+04, 0.19376900E+04, -.98592900E+03, -.10011200E+05, -.96887400E+03, 0.45610700E+03, 0.26133500E+04, -.50956500E+03, 0.44779700E+04, 0.14452700E+04, 0.17060700E+04, -.92369900E+03, 0.96439800E+03, -.53358700E+03, 0.31106500E+04, -.48199600E+03, -.11282200E+03, 0.13389100E+03, -.77726900E+03, -.93740100E+03, -.91729000E+03, 0.58768400E+03, -.22521200E+04, 0.41128200E+04, -.19012800E+04, -.73992500E+04, -.20560600E+04, 0.63149500E+03, -.18770300E+03, -.14564500E+04, 0.19423500E+03, 0.30301800E+03, 0.59936300E+03, 0.23075000E+04, -.16992900E+04, 0.20549800E+03, -.12040800E+04, -.56964700E+03, -.88581800E+03, 0.25894000E+03, 0.16415700E+03, -.11931200E+04, 0.12829700E+04, -.45910700E+03, 0.17396900E+04, 0.81702500E+02, -.22778100E+04, 0.11726800E+03, -.51365100E+04, -.63898900E+03, 0.29543800E+04, 0.11650400E+04, -.49180600E+04, -.21516200E+04, 0.16384900E+04, -.72920700E+03, 0.17571600E+04, 0.73810600E+03, 0.89688100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34923200E+00, -.15317600E+00, -.16335500E+00, 0.49311600E+00, -.46251200E+00, -.12845400E+00, -.28391500E+00, -.42946300E+00, 0.39664100E+00, 0.35436300E+00, 0.65077300E-01, -.24390300E+00, 0.43435200E+00, 0.51816700E+00, -.30302200E+00, 0.39401000E+00, 0.22778200E+00, 0.11710500E+00, 0.26796600E+00, 0.50291100E+00, 0.25802000E+00, 0.23671500E-01, -.37198700E-01, -.12333300E+00, -.10130600E-01, 0.78375900E-04, 0.21251800E+00, 0.13835100E-01, 0.31538600E-01, -.60763300E-01, -.13992600E+00, 0.21179300E+00, 0.12436300E+00, 0.46611200E+00, 0.15374300E+00, 0.44061400E+00, 0.12876400E-01, -.24977200E+00, 0.11042300E+00, 0.11689000E+00, 0.10294800E+00, 0.33651900E-02, -.49145100E+00, -.11016000E+00, 0.18607900E+00, 0.32451600E+00, -.46062000E-01, 0.14772400E-02, -.17761000E+00, 0.16574500E+00, 0.95308300E-01, 0.11195900E+01, 0.23144000E-02, 0.30855400E+00, -.86919200E-01, -.12176000E+00, -.70938200E-01, 0.17246700E-01, -.83225300E-02, -.57289600E-02, -.48705600E-01, -.26008200E+00, 0.18594800E+00, -.35756300E+03, 0.20947200E+03, -.29396000E+03, 0.36554600E+04, -.15960900E+04, -.25437700E+04, -.18283400E+04, -.60162500E+03, -.13896100E+04, -.61731700E+03, -.32344500E+03, -.11257700E+04, -.10363500E+04, -.69810400E+03, -.47383600E+02, 0.16063200E+03, -.14517500E+03, 0.23833600E+02, -.57197900E+03, -.62730400E+03, 0.61420000E+03, 0.97926200E+03, 0.55977700E+03, -.39941800E+03, 0.11884300E+04, -.89166400E+03, 0.41508300E+03, -.13774800E+04, 0.44624100E+03, 0.20559400E+04, -.43516700E+03, 0.40359900E+03, 0.13726700E+04, 0.52016900E+03, 0.32223900E+03, -.43342300E+04, 0.10086800E+05, -.50158500E+04, 0.99201300E+03, -.50434500E+04, 0.28431700E+03, -.52994600E+03, -.25178100E+04, 0.35604000E+03, -.36901800E+04, 0.11154500E+04, -.12089800E+04, -.39404900E+04, 0.18049500E+04, 0.41867900E+03, 0.19703700E+04, -.63524000E+02, -.29915000E+03, 0.77873200E+03, -.43366200E+03, 0.94339100E+03, -.21494800E+03, -.16399500E+03, -.24295500E+04, 0.11307100E+04, -.33746900E+04, 0.12148300E+04, -.13800100E+04, -.12315200E+04, 0.19565300E+04, 0.18165900E+04, 0.28979800E+04, -.18865500E+04, 0.76874900E+03, 0.49937900E+04, -.24091100E+04, -.86267700E+03, -.24968200E+04, 0.30608300E+03, 0.26528200E+03, -.12370600E+04, 0.10480000E+03, -.97929600E+03, 0.51508100E+02, 0.58053300E+03, -.47316600E+04, 0.23339500E+04, -.15062900E+04, 0.23658300E+04, 0.76062600E+03, -.58467400E+03, 0.56992400E+03, -.36522800E+03, 0.16986400E+04, -.66406800E+03, 0.58528800E+04, -.37479400E+04, 0.15769200E+04, 0.26818200E+04, 0.18751400E+04, 0.45679800E+03, 0.12480000E+04, 0.91530500E+03, 0.82168300E+03, 0.14444800E+04, 0.91742900E+03, 0.98659300E+03, -.31261800E+04, 0.15317800E+04, -.70540700E+03, 0.15634300E+04, -.57636500E+03, 0.12422800E+02, 0.95917400E+03, -.25552100E+03, 0.72755400E+03, -.63155300E+03, -.24428500E+04, 0.50598200E+04, -.25800500E+04, 0.31656300E+04, -.25298800E+04, 0.39436800E+03, 0.11057300E+04, -.17706200E+04, -.59395500E+03, -.18274000E+04, 0.12690700E+04, -.11837800E+05, 0.37955800E+04, -.18611900E+04, 0.17514700E+04, -.18978000E+04, -.65297500E+03, 0.57765200E+03, -.52472400E+03, 0.47365800E+03, -.15824800E+04, 0.52753900E+03, -.40067600E+04, -.40049900E+03, 0.28669700E+03, 0.29223700E+04, 0.20007300E+03, 0.11164800E+04, 0.16622700E+04, -.16224900E+04, -.28736800E+04, -.21771600E+04, 0.13630700E+04, 0.86202500E+03, -.75419700E+04, 0.37721000E+04, -.92859800E+03, 0.37710100E+04, -.40620600E+03, 0.13809500E+03, 0.19672600E+04, -.40575500E+03, 0.33797600E+04, -.13467600E+04, 0.34301400E+04, 0.38673900E+04, -.19419000E+04, 0.24022600E+04, -.19337200E+04, 0.18035800E+04, -.57882400E+02, -.12178200E+04, 0.62169500E+03, -.99503100E+03, 0.95345500E+03, -.83409200E+04, 0.48468400E+04, -.24415600E+04, 0.12420300E+04, -.24234100E+04, 0.20883100E+03, 0.14422800E+04, -.15302500E+04, 0.44679600E+03, -.20208200E+04, 0.67259400E+03, -.16649100E+04, -.24758700E+04, 0.12314000E+04, -.24809200E+04, 0.12378600E+04, -.81633900E+03, -.53916200E+03, 0.84714000E+03, -.24699200E+03, 0.10161700E+04, -.71033600E+03, 0.30833100E+04, -.58204300E+02, 0.10217100E+03, 0.35463100E+04, 0.28956000E+02, 0.38570700E+03, 0.73983400E+03, -.83883400E+03, -.12246000E+04, -.12624100E+04, 0.76130400E+03, -.25058700E+04, -.36731400E+03, 0.68678600E+03, 0.78055900E+03, 0.70932200E+03, -.52466000E+03, 0.84568000E+03, 0.83572000E+03, 0.74739700E+03, -.85173800E+03, -.76828400E+03, -.89630900E+02, -.56667100E+03, 0.21501100E+03, -.62281600E+03, -.28110700E+03, 0.69857500E+03, -.58400200E+02, -.28781000E+03, -.17278000E+03, -.34172900E+03, -.65231800E+03, -.97049100E+02, 0.61639100E+03, 0.41456400E+03, 0.26020300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29921500E+00, 0.65961600E+00, 0.94071400E+00, 0.93341300E-01, 0.74055300E+00, 0.10555300E+00, -.30625100E+00, -.41429500E+00, 0.29199500E+00, 0.24657400E+00, 0.25748600E-01, -.13024600E+00, 0.51857100E-01, 0.35893900E+00, -.35434300E+00, 0.23127700E+00, 0.51521200E-01, 0.31882300E+00, -.40966000E+00, 0.48026200E+00, 0.80027600E+00, -.98843600E-01, 0.44135400E+00, -.36167900E+00, 0.51910600E-01, -.56320300E-01, -.86836100E+00, 0.20157400E+00, 0.43335900E+00, -.74221200E-01, 0.31581500E-01, -.77041400E+00, -.80178800E-01, 0.47424200E+00, -.17113100E+00, -.48488900E+00, -.12381400E-01, -.73223400E-01, 0.20234100E-01, 0.19197400E+00, -.25438400E+00, -.15341000E+00, -.80423200E-01, -.64905400E-01, -.11702000E+00, 0.13113100E+00, -.37926100E-01, -.16031300E-02, 0.10718700E+00, -.50591300E+00, -.26158100E+00, -.29329400E+00, -.36994200E-01, -.11574200E+00, 0.55898100E-01, -.18919700E+00, 0.18124400E+00, 0.89978300E+00, 0.12580300E-01, 0.82063900E-01, 0.11653600E+00, 0.36477800E-01, 0.10674500E+00, -.59757900E+00, 0.14986300E+03, -.11246300E+03, 0.28839700E+04, -.13494600E+04, -.33494800E+03, -.14437900E+04, 0.51079200E+01, 0.34417300E+02, -.68685000E+03, -.48872900E+03, -.17176900E+04, 0.15376400E+03, -.10606600E+04, 0.25326400E+03, -.13998800E+03, 0.30836000E+02, -.12626400E+03, -.30773700E+03, -.25393100E+03, 0.26142800E+03, 0.56110200E+03, 0.25326500E+03, -.18749200E+03, 0.33864500E+03, -.13657700E+04, 0.67160500E+03, -.36184000E+03, 0.68418200E+03, 0.61924500E+03, -.62144500E+02, 0.32901900E+03, -.15908300E+02, -.15438300E+03, 0.27972200E+03, -.11014600E+04, 0.17343700E+04, -.85799900E+03, 0.24766600E+03, -.86742000E+03, -.79106200E+03, -.45362900E+03, -.25878100E+03, 0.28130400E+03, -.65282400E+03, 0.32216300E+03, 0.80645900E+03, -.27904600E+04, 0.13944300E+04, 0.10390100E+04, 0.13955600E+04, 0.10598300E+02, 0.31598400E+02, 0.46947300E+03, -.30950800E+03, 0.76535700E+03, 0.89030800E+02, 0.56692700E+03, 0.34699600E+04, -.17625600E+04, -.90710300E+03, -.17348000E+04, -.96323100E+03, -.84809100E+03, 0.47101500E+03, 0.24213600E+04, 0.85702500E+03, -.10436400E+04, -.15057200E+04, 0.30245200E+04, -.15178000E+04, -.13991500E+04, -.15120200E+04, 0.24329900E+03, 0.29842300E+01, -.64199000E+03, 0.78723500E+02, -.72474500E+03, -.10218900E+03, -.33363100E+03, -.16069300E+04, 0.79482500E+03, -.18561900E+04, 0.80346800E+03, 0.86723300E+03, 0.61541400E+03, 0.55667600E+03, 0.59230800E+03, 0.35814100E+03, 0.34308300E+03, 0.20263700E+04, -.29139400E+04, 0.13274100E+04, 0.19875100E+03, 0.14603700E+04, -.98306100E+02, -.20769900E+03, 0.89539200E+03, 0.76551000E+03, 0.19122600E+04, -.29563800E+03, 0.11977600E+04, -.54237100E+03, 0.25544000E+03, 0.16693600E+03, 0.27116400E+03, 0.35023500E+03, 0.14199100E+03, 0.86380900E+02, -.47834000E+03, -.11050300E+03, -.20238200E+02, -.15858600E+04, 0.13429800E+04, -.69028400E+03, 0.70109400E+03, -.67139800E+03, 0.22949100E+03, -.84418000E+01, -.83018300E+03, -.12198600E+04, -.63156400E+03, 0.28138400E+03, -.44561400E+04, 0.29849800E+02, -.38308500E+01, 0.16740800E+04, -.14948800E+02, -.77901600E+03, -.96702400E+03, 0.29676700E+03, -.22089200E+03, 0.11027900E+03, -.60723100E+03, -.10405300E+04, -.95146700E+03, 0.50553000E+03, 0.16998500E+04, 0.47520500E+03, 0.98192400E+03, 0.10288600E+04, -.89372600E+03, -.25205700E+04, -.14897800E+04, 0.80325000E+03, 0.31624300E+03, -.13363300E+04, 0.67319300E+03, 0.36887800E+02, 0.66822700E+03, 0.43531900E+03, 0.33971200E+03, 0.23892900E+03, -.70975200E+02, 0.79639700E+03, -.45172300E+03, 0.49123700E+03, 0.15421500E+04, -.77359700E+03, 0.33449900E+03, -.77115400E+03, 0.25845500E+03, -.27691100E+03, -.84844500E+03, -.79605700E+03, -.72379600E+03, 0.23374400E+03, -.33563200E+04, 0.13451800E+04, -.66882600E+03, 0.83130700E+03, -.67255500E+03, 0.88465400E+01, 0.33775000E+03, 0.56148900E+01, 0.44875800E+03, -.58953100E+03, 0.14564400E+03, -.74079100E+03, -.59368700E+03, 0.29333000E+03, -.58762200E+03, 0.29658700E+03, -.22375800E+03, -.14791500E+03, 0.44783200E+03, 0.36639100E+03, 0.58326100E+03, -.22631500E+03, 0.94422600E+03, 0.28072600E+03, -.13323100E+03, 0.10082100E+04, -.14081300E+03, 0.39163800E+03, 0.43073000E+03, -.75767000E+03, -.13955300E+04, -.11153500E+04, 0.45046100E+03, -.12961100E+04, 0.82823000E+02, 0.19039500E+03, 0.27720800E+03, 0.14381700E+03, -.46194000E+01, 0.26966300E+03, 0.27474700E+03, 0.18223400E+03, -.30446800E+03, -.12314700E+03, 0.52239000E+02, -.20468000E+03, 0.22886700E+03, -.14936000E+03, -.36719300E+03, 0.15058000E+03, 0.82242900E+02, -.96901900E+01, -.35941300E+03, 0.17427900E+03, -.12574600E+03, 0.19600600E+03, -.52132000E+02, 0.14774500E+03, -.24109800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14588000E+01, -.36527000E+00, -.76260000E+00, 0.10894800E+01, -.10344500E+01, -.12793700E+00, -.67000000E+00, 0.10375900E+01, 0.38976200E+01, 0.40188100E+00, -.64525400E+00, -.35620800E+01, 0.25258500E+00, -.74209800E-01, -.20316400E+01, 0.82477100E+00, 0.15907200E+01, 0.22709600E+00, 0.13093900E+00, 0.44583900E+00, -.28928400E+00, 0.71506900E+00, 0.48239000E+00, 0.38192000E+01, -.11739700E+00, 0.27234600E+00, 0.30785600E+00, -.43257900E+00, -.29764500E+00, 0.10667500E+01, 0.51706600E+00, -.12382800E+01, 0.57957400E+00, -.94551800E+00, -.16036800E+01, -.61986600E+00, 0.15891700E-01, -.13998000E+00, -.65870500E+00, -.51421400E+00, 0.14156600E+00, -.12754000E+00, 0.19242600E+01, 0.61483900E+00, 0.80902000E+00, -.53143300E+00, 0.63750500E-01, 0.27950700E-03, 0.76942400E+00, -.87607600E+00, 0.52003200E+00, 0.36116800E+01, -.20609500E+00, -.95947700E-02, -.10971400E+01, 0.84963000E+00, 0.94798200E+00, -.90491400E+00, -.45815300E-01, -.98415500E+00, -.20774900E-01, 0.15242200E+00, 0.51118500E+00, -.25106100E-01, 0.14128900E+01, 0.45540700E+04, -.10586200E+05, 0.53054100E+04, 0.92045000E+04, 0.53011300E+04, -.43701700E+02, 0.11039500E+04, 0.22801800E+04, -.76634600E+03, 0.27866900E+04, 0.70872100E+03, 0.15101300E+03, -.37513300E+04, 0.20227000E+04, 0.70478400E+03, 0.18741400E+04, 0.13429800E+04, 0.10052200E+04, -.12227800E+04, -.39927400E+04, -.13984200E+04, 0.79567700E+03, -.18078400E+04, -.48313200E+04, 0.24398900E+04, -.14523700E+04, 0.24098400E+04, -.18068400E+04, -.24987800E+04, 0.10395200E+04, -.26744800E+04, 0.48128200E+03, -.22775400E+04, 0.26519900E+04, -.12871000E+05, 0.64284100E+04, 0.67723900E+04, 0.64365500E+04, 0.41160300E+02, -.35784300E+04, 0.37469900E+04, -.26324000E+04, 0.11566100E+04, -.33148000E+04, -.23874300E+04, 0.10189800E+05, -.52246500E+04, -.38982900E+04, -.50963400E+04, -.82941700E+03, -.57086800E+03, -.13775700E+04, 0.25980900E+04, -.10941700E+04, -.68398900E+03, 0.17421900E+04, -.12255700E+05, 0.61458000E+04, 0.29019200E+04, 0.61270700E+04, 0.44863200E+04, 0.70079000E+04, -.24608500E+04, -.38225800E+04, -.24678500E+04, 0.62447200E+04, 0.87825500E+04, -.19385700E+05, 0.97708200E+04, 0.70292500E+04, 0.96917700E+04, 0.94068600E+03, 0.16687500E+04, 0.32422900E+04, -.29151000E+04, 0.32411500E+04, 0.18604800E+04, -.53859000E+02, 0.14189600E+05, -.70955400E+04, -.89317500E+04, -.70948300E+04, -.47599800E+04, -.15594800E+04, -.93380800E+03, 0.36701700E+04, -.16514700E+04, -.13427800E+04, -.33535900E+04, 0.47408700E+04, -.24158900E+04, -.83412400E+04, -.23854900E+04, 0.10171600E+04, -.55411900E+02, -.28087900E+04, -.21093700E+04, -.28881900E+04, 0.19205800E+03, 0.18281900E+04, 0.76245100E+04, -.37972600E+04, -.14340400E+04, -.38147600E+04, -.72125400E+03, 0.23063000E+04, -.17537600E+04, 0.26866300E+04, 0.52921500E+03, 0.24502000E+04, 0.94432100E+04, 0.13868300E+05, -.69241000E+04, -.13579700E+04, -.69345600E+04, 0.61120000E+02, 0.40845500E+04, -.62256900E+04, -.37774500E+04, -.79646100E+04, 0.37537300E+04, 0.11936300E+05, -.84661000E+04, 0.42282300E+04, 0.54280200E+04, 0.42331600E+04, 0.34647500E+04, 0.32120500E+03, 0.61892000E+03, -.19290300E+04, 0.18461800E+04, 0.32580800E+03, 0.17489500E+04, 0.11740800E+05, -.58943100E+04, -.21359500E+04, -.58680500E+04, -.35565800E+04, -.49960400E+04, 0.34777200E+04, 0.62807000E+04, 0.42571200E+04, -.42028600E+04, -.77833000E+04, 0.90747300E+04, -.45420200E+04, -.20258100E+04, -.45376400E+04, 0.24772600E+04, 0.35490700E+04, -.34664700E+04, -.18231800E+03, -.38763400E+04, 0.34648200E+04, -.10180800E+05, -.15706100E+04, 0.77698500E+03, -.46244300E+04, 0.78565100E+03, -.55649700E+04, -.15606200E+04, 0.10627800E+03, -.22060700E+04, 0.87263600E+01, -.16167400E+04, 0.18918900E+05, 0.17172900E+05, -.86056200E+04, -.70844900E+04, -.85866200E+04, -.16854300E+04, 0.11744600E+04, -.34147200E+04, 0.13937200E+04, -.39604300E+04, 0.12168000E+04, -.35808700E+04, 0.32020300E+04, -.16018900E+04, 0.95062200E+03, -.15998500E+04, 0.12704600E+04, 0.32057100E+04, -.13789300E+04, 0.15289000E+04, -.11241200E+04, 0.24975100E+04, -.26035000E+04, 0.11276700E+04, -.54812800E+03, -.10330500E+04, -.56183200E+03, -.33118300E+04, -.32397500E+04, 0.20894000E+04, 0.16587700E+04, 0.34360000E+04, -.28887100E+04, 0.12070400E+05, 0.65348500E+03, -.10540700E+04, -.14742000E+04, -.83908300E+03, 0.10309500E+04, -.11772900E+04, -.12372900E+04, -.66167400E+02, 0.16617200E+04, 0.39830200E+03, -.24035900E+04, 0.17083200E+04, 0.26979000E+04, 0.99094800E+03, 0.42804300E+03, -.49258300E+03, -.34859600E+04, 0.43515300E+02, 0.31361600E+03, 0.17500600E+04, -.28718900E+04, -.98426200E+02, -.86585300E+03, -.11791500E+04, -.52550400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19984000E+01, 0.90804600E+00, 0.72791100E+00, -.12966800E+01, 0.35285900E+00, 0.40679100E+00, 0.10453600E+01, 0.52580400E+01, 0.17075000E+01, -.46594200E+00, -.12012000E+01, -.57476900E+01, 0.51724700E-01, -.98836300E+00, -.33549400E+01, 0.30077000E+01, 0.27086100E+01, -.48031000E+00, -.21351500E+00, 0.84132300E+00, 0.10343000E+01, 0.12858500E+01, 0.12931500E+00, 0.40403200E+01, -.40483500E+00, 0.32608500E+00, 0.20188600E+01, -.30192300E+00, 0.32332000E+00, 0.19695100E+01, 0.14596500E+01, -.11995600E+01, 0.11152200E+01, -.44140200E+00, -.18202000E+01, -.67017500E+00, 0.50483100E-01, 0.53773900E+00, -.29227900E+00, 0.28202000E+01, 0.26452400E+00, 0.32639100E+00, -.15621400E+01, -.70143800E-01, 0.30961600E+00, 0.45370700E-01, -.11340600E+01, 0.22417200E-01, 0.90849500E+00, -.49552200E+00, 0.81746700E+00, 0.74027400E+01, -.16569200E+00, 0.21250500E+00, -.70180200E+00, 0.87664800E+00, 0.79041100E+00, -.19510500E+01, 0.15730600E+00, -.10687900E+01, 0.64763400E-01, 0.98196200E+00, -.44806000E+00, -.26817400E+01, 0.38585700E+01, -.37922300E+00, -.24424500E+05, 0.12671700E+05, 0.11979700E+05, 0.12221400E+05, -.44129300E+03, -.15443900E+04, 0.56761200E+04, 0.31333800E+03, 0.88163700E+04, -.16713600E+04, 0.40664500E+04, -.84769500E+04, 0.49906300E+04, 0.31995800E+04, 0.42369200E+04, 0.21742500E+04, 0.68139200E+02, -.54331200E+03, -.58397800E+04, -.10266100E+04, 0.44802500E+02, -.33844100E+04, -.22768000E+02, -.58527000E+02, 0.61657100E+03, 0.48359200E+01, -.12858300E+04, -.24768500E+04, 0.27942100E+03, -.67285900E+03, 0.13565400E+04, -.29978500E+04, 0.40050900E+04, -.20067800E+05, 0.10107800E+05, 0.10789200E+05, 0.10035100E+05, 0.11084000E+05, 0.27378600E+03, 0.46589100E+04, -.19533000E+04, 0.13154400E+04, -.26178500E+02, -.15933800E+05, 0.14895900E+05, -.82259100E+04, -.10489900E+05, -.74495900E+04, -.14650200E+04, -.10816600E+04, -.18394900E+04, 0.22719700E+04, -.23209600E+04, -.62042000E+03, 0.46821800E+04, -.30865000E+05, 0.15204700E+05, 0.74884000E+04, 0.15431600E+05, 0.65007100E+04, 0.91390500E+04, -.53866700E+04, -.14865800E+05, -.28353100E+04, 0.94360100E+04, 0.15638800E+05, -.29104600E+05, 0.14998400E+05, 0.16750700E+05, 0.14551100E+05, 0.10737000E+04, 0.20242900E+04, 0.47644000E+04, -.19836500E+04, 0.56967400E+04, 0.14787800E+04, -.23846300E+04, 0.30318000E+05, -.15258400E+05, -.43456300E+04, -.15159000E+05, -.32986000E+04, 0.49153300E+04, -.95205200E+04, 0.31981600E+04, -.10118200E+05, 0.26062000E+04, -.16619900E+05, 0.18165600E+05, -.96152700E+04, -.86337500E+04, -.90998700E+04, 0.18646100E+04, 0.33209700E+04, -.68936900E+04, -.42586500E+04, -.10287300E+05, 0.31959400E+04, -.28419800E+04, 0.95546600E+04, -.48517600E+04, -.61895200E+04, -.47802300E+04, -.70516000E+04, -.12867400E+04, -.55958900E+03, 0.35962800E+04, 0.29060400E+04, -.41654500E+03, 0.20766600E+05, 0.15710500E+05, -.79983000E+04, -.64163700E+04, -.78556900E+04, -.37830000E+04, 0.81633900E+04, -.80412600E+04, -.58268300E+04, -.95540400E+04, 0.82773400E+04, 0.32145500E+05, -.20496700E+05, 0.10353200E+05, 0.36078700E+04, 0.10248500E+05, 0.41409700E+04, -.26472900E+04, 0.48292900E+04, -.15879100E+04, 0.74745100E+04, -.93718100E+03, 0.11163500E+05, 0.15780300E+05, -.76533200E+04, -.76701500E+04, -.78875500E+04, -.80282000E+04, -.84615600E+04, 0.72915400E+04, 0.14061000E+05, 0.78483100E+04, -.76736500E+04, -.78226900E+04, 0.66156000E+04, -.33153300E+04, -.37023700E+04, -.33081100E+04, -.45778700E+04, 0.14636300E+04, -.30522300E+04, -.20370400E+04, -.45387800E+04, 0.16254100E+04, -.38702000E+03, 0.26702000E+04, -.13925500E+04, -.39971300E+04, -.13347100E+04, -.28694900E+04, 0.30863500E+04, -.14845300E+04, -.16454200E+04, -.86964500E+03, 0.28926600E+04, 0.31658400E+05, 0.20776800E+05, -.10477000E+05, -.11083300E+05, -.10388600E+05, -.13034300E+04, 0.36069600E+04, -.57831600E+04, 0.26905800E+04, -.65043000E+04, 0.27516200E+04, -.40811300E+04, -.40788700E+03, 0.18449700E+03, 0.10346400E+04, 0.20526700E+03, 0.38423500E+02, 0.93528800E+03, -.43620200E+03, -.10269700E+04, -.19190900E+04, 0.62491400E+03, -.26783700E+04, 0.14280300E+04, -.43719500E+03, -.23062600E+04, -.71177600E+03, -.28113900E+04, -.10521200E+04, 0.91307200E+03, 0.15238400E+04, 0.28201000E+04, -.51688700E+02, 0.20776100E+05, -.59190100E+03, -.56648000E+03, -.33165600E+03, -.40193500E+03, 0.32499000E+03, -.61268000E+03, -.51865900E+03, 0.13532000E+03, 0.73136500E+03, -.30392000E+03, -.60690300E+03, 0.18317300E+04, 0.88417600E+03, 0.56680000E+03, -.45345000E+03, -.10740000E+03, -.23099800E+04, -.15022300E+04, 0.23533600E+03, 0.54566000E+02, -.88266000E+03, 0.74818000E+03, 0.24700900E+03, -.75068800E+03, 0.46610600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26888500E+00, 0.14726400E-01, 0.49715300E+00, 0.16866000E+00, -.39768800E+00, -.13483700E+00, 0.72007900E+00, 0.42929000E-01, -.16350300E+01, -.21256700E+00, 0.19125500E-01, 0.13279000E+01, 0.22757300E+00, 0.35780500E+00, 0.70271800E+00, -.11832500E+01, -.73342000E+00, 0.22699100E+00, 0.36445400E+00, 0.20080200E+00, -.98242800E+00, -.48457800E-01, 0.74172600E-01, 0.23640000E+00, 0.70159500E-01, 0.13084100E+00, 0.72144200E+00, -.23353900E+00, 0.19858200E+00, -.20455300E+00, -.20217900E+00, -.75561400E-01, 0.77512300E+00, 0.39612400E+00, -.10356100E+00, 0.15154000E+00, 0.39405200E-02, -.98669200E-01, -.51466000E+00, 0.74063900E+00, -.63075300E-01, 0.93972800E-01, -.22583400E+00, 0.69446500E-01, 0.11525400E+00, -.27663400E-02, 0.11919900E+00, -.24108300E-02, 0.48868100E+00, -.26101200E+00, 0.33022800E+00, 0.14517300E+01, -.17235400E-01, 0.25286700E+00, 0.15199800E+00, 0.17069000E+00, 0.15700500E+00, -.29349400E+00, -.27062600E-02, 0.16021500E+00, 0.80689200E-01, 0.51748800E-01, -.82648300E-01, 0.14473600E+00, 0.66096800E+00, 0.96132100E-01, 0.15571100E+00, -.21301200E+03, -.44808200E+03, -.13810500E+01, 0.10627700E+04, 0.22700600E+04, -.85270100E+03, 0.33915000E+03, -.44795500E+02, 0.17532800E+04, 0.48361100E+03, 0.26533800E+04, -.14540100E+04, -.44946500E+03, -.13264800E+04, 0.13853200E+03, 0.37402600E+03, -.46030800E+03, 0.55702600E+03, -.60727000E+03, 0.18805300E+03, -.71936800E+03, 0.20376200E+04, -.99929500E+03, 0.30407700E+04, -.10177500E+04, -.89716700E+03, 0.93971900E+03, -.18115200E+03, 0.55203600E+03, -.57121800E+03, 0.56001700E+03, 0.98025300E+03, -.60528900E+04, 0.30156100E+04, -.22000000E+04, 0.30262500E+04, -.33713600E+03, 0.23113000E+04, 0.10182900E+04, 0.18422500E+03, 0.23753500E+04, 0.10930900E+04, 0.40068000E+04, -.17861500E+03, 0.23664600E+03, 0.18731100E+04, 0.89542000E+02, 0.54510800E+03, 0.11515100E+04, -.15011000E+03, -.22415200E+03, -.40183200E+03, 0.11863500E+04, -.66180100E+03, 0.65551900E+04, -.32537600E+04, 0.33813800E+04, -.32774500E+04, 0.28596500E+03, -.69228000E+03, -.16029800E+04, -.92376400E+03, -.26921900E+04, 0.32257600E+03, -.28216400E+04, 0.20371400E+04, -.11052700E+04, -.22575300E+04, -.10183700E+04, -.86565400E+03, -.15820200E+04, -.12443400E+03, 0.50438200E+03, -.18257500E+03, -.15211900E+04, -.16254400E+03, 0.31638800E+04, -.15845800E+04, 0.24992000E+04, -.15819400E+04, 0.37535900E+03, 0.21466500E+04, -.12318800E+04, 0.26852300E+03, -.24707400E+04, 0.18549000E+04, -.31535600E+04, 0.15152700E+04, -.46307700E+03, 0.12480800E+03, -.75507800E+03, -.12049600E+04, -.25209900E+04, 0.78958000E+03, -.34781200E+01, -.26056400E+03, -.19854900E+04, -.10661700E+04, 0.15196500E+04, -.77334100E+03, 0.25184500E+03, -.75931000E+03, 0.97104200E+03, -.13876800E+04, -.29088900E+03, -.52090000E+03, -.85560200E+03, -.49069300E+03, -.24552800E+04, -.12512900E+05, 0.62469700E+04, -.14548000E+04, 0.62565500E+04, 0.40450000E+03, -.30755200E+04, 0.47451300E+04, 0.17661700E+04, 0.51530900E+04, -.23911600E+04, 0.53113500E+04, -.31505100E+04, 0.15731900E+04, -.24120700E+04, 0.15752300E+04, -.56372900E+02, -.14705000E+04, 0.91057700E+03, -.45301500E+03, 0.18478100E+04, -.11944500E+04, 0.23659500E+04, -.46794000E+04, 0.23279400E+04, -.21304100E+04, 0.23393000E+04, 0.10057900E+03, 0.19883900E+03, 0.68904900E+03, 0.29094700E+03, 0.15065600E+04, -.13916700E+03, 0.13445100E+04, 0.35371300E+04, -.17508000E+04, 0.16650900E+04, -.17685200E+04, -.21417100E+03, -.13905100E+04, -.37512700E+03, 0.63769400E+03, -.11509200E+04, -.67024700E+03, -.14254200E+04, -.30376400E+04, 0.14900000E+04, 0.24083800E+03, 0.15187600E+04, 0.54825400E+03, 0.83476700E+03, 0.10357000E+04, 0.37708200E+03, 0.73460700E+03, 0.33723000E+03, -.25550800E+03, -.95944300E+04, 0.48135500E+04, 0.10394200E+04, 0.47972400E+04, 0.34548000E+03, -.15605100E+04, 0.26010400E+04, -.19502600E+03, 0.28432200E+04, -.95067800E+03, 0.29948500E+04, 0.12715300E+04, -.64637300E+03, 0.17279000E+04, -.63598500E+03, 0.94928300E+02, -.43056100E+03, -.49082500E+03, -.71132700E+03, -.92166500E+03, -.98942700E+02, -.11252000E+04, -.10343800E+04, 0.48933100E+03, -.24510700E+04, 0.51683800E+03, 0.90908100E+03, 0.97185200E+03, -.12996700E+03, -.49774100E+02, -.12661800E+03, 0.82764900E+03, -.13949300E+04, 0.11746100E+03, -.69678100E+02, -.14372100E+03, -.24569900E+03, -.22277000E+03, -.50458000E+03, -.51124600E+03, -.57387700E+03, 0.15379800E+03, 0.40418900E+03, 0.87238000E+03, -.14104800E+03, -.12016700E+04, 0.12223200E+03, -.69521200E+03, -.33300500E+03, 0.10334500E+04, 0.24547000E+03, -.65875600E+03, -.22849800E+03, 0.16257700E+04, 0.19207200E+03, 0.27397400E+02, 0.78348000E+02, -.78911600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.53876200E+00, -.32498600E+00, -.12025600E+01, -.12873800E+01, -.99437600E+00, -.74110700E-02, 0.46978300E+00, 0.73728700E+00, 0.60202300E+00, -.16466600E+00, -.84298000E-01, -.97313200E+00, -.42520600E+00, -.44493300E+00, 0.15102400E+00, 0.86645600E+00, 0.38988000E+00, 0.83062900E-01, -.21760400E+00, 0.27232400E+00, -.35502500E+00, 0.29106900E-01, -.44606300E+00, 0.25335300E+00, -.18038800E+00, 0.14592300E+00, 0.76216600E+00, -.28216800E+00, 0.93212600E-01, 0.10627000E+01, -.12692500E+00, 0.44034300E+00, 0.60188900E+00, -.45938600E+00, 0.35246600E+00, 0.10181200E+01, 0.39125000E-01, 0.54342300E+00, 0.20015000E-01, 0.10512200E+01, -.66321900E+00, -.35841500E+00, -.97016600E+00, -.36985500E-01, 0.77237900E-01, 0.23047900E-02, -.12553800E+00, 0.10325600E-01, 0.15321300E+00, -.44178200E+00, -.29304800E+00, 0.10534500E+01, -.13899900E+00, -.14644800E+00, -.51314900E-01, -.33469900E+00, -.96372200E-01, -.89957600E-01, 0.16854100E-01, -.31659000E-01, -.38058600E-01, 0.12675800E+00, 0.94947300E-01, 0.43629500E+00, -.82667800E+00, -.11532900E+00, 0.99323400E-02, 0.10964700E+01, 0.62214600E+04, 0.10796500E+01, -.10392600E+04, -.17032600E+04, 0.84308900E+03, -.11231800E+04, -.18110400E+04, -.10907800E+04, -.18510800E+04, -.40342500E+04, 0.20365000E+04, 0.10605400E+04, 0.20169300E+04, 0.69884000E+02, 0.14076800E+03, 0.25044500E+03, -.13955800E+04, 0.54256700E+03, 0.18856000E+03, 0.31368200E+03, -.48998200E+04, 0.24602300E+04, -.36492700E+04, 0.24491300E+04, -.77110100E+03, -.11302600E+04, 0.45483500E+03, -.24584700E+04, 0.17437900E+03, -.77349900E+03, 0.26000900E+04, 0.89609700E+03, -.46477500E+03, 0.25538600E+04, -.44790600E+03, -.16463800E+04, -.46552900E+04, 0.80521600E+03, -.84143900E+03, -.10286400E+04, -.31877400E+04, -.39596900E+04, 0.90471800E+03, -.46687800E+03, -.17320200E+04, -.45255200E+03, -.84303300E+03, -.14549100E+04, 0.20571500E+03, 0.11555700E+04, 0.85848800E+03, -.16804000E+04, 0.19729200E+04, -.53419500E+04, 0.27306200E+04, -.28324200E+04, 0.26708700E+04, 0.86281700E+03, 0.25443700E+04, 0.14841700E+04, 0.25152000E+04, 0.20120900E+04, 0.10543500E+04, 0.33892800E+04, -.55593900E+04, 0.27970100E+04, 0.16813000E+04, 0.27795500E+04, 0.17704100E+04, 0.27098300E+04, 0.19686300E+03, -.21562700E+04, 0.60063300E+02, 0.28790200E+04, -.57815600E+03, -.64008800E+04, 0.32347200E+04, -.26904800E+04, 0.32004400E+04, -.16378100E+04, -.39959700E+04, 0.32346300E+04, -.94006300E+02, 0.43312100E+04, -.30640300E+04, 0.36520000E+04, -.29814700E+04, 0.14582300E+04, -.62177500E+04, 0.14887100E+04, 0.14559900E+04, 0.22171500E+04, -.81611100E+03, 0.16074500E+03, 0.22288700E+04, 0.15580800E+04, 0.29560400E+04, 0.89604000E+03, -.39591200E+03, 0.10920100E+04, -.44960700E+03, 0.36475900E+03, 0.31819400E+04, -.75472900E+03, 0.11187300E+04, 0.70841100E+03, 0.19574400E+04, 0.38368100E+04, 0.16467300E+05, -.81676400E+04, 0.88906700E+03, -.82337300E+04, -.12200500E+04, 0.38232600E+04, -.65863800E+04, -.32997700E+04, -.72530200E+04, 0.26154100E+04, -.57367600E+03, 0.48902400E+04, -.24790900E+04, 0.24497900E+04, -.24451100E+04, 0.82642100E+03, 0.20972500E+04, -.16305400E+04, 0.41685400E+03, -.25513300E+04, 0.15187200E+04, -.26561100E+04, 0.88100400E+04, -.44841700E+04, 0.21332500E+04, -.44047100E+04, -.66456200E+03, -.10011800E+04, -.98170000E+03, 0.30020500E+03, -.17235100E+04, -.37456800E+03, -.44053600E+04, 0.14166800E+04, -.73328500E+03, -.11238300E+04, -.70837600E+03, 0.17412200E+04, 0.33275600E+04, -.13432900E+04, -.36654600E+03, -.89714200E+03, 0.25453200E+04, -.59456600E+03, 0.95705100E+03, -.43491900E+03, -.32896900E+04, -.47847900E+03, -.35738300E+04, -.21121000E+04, -.92382100E+03, -.21672800E+04, -.40408100E+03, -.17709800E+04, 0.65114500E+04, 0.11222100E+05, -.56159400E+04, -.17060000E+04, -.56110800E+04, -.94108400E+03, 0.16239400E+04, -.28493600E+04, -.22766200E+02, -.28469200E+04, 0.12848800E+04, -.33188800E+04, 0.82736500E+03, -.39379800E+03, -.73766900E+03, -.41352400E+03, 0.78499700E+03, 0.15386600E+04, 0.84405500E+02, 0.20564600E+04, 0.84921200E+03, 0.10612600E+04, -.96689700E+03, 0.12212400E+04, -.64819000E+03, 0.11200500E+04, -.61035400E+03, -.14374500E+04, -.25403700E+04, 0.72204500E+03, 0.26941000E+03, 0.94042700E+03, -.24371500E+04, 0.38060400E+04, 0.54395100E+03, -.48237700E+03, -.61082800E+03, -.46092800E+03, 0.11294300E+04, 0.17794000E+02, 0.27083400E+02, 0.27177200E+03, 0.62449800E+03, 0.23652400E+03, -.17534700E+04, 0.11997800E+04, 0.23165400E+04, 0.75239300E+03, 0.15453300E+04, -.22016100E+03, -.20229600E+04, -.42732400E+02, 0.13135700E+04, 0.10966400E+04, -.26403000E+04, -.15854300E+03, -.89711500E+03, -.49186800E+03, -.57046600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20728400E+01, 0.20388900E+00, 0.26358300E+01, -.32706800E+01, 0.17252800E+01, 0.52551700E+00, 0.26785400E+01, 0.46987400E+01, -.48147700E+01, -.15478700E+01, -.23630600E+00, -.18368900E+01, 0.24578600E+01, -.48258900E+00, 0.45677000E+01, 0.21146400E+01, 0.34027000E+00, -.11589600E+01, -.10741900E-01, -.17475200E+00, 0.26051400E+01, 0.17985000E+00, -.61326300E+00, 0.14731300E+01, -.16669000E+00, -.48001700E+00, -.24712500E+00, -.26023100E+00, 0.37571500E+00, -.15798600E+00, 0.33592400E+00, -.70556500E+00, -.31719100E+00, 0.71490400E+00, -.69345300E+00, -.20755200E+01, 0.67373500E+00, -.32091600E+00, 0.11543000E+01, 0.12400200E+01, 0.49932800E+00, 0.68270700E+00, -.14630800E+01, -.37613500E-01, 0.10909700E+00, 0.49599000E+00, 0.64795800E+00, -.11578700E+00, 0.11613000E+01, -.13881800E+01, -.24567000E+01, 0.12361700E+01, -.51824800E+00, -.99705600E+00, -.63688900E+00, 0.60089000E+00, 0.81606300E+00, 0.41476600E+00, 0.30551300E-01, -.22558700E+00, -.37544100E+00, -.58334700E+00, 0.46897700E+00, -.26648000E+00, -.10884800E+00, -.18745000E+00, -.13100600E+00, -.19984400E+01, -.61522700E+00, 0.14030900E+02, -.23077700E+04, -.28935600E+04, 0.19828200E+04, 0.16519500E+04, 0.23249100E+04, -.26654200E+04, -.12739300E+04, -.31121800E+04, 0.16089600E+04, -.79072700E+03, 0.15612000E+04, 0.23908700E+03, 0.34507800E+03, -.18017700E+03, -.18306100E+04, 0.17071500E+03, 0.28991500E+03, 0.53050000E+02, -.75034000E+04, 0.38026000E+04, -.76481100E+04, 0.37473200E+04, -.16764600E+04, -.77320600E+04, 0.35316700E+04, 0.22973800E+04, 0.56008200E+04, -.60795000E+04, 0.23799600E+04, 0.13293200E+05, -.66799100E+04, 0.58503500E+04, -.66437700E+04, -.27995200E+04, -.51850300E+04, -.18438400E+04, -.23383800E+03, -.43786100E+04, -.24270900E+04, -.10342100E+05, 0.28446200E+04, -.14484900E+04, -.17923600E+04, -.14245100E+04, -.11192500E+03, -.22167200E+04, -.37245200E+03, 0.15560300E+04, 0.12073000E+03, -.23232300E+04, 0.52112900E+03, -.13427400E+05, 0.68215000E+04, -.75508700E+04, 0.67136600E+04, 0.21554900E+04, 0.21444200E+04, 0.46044000E+04, 0.40445200E+03, 0.29542100E+04, 0.33980600E+03, 0.87660600E+04, -.44340400E+04, 0.22394100E+04, 0.18341500E+04, 0.22192500E+04, 0.40197900E+03, 0.31733900E+04, 0.83493200E+03, -.15922600E+04, 0.34615000E+03, 0.32647100E+04, -.90844200E+03, -.10061600E+05, 0.50668200E+04, -.17292500E+04, 0.50315600E+04, -.27144000E+04, -.75999600E+04, 0.22306100E+04, -.49966900E+04, 0.85216700E+04, -.52412900E+04, 0.59288800E+04, -.36454600E+04, 0.17338000E+04, -.60357200E+03, 0.17978800E+04, 0.27098700E+04, 0.34312800E+04, -.18218400E+04, -.26283300E+04, -.14240800E+04, 0.31146200E+04, 0.26692500E+04, -.48871200E+04, 0.25144700E+04, -.16611000E+03, 0.24454800E+04, 0.15022100E+04, 0.43073300E+04, 0.58123200E+03, 0.24648900E+04, 0.12110300E+04, 0.27422100E+04, 0.56815100E+04, 0.23685700E+05, -.11754000E+05, 0.38329800E+04, -.11844800E+05, 0.60250500E+03, 0.49604700E+04, -.76924000E+04, 0.38413400E+03, -.92061000E+04, 0.39033500E+04, -.46350700E+04, 0.12313000E+05, -.61997800E+04, 0.20325400E+04, -.61570900E+04, 0.12929800E+04, 0.56277200E+04, -.18860700E+04, 0.44936700E+04, -.70583200E+04, 0.35440100E+04, -.64375200E+04, 0.61482500E+04, -.32060300E+04, 0.35459600E+04, -.30808200E+04, -.82468100E+03, -.85178500E+01, -.19085100E+04, 0.26682900E+04, 0.92444900E+03, 0.45575400E+02, -.45975100E+04, -.39678200E+04, 0.19609300E+04, -.62829400E+04, 0.19855500E+04, 0.23519900E+04, 0.25305500E+04, 0.81518100E+02, -.16407600E+04, 0.25275000E+04, 0.60392100E+03, 0.30589200E+04, -.17704100E+04, 0.92634800E+03, -.27647000E+04, 0.88479300E+03, -.42049500E+04, -.53810100E+04, 0.90791900E+03, 0.16050000E+04, 0.67884400E+03, -.37570800E+04, 0.70789600E+04, 0.14189800E+05, -.71077900E+04, -.67653300E+03, -.70999800E+04, 0.43259900E+03, 0.32762100E+04, -.47185000E+04, -.87285900E+03, -.33060600E+04, 0.28180500E+04, -.53469500E+04, 0.68769000E+03, -.32745200E+03, -.21118100E+04, -.34375300E+03, 0.22900200E+04, 0.44886300E+04, -.16148800E+04, 0.21795300E+03, -.82945800E+03, 0.36639900E+04, -.86846700E+03, -.70503800E+03, 0.29142700E+03, 0.41826400E+04, 0.35056800E+03, -.32209800E+04, -.32591000E+04, 0.19986400E+04, 0.37854900E+04, 0.27158200E+04, -.31285200E+04, 0.48988200E+04, 0.84507000E+03, -.82412800E+03, -.12882700E+04, -.66060400E+03, 0.38638700E+03, -.63362800E+03, -.59111300E+03, 0.24341400E+03, 0.13097900E+04, -.50888100E+03, -.39349400E+04, 0.10018300E+04, 0.27310400E+04, 0.87471900E+03, 0.35125700E+04, -.36542800E+03, -.42080200E+04, 0.10743400E+04, 0.37164800E+04, 0.90998100E+03, -.52280600E+04, -.18646200E+04, 0.12128000E+03, -.11614900E+04, -.43765700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19383600E+00, -.51781800E-01, 0.15427800E+00, 0.18976400E+00, -.19798400E+00, -.48604300E-01, -.10849500E+00, -.34010900E+00, 0.18828800E+00, 0.15306100E+00, 0.18993900E-01, -.25525100E+00, -.24272300E-01, 0.48096300E-01, -.26606700E+00, 0.12001600E+00, 0.20887000E+00, 0.35698900E+00, 0.36437000E+00, 0.69399400E+00, 0.39560700E+00, 0.63165900E-02, -.19755100E+00, 0.10609800E+00, -.34731200E-01, 0.10445300E-01, 0.27598300E+00, 0.36073700E-01, 0.26468400E+00, 0.29989400E-01, 0.92160200E-01, -.30325500E+00, 0.24514300E-01, 0.69158800E+00, -.23075400E-01, 0.29062400E+00, 0.17051300E-01, 0.13717400E+00, 0.19086000E+00, -.16820200E+00, 0.41001700E+00, 0.41720600E-01, -.18420100E+00, -.24083200E-01, -.75381500E-01, 0.14690700E+00, -.27281200E+00, 0.49019700E-02, -.41971300E+00, 0.89967200E-01, -.20426700E+00, -.60177500E+00, -.48068100E-01, -.31951700E+00, -.87252800E-01, -.40102900E-02, 0.31103400E-01, 0.18626100E-02, 0.16160200E-01, -.30082200E+00, 0.27233200E-02, 0.26677900E-01, -.61968000E-01, -.36821800E+00, -.43839900E+00, -.80601600E-01, -.39892700E-01, -.61584600E+00, 0.13078600E+00, -.30221800E-01, 0.64689100E+03, 0.14521100E+04, -.69962600E+03, 0.37575500E+03, 0.21213100E+03, 0.10594500E+04, -.48232500E+02, 0.14609700E+04, -.66919100E+03, -.14117800E+03, -.73023900E+03, 0.13744000E+01, -.51556800E+02, -.11216100E+03, 0.54395900E+03, -.19301200E+03, -.10914900E+03, -.57413500E+03, 0.22579400E+04, -.11396400E+04, 0.28797200E+04, -.11287400E+04, 0.11891500E+01, 0.17756300E+04, -.80751400E+03, 0.24875000E+03, -.95603300E+03, 0.14231000E+04, -.18077600E+03, -.39360700E+04, 0.19897000E+04, -.94871600E+03, 0.19680500E+04, 0.10469700E+04, 0.26607500E+04, 0.20753200E+03, 0.46564900E+03, 0.80767700E+03, 0.18130300E+04, 0.20144600E+04, -.11019400E+04, 0.48806000E+03, 0.11468200E+04, 0.55097600E+03, 0.33742700E+03, 0.10371100E+04, 0.20791100E+03, -.26650500E+03, -.21570700E+02, 0.10805800E+04, 0.17917900E+03, 0.45058600E+04, -.23324700E+04, 0.46928200E+04, -.22528800E+04, 0.15408300E+03, 0.14974300E+03, -.23068100E+04, -.14646900E+04, -.24144500E+04, 0.88342300E+03, -.14920400E+04, 0.17490100E+04, -.85006700E+03, -.12199600E+04, -.87436000E+03, -.64951600E+03, -.14739100E+04, -.37474100E+03, 0.39934600E+03, -.53076200E-01, -.15114300E+04, -.41862700E+03, 0.12274500E+04, -.66210600E+03, 0.25531200E+04, -.61370000E+03, 0.10893600E+04, 0.34036800E+04, -.14352100E+04, 0.39302300E+03, -.26623200E+04, 0.27186800E+04, -.15061200E+04, 0.42119800E+03, -.18347400E+03, -.56725600E+02, -.21054100E+03, -.76492800E+03, -.16172900E+04, 0.70490400E+03, -.23807900E+03, -.31577700E+03, -.12224300E+04, -.51989800E+02, 0.95595100E+03, -.54143800E+03, -.78177000E+03, -.47781300E+03, -.33411400E+03, -.21939800E+04, 0.51376600E+03, -.42213600E+03, 0.29537400E+03, -.15229900E+04, -.13443600E+04, -.98556100E+04, 0.48433300E+04, -.16977900E+04, 0.49277700E+04, 0.36983400E+03, -.17773900E+04, 0.32254100E+04, -.36075500E+02, 0.37689400E+04, -.11340700E+04, 0.46205000E+04, -.30862300E+04, 0.15910300E+04, -.19941700E+04, 0.15430900E+04, -.29462300E+03, -.22845600E+04, 0.98289300E+03, -.60075000E+03, 0.22250300E+04, -.16252100E+04, 0.17091500E+04, -.27613000E+04, 0.14816400E+04, -.17371200E+04, 0.13803100E+04, 0.14245300E+03, -.45281000E+03, 0.78165500E+03, -.25102600E+03, 0.62260400E+03, -.59740700E+03, -.32351600E+02, 0.11416000E+04, -.54248400E+03, 0.10760100E+04, -.57073300E+03, -.76387200E+03, -.15104300E+04, 0.78785100E+02, -.11338700E+03, -.67757400E+03, -.94647900E+03, -.16050200E+03, 0.63054500E+02, -.91161400E+02, 0.11268700E+04, -.31560800E+02, 0.10466100E+04, 0.18230000E+04, -.17556100E+03, -.27494000E+03, -.24342000E+03, 0.14543000E+04, -.85589200E+03, -.66772900E+04, 0.33359700E+04, 0.10204200E+04, 0.33385000E+04, 0.30673700E+03, -.91648400E+03, 0.18147300E+04, 0.20269600E+03, 0.13157800E+04, -.55170700E+03, 0.21705800E+04, -.10674800E+03, 0.27769100E+02, 0.98843100E+03, 0.53301700E+02, -.36843700E+03, -.10070200E+04, 0.33803800E+03, -.44475600E+03, -.36105800E+03, -.81341000E+03, -.13934700E+03, -.21408500E+03, 0.17121300E+03, -.14410000E+04, 0.10686100E+03, 0.90671800E+03, 0.11131700E+04, -.78170900E+03, -.11714700E+04, -.85127000E+03, 0.10843300E+04, -.99627300E+03, -.16925700E+03, 0.15224200E+03, 0.24792400E+03, 0.95725800E+02, -.33873500E+03, -.39166600E+02, -.38403900E+02, -.79576300E+02, -.22965300E+03, 0.17275400E+03, 0.11945100E+04, -.28438800E+03, -.11266500E+04, -.17009800E+03, -.10886100E+04, 0.45333300E+02, 0.12666200E+04, -.30429300E+03, -.98575600E+03, -.18460600E+03, 0.17485100E+04, 0.56128100E+03, 0.96117700E+02, 0.18549000E+03, -.57579700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.33781500E+00, -.31522100E+00, -.69311900E+00, 0.28379800E+00, -.30659400E+00, -.77319700E-01, -.42417600E+00, -.11972400E+01, -.23036400E+00, 0.24965400E-01, 0.62118700E-01, 0.17656100E+01, 0.28847200E+00, -.33001300E+00, 0.14188500E+00, -.13818200E+01, -.88982700E+00, 0.17109800E+00, 0.17194100E+00, -.26785200E+00, -.58846100E+00, -.43203000E-01, -.11909600E+00, -.87247500E+00, 0.71214200E-01, -.71857000E-02, -.11671000E+01, 0.74683200E-01, -.16662800E+00, -.32350800E+00, 0.18444000E-01, 0.34051200E+00, -.31507500E+00, -.42605000E+00, -.84223500E-01, 0.61818100E-01, 0.18247800E-01, -.62735300E+00, 0.22764700E+00, -.10791100E+00, 0.20672500E+00, 0.24041200E+00, -.17532800E+00, -.62792000E-01, 0.84229600E-01, 0.14728700E+00, 0.51864800E-02, 0.42310700E-02, -.10374100E+00, 0.30160200E+00, -.38224300E-01, 0.47885800E+00, 0.27727500E-02, 0.14959800E+00, 0.22930400E-01, 0.63368300E-01, 0.63156600E-01, -.20829700E+00, 0.23753800E-01, 0.45958000E-02, 0.95338600E-02, 0.24479800E-01, -.71863400E-02, -.18807400E+00, 0.43038400E+00, -.32914500E-01, 0.16745100E+00, -.24391900E-01, -.42927400E+00, -.81514100E-01, 0.21811400E+00, -.69355700E+03, 0.23418800E+03, -.66700000E+03, -.60961200E+03, -.36883900E+03, -.57837000E+02, -.35873800E+03, 0.18498400E+03, -.30073500E+03, 0.17989800E+03, -.26676900E+02, 0.19356600E+03, -.56454900E+02, -.17309700E+03, 0.66618900E+02, 0.19835100E+03, 0.27048100E+03, -.24687700E+04, 0.12399500E+04, -.24577000E+04, 0.12348300E+04, -.22273400E+03, -.10446100E+04, 0.40589100E+03, -.66798700E+03, 0.53313800E+03, -.67735300E+03, 0.44738600E+03, 0.49855200E+04, -.25040200E+04, 0.34103900E+03, -.24926900E+04, -.18656900E+04, -.23123400E+04, -.63077000E+03, -.18581200E+03, -.11357800E+04, -.14258200E+04, -.12718500E+04, -.41521300E+03, 0.20341800E+03, 0.14106800E+03, 0.20762000E+03, -.18186100E+03, -.91547200E+03, 0.15144300E+03, 0.32224400E+03, 0.36441500E+03, -.10741400E+04, -.29186000E+02, -.12348700E+04, 0.65755200E+03, -.37712200E+04, 0.61753700E+03, -.51562100E+03, -.35604200E+03, 0.21690700E+04, 0.24827300E+04, 0.18566700E+04, -.11817400E+04, 0.13831500E+04, 0.33738200E+03, -.15844800E+03, -.18122200E+03, -.16839000E+03, 0.51054400E+03, 0.13596000E+04, -.24083900E+03, -.67933700E+03, -.66234700E+03, 0.15782900E+04, 0.35276800E+02, -.56774400E+04, 0.28626600E+04, -.97912400E+03, 0.28387800E+04, -.82194600E+03, -.32840600E+04, 0.21925900E+04, -.12326800E+04, 0.36342300E+04, -.23477000E+04, 0.35138300E+04, 0.23989200E+03, -.13318600E+03, -.31237100E+03, -.11987500E+03, -.34129700E+02, 0.73570100E+03, -.20832400E+03, 0.76758700E+03, 0.65964200E+03, 0.43102800E+03, -.68075900E+02, -.20486000E+04, 0.10586900E+04, 0.11618900E+04, 0.10243500E+04, 0.10184600E+04, 0.20157400E+04, -.14532900E+03, 0.20621400E+03, -.83027900E+01, 0.12335300E+04, -.10084000E+03, 0.74357600E+04, -.36729900E+04, 0.16068400E+04, -.37179800E+04, -.30917700E+03, 0.10957900E+04, -.23657500E+04, 0.14543300E+02, -.26143300E+04, 0.32985700E+03, -.46048100E+04, 0.55016900E+04, -.27741100E+04, 0.92371700E+03, -.27509000E+04, 0.11826800E+03, 0.21520700E+04, -.13249700E+04, 0.10754100E+04, -.27925800E+04, 0.13725400E+04, -.30241900E+04, 0.14499800E+04, -.77788800E+03, 0.18322500E+04, -.72578800E+03, 0.79466400E+03, 0.82955700E+03, -.13099000E+04, -.93813900E+03, -.10391300E+04, 0.10150500E+04, -.11031500E+04, -.12664500E+04, 0.61735700E+03, -.10317600E+04, 0.63338200E+03, 0.10746900E+04, 0.11323200E+04, 0.10301600E+03, 0.16044800E+02, 0.80997100E+03, 0.61336800E+03, 0.61208000E+03, -.44557500E+03, 0.25327100E+03, -.96328300E+03, 0.22271200E+03, -.13919200E+04, -.19204300E+04, 0.18749100E+03, 0.47466400E+01, 0.29998900E+03, -.16551700E+04, -.20209400E+03, 0.40991600E+04, -.20510600E+04, 0.15191100E+03, -.20499400E+04, -.25586100E+03, 0.61776900E+03, -.11472800E+04, -.50220700E+03, -.74323500E+03, 0.45795500E+03, -.15629500E+04, 0.40645700E+03, -.18990300E+03, -.82706200E+03, -.20338400E+03, 0.38194600E+03, 0.86345400E+03, -.12480000E+03, 0.83576400E+03, 0.47238200E+03, 0.65872800E+03, -.81065500E+02, 0.92322700E+02, -.72650500E+02, 0.12656800E+04, -.46566800E+02, -.67238900E+03, -.13838800E+04, 0.75641200E+03, 0.98182800E+03, 0.70340200E+03, -.14785400E+04, -.20919100E+03, 0.32412100E+03, -.18860700E+03, -.31331000E+03, -.64630600E+02, 0.43064500E+03, 0.84095700E+02, 0.79911900E+02, -.11010100E+03, 0.28589000E+03, 0.14204500E+02, -.98954900E+03, 0.24713400E+03, 0.10019600E+04, 0.21078000E+03, 0.12767400E+04, -.10066200E+03, -.91585800E+03, 0.29392200E+03, 0.11741000E+04, 0.38081500E+03, -.14293900E+04, -.47277600E+03, -.29569000E+03, -.21864700E+03, -.16123800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.98283100E+00, -.20616200E+00, -.52448900E+00, -.49683100E+00, -.20283100E+01, -.26117000E+00, 0.70282600E+00, -.61548500E+00, -.44431900E+00, -.81385200E-01, 0.72641700E-01, -.12902200E+01, 0.11438100E+01, 0.39157600E+00, 0.37720800E-01, -.40199100E+00, 0.95289800E+00, 0.86938000E+00, -.25085200E+00, 0.16172800E+01, 0.10384700E+01, -.16079500E+00, -.50712200E+00, 0.12477300E+01, -.48856000E-01, 0.17308700E+00, 0.14502800E+01, -.21826700E+00, 0.56855800E+00, 0.11235400E+01, 0.24524800E+00, -.24705200E+00, 0.70384200E+00, -.23653000E+00, -.25754600E+00, 0.97203000E+00, 0.35180400E-01, 0.51298200E-01, 0.17900700E+00, 0.79719800E+00, -.51838100E+00, -.20280300E+00, -.48965200E+00, -.93548300E-01, 0.21572400E+00, 0.17361600E+00, 0.64499000E+00, 0.45600900E-02, 0.90591900E+00, -.72821600E+00, -.94229300E+00, 0.15390600E+01, -.17901200E+00, 0.34231700E+00, -.28442700E+00, -.39996600E-03, 0.40045500E+00, -.85859300E+00, -.22592100E-01, -.62615900E+00, -.40392900E-01, -.21018100E-01, 0.40516100E-01, 0.16040800E+01, -.21815700E+01, 0.37630200E-01, 0.42121000E-01, 0.81249300E+00, 0.98391000E+00, -.17033600E-01, 0.15638100E+01, -.13399300E+01, 0.10091300E+04, -.33569500E+03, -.94874200E+03, 0.21602000E+03, -.10598000E+04, -.94653300E+03, 0.16924300E+03, -.49418500E+03, 0.47371600E+03, 0.42095700E+03, 0.10443400E+04, -.57673000E+03, -.13530800E+04, -.33187300E+03, 0.73982900E+03, -.57322900E+03, -.51576800E+04, 0.26210400E+04, -.55215500E+04, 0.25791700E+04, -.25614000E+04, -.46413200E+04, 0.23207900E+04, -.11538300E+04, 0.19028200E+04, -.37113700E+04, 0.46280900E+04, 0.38856300E+04, -.20096700E+04, 0.11217000E+04, -.19427300E+04, -.54066600E+04, -.53547500E+04, 0.96408900E+03, -.89746100E+03, 0.23082900E+03, -.38861000E+04, -.35184600E+04, 0.30350600E+04, -.12047900E+04, -.17058600E+03, -.15175100E+04, 0.13801900E+03, -.11946200E+04, -.13513300E+04, 0.11007600E+03, -.23170900E+03, -.13347800E+04, 0.51677500E+03, -.17371000E+04, 0.11139500E+04, -.83152000E+04, 0.86863200E+03, 0.44105500E+03, -.15474700E+03, 0.41235900E+04, 0.45636200E+04, 0.21555800E+04, -.13381700E+04, 0.26549800E+04, -.36380400E+04, 0.16608600E+04, 0.75037200E+03, 0.18192600E+04, 0.34936800E+03, 0.17308200E+04, 0.19853000E+04, 0.19812900E+03, -.59566600E+02, 0.20979600E+04, -.14917000E+04, -.45177200E+04, 0.23999000E+04, -.19009600E+04, 0.22589100E+04, -.21349000E+04, -.69891100E+04, 0.41021000E+04, -.49715600E+03, 0.55911900E+04, -.46722800E+04, 0.10999700E+03, -.34322600E+03, 0.49254400E+02, -.78192600E+03, 0.17163700E+03, 0.10569800E+03, 0.40191900E+02, -.92220900E+03, -.79988300E+02, 0.10930100E+04, -.15692100E+03, 0.89933800E+03, -.66517500E+03, 0.49699900E+03, 0.26760000E+04, 0.33254900E+03, 0.28132500E+04, 0.48889200E+04, -.17023900E+04, 0.73602400E+03, -.17789600E+04, 0.38728100E+04, 0.28650100E+04, 0.16881900E+05, -.82044800E+04, 0.24689400E+04, -.84410400E+04, -.62877800E+03, 0.14336400E+04, -.56068200E+04, -.59001000E+02, -.67516000E+04, 0.46605100E+03, -.92574100E+03, 0.54327800E+04, -.28562400E+04, 0.14748300E+04, -.27164400E+04, 0.41140600E+03, 0.37636800E+04, -.14686200E+04, 0.99273900E+03, -.36024800E+04, 0.21349400E+04, -.15029500E+04, 0.32924700E+04, -.19465200E+04, 0.42798900E+04, -.16469500E+04, 0.84990900E+03, 0.18148000E+04, -.24913800E+04, 0.15566300E+03, -.94900400E+02, 0.17530900E+04, -.28029500E+04, 0.25045800E+04, -.13128400E+04, -.16070800E+04, -.12521500E+04, 0.41739400E+04, 0.33236700E+04, -.16515500E+04, 0.94229200E+03, 0.15128000E+03, 0.22129500E+04, -.13527900E+04, -.34050700E+04, 0.18627100E+04, -.40426100E+04, 0.17024700E+04, -.47698500E+04, -.53582600E+04, 0.63057200E+03, -.14974000E+04, 0.65264200E+03, -.45345100E+04, 0.74733000E+04, 0.50375600E+04, -.24801100E+04, 0.35716800E+03, -.25191200E+04, -.71794800E+02, 0.38169900E+03, -.11776600E+04, -.87116300E+03, 0.38960600E+03, 0.73781800E+03, -.27543900E+04, 0.23851400E+04, -.11280800E+04, -.23831300E+03, -.11926900E+04, 0.16849000E+04, 0.29250400E+04, -.10626100E+04, 0.18260300E+04, 0.55491200E+02, 0.26049200E+04, -.27163600E+04, 0.12940300E+04, -.89147000E+03, 0.49107300E+03, -.64736500E+03, -.19979900E+04, -.23919800E+04, 0.93366900E+03, 0.14985100E+04, 0.15944000E+04, -.25887700E+04, 0.24081000E+04, 0.87467600E+03, -.87809300E+03, -.17099500E+04, -.10580800E+04, 0.95510700E+03, -.59191000E+03, -.58363800E+03, -.89766700E+03, 0.17283000E+04, 0.15400000E+03, -.27574100E+04, 0.51037200E+03, 0.23755300E+04, 0.93501200E+03, 0.25922000E+04, -.99232800E+03, -.27305000E+04, 0.13512000E+04, 0.21411500E+04, 0.81165500E+03, -.35862400E+04, -.10600600E+04, -.77605300E+03, -.83525800E+03, -.48737200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.83516600E+00, 0.78995300E-01, 0.89876200E+00, -.65253600E+00, 0.30906200E+00, 0.57968400E-01, 0.52271500E+00, 0.25033800E+01, 0.60330200E+00, 0.19008400E+00, -.80170700E-01, -.84317200E+00, 0.22480100E+01, 0.93368200E+00, 0.10491700E+01, 0.22747500E+00, 0.59613100E+00, -.66024000E+00, 0.19030800E+00, -.58290500E+00, 0.14395700E+01, 0.14386100E+00, -.44510300E+00, -.58313600E+00, -.25602300E+00, 0.59761800E-01, 0.71530200E+00, -.35410600E-01, -.48332300E+00, -.13344100E+01, -.89077300E-01, -.24149800E+00, 0.17198200E+00, 0.51984600E+00, 0.23257400E-01, -.83433900E+00, -.16600400E-01, -.44121100E+00, -.37825300E-01, 0.88473300E+00, -.11133200E+01, -.36456000E+00, -.10398200E+00, -.13792900E+00, -.38861400E+00, -.30630800E-01, -.37791500E+00, -.51059400E-03, -.88644400E+00, -.55081900E+00, -.10914800E+00, -.67832400E+00, -.12998600E+00, -.52965200E+00, 0.88057200E-01, -.19039300E+00, 0.26168400E+00, 0.14236400E+01, 0.12827700E-02, -.16610600E-01, 0.54492500E-01, -.18862800E+00, -.40281400E-01, -.78661700E+00, 0.12635400E+01, -.16144000E-01, -.27923500E+00, -.19044200E+01, 0.61078000E-01, 0.62639600E-01, 0.19236100E+01, -.71077200E+00, 0.62166300E+00, 0.20306000E+04, 0.14078600E+04, -.16448900E+03, 0.11831100E+04, 0.97214900E+03, -.12580100E+03, -.27671100E+03, -.48689500E+03, 0.19406500E+03, 0.28808000E+03, -.50457300E+03, -.28684800E+03, -.66404200E+03, 0.29526400E+03, 0.32017400E+03, 0.90712300E+03, -.47891800E+03, 0.38028900E+03, -.45413800E+03, 0.98490300E+02, 0.13258400E+03, -.20271900E+03, 0.24458500E+04, 0.11112300E+04, -.22291500E+03, -.11321200E+04, 0.30790200E+04, -.15060400E+04, -.10017600E+04, -.15396300E+04, 0.73782400E+03, -.54654500E+03, -.66417600E+03, 0.11357500E+03, -.86310100E+03, -.60453200E+03, -.16253900E+04, 0.16144700E+04, -.11625800E+04, -.47696700E+03, -.80727300E+03, -.12342000E+03, -.47499100E+03, 0.51398500E+03, 0.14941300E+04, -.40175200E+03, -.26027400E+03, -.23794700E+04, -.58164900E+04, 0.27926800E+04, 0.58759700E+03, 0.29081000E+04, 0.96407800E+03, 0.10158600E+04, -.15363500E+03, -.37752600E+04, 0.11349200E+04, 0.11998300E+04, -.23689100E+03, -.14833400E+04, 0.94365000E+03, 0.56860900E+03, 0.74124800E+03, -.26210300E+03, 0.36358800E+03, -.66741000E+03, -.17026500E+04, 0.26179100E+03, 0.12361800E+03, 0.28239400E+04, 0.54432400E+04, -.27879800E+04, -.31122100E+04, -.27217100E+04, -.58573800E+02, 0.20538800E+03, -.26051300E+04, -.76774800E+03, -.34647900E+03, -.69079300E+03, -.19561600E+03, 0.11795800E+04, -.48071900E+03, 0.41208800E+03, -.58991600E+03, -.20412200E+03, -.12934500E+03, -.28689800E+03, -.19305600E+04, -.18468600E+04, 0.66596900E+02, -.16576800E+04, -.13001100E+04, 0.60465200E+03, 0.28851100E+03, 0.65061400E+03, -.72844500E+03, 0.27198100E+03, 0.16161000E+03, 0.14524200E+03, -.40104300E+03, 0.52010100E+03, 0.89894300E+03, -.15602700E+04, 0.69033600E+03, 0.72439000E+03, 0.78027900E+03, -.80865600E+03, 0.87888400E+03, 0.11671800E+04, 0.20428000E+04, 0.11462100E+04, 0.97752600E+03, -.15575300E+04, -.66345900E+03, 0.39635900E+03, 0.15724600E+04, 0.33181500E+03, 0.27643700E+03, 0.88255900E+03, 0.27175600E+02, 0.62046300E+03, -.10010000E+04, 0.10285300E+04, -.41917500E+03, -.56216300E+03, 0.41056200E+03, -.16874100E+04, 0.28225400E+03, -.54194200E+03, -.86162000E+03, 0.15087800E+04, 0.33427600E+04, 0.69946200E+03, -.81427800E+03, 0.35827000E+04, -.99146900E+03, 0.49567700E+03, 0.15892400E+02, 0.49550200E+03, -.54038000E+03, -.19497900E+02, 0.77703100E+03, -.34969300E+03, 0.87998400E+03, -.63233700E+02, 0.31602900E+03, -.24286900E+04, 0.11551700E+04, 0.98670800E+03, 0.12144500E+04, 0.18685500E+03, 0.53364100E+03, 0.16891300E+04, 0.35858700E+04, 0.14324600E+04, 0.57241700E+03, -.86142400E+03, 0.48648800E+04, -.24912200E+04, -.25002300E+04, -.24319000E+04, 0.43214100E+03, 0.12146600E+04, -.21571600E+04, 0.25150700E+03, -.16666900E+04, 0.35766400E+03, -.76042500E+03, 0.23800400E+02, -.28594700E+02, -.15711200E+03, -.11698500E+02, 0.30904400E+03, 0.58874800E+03, -.94528800E+03, -.18104600E+04, -.10287800E+04, 0.61281800E+03, 0.49063900E+03, -.25046500E+04, 0.14322300E+04, 0.10398500E+04, 0.12529100E+04, -.29911300E+03, -.57883800E+03, 0.16554700E+04, 0.32717600E+04, 0.14286500E+04, -.11634600E+03, 0.12249900E+04, -.59710400E+02, 0.11250900E+03, 0.28656800E+03, 0.29319400E+03, -.48083700E+03, -.44134100E+03, -.46054400E+03, 0.68922500E+02, -.28884900E+03, -.14900800E+02, -.66116500E+03, 0.55014200E+03, -.34213800E+03, -.24102600E+02, -.47031200E+03, 0.18441100E+03, -.57216800E+03, -.16744400E+02, -.12331700E+03, -.24964700E+03, -.61419900E+03, -.86538700E+03, 0.87508500E+03, 0.13347400E+03, 0.47854800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11809500E+01, -.66529200E-01, -.77485500E+00, -.19610000E+01, 0.94207400E-01, 0.18200100E+00, 0.79137900E+00, -.18934400E+01, -.47305200E+01, -.11983700E+01, -.18216600E+00, 0.25667500E+01, -.22161400E+01, -.23211100E+01, 0.15000400E-01, -.67941800E+01, -.19727500E+00, 0.25046900E+01, -.74434200E+00, 0.20408400E+01, 0.24992800E+01, 0.18163700E+00, -.82177200E+00, 0.41184800E+01, 0.12488900E+00, -.97502000E-01, 0.14982600E+01, 0.48739500E-01, 0.19085200E+01, -.19571100E+00, -.15084300E+01, 0.10077400E+00, -.16712100E+00, 0.12788900E+00, 0.42088800E+00, -.36109300E+00, 0.39411100E-01, 0.75152600E+00, 0.78433000E-01, -.20340500E+00, 0.13423200E+01, 0.75207100E+00, -.72755400E+00, 0.17114300E+00, -.86014200E-02, -.15976200E+00, -.19988200E+00, 0.80801800E-02, -.23756300E+00, 0.20259400E+00, -.36344800E+00, -.40614200E+00, -.16110400E+00, -.47617500E+00, 0.66466000E-01, 0.27554300E+00, -.34722400E+00, 0.15339700E+01, -.10557800E-01, 0.43119600E-01, -.11504200E+00, -.57403300E+00, 0.66103200E-01, 0.33681800E+00, 0.10441300E+01, 0.23062500E+00, 0.10165700E+00, 0.30340600E+00, -.89613800E+00, -.47949000E-01, -.35325400E+01, -.95363300E+00, -.55234800E+00, -.24816600E-01, 0.14168400E+04, -.14254200E+02, -.34124600E+03, 0.11549700E+04, -.37196000E+03, -.86690500E+03, -.57551100E+03, -.19961800E+03, -.98534500E+02, 0.10048700E+03, 0.10344900E+04, 0.55808100E+03, -.11549900E+03, -.41028700E+03, -.33262100E+03, 0.14569600E+03, 0.26552600E+03, 0.16790300E+03, -.34718300E+03, 0.25661700E+04, -.17583800E+04, -.24939700E+04, -.19342800E+04, 0.24619900E+04, 0.67303700E+03, 0.40356500E+04, -.19889400E+04, -.11976900E+04, -.20175900E+04, -.22629600E+04, 0.47939600E+03, -.12001500E+04, 0.65914000E+03, -.16250500E+04, 0.91931300E+03, 0.75257000E+03, -.32419100E+04, 0.14205500E+04, 0.21753400E+04, 0.16210200E+04, -.30253800E+03, -.47065800E+03, 0.92963900E+03, 0.19171500E+03, 0.75403100E+03, -.83253900E+03, 0.67360400E+03, 0.94216400E+04, -.48085300E+04, 0.12751300E+04, -.47104600E+04, -.13755600E+04, -.10026700E+04, -.46642900E+02, 0.40980400E+04, -.68340400E+03, -.16778800E+04, -.12919000E+04, 0.44086200E+04, -.20980300E+04, -.30342200E+04, -.22032300E+04, 0.26538500E+03, 0.20908300E+03, -.11595000E+04, -.48101200E+03, -.40720200E+03, 0.68398900E+03, -.11295900E+04, -.11363600E+05, 0.56258900E+04, 0.32291800E+04, 0.56820000E+04, -.13321700E+03, -.86487600E+03, 0.27159000E+04, -.16222600E+04, 0.30392000E+04, -.22952100E+03, 0.48624500E+04, -.60680300E+03, 0.32524500E+03, -.15040000E+04, 0.30374700E+03, -.14203100E+03, -.13809000E+03, 0.27916100E+03, 0.32651900E+03, -.17557500E+03, -.13199100E+03, 0.79578400E+03, -.34587600E+04, 0.16620400E+04, 0.11404100E+04, 0.17294900E+04, 0.12268900E+04, -.10690600E+03, 0.11425300E+04, -.50646300E+03, 0.14673400E+04, -.87221200E+03, -.21307400E+04, -.21918000E+04, 0.10060000E+04, -.89342400E+03, 0.10955700E+04, 0.89827700E+02, -.10987100E+04, 0.52115800E+03, -.15560700E+04, 0.12214400E+04, -.21389200E+04, -.69656500E+03, 0.58264600E+04, -.28542300E+04, -.21895800E+04, -.29134400E+04, 0.52872000E+02, 0.24300200E+03, -.10994100E+04, 0.91735500E+03, -.16257700E+04, 0.62677600E+02, -.30719100E+04, -.20987700E+04, 0.11649000E+04, 0.16772200E+04, 0.10465600E+04, 0.23430800E+04, 0.10831500E+04, -.17447400E+04, -.37205000E+04, -.21879000E+04, 0.16074300E+04, -.28803200E+04, -.27825700E+03, 0.16491500E+03, -.36955000E+03, 0.13968400E+03, 0.14734700E+04, -.81210900E+03, 0.98018900E+02, -.27471000E+03, 0.32494900E+03, -.71147900E+03, 0.75363400E+03, 0.11932600E+04, -.65896100E+03, 0.20806100E+03, -.59689700E+03, -.11984500E+04, -.15519800E+03, -.71685500E+03, -.15358200E+04, -.48168000E+03, -.90967300E+03, -.24921200E+04, -.24707400E+04, 0.12273500E+04, 0.16658600E+04, 0.12341100E+04, -.24788400E+03, -.80084900E+03, 0.10723500E+04, -.27488900E+03, 0.43464200E+03, -.43248100E+03, -.15060600E+03, 0.16044500E+03, -.10642700E+03, 0.26804500E+03, -.80761700E+02, 0.18616000E+02, -.40257400E+03, 0.10430700E+04, 0.18415500E+04, 0.76344100E+03, -.51253900E+03, -.39650100E+03, 0.72432500E+03, -.27353600E+03, -.32248700E+03, -.36360500E+03, -.17288600E+02, -.12507200E+04, -.36235200E+03, -.10637800E+04, -.45792900E+03, -.16850300E+04, -.28689600E+04, 0.26754900E+03, -.12421500E+03, -.45909500E+03, -.23204000E+03, 0.56222400E+03, 0.55301100E+03, 0.55498900E+03, -.61592900E+02, 0.42588400E+03, 0.48429200E+03, 0.79228100E+03, 0.27916400E+03, -.17084900E+03, 0.29686100E+03, 0.86094800E+03, -.21208200E+03, 0.11738100E+04, -.16983200E+03, 0.80489600E+03, 0.41635300E+03, 0.90775700E+03, 0.35238900E+03, -.80571400E+03, -.10525500E+03, -.35668000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37475700E+00, -.17483800E+00, -.69523000E+00, 0.34676500E+00, -.14383100E-01, 0.52938100E-02, -.66959800E+00, -.11814100E+01, -.26707800E-01, 0.13252000E+00, 0.14473400E-01, 0.25320900E+01, 0.30167000E+00, -.37129000E+00, 0.13695500E+01, -.13179200E+01, -.12580100E+01, -.68438900E-01, 0.17457700E+00, -.74896600E+00, -.50632200E+00, 0.21982800E-01, -.18673200E-01, -.16495100E+00, 0.94644700E-01, 0.57366000E-01, -.18571600E+01, 0.11641500E+00, -.25851900E+00, -.72946400E+00, -.98457600E-01, 0.11418300E+00, -.30183400E+00, -.47214400E+00, 0.19350600E+00, 0.13493200E+00, 0.28915700E-01, -.18081300E+00, -.82004800E-01, -.11410900E+00, 0.18013200E+00, 0.22337800E+00, 0.30012300E-01, 0.35250200E-01, 0.13198500E+00, 0.31576000E-01, -.20835200E-01, 0.33593100E-02, -.86209300E-01, 0.77889400E+00, 0.49324100E+00, 0.99935700E+00, 0.74338300E-01, 0.48431700E+00, 0.22504500E+00, 0.21199300E+00, 0.25150600E+00, -.16529300E+01, 0.28159800E-01, 0.23485800E+00, -.61065600E-02, 0.17509200E+00, -.69121500E-01, -.71312400E+00, 0.79297200E+00, -.46195800E-01, 0.10624300E+00, -.17974900E+00, -.37619900E+00, -.55997200E-01, 0.13943300E+00, 0.62461400E+00, -.34143700E+00, -.26035900E+00, -.27698900E+00, 0.18333000E+03, 0.18936600E+03, 0.99811400E+02, 0.80906600E+02, -.16527700E+03, -.49343000E+02, 0.62534600E+02, 0.31330900E+02, -.99927200E+02, -.12876800E+03, -.52478900E+02, 0.82916100E+02, 0.26022800E+02, -.22347100E+04, 0.11153400E+04, -.17099800E+04, 0.11177700E+04, 0.13133100E+03, -.26525300E+03, -.38369500E+03, -.11109200E+04, 0.46679800E+00, -.17833900E+03, 0.40588000E+03, 0.53388400E+04, -.26639100E+04, 0.35682200E+02, -.26693500E+04, -.11320000E+04, -.17212300E+04, -.59950700E+03, 0.24588200E+03, -.16832900E+04, -.88752100E+03, -.15747600E+04, 0.12442600E+04, -.74911900E+03, -.66802900E+03, -.62210700E+03, -.35818300E+03, -.31781900E+03, -.24391700E+03, 0.30091800E+03, -.34072300E+03, -.45719900E+03, -.70020000E+03, -.59932400E+03, 0.28027000E+03, -.31354600E+04, 0.29975900E+03, -.77827200E+03, -.69004100E+03, 0.15411000E+04, 0.16466700E+04, 0.19322100E+04, -.13095600E+04, 0.10362500E+04, -.21435700E+04, 0.11502700E+04, 0.10495900E+04, 0.10720800E+04, 0.60121500E+03, 0.37957200E+03, 0.47792900E+03, -.36477100E+03, 0.57817600E+03, 0.58601800E+03, 0.10244700E+04, 0.32458900E+03, -.17392000E+03, -.26052100E+04, -.16223900E+03, -.86301600E+03, -.14143800E+04, -.38773900E+03, -.13498100E+04, 0.13353500E+04, -.14375400E+04, 0.13815100E+04, -.11226300E+03, 0.79209500E+02, -.31205700E+03, 0.56238600E+02, 0.10320200E+02, -.10696800E+03, 0.98869000E+02, 0.15520600E+03, 0.33002900E+03, -.27258100E+03, -.12794100E+03, -.25823300E+04, 0.12911000E+04, 0.96647000E+03, 0.12909700E+04, 0.49041000E+03, 0.15092100E+04, 0.11919800E+03, 0.51772500E+02, 0.36718100E+03, 0.83825200E+03, 0.27487500E+03, 0.62607900E+04, -.31395800E+04, 0.53352000E+03, -.31304900E+04, -.88565600E+03, 0.12915100E+04, -.20026700E+04, -.21955100E+03, -.21279600E+04, 0.36192200E+03, -.32280800E+04, 0.14154700E+04, -.69633900E+03, 0.19539400E+04, -.70779300E+03, 0.55178400E+03, 0.10946000E+04, 0.97227600E+02, 0.12908400E+04, -.13495100E+04, 0.95296100E+03, -.15615100E+04, -.60642900E+03, 0.32057100E+03, 0.18264900E+04, 0.30243300E+03, 0.95707800E+03, 0.10493300E+04, -.84251200E+03, -.70965400E+03, -.88169100E+03, 0.12720100E+04, -.22366600E+03, -.98240400E+03, 0.48622300E+03, -.10777900E+04, 0.49135500E+03, 0.70137700E+03, 0.72362600E+03, 0.34344900E+02, -.35422200E+03, 0.80742600E+03, 0.24934600E+03, 0.45798300E+03, -.10992600E+04, 0.54296500E+03, -.76023900E+03, 0.54955600E+03, -.15366900E+04, -.16942500E+04, 0.48488200E+03, 0.35062600E+03, 0.61988800E+03, -.16920300E+04, 0.12481700E+03, 0.61616700E+04, -.31011300E+04, -.13646800E+04, -.30811900E+04, -.31123200E+03, 0.90109300E+03, -.16695500E+04, 0.79138800E+02, -.15761800E+04, 0.33375600E+03, -.21086600E+04, 0.66362800E+03, -.33292500E+03, -.62395000E+03, -.33195500E+03, 0.18834700E+03, 0.57089400E+03, -.74246700E+01, 0.67681500E+03, 0.25536800E+03, 0.40713700E+03, -.25760300E+03, -.55059700E+03, 0.32314100E+03, 0.99138900E+03, 0.27490400E+03, -.85114600E+03, -.11382200E+04, 0.78312900E+03, 0.11807700E+04, 0.76567900E+03, -.11331000E+04, 0.29602300E+03, 0.39520700E+03, -.16912600E+03, -.37426700E+03, -.29548100E+03, 0.49338600E+03, 0.12539700E+03, 0.13763000E+03, -.24435800E+03, 0.37201000E+03, 0.13298400E+03, -.61584900E+03, 0.47951300E+03, 0.66756400E+03, 0.29583600E+03, 0.11685700E+04, -.26388400E+03, -.52464600E+03, 0.11630900E+03, 0.14145000E+04, 0.28498400E+03, -.99944900E+03, -.41558400E+03, -.24933000E+03, -.15942000E+03, -.13716500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33191000E+01, -.23536100E+00, 0.12662200E+01, -.43112200E+01, -.42494300E+00, 0.24623500E+00, 0.38097300E+01, 0.60632000E+01, -.11342900E+01, -.75221000E+00, -.37009500E+00, -.42153000E+01, 0.47521200E+01, 0.80960200E+00, -.47245200E+01, -.40369300E+01, 0.59247900E+01, 0.58048700E+00, -.70421700E+00, 0.25477400E+01, 0.87336000E+01, 0.51516000E+00, -.19824500E+01, 0.30542200E+01, -.98386300E+00, -.80451700E+00, 0.65415000E+01, 0.17750400E+01, 0.20028300E+01, 0.13203000E+01, 0.17529200E+01, -.75664300E+00, -.94363400E+00, -.22849600E+00, -.16182700E+01, -.10458300E+01, 0.55837900E-01, -.90392200E+00, 0.42621500E+00, -.95107000E+00, 0.27547100E+01, 0.24596100E+01, -.53327700E+00, 0.12496700E+00, -.10245500E+01, -.97664100E+00, -.69119800E+00, 0.28425900E-01, 0.53470700E+00, -.13667800E+01, 0.50173200E+00, -.24661500E+00, 0.12056200E+00, -.10852500E+01, -.58400300E+00, -.43317000E+00, 0.95380000E+00, 0.46344800E+01, 0.41987600E+00, -.16329200E+01, 0.13508900E+00, -.13787800E+00, -.48186100E+00, -.56350900E+00, 0.22232100E+01, -.37424600E+00, 0.48219000E+00, -.35315900E+01, -.54494900E+00, -.10483200E+01, 0.38855200E+01, -.24489500E-01, -.42285400E-01, -.20395600E+01, -.98381000E+00, 0.21535200E+01, 0.58596800E+04, 0.23449100E+04, -.28796000E+03, -.85064100E+03, -.11665200E+04, 0.38687300E+03, 0.16234000E+04, -.13652700E+04, -.32306900E+03, -.17584700E+04, 0.15330000E+04, 0.26090500E+04, -.23931900E+04, 0.10918100E+04, -.10567300E+05, 0.12019200E+04, -.30862700E+04, -.66069100E+04, 0.29241700E+04, 0.53832300E+04, 0.70135200E+04, -.66890300E+04, -.22983000E+04, 0.30980000E+05, -.15414700E+05, -.10527200E+05, -.15489400E+05, -.88058100E+04, -.79243500E+04, -.30911200E+04, 0.27649000E+04, -.58281100E+04, -.49674600E+04, -.47540300E+04, 0.33194200E+04, -.25640900E+04, 0.10420400E+04, -.16595800E+04, -.32289200E+04, -.81021000E+04, 0.31520900E+04, 0.62577400E+04, 0.12266800E+04, -.76187200E+04, -.94065300E+04, -.10299300E+05, 0.49390400E+04, -.42658900E+04, 0.51508500E+04, 0.32487100E+03, 0.83571800E+03, 0.45998900E+04, -.75051200E+02, -.68311100E+03, -.74522800E+03, -.43502100E+04, -.20026000E+04, 0.15265000E+04, -.16691800E+04, 0.10047700E+04, 0.33296000E+04, 0.96315300E+04, -.43503000E+04, -.96095200E+04, -.38534100E+04, 0.94656700E+04, 0.12864000E+05, -.87937100E+04, 0.43130300E+04, -.14245500E+05, 0.43974800E+04, 0.20721300E+04, -.64766400E+04, -.71851500E+03, -.84308400E+04, 0.16751900E+05, -.71134500E+04, 0.80141800E+04, -.19134000E+04, 0.11433300E+04, 0.20110900E+04, 0.96322500E+03, 0.74475100E+03, 0.14131500E+04, -.11387000E+04, -.12453000E+04, -.74429400E+03, 0.15904100E+04, -.43311900E+04, -.15027000E+05, 0.74933900E+04, 0.76670500E+04, 0.75198400E+04, 0.17867400E+04, 0.70708300E+04, 0.89514300E+02, -.96672100E+02, -.16088900E+04, 0.53203700E+04, 0.20201100E+03, 0.16603600E+05, -.83893300E+04, 0.61454900E+03, -.83027900E+04, -.46629800E+04, 0.29008500E+04, -.42943800E+04, 0.55001600E+04, -.34265700E+04, 0.74778300E+03, -.27524800E+05, 0.22772400E+05, -.11286200E+05, 0.78842500E+04, -.11386800E+05, -.41722200E+04, 0.45366200E+04, -.13299400E+04, 0.84293100E+04, -.16313400E+05, 0.38780500E+04, -.10122600E+05, 0.21998300E+04, -.89845300E+03, -.34114900E+04, -.11087100E+04, 0.10974600E+04, -.11878000E+04, 0.79466900E+03, 0.36428100E+04, 0.58274500E+04, -.11134200E+04, 0.10505600E+05, -.75674200E+04, 0.37265600E+04, -.11387700E+04, 0.37854300E+04, 0.51400300E+04, 0.19587400E+04, 0.10851200E+04, -.24273600E+04, 0.67581700E+04, -.32041800E+03, 0.12396500E+04, -.83557300E+04, 0.41580600E+04, -.19051000E+04, 0.41770200E+04, -.56868800E+04, -.68130800E+04, 0.50860800E+04, 0.97436300E+04, 0.50457900E+04, -.58903400E+04, -.11474800E+05, 0.26229300E+05, -.13244500E+05, -.80200600E+04, -.13118600E+05, -.67016400E+02, 0.53478400E+04, -.87045500E+04, -.27084600E+03, -.41817200E+04, 0.23724700E+04, -.11299800E+05, 0.36979100E+04, -.18375100E+04, -.25664900E+04, -.18507600E+04, 0.37268100E+04, 0.71098100E+04, -.52036300E+04, -.16085200E+04, -.29185900E+04, 0.65357900E+04, 0.81714800E+02, -.42437400E+04, 0.24875600E+04, 0.42471300E+04, 0.21173100E+04, -.39906700E+04, -.80818600E+04, 0.73769500E+04, 0.12834000E+05, 0.88323500E+04, -.70852400E+04, -.47360100E+04, 0.72692100E+03, -.16496600E+04, -.69634200E+03, 0.36973700E+03, 0.41639700E+03, -.10705200E+04, -.11047700E+04, 0.54038800E+02, 0.54542100E+03, 0.23151100E+03, -.32848200E+04, 0.41049900E+04, 0.12783000E+04, 0.14562600E+04, 0.24677400E+04, 0.21672400E+03, -.17023400E+04, 0.31181800E+04, 0.37349200E+04, 0.15171600E+03, -.46331200E+04, -.52431300E+04, 0.14990300E+04, -.15340300E+04, 0.71749200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37117700E+00, -.56571300E+00, -.94111400E+00, 0.54182000E+00, -.21011900E+00, -.88520000E-01, -.69330800E+00, -.88609200E+00, 0.94348400E+00, 0.41580400E+00, -.55015800E-01, 0.20180300E+01, -.13823000E+01, -.24884400E+00, -.47312100E+00, -.72843200E+00, -.64078500E+00, 0.55565900E-01, 0.26206500E+00, -.56871800E+00, -.16463800E+00, -.33455500E-01, 0.36224900E-02, 0.10021500E-01, 0.16941500E-01, 0.13217500E-01, -.52044300E-01, 0.15386900E+00, -.22578300E+00, 0.48527600E+00, 0.20140600E+00, 0.76031900E-01, -.79195600E-02, -.60348900E+00, 0.70533200E-02, 0.46635400E+00, 0.17945300E-01, -.11446600E+00, 0.81566100E-01, -.92886000E+00, -.18371600E+00, 0.20750900E+00, 0.41671000E+00, 0.15198300E+00, 0.54947500E-01, -.37004600E+00, 0.23516200E-01, 0.56408900E-03, -.37199900E+00, 0.49101400E+00, 0.79788200E+00, -.52849600E+00, 0.10041700E+00, -.94147100E-01, 0.16341600E+00, 0.14163000E+00, -.31874600E+00, -.12517500E+01, 0.11683400E-01, 0.37422000E+00, 0.58299500E-01, -.39452300E-01, -.85255900E-01, 0.57493300E+00, 0.21701600E-01, 0.44278900E-03, 0.14802000E+00, 0.73485400E+00, -.26561700E-01, -.13904800E+00, 0.10006400E+01, 0.32329800E+00, 0.23444900E+00, -.16020900E+00, 0.58881200E-01, -.24995100E+00, 0.86989500E-01, -.97216700E+03, 0.41372900E+03, 0.42026200E+03, 0.48603500E+03, 0.71042400E+02, -.10439100E+03, 0.15047600E+03, -.29212300E+03, 0.17437800E+03, -.16799000E+02, 0.36000000E+03, 0.13142400E+04, -.65496800E+03, 0.43518700E+03, -.65723900E+03, 0.43532500E+03, 0.46932700E+03, -.46520900E+03, -.51337600E+03, -.89787800E+03, 0.20131600E+03, -.16731100E+04, -.35243500E+03, 0.16955200E+03, 0.22664600E+03, 0.17620800E+03, 0.79938500E+03, 0.14081100E+03, -.26116700E+03, -.99018600E+03, -.67086300E+01, -.49085200E+03, -.20562300E+03, 0.24362900E+04, -.11499700E+04, -.10780800E+04, -.12181400E+04, -.11922300E+02, 0.62771300E+03, -.61216900E+03, -.40696100E+02, -.83165000E+03, 0.59381400E+03, -.99969200E+03, -.39479700E+04, 0.19952600E+04, -.18274200E+04, 0.19739600E+04, -.17616600E+02, -.17011600E+03, 0.30889100E+03, -.73693400E+03, 0.20689400E+04, 0.68726900E+02, 0.12960800E+04, -.30047700E+04, 0.14671700E+04, 0.13225400E+04, 0.15023200E+04, -.72731800E+02, -.85114400E+03, 0.87482500E+03, 0.23995200E+03, 0.10180100E+04, -.86245800E+03, 0.11598000E+04, 0.63317900E+04, -.31514000E+04, -.11755900E+04, -.31659100E+04, -.14986400E+04, -.17791400E+04, -.27154700E+03, 0.11785000E+04, -.18219500E+04, -.23047800E+04, -.91578800E+03, 0.16974300E+03, -.80766100E+02, 0.28566400E+03, -.85314100E+02, -.37913200E+02, -.11115500E+03, 0.30606400E+02, 0.34193400E+02, -.15535900E+02, -.10603600E+03, -.17434900E+03, 0.10999500E+04, -.53292400E+03, -.51894300E+03, -.55094900E+03, -.25502800E+03, -.35215500E+01, -.27179200E+03, 0.31579900E+03, -.18148500E+03, 0.19830800E+03, 0.74210200E+02, -.24767100E+02, 0.34364100E+02, 0.91032600E+03, 0.12406400E+02, 0.17331000E+03, 0.21071400E+03, 0.43022100E+03, 0.11645000E+04, 0.68467600E+02, 0.21892100E+03, -.39466000E+03, -.28433400E+04, 0.14058300E+04, 0.17667700E+03, 0.14216800E+04, 0.10498000E+04, 0.18695800E+04, -.58699200E+03, -.10319100E+04, 0.79764100E+03, 0.19225400E+04, 0.41769500E+03, 0.47635300E+03, -.26397400E+03, -.37060300E+03, -.23800600E+03, -.52102200E+03, -.25351100E+03, 0.97770400E+03, 0.11385700E+04, -.37296600E+03, -.18623500E+03, 0.78116300E+03, -.10044100E+04, 0.49464600E+03, 0.57714700E+03, 0.50216900E+03, -.63675900E+03, 0.10639300E+03, 0.54649500E+03, 0.87863600E+03, 0.76858300E+02, 0.59389100E+03, 0.37797200E+03, -.57027600E+03, 0.30273300E+03, 0.20189700E+03, 0.28515400E+03, 0.66366000E+03, 0.25169400E+03, 0.61612600E+03, 0.68048500E+03, 0.56439800E+03, 0.26095800E+01, 0.43355200E+03, 0.25417000E+04, -.12689400E+04, -.17980000E+04, -.12707600E+04, -.65640700E+03, -.59411200E+03, -.17325800E+03, 0.36442300E+03, -.55131100E+03, -.10667300E+04, 0.74033000E+03, -.17078700E+03, 0.92665600E+02, 0.91705800E+02, 0.85442300E+02, -.35661700E+03, -.45454200E+03, 0.46221100E+02, -.32795100E+03, 0.15495900E+03, -.38054700E+03, 0.55783500E+03, -.29930900E+03, 0.12807100E+03, -.14246900E+03, 0.14974400E+03, 0.89100100E+02, 0.36273800E+03, 0.46610800E+03, 0.54012000E+03, 0.38567900E+03, 0.39667000E+03, 0.80301500E+03, -.27648400E+03, 0.18212500E+03, 0.19237300E+01, 0.65056600E+02, -.65291000E+02, -.13515100E+02, -.32322300E+02, 0.53815600E+02, -.26022900E+01, -.14531400E+03, -.11564700E+03, -.12269900E+03, 0.12234000E+03, -.18397100E+03, 0.14914200E+03, 0.64919000E+02, -.27062500E+03, -.11366500E+03, 0.99365500E+02, -.14076100E+03, -.82440400E+02, -.90461500E+02, 0.14631200E+03, 0.26045500E+03, 0.25360100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18137000E+01, -.19345600E+01, -.28868800E+01, 0.26878200E+01, -.37005700E+01, -.79899900E+00, -.99012300E+00, -.27703900E+01, 0.81345600E+00, 0.26184400E+00, 0.75324700E-01, 0.87945900E+00, 0.47414800E+01, 0.27724400E+00, 0.33743400E+01, -.18392700E+01, -.19099300E+01, 0.14039200E+00, 0.40161200E+00, -.13735600E+01, -.21554700E+01, -.15330600E+00, -.50652200E+00, -.47462900E+01, 0.18105500E+00, 0.97442000E-01, -.24537000E+01, -.61690800E-01, -.55143800E+00, 0.42705900E+00, -.49261800E-01, 0.98173800E+00, 0.44618400E+00, -.56543100E+00, -.69075200E-01, -.31173500E-01, 0.22656400E-02, -.10559800E+01, 0.53907300E+00, 0.14537000E+01, -.71458600E+00, -.22621400E-01, -.14346800E+01, -.44187200E+00, 0.10110500E+00, 0.80869100E+00, -.10127000E+00, 0.62651000E-02, -.66297000E+00, -.71142400E+00, -.16650600E+01, 0.72854400E+00, -.28371400E+00, -.10100300E+00, -.19132700E+00, -.31473500E+00, -.33692600E+00, 0.25733900E+01, -.37499800E-01, 0.21067500E-01, 0.55131200E-01, -.10426500E+00, 0.10669500E+00, 0.41480800E+00, -.56155400E+00, -.61187400E-02, 0.31101800E+00, -.16449700E+01, -.41835400E+00, -.31879600E+00, 0.32881800E+01, 0.10928800E+01, 0.99325800E+00, 0.16611400E+00, -.28817600E+00, 0.13028800E+00, 0.16095500E+00, -.23716100E+01, -.60330300E+03, -.40288600E+03, -.50838900E-01, 0.25449000E+02, 0.15720300E+03, -.34672100E+01, -.30233200E+02, 0.26396400E+03, 0.12636700E+03, 0.59871400E+03, 0.19284500E+04, -.88079500E+03, 0.34054700E+04, -.96445700E+03, -.25597300E+03, 0.13394300E+04, -.10526700E+03, -.53953100E+03, -.22431200E+04, 0.10441500E+04, -.93601900E+03, -.77229800E+04, 0.37851100E+04, 0.13006900E+04, 0.38615000E+04, -.89066300E+02, 0.91483000E+03, 0.45154800E+02, -.35052700E+04, 0.26554400E+04, -.14232600E+04, 0.41833100E+04, 0.41470600E+03, 0.40887300E+03, 0.12032200E+04, -.20732800E+03, 0.13540700E+04, 0.21603800E+04, -.97941600E+03, -.11080900E+04, -.92611800E+03, 0.18728900E+04, -.10406000E+04, -.14161500E+04, 0.93430400E+03, -.49029700E+04, 0.70803400E+03, 0.12805300E+03, -.16382400E+04, 0.17395600E+04, 0.70970700E+03, 0.47145000E+04, -.77817300E+03, 0.10608200E+03, 0.18166000E+04, -.12635800E+04, -.28412400E+04, -.90840000E+03, -.14096500E+04, -.23545100E+04, 0.82304600E+03, 0.18893800E+04, 0.61361300E+03, -.21780000E+04, -.50088400E+03, 0.47973700E+04, -.23003400E+04, 0.36897100E+04, -.23987000E+04, -.40830500E+04, -.67650400E+04, 0.36465400E+04, 0.28336900E+04, -.24395100E+04, -.60373000E+04, -.30456800E+03, 0.16174700E+04, -.90598300E+03, -.11649400E+04, -.81073800E+03, -.20176400E+03, -.39490900E+03, 0.28229200E+03, 0.66267000E+03, 0.32245700E+03, -.46948100E+03, -.80958700E+03, 0.51601500E+04, -.24854800E+04, -.93172100E+03, -.25817600E+04, 0.21580600E+04, 0.27854000E+02, -.12901400E+04, 0.76062800E+03, -.12192100E+04, 0.93915100E+03, -.34835600E+04, -.98466000E+04, 0.50713400E+04, 0.46013500E+04, 0.49233200E+04, 0.27915600E+04, -.25912000E+04, 0.54105600E+04, 0.47728600E+04, 0.41934900E+04, -.18680500E+04, 0.19836200E+04, -.19155600E+04, 0.84557600E+03, -.41989700E+04, 0.95780000E+03, 0.26996800E+04, 0.60336000E+04, -.37234000E+04, -.32282500E+04, 0.12592300E+04, 0.48976500E+04, 0.32189000E+03, -.77857700E+03, 0.14714600E+03, -.36127200E+03, 0.38950100E+03, -.10466200E+04, 0.59504500E+03, 0.79035000E+03, 0.17734000E+04, -.23970200E+04, 0.59904500E+03, 0.14504300E+04, 0.15035100E+04, -.75973200E+03, 0.19123500E+04, -.75179700E+03, -.87525400E+03, 0.79336000E+02, 0.11690700E+04, 0.37983100E+04, -.12957300E+04, 0.17954400E+04, -.37547400E+03, -.35414400E+04, 0.18420400E+04, 0.30450700E+03, 0.17707400E+04, 0.23324800E+04, 0.73360600E+03, 0.22037800E+04, 0.98300100E+03, 0.14085300E+04, 0.79101900E+02, 0.32577300E+03, -.79799200E+04, 0.40511200E+04, 0.92650700E+03, 0.39900500E+04, -.68861400E+03, -.34625100E+04, 0.31067100E+04, -.71740000E+03, 0.27147600E+04, -.30818400E+04, 0.58487900E+04, 0.20982200E+03, -.80424400E+02, 0.16538000E+04, -.10482700E+03, -.35962000E+03, -.11621500E+04, -.17108900E+03, -.90561500E+03, 0.27755500E+03, -.80248700E+03, 0.54055600E+03, -.14952500E+04, 0.48210900E+03, -.14923200E+04, 0.74775300E+03, 0.17769500E+04, 0.17273500E+04, 0.61281100E+03, 0.32492000E+03, -.28682500E+03, 0.13783600E+04, -.25506300E+03, -.22027600E+03, 0.55616700E+03, -.40739700E+03, -.22141200E+03, -.23786800E+03, -.57810500E+03, -.65197200E+03, -.21782800E+03, 0.36540200E+03, 0.48523300E+02, -.62411300E+03, -.10465700E+04, 0.42026000E+02, -.24776200E+03, 0.62732400E+03, -.18693700E+03, -.10945200E+04, -.89424300E+02, -.19190800E+03, -.16768300E+03, 0.80959700E+02, 0.20758200E+03, -.78214600E+02, 0.79142400E+03, 0.16569600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15665700E+01, 0.84251600E+00, -.37635700E+01, 0.54759400E+00, -.17130300E+01, -.11467700E+00, -.20319300E+01, -.23081300E+01, 0.56610700E+01, 0.13218000E+01, 0.21002500E+00, -.15614900E+01, -.28144400E+00, 0.92176400E+00, -.25369900E+01, 0.49927200E+00, 0.67665300E+00, 0.66254500E+00, -.78322600E+00, 0.51315600E+00, 0.10376800E+01, -.32213500E+00, 0.13796600E+01, -.10707600E+01, 0.56839100E-01, -.10971200E+00, -.18887300E+01, 0.51841900E+00, -.72465800E+00, 0.52661700E+00, -.40107400E+00, 0.51160000E+00, 0.16087100E+00, -.13518800E+01, 0.43814300E+00, 0.20866200E+01, 0.62045100E-01, -.46942800E+00, -.61025300E+00, 0.14775900E+01, -.29751700E+01, -.72465300E+00, -.87146000E+00, -.45263700E+00, -.91200600E-01, 0.51382500E+00, 0.14507800E+00, -.42050100E-03, -.10621500E+01, 0.32001100E+00, -.85092500E+00, 0.25545400E+01, -.31980500E-01, 0.96048800E+00, 0.21640500E+00, -.11677800E+01, -.13590300E+01, 0.21477700E+01, -.93961800E-01, 0.28377500E+00, 0.91814200E-01, -.72385400E+00, -.44798700E-01, 0.16773400E+01, 0.92993200E+00, 0.45387300E+00, -.37951300E+00, -.19288100E+01, -.97489800E+00, 0.73940800E-01, 0.34837500E+01, 0.49588300E+00, 0.10432500E+01, -.11945300E+00, -.13145400E-01, 0.80376900E+00, 0.11841100E+00, 0.75464200E+00, 0.81093900E+00, 0.21757900E+04, -.34056900E+01, 0.17019500E+03, 0.29278300E+02, 0.23514300E+03, -.82822500E+02, -.70399100E+03, 0.61563700E+02, -.88255400E+03, 0.71505300E+04, -.36291700E+04, 0.19015600E+04, -.35776500E+04, 0.21657000E+03, 0.36350900E+04, -.20018500E+04, 0.97970600E+03, -.41511900E+03, 0.23557400E+04, 0.55516700E+03, -.17891900E+05, 0.89572200E+04, -.43259400E+04, 0.89454900E+04, 0.18863700E+04, 0.25210300E+04, 0.47714100E+04, 0.27233400E+04, 0.81788300E+04, 0.28249200E+04, 0.53728000E+04, -.75200800E+03, 0.36796800E+03, -.21057900E+03, 0.37583800E+03, -.10595500E+04, -.15399000E+04, 0.92939500E+03, 0.11122100E+04, 0.14893400E+04, -.12591800E+04, 0.27196600E+04, 0.79583700E+04, -.39754400E+04, 0.11191900E+05, -.39797400E+04, 0.15446500E+04, 0.20910700E+04, -.42511700E+04, -.40187400E+04, -.10355600E+05, 0.21970400E+04, -.75274500E+04, -.15089100E+04, 0.77128900E+03, 0.16711500E+04, 0.75272100E+03, 0.11188900E+04, 0.18790400E+04, -.93561200E+03, -.16817600E+04, -.86659400E+03, 0.17531200E+04, -.14373500E+04, 0.30754400E+05, -.15322600E+05, -.19681100E+05, -.15377500E+05, 0.27244300E+04, 0.98653200E+04, -.82529400E+04, 0.74936200E+04, -.89448400E+04, 0.80573200E+04, -.18264700E+05, -.75766000E+03, 0.34452300E+03, 0.24335100E+04, 0.37948200E+03, 0.38707200E+03, 0.65158800E+03, -.54421500E+03, -.10191500E+04, -.10760500E+04, 0.72431200E+03, 0.20041000E+03, 0.27903900E+04, -.13808800E+04, 0.26856600E+04, -.13923300E+04, -.22705800E+04, -.14503200E+04, -.15440500E+04, -.31811700E+04, -.24576400E+04, -.11961400E+04, 0.43908300E+04, -.62082200E+04, 0.31407400E+04, -.99333300E+04, 0.31046600E+04, -.33196400E+04, -.12488500E+04, -.50448600E+03, -.36809800E+04, 0.23648500E+04, -.19620100E+04, 0.10084500E+05, -.23545700E+05, 0.11736800E+05, 0.15570400E+05, 0.11773200E+05, -.18007300E+04, -.88988500E+04, 0.69838000E+04, -.45195000E+04, 0.70583100E+04, -.67280800E+04, 0.13189500E+05, -.14041400E+04, 0.69239300E+03, -.68695600E+04, 0.70665600E+03, -.21989000E+04, -.27419100E+04, 0.17279100E+04, 0.16608600E+04, 0.66775000E+04, -.26118700E+04, 0.38567300E+04, 0.13363500E+05, -.66978900E+04, 0.79843300E+03, -.66826700E+04, -.92506600E+03, -.15958700E+04, -.34299700E+04, -.12913900E+03, -.44993900E+04, -.23491700E+04, -.75590200E+04, 0.67021400E+04, -.33016400E+04, -.97009000E+03, -.33506300E+04, 0.13133600E+04, 0.52752700E+04, -.40403500E+04, -.10386600E+04, -.20527000E+04, 0.42739100E+04, 0.22115500E+04, 0.83447200E+04, -.41315800E+04, -.92160400E+04, -.41703100E+04, -.58079200E+03, 0.12606000E+04, -.20270200E+04, 0.27146700E+04, -.12679100E+04, 0.12584500E+04, -.54538500E+04, -.30096600E+04, 0.15312500E+04, 0.13142500E+04, 0.15056200E+04, -.51280900E+03, -.16711100E+04, 0.42488800E+03, -.10600000E+04, -.64988800E+03, -.74929100E+03, -.24584000E+03, 0.22751800E+04, -.11996500E+04, -.37334000E+04, -.11352800E+04, 0.30755100E+03, 0.16386000E+03, -.10497300E+04, -.15127900E+03, -.14369200E+03, 0.25552600E+03, 0.20677300E+04, -.11712100E+04, -.18678700E+03, 0.11325800E+04, 0.38564700E+03, -.25500700E+03, 0.83980200E+03, 0.82728500E+03, 0.36939000E+03, -.10678000E+04, 0.13909000E+03, 0.35143400E+04, 0.48556400E+03, -.34288700E+04, -.34870700E+02, -.54319600E+04, 0.35392300E+03, 0.41141000E+04, -.29317100E+03, -.54026900E+04, -.18449800E+04, 0.45346600E+04, 0.66906500E+03, 0.64271100E+03, 0.22036500E+03, 0.79390500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19678100E+01, 0.11856000E+01, 0.18979700E-02, 0.23422800E+01, 0.45286700E+00, 0.14311600E-01, -.18020400E+01, -.24570700E+01, 0.15326700E+01, 0.30311300E+00, 0.35743200E+00, -.39009000E+01, -.95990700E+00, 0.84111100E+00, 0.17520500E+00, 0.26906000E+01, 0.42338400E+00, 0.80210900E+00, -.83230500E+00, 0.87503100E+00, -.18976500E+01, -.17556500E+00, 0.19194700E+01, 0.10796200E+01, 0.20034500E+00, 0.53255300E+00, -.17574500E+01, -.92697300E+00, -.29130700E+00, 0.28195100E+00, -.46513800E+00, -.62778400E+00, 0.24092000E+00, 0.92115800E+00, 0.60854200E+00, 0.12771900E+01, 0.88691500E-01, 0.23748500E+01, -.13622400E+01, -.35200200E+00, -.72568400E+00, -.13285000E+01, 0.11672700E+01, 0.91539400E-01, 0.41365800E+00, -.55385800E+00, 0.31759400E+00, 0.82391400E-03, 0.80347400E-01, 0.93477100E+00, 0.19066000E+01, 0.74977200E-01, 0.34997300E+00, 0.82988100E+00, 0.24162700E+00, 0.48656800E+00, 0.17897800E-02, -.34037700E+01, 0.11374400E+00, 0.33123100E+00, -.62049200E-01, 0.78203900E+00, -.43807100E+00, -.75860600E+00, -.14853700E+01, 0.70414700E-01, -.86079700E-04, 0.11178000E+01, 0.69408900E+00, -.41146800E+00, -.25845800E+01, -.20569900E+01, -.32842400E+00, 0.27179600E-01, 0.12346300E+00, -.32783500E+00, -.26627600E+00, 0.24294200E+00, -.30949000E+00, -.42474600E+00, 0.11148500E+02, 0.20299300E+03, 0.60496600E+03, -.31791600E+03, -.46651200E+03, -.43026100E+03, 0.40230900E+03, -.34659800E+03, -.45358400E+04, 0.22918500E+04, -.33772300E+04, 0.22719800E+04, -.15927600E+04, -.30398300E+04, 0.19429400E+04, 0.17696200E+04, 0.33218700E+04, -.21500400E+04, 0.24747900E+04, 0.44439200E+04, -.22389000E+04, 0.12804500E+04, -.22212800E+04, -.32111200E+04, -.26208100E+04, -.26606800E+03, 0.76827400E+03, -.11260700E+04, -.58407600E+03, -.26817400E+04, -.18643000E+04, 0.95112400E+03, 0.16359300E+04, 0.93240300E+03, -.22728100E+02, -.11424200E+04, 0.72917300E+03, 0.10638000E+04, 0.14509400E+04, -.10621800E+04, 0.11586000E+04, -.18221900E+04, 0.96545000E+03, 0.36510000E+03, 0.91203600E+03, 0.17487100E+04, 0.22481600E+04, 0.17645400E+04, 0.13105300E+04, -.17964600E+04, 0.10806200E+04, 0.14117400E+04, 0.19610000E+04, -.99605600E+03, -.14627900E+04, -.97760400E+03, 0.28980200E+03, 0.17380700E+04, -.10084200E+04, -.15533400E+04, -.16758900E+04, 0.17474000E+04, -.12713900E+04, -.28215200E+04, 0.14286300E+04, -.73814500E+04, 0.14113000E+04, 0.45015200E+03, -.77446600E+03, -.10993100E+03, -.61506300E+03, 0.40344100E+04, -.17936600E+02, 0.76507600E+03, -.75781700E+03, 0.35109400E+03, 0.11368800E+03, 0.38163600E+03, 0.11476500E+03, 0.25625600E+03, -.21563100E+02, -.42177000E+03, -.26687600E+03, 0.22832100E+03, 0.25512100E+03, -.16084800E+04, 0.82911700E+03, 0.86445100E+03, 0.80505700E+03, 0.15647100E+04, 0.20301900E+04, -.71327100E+01, 0.59876800E+03, 0.30244900E+03, 0.12368400E+04, 0.11868900E+04, 0.70051700E+04, -.34685000E+04, 0.80235800E+03, -.35034700E+04, -.11225600E+03, 0.18753200E+04, -.34252000E+04, -.15521900E+04, -.27650300E+04, 0.14539400E+04, -.17165300E+04, 0.27518800E+04, -.13957200E+04, 0.67396000E+04, -.13764800E+04, -.76615500E+03, -.44691300E+03, 0.99090300E+03, 0.12462100E+04, -.27560800E+04, -.73063800E+03, -.10966000E+04, 0.31396800E+04, -.16292700E+04, -.88224400E+03, -.15773800E+04, -.24801900E+02, -.71668500E+03, -.14706600E+04, -.93829900E+02, 0.18918300E+04, -.76646200E+03, -.20275200E+04, -.11276900E+04, 0.55860700E+03, -.18868300E+04, 0.56532000E+03, 0.24728600E+04, 0.15378200E+04, -.29129900E+03, -.11336100E+04, 0.11277600E+04, -.23383500E+03, 0.84017500E+03, -.62348400E+03, 0.31999800E+03, -.19982100E+04, 0.31102600E+03, -.22817800E+04, -.20964400E+04, -.62068600E+03, -.46470800E+03, 0.25625200E+02, -.86177500E+03, 0.14482200E+04, 0.78772800E+04, -.39350100E+04, -.99060000E+03, -.39419900E+04, 0.74916400E+03, 0.25607000E+04, -.25708000E+04, 0.50942200E+03, -.16469100E+04, 0.23534700E+04, -.44939700E+04, 0.28673300E+03, -.13733500E+03, -.68169700E+03, -.14471100E+03, 0.13559100E+04, 0.25433300E+04, -.98451000E+03, 0.10410000E+03, -.86103700E+03, 0.22357400E+04, -.54687000E+03, -.13361300E+03, 0.26097800E+02, 0.14685300E+04, 0.62986100E+02, -.62539200E+03, -.18167100E+04, 0.43936200E+03, 0.60824700E+03, 0.60269300E+03, -.15626900E+04, 0.86779700E+03, 0.65567800E+03, -.60379300E+03, -.68434600E+03, -.38973400E+03, 0.25780100E+03, -.52738200E+03, -.52464000E+03, -.36639800E+03, 0.69801600E+03, 0.11500000E+03, -.15952900E+04, 0.74349600E+03, 0.90239400E+03, 0.67751200E+03, 0.36015700E+02, -.38605700E+03, -.15047100E+04, 0.53638300E+03, 0.14724400E+03, 0.64819500E+03, -.21479600E+04, -.57701700E+03, 0.56659900E+02, -.73965000E+03, -.55046700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.60700000E+00, 0.49863400E+00, 0.83981100E+00, 0.16465300E+00, -.37633400E+00, 0.23108700E-01, 0.76384500E+00, 0.11270900E+01, -.65699500E+00, -.24491800E+00, 0.13655600E+00, 0.49359300E+00, 0.17438000E+01, 0.61246500E+00, 0.52783100E+00, -.27459100E+00, -.14423600E+00, -.68564900E+00, 0.41311800E+00, -.14295200E+00, -.79319000E+00, -.14777900E+00, 0.10109900E+00, -.73582600E+00, 0.10628400E+00, 0.10032600E+00, -.89488600E+00, 0.28368000E-01, 0.12536400E+00, 0.36061200E+00, -.49580000E+00, -.36156400E+00, 0.55082500E+00, -.97515600E+00, 0.14329700E+00, 0.35158600E+00, 0.39221900E-02, 0.29318400E+00, -.24281300E+00, -.10509200E+01, 0.59866800E+00, 0.58773800E-01, 0.63034200E+00, 0.79376500E-01, 0.27161700E+00, -.12243600E+00, -.15550000E+00, -.13890500E-02, 0.61292800E+00, -.17590700E+00, 0.54189800E+00, -.95830900E+00, 0.73389000E-01, -.20275000E+00, 0.70145900E-01, 0.22618600E+00, 0.66650900E+00, 0.83080000E+00, 0.72211000E-01, -.34317600E+00, 0.89127700E-01, 0.38053700E+00, -.91820300E-01, -.11416900E+01, 0.70241900E+00, -.15050500E+00, 0.17066000E+00, 0.35524400E+00, 0.55333300E-01, -.23066000E-01, -.16070800E+01, 0.59506700E+00, -.46286300E+00, 0.38843400E+00, -.87958600E-01, 0.39280600E+00, -.52722000E-01, -.70881800E+00, 0.26399100E-02, 0.14429300E+00, 0.14015400E+00, -.27302400E+03, -.42459300E+03, 0.23855300E+03, 0.42329300E+03, 0.52029600E+03, -.34819900E+03, 0.38863700E+03, 0.11729100E+04, -.60734600E+03, 0.22248700E+04, -.58597100E+03, 0.47182600E+03, 0.16919400E+04, -.88242500E+03, -.10208100E+04, -.20680300E+04, 0.19317900E+04, -.91333000E+03, 0.36325000E+04, -.17940400E+04, 0.96742700E+03, -.18161500E+04, 0.21139500E+04, 0.66963400E+03, -.13774700E+04, -.27093700E+03, -.16539600E+04, 0.15922600E+03, -.40711900E+03, 0.13592400E+03, -.84904200E+02, -.84927100E+03, -.67914900E+02, 0.48365400E+03, 0.14427300E+04, -.52075300E+03, -.92074100E+03, -.75909200E+03, 0.13514800E+04, -.60568200E+03, -.52237400E+03, 0.18445300E+03, -.17986800E+04, 0.26130300E+03, -.85834400E+03, -.94079200E+03, -.39074400E+03, 0.54149200E+03, 0.32789500E+04, -.81199600E+03, 0.24928200E+04, 0.11339300E+04, -.56431200E+03, 0.16870500E+03, -.56659400E+03, -.58071300E+03, -.18646600E+04, 0.43760800E+03, 0.13804100E+04, 0.62755600E+03, -.18749500E+04, -.69966700E+02, -.74601000E+04, 0.36906500E+04, 0.74505100E+04, 0.37301200E+04, -.85345900E+03, -.19735900E+04, 0.32328100E+04, 0.97082400E+02, 0.21368100E+03, -.16381400E+04, 0.16982700E+04, 0.64793700E+03, -.30600900E+03, -.64001100E+03, -.32423700E+03, -.15239100E+03, -.32907600E+03, 0.15319100E+03, 0.44424400E+03, 0.32435600E+03, -.34111900E+03, -.13702700E+03, -.13835000E+04, 0.63895400E+03, -.95853400E+03, 0.69031000E+03, -.61978800E+03, -.99336600E+03, 0.92175200E+03, -.22200700E+03, 0.49435000E+03, -.77079300E+03, -.21373900E+04, -.41039200E+04, 0.19845800E+04, 0.33406700E+04, 0.20518400E+04, -.64473800E+02, -.73046000E+03, 0.21213800E+04, 0.26215400E+03, 0.87319400E+03, -.17316000E+03, -.28801300E+03, 0.18188200E+04, -.86930700E+03, -.50006500E+04, -.90948000E+03, 0.14944600E+04, 0.18124500E+04, -.21630300E+04, -.90854400E+03, 0.60341200E+03, 0.16569900E+04, -.35522900E+03, -.25464600E+03, 0.21816800E+03, 0.26395400E+04, 0.12632900E+03, 0.46248900E+03, 0.12274800E+04, -.24428000E+03, -.15365700E+04, -.37290800E+04, 0.13996500E+04, -.25281500E+04, -.33802400E+04, 0.17114900E+04, 0.49691200E+03, 0.16903100E+04, -.17620200E+04, -.37603900E+03, 0.11551000E+04, 0.26503200E+03, 0.72881800E+03, 0.25469100E+03, 0.21653600E+04, 0.10281500E+04, -.55084500E+03, 0.19442700E+04, -.51416900E+03, 0.83511100E+03, 0.76706200E+03, 0.20181300E+03, -.23515400E+03, -.67172000E+03, 0.54155000E+03, -.25341400E+04, -.65694300E+04, 0.32862200E+04, 0.39575600E+04, 0.32842800E+04, 0.79166300E+03, -.11524900E+04, 0.23826400E+04, -.34893400E+03, 0.72805400E+03, -.87926100E+03, 0.10522800E+04, -.17275800E+03, 0.67168200E+02, -.33218700E+03, 0.86222200E+02, -.43187200E+03, -.10131800E+04, 0.90927400E+03, 0.29613900E+03, 0.62458000E+03, -.12537800E+04, 0.11407500E+03, 0.10251900E+04, -.46332800E+03, -.98650000E+02, -.51308800E+03, 0.35018000E+03, 0.62938500E+03, -.64328800E+03, -.12479400E+04, -.10677600E+04, 0.47639900E+03, -.23156200E+04, -.34496100E+03, 0.54959800E+03, 0.15408000E+03, -.11659100E+02, -.48611700E+03, 0.47027400E+02, 0.68845300E+02, -.41611600E+01, -.16720000E+03, -.24368600E+03, 0.42924700E+02, -.45727500E+03, 0.16141600E+03, -.21513500E+03, 0.40605100E+03, 0.73250600E+01, -.69381800E+02, -.54654900E+03, 0.26172000E+02, -.21450900E+02, -.77656300E+02, 0.29959500E+03, -.60605100E+02, 0.34201500E+03, 0.14698900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.58964900E+00, 0.44921400E+00, 0.36237600E+00, 0.47677700E+00, 0.63649500E-01, -.51456900E-01, -.80064300E+00, -.39505800E+00, 0.54497800E+00, 0.29068500E+00, 0.75659500E-01, -.32666700E+00, -.12278500E+01, 0.54941600E+00, -.17148600E+01, 0.14881100E+01, 0.38117700E-01, -.11483000E+00, 0.84006500E+00, 0.26310000E+00, -.10781200E+01, -.25426200E-01, 0.53232600E+00, -.19021400E-01, 0.21032100E-01, -.18703700E-01, -.13940700E+00, -.83873300E-01, -.37040700E+00, 0.21835700E+00, -.20156800E-01, -.27297200E+00, -.35954600E+00, -.27825900E+00, -.25257300E+00, 0.26703800E+00, 0.47362600E-02, 0.81918100E-01, -.66356800E-01, -.64396800E+00, 0.40105300E+00, -.36602200E-01, 0.46328600E+00, 0.14800100E+00, -.16816200E+00, -.47559000E-01, -.29734700E+00, 0.67931500E-03, 0.14450200E+00, 0.19387600E-01, -.21144200E+00, -.66380000E+00, 0.88171600E-01, -.14425700E+00, -.10307400E+00, 0.23922600E+00, 0.70675800E+00, -.94620000E-01, 0.95874800E-01, -.33417800E+00, 0.35649600E-01, 0.11654100E+00, 0.20583700E+00, -.12731600E+01, 0.17431400E+01, -.14189900E+00, 0.13053300E+00, -.15570400E+01, -.77929100E+00, -.14827800E+00, -.68161900E+00, -.13112500E+00, -.16629200E+00, 0.58854500E-01, 0.31631800E+00, 0.15546400E+00, 0.90245200E-02, 0.30362300E-01, 0.81766300E-01, 0.66751100E-01, 0.90915100E-01, -.47709600E+00, -.35168100E+03, -.12019100E+03, -.42848600E+03, 0.24805400E+02, -.21232200E+03, 0.11412300E+03, 0.25028100E+03, -.12527500E+03, 0.18343000E+04, -.12445300E+03, 0.10356300E+04, 0.64184700E+03, -.56384000E+03, -.74006500E+03, -.11013400E+04, 0.65819500E+03, -.10161900E+04, -.58109800E+03, 0.29350600E+03, 0.11372400E+04, 0.29063900E+03, 0.28380100E+04, 0.90110200E+03, -.28370500E+03, -.39955000E+03, -.64325300E+03, 0.20039200E+03, 0.26550000E+03, 0.51344200E+04, -.25751600E+04, -.30187800E+04, -.25671700E+04, 0.42570300E+03, 0.12445700E+04, -.18885300E+04, -.11662400E+04, -.24734600E+04, 0.11068500E+04, -.21355100E+04, -.85040600E+03, 0.40855200E+03, -.25027700E+04, 0.42535700E+03, -.10272100E+04, -.15110700E+04, -.23054900E+03, -.10910600E+04, 0.21330000E+04, -.11302400E+04, 0.31824000E+04, -.55120700E+04, 0.27650200E+04, 0.32223200E+04, 0.27565000E+04, -.72022200E+03, -.16404500E+04, 0.26747400E+04, 0.23533500E+04, 0.26967700E+04, -.15243900E+04, 0.15699200E+04, -.49209900E+03, 0.23511300E+03, 0.57979900E+04, 0.24613200E+03, -.19163200E+04, -.17597700E+04, 0.57682900E+03, -.14487000E+04, -.12464900E+04, -.14899900E+04, 0.67721700E+03, 0.46468400E+03, -.22875400E+03, 0.11554700E+03, -.23245600E+03, -.13952300E+03, -.29762500E+03, 0.21933600E+03, 0.36701500E+03, -.22003800E+02, -.28614400E+03, -.24885900E+03, -.48085300E+03, 0.23360100E+03, -.10252400E+04, 0.23863200E+03, -.58126300E+03, -.57744600E+03, 0.53344900E+03, 0.29225900E+03, 0.43949800E+03, -.28810200E+03, -.13214600E+04, -.36645700E+04, 0.18209600E+04, 0.17287200E+04, 0.18321500E+04, -.47568400E+03, -.39615300E+03, 0.20822100E+04, 0.13030600E+04, 0.12179400E+04, -.21795500E+03, 0.22650700E+04, -.39925900E+03, 0.20845900E+03, -.40133700E+04, 0.19954500E+03, 0.19821700E+04, 0.20793100E+04, -.77678500E+03, 0.55512900E+03, 0.93559800E+03, 0.16458400E+04, -.47607200E+03, -.27416100E+04, 0.13872800E+04, 0.15513500E+04, 0.13696300E+04, 0.10442100E+03, 0.10116500E+04, 0.50764200E+03, 0.52026300E+03, -.10687900E+04, 0.10757000E+04, -.16248400E+04, -.11790900E+04, 0.59259200E+03, -.15066400E+02, 0.58977200E+03, -.25126600E+04, -.79716300E+03, 0.46788300E+03, -.22389600E+03, 0.32085300E+03, -.10679200E+03, 0.15525100E+04, -.15874300E+04, 0.78953200E+03, 0.10586000E+04, 0.79360300E+03, 0.52780400E+03, 0.29135000E+03, 0.12896700E+04, 0.11800300E+04, 0.47453300E+03, -.21812100E+03, 0.65361300E+03, -.50393100E+04, 0.25133100E+04, 0.17603100E+04, 0.25191400E+04, -.13071600E+03, -.96986700E+03, 0.17426900E+04, -.60898100E+03, 0.90654700E+03, -.85120700E+03, 0.23798200E+04, 0.82682400E+03, -.41833800E+03, -.34621200E+02, -.41363400E+03, -.36692600E+03, -.53680900E+03, 0.17364900E+03, -.34279400E+03, -.95506200E+02, -.63295500E+03, -.49953300E+03, -.72052600E+03, 0.37846400E+03, -.46226500E+03, 0.35965600E+03, -.48448900E+03, 0.28709300E+03, 0.47081400E+03, 0.64377800E+03, 0.24087600E+03, 0.76474900E+02, 0.23018100E+03, 0.35993300E+02, 0.28244400E+03, 0.24610500E+03, -.52261000E+02, -.25036300E+03, -.17543100E+03, -.13728200E+03, -.58433300E+02, -.21887200E+03, -.10882500E+03, -.44064800E+02, -.73362200E+03, 0.53905400E+02, -.43470300E+03, 0.11582300E+04, -.45745300E+02, -.29518300E+03, -.39646600E+03, 0.11890400E+04, -.46169500E+01, 0.78949700E+02, 0.51541500E+02, 0.23336000E+02, 0.14706800E+03, 0.22560300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.31965700E+00, 0.18995700E+00, 0.26641100E+00, 0.31266300E+00, -.79926600E-01, -.36637800E-01, -.28047300E+00, -.50091200E-01, 0.37278200E+00, 0.23107100E+00, 0.46842100E-01, -.46404500E+00, -.10864400E+01, 0.41226200E+00, -.15014800E+01, 0.17416600E+01, 0.12154900E-01, 0.17595900E-01, 0.33224600E+00, 0.25524900E+00, -.11431000E+01, 0.12868200E-01, 0.32169000E+00, -.52045900E+00, 0.48176300E-01, 0.41747400E-02, 0.12917800E+01, -.11874600E+00, -.53731900E+00, -.92907900E-01, 0.82048000E-01, -.26993300E-01, -.10249300E+00, 0.29426000E+00, -.45218100E-01, -.15038400E+00, -.54160100E-02, -.34435700E-01, 0.13445400E-01, -.13499000E+00, 0.14936900E+00, 0.97605700E-02, 0.12452300E+00, 0.60755600E-03, -.14036200E-01, -.24700000E-01, 0.19212400E-01, -.70708900E-03, 0.48773200E-01, 0.24735400E-01, 0.76675400E-01, -.37540200E+00, 0.14236300E-01, -.64032400E-02, 0.28530500E-01, 0.40081700E-01, 0.25066300E-01, -.45865900E+00, -.34977800E-02, 0.97491500E-01, -.19544900E-01, -.78566100E-01, 0.77863300E-01, -.13523700E+00, 0.32032300E+00, -.51517800E-02, 0.59774000E-02, 0.10800700E+00, -.92810800E-01, 0.16247100E-01, -.61133800E+00, -.23666400E+00, 0.76969300E-01, 0.98037800E-01, 0.83750700E-01, -.21562700E+00, -.20142500E-01, -.11861000E+00, -.10932000E+00, -.36436200E-01, 0.11559300E-01, 0.21529000E+00, 0.27365200E+00, 0.14498300E+03, 0.21723600E+03, 0.23929200E+02, 0.21866200E+02, 0.34082900E+02, 0.13804300E+03, -.63665300E+02, -.22836800E+03, -.69261600E+02, 0.14718500E+03, 0.49628100E+03, -.31618200E+03, -.14049900E+03, -.14673200E+03, 0.25194600E+03, -.71883600E+03, -.98287500E+03, 0.48757000E+03, -.54788600E+03, 0.49139700E+03, -.89595400E+03, 0.18660900E+03, 0.12090000E+03, -.20733800E+02, 0.45074000E+03, 0.17759500E+03, 0.83372100E+03, -.17460000E+04, 0.87742800E+03, 0.10742200E+04, 0.87298500E+03, -.14656700E+03, -.88499300E+02, 0.60759300E+03, 0.46132100E+03, 0.79825800E+03, -.14363000E+03, 0.54522600E+03, 0.13817600E+04, -.67971500E+03, 0.78695800E+03, -.69093600E+03, -.91329300E+02, 0.12224600E+03, 0.67074900E+02, 0.41043300E+03, -.62711000E+03, 0.72371800E+02, -.15642700E+04, 0.15147900E+04, -.75820300E+03, -.11175300E+04, -.75756900E+03, 0.25619600E+03, 0.12609700E+03, -.80471300E+03, -.85751800E+03, -.65203300E+03, 0.18613300E+03, -.19734300E+03, 0.47657300E+04, -.23770300E+04, -.42299200E+04, -.23828900E+04, 0.16279500E+03, 0.10807700E+04, -.14073200E+04, 0.81542300E+03, -.10513300E+04, 0.52717900E+03, -.13292000E+03, -.21939700E+03, 0.10923000E+03, -.88532600E+02, 0.10966600E+03, 0.17657300E+01, -.12568700E+02, 0.85262200E+02, -.46540200E+01, 0.11434600E+03, -.70037000E+01, 0.78539300E+02, 0.61533800E+03, -.30199500E+03, 0.25968100E+03, -.30715600E+03, 0.33326200E+03, -.20631900E+02, -.22083200E+03, -.10709500E+03, -.25549400E+02, -.96734600E+02, -.17202900E+03, 0.37836000E+03, -.18257200E+03, -.11824600E+04, -.18912800E+03, 0.47151800E+03, 0.43738300E+02, -.34177800E+03, -.10153300E+03, 0.21733300E+03, -.20563500E+03, -.14791600E+04, -.21925700E+04, 0.10899200E+04, 0.26950800E+04, 0.10963200E+04, -.36228800E+03, -.75890900E+03, 0.72829700E+03, -.40868900E+03, 0.39812600E+03, -.43810400E+03, 0.48336000E+01, -.52807000E+03, 0.25260900E+03, -.69932500E+03, 0.26448400E+03, 0.22580300E+03, -.25243600E+03, -.51525000E+00, -.30377800E+03, 0.52034700E+03, -.22437700E+03, 0.12780800E+04, 0.82843500E+03, -.41555400E+03, 0.11638100E+03, -.41430500E+03, 0.65465000E+03, -.16085000E+02, -.95265000E+02, 0.24077900E+03, -.29677800E+03, -.69373000E+02, -.68476200E+03, 0.35935000E+03, -.17888000E+03, -.30258900E+03, -.17963200E+03, 0.23174600E+03, 0.21329000E+03, -.33680800E+03, -.11760900E+03, 0.12831800E+03, 0.17213400E+03, -.79285800E+03, 0.35599900E+04, -.17799000E+04, -.21117000E+04, -.17798000E+04, -.47628300E+03, 0.24013600E+03, -.95754000E+03, 0.46036300E+03, -.71911800E+03, -.81903500E+02, -.18890400E+03, -.51093400E+03, 0.25712000E+03, 0.19058600E+03, 0.25554500E+03, -.16211000E+03, -.22110900E+03, 0.82058200E+02, -.19899300E+02, 0.16483200E+03, -.83727100E+02, 0.70806100E+03, -.52195900E+03, 0.25420300E+03, 0.19988500E+03, 0.26120700E+03, 0.34260300E+03, 0.15521900E+03, 0.48250600E+02, 0.14068300E+01, 0.33613000E+02, 0.19616400E+03, 0.17266200E+03, 0.47737200E+01, -.26400700E+02, 0.97888400E+01, 0.82447600E+02, 0.19384800E+03, 0.23001900E+03, 0.20717400E+03, 0.82343900E+02, -.22690400E+02, 0.11520900E+03, 0.31908500E+03, 0.15710900E+03, -.20929100E+03, 0.40197800E+02, -.53814900E+03, 0.80745800E+02, 0.38637300E+03, 0.20268900E+02, -.40831900E+03, -.27226100E+02, 0.43392400E+03, 0.81744700E+02, -.65254000E+00, 0.10752300E+03, -.48471300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.41660500E+00, 0.28933800E+00, 0.36159000E+00, 0.27780600E+00, -.33162100E+00, -.89347600E-01, -.65429600E+00, -.23617000E+00, 0.43915600E+00, 0.12468500E+00, 0.89511200E-01, -.26603400E+00, -.39675700E+00, 0.37610300E+00, -.73210400E+00, 0.30767200E+00, 0.19515800E+00, 0.22173000E+00, 0.40866700E+00, 0.39175400E+00, -.27818100E+00, -.84965800E-02, 0.82566200E-01, -.11118900E-01, -.48154000E-01, -.31491800E-01, -.41661500E+00, 0.32545800E-01, -.13116300E+00, 0.20439800E+00, 0.21977500E+00, -.85430300E-01, -.24668600E+00, -.32734100E+00, 0.26954800E-01, -.37193900E-02, 0.16130500E-02, 0.31410400E+00, 0.23555500E+00, -.46388900E+00, 0.81919100E+00, 0.26460800E+00, -.15568100E+00, 0.12197700E+00, -.81482000E-03, -.13732300E+00, -.85919300E-01, 0.24526100E-02, 0.40824400E-02, 0.26379900E+00, -.31971800E+00, -.51566900E+00, -.51424800E-01, -.40481000E+00, -.42601600E-01, 0.29184300E+00, 0.75348900E-01, 0.42162800E+00, 0.11605600E-02, -.28025900E+00, -.70328400E-01, -.18540800E+00, -.61283400E-01, -.30985000E+00, 0.93098800E-01, -.21490300E-01, -.35121600E-01, -.12136800E+01, -.37815300E+00, -.57516600E-02, 0.27808100E+00, 0.14949200E+00, -.47294100E-01, 0.24426200E-01, -.73601100E-01, 0.42761700E+00, 0.63504300E-03, -.44051200E+00, 0.19971700E+00, 0.13565800E+00, 0.23381700E-01, 0.21084800E+00, 0.15918400E+00, 0.14595100E+00, 0.10142100E+03, 0.43932300E+02, -.20154700E+02, -.40932900E+02, 0.53001600E+03, -.26730200E+03, -.45475700E+02, -.26504100E+03, 0.91925200E+02, -.15854700E+03, 0.33411800E+02, 0.22004900E+03, 0.28872000E+03, -.23659900E+03, 0.20622600E+03, -.12917700E+04, 0.64766900E+03, -.23796100E+02, 0.64586100E+03, -.47654100E+02, 0.68800800E+03, -.70928600E+02, -.40081800E+03, -.34229900E+03, 0.61678100E+03, 0.74949200E+03, -.54334500E+03, 0.27158600E+03, 0.50521300E+03, 0.27166000E+03, -.53588400E+02, -.22298100E+03, 0.28906000E+03, 0.97091100E+01, 0.92156700E+02, -.14069400E+03, 0.15428600E+03, -.12647800E+03, 0.57246900E+02, 0.14282400E+04, 0.63228000E+02, 0.82334400E+02, 0.25322600E+03, -.70745100E+03, -.77450900E+03, -.92341000E+03, 0.45804900E+03, 0.19073600E+03, 0.84877700E+03, -.42566100E+03, -.59842000E+03, -.42443200E+03, -.94061000E+01, 0.34116200E+03, -.48006900E+03, -.21314000E+03, -.32017300E+03, 0.25646600E+03, -.15612600E+03, 0.77142900E+03, -.38864700E+03, 0.74857300E+03, -.38572500E+03, 0.76936500E+03, 0.49079700E+03, -.53199400E+03, -.47037000E+03, -.61762600E+03, 0.29771500E+03, -.10185700E+04, -.24076300E+03, 0.12017900E+03, 0.25435200E+03, 0.12045500E+03, 0.46747400E+02, 0.17042400E+03, -.11930300E+03, -.15920700E+03, -.12941800E+03, 0.16017600E+03, 0.15295200E+03, 0.72064700E+03, -.36566700E+03, -.47553800E+03, -.36003600E+03, 0.48616300E+02, -.34865900E+03, 0.74585900E+02, 0.30505900E+03, 0.27195500E+03, -.24398000E+03, -.56683900E+03, -.19660400E+04, 0.97657800E+03, -.70653200E+03, 0.98304000E+03, 0.40001800E+03, -.13984600E+03, 0.46676300E+03, 0.20694200E+03, 0.10224600E+04, -.78092800E+02, 0.97087100E+03, -.11647100E+03, 0.62050300E+02, -.82038600E+03, 0.58244500E+02, -.73542300E+03, -.22710500E+03, 0.27093900E+03, 0.33367900E+03, 0.18887100E+03, -.12168300E+03, 0.59334600E+03, -.17863800E+03, 0.97630700E+02, -.12902200E+04, 0.89453400E+02, -.98743400E+02, -.71438400E+03, 0.91389300E+03, 0.69746700E+03, 0.82619400E+03, -.80323500E+03, -.23635400E+02, -.61157200E+03, 0.30780400E+03, 0.38421400E+03, 0.30575900E+03, 0.94591100E+02, -.40216500E+03, 0.25329200E+03, 0.64557300E+01, 0.31920900E+03, -.42987200E+03, 0.29967800E+03, -.40229600E+02, 0.16496100E+02, 0.12321900E+03, 0.20126800E+02, 0.45520500E+03, 0.42282200E+03, -.90951600E+02, 0.16588800E+03, 0.11893200E+03, 0.36554100E+03, -.23344100E+03, -.95081100E+03, 0.47684900E+03, -.99427000E+02, 0.47546700E+03, -.88873900E+02, -.30267800E+03, 0.38947900E+03, -.38115400E+02, 0.14540600E+03, -.26554400E+03, 0.51461700E+02, -.31942300E+03, 0.15811500E+03, 0.15409000E+03, 0.15972200E+03, -.96939300E+02, -.14602200E+03, 0.39017600E+02, -.23387600E+03, -.14353800E+03, -.29296300E+02, 0.29126200E+02, 0.24537000E+02, -.91589000E+01, -.16779700E+03, -.12207500E+02, 0.88554700E+02, 0.15675700E+03, 0.60513600E+02, 0.14672300E+03, -.15187800E+03, 0.14317900E+03, -.37633500E+03, -.73175800E+02, -.47026000E+02, 0.10555200E+03, 0.18148200E+03, -.52600600E+02, -.44107700E+02, -.54704500E+02, 0.17650800E+03, -.10553500E+03, -.50006500E+02, 0.21008100E+03, -.41250200E+02, -.18117900E+03, -.78554400E+02, 0.11830900E+03, 0.16994100E+03, 0.14088800E+03, 0.45885200E+01, 0.17377000E+03, 0.55424300E+02, 0.39960300E+03, 0.55366500E+02, 0.86490500E+01, -.15688000E+02, 0.79544300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.57080300E+00, -.38186500E+00, -.39600600E+00, 0.29768800E+00, 0.65173200E+00, 0.79399000E-03, -.53019700E+00, -.69631500E+00, -.36154600E+00, 0.30458600E-01, -.13345200E+00, 0.20327200E+01, -.15636200E+01, -.59726600E+00, 0.11697000E+00, -.18851200E+01, -.13208100E+01, 0.39702700E+00, 0.27319700E+00, -.35995100E+00, -.10775200E+01, -.19943500E-01, 0.44039800E+00, 0.97278900E+00, 0.22002500E+00, 0.16024100E-01, 0.66657300E+00, -.22118900E+00, 0.58169200E+00, 0.59428300E+00, -.80824100E+00, -.61342800E+00, 0.94426300E+00, 0.48652500E+00, 0.20849600E+00, 0.15956500E+00, -.91710300E-02, 0.96870200E+00, -.64504800E+00, 0.41792500E-01, 0.32482900E+00, -.91414400E-01, 0.10316200E+00, -.47601800E-01, -.26652600E+00, 0.36131500E+00, 0.14125100E+00, -.90193600E-02, -.16107500E-01, -.45689400E+00, -.54208300E+00, -.47657500E+00, -.39113200E-03, 0.39990000E+00, 0.17555000E+00, -.38460500E+00, 0.14080200E-01, 0.12124700E+01, -.39698100E-01, 0.35339300E+00, 0.15552900E+00, 0.32169200E-01, 0.20508900E+00, -.47849900E+00, 0.73911100E+00, 0.74238000E-01, -.64839800E-01, -.95794700E+00, -.60706000E+00, -.81885500E-02, 0.47925300E-01, 0.39232000E+00, -.31556200E+00, 0.33414200E-01, 0.20666100E+00, 0.11122900E+00, -.80116900E-01, 0.27089600E+00, 0.25063800E+00, -.10140200E+00, -.27671900E-01, -.45795700E+00, 0.19611500E+00, -.27366300E+00, -.11761900E+01, -.17107900E+03, -.43721100E+02, -.36091600E+03, -.23116600E+03, 0.10917800E+03, -.10917300E+04, 0.11558100E+03, -.10858000E+04, -.16627000E+04, 0.56237900E+03, 0.22410700E+03, 0.16477500E+04, -.15562800E+04, 0.26841100E+04, -.25446400E+04, 0.12806900E+04, -.15464200E+04, 0.12722900E+04, -.11732800E+04, -.23095500E+03, 0.99089900E+03, 0.34132300E+03, 0.10973000E+04, 0.43475000E+03, 0.51523700E+03, -.12954900E+04, 0.64732300E+03, 0.11621400E+04, 0.64771500E+03, -.51863300E+03, -.13429100E+04, 0.93540900E+03, 0.68316700E+03, 0.84316600E+03, -.10650800E+04, 0.13475000E+04, -.27769700E+03, 0.11181900E+03, 0.33928300E+04, 0.13884100E+03, 0.21739700E+04, 0.12516600E+04, -.92868900E+03, -.14921100E+04, -.34840200E+04, 0.12942800E+04, -.53502500E+03, 0.12348200E+04, -.62512200E+03, -.86733300E+03, -.61745900E+03, 0.64262100E+03, 0.19390000E+04, -.14327900E+04, -.13167700E+04, -.12494700E+04, 0.16915100E+04, -.10908000E+04, 0.36477500E+04, -.18346200E+04, -.22353000E+04, -.18238900E+04, 0.26692900E+04, 0.25932200E+04, -.25432200E+04, -.49772800E+03, -.60252800E+03, 0.23317700E+04, -.60328100E+04, -.66073400E+02, 0.26160500E+02, 0.82357100E+03, 0.34205600E+02, 0.14673200E+03, 0.33527400E+03, -.44961500E+03, -.54737700E+03, -.59452800E+03, 0.37754900E+03, 0.49224600E+02, -.10739800E+03, 0.25750900E+02, 0.92366800E+03, 0.55312100E+02, 0.26034800E+03, 0.40960900E+03, -.30681600E+03, 0.31415000E+02, -.26964100E+03, 0.27271800E+03, 0.14284500E+04, -.89908800E+03, 0.41783300E+03, -.26945800E+04, 0.44956400E+03, -.75488000E+03, -.15315500E+03, -.33369600E+03, -.27819000E+03, 0.50555800E+03, -.31489300E+03, 0.34433900E+04, -.13449700E+04, 0.68780500E+03, 0.17451300E+04, 0.67249600E+03, -.20734700E+04, -.21958400E+04, 0.18664300E+04, 0.83813500E+03, -.32026600E+02, -.17651500E+04, 0.34220100E+04, -.13212400E+04, 0.69760600E+03, -.29631600E+04, 0.66077400E+03, -.11348500E+04, -.82632000E+03, 0.10700300E+04, 0.13609700E+04, 0.35808600E+04, -.10862100E+04, 0.12050800E+04, 0.28976400E+04, -.14347700E+04, -.32136300E+03, -.14488500E+04, 0.84917400E+03, -.54011100E+02, -.69700300E+03, -.80630900E+02, -.63909700E+03, -.68328200E+03, -.17838800E+04, -.10871900E+04, 0.52165500E+03, -.16449700E+04, 0.54360800E+03, -.88776100E+03, -.23744800E+03, -.31638300E+03, -.26104100E+03, 0.30653400E+03, -.15259300E+03, 0.23265200E+04, 0.13351400E+04, -.65777100E+03, -.16253200E+04, -.66750600E+03, 0.69616100E+03, 0.76782400E+03, -.70475400E+03, 0.29351400E+03, -.21795600E+03, 0.90805900E+03, -.31837100E+04, 0.72463400E+03, -.37097500E+03, 0.43882200E+03, -.36232500E+03, 0.71802400E+03, 0.65584500E+03, -.56676300E+03, -.66385200E+02, -.87032200E+03, 0.73730700E+03, -.13783300E+04, 0.40101600E+03, -.19051300E+03, -.12316000E+04, -.20044300E+03, -.45958600E+03, -.32837300E+03, 0.24355800E+03, 0.11536300E+04, 0.68049300E+03, -.31391400E+03, 0.31704900E+03, 0.15036300E+03, -.55060000E+03, -.47169900E+02, -.11356800E+03, 0.22013800E+03, -.37556200E+03, -.38699800E+03, -.13031600E+03, 0.62368500E+02, 0.90407900E+02, 0.18665900E+03, 0.79322200E+03, -.58026600E+03, 0.49720600E+03, -.13199000E+03, -.13719000E+03, 0.39777700E+03, 0.53845700E+03, 0.29935900E+02, -.15066300E+03, 0.35184900E+03, -.22169300E+03, -.14128400E+03, -.49368400E+03, -.48871800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15622300E+01, 0.86693000E+00, 0.14728200E+01, 0.12513500E+01, 0.20384000E+01, 0.25920800E+00, -.98476200E+00, 0.13149000E+01, 0.33210600E+01, 0.72041400E+00, -.69969500E+00, -.26735200E+01, 0.73684400E-01, -.17765700E+00, -.19971600E+01, 0.18627200E+01, 0.14424100E+01, -.50893500E+00, -.12070400E+01, -.89907400E+00, 0.16444600E+01, 0.31876300E+00, 0.41008800E+00, 0.51278500E+00, -.14658000E-01, -.18653800E-01, -.16944500E+01, 0.28811600E+00, 0.49651600E+00, 0.27290300E+01, 0.23667800E+00, -.63349100E+00, -.21179100E-01, -.18755600E+01, 0.56668300E-01, 0.15320100E+01, 0.51203000E-01, 0.67917200E+00, -.34132200E+00, -.25257500E+01, 0.14507600E+00, 0.39796500E-01, 0.27737300E+01, 0.12223500E+01, 0.45066400E+00, -.15111600E+01, 0.31635000E+00, 0.33689000E-02, 0.83111000E+00, 0.18236800E+00, 0.90432400E+00, -.47051400E+00, 0.15180700E+00, -.17731200E+00, 0.29238400E+00, 0.84032500E+00, -.12776900E+00, -.67432500E+01, 0.62889400E-01, 0.32811700E+00, -.23725600E+00, 0.49332000E+00, 0.84659000E-01, -.26363900E+01, -.14947500E+01, 0.43421600E+00, -.36053500E+00, -.22826400E+01, 0.35271500E+00, -.63586700E+00, 0.36970000E+00, -.20293700E+01, 0.18660800E+00, 0.21624000E+00, 0.95428400E-01, 0.43143700E+00, -.13818700E+00, -.11053800E+01, 0.26775400E+00, -.24664800E-01, 0.56459400E+00, -.97604100E-01, 0.19610300E+00, 0.17651900E+01, 0.14776200E+01, -.15409400E+01, -.25509800E+03, -.49959900E+03, 0.26580200E+04, -.13884400E+04, 0.54327100E+02, -.13258400E+04, -.20061100E+04, -.60249600E+04, 0.33908800E+04, 0.48952000E+04, 0.38977000E+04, -.47854200E+04, 0.43279100E+04, 0.22146500E+04, -.10619800E+04, 0.32455500E+04, -.11069500E+04, 0.20277600E+04, 0.12973200E+04, -.81351200E+03, 0.26307800E+03, -.10548200E+02, 0.20627300E+04, -.13543300E+04, 0.68793400E+03, -.37827700E+03, -.42953400E+02, -.34389200E+03, 0.11867300E+03, -.58678800E+03, -.56690300E+03, -.13279100E+04, -.81635800E+03, 0.15666100E+03, 0.18055400E+04, -.86751900E+04, 0.41984900E+04, -.37424500E+03, 0.43383000E+04, 0.35394500E+04, -.70872800E+03, 0.37614300E+03, -.42408900E+04, -.10388900E+04, -.53997600E+02, 0.58443600E+04, 0.24326900E+04, -.12095500E+04, -.46219600E+03, -.12142800E+04, -.26689200E+03, 0.11576700E+04, -.38164100E+03, 0.14731200E+04, -.11910500E+04, 0.49858600E+03, -.36506800E+04, 0.57530200E+04, -.29230200E+04, 0.83789300E+04, -.28761400E+04, 0.27936400E+04, 0.21029100E+03, -.15270500E+04, -.13397700E+04, -.43721900E+04, 0.17267700E+04, -.19286400E+05, 0.16662500E+04, -.82145300E+03, 0.14065500E+04, -.83091400E+03, 0.12514400E+03, 0.34078700E+03, -.74302500E+03, -.41087800E+03, -.14467700E+04, 0.38885200E+03, -.71345300E+03, -.47317900E+04, 0.22716200E+04, -.15996200E+04, 0.23682700E+04, 0.23237500E+03, -.34328400E+03, 0.41508900E+03, -.40713000E+03, 0.90150000E+02, 0.22314700E+03, 0.32507500E+04, -.28329800E+04, 0.13072900E+04, 0.17705900E+04, 0.14158800E+04, -.14391000E+04, -.52518700E+03, 0.16638300E+04, 0.20813500E+04, 0.37008800E+03, 0.92247300E+03, 0.88276500E+04, -.72126800E+04, 0.36674400E+04, -.46037900E+04, 0.36059500E+04, -.15157000E+04, -.28030600E+03, 0.17798300E+04, 0.38847000E+03, 0.38812100E+04, -.94974500E+03, 0.14115500E+05, -.89770300E+03, 0.61031100E+03, -.21463400E+04, 0.44360000E+03, -.33925600E+04, 0.60349600E+03, 0.97893000E+03, 0.37148400E+04, 0.28488100E+04, -.39774200E+03, -.18163000E+04, -.19530600E+04, 0.10122500E+04, -.36545200E+04, 0.97755800E+03, -.26544800E+04, -.16604400E+04, 0.19110600E+04, 0.77739700E+03, 0.13598500E+04, -.27054600E+04, 0.50068800E+03, 0.13511500E+04, -.72426900E+03, 0.50441900E+03, -.67608000E+03, 0.13894600E+04, 0.13767000E+03, -.47693500E+03, 0.16741700E+04, -.16675400E+04, 0.11500800E+04, 0.23520300E+04, -.10254600E+05, 0.51510400E+04, 0.53931100E+04, 0.51249800E+04, 0.26529100E+04, 0.45799600E+03, 0.20698600E+04, -.12829100E+04, 0.15641600E+04, 0.15711800E+04, -.51429700E+04, -.64539200E+03, 0.29850600E+03, -.46567300E+03, 0.32161800E+03, 0.99712100E+03, 0.10546100E+04, -.97123900E+03, -.25841600E+04, -.21461500E+04, 0.11185900E+04, -.19246000E+04, 0.25347600E+04, -.12018700E+04, -.13099500E+04, -.12701000E+04, -.16061500E+03, 0.13685800E+04, -.99472500E+03, 0.14714400E+04, -.93449900E+03, 0.13246300E+04, -.12819600E+04, -.81911400E+03, 0.87320300E+02, 0.12564700E+03, -.12109100E+03, -.15630100E+04, -.11438600E+04, -.11254300E+04, -.14726400E+03, -.77341900E+02, -.12495900E+04, -.79598800E+03, -.28886300E+02, -.13254300E+04, 0.26945200E+03, 0.95477600E+03, -.13134700E+03, -.96332000E+03, 0.76783900E+03, 0.36689000E+03, -.14568500E+04, -.56518400E+03, -.93907600E+03, 0.92824800E+03, -.26248200E+03, 0.99855400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10042400E+01, -.57133200E+00, -.62334700E+00, -.84733300E+00, -.45911000E+00, -.97351400E-01, 0.38855800E+00, -.82029900E+00, -.13641800E+01, -.14003200E+00, 0.42013400E+00, 0.19275500E+01, -.12402100E+01, -.16539700E+00, -.16697900E+00, -.11947600E+01, -.51603700E+00, 0.49113900E+00, -.77721500E-01, 0.44661400E+00, -.61805000E+00, -.43544500E-01, -.27777500E+00, -.46067200E+00, 0.16170600E-01, -.42193000E-01, 0.13392100E+01, 0.71977500E-01, 0.32351400E+00, -.13991100E+00, 0.22830300E+00, 0.63045500E+00, -.48377700E+00, 0.40045400E+00, -.20407200E+00, -.45012100E+00, -.24635400E-01, -.10453700E+01, 0.72163900E+00, -.40052100E+00, 0.99633300E+00, 0.54262400E+00, -.38832800E+00, -.20120600E-01, -.90107400E-01, 0.17719200E+00, 0.25090400E+00, -.22293800E-02, 0.52188200E+00, -.98291200E-01, -.96451100E+00, -.11505400E+01, -.82522300E-01, -.18209300E+00, 0.69218300E-01, -.86709300E-01, -.25364800E+00, 0.12570200E+01, -.57954500E-01, 0.37185700E-01, -.10243100E-01, -.49178200E+00, 0.13574900E+00, 0.93128400E+00, -.16537700E+00, 0.10779200E+00, -.10123300E+00, -.59724900E-01, -.11703500E+00, 0.61068100E-01, 0.83952800E-01, -.41398100E-01, 0.25026600E+00, 0.16495400E+00, 0.61509600E-02, -.60943000E+00, -.31000500E-01, -.22605600E+00, -.18335300E+00, -.23665800E+00, -.72893500E-01, 0.51345200E+00, 0.66364200E-01, 0.28711700E+01, 0.15719200E+00, 0.26877700E+00, 0.39161200E-01, -.37875200E+03, 0.87502900E+03, -.45276500E+03, 0.10108600E+04, -.43752800E+03, -.71333800E+03, -.19143300E+03, 0.26751500E+03, 0.86964700E+02, 0.12486400E+01, -.37990400E+03, 0.23534700E+04, -.60806800E+04, 0.30402500E+04, 0.67091200E+02, 0.30403500E+04, 0.12483900E+04, 0.23294400E+03, 0.20083600E+04, 0.46664700E+03, 0.26191300E+04, -.80780700E+02, 0.18446400E+04, 0.42257000E+03, -.21745500E+03, -.66777100E+03, -.21127300E+03, 0.37404600E+02, -.29688700E+03, -.30389100E+03, -.23573300E+03, -.14519000E+03, -.36742700E+03, 0.18664600E+04, 0.14022000E+04, -.68944200E+03, 0.45747600E+03, -.70110100E+03, 0.59163100E+03, -.15979700E+03, -.60059300E+03, -.81731700E+03, -.15980700E+04, 0.91562300E+02, -.14457200E+03, -.65206500E+03, 0.33835500E+03, 0.72217500E+03, 0.32604100E+03, 0.91697700E+02, 0.65391600E+03, 0.28697400E+03, 0.18506800E+02, -.19176800E+03, 0.80737600E+03, -.21850900E+04, 0.95024200E+03, -.45488300E+03, 0.17064900E+04, -.47512000E+03, -.16707500E+04, -.95235400E+03, 0.53002500E+03, -.29822900E+03, -.35313400E+03, -.23615500E+03, -.36034000E+04, 0.16079200E+02, -.28687400E+02, 0.20170700E+03, -.81801000E+01, 0.14246000E+03, 0.21317500E+03, -.19483700E+03, -.55370300E+02, -.15376700E+03, 0.23039300E+03, 0.72902500E+00, 0.46876700E+03, -.22488900E+03, 0.63890000E+03, -.23477600E+03, -.10683800E+02, 0.25941000E+03, -.64605500E+03, -.40711600E+03, -.69791100E+03, 0.44508900E+03, 0.96995800E+03, -.16894900E+04, 0.86651600E+03, -.13209900E+04, 0.84474200E+03, -.12532400E+04, -.83227600E+03, 0.81204800E+03, 0.43749300E+03, 0.44552200E+03, -.10546400E+04, 0.51977000E+04, -.13869800E+04, 0.67798000E+03, -.79996100E+03, 0.69349000E+03, 0.14043200E+04, 0.42348500E+03, 0.11389800E+03, 0.13203200E+03, 0.60882100E+03, 0.72948500E+02, 0.22964800E+04, 0.25689800E+03, -.14449300E+03, -.67558800E+03, -.12846900E+03, -.10969900E+04, -.32861700E+02, 0.26546000E+02, 0.10378700E+04, 0.95711300E+03, -.31564000E+02, -.81044900E+03, 0.52610300E+04, -.26353000E+04, -.53690400E+03, -.26305100E+04, -.12247500E+04, -.40134800E+03, -.15336200E+04, -.47394000E+02, -.18510900E+04, -.10493600E+03, -.24019400E+04, -.17554800E+03, 0.10910400E+03, -.12619700E+04, 0.87772400E+02, -.52237800E+03, 0.21928700E+03, 0.17713000E+03, 0.10652600E+03, -.27486000E+03, -.50054900E+03, 0.33954600E+04, -.33669600E+04, 0.17011500E+04, -.13299800E+03, 0.16834700E+04, -.99198700E+02, -.41374200E+03, 0.97864000E+03, -.45867600E+03, 0.12589500E+04, 0.15510200E+03, -.30686200E+03, 0.14833600E+04, -.73336500E+03, 0.76455300E+03, -.74167100E+03, 0.37429900E+03, 0.26714100E+03, -.52688600E+03, 0.45577400E+02, -.65892400E+03, 0.38256400E+03, -.22987100E+04, 0.70082100E+02, -.69660000E+02, -.19612100E+04, -.35047600E+02, -.55840200E+03, -.78967000E+03, 0.44935800E+03, 0.95890200E+03, 0.93155200E+03, -.10490700E+04, 0.11628500E+04, 0.37952000E+02, -.25614900E+03, -.12996200E+03, -.32436800E+03, 0.12604900E+03, -.26129400E+03, -.21716100E+03, -.30648700E+03, 0.13862500E+03, 0.18814500E+03, 0.31531300E+03, 0.21704500E+03, -.34874400E+03, 0.37107500E+03, 0.34441900E+03, -.31458400E+03, 0.27440200E+03, 0.20667500E+03, 0.21094700E+03, -.28754100E+03, 0.54283200E+03, -.15475200E+03, -.18735200E+03, -.21599000E+03, 0.13158000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15664200E+01, 0.28320400E+00, -.86032500E+00, -.12629000E+01, -.11251400E+01, 0.18847200E+00, 0.88033500E+00, 0.36010900E+01, 0.28812700E+01, -.26570900E+00, -.77971600E+00, -.75231300E+01, 0.41591400E+00, -.97787500E+00, -.49229800E+01, 0.44446800E+01, 0.42498200E+01, -.65188400E+00, -.30473200E+00, 0.58199700E+00, 0.20587500E+01, 0.96054600E+00, -.41252100E+00, 0.30326000E+01, -.44078800E+00, 0.19983000E+00, 0.15381000E+01, 0.24200100E+00, 0.33621100E+00, 0.26417400E+01, 0.79720900E+00, -.70890300E+00, 0.16237900E+01, -.14610100E+01, -.76615300E+00, 0.17048600E+01, 0.12966200E+00, 0.93883700E+00, -.18725100E+00, 0.23840800E+01, -.67559600E+00, -.32639300E+00, -.15063900E+01, 0.28637800E+00, 0.43957300E-02, -.48697000E+00, -.10805400E+01, 0.32671400E-01, 0.72686000E-01, -.16989800E+01, -.45446300E+00, 0.53301000E+01, -.45907900E+00, -.76794100E+00, -.93664700E+00, 0.27764300E+00, 0.81223900E+00, -.22394500E+01, 0.14867200E+00, -.14344100E+01, -.36316000E+00, 0.31950500E+00, 0.27090900E+00, -.17532600E+01, 0.24107300E+01, -.27236700E+00, 0.49960100E+00, 0.44672400E+00, 0.64995500E+00, 0.11802300E+00, -.35814600E+00, 0.93862000E+00, -.88207500E+00, -.71999000E+00, -.47178100E+00, 0.37736500E+00, 0.32137700E+00, 0.69752000E+00, -.49759600E+00, -.33133100E+00, -.33342300E+00, -.10197800E+01, -.95121800E+00, -.22286000E+01, -.17651100E+01, 0.81003100E+00, -.89121200E+00, -.90945700E+00, 0.69261900E+04, -.35315800E+04, 0.37903900E+04, -.34616600E+04, -.69888800E+02, 0.96227900E+03, -.71460600E+03, 0.95418900E+03, -.18523000E+04, 0.15253100E+04, -.11702900E+02, 0.26707500E+04, -.12902800E+04, 0.39336000E+04, -.13351000E+04, 0.47497300E+04, 0.20102500E+04, -.13150900E+04, 0.51796600E+03, -.29189500E+03, 0.17186300E+04, -.21001700E+04, 0.20147600E+04, -.10510700E+04, -.25984600E+04, -.10072600E+04, 0.76505000E+03, 0.11967700E+04, -.20391800E+04, -.26084700E+04, -.15012100E+04, 0.10639000E+04, 0.15597800E+04, -.23963700E+04, 0.10590500E+04, -.31876900E+04, 0.11985200E+04, 0.32602500E+03, -.26406600E+04, -.10859500E+03, -.14179100E+04, 0.27230700E+04, -.23689900E+04, 0.26483600E+04, -.18099100E+04, 0.92854700E+03, 0.29344700E+04, 0.90601700E+03, -.71944100E+03, -.14212900E+04, 0.24465500E+04, 0.35800400E+04, 0.13094500E+04, -.12709600E+04, -.27875800E+04, 0.58888400E+04, -.29805100E+04, 0.94314500E+04, -.29442200E+04, -.37959300E+04, -.48891700E+04, 0.29789800E+04, 0.15934700E+04, -.60052800E+04, -.24463300E+04, -.92054900E+04, 0.13422700E+04, -.67910300E+03, -.81565000E+02, -.67231900E+03, -.40501300E+02, -.18270800E+03, -.79804900E+02, 0.39452700E+03, -.15003800E+03, -.14835000E+03, -.77973500E+03, -.62877200E+04, 0.30488900E+04, -.87075000E+03, 0.31411800E+04, -.11467500E+04, -.84244500E+03, 0.88574100E+03, -.19713600E+04, 0.41156700E+03, -.55757000E+03, 0.49230500E+04, -.55706900E+04, 0.26818300E+04, 0.38489400E+04, 0.27850100E+04, -.22096300E+04, -.15874400E+04, 0.31932600E+04, 0.42365500E+03, 0.83366700E+03, -.10184700E+04, 0.77790900E+04, -.11382800E+05, 0.57425800E+04, -.50827300E+04, 0.56912100E+04, 0.38806600E+04, 0.37760000E+04, -.11945800E+04, -.28191400E+04, 0.64175400E+04, 0.22666000E+04, 0.91554300E+04, 0.71031400E+03, -.19506000E+03, 0.22711700E+04, -.35796200E+03, -.16955800E+04, 0.18853500E+04, 0.24185100E+03, 0.17834300E+04, -.34558600E+04, 0.18861500E+04, -.22351100E+04, -.10115200E+04, 0.54365300E+03, -.28308900E+04, 0.50631000E+03, -.41520100E+04, -.22714000E+04, 0.20252200E+04, 0.15634500E+04, 0.51884100E+03, -.18669500E+04, 0.14862200E+03, 0.65938800E+04, -.33398800E+04, 0.27400600E+04, -.32972000E+04, 0.16706200E+04, 0.27552300E+04, -.16311000E+04, 0.22694600E+03, -.34136600E+04, 0.21022100E+04, 0.11594300E+03, -.12341800E+05, 0.62097300E+04, 0.61192600E+04, 0.61696600E+04, 0.79979000E+03, -.20867500E+04, 0.40635700E+04, -.10830000E+04, 0.18826300E+04, -.74117000E+03, 0.23784100E+04, -.28321200E+04, 0.13926900E+04, -.87688500E+02, 0.14155900E+04, -.40847000E+03, -.17300400E+04, 0.14907500E+04, -.86645700E+03, 0.18509700E+03, -.14974300E+04, -.97897400E+03, 0.43832700E+04, -.21514000E+04, -.21475700E+04, -.21930400E+04, -.41430400E+03, 0.59342600E+03, -.15216600E+04, -.38896800E+03, -.19772200E+04, -.11555000E+03, -.15293600E+04, -.15955000E+04, 0.88562200E+03, -.52514000E+02, -.20353700E+03, -.16520700E+04, -.34415700E+02, 0.10851600E+02, -.20127400E+03, 0.54337200E+02, -.11251100E+04, 0.36715100E+03, -.11587800E+04, -.13952200E+04, -.30921500E+03, 0.87838300E+03, -.17663100E+03, 0.25173400E+03, -.50454300E+03, -.21839100E+03, -.17863200E+04, 0.76045600E+03, -.15261100E+03, 0.69450300E+03, 0.62125200E+03, 0.14905400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.48262600E+00, -.44329800E+00, -.38299000E+00, -.33540200E+00, 0.38592500E+00, 0.89424500E-01, 0.34221700E+00, 0.96884200E+00, -.60197000E+00, -.33830600E+00, -.30861500E-01, -.10774800E+01, 0.72910300E+00, -.46641500E+00, 0.34346800E+00, 0.56049500E+00, 0.53189400E+00, -.62675900E+00, -.10739000E+00, -.90825400E+00, -.89095100E-02, 0.12929800E+00, -.41642000E+00, 0.15610800E+00, -.90812900E-01, 0.25710500E-02, 0.57230200E+00, -.10621700E+00, -.16092800E+00, 0.43572900E+00, 0.24135500E+00, 0.39710300E+00, -.14907600E+00, 0.14829300E+00, -.28336300E-01, -.61617100E+00, -.18227000E-01, 0.72881700E-01, 0.24066200E+00, -.11022400E+01, 0.46593300E+00, 0.18284300E+00, 0.70703100E+00, 0.49779900E-01, 0.20445200E+00, 0.97836600E-02, 0.69362300E+00, -.66855900E-02, 0.28472100E+00, -.17769500E+00, -.29375600E+00, -.13636200E+01, -.27567800E-02, -.17601600E+00, -.43727500E-02, 0.22932100E+00, 0.20078400E+00, -.11722700E+01, -.41474500E-01, 0.63950500E+00, 0.46405600E-01, 0.11929600E+00, -.36663000E-01, -.12178100E+01, -.20213900E+00, 0.15491900E+00, -.73483700E-01, -.63815600E+00, -.29262700E+00, -.16756800E+00, 0.42455900E-01, -.69305200E+00, -.19578600E+00, -.13417400E+00, -.10214600E+00, 0.24907500E+00, -.33258200E-01, -.32261500E+00, 0.10819900E+00, -.23408600E+00, 0.94561900E-01, -.68372900E+00, 0.17102000E+00, 0.10339600E+01, -.29437200E+00, -.46023100E+00, 0.25807300E+00, -.61162200E-01, -.62092800E-01, -.30826000E+02, -.97426500E+03, 0.30958800E+00, -.23124500E+03, -.10083000E+04, -.29670100E+03, -.81206900E+03, 0.27468600E+03, -.55863200E+03, 0.85818700E+03, 0.29400300E+04, -.14507100E+04, 0.79828900E+03, -.14699700E+04, 0.49935600E+03, -.29018200E+03, -.77015100E+03, 0.10426700E+03, -.11555400E+04, 0.52617900E+03, -.14178600E+04, 0.85526500E+03, -.44193700E+03, -.89644700E+03, -.42762400E+03, -.14633700E+03, -.48313900E+03, -.33139400E+03, -.27980400E+03, -.44435700E+03, -.42717500E+03, 0.43168800E+03, -.86456600E+03, 0.38118000E+03, -.17954700E+04, 0.43235400E+03, -.28667500E+03, -.10355600E+04, 0.96006700E+03, -.16621300E+03, 0.28307300E+03, -.11704500E+04, 0.18460500E+04, -.10626600E+04, 0.53320800E+03, 0.11792700E+04, 0.53153800E+03, 0.32146700E+03, 0.76453300E+03, 0.39954600E+03, 0.40094200E+03, 0.42697500E+03, 0.73096800E+03, -.63534500E+03, 0.10586400E+04, -.54262200E+03, 0.16538600E+04, -.52928200E+03, 0.34597200E+03, -.44990100E+03, -.63407000E+03, -.12874600E+04, -.77708700E+03, 0.36402100E+03, -.19820100E+04, 0.16212600E+03, -.96200800E+02, 0.32627600E+02, -.80831100E+02, 0.56282800E+02, 0.67017700E+02, -.58596500E+02, 0.31989000E+02, -.40620000E+02, 0.91631200E+02, -.74970000E+02, -.24856200E+04, 0.12075000E+04, 0.91626000E+02, 0.12430100E+04, -.14808600E+03, 0.60082500E+03, 0.55426100E+03, 0.13891200E+03, 0.46263500E+03, 0.15497200E+03, 0.81713600E+03, 0.19041000E+04, -.98751800E+03, 0.12097200E+03, -.95211600E+03, -.10104900E+04, 0.42311700E+03, -.66156500E+03, -.38362000E+03, -.93788600E+03, 0.11492000E+03, 0.43913600E+03, -.10327700E+04, 0.53753600E+03, -.31712200E+03, 0.51634600E+03, -.20406700E+01, 0.25044900E+03, 0.94499600E+03, 0.10608200E+04, 0.50849500E+03, -.20645500E+03, 0.70087600E+03, -.19220700E+04, 0.10192500E+04, 0.54485000E+03, 0.96048300E+03, 0.27683900E+03, 0.10693100E+04, -.76912600E+02, 0.75177000E+03, 0.54642700E+03, 0.80128900E+03, -.60968600E+03, -.11784400E+04, 0.60174900E+03, -.12160000E+04, 0.58932900E+03, -.33044100E+03, -.18057100E+03, 0.59338000E+03, -.34965100E+01, 0.88107300E+03, -.78932200E+03, 0.70060100E+03, 0.92414400E+03, -.47326800E+03, -.43675000E+03, -.46212400E+03, -.81820700E+03, -.22442400E+03, -.71180000E+03, -.55985200E+03, -.72976900E+03, -.75425000E+02, 0.70361100E+03, -.79184600E+03, 0.41393400E+03, 0.99443700E+03, 0.39567300E+03, 0.90709300E+03, 0.41044600E+03, 0.46889500E+03, -.90577400E+02, -.29923400E+03, 0.72040400E+03, -.14075200E+04, -.91957000E+03, 0.45299100E+03, -.24579400E+03, 0.45967700E+03, 0.25373600E+03, -.81422200E+02, 0.52589900E+03, 0.21299500E+03, 0.25024800E+03, -.35055700E+02, -.52850700E+03, 0.12891700E+04, -.63605500E+03, -.36313200E+03, -.64486400E+03, -.75476100E+03, -.93373100E+02, -.24389300E+03, 0.67931600E+03, -.35436800E+03, -.35952600E+03, -.36508800E+03, -.11274500E+03, -.10004000E+03, -.14354800E+03, -.15219200E+03, -.47203700E+02, -.10059100E+02, 0.19166000E+02, -.14755800E+03, 0.14375100E+03, -.28471200E+03, -.88454700E+02, 0.13751700E+03, -.26700800E+03, 0.15846100E+03, 0.11385400E+04, -.14560100E+03, -.56304100E+02, 0.98297300E+02, 0.11852000E+04, -.37076000E+03, -.13466700E+03, -.15555800E+03, -.12406600E+03, -.10510900E+03, 0.32209400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.41871500E+00, -.41379600E-01, 0.31921600E+00, 0.84299200E-01, -.56695000E+00, -.15822400E+00, 0.28085300E+00, -.63432200E-01, -.55167900E+00, -.22459000E+00, -.10454500E-01, -.56749100E+00, -.35541300E+00, -.77764700E-03, -.32423200E-01, -.40089600E+00, 0.34988400E+00, 0.81495800E+00, -.29069700E+00, 0.15039900E+01, 0.12189800E+00, -.72147600E-01, -.76900800E-01, 0.11788700E+01, 0.11515800E-01, 0.78222800E-01, 0.30852500E+00, -.13915000E+00, 0.38087600E+00, 0.77681900E+00, 0.45392000E-01, -.47981000E+00, 0.40696800E+00, -.17772200E+00, -.39700100E+00, 0.18743700E+00, 0.69020400E-02, 0.23447300E-01, 0.27567400E-01, -.74672100E-01, 0.10303100E+00, 0.61651300E-01, -.66966900E-01, -.16168100E-01, 0.24891800E+00, 0.15209900E+00, 0.36527700E+00, -.15003200E-02, 0.83833300E+00, -.34891700E+00, -.13933400E+00, 0.90537900E+00, -.44022300E-01, 0.39635300E+00, 0.61215800E-01, 0.15916100E+00, 0.49301400E+00, -.26538900E+00, -.16874200E-04, -.12979700E+00, 0.77643900E-01, 0.84353400E-01, 0.85698900E-01, -.34744600E+00, -.40966200E-01, 0.38936400E-01, 0.32236500E-01, -.48905600E+00, 0.59359700E-01, -.93536100E-01, 0.33332900E+00, -.72313800E+00, 0.61196100E-01, 0.68107300E-02, -.78390400E-01, 0.35822000E+00, -.66562400E-01, -.67286300E+00, 0.18143500E-01, -.27747700E-01, 0.10911600E+00, -.20906400E+00, 0.22342000E+00, 0.37446500E+00, -.81617300E-01, -.57380200E+00, 0.14388800E+00, 0.51208000E-01, 0.95489900E-01, -.29890000E-01, -.14208200E+04, 0.16831100E-01, -.32990300E+03, -.11050800E+04, 0.36050300E+03, -.75031300E+01, 0.55503400E+03, -.11471000E+04, 0.34478000E+02, 0.75269800E+03, -.37282600E+03, -.11806200E+04, -.37637300E+03, -.14474200E+04, -.43876600E+03, -.36419500E+02, -.47552900E+03, -.25102700E+03, -.14710900E+03, 0.70287700E+02, -.34763000E+03, 0.17422700E+03, 0.91720100E+03, 0.17379300E+03, -.32479700E+03, -.60185800E+03, 0.60036900E+03, 0.66907700E+03, 0.28718400E+03, -.45448100E+03, -.25589100E+03, -.11618500E+04, 0.56764200E+03, -.53852900E+02, 0.58092400E+03, 0.48641200E+03, 0.15488200E+03, 0.31746500E+03, -.43478000E+02, -.40661700E+03, 0.27291800E+03, 0.61176100E+03, 0.57005900E+03, -.29002000E+03, -.10223300E+04, -.28505400E+03, 0.35746400E+03, 0.82081200E+03, -.90405100E+03, -.10485500E+04, -.52144300E+03, 0.66881600E+03, 0.41977600E+03, 0.32157700E+04, -.16167600E+04, -.37992800E+04, -.16078900E+04, 0.98758500E+03, 0.50410900E+03, -.14227200E+04, -.46938800E+02, 0.19859100E+03, -.27648200E+03, -.73308300E+03, -.37412700E+02, 0.21079000E+02, 0.28454200E+03, 0.19221200E+02, 0.90445700E+02, 0.17514100E+03, -.23316800E+03, -.23214400E+03, -.17248700E+03, 0.18536300E+03, 0.47912100E+02, 0.24905800E+03, -.13639000E+03, 0.47186900E+03, -.12355300E+03, 0.61137600E+03, 0.57229900E+03, -.30799200E+03, 0.28387100E+03, -.19674300E+03, 0.46940800E+03, -.71268500E+03, 0.12242200E+04, -.62858600E+03, -.91321900E+03, -.61210100E+03, 0.30671100E+03, 0.12301100E+03, -.48066900E+03, 0.67080200E+03, 0.94588500E+02, -.39273700E+02, -.13329700E+04, 0.10116000E+04, -.49710900E+03, 0.20018400E+04, -.50579700E+03, -.10674500E+04, -.24277400E+03, 0.51164000E+03, 0.52342400E+03, -.12162700E+04, 0.18830200E+03, -.90450800E+03, -.16174000E+04, 0.82667200E+03, -.12948400E+04, 0.80878200E+03, -.11544500E+03, -.14177000E+03, 0.85433500E+03, 0.48564200E+03, 0.18584000E+04, -.43401600E+03, 0.97434400E+03, -.12486100E+03, 0.67757800E+02, 0.19148100E+03, 0.62414400E+02, 0.95236600E+03, 0.29663300E+03, 0.10955500E+03, 0.49416200E+03, 0.38255500E+03, -.74876700E+02, 0.36715900E+02, -.14509000E+04, 0.71288300E+03, -.70049800E+03, 0.72545900E+03, -.13772600E+03, -.64121900E+03, 0.42456500E+03, 0.54171800E+03, 0.92166300E+03, -.43305400E+03, 0.13323800E+02, 0.48643400E+04, -.24331900E+04, -.25361900E+04, -.24321400E+04, 0.43532000E+02, 0.49593900E+03, -.11382400E+04, 0.61281500E+03, -.10726200E+04, -.44453300E+02, -.21061400E+04, 0.13868000E+03, -.74118400E+02, 0.68002100E+02, -.69351000E+02, 0.22934900E+03, 0.22849900E+03, -.34086700E+03, -.13139300E+03, -.16807500E+03, 0.31298600E+03, -.71942700E+01, -.64332200E+03, 0.33323600E+03, 0.17856200E+03, 0.32169300E+03, 0.32233100E+02, 0.34215200E+03, 0.45731600E+03, 0.98021200E+03, 0.65437200E+03, 0.42231800E+03, 0.92625600E+01, 0.63582100E+02, -.21696700E+03, 0.20596900E+02, 0.80985300E+02, 0.22288600E+03, -.66404300E+02, -.96969800E+02, 0.79064000E+02, -.21286800E+02, -.13728600E+02, -.71995800E+02, 0.41098100E+03, -.76972100E+02, 0.13501400E+03, -.22820600E+02, 0.74730300E+02, 0.12125700E+02, 0.39142300E+03, 0.22211300E+03, -.15194700E+02, -.77529300E+02, -.27901500E+03, -.30704700E+01, -.94449700E+02, 0.40474000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25285900E+01, -.13409900E+01, -.69186000E+00, -.48881000E+01, -.38313400E+01, 0.33776500E-01, 0.52496500E+01, 0.91518500E+01, 0.81205000E+00, -.11199500E+01, -.19755200E+00, -.85790600E+01, 0.94269700E+01, 0.20504100E+01, 0.99170700E+01, 0.62533800E+01, 0.25177800E+01, -.25902000E+01, 0.47777400E+00, 0.16563200E+00, 0.18040800E+01, 0.42354800E+00, -.12054500E+01, 0.14220400E+01, -.75624100E+00, -.78353200E+00, -.28341300E+01, -.81953500E+00, -.27920100E+00, 0.63772300E+00, -.25827900E+00, 0.46253100E+00, 0.10190000E+01, 0.50744500E+00, -.76522600E+00, 0.69577500E+00, 0.64326000E-01, -.13605200E+01, 0.81129700E+00, 0.24904900E+01, -.30785600E+01, -.18988100E+01, -.15747200E+01, -.55534500E+00, 0.29516600E+00, 0.57924300E+00, -.17419200E+00, 0.18567200E-01, -.55153600E+00, -.16259500E+01, -.12674000E+01, 0.10551500E+01, -.42542000E+00, -.11086200E+01, -.35151100E+00, -.50835500E+00, 0.89313300E+00, 0.25957100E+01, 0.90589700E-01, -.10712800E+01, 0.12080400E+00, 0.18714600E+00, 0.40475900E+00, 0.60479600E+00, -.10535200E+01, -.31338000E+00, 0.92684700E-01, 0.19731100E+01, 0.14557800E+01, 0.54333600E-01, -.20430400E+01, -.12144700E+01, 0.81669800E+00, 0.13101700E+01, 0.71778800E+00, -.11224100E+01, -.33934500E+00, -.67232300E+00, -.59060700E+00, -.12584300E+00, 0.22023000E+00, 0.18927900E+00, -.36019900E+00, -.15572900E+01, -.18885500E+01, 0.52260600E+00, -.38749200E+00, -.93338700E+00, 0.69824200E+00, -.24422200E+00, 0.43339000E+00, 0.65058100E+01, -.14596300E+04, 0.20299100E+03, 0.33768300E+03, 0.60017700E+03, 0.89161800E+03, -.92567500E+03, 0.76955600E+03, -.80926100E+04, 0.40300400E+04, -.33491200E+04, 0.40463000E+04, -.98345500E+03, 0.21021500E+03, 0.19840800E+04, -.14089900E+03, 0.31834600E+04, -.94186900E+03, 0.52215000E+04, -.23006400E+04, 0.11540700E+04, 0.18037800E+04, 0.11503200E+04, 0.13419800E+03, -.62848100E+03, 0.13696100E+04, 0.17947900E+04, 0.13295200E+04, -.67115400E+03, 0.38512900E+03, 0.22154500E+04, -.10435800E+04, 0.42239500E+04, -.11075400E+04, 0.66383000E+03, 0.21371900E+04, -.21926300E+04, -.16749300E+04, -.31218400E+04, 0.26869200E+04, -.11408100E+04, 0.30827000E+04, -.15281100E+04, -.26757100E+04, -.15408200E+04, -.14100900E+03, 0.12706000E+04, -.22082200E+04, -.30521600E+04, -.23789600E+04, 0.14048000E+04, -.17739500E+03, 0.85486100E+04, -.42294700E+04, -.63883300E+04, -.42742400E+04, -.56104300E+03, 0.12379100E+04, -.21349900E+04, 0.47525900E+02, -.10562800E+04, -.55215200E+03, -.27683100E+04, -.96479800E+03, 0.44548200E+03, 0.35006600E+03, 0.48385700E+03, 0.10543200E+03, 0.45168800E+03, -.17469300E+03, -.39282600E+03, -.24158500E+03, 0.43165800E+03, 0.73201600E+03, 0.35724700E+04, -.17340600E+04, 0.12605100E+04, -.17790000E+04, 0.98333100E+03, 0.51226700E+02, -.10226800E+04, 0.13817900E+03, -.15676800E+04, 0.62318800E+03, -.36832000E+04, -.35741800E+04, 0.18574400E+04, -.35940300E+04, 0.17870000E+04, 0.21851700E+03, -.44816700E+03, 0.97741600E+03, 0.20612500E+04, 0.25439800E+04, -.63408900E+03, 0.48076800E+03, -.21275900E+04, 0.10194800E+04, 0.28686600E+04, 0.10637200E+04, -.32179900E+03, -.72566100E+03, 0.73774000E+03, 0.26974800E+03, -.44226100E+03, 0.24454100E+03, 0.10356000E+04, -.89920700E+02, -.34601700E+02, -.34390200E+04, 0.43871500E+02, -.34243400E+03, -.23558300E+04, 0.15184400E+04, 0.93099600E+03, 0.22321100E+04, -.22839600E+04, 0.15108200E+03, 0.46603900E+04, -.23555900E+04, 0.23619500E+04, -.23299900E+04, 0.30146700E+03, 0.21561300E+03, -.15722900E+04, -.16101200E+03, -.16374100E+04, 0.91936000E+03, -.18005400E+04, -.33524900E+04, 0.17249700E+04, -.20691100E+04, 0.16761300E+04, -.51905500E+03, 0.12910900E+03, 0.11645400E+04, 0.14331400E+04, 0.18470300E+04, -.51043900E+03, 0.72298600E+03, 0.48325200E+04, -.24080200E+04, -.54720600E+04, -.24166900E+04, -.20057800E+04, -.56416000E+03, -.68818100E+03, 0.20058100E+03, -.38351600E+03, -.12853700E+04, -.10347300E+04, 0.25152200E+04, -.12346500E+04, 0.13926800E+04, -.12578900E+04, 0.39019500E+03, 0.48839700E+03, -.11406200E+04, -.42147500E+03, -.11632300E+04, 0.67783800E+03, -.98976200E+03, -.28937400E+04, 0.13847400E+04, -.11251900E+04, 0.14462500E+04, 0.54912600E+03, -.12544500E+04, 0.20449700E+04, 0.27851400E+04, 0.24562600E+04, -.91543500E+03, 0.41038800E+03, 0.34747800E+03, -.65311500E+03, 0.11649600E+03, 0.13731300E+03, 0.58697600E+03, -.43669800E+03, -.44794000E+03, 0.12954400E+03, -.11635600E+03, 0.82055700E+03, 0.29376800E+03, 0.71051400E+03, 0.16027800E+02, 0.40435700E+03, -.63423900E+03, 0.10034300E+03, 0.40947700E+03, 0.52209500E+03, -.24742200E+03, 0.68219200E+03, 0.71612800E+03, -.47393800E+03, -.17387700E+03, -.27130300E+03, -.23026500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.70184300E+00, 0.75548500E-01, 0.14570600E+01, 0.92087000E-01, 0.54738400E+00, -.12600300E-01, 0.65916500E+00, 0.67467900E+00, -.14391700E+01, -.26585500E+00, -.24398800E-01, -.13081500E+01, 0.87837000E+00, 0.16754400E+00, 0.96777200E+00, 0.26696500E+00, 0.27512000E+00, 0.10630100E+00, -.12308600E+00, 0.78971200E+00, 0.90922600E+00, 0.76632200E-01, -.99132800E-01, 0.53049000E+00, -.23568200E-01, -.23065800E-01, 0.28520400E+00, -.19106500E+00, 0.58074600E-01, -.38859800E+00, -.33081000E+00, 0.13897700E+00, 0.15991400E+00, 0.15013900E+00, 0.28270400E+00, 0.64662600E-01, 0.11207400E-03, 0.12104700E+00, 0.53911700E-01, 0.12533300E+00, 0.63724100E+00, 0.49707800E-01, 0.11277100E+00, 0.12324500E-01, 0.15477700E+00, 0.30380100E+00, 0.40983000E-01, 0.12262700E-02, -.23008700E+00, 0.32368300E+00, -.59149600E+00, -.14542700E+01, -.14409700E-02, 0.23284600E-01, -.24381700E-01, 0.27635500E+00, 0.15791000E+00, -.41928300E+00, 0.83123800E-02, -.52228200E-01, 0.19732000E-01, 0.74339600E-01, -.11193500E+00, -.87598900E+00, -.19131400E+00, 0.10053200E+00, -.68212100E-01, -.98371100E+00, -.52540900E-01, -.14971600E+00, 0.23766800E+00, -.63061500E+00, -.33822400E-01, 0.15053100E+00, 0.97685500E-01, -.34013500E-01, -.55952200E-01, -.37048400E+00, 0.17602000E+00, -.66114700E-01, 0.13234300E+00, 0.41052800E-01, -.66924300E-01, 0.46241900E+00, 0.21708500E+00, -.33384600E+00, 0.28413400E+00, 0.18997000E+00, -.84118200E-01, -.90536100E-01, 0.45178900E+00, 0.22059200E-01, 0.98449100E+03, -.11100900E+03, -.28127400E+03, -.98477700E+02, -.39657900E+02, 0.30115500E+03, -.46659800E+03, 0.94726900E+03, -.47286200E+03, 0.23553400E+04, -.47362100E+03, 0.14304100E+04, 0.10410900E+04, -.61511000E+03, -.42017500E+02, -.11907300E+04, 0.14716800E+04, -.12034800E+04, 0.10939200E+04, -.54735200E+03, -.86798200E+03, -.54695900E+03, 0.67664900E+02, 0.26759700E+03, -.59194000E+03, -.65976200E+03, -.65549200E+03, 0.22938600E+03, -.10032300E+03, -.15143900E+04, 0.75619700E+03, -.89081200E+03, 0.75722300E+03, -.74852200E+03, -.53752600E+03, 0.34656300E+03, -.35471000E+03, 0.38772500E+03, -.65713100E+03, 0.11606800E+04, -.15332200E+04, 0.76984100E+03, 0.11613600E+04, 0.76668900E+03, -.12369700E+03, -.38046900E+03, 0.92261000E+03, 0.10513200E+04, 0.96874500E+03, -.37542000E+03, 0.70968900E+02, -.27461000E+04, 0.13721400E+04, 0.27661800E+04, 0.13730700E+04, 0.27744000E+03, -.22203100E+03, -.14979500E+03, -.12861600E+04, -.19602700E+02, 0.49205800E+03, 0.16069900E+04, -.15867700E+03, 0.70895100E+02, 0.97022600E+01, 0.79252000E+02, -.28573700E+02, -.21851400E+02, 0.14791300E+03, 0.82731100E+02, 0.36483400E+02, -.34802000E+02, 0.26131900E+02, -.23095200E+03, 0.11371900E+03, -.15430200E+04, 0.11560400E+03, -.67232100E+03, -.64201200E+03, 0.63036100E+03, 0.47787800E+03, 0.92442800E+03, -.89051000E+03, 0.59968700E+03, 0.17908400E+04, -.89525000E+03, 0.33917000E+03, -.89544300E+03, 0.25377200E+03, 0.58916400E+03, -.67338300E+03, -.33550800E+03, -.79708700E+03, 0.52564000E+03, -.27725400E+03, 0.16031400E+04, -.80059500E+03, -.13826600E+04, -.80158700E+03, -.40083700E+00, 0.41849900E+03, 0.13921400E+03, 0.86357200E+03, -.26236000E+02, -.11998900E+03, -.12357600E+04, -.29624700E+03, 0.14878600E+03, 0.55274300E+03, 0.14792600E+03, 0.32970500E+03, 0.25433500E+03, -.15083000E+03, 0.84836600E+02, 0.84502700E+02, 0.13127000E+03, -.38122000E+03, -.19181600E+04, 0.96137800E+03, -.12957400E+04, 0.95911700E+03, -.84989800E+03, -.64033700E+03, 0.38946100E+03, -.50133000E+03, 0.61575700E+03, -.94094600E+03, 0.11349800E+04, 0.20393100E+04, -.10179700E+04, 0.78316700E+03, -.10196800E+04, 0.57684500E+03, 0.45744600E+03, -.72404100E+03, -.13509000E+03, -.80536400E+03, 0.62611700E+03, -.48303600E+03, -.17170900E+04, 0.86091000E+03, 0.14923000E+04, 0.85845400E+03, 0.37121100E+03, 0.13122900E+03, 0.24932700E+03, -.31913900E+03, 0.87036700E+02, 0.37823100E+03, 0.73033500E+03, -.11056400E+04, 0.55142000E+03, -.79197000E+03, 0.55277900E+03, -.45637800E+03, -.48169500E+03, 0.48356800E+03, -.69946800E+02, 0.40611700E+03, -.47825900E+03, 0.47476000E+03, 0.58201100E+03, -.29467400E+03, 0.64368400E+03, -.29110800E+03, -.21756200E+03, 0.41959700E+03, -.43915200E+03, -.59299500E+03, -.62925900E+03, 0.19137800E+03, 0.18587500E+03, -.16302200E+03, 0.26412000E+03, 0.24409300E+03, 0.25647600E+03, -.18441100E+03, 0.43683700E+03, 0.46158400E+03, 0.25466200E+03, -.24365600E+03, -.37524900E+03, 0.32693800E+03, -.58295200E+03, -.45385200E+02, -.42740700E+03, 0.63482700E+03, 0.25539800E+03, 0.11235600E+03, -.38950200E+03, 0.67858300E+03, -.17900000E+03, 0.28015600E+03, 0.24217400E+03, 0.80640200E+02, 0.96765900E+02, 0.20380200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10368300E+01, -.53829800E+00, 0.21191200E+01, -.52904300E+00, 0.15414800E+01, 0.12660900E+00, 0.10868000E+01, 0.12375500E+01, -.24105500E+01, -.41557900E+00, -.15080100E+00, 0.19189800E+01, -.11132300E+01, -.84547400E+00, 0.32585500E+00, 0.27537600E+00, -.46915100E+00, -.15117400E+00, -.27901900E+00, -.53388900E-01, 0.63584500E+00, 0.42495400E-01, -.76976900E+00, -.93540600E+00, -.30958700E+00, 0.85374500E-02, 0.39121200E+00, 0.60264600E-01, -.41881600E+00, -.30207600E+00, 0.25086700E+00, 0.59972500E+00, -.46587800E+00, -.36047700E+00, -.49653700E+00, -.10340100E+01, -.34263100E-01, -.16569700E+01, 0.94078500E+00, -.46477100E+00, 0.30540800E+00, 0.28623800E+00, 0.46983800E+00, -.24239100E-01, 0.12577400E+00, 0.31491500E+00, 0.45582900E+00, -.22738200E-02, 0.11401900E+00, -.38169200E+00, -.11949300E+01, -.10141100E+01, -.21587600E+00, -.31503200E+00, -.39785900E-01, -.18648200E+00, 0.20400300E+00, 0.56320200E+00, -.10095300E+00, 0.43645900E+00, 0.21340500E+00, -.17505500E+00, 0.30876900E+00, 0.71450800E+00, -.11339200E+01, 0.29353600E+00, -.22128000E+00, 0.16134100E+00, 0.95404300E+00, -.13083800E+00, 0.20425200E+01, -.85713600E+00, 0.42771700E+00, 0.14549600E+00, 0.82110800E-01, -.11050300E+01, 0.18147600E-01, -.90458000E+00, -.22514100E-01, -.95126900E-01, 0.73160400E-01, -.50322900E+00, 0.42911800E+00, 0.25738400E+01, 0.12179800E+00, -.11514400E+01, 0.11874200E+00, 0.57086100E+00, -.17284900E+00, 0.13546100E+01, -.48342000E-01, 0.46933500E-01, -.54645600E+00, -.27361200E+04, 0.17215400E+04, 0.18664700E+04, 0.11064500E+04, -.21664800E+04, 0.98910700E+02, 0.27532600E+04, -.13680700E+04, 0.16455900E+04, -.13765400E+04, 0.84829600E+02, -.13218300E+03, -.51361300E+03, -.10562200E+04, -.90237000E+03, -.36289200E+03, -.17046500E+04, 0.86020200E+03, -.43846000E+03, 0.13095300E+04, -.43007100E+03, 0.59604100E+02, 0.60030000E+03, -.58589000E+02, 0.77430700E+02, -.59877100E+03, 0.87932300E+03, -.88901300E+03, -.88880700E+04, 0.44039000E+04, -.35040300E+04, 0.44441200E+04, 0.19833800E+04, -.64892800E+02, 0.95703900E+03, -.11389800E+04, 0.34487300E+04, 0.24508800E+03, 0.33537500E+04, 0.23951400E+03, -.11103700E+03, -.12785900E+04, -.11949800E+03, -.23567700E+03, -.72813900E+03, -.22871600E+03, -.76796200E+02, -.10114800E+03, -.11307400E+04, 0.36271900E+03, 0.16867500E+04, -.86501700E+03, 0.25908800E+04, -.84332200E+03, -.66940600E+03, -.31008200E+04, 0.52495200E+03, -.15473500E+03, -.40727700E+03, -.31120500E+04, -.33196100E+04, 0.13968000E+04, -.68106100E+03, 0.56749700E+03, -.69836600E+03, -.60304400E+02, -.66307300E+02, -.32619800E+03, 0.58461100E+01, -.55918000E+03, -.48337100E+02, -.67670700E+03, 0.61063300E+02, -.59005200E+02, -.13432500E+04, -.30686100E+02, 0.44885000E+03, 0.23015300E+03, -.47881700E+03, 0.60569800E+03, -.14903600E+03, 0.58427400E+03, 0.11082000E+04, 0.14786600E+04, -.77977700E+03, 0.30687100E+04, -.73942500E+03, 0.64662400E+03, 0.25875300E+03, 0.56273200E+03, 0.28237400E+04, -.57171200E+03, 0.96396800E+03, 0.15269300E+03, 0.12185400E+04, -.58925300E+03, -.26768000E+04, -.60932200E+03, 0.61160300E+03, 0.31197400E+04, -.15935100E+04, -.16708800E+03, -.50474600E+03, 0.27479500E+04, 0.17366000E+04, 0.27609800E+03, -.88589900E+02, -.23918800E+03, -.13878200E+03, -.18851700E+04, 0.27563700E+03, 0.10548700E+04, 0.13785500E+04, -.92005100E+02, -.20988400E+02, 0.11866300E+04, -.24877400E+04, 0.12585100E+04, -.10290700E+04, 0.12440200E+04, -.70270800E+03, 0.19207100E+02, 0.10738400E+04, 0.87581800E+03, 0.66229000E+03, 0.12736800E+03, 0.68942700E+03, -.24334300E+04, 0.11911200E+04, 0.23372500E+03, 0.12166500E+04, 0.11005600E+04, -.11760800E+04, 0.16764900E+04, 0.21430900E+04, 0.11158900E+04, -.75728500E+03, 0.80414800E+03, 0.11219100E+04, -.56689700E+03, 0.55605400E+02, -.56129300E+03, 0.51325100E+03, -.14154900E+03, -.41930000E+03, -.14999700E+03, -.44374800E+03, -.51324100E+03, -.13648600E+04, 0.12578200E+04, -.64222900E+03, -.65457200E+03, -.62902500E+03, 0.16479400E+03, 0.60249800E+03, -.10258800E+04, -.11141700E+04, -.76852500E+03, 0.43562000E+03, -.32038800E+03, -.95552400E+03, 0.51582000E+03, 0.69364000E+03, 0.47740400E+03, -.12378400E+03, 0.83294800E+03, 0.68385100E+03, 0.10702100E+04, 0.67114800E+03, 0.87107900E+03, 0.79013600E+03, -.10599100E+03, 0.25629700E+03, -.77849500E+01, -.26427800E+02, -.42405500E+03, -.49360200E+03, -.52667500E+03, -.62910600E+02, 0.77220600E+01, -.57278500E+03, -.11112900E+04, 0.13874600E+03, 0.52661400E+03, 0.56783100E+02, 0.79927300E+03, -.36316400E+02, -.13947300E+04, 0.32764600E+03, 0.58474700E+03, -.11915500E+03, -.12871700E+04, -.62583200E+03, 0.41623600E+03, 0.46388600E+02, 0.27675900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.50438700E+00, -.75826600E+00, -.98538900E+00, -.18508500E+00, -.44925300E+00, -.16395400E-01, 0.58331000E+00, 0.27740300E+00, -.11892200E+00, -.23602600E+00, -.18620600E-01, 0.49296200E-01, 0.11185900E+01, -.32075800E+00, 0.13771600E+01, -.13946500E+01, -.44819800E+00, 0.28030300E+00, -.60985900E-01, 0.23204800E+00, -.14302000E+00, 0.14924300E-01, -.28450600E+00, -.49435300E+00, -.38980600E-01, 0.63035400E-01, 0.12818800E+00, -.22135600E+00, 0.46445100E-01, -.73065300E-01, -.37275600E+00, 0.48962700E+00, 0.53779100E+00, 0.29512400E+00, 0.85404600E-01, 0.46630900E+00, 0.21444900E-02, -.30600000E+00, -.28459100E+00, 0.89181300E+00, -.57221400E+00, -.24105300E+00, -.40886000E+00, -.19658300E+00, -.39719800E-01, 0.18891500E+00, 0.68574900E-01, -.12143600E-02, -.25703600E+00, -.35251100E+00, -.25542100E-01, 0.71213900E+00, -.33057900E-01, 0.50045100E+00, 0.14690600E+00, -.30664300E+00, -.25774800E-01, 0.53549500E-01, -.13108700E-01, 0.27818100E+00, 0.53876300E-01, 0.28014700E+00, 0.32312300E-01, 0.27985500E+00, -.77442100E+00, 0.20281700E-01, -.11419900E-02, 0.13264800E+01, 0.60356500E+00, 0.49266500E-02, -.90393700E+00, -.18223900E+00, -.14818400E+00, -.92202600E-02, 0.90153600E-01, -.42848400E+00, -.25169800E-01, -.14319600E+00, -.22763100E+00, -.80716400E-01, 0.27143900E-01, -.14833800E+00, -.65711400E-01, -.12957700E+00, -.11206800E+01, -.20111900E+00, 0.14912700E+00, 0.13104500E-01, -.15330400E+00, 0.26299100E+00, -.25839400E+00, -.40364300E-01, -.31128200E+00, 0.86481600E-02, 0.45964800E+03, 0.92984900E+01, -.11380600E+03, -.37745900E+01, -.64748800E+02, -.11642500E+04, 0.58437700E+03, 0.46834100E+03, 0.58210800E+03, -.36236800E+03, -.21044300E+02, 0.14366800E+03, -.41175100E+03, -.24577000E+03, -.19512700E+03, 0.63596400E+02, -.11139600E+04, 0.55659300E+03, 0.71755600E+03, 0.55698400E+03, 0.14499200E+03, 0.22905000E+03, 0.16885800E+03, -.18494200E+03, 0.29180800E+03, 0.28571400E+03, 0.36876200E+03, 0.13691200E+01, -.97434500E+01, 0.19127900E+02, -.72572300E+00, 0.10741800E+02, 0.19275100E+03, -.44946400E+03, 0.22417600E+03, 0.47692600E+03, 0.50295800E+03, -.53743800E+03, 0.99462500E+03, -.49764900E+03, -.66747900E+03, -.49742500E+03, -.20302500E+03, -.28866500E+03, -.15369200E+03, 0.19236500E+03, -.13823800E+03, -.44127000E+03, -.27506600E+03, 0.13099300E+04, -.66097800E+03, -.17130400E+04, -.65498800E+03, 0.17603200E+03, -.75140600E+02, -.28143100E+02, 0.74573300E+03, -.85049900E+03, -.72205700E+03, 0.10642400E+04, -.26091000E+02, 0.18496100E+02, -.56677900E+02, 0.12634900E+02, -.39971700E+02, -.16651300E+01, 0.12271500E+02, -.43184000E+01, 0.15708000E+02, -.33090800E+02, -.29363600E+02, 0.11838100E+04, -.60041200E+03, -.26610400E+03, -.59180800E+03, 0.12608000E+03, -.89299300E+02, -.26731300E+03, -.64182600E+02, 0.20652100E+02, 0.28268400E+02, 0.71205000E+01, -.38593600E+03, 0.18175200E+03, 0.39923600E+03, 0.19300300E+03, 0.73826600E+03, -.49170100E+02, -.93348800E+02, -.44651900E+03, 0.20790900E+03, 0.26619600E+03, -.14603200E+03, -.60859400E+03, 0.30913100E+03, 0.82738700E+03, 0.30432000E+03, -.24308000E+03, 0.27359700E+03, -.22512300E+03, -.56844000E+03, 0.46314400E+03, 0.63011500E+03, -.58889300E+03, 0.39560000E+02, -.73469400E+01, 0.29524500E+03, -.19485500E+02, 0.85062300E+02, -.10402600E+03, 0.52803300E+03, -.21747600E+03, -.41826000E+03, -.32806500E+03, 0.65849500E+03, -.29816400E+03, 0.15368400E+03, 0.40415200E+03, 0.14902300E+03, 0.40360800E+03, 0.25877800E+03, 0.91815300E+02, 0.29886500E+03, -.20225200E+02, 0.37335700E+03, 0.10521000E+03, 0.15211200E+03, -.84983400E+02, 0.97836600E+02, -.76027700E+02, 0.39700100E+03, 0.12939300E+03, -.16314400E+03, -.48056200E+03, 0.10389300E+03, 0.27964800E+03, -.18125900E+03, 0.12273700E+04, -.61338900E+03, -.42662800E+03, -.61354700E+03, -.38309600E+03, -.43823700E+03, -.30346900E+02, 0.36369000E+03, -.49648200E+03, -.72166900E+03, 0.75732800E+03, -.16162400E+03, 0.76861800E+02, 0.81845400E+01, 0.80881100E+02, -.34150900E+03, -.56784200E+03, 0.34898100E+03, 0.19876900E+03, 0.20598600E+03, -.50084200E+03, 0.20516700E+03, -.39042700E+03, 0.20094700E+03, 0.46058800E+03, 0.19536700E+03, 0.48562700E+03, 0.71500900E+03, -.45353700E+03, -.81107000E+03, -.40799000E+03, 0.70580200E+03, 0.13630800E+03, 0.28386400E+01, 0.68572400E+02, 0.32270400E+02, 0.88218600E+02, 0.64534900E+01, 0.24324900E+02, 0.41665200E+01, 0.79956700E+02, -.31225500E+02, 0.22258400E+02, -.10430300E+03, -.21072000E+03, 0.28345700E+03, -.13239900E+03, -.25224900E+03, 0.79776600E+02, -.22408100E+03, -.80086100E+02, -.23913200E+03, 0.21679800E+03, -.83288300E+02, 0.24545500E+03, -.34228800E+02, 0.71396000E+02, -.89386200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.52245600E+00, 0.53267900E+00, 0.81148400E+00, 0.37850400E+00, -.11950200E+00, -.34992200E-01, -.49383100E+00, -.11507700E+00, 0.79771300E+00, 0.40295200E+00, 0.40990000E-01, -.61775800E+00, -.15200100E+01, 0.78446900E+00, -.24942600E+01, 0.22465200E+01, 0.13871300E-01, 0.13420600E+00, 0.48979100E+00, 0.36122700E+00, -.19685600E+01, -.41599800E-01, 0.72551600E+00, -.67401500E+00, 0.46505200E-01, 0.15000900E-01, 0.11526500E+01, -.20790000E+00, -.77678400E+00, 0.17270600E+00, -.78598400E-01, -.24346900E+00, 0.10653900E+00, -.37472700E+00, -.18003700E-01, 0.34673700E+00, 0.94458600E-02, 0.26686700E+00, -.12100000E+00, 0.11640600E-01, 0.32544300E-01, -.10183300E+00, -.49557800E-02, 0.91998500E-02, -.21620600E-01, -.58773500E-01, -.85528800E-01, 0.16618800E-02, -.24922300E+00, 0.41273800E-01, -.35260000E-01, 0.42320300E+00, -.21456500E-01, -.10967800E+00, -.79675800E-01, -.53758300E-01, 0.18582600E+00, 0.15498900E+00, 0.11542400E-01, -.20111000E+00, 0.43348300E-01, 0.17247200E+00, -.52274200E-01, 0.93303500E-01, -.43819800E+00, -.54471400E-01, -.21234100E-01, -.92731900E+00, 0.20487600E+00, -.62359200E-01, 0.18045900E+01, -.12293800E+00, 0.89191700E-01, -.27709200E+00, -.97834400E-01, 0.29614000E+00, 0.93816500E-01, 0.33664600E+00, 0.11065200E+00, 0.82573300E-01, -.35591400E-01, -.67158600E+00, -.26577300E+00, -.12122500E+01, -.13377100E+00, -.70424400E+00, 0.15950700E+00, -.71086000E-02, -.22988300E+00, 0.46719000E+00, -.10428800E+01, -.38234300E-01, -.72754800E+00, 0.22775600E+00, -.74058900E+00, -.84838200E+03, -.16210200E+03, 0.44073100E+02, 0.54939400E+03, -.28982400E+04, 0.14531900E+04, -.15078400E+03, 0.14490500E+04, -.50929300E+03, 0.12000700E+03, 0.49139500E+03, -.98925300E+03, -.86887100E+02, 0.21544000E+03, 0.71954600E+03, -.45991800E+03, 0.22886500E+03, 0.78461200E+03, 0.22993200E+03, -.70866400E+02, -.53417000E+02, 0.37797100E+03, 0.26566700E+03, 0.12409600E+03, 0.43126900E+01, 0.27511000E+03, -.63273100E+03, 0.29814500E+03, 0.59048900E+03, 0.31628400E+03, 0.45814600E+03, 0.41913000E+03, -.68519200E+03, -.48089100E+03, -.36548100E+03, 0.73373900E+03, 0.40626600E+03, 0.12094300E+03, -.61838500E+02, -.81117100E+03, -.60726600E+02, 0.10180400E+03, 0.27591100E+03, -.55232900E+03, -.55200500E+03, -.95944400E+02, 0.13791100E+03, -.12173100E+02, 0.32517900E+04, -.16362400E+04, -.24535200E+04, -.16259400E+04, 0.59990600E+03, -.56822900E+02, -.11264300E+04, 0.47326600E+02, -.95089400E+03, -.71028300E+03, 0.13814000E+03, -.15155900E+03, 0.72361800E+02, 0.68500300E+02, 0.75609500E+02, -.89326500E+01, 0.33599200E+02, -.28849500E+02, -.14090200E+03, -.46535500E+02, 0.15998100E+02, 0.50567200E+02, 0.18245400E+04, -.93279800E+03, -.35150800E+02, -.91149100E+03, 0.46611200E+03, 0.21496900E+03, -.37756000E+03, 0.44847100E+03, -.44237200E+01, 0.16754500E+03, -.74569300E+03, -.25300000E+04, 0.12401100E+04, -.28360400E+03, 0.12650800E+04, 0.65061300E+03, -.36967500E+03, 0.73558500E+03, 0.55904200E+03, 0.14092100E+04, -.42624400E+03, 0.97817400E+03, 0.16556900E+03, -.72547400E+02, 0.11409800E+04, -.82734400E+02, -.56218600E+03, 0.50576000E+03, 0.15538500E+03, 0.14231500E+03, -.28223300E+03, 0.79295100E+03, -.10597400E+04, -.18306900E+04, 0.94186800E+03, -.13991000E+04, 0.91604000E+03, -.18882100E+03, -.38229100E+03, 0.16950700E+04, 0.87878900E+03, 0.15258100E+04, -.68527600E+03, 0.10574100E+04, 0.84526100E+03, -.41085900E+03, 0.64798100E+03, -.42276700E+03, 0.38518500E+03, 0.17937000E+03, -.85588300E+02, 0.66235000E+03, -.12596900E+03, 0.47803400E+02, -.10933600E+03, -.13833100E+04, 0.67144000E+03, -.45414400E+03, 0.69172200E+03, 0.13349900E+03, 0.18514600E+03, 0.33199000E+03, 0.81409200E+02, 0.84828600E+03, 0.10309300E+03, 0.61744500E+03, 0.19336800E+04, -.96145200E+03, -.17795400E+04, -.96652400E+03, -.10357200E+03, -.34669000E+03, -.10548000E+03, 0.52614900E+03, -.57606500E+03, -.67569100E+03, -.39777700E+02, 0.31308800E+03, -.16538400E+03, 0.23698600E+03, -.15642900E+03, -.18346400E+03, -.57953300E+03, 0.10099200E+03, 0.11353800E+03, -.57582300E+02, -.43386300E+03, -.45918300E+03, -.79950200E+03, 0.40678800E+03, -.28567200E+03, 0.40009600E+03, 0.17583200E+03, 0.56622900E+03, 0.39072300E+03, 0.55492100E+03, 0.40426600E+03, 0.40014800E+03, 0.19663400E+03, 0.10075600E+03, -.87043700E+02, 0.69188200E+02, 0.12321600E+03, 0.19647900E+03, -.70263800E+02, -.97155400E+02, 0.11431600E+03, -.69194300E+02, 0.73526700E+02, 0.15223000E+03, 0.10768600E+03, 0.29910400E+02, -.86509200E+01, 0.20438100E+03, 0.11297400E+03, 0.44456900E+02, 0.13917600E+02, 0.36424000E+03, 0.18070800E+03, 0.32761400E+03, 0.14042700E+03, -.17053500E+03, -.55233100E+02, 0.16758000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.41221000E+00, -.39641800E+00, -.20726500E+00, -.25312400E+00, 0.20951400E+00, 0.43490100E-01, 0.86571400E+00, -.73190800E-01, -.71496300E+00, -.74628500E-01, -.12228900E+00, 0.46953900E+00, 0.47955600E+00, -.36171900E+00, 0.75552000E+00, -.12271700E+00, -.17533200E-01, -.26196600E+00, -.50679800E+00, -.64578700E+00, 0.72675400E+00, 0.21749300E-01, -.21769500E+00, 0.28861300E+00, 0.64228100E-01, 0.54635600E-01, 0.61681200E+00, 0.72843900E-01, 0.17008100E+00, -.39786700E+00, -.68181800E-01, 0.21077000E-01, 0.18017600E+00, 0.63981800E+00, -.12487800E-01, 0.45321800E-01, 0.11686900E-01, -.28971300E+00, -.56394100E-01, 0.40606400E+00, -.53128900E+00, -.38184700E-01, 0.16371000E-01, -.52763500E-01, -.64318000E-01, 0.54306100E-01, 0.61044300E-01, 0.92598500E-03, -.31555300E+00, 0.17726800E+00, 0.54260400E+00, 0.33690000E+00, 0.60466500E-01, 0.94846500E-01, -.40552700E-01, -.38600700E+00, -.37445000E+00, -.16184000E+00, -.12372900E-01, 0.26323600E+00, -.27676700E-01, -.77079900E-01, 0.38273700E-01, 0.75856000E+00, -.88329700E-01, 0.49546200E-01, -.11066100E-01, 0.73019900E+00, -.82549400E-01, 0.33445000E-01, -.59647600E+00, 0.21172200E+00, 0.76281300E-01, 0.36318600E-01, 0.12846800E+00, -.33091200E+00, 0.41907200E-01, 0.33297200E+00, -.53172800E-01, 0.16231700E+00, 0.32742600E-02, 0.89642000E-01, 0.11184700E+00, 0.26921800E+00, 0.32904400E+00, 0.18179600E+00, -.14699100E+00, -.13806700E+00, -.97603200E-01, 0.22167400E+00, -.47975200E+00, 0.62146300E-01, -.46813500E-01, 0.35718400E+00, -.96049900E-01, 0.18347500E+00, -.29791400E+03, 0.72836200E+02, -.69648600E+03, 0.14330400E+04, -.71613000E+03, -.11688600E+03, -.71645600E+03, 0.43951100E+03, -.18881600E+03, -.15034400E+02, 0.68573800E+03, 0.16436900E+03, -.18410800E+03, -.45316500E+03, 0.14878700E+03, -.75035700E+02, -.10003700E+04, -.74365200E+02, 0.27628500E+02, -.77749900E+02, -.33504600E+03, -.43709700E+03, -.64255900E+02, -.20672900E+03, 0.35481900E+03, 0.30330300E+04, -.15159100E+04, -.76928500E+03, -.15164500E+04, -.88182500E+03, -.82214300E+03, 0.28344000E+03, 0.12291100E+04, -.29134400E+02, -.94774000E+03, -.13859900E+04, -.12508200E+03, 0.62215600E+02, 0.99922100E+03, 0.62758300E+02, 0.89958900E+01, -.39248800E+02, 0.51171000E+03, 0.58561700E+03, 0.12978200E+03, 0.12916200E+03, -.49030000E+03, -.31558600E+04, 0.15766500E+04, 0.19916700E+04, 0.15779700E+04, -.54743100E+03, 0.24976800E+03, 0.96954100E+03, -.31927300E+03, 0.76985300E+03, 0.52973500E+03, 0.15081200E+04, 0.19614900E+03, -.95325900E+02, -.32627400E+03, -.98369600E+02, -.24129000E+02, -.86000300E+02, 0.83377700E+02, 0.20324400E+03, 0.13099200E+03, -.80903000E+02, -.11270200E+03, -.10167100E+04, 0.50894700E+03, 0.36147600E+03, 0.50706400E+03, -.31124600E+03, -.53761500E+02, 0.17864900E+03, -.35221900E+03, 0.84053000E+01, -.14780900E+03, 0.49135600E+03, 0.23422000E+04, -.11689100E+04, -.42344900E+03, -.11711700E+04, -.40045600E+03, -.76711800E+02, -.64534100E+03, -.83346400E+03, -.12765100E+04, 0.22377500E+02, -.12950200E+04, 0.53667700E+03, -.26780600E+03, -.11924800E+04, -.26838000E+03, 0.46820000E+03, -.52747800E+03, -.67000500E+02, 0.18010700E+03, 0.13237200E+03, -.60675900E+03, -.43809500E+03, 0.30036300E+03, -.15271500E+03, 0.19809200E+04, -.15076600E+03, 0.54609400E+03, 0.80903800E+03, -.11451500E+04, -.11308400E+04, -.12223300E+04, 0.86298900E+03, -.28622200E+03, 0.68971200E+03, -.34452800E+03, -.32053900E+03, -.34474200E+03, -.23705400E+03, 0.48890500E+02, -.28974800E+03, -.24874500E+03, -.42488000E+03, 0.13380000E+03, -.42586200E+03, 0.15034700E+04, -.75042100E+03, 0.25612800E+03, -.75178700E+03, -.18813300E+03, -.17868000E+03, -.47455400E+03, -.57772100E+03, -.76021500E+03, -.90749200E+02, -.42245000E+03, -.14165500E+04, 0.70865100E+03, 0.12845800E+04, 0.70801200E+03, 0.76363700E+02, 0.11679400E+03, 0.27525500E+03, -.31854400E+03, 0.38858700E+03, 0.27983900E+03, 0.69305300E+03, -.13098700E+03, 0.65139200E+02, -.26187600E+03, 0.65402500E+02, -.69084900E+02, -.70780700E+02, 0.24532500E+03, 0.37147200E+03, 0.37575500E+03, -.15075400E+03, 0.18163500E+03, 0.39377200E+03, -.19909200E+03, 0.32373600E+03, -.19717500E+03, -.21473600E+02, -.49786400E+02, -.41714300E+03, -.65923000E+03, -.26129900E+03, -.61483700E+02, 0.60885000E+02, -.25267000E+02, 0.71323200E+02, -.28821400E+01, -.65854700E+02, 0.21665000E+02, 0.23542300E+03, 0.26552200E+03, -.58225500E+02, 0.19411300E+01, -.24256000E+02, 0.23956100E+03, -.18338700E+03, 0.18029700E+02, -.38781100E+02, 0.47416800E+02, -.55945100E+02, 0.34320500E+03, 0.34248300E+02, 0.34739700E+02, -.12471800E+03, 0.11227200E+03, 0.72583400E+02, -.53902800E+02, 0.45198700E+02, -.50706200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42976200E+00, 0.14644600E+00, -.12280300E+00, 0.29985300E+00, -.59262100E-01, 0.31097600E-01, 0.62014400E-01, -.68953100E+00, 0.17537800E+00, -.19162700E-01, 0.24126700E-01, -.42094000E+00, -.46602300E+00, -.42109400E-02, -.17462600E+00, -.64998500E-01, 0.64120400E-01, 0.57169200E+00, 0.43627000E-01, 0.67939400E+00, -.67578100E+00, -.41498700E-02, 0.12873400E+00, 0.82250800E+00, -.19510700E-01, 0.24176000E-01, 0.30922600E+00, -.29512300E+00, 0.55166800E-01, 0.36883000E+00, 0.86854900E-01, -.33802600E+00, 0.36751600E+00, 0.32585100E+00, -.78766500E-01, 0.45938600E+00, -.28449200E-02, 0.81595500E+00, -.53434700E+00, 0.24187000E+00, 0.36654100E-01, -.27846900E+00, 0.83445800E-01, -.31910300E-01, 0.73879800E-01, -.16561900E+00, 0.82978700E-01, -.23603200E-02, -.17756000E-01, -.22984600E+00, 0.64443700E+00, 0.64221700E+00, -.32709000E-02, 0.59933400E-01, 0.16668500E+00, -.12499400E+00, -.95511500E-01, -.15192100E+00, -.17805800E-01, -.10236900E+00, 0.40709900E-01, 0.18633000E+00, -.89112400E-01, 0.44818600E+00, -.63196400E+00, -.12639500E-01, 0.26039900E-01, 0.72293100E+00, 0.50680500E+00, 0.84888000E-01, 0.10076400E+01, -.37379700E-02, 0.16653800E+00, -.22598500E+00, -.23731800E+00, 0.16771600E-01, 0.48830500E-01, 0.62136500E+00, -.39293100E-01, 0.75648300E-01, -.64628400E-01, 0.10155700E+00, -.63000600E+00, -.77736600E+00, -.10892100E+00, -.40073500E+00, -.11798000E-01, 0.15976500E+00, -.26312600E+00, 0.24638600E+00, -.47222700E+00, 0.32556400E-01, -.51014600E+00, 0.55593000E-01, -.68645600E+00, 0.53121900E+00, 0.52850100E-01, 0.25460800E+03, -.50559300E+02, 0.27642600E+04, -.13745300E+04, 0.64576100E+03, -.13820800E+04, -.12637700E+03, -.13930900E+03, -.70805500E+03, 0.23732500E+03, -.10340800E+04, 0.17504900E+03, -.12146800E+04, -.16491000E+03, 0.78392700E+02, 0.20205600E+03, 0.82467300E+02, -.22965300E+02, 0.96193900E+02, 0.84939700E+02, 0.22009200E+03, 0.60494100E+02, 0.71858400E+02, -.19272600E+03, -.10503900E+03, 0.19746300E+02, -.64531900E+03, 0.52580600E+02, -.93527700E+02, -.41817400E+03, 0.29370200E+03, 0.65073200E+03, 0.82547000E+03, -.59187800E+03, 0.56627400E+03, 0.33998500E+02, -.20795300E+02, -.40986300E+01, -.16814800E+02, 0.42003200E+02, -.16180300E+03, 0.14672300E+01, -.78487800E+02, 0.84876500E+02, -.16324100E+03, 0.16295200E+03, -.39154300E+02, -.10223200E+00, 0.55586500E+03, 0.19614200E+02, 0.59662000E+01, -.21208300E+03, 0.72517800E+02, -.18565500E+03, -.61228700E+03, -.24414100E+02, 0.22365200E+03, 0.18846200E+03, -.79620200E+02, -.36824300E+02, -.94313100E+02, -.49952700E+02, -.73464800E+02, 0.30610100E+02, 0.99462800E+02, 0.91156700E+01, -.72440800E+02, -.13004400E+03, -.18242600E+04, 0.88619900E+03, 0.18428700E+02, 0.91168200E+03, 0.28961400E+02, 0.11545900E+03, 0.34459900E+03, -.30637500E+03, 0.52705800E+03, -.90546500E+02, 0.10625300E+04, 0.61324800E+03, -.34195700E+03, 0.81305400E+03, -.30668600E+03, -.17250100E+03, 0.20544800E+03, -.20174100E+03, -.52448200E+03, -.32596700E+03, 0.20405200E+03, 0.50467400E+01, -.72168500E+03, 0.38105300E+03, -.31644500E+03, 0.36080500E+03, 0.54403400E+02, 0.18658500E+03, 0.79830700E+01, 0.19462500E+02, 0.63557800E+03, 0.49173200E+02, 0.39216900E+03, -.14118900E+03, 0.11090300E+03, 0.75408900E+03, 0.70089000E+02, 0.23702300E+03, 0.53012800E+03, -.29106400E+03, -.59732300E+03, -.91419900E+03, 0.54921200E+03, -.51646300E+03, -.13347500E+04, 0.68007900E+03, -.65472300E+03, 0.66747400E+03, 0.71465900E+00, -.12332600E+03, 0.59671900E+03, -.25078800E+01, 0.52115700E+03, -.27552200E+03, 0.54659500E+03, 0.78342300E+03, -.41678900E+03, 0.50746800E+03, -.39175900E+03, 0.32868300E+02, -.12573700E+02, -.31077500E+03, -.17474100E+03, -.34240400E+03, 0.14289300E+03, -.68167100E+03, 0.10250800E+03, -.54644700E+02, 0.88769200E+03, -.51486100E+02, -.77135200E+01, 0.22612900E+02, 0.13297400E+02, -.16604000E+02, -.42534800E+03, 0.24582900E+02, 0.18718100E+03, -.55517600E+03, 0.26648400E+03, -.35852500E+03, 0.27749600E+03, -.74644900E+02, -.20274000E+03, 0.38994800E+03, 0.15245300E+03, 0.22756000E+03, -.25765700E+03, 0.26513400E+03, 0.62492600E+03, -.28115800E+03, 0.37914400E+03, -.31271600E+03, 0.52221000E+02, 0.58670500E+02, -.37436300E+03, -.38062100E+03, -.55397900E+03, -.10556000E+02, -.69511200E+03, -.11200800E+03, 0.12763300E+03, -.54616200E+02, -.15378100E+02, -.15743500E+03, 0.66895200E+02, 0.61515100E+02, -.22637800E+02, 0.54695200E+02, -.15686800E+03, -.15138100E+03, 0.34769900E+02, 0.10584400E+02, -.96725900E+01, 0.23204800E+03, -.17750200E+02, -.11696100E+03, -.10395900E+03, 0.18512200E+03, -.59583400E+02, -.21681900E+03, 0.14488500E+02, 0.60774900E+02, 0.44773500E+02, 0.59777200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18680900E+01, -.17215400E+01, -.19885900E+01, 0.19141300E+01, -.17235300E+01, -.61337300E+00, -.13861900E+01, -.56840400E+01, -.85018300E+00, 0.24989200E+00, 0.13811600E+01, 0.53518200E+01, 0.98949900E+00, 0.98701600E+00, 0.27044100E+01, -.46361900E+01, -.26250800E+01, 0.14861700E+01, 0.40143000E+00, 0.89126600E+00, -.10464400E+01, -.10982100E+01, 0.29016700E+00, -.37642300E+01, 0.87960900E-01, -.27613300E+00, -.14646600E+01, 0.18225600E+00, -.60820100E+00, -.18260200E+01, -.84650300E-01, 0.15998400E+01, -.11196300E+01, 0.19708500E+01, -.63324900E+00, -.28074500E+01, -.19167200E+00, -.36047500E+01, 0.13625000E+01, -.78416400E+00, 0.21436700E+00, 0.28519900E+00, -.29638900E+00, -.83140100E+00, -.49988000E+00, 0.98239800E+00, 0.10901500E+01, -.34895000E-01, -.47261500E+00, -.62798300E+00, -.17980800E+01, -.54363200E+01, 0.14720600E-01, -.46258400E+00, -.13373300E+00, -.84362600E+00, 0.45459000E+00, 0.78695200E+01, -.17507900E+00, 0.25569100E+00, 0.47116800E+00, -.52888100E+00, 0.49956200E+00, 0.27258500E+00, -.71347200E+00, 0.29194400E+00, -.63709000E+00, -.16668900E+01, -.52824000E+00, 0.17093700E+00, -.31965500E-01, 0.97757800E+00, 0.25781500E-01, 0.55637100E+00, -.12509000E+00, 0.79054000E+00, -.10453000E+00, -.17278200E+01, 0.51169400E+00, 0.49953600E+00, 0.56962700E-01, 0.15382200E+01, -.32960500E+00, 0.46637600E+00, 0.42113900E+00, -.63922200E+00, 0.85692100E+00, 0.14004400E+00, -.22657100E+00, -.75976000E+00, 0.12949900E+01, -.36982700E+00, -.38529800E+00, -.97761400E+00, -.13853000E+01, 0.15274600E+01, 0.59630900E+00, -.26296700E+01, 0.30361400E+04, 0.13396400E+04, -.66682800E+03, 0.28070600E+04, -.66984100E+03, 0.12042000E+04, 0.14964000E+04, -.75756300E+03, 0.28521000E+03, -.17554700E+04, 0.10774100E+04, -.23203600E+04, -.63602400E+03, 0.30503100E+03, 0.16530000E+04, 0.31805800E+03, 0.29868700E+03, 0.79657300E+03, 0.15847000E+03, 0.58035200E+03, 0.16458200E+03, 0.86335200E+03, -.48329200E+03, -.35966800E+04, 0.17825100E+04, -.57281700E+03, 0.17981500E+04, -.82395900E+02, 0.21566600E+03, -.10539900E+04, -.61049400E+03, 0.26354600E+04, 0.52351700E+03, 0.95318400E+03, 0.87286800E+03, -.41698400E+03, -.10566500E+04, -.43691700E+03, -.72390400E+03, -.12309300E+04, 0.28575200E+03, 0.18031300E+03, 0.13445000E+03, -.14891700E+04, 0.11001400E+03, 0.56307700E+04, -.28194300E+04, 0.20362900E+04, -.28154600E+04, -.21153200E+03, 0.43641900E+03, -.23559900E+04, -.10412600E+04, -.47606300E+04, -.30008200E+03, -.92966000E+03, 0.57201100E+03, -.26038100E+03, 0.26799700E+03, -.28720400E+03, -.26930800E+03, -.32078100E+02, 0.13302100E+03, 0.33991300E+03, -.23478500E+03, -.10896300E+03, -.21476200E+03, 0.37848800E+03, -.18217900E+03, -.24958800E+04, -.19043900E+03, -.11048000E+04, -.14760400E+04, 0.55782800E+03, 0.18014900E+03, 0.11439100E+04, -.14236200E+04, 0.30109400E+04, 0.43466400E+04, -.21722000E+04, 0.39594500E+03, -.21732000E+04, 0.65510000E+03, 0.14936500E+04, -.18983300E+04, -.78097700E+03, -.15304000E+04, 0.17541600E+04, 0.10520700E+04, -.35751100E+04, 0.17902700E+04, -.27354700E+04, 0.17876400E+04, 0.14888300E+03, 0.10946300E+04, 0.27035900E+03, 0.20989700E+03, 0.29859700E+04, 0.11173200E+04, 0.21096100E+04, -.21718200E+02, 0.19501900E+02, 0.22489500E+04, 0.12003000E+02, 0.78118200E+03, 0.31126000E+03, -.29260200E+03, -.15068300E+04, -.26056900E+04, 0.27337200E+03, 0.17753400E+03, -.42965600E+04, 0.21424800E+04, -.61196400E+03, 0.21480600E+04, -.54523600E+03, -.80954100E+03, 0.76782300E+03, -.11268100E+04, 0.69888300E+03, -.20010900E+03, 0.14359600E+04, 0.17963000E+04, -.88790100E+03, 0.52785100E+03, -.89803700E+03, 0.84176600E+03, 0.31187700E+03, -.82345600E+03, -.71211500E+03, -.40006500E+03, 0.43224900E+03, 0.46340300E+02, 0.15876000E+04, -.81313500E+03, 0.12019000E+03, -.79329100E+03, -.16022900E+04, -.94164300E+03, -.54149000E+03, -.42426700E+03, -.13629000E+04, -.13590000E+04, 0.18551400E+04, -.67381000E+03, 0.33835800E+03, -.58333500E+03, 0.33722900E+03, -.79475500E+03, -.12358000E+04, 0.11739700E+04, 0.40640300E+03, 0.60865900E+03, -.12442100E+04, -.11652400E+02, -.26289800E+01, 0.37963400E+02, 0.13653000E+04, 0.19456500E+01, 0.88601100E+03, 0.76348800E+03, -.99573800E+03, -.16651700E+04, -.11205800E+04, 0.74307100E+03, -.10801700E+04, -.21870400E+03, 0.27584400E+03, 0.50772900E+02, 0.15368800E+03, -.78535400E+02, 0.45979200E+03, 0.46711400E+03, 0.77787600E+02, -.50764200E+02, -.23629100E+03, -.81488400E+02, -.41152300E+03, 0.65745200E+03, -.35986600E+03, 0.82819300E+03, 0.93373400E+02, -.39922100E+03, -.59802800E+03, 0.98977500E+03, 0.38562000E+03, -.19402900E+03, 0.41819600E+03, -.66888300E+01, 0.17672700E+03, -.28173700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.43604900E+00, 0.42482800E-01, 0.45460600E+00, -.47245200E+00, 0.83613200E+00, 0.17429600E+00, 0.16455200E+00, 0.72833800E+00, -.65457200E+00, -.34880400E+00, -.49716600E-01, -.59878600E+00, 0.32714000E+00, -.50367500E+00, 0.39567200E+00, 0.51281500E+00, 0.31198800E+00, -.51246200E+00, -.31625900E+00, -.68939400E+00, 0.87816800E+00, 0.24178100E-01, -.19602000E+00, 0.11384600E+00, -.13226400E-01, -.30961400E-01, -.52589400E-01, 0.36364000E-01, -.23107000E+00, 0.93794300E-01, 0.12474000E-01, 0.16831600E+00, -.24483500E+00, -.72088400E+00, 0.16106400E+00, -.29774900E+00, -.86640000E-02, 0.17444000E+00, 0.19132500E+00, -.86889700E+00, 0.56945900E+00, 0.26959900E+00, 0.62692000E+00, 0.14104000E+00, 0.22431500E+00, -.12131000E+00, 0.58993700E+00, -.39170500E-02, 0.35252700E+00, 0.29741700E+00, -.26335300E+00, -.77427300E+00, 0.12126200E-01, 0.15290600E-02, -.79009500E-01, 0.38427700E+00, 0.14024300E+00, -.16612700E+01, -.47120100E-01, 0.35260200E+00, -.16758600E+00, 0.23544000E-01, -.14994400E-01, -.40084200E+00, -.11279000E+01, 0.66018500E-01, -.12375500E+00, -.73288900E+00, -.22536800E+00, -.51958600E-01, -.11574100E+01, -.76852900E+00, -.25128900E+00, -.11876900E+00, -.38099700E-01, 0.80212200E-01, -.32854000E-03, -.54951200E+00, -.25943400E-01, -.13649600E+00, 0.55488000E-01, -.43756500E+00, 0.32623100E+00, 0.80916400E+00, -.49337900E+00, -.24721400E+00, 0.90034900E-01, -.24319900E+00, -.10215300E+00, 0.70257100E+00, -.33698000E+00, 0.18560400E-01, -.10802200E+00, 0.41433300E+00, 0.22448000E+00, -.33236100E+00, -.55711800E-01, 0.49985200E+00, -.65659000E-01, -.16591600E+04, 0.82826600E+03, 0.44607900E+03, 0.82952300E+03, 0.37616300E+03, 0.40991700E+03, -.75548100E+01, -.36486400E+03, -.26898700E+02, 0.56920200E+03, 0.93534400E+03, -.65842700E+03, 0.33194300E+03, -.20921600E+03, 0.32919500E+03, 0.74359000E+02, -.19202200E+03, 0.91367200E+02, -.86532100E+02, 0.25059400E+03, -.23152700E+03, 0.79583400E+03, 0.11469800E+04, -.56737000E+03, 0.95316800E+03, -.57355600E+03, -.77679800E+02, 0.33110000E+03, -.49385600E+03, -.29334200E+03, -.12311800E+04, 0.32811500E+03, 0.13115800E+02, 0.70179400E+03, -.35069900E+03, 0.57044900E+01, -.35109600E+03, -.28154200E+01, 0.44305600E+03, -.23945600E+03, -.18219400E+03, -.31221400E+03, 0.48715700E+03, -.74372100E+03, 0.19659200E+04, -.97932600E+03, -.18296800E+04, -.98299900E+03, -.37939000E+03, -.65398600E+01, -.31452400E+03, 0.25822200E+02, -.11916900E+03, -.10992400E+03, 0.29609400E+02, -.44978200E+03, 0.21379400E+03, -.37519300E+02, 0.22456200E+03, 0.77649700E+02, 0.14498300E+03, -.19859900E+02, -.91854100E+02, 0.41099700E+02, 0.12473700E+03, 0.27137500E+03, 0.66071700E+03, -.33189600E+03, -.29030900E+03, -.33025000E+03, 0.79391600E+02, -.10789300E+03, 0.20488700E+03, 0.36545800E+03, 0.18805500E+03, -.14740800E+03, -.11322600E+04, -.13617100E+04, 0.68297900E+03, -.51493800E+03, 0.68092100E+03, 0.10210600E+03, -.10433600E+03, 0.24779100E+03, -.10079600E+03, 0.56281900E+03, -.15401400E+03, -.15378800E+02, -.13747300E+04, 0.68321400E+03, 0.15081400E+04, 0.68740400E+03, 0.16659300E+03, -.21721800E+03, 0.56394700E+03, 0.12183200E+03, 0.10755200E+03, -.62764600E+02, -.30904600E+03, 0.15818100E+03, -.83693700E+02, -.78636600E+03, -.78540900E+02, -.18126200E+03, -.64824700E+03, 0.61119900E+03, 0.58191700E+03, 0.87455500E+03, -.71196600E+03, -.59484300E+03, 0.35845000E+03, -.17627900E+03, -.60369100E+02, -.17933400E+03, -.19733300E+03, -.18070500E+03, -.33304300E+02, 0.20528800E+02, 0.12974400E+03, -.39860700E+03, 0.19112100E+03, 0.67219500E+03, -.33759700E+03, -.94647900E+02, -.33604600E+03, -.13791600E+02, 0.44572200E+03, -.38344900E+03, 0.49389900E+02, -.25701700E+03, 0.42672600E+03, -.27163100E+03, 0.15376200E+04, -.76016900E+03, -.92081300E+03, -.76856000E+03, -.19202200E+03, 0.13723400E+03, -.12314700E+01, 0.34736000E+03, -.31650300E+03, 0.81670200E+02, -.67245900E+03, -.32303700E+03, 0.16065100E+03, 0.78485800E+02, 0.16161100E+03, 0.70619100E+02, 0.83762500E+02, -.20329300E+02, -.12467100E+03, -.79511500E+02, 0.13274600E+03, -.71333200E+02, -.25268300E+03, 0.10880400E+03, -.76640500E+01, 0.12661300E+03, -.10688200E+03, -.18974400E+03, 0.23061000E+03, 0.43207700E+03, 0.21541200E+03, -.22234700E+03, 0.65420100E+02, 0.88387300E+01, -.57504000E+02, 0.75137900E+02, 0.78940100E+02, 0.28989400E+02, 0.32040100E+02, 0.42290000E+02, 0.10013600E+03, -.74386900E+02, 0.24180800E+02, 0.24253400E+03, -.56161500E+02, -.82553100E+02, 0.18480800E+01, -.14497600E+02, 0.86064300E+02, 0.16111400E+03, -.27461500E+02, 0.91531000E+02, 0.76124500E+02, 0.38692000E+03, 0.28490800E+02, 0.74864400E+01, -.31959800E+02, 0.57692800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12923200E+01, -.22501700E+01, -.34231400E+01, 0.18968100E+01, -.53060400E+01, -.96071600E+00, 0.36334700E+00, -.13955500E+01, 0.83471500E+00, -.11769700E+00, 0.13401300E+00, -.40795900E+01, 0.57747600E+01, 0.10153900E+01, 0.16714600E+01, -.30886400E+01, 0.12234900E+01, 0.16246800E+01, -.57682500E+00, 0.17315700E+01, -.26339300E+00, -.83591600E-01, -.67784000E-01, 0.85322900E+00, -.15637800E+00, -.49382400E-01, -.12726000E+00, -.52008400E+00, 0.85820500E+00, 0.14334700E+01, -.91389900E-02, -.11042000E+00, 0.71654900E+00, 0.74789800E+00, -.10481200E+01, 0.67386100E+00, -.39631700E-01, -.37824500E+00, -.21566500E+00, 0.11917700E+01, -.44977300E+00, -.45097600E+00, -.93008000E+00, -.44177800E+00, 0.64625400E-01, 0.47993400E+00, 0.20515600E+00, -.63453300E-02, 0.45511300E+00, -.19709900E+01, -.60982700E+00, 0.14643200E+01, -.17182900E+00, 0.77537700E-01, -.12415200E+00, -.58561100E+00, 0.17796700E+00, 0.42841900E+01, -.21815100E-03, -.11176200E+01, 0.22468200E+00, 0.34680300E-01, -.54452200E-02, 0.11345300E+01, -.71757800E+00, 0.29676000E-01, 0.14845000E+00, 0.13152500E+01, 0.47745800E+00, 0.16204300E+00, 0.14046600E+01, 0.27644500E+00, 0.10868100E+01, 0.54713500E+00, 0.12760100E+00, 0.99392400E-02, -.12313100E+00, -.31840400E+00, -.26691000E+00, 0.11455100E+00, -.89876900E-01, 0.40634300E+00, -.54363400E+00, -.17959000E+01, -.64536300E+00, 0.30213600E+00, 0.88112100E-01, -.62590400E+00, 0.37862400E+00, -.34568100E+00, -.29251100E+00, -.21797000E+00, -.48155000E+00, -.63372800E+00, 0.22556500E+01, -.13954700E+01, -.20218600E+01, -.27817100E+01, -.25057900E+00, 0.17283400E+00, 0.21832100E+02, -.12513200E+04, 0.46548600E-02, -.10834400E+04, 0.58463100E+03, -.22101600E+03, -.60419900E+03, -.58695600E+03, 0.57753700E+03, -.15345200E+03, -.12284300E+04, 0.58692600E+03, 0.21004300E+04, 0.61420500E+03, -.18354500E+03, -.68071200E+03, 0.12479000E+04, 0.16238400E+04, 0.76112900E+03, -.80389200E+03, -.87865900E+03, 0.12571100E+04, -.73029300E+03, 0.63516600E+03, -.62853400E+03, -.17212600E+03, -.99896700E+02, -.90109100E+02, 0.14148200E+04, -.10606600E+03, -.21209300E+03, -.11776300E+04, 0.13007900E+04, -.65459600E+03, -.20635300E+04, -.65034100E+03, 0.22347400E+02, 0.66893000E+03, -.12089300E+04, -.17909100E+04, -.64683200E+03, 0.72671500E+03, 0.10404600E+04, -.10301100E+04, 0.45176100E+03, 0.11417000E+04, 0.51506400E+03, 0.10626100E+04, 0.59358000E+03, -.11706600E+04, -.21003100E+04, 0.54375300E+03, -.37798900E+03, 0.29758700E+04, 0.31658900E+03, -.95129800E+02, 0.35249500E+03, -.15837800E+03, -.14070600E+03, -.73343300E+01, 0.21117300E+02, 0.57070700E+02, -.34446500E+03, -.28157500E+02, -.19686800E+03, 0.16227600E+04, -.88152400E+03, -.34910100E+03, -.81211800E+03, 0.17277600E+03, -.41197500E+03, -.57703700E+01, 0.10807400E+04, 0.12714700E+04, -.78000300E+03, 0.52027900E+03, 0.19433700E+04, -.10767600E+04, -.24129200E+04, -.97170000E+03, 0.51326200E+03, 0.42883400E+03, -.46226700E+03, 0.87448400E+03, 0.25501300E+03, 0.23749400E+03, -.71558200E+03, 0.54711200E+04, -.26736300E+04, -.31954800E+04, -.27355700E+04, -.14865800E+04, 0.20725900E+03, -.35953300E+03, 0.17717300E+04, -.19616500E+04, 0.38146900E+03, -.25729100E+04, -.11782500E+04, 0.71250500E+03, -.16286500E+04, 0.58897900E+03, 0.36966800E+03, -.67128700E+03, 0.79236500E+03, -.85342300E+03, 0.68387200E+03, -.60206300E+03, 0.13514000E+04, 0.34094200E+03, -.13977300E+03, 0.54368600E+03, -.17044200E+03, 0.62596600E+03, -.66465000E+02, 0.15325900E+03, 0.36952800E+03, -.87522600E+03, 0.72494400E+02, -.40325400E+03, -.70063200E+03, 0.27830500E+03, 0.64824400E+02, 0.35030200E+03, 0.88847100E+03, -.49072500E+02, 0.54209200E+03, 0.10817500E+04, 0.13700100E+04, 0.71007600E+01, -.98969500E+03, 0.43816600E+04, -.22162400E+04, -.26485500E+04, -.21909000E+04, -.86107100E+03, -.11039700E+03, -.12186000E+04, -.16145000E+03, -.94501100E+03, -.92958900E+03, 0.67013400E+03, 0.76964300E+03, -.41602100E+03, -.63850200E+03, -.38486500E+03, -.27500500E+03, -.42549800E+03, -.31973300E+03, 0.97901300E+02, 0.23662900E+03, -.41889400E+03, 0.44904700E+03, -.14375100E+04, 0.83730100E+03, 0.77682400E+03, 0.71867500E+03, 0.97910500E+03, -.84797800E+01, 0.10130100E+04, 0.47635900E+03, 0.85865400E+03, 0.32856700E+02, -.50500800E+03, 0.62504700E+02, 0.10911800E+03, 0.33228100E+03, 0.39611900E+03, 0.49584300E+03, 0.49987300E+03, 0.46273000E+03, 0.34183300E+03, -.33818700E+03, 0.54986600E+01, 0.78153500E+03, 0.10315100E+03, 0.58964700E+02, -.23376700E+03, 0.70344400E+03, 0.34800900E+03, 0.84663100E+03, -.34902500E+02, 0.11122000E+04, 0.31732900E+03, 0.87639700E+03, 0.43198500E+02, -.13140200E+03, 0.94210100E+02, -.21518600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.86172400E+00, -.13540600E+01, 0.21362100E+01, 0.34393500E+00, 0.10910700E+01, -.13359900E-01, 0.14331700E+01, 0.50138900E+00, -.28174000E+01, -.47807600E+00, -.29274100E+00, -.17347500E+00, -.82438300E-01, -.13859100E+01, 0.10974500E+01, 0.39053200E+00, 0.23283700E+00, -.17685400E+00, -.58176400E+00, -.13938000E+00, 0.18383000E+01, 0.87591300E-01, -.73610900E+00, 0.10270000E+01, -.46566300E-01, 0.61049500E-01, 0.12182900E+01, 0.10071600E+00, 0.44306200E+00, 0.28908500E+00, 0.15855300E+00, -.20315200E+00, -.25046400E-01, 0.15141100E+01, -.40307700E+00, -.93808200E-01, 0.69182400E-02, -.63865500E-01, -.10822000E+00, 0.43253800E+00, -.78987300E+00, -.18725400E+00, 0.25934200E+00, -.11808800E+00, -.25429000E+00, 0.29985100E+00, 0.32231100E+00, -.26126600E-02, -.75225600E+00, -.16111000E+00, -.39977100E+00, 0.81279600E-01, 0.20018200E-01, 0.88537800E+00, 0.22769600E+00, -.60891900E+00, -.18858600E+00, -.85753200E-01, -.18445800E-01, 0.57660800E+00, 0.22012000E+00, 0.82437200E-02, 0.22846400E+00, 0.10557900E+01, -.13905500E+01, 0.33388800E+00, -.16795200E+00, 0.72043100E+00, 0.61197600E+00, -.37105800E+00, 0.17557700E+01, -.65532000E+00, -.43017100E-01, -.49004300E+00, -.31276400E+00, 0.46255500E-01, 0.18602000E-01, 0.31654800E+00, -.28448100E+00, -.15665700E+00, 0.21875600E+00, -.63529100E+00, 0.18944600E+00, 0.44130200E+00, 0.13626100E+00, -.61999900E+00, -.21237400E+00, 0.22690300E+00, 0.15670300E+00, 0.30882400E+00, 0.55241200E+00, 0.23940000E+00, -.19392500E+00, 0.41257600E+00, 0.17356700E+00, -.65679200E+00, 0.13439000E+01, 0.17801100E+00, 0.13721400E+00, 0.33008400E-01, 0.86895400E-01, -.29311500E+04, 0.76375500E-01, -.20823000E+04, -.98057700E+03, 0.71826400E+03, -.17789500E+03, 0.24048200E+03, -.60133900E+03, 0.54961500E+03, -.39020300E+03, 0.20152300E+03, 0.63180600E+03, 0.19509200E+03, -.49178900E+03, -.75107500E+03, 0.49842200E+03, 0.49851100E+03, 0.25144700E+03, -.50658400E+03, -.37241400E+03, 0.14061400E+04, -.69704200E+03, 0.95424200E+03, -.70291000E+03, 0.86832000E+03, 0.36897700E+03, -.63793100E+03, -.27280100E+03, -.48117500E+03, 0.43074600E+03, -.11863900E+04, 0.17756500E+03, -.96853400E+02, -.54740200E+03, -.88338100E+02, 0.58878600E+03, 0.95861700E+03, -.78439200E+03, -.10018400E+04, -.34964200E+03, 0.74805400E+03, 0.78627600E+03, 0.87964900E+04, -.43941800E+04, -.56327800E+04, -.43981600E+04, 0.65747800E+03, 0.12120800E+04, -.21410700E+04, 0.14234900E+04, -.17483800E+04, 0.45338000E+03, -.48544400E+04, -.16221800E+03, 0.74611200E+02, -.13558700E+03, 0.81752800E+02, 0.53265300E+02, -.76981000E+02, -.67389600E+02, -.28775500E+03, 0.12818000E+03, -.15098700E+02, 0.72359500E+02, 0.34377700E+03, -.17184700E+03, 0.18885600E+04, -.17019300E+03, 0.76798600E+03, 0.10541500E+04, -.96506800E+03, -.40822800E+03, -.12338500E+04, 0.10925300E+04, -.46675800E+03, -.21140900E+04, 0.10597200E+04, -.58470700E+03, 0.10569100E+04, 0.29644900E+03, -.84983400E+03, 0.77300600E+03, 0.10443700E+04, 0.12232500E+04, -.87373400E+03, -.99547200E+02, -.48692000E+04, 0.24321300E+04, 0.37280800E+04, 0.24345100E+04, -.47956400E+03, -.95036400E+03, 0.13132400E+04, -.68249300E+03, 0.78526900E+03, -.34713700E+03, 0.25172700E+04, -.18416700E+04, 0.91555300E+03, -.83928400E+03, 0.91967700E+03, -.19805200E+03, 0.25030100E+02, 0.11344000E+04, 0.10345300E+04, 0.10481100E+04, -.17943500E+03, 0.15817800E+04, 0.24778900E+04, -.12386100E+04, 0.15019300E+04, -.12387200E+04, 0.17264300E+04, 0.75650900E+03, -.49540800E+03, 0.91638200E+03, -.37507200E+02, 0.17377100E+03, -.16149000E+04, -.20405200E+04, 0.10211800E+04, 0.56633000E+02, 0.10201500E+04, -.16522200E+03, -.95808100E+02, 0.46073400E+03, 0.78615100E+03, 0.84668000E+03, -.20925100E+02, 0.15559900E+03, 0.34071900E+04, -.16986600E+04, -.24392300E+04, -.17041300E+04, 0.63464400E+03, 0.18797300E+03, -.64738000E+03, 0.99925800E+03, -.72407100E+03, -.83542100E+02, -.24915800E+04, 0.18664300E+02, -.79985900E+01, 0.51130900E+03, -.95967500E+01, 0.73755200E+02, -.49563700E+02, -.23545100E+03, -.41483400E+03, -.40985400E+03, 0.14176000E+03, 0.56918500E+01, -.41989700E+03, 0.19980700E+03, -.46686200E+03, 0.20934600E+03, -.15978900E+03, 0.32042500E+03, 0.31641000E+03, 0.12030300E+04, 0.23094100E+03, 0.31303000E+03, 0.13923400E+03, 0.10042600E+03, -.49038500E+02, -.45742200E+02, -.34105400E+01, -.18120100E+02, -.17585900E+03, -.19848400E+03, 0.36624600E+01, 0.46036800E+02, 0.76041600E+02, 0.10428800E+03, 0.54120400E+03, -.34211100E+03, 0.21360700E+03, -.57336800E+03, 0.52440300E+01, 0.37646900E+03, 0.34398700E+03, -.48287300E+03, -.11036300E+03, 0.19267500E+03, -.17428700E+03, 0.56373500E+02, 0.57709900E+02, 0.13209500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.32837100E+01, 0.52003600E+00, 0.30294700E+01, -.55244600E+01, 0.12648200E+01, 0.62687900E+00, 0.48214400E+01, 0.81911500E+01, -.47289500E+01, -.15112000E+01, -.50712200E+00, -.83473100E+00, 0.25886600E+01, 0.40628200E+00, 0.29206800E+01, 0.14635700E+01, 0.31641600E+00, -.20600200E+01, -.74473700E-01, -.94632700E+00, 0.13856600E+01, 0.39841300E+00, -.63430000E+00, 0.78105200E+00, -.35237000E+00, -.84535100E+00, 0.13351600E+01, 0.51268900E+00, 0.57009200E+00, 0.88953800E+00, 0.58662100E+00, -.50874500E+00, 0.79894800E-01, -.13667900E+01, 0.18354500E+00, 0.55047700E+00, 0.50176800E-01, 0.94852300E+00, -.81933800E-01, 0.69469300E+00, 0.94157700E+00, 0.81932800E+00, -.11754800E+01, 0.21675100E+00, -.26011900E-01, -.58211100E+00, -.63020800E+00, 0.15511400E-01, 0.67714200E+00, -.28788800E+00, 0.34313300E+00, 0.68099100E-01, -.22996900E-01, -.13648100E+01, -.51600300E+00, 0.12736300E+00, 0.40244900E-01, -.15588200E+01, 0.10611700E+00, -.71337700E+00, -.26272800E+00, 0.32229300E+00, -.34572900E+00, -.53517200E+00, 0.21231700E+00, -.52679400E+00, 0.32813500E+00, 0.13052600E+01, 0.47751200E+00, 0.22788100E+00, 0.23792000E+00, 0.17255600E+01, -.23417200E-01, -.25512800E+00, 0.12551900E+00, -.29024600E+00, 0.24828400E+00, 0.13029900E+01, 0.10404200E-01, 0.29781600E+00, -.30571100E+00, 0.70691400E+00, -.41959100E+00, -.10923500E+01, -.63503300E-01, 0.86314500E+00, -.16741100E+00, -.66068400E+00, 0.56720100E-02, -.30933500E+00, -.10537900E+01, -.22346000E+00, 0.66364200E+00, 0.48004800E-01, 0.55453700E+00, -.10504600E-01, -.13153200E+01, -.18432300E+01, -.45149400E+00, -.11053600E+01, 0.14915000E+00, -.59568500E+00, 0.55717800E+01, 0.52656600E+03, 0.46034100E+03, -.15314300E+03, 0.95885900E+03, -.47733700E+03, 0.68033400E+03, 0.88051200E+03, -.54448500E+03, 0.27371100E+03, -.72913400E+03, 0.27227300E+03, -.23674600E+03, -.90889000E+03, 0.23636400E+03, 0.61903100E+03, 0.25353300E+03, -.10364900E+04, 0.62269000E+03, 0.61915100E+04, -.30931400E+04, -.95256800E+02, -.30958900E+04, -.17564300E+04, -.16901400E+04, -.37056100E+03, 0.68708800E+03, -.14347100E+04, -.15782300E+04, -.17381900E+04, 0.20400100E+03, -.10440200E+03, 0.88472500E+03, -.10235400E+03, 0.35771400E+03, 0.11277100E+04, -.14173800E+03, -.91337500E+03, -.18624200E+03, 0.13456100E+04, -.41962700E+03, 0.13420300E+04, -.66983100E+03, 0.75074800E+03, -.67106800E+03, -.62524200E+03, 0.20024900E+04, -.10888400E+04, -.20605800E+04, -.15960400E+04, 0.21927500E+04, 0.18557300E+04, -.70899400E+02, 0.44640500E+02, -.20499900E+03, 0.34105500E+02, 0.72979000E+01, 0.25604100E+02, 0.72624300E+02, 0.27950100E+03, 0.17825600E+03, 0.33816300E+02, 0.11421900E+03, -.23779200E+04, 0.11895500E+04, 0.71218300E+03, 0.11918500E+04, -.43480700E+03, 0.59899800E+02, 0.56061500E+03, -.66476300E+03, 0.69183700E+03, -.23326500E+03, 0.47930800E+03, 0.19426700E+04, -.96664800E+03, -.23273700E+04, -.97125900E+03, -.61783900E+03, -.63728000E+02, -.56721400E+03, -.64180900E+03, -.32124700E+03, -.32097500E+03, -.19475100E+04, -.21224000E+04, 0.10611100E+04, -.39098800E+03, 0.10612600E+04, 0.27492000E+03, -.17497200E+04, 0.15305200E+04, 0.16019700E+04, 0.15217300E+04, -.17965000E+04, -.50220700E+03, -.25628800E+04, 0.12752200E+04, 0.15786100E+04, 0.12822300E+04, 0.11210700E+04, 0.10267500E+04, -.34863100E+03, -.58784400E+03, -.96745800E+02, 0.76591700E+03, 0.84368800E+01, 0.11900500E+04, -.59391800E+03, -.71063400E+03, -.59517900E+03, -.14079800E+03, -.65823200E+03, -.14142000E+03, -.62323400E+03, 0.77019100E+02, -.79115500E+03, -.61151300E+03, 0.19969600E+04, -.99672500E+03, 0.62359100E+03, -.99840000E+03, -.37910700E+03, 0.24794200E+03, -.86111100E+03, -.13857800E+03, -.89834000E+03, 0.21969000E+03, -.12641900E+04, -.15109100E+04, 0.75895200E+03, 0.91075700E+03, 0.75579900E+03, -.10147000E+04, 0.30651900E+02, 0.43138900E+03, -.70878500E+03, 0.42519200E+02, 0.26524900E+03, 0.18734900E+04, -.11846200E+04, 0.59228500E+03, -.10516000E+03, 0.59254300E+03, -.48137600E+03, -.78607700E+03, 0.83856600E+03, 0.29893600E+03, 0.51729200E+03, -.60328800E+03, 0.34955400E+03, 0.31667100E+03, -.16378600E+03, 0.31256400E+03, -.15788900E+03, 0.38290700E+02, -.43862300E+02, -.49562500E+03, 0.24059000E+03, -.60051600E+03, -.30682000E+03, -.10692300E+04, -.40583400E+02, 0.45822900E+02, 0.21810600E+03, 0.16310100E+03, 0.49164200E+02, 0.60889000E+03, 0.64478200E+03, 0.17199000E+03, -.21986600E+03, 0.25121900E+02, 0.78619400E+03, 0.86543300E+02, -.46165400E+03, -.37995100E+02, 0.55239100E+03, 0.16427200E+03, 0.89372900E+03, -.11136300E+02, 0.89749600E+03, -.23851700E+03, 0.10379200E+04, 0.42514300E+02, -.77201200E+02, 0.10476000E+03, 0.20617100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32413600E+00, -.22650700E+00, 0.51115600E+00, -.64580400E+00, 0.14175700E+00, 0.84048400E-01, 0.98278000E+00, 0.16064600E+00, -.20689700E+01, -.50428400E+00, 0.30885300E-01, 0.80082400E+00, -.52929100E+00, -.45540600E+00, 0.68125700E+00, -.61513500E+00, -.48068600E+00, 0.26737300E+00, 0.26360700E+00, 0.54020900E+00, -.53347400E+00, -.36894000E-01, -.32778300E-01, 0.36360300E+00, 0.17691600E-01, 0.53366200E-01, 0.57015000E+00, -.14521600E+00, 0.19114700E+00, -.65637200E+00, 0.19192600E+00, -.35480600E+00, -.26539700E-01, 0.10142000E+01, -.48309600E+00, -.86741900E+00, -.31614500E-01, -.29669600E+00, 0.94315700E-01, -.19937000E+00, 0.12417400E+00, 0.17106800E-01, 0.23934300E+00, 0.49835800E-02, -.13721900E+00, 0.27186400E-01, 0.59561700E-01, -.47760200E-02, 0.11236500E+00, -.22954100E+00, 0.34424300E-01, -.11797600E+00, 0.25917600E-01, 0.23440800E+00, 0.13267100E+00, 0.25292300E-01, 0.16728800E+00, 0.25363000E+00, 0.23737200E-02, 0.28103100E+00, 0.14805500E+00, 0.41495400E-01, 0.45004900E-01, -.41194000E+00, 0.56156400E+00, 0.73533000E-01, 0.44349700E-01, 0.22381100E+00, -.36766300E-01, -.11174100E+00, 0.33880200E+00, -.21260500E+00, -.14861300E+00, -.18793800E+00, -.20280800E+00, 0.10838100E+00, -.21466400E-02, -.71084500E-01, -.99350700E-01, -.19763400E+00, 0.43637900E-01, -.26991400E+00, 0.14762000E+00, 0.44202900E+00, -.58645400E-01, -.12593300E+00, -.16417800E-01, 0.14163800E+00, 0.52784000E-01, 0.22004000E-01, 0.50507000E+00, 0.52395900E-01, 0.90388200E-01, -.38068600E-01, -.92994800E-01, -.37974400E+00, 0.41127400E+00, 0.30064700E+00, 0.94614000E-01, 0.27785900E+00, -.71973500E-01, 0.68138000E-01, 0.19238500E-03, -.52800000E+03, -.18830100E+03, 0.80136800E+02, -.39982700E+03, -.17825700E+03, 0.43522800E+01, -.26465100E+03, -.47362400E+03, 0.23472500E+03, 0.72671200E+03, 0.23680400E+03, -.85455000E+02, -.14820800E+03, 0.32065800E+03, 0.27893200E+03, 0.17806400E+03, -.86645000E+02, -.61397100E+02, -.13677300E+04, 0.68140500E+03, -.87923500E+02, 0.68387800E+03, 0.53159000E+03, 0.28627900E+03, -.12049400E+03, -.22175900E+03, 0.55593300E+03, 0.23804600E+03, 0.39324100E+03, 0.30994000E+03, -.15405900E+03, -.67562400E+03, -.15493600E+03, 0.13928000E+03, 0.24964800E+03, -.44864200E+03, -.46670700E+03, -.18450100E+03, 0.16295900E+03, 0.20036500E+03, 0.32463600E+04, -.16229500E+04, -.23394800E+04, -.16231700E+04, 0.50356400E+03, 0.45254100E+01, -.79342800E+03, 0.49018200E+03, -.60295100E+03, -.37940000E+03, -.17961200E+04, 0.47450200E+02, -.20919400E+02, 0.39907100E+02, -.23629500E+02, -.11275700E+02, -.40619100E+02, -.29655200E+02, -.82637300E+02, -.29242900E+01, -.31476600E+02, -.42037000E+02, 0.14356400E+03, -.71601600E+02, 0.10585800E+03, -.71181900E+02, 0.28373700E+03, 0.28330100E+03, -.24544200E+03, 0.22831600E+02, -.16358900E+03, 0.22395600E+03, 0.15934900E+03, 0.20832000E+03, -.10654800E+03, 0.59142600E+02, -.10417000E+03, 0.12454400E+03, 0.22248800E+03, -.12592500E+03, 0.39239700E+03, 0.97744200E+02, 0.12895000E+03, -.12662100E+03, -.12266600E+04, 0.61295000E+03, 0.15062900E+04, 0.61332400E+03, -.36192900E+03, 0.18838400E+03, 0.13548000E+03, -.31333600E+03, 0.60619100E+02, 0.37327100E+03, 0.90811200E+03, -.66794100E+03, 0.33720700E+03, -.51700500E+03, 0.33388500E+03, -.19818700E+03, -.79621200E+02, 0.75946100E+03, 0.45854100E+03, 0.34867600E+03, -.11931200E+03, 0.71808800E+03, 0.24479100E+02, -.13437200E+02, -.16174400E+02, -.12222200E+02, 0.28458100E+03, 0.15950500E+03, 0.14984000E+03, 0.43424800E+03, 0.20334300E+03, -.34886900E+02, -.45177000E+02, -.35535000E+03, 0.17620900E+03, -.11316100E+03, 0.17766700E+03, 0.60095900E+02, 0.12390500E+03, 0.83649800E+02, 0.43474600E+03, 0.28036100E+03, 0.15629000E+03, 0.48217900E+02, 0.25923900E+04, -.12990500E+04, -.12558900E+04, -.12962400E+04, 0.21883100E+03, 0.27508800E+03, -.68582600E+03, 0.35475100E+03, -.66906900E+03, -.56054200E+02, -.13289000E+04, 0.53634900E+01, -.22371800E+01, -.38440000E+02, -.27096600E+01, 0.69505300E+01, -.11135200E+03, -.82693300E+02, -.16932500E+03, -.13938100E+02, -.90492300E+02, 0.15700000E+02, -.35332100E+03, 0.18293100E+03, 0.10780800E+03, 0.17661300E+03, 0.48348400E+02, 0.11120300E+03, 0.36530100E+03, 0.60196500E+03, 0.20446600E+03, 0.15614600E+03, 0.28208000E+03, -.22074200E+02, 0.44234200E+02, 0.14379100E+02, 0.44199200E+02, 0.14452400E+02, 0.82263200E+01, -.12383500E+02, 0.37268900E+02, -.14306200E+02, -.18461400E+02, -.45085900E+02, 0.14435100E+03, -.47815800E+01, 0.37000900E+02, -.10006200E+03, 0.41041300E+02, -.56855000E+02, -.11392700E+02, -.99625800E+02, -.39649300E+01, -.25900400E+02, -.86049800E+02, 0.57119800E+02, 0.64298000E+02, 0.71828200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.85476800E+00, -.74304900E+00, -.17753900E+01, 0.54866300E+00, -.19513300E+00, -.11075000E-01, -.11171500E+01, -.15202600E+01, 0.23979900E+00, -.88110500E-01, 0.77993000E-01, 0.33261900E+01, 0.25922300E+01, -.82894800E+00, 0.17082600E+01, -.47118900E+01, -.17120500E+01, 0.51996400E+00, 0.27741100E+00, -.10130900E+00, -.28113800E+00, 0.75460100E-01, -.65979100E+00, -.11000100E+01, 0.36929500E-01, 0.11427900E+00, -.22473500E+01, 0.19644200E+00, -.34064400E+00, -.13521700E+01, 0.95696200E-01, 0.14192900E+01, -.44819300E+00, 0.11734700E+00, 0.29246900E+00, -.68604000E+00, 0.10024400E-01, -.13117900E+01, 0.74934900E+00, 0.82416200E+00, 0.12799500E+01, 0.87054000E+00, -.15146500E+01, -.22341900E+00, 0.76945200E-01, 0.29602300E+00, -.20530900E+00, 0.91629000E-02, -.73771300E+00, 0.82474600E+00, -.57926300E-01, -.85009400E+00, -.78297300E-01, -.44200800E+00, -.39269200E-01, -.92730300E-01, -.56754600E+00, 0.92468800E+00, -.34800500E-01, -.78494100E-01, -.15642100E+00, -.35339300E+00, -.10477300E-01, 0.42618600E+00, -.38743200E+00, 0.15577500E-01, -.28064800E+00, -.56337500E+00, 0.14266300E+00, 0.16349600E+00, -.87715800E+00, -.59141000E+00, 0.18831900E+00, 0.62690700E+00, 0.36148300E+00, -.41624200E+00, -.19489400E+00, -.28046700E+00, -.25443700E-02, -.74461200E-01, 0.53549000E-02, 0.66555100E-01, 0.49548400E-02, -.13389600E+00, -.33019300E+00, 0.14272300E+00, 0.14306300E+00, 0.94871300E-01, 0.11806400E+00, -.23945300E+00, 0.33583600E+00, -.69338800E-01, -.34074600E+00, -.48633800E+00, -.22836800E+00, 0.39001500E+00, -.58813000E+00, -.39755300E+00, -.14439300E+00, -.51307500E+00, 0.36582300E-01, -.20233300E-01, 0.77811300E-03, -.10451800E-01, 0.74725000E+03, -.78399900E+02, 0.16663500E+03, 0.16147100E+03, 0.45150500E+03, -.22007600E+03, -.21237000E+03, 0.10729700E+03, 0.52555000E+03, 0.10618700E+03, 0.19780300E+03, 0.35294200E+03, -.71245700E+02, -.51094800E+02, 0.15323300E+03, 0.32967500E+03, -.37940200E+03, 0.26925300E+03, -.13191600E+03, 0.72478600E+03, -.13464300E+03, -.16142000E+03, 0.39715700E+03, -.55428200E+03, 0.35115200E+02, -.31573000E+03, 0.51255600E+03, -.94096200E+03, 0.44797100E+03, -.21705700E+03, -.46856600E+03, -.22403000E+03, -.35492200E+03, -.57923300E+03, 0.23757000E+03, 0.32872500E+03, -.62072200E+02, -.60318900E+03, 0.26731100E+03, 0.71186100E+03, -.35327500E+03, -.22579500E+03, -.35593500E+03, -.39845000E+02, -.12398500E+02, -.28967200E+03, -.16524500E+02, -.88223700E+02, -.38886800E+03, 0.58481300E+03, 0.18486200E+03, -.81092000E+02, -.40997200E+02, -.92321900E+02, -.56558700E+02, -.91439900E+01, 0.18127800E+02, 0.64350800E+02, -.78370600E+02, -.29224200E+02, -.11744300E+03, 0.10039900E+04, -.49735200E+03, -.66696900E+03, -.50168100E+03, -.27516200E+03, -.74614200E+03, 0.11407100E+03, 0.24241700E+03, -.70987600E+01, -.64717700E+03, 0.29346000E+03, 0.55634400E+03, -.27236300E+03, -.57992500E+03, -.27816600E+03, 0.62605500E+03, -.30538600E+01, -.28030600E+03, 0.10962800E+03, -.13322100E+03, 0.18127600E+03, -.33697000E+03, 0.14038800E+03, -.74060400E+02, -.38312400E+03, -.70187900E+02, -.10028300E+03, 0.27504000E+03, -.12614700E+03, -.50425800E+00, -.10354100E+03, 0.40418300E+03, -.20687300E+03, 0.44798800E+03, -.22799200E+03, 0.16133700E+03, -.22391100E+03, 0.23280900E+03, -.47733200E+03, 0.23576700E+02, -.45494300E+03, -.12481800E+03, -.47183000E+03, 0.49144000E+03, -.36479500E+03, 0.18077800E+03, 0.34548900E+02, 0.18238200E+03, 0.21976000E+03, -.30944500E+03, -.12715000E+03, -.28775900E+03, -.26033100E+03, -.25424400E+02, -.10846000E+02, 0.25582900E+03, -.12170500E+03, 0.11962000E+03, -.12790600E+03, 0.28607100E+03, -.75327600E+02, -.70801400E+02, -.10125700E+03, 0.20597500E+03, -.74241600E+01, -.35705500E+03, 0.67510200E+03, -.33967100E+03, -.64713300E+03, -.33752100E+03, -.49699500E+03, -.52046300E+03, -.14642900E+03, 0.65133700E+02, 0.20410800E+03, -.69373800E+03, 0.88789100E+03, 0.10201100E+03, -.49623500E+02, -.17192600E+03, -.50980300E+02, -.20137000E+03, -.16524000E+03, 0.36378000E+00, 0.99991600E+02, 0.14797900E+03, -.17841300E+03, 0.35699200E+03, -.20192800E+03, 0.10101500E+03, 0.31293100E+03, 0.10101400E+03, 0.32276400E+03, 0.15452600E+03, -.77028600E+02, -.48285100E+03, 0.12082600E+03, 0.16123200E+03, -.11179000E+03, 0.12462300E+00, 0.20055700E+02, 0.42932600E+02, 0.68005900E+02, 0.68398900E+02, 0.19257900E+03, 0.19463500E+03, 0.52296800E+02, -.42509600E+02, -.27665500E+01, 0.25838000E+03, -.28537400E+03, 0.20707900E+03, -.17806700E+03, -.50138300E+02, 0.55875200E+02, 0.26494900E+03, -.37350700E+02, 0.23112200E+02, 0.21587900E+03, 0.24391100E+03, 0.11531600E+03, 0.12159200E+02, 0.29549100E+01, -.10237000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14473200E+01, 0.38903900E+00, 0.15346400E+00, 0.12270000E+01, 0.17186600E+00, 0.50508400E-01, -.71197000E+00, 0.46430200E+00, 0.12775600E+01, 0.14933300E+00, -.72571800E+00, -.16641700E+01, -.28323900E+01, -.11006100E+01, -.35846400E+01, 0.43816000E+01, 0.20878900E+00, -.95224200E+00, -.22309900E+00, -.10507200E+01, -.64202700E+00, -.85544600E-01, 0.13390900E+01, 0.51488600E+00, 0.41313500E+00, 0.82655300E-02, -.99154600E+00, 0.85348500E+00, -.64496900E+00, 0.40461400E+00, -.86456100E-01, -.16205700E+00, 0.17567900E+01, -.11657200E+01, 0.41038800E+00, 0.16685500E+00, 0.73293000E-01, -.53428600E-01, 0.57628200E-01, 0.22656300E+01, -.11609100E+01, -.19776900E-01, -.93720900E+00, 0.16726000E+00, 0.86798600E-01, 0.26035400E+00, 0.11091900E-01, 0.15545200E-01, -.14591100E+00, -.18698000E+00, -.11821300E+01, 0.27531300E+01, -.35272100E+00, 0.26846200E+00, -.23024500E-01, 0.23522900E+00, 0.50461100E+00, -.49438700E+00, -.33486900E-02, 0.22976400E+00, 0.98646900E-01, 0.90456000E-01, 0.85883500E-01, -.81746000E+00, 0.60831700E+00, 0.88563800E-01, 0.11479000E+00, 0.70595400E-01, -.61764800E+00, -.91922500E-01, -.85846600E+00, 0.83707700E+00, -.70050700E+00, -.55524100E+00, -.63239200E+00, 0.76280300E+00, 0.16745300E+00, -.71269400E+00, 0.74011500E-01, -.89354200E-01, -.14356200E-01, 0.64912700E+00, 0.81430300E-01, 0.13417600E+01, 0.43421800E+00, -.37582300E+00, 0.23038900E+00, 0.11325200E+01, -.30726400E+00, -.39228200E+00, 0.64412700E+00, -.53469200E-01, 0.83984500E+00, -.76262400E+00, -.91001900E-01, 0.22494100E+00, 0.16551000E+01, 0.12745400E+01, 0.69183900E-01, -.73955600E+00, -.14595400E-01, 0.83005300E-01, -.28823800E-01, 0.27320500E+01, 0.36863900E+00, -.99373700E+03, -.64700800E+03, -.66801000E+03, -.47232600E+03, 0.96106700E+03, -.86805100E+02, 0.52175400E+02, 0.12320100E+03, 0.43390500E+02, 0.40882100E+03, 0.88258700E+03, -.36010200E+03, -.67329600E+03, -.12068800E+03, 0.10283200E+04, -.14358500E+02, -.14529400E+04, 0.72997200E+03, 0.56033700E+03, 0.72618600E+03, 0.70437300E+03, 0.87140900E+03, 0.43843800E+01, -.57785100E+03, -.29495200E+01, 0.10013400E+04, 0.13804600E+04, 0.81754500E+03, -.41147200E+03, -.25594100E+03, -.40958100E+03, -.55150500E+03, -.10966100E+04, 0.29233200E+03, 0.88425400E+03, 0.69665100E+02, -.12732100E+04, -.30003200E+03, -.15644900E+04, 0.78446100E+03, 0.18055500E+04, 0.78209100E+03, -.82794500E+03, -.10576000E+04, 0.16960000E+04, 0.13435800E+04, -.50252300E+03, -.64203700E+03, 0.13368300E+04, -.49775300E+03, 0.19122800E+03, 0.20882500E+03, 0.24782700E+03, 0.48706000E+02, 0.17610600E+03, -.80731700E+02, -.21718200E+03, -.10228200E+03, 0.13225600E+03, 0.44368700E+03, 0.12471200E+04, -.63320700E+03, -.64479200E+03, -.62479300E+03, -.38534400E+01, -.38516400E+03, 0.38856600E+03, 0.39930100E+03, 0.10668900E+03, 0.42377400E+02, -.18467900E+04, -.38883100E+04, 0.19416200E+04, 0.22187000E+04, 0.19444100E+04, 0.25465500E+03, -.43872000E+03, 0.11369300E+04, -.30924500E+03, 0.10074500E+04, 0.89946200E+02, 0.11183200E+04, -.13119300E+04, 0.65452600E+03, -.74343400E+03, 0.65612800E+03, 0.63108200E+03, 0.42798100E+03, -.57934400E+03, -.12276300E+04, 0.10338500E+04, 0.36269300E+03, -.45215700E+03, 0.18844500E+04, -.94335400E+03, -.58699200E+03, -.94009500E+03, -.37772200E+03, -.68635900E+03, -.18831500E+03, 0.14700000E+03, -.50107400E+03, -.60159400E+03, -.18368900E+04, -.30256600E+04, 0.15222700E+04, 0.14311000E+04, 0.15124100E+04, 0.35046200E+03, 0.27132300E+03, 0.88129300E+03, 0.94899200E+02, 0.88167000E+03, 0.48614200E+03, 0.14039300E+04, -.82257000E+03, 0.40808300E+03, 0.84254000E+02, 0.41148800E+03, -.85712100E+02, -.84611200E+02, 0.88743600E+02, -.10083400E+04, -.10697300E+03, 0.81091500E+02, 0.86332200E+02, -.29721000E+04, 0.15054300E+04, 0.16921900E+04, 0.14870300E+04, -.36287300E+03, -.84746200E+03, 0.15201500E+04, 0.14868000E+03, 0.26250200E+03, -.32559000E+03, 0.14599500E+04, -.33967400E+03, 0.16566400E+03, 0.56428000E+03, 0.17028500E+03, 0.23238500E+03, 0.51797700E+03, 0.14183100E+03, -.19503300E+03, -.48123100E+03, 0.45760100E+03, 0.17009100E+03, 0.83889200E+03, -.45602900E+03, -.37964200E+03, -.41835100E+03, -.16440000E+03, 0.10135200E+03, -.71983200E+03, -.13046500E+04, -.91257800E+03, 0.20745500E+03, -.65047700E+03, -.13109800E+02, -.91351600E+02, -.23025200E+03, -.14136500E+03, -.26470800E+03, -.58757200E+03, -.60311300E+03, -.11878200E+03, 0.23503500E+03, -.42262200E+02, -.79410500E+03, -.18969600E+03, 0.27329700E+03, 0.35480400E+02, -.29566700E+03, -.13656100E+03, -.91590600E+03, 0.13316900E+02, -.56102600E+03, 0.31177100E+03, -.76345800E+03, 0.14641900E+03, -.44016600E+02, -.10393500E+03, -.13609100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16041500E+01, -.45490800E+00, -.42229900E+01, 0.85792200E+00, -.37861800E+01, -.44093000E+00, -.14882400E+01, -.15653900E+01, 0.50739800E+01, 0.88326500E+00, 0.28703100E+00, -.34059000E+01, 0.20280500E+01, 0.68243000E+00, -.10038200E+01, 0.10281600E+01, 0.17639300E+01, 0.27908500E+00, 0.35070200E+00, 0.10666800E+01, 0.18546100E+01, -.10197600E+00, -.26211000E+00, 0.19054300E-01, -.15039000E+00, -.16702700E-01, -.10124500E+00, -.17166500E-01, -.16993500E+00, 0.10075900E+01, 0.46918300E+00, -.45932600E-02, 0.17455000E+00, -.50745700E+00, -.24797400E+00, 0.88072200E+00, 0.71638800E-02, -.34041000E-02, -.87852400E-01, -.26616900E+00, -.10214700E+01, -.33159300E+00, 0.62761200E+00, -.12426700E+00, 0.52637200E+00, 0.10234500E+00, 0.11483800E+01, -.71150200E-02, 0.56674700E+00, -.19689400E+00, -.14508000E+01, 0.66813200E+00, -.15506200E+00, 0.84063200E+00, -.88332100E-02, 0.41916600E+00, 0.31293500E+00, 0.12060800E+01, -.87391700E-01, -.57940800E+00, 0.49550500E-02, -.40881000E+00, -.17247100E-01, 0.19043500E+01, -.25320800E+01, 0.40440200E+00, -.29304000E+00, -.45355200E+00, 0.69620800E+00, -.60639400E-01, 0.26111200E+01, -.14529800E+01, 0.10471800E+01, -.29348200E+00, -.10765500E+00, 0.37411800E+00, 0.79056000E-01, -.62867100E+00, 0.30957700E+00, 0.48638800E+00, 0.90853900E-01, -.32295700E-01, 0.88273200E+00, 0.12702800E+01, 0.15042000E+01, -.94217300E-01, -.78340200E-02, 0.13993500E+00, -.36315100E+00, 0.36710600E+00, -.34438700E+00, 0.80746700E-01, -.35886100E+00, 0.25713500E+00, 0.37891100E+00, -.13568300E+00, 0.11708000E+01, 0.93937400E+00, 0.50918700E+00, -.34932100E-02, -.14312000E+00, -.57501700E-01, 0.46316600E-02, -.21072300E+00, 0.33996200E+00, 0.31462500E+00, -.12300000E+04, 0.42007300E+03, 0.50565300E+03, -.74068700E+03, 0.25303100E+03, -.12434700E+03, -.81432900E+03, -.12652800E+03, -.31948000E+03, -.47235100E+03, 0.13456000E+03, -.29770000E+03, -.30127100E+02, -.46706500E+03, 0.56487000E+03, -.26598400E+04, 0.13257600E+04, 0.15054800E+03, 0.13301000E+04, 0.11380400E+04, 0.37778300E+03, 0.89625000E+03, -.78945300E+02, 0.40311200E+02, 0.59657500E+02, 0.20992600E+03, -.96959200E+03, 0.47149200E+03, 0.67815300E+03, 0.48529200E+03, 0.66710700E+03, 0.78631200E+03, -.39710400E+03, -.25440000E+03, 0.59378300E+02, 0.84246600E+03, -.82312100E+02, 0.52988800E+03, -.27493400E+03, -.19382300E+04, -.26485400E+03, -.68136000E+03, -.22672800E+04, 0.65389200E+03, 0.88856300E+03, 0.23990500E+04, -.21412200E+04, -.20219500E+04, -.51799300E+02, 0.32558700E+02, -.10333700E+03, 0.26287500E+02, 0.22159300E+03, -.31043500E+01, -.17439600E+03, -.26818900E+03, 0.19620100E+03, 0.52782100E+02, -.10235400E+03, 0.26673000E+03, -.14331600E+03, -.21191600E+03, -.13174900E+03, 0.29273400E+03, 0.61164200E+03, -.42117700E+03, 0.57446000E+03, -.38931300E+03, 0.59014900E+03, 0.32326500E+03, -.32513800E+04, 0.16102400E+04, -.33483200E+02, 0.16255400E+04, -.49287200E+03, -.11600400E+03, 0.98498200E+03, 0.11275800E+04, 0.15149100E+04, -.59056800E+03, 0.22335400E+04, 0.17820400E+04, -.88340200E+03, 0.14946100E+04, -.89111700E+03, 0.50577100E+03, 0.13517600E+04, -.51128200E+03, -.25349500E+03, -.21807600E+04, 0.13448900E+04, -.10848700E+03, 0.15270800E+04, -.75137100E+03, -.36714000E+04, -.76481200E+03, -.18245900E+04, -.14740500E+04, 0.14440800E+04, 0.22142000E+04, 0.17726700E+04, -.13051300E+04, 0.93781300E+03, -.70514000E+03, 0.35556300E+03, -.44164600E+03, 0.35282200E+03, -.14018000E+03, -.20104700E+03, 0.58083400E+03, 0.11902600E+04, 0.75790400E+03, -.83725100E+03, 0.44481600E+03, -.17629300E+04, 0.86459000E+03, -.43479900E+03, 0.88134300E+03, -.32746200E+03, -.84279900E+02, 0.74061200E+03, 0.10795300E+04, 0.95448800E+03, -.23182600E+03, 0.13940700E+04, 0.20580400E+04, -.10283200E+04, -.19600400E+04, -.10296000E+04, 0.13279200E+04, 0.54598200E+03, -.60394200E+03, 0.76938900E+03, 0.43262700E+03, 0.37011000E+03, -.26589300E+04, 0.89981700E+03, -.45396900E+03, 0.25942800E+03, -.45020500E+03, 0.64682300E+03, 0.84066700E+03, -.10977500E+04, -.42102800E+03, -.53465700E+03, 0.85686000E+03, -.70864000E+03, -.50113300E+03, 0.25356400E+03, -.98781600E+03, 0.24989900E+03, -.78714200E+03, -.69145900E+03, 0.12385200E+04, 0.13989500E+04, 0.11495100E+04, -.51653300E+03, 0.15468700E+04, 0.15217000E+03, -.10622200E+03, -.14129800E+03, -.25893400E+03, 0.16055000E+03, -.37559200E+03, -.39744600E+03, -.21197800E+03, 0.13833600E+03, 0.10355800E+03, 0.11925200E+03, 0.53964500E+03, -.27349900E+03, 0.39911400E+03, 0.17361000E+02, -.21098700E+03, 0.71424300E+02, 0.13547800E+03, -.51225500E+02, -.13403400E+03, 0.17567000E+03, -.31246300E+03, 0.67412000E+02, -.75214500E+02, -.14084200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.49824600E+00, -.13768700E+00, -.15590200E+00, 0.36383400E+00, 0.65911300E-01, -.10533400E-02, -.40252800E+00, -.23630500E+00, 0.11187300E+01, 0.75060700E-01, -.20774900E-01, -.47935400E-01, -.36944500E+00, -.27449300E+00, -.34309900E+00, -.20951300E+00, -.56021700E-01, -.54145700E-01, 0.18568800E+00, -.48684700E+00, -.51827700E+00, -.64886500E-02, 0.21106900E+00, 0.23839800E+00, 0.17744700E-01, 0.18979400E-01, -.68250200E+00, 0.21670200E-01, 0.69024400E-01, 0.37959300E+00, 0.86651200E-01, -.34994700E+00, 0.25785600E-01, -.27900500E+00, -.27400600E+00, -.16434000E+00, -.27088900E-02, 0.75741000E-01, -.42022600E-01, -.32718500E+00, -.17924400E+00, -.14615900E+00, 0.27372300E+00, 0.33119200E-01, 0.13150800E+00, -.18435500E+00, -.14952600E+00, 0.45608900E-03, 0.22031500E+00, -.36357400E+00, 0.10616700E+00, 0.19400200E+00, -.83153100E-01, -.16123400E+00, 0.13399200E+00, -.17835700E-01, 0.27184500E+00, 0.46159900E+00, -.11777500E-02, 0.19527600E-02, 0.60578300E-01, 0.13602600E+00, 0.57196600E-01, -.10666900E+00, 0.90067200E-01, -.20505300E-01, 0.19475700E-01, 0.24879700E+00, 0.16613800E+00, 0.27823900E-01, -.26426600E+00, 0.15906400E-01, -.13729300E+00, -.87440400E-01, -.35678900E-01, -.15701200E-02, -.69834400E-02, -.19563900E+00, -.12787600E+00, -.41464600E-01, -.18249500E-01, -.95066900E-01, 0.11155600E-01, -.44724200E+00, 0.15559200E-01, -.12247600E-01, -.15096100E+00, 0.34924500E-01, 0.21507400E-01, 0.25217700E-01, -.12942500E+00, 0.39140100E-01, -.41370200E+00, 0.16591700E+00, 0.22434500E-01, 0.40552300E-01, 0.38156500E+00, 0.19717900E+00, 0.25816400E-01, 0.48618400E+00, 0.43154800E-01, 0.26850300E+00, -.47109200E-03, 0.65461600E+00, -.36039000E+00, 0.73897500E-01, -.24741200E+00, 0.43696300E+03, -.27537600E+03, -.16424200E+03, 0.56375000E+03, -.28052900E+03, -.11813300E+03, -.28187400E+03, 0.13371500E+03, 0.49520100E+03, -.30520100E+03, -.34589400E+03, -.19659400E+03, 0.49282700E+03, -.30025000E+03, -.12633200E+04, 0.63277600E+03, -.13711800E+02, 0.63171200E+03, 0.20805500E+03, 0.39663700E+03, 0.31197300E+03, 0.91566700E+02, 0.18942400E+03, 0.42784500E+03, 0.86842900E+02, -.25938900E+03, 0.12928500E+03, -.23128900E+02, 0.12984900E+03, -.22865600E+03, -.71020100E+03, 0.40331300E+03, 0.65505300E+03, 0.18602200E+03, -.71364400E+03, 0.12016800E+03, -.18586700E+04, 0.92745200E+03, 0.37152500E+03, 0.92936600E+03, -.29884200E+03, -.81184100E+03, 0.77747800E+03, 0.46225600E+03, 0.97060800E+03, -.72864200E+03, 0.35388700E+03, 0.22484600E+03, -.98791600E+02, -.24597200E+02, -.11204200E+03, -.12253000E+02, -.43713100E+02, 0.44013000E+00, 0.36890400E+02, -.55774100E+02, -.48242700E+02, -.17110300E+03, 0.98474000E+03, -.48910300E+03, -.36954900E+03, -.49184500E+03, 0.17363400E+02, -.24390500E+03, -.11120500E+03, 0.19999300E+03, -.27160400E+03, -.56031600E+02, -.14929100E+03, -.71964500E+03, 0.36182400E+03, 0.66692600E+03, 0.35977400E+03, 0.38079400E+03, -.11133500E+03, 0.25880900E+03, 0.19157800E+02, 0.96868600E+02, 0.11400700E+02, 0.58184200E+03, 0.15009800E+04, -.74979500E+03, -.36191800E+03, -.75051900E+03, 0.19596400E+03, 0.65763100E+03, -.67930400E+03, -.37446900E+03, -.70957900E+03, 0.55411200E+03, -.23133100E+03, 0.12017500E+04, -.60226100E+03, -.28971600E+03, -.60128000E+03, -.24009300E+03, -.35651000E+03, -.38147500E+03, -.23217400E+03, -.11018300E+03, -.25215300E+03, -.65572300E+02, -.63751300E+03, 0.31603900E+03, 0.35246600E+03, 0.31883600E+03, 0.31566400E+02, 0.17267600E+03, -.48223600E+02, -.15397000E+03, -.14435500E+03, 0.39346000E+03, 0.25624000E+03, -.58341900E+03, 0.29374500E+03, -.18379700E+03, 0.29167100E+03, 0.21653000E+03, -.22901400E+03, 0.36292400E+03, -.14873900E+03, 0.26929700E+03, -.27527800E+03, 0.21255300E+03, -.11458600E+04, 0.56806600E+03, 0.33024900E+03, 0.57274800E+03, 0.75944900E+02, -.35007800E+03, 0.27521200E+03, -.19198700E+02, 0.67208000E+03, -.28143800E+03, 0.48353100E+03, 0.48615600E+03, -.24199300E+03, 0.78180300E+02, -.24316500E+03, 0.12623500E+03, 0.33440200E+03, -.32055500E+03, 0.46310600E+02, -.94360800E+02, 0.28634600E+03, -.93464600E-01, -.31987900E+01, 0.74336800E+01, -.18470200E+03, 0.13909100E+01, 0.69393200E+02, -.55033100E+01, -.78455600E+01, -.53524300E+03, 0.14725800E+03, 0.38486500E+02, 0.28517000E+02, 0.56050600E+02, -.55030800E+02, -.97196700E+02, -.10847100E+03, 0.91633600E+01, -.19038400E+03, -.19550600E+03, -.10966500E+03, 0.97140200E+02, 0.24327400E+02, -.24968600E+03, -.12927900E+03, 0.20967800E+03, -.17480400E+02, -.15731100E+03, -.10426800E+03, -.27535300E+03, 0.18248000E+02, -.27078600E+03, 0.12352900E+03, -.36374300E+03, 0.46600500E+02, 0.16127000E+00, -.69275900E+02, -.15532700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.60222100E+00, 0.57538900E+00, 0.99468300E+00, 0.14327500E+01, 0.42885200E+00, -.16146800E-01, -.32226500E+00, -.65119700E+00, 0.11223600E+00, 0.22584800E+00, 0.13837100E+00, 0.11458300E+01, -.48109900E+00, 0.20698400E+00, -.30594400E+01, -.76544500E+00, 0.66631300E-01, 0.52130300E-02, 0.48933000E+00, -.35791100E+00, -.11124600E+01, -.11803500E+00, 0.89408500E-01, -.12068800E+01, 0.32024600E-01, -.25507000E+00, 0.93490800E-01, 0.39870800E+00, -.19974200E+00, -.26652900E+00, 0.52898700E+00, 0.19710400E+00, -.88263400E+00, -.35716500E+00, -.72427100E+00, -.85370800E+00, -.10189400E+00, -.15981200E+01, 0.64740200E+00, -.96761000E+00, 0.57149400E+00, 0.54010500E+00, 0.47522100E+00, 0.22315800E-01, -.19668800E+00, -.12389500E-01, 0.10045700E+00, -.17819000E-01, 0.58490000E+00, -.85160100E-01, -.29356500E+00, -.89922100E+00, 0.13301400E+00, -.95921300E-02, -.18008100E+00, 0.14094100E+00, 0.26093900E+00, 0.37140000E+00, -.54279200E-01, -.25003000E+00, 0.76958500E-01, -.15876400E+00, 0.15411400E-01, 0.85899300E-01, 0.66457700E+00, -.31341800E-01, 0.26000700E-01, 0.12182100E+00, -.43482200E+00, 0.28058900E+00, 0.11697200E+01, 0.82308600E+00, 0.10825200E+00, -.28908700E+00, -.37006500E+00, 0.36508600E+00, 0.87462700E-01, 0.59653900E+00, 0.26468500E-01, 0.11023100E+00, -.24518700E+00, 0.16214800E+00, 0.74656300E-01, -.35779000E-01, 0.59435700E+00, 0.61605600E+00, -.18901200E+00, -.14103200E+00, 0.29854100E-01, -.60526400E-01, -.67000200E+00, -.13722000E+00, 0.37040200E+00, -.28329900E-01, 0.80324300E+00, -.83097100E+00, -.25496500E+00, -.99541100E+00, -.96744100E-01, -.66843700E+00, 0.95834500E-01, -.11488100E-01, -.14881200E-01, 0.76739100E+00, 0.14589300E+00, 0.34426000E+00, -.11256400E+00, -.31873600E+00, 0.51669100E+03, 0.14744000E+03, -.60067800E+03, 0.30162300E+03, -.27222600E+03, 0.30033400E+03, -.21943300E+03, -.69023900E+03, 0.46438300E+03, 0.64614900E+03, 0.41900700E+03, -.77379300E+03, 0.74066500E+03, 0.19489600E+04, -.97799600E+03, 0.34731400E+03, -.97454500E+03, -.17921200E+03, -.35340100E+03, 0.27160000E+01, 0.41405800E+03, -.10200800E+04, -.54759500E+03, -.99752500E+02, 0.15659000E+03, -.81896800E+02, 0.35621100E+02, -.78481000E+02, 0.53765700E+03, 0.11484700E+04, -.70300500E+03, -.11598700E+04, -.43130600E+03, 0.12787100E+04, -.42987200E+03, 0.29476500E+04, -.14762600E+04, -.23331300E+04, -.14738500E+04, -.29940900E+01, 0.72677400E+03, -.86943900E+03, -.19062700E+03, -.22469100E+03, 0.63045300E+03, -.10307500E+04, -.28267300E+03, 0.16664100E+03, -.14768400E+03, 0.14164900E+03, 0.11640000E+03, 0.65844100E+02, -.28194200E+02, -.28772300E+01, 0.20814100E+03, 0.81614700E+02, 0.99319600E+02, -.12453400E+04, 0.61572300E+03, 0.44260400E+03, 0.62381300E+03, 0.28431900E+03, 0.36703000E+03, 0.16609000E+03, -.10391900E+03, 0.17334000E+03, 0.13073600E+03, -.19368100E+03, -.16063900E+03, 0.72220300E+02, -.10154100E+04, 0.80357400E+02, -.71091200E+03, -.15917500E+01, -.64385100E+02, -.15044100E+03, 0.23037000E+03, -.32821100E+03, -.29941400E+03, -.16345000E+04, 0.81952000E+03, 0.16867400E+04, 0.81727700E+03, -.15098800E+03, -.91718900E+03, 0.97379100E+03, 0.39920500E+03, 0.12889800E+03, -.75588600E+03, 0.43733500E+03, -.88035300E+03, 0.44679400E+03, -.65831500E+03, 0.44058700E+03, -.16321600E+03, -.45413000E+02, 0.45081000E+03, 0.24219600E+03, 0.98743900E+03, -.74677400E+02, -.24730500E+03, 0.69318500E+03, -.34257900E+03, -.60390400E+03, -.34667000E+03, -.24251400E+03, -.20698300E+03, 0.55596700E+02, 0.18523300E+03, 0.28464100E+03, -.66237300E+03, 0.53399800E+02, 0.84076400E+03, -.43271200E+03, -.14311900E+03, -.42034100E+03, -.43483000E+03, 0.34378100E+03, -.37210900E+03, 0.42579600E+03, -.33670600E+03, 0.28138000E+03, -.49088500E+03, 0.24457500E+04, -.12198000E+04, -.10872600E+04, -.12227100E+04, 0.57442000E+02, 0.77824700E+03, -.55900900E+03, 0.24565000E+03, -.55462000E+03, 0.60789000E+03, -.15487500E+04, -.25400600E+02, 0.97728400E+01, -.83175700E+02, 0.12797600E+02, 0.21609300E+03, 0.13114700E+03, -.15376700E+03, -.59665100E+02, -.53064000E+02, 0.13840300E+03, -.29731800E+03, -.30848100E+03, 0.15673500E+03, -.56706300E+02, 0.15446700E+03, -.35610300E+03, -.44197200E+03, 0.55274200E+03, 0.10767600E+04, 0.56130600E+03, -.43183600E+03, -.82970300E+02, -.11396900E+02, -.39516900E+02, 0.49976500E+02, 0.18788700E+02, 0.67645400E+02, 0.13220000E+03, 0.13535000E+03, 0.46249300E+02, -.51119900E+02, 0.24268600E+02, 0.37796200E+03, 0.39809400E+03, -.33667600E+03, 0.20284900E+03, -.17262800E+02, 0.39914600E+02, 0.44545300E+03, 0.62160300E+02, 0.13085600E+03, -.16702200E+03, 0.48172300E+03, -.18608200E+03, 0.62462800E+02, -.16251300E+02, 0.13288600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.90190300E+00, 0.66147900E+00, -.15600800E+01, -.24375100E+01, -.13298100E+01, 0.12291600E+00, 0.12805800E+01, -.57236600E+00, -.31381900E+01, -.73141900E+00, 0.36346600E-01, -.39281300E+00, -.19982400E+01, -.10242100E+01, 0.80504800E-01, -.93348700E+00, -.11595700E+00, 0.13199100E+01, -.78686900E-01, 0.29931300E+01, 0.46992200E+00, -.67704800E-01, 0.17767100E-02, 0.10398000E+01, 0.22567900E+00, -.13662000E+00, 0.16923600E+01, -.11789000E-01, 0.77351000E+00, -.19873900E+01, -.32940000E+00, -.84754300E+00, -.26051100E+00, 0.15983600E+01, -.85266400E-01, -.89034500E+00, -.50214300E-01, 0.40344100E+00, -.18275400E+00, 0.11902100E+01, 0.17112300E+00, 0.42745700E-01, -.67356300E+00, -.81272200E-01, -.33969200E+00, 0.55793100E+00, -.68029100E+00, -.47681200E-02, 0.31340600E+00, 0.10946500E+00, 0.19043400E+00, -.88694400E+00, 0.20540400E+00, 0.20154200E+00, 0.15198000E-01, -.31231100E+00, -.31182000E+00, -.53403400E+00, 0.24444700E-01, 0.55207200E+00, 0.16367200E-01, 0.10595800E+00, 0.11309900E+00, -.10971300E+00, 0.10041900E+01, -.17211500E+00, 0.14331500E+00, 0.89782700E+00, -.19430100E+00, 0.20851600E-01, -.57752600E+00, 0.79877100E+00, -.28441800E+00, -.59426200E-01, 0.18504900E+00, -.51727900E+00, 0.76603500E-01, 0.94683500E+00, 0.75206000E-01, -.34846200E+00, -.18057500E+00, -.19103400E+00, -.32554500E+00, -.41070800E+00, -.22791500E+01, 0.11128800E+01, -.21113300E-01, -.25737500E+00, 0.13571100E+00, 0.13929100E+00, 0.47874200E-01, -.12936700E+00, 0.11320800E+01, -.28664000E+00, 0.28541500E+00, 0.22061800E-01, 0.35438200E+00, -.19068400E+01, -.23663500E+00, 0.40728000E+00, 0.93133500E-01, -.11687000E+00, -.11397200E-02, 0.12902500E+01, 0.39714600E+00, 0.12610200E-01, -.60839300E+00, 0.20010100E+00, -.14428700E+00, 0.10834700E+04, 0.99916400E+03, -.50270200E+03, -.11184100E+03, -.49957200E+03, -.26385100E+03, -.23096200E+02, 0.14860000E+03, 0.92999100E+03, -.23014500E+03, -.81880500E+02, -.10004400E+04, -.21161800E+03, 0.10950000E+03, -.10605000E+04, 0.10582100E+03, -.10317700E+03, -.50995400E+03, 0.56012200E+01, -.20157400E+03, 0.50009300E+03, -.55724700E+03, 0.80354600E+03, -.77239600E+03, 0.38587200E+03, 0.50416200E+02, 0.38624000E+03, 0.33184700E+03, 0.50366800E+02, -.30395000E+03, -.11428000E+04, -.13960400E+03, 0.23617100E+03, 0.10859700E+04, 0.31812600E+04, -.15873700E+04, -.52246300E+02, -.15906100E+04, -.11253200E+04, -.28050600E+03, -.38022900E+03, -.27252400E+03, -.13207900E+04, 0.62263100E+02, -.21173800E+04, 0.38197200E+03, -.17608900E+03, -.31595200E+02, -.19102400E+03, -.28010300E+01, -.72934400E+02, -.52734100E+02, 0.12869700E+03, 0.27311400E+00, -.21853800E+02, -.12424600E+03, -.10594500E+04, 0.53988800E+03, 0.41313200E+03, 0.52977500E+03, 0.18611800E+03, 0.46967100E+03, -.14654100E+03, -.54612400E+03, -.45075600E+03, 0.51298600E+03, -.20197500E+03, -.29111600E+03, 0.15598600E+03, 0.56997100E+03, 0.14553200E+03, -.44504600E+03, -.25786400E+03, 0.62665600E+03, 0.11924600E+04, 0.56137800E+03, -.54021800E+03, -.31728700E+03, -.16248300E+04, 0.80993900E+03, -.26964700E+03, 0.81240300E+03, 0.81589400E+03, 0.34730700E+03, -.56427000E+02, 0.11357700E+03, 0.73749900E+03, 0.24138500E+02, 0.17174500E+04, -.10830400E+04, 0.53202700E+03, 0.34210500E+03, 0.54135800E+03, -.22760600E+03, 0.39635300E+03, 0.17250600E+03, 0.74059100E+02, 0.20148400E+03, 0.41969200E+03, 0.12778700E+03, 0.26946000E+03, -.14163700E+03, -.27508100E+03, -.13469700E+03, -.22114500E+03, -.33547700E+03, 0.51795900E+02, 0.11911700E+03, 0.42043100E+03, -.39800700E+03, -.40063500E+03, -.15374900E+04, 0.77933900E+03, 0.35052400E+03, 0.76872900E+03, -.18903500E+03, -.51822200E+03, 0.84738400E+03, 0.10277700E+04, 0.63538100E+03, -.67287700E+03, -.45521200E+03, -.11559200E+04, 0.56964600E+03, 0.32112200E+03, 0.57787900E+03, -.51803900E+03, -.33934600E+03, 0.93477300E+02, -.59306400E+03, 0.21763100E+03, -.18603900E+03, 0.20132700E+03, 0.29486800E+03, -.14268600E+03, 0.50021800E+02, -.14744900E+03, -.70043400E+02, -.14016200E+00, -.31947700E+02, -.19897200E+03, -.32278100E+03, 0.16693900E+02, 0.16515000E+02, 0.83627200E+01, 0.62831300E+01, -.17109900E+03, -.42512000E+01, -.26430400E+03, -.90667500E+02, 0.31583400E+03, 0.96662300E+03, 0.26490100E+03, -.20775400E+03, -.82438500E+03, -.81710500E+01, 0.11314000E+02, -.22608200E+02, -.41491500E+02, -.89074200E+02, -.20130700E+02, -.32176000E+02, -.42126000E+02, 0.21522300E+02, -.10226100E+02, -.19264900E+03, 0.50152800E+03, -.60768300E+02, 0.20481500E+03, 0.30723900E+03, -.34688600E+02, -.20699000E+03, 0.13700100E+03, 0.23415000E+03, -.12282400E+03, -.82540000E+02, -.34717000E+03, 0.32663400E+02, 0.36881700E+01, 0.19726000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17547200E+00, -.26764700E+00, -.69807100E+00, -.35159100E+00, -.49125400E+00, -.39141900E-01, -.20571400E-01, -.47661900E+00, -.10518400E+00, -.12329000E+00, 0.50442800E-01, 0.30331200E+00, 0.15042000E+01, -.12735100E-01, -.10198200E+00, -.80919200E-01, 0.34869400E-01, -.12907400E+00, 0.72071800E-01, -.17055000E+00, 0.17781300E+00, 0.42451500E-01, -.11745500E+00, -.63284800E-01, -.11326500E-01, -.41583900E-01, -.47942500E-01, 0.60550400E-01, 0.46530200E-02, 0.62152200E-01, 0.52239800E-01, 0.75997400E-01, -.62243100E-01, -.88203200E-01, 0.33826500E-01, 0.41174800E-01, -.22944800E-02, 0.59906700E-01, 0.21002500E-01, 0.90375900E-01, 0.70459100E-01, 0.94773200E-01, -.21995400E+00, -.14850700E-01, -.21686300E-01, 0.63154200E-01, -.11854700E+00, 0.24964000E-03, 0.86467200E-02, -.63179800E-01, -.16127200E+00, 0.10112000E+00, -.18472500E-01, -.79125100E-01, -.77277200E-01, 0.15095500E-01, -.79534500E-01, 0.53073700E+00, -.16271000E-02, -.10325700E+00, -.22082100E-01, -.66520100E-01, -.12072000E-02, 0.80267300E-01, 0.17585400E+00, -.23148800E-01, 0.55452600E-01, -.11908900E+00, -.13501400E+00, 0.23358300E-01, 0.27256500E+00, 0.31721600E+00, 0.57169600E-01, -.12807200E-01, -.45002300E-01, 0.12063400E+00, 0.30035200E-01, -.16829000E-01, 0.76532600E-01, 0.21751800E-01, -.49573100E-01, -.64508500E-01, 0.83419500E-01, 0.36872500E-01, 0.31982600E+00, -.25725900E-01, 0.11795700E-01, 0.96373700E-01, -.68050800E-02, 0.11570600E+00, -.24163200E+00, -.46616000E-01, -.12919600E+00, -.14165500E+00, 0.29436500E+00, -.23116900E+00, 0.23781000E-01, 0.21418000E+00, -.52705000E-01, 0.12041200E+00, 0.95682400E-01, 0.13478700E+00, -.94475900E-02, 0.34340200E-01, 0.15596000E+00, -.26707500E-01, 0.73234600E-01, 0.12638200E+00, -.15521800E+00, 0.15616700E-01, -.30240100E+03, 0.15211700E+03, 0.35759600E+03, 0.15119000E+03, -.35722300E+02, -.10747700E+03, 0.25975000E+03, 0.28735100E+03, 0.16474500E+03, -.84307000E+02, 0.71018700E+01, -.66692000E+03, 0.33291500E+03, 0.89887300E+02, 0.33333200E+03, 0.22155500E+03, 0.17956500E+03, -.51900200E+02, -.21097000E+03, -.19962100E+02, 0.16384400E+03, 0.33085300E+03, 0.39348600E+03, -.19611400E+03, -.44012100E+03, -.19711500E+03, 0.44072300E+02, 0.17653200E+03, -.41396900E+03, -.46147200E+03, -.24718400E+03, 0.13895100E+03, 0.82138800E+02, -.13744400E+04, 0.68754800E+03, 0.15446500E+03, 0.68715100E+03, 0.41574700E+03, 0.28520400E+03, 0.13297100E+03, 0.21094800E+02, 0.39997400E+03, 0.26723400E+03, 0.58681600E+03, -.60587100E+02, 0.29158400E+02, 0.69987600E+02, 0.30329200E+02, 0.48329700E+01, 0.40809100E+02, -.48286000E+02, -.68637100E+02, -.83284100E+01, 0.36048500E+02, 0.79774000E+02, -.54434900E+02, 0.26811900E+02, -.39045700E+02, 0.27693400E+02, -.47975200E+02, -.73398400E+02, 0.70002000E+02, -.23648500E+02, -.92928700E+01, -.61530100E+02, -.20704000E+03, 0.17706800E+03, -.89078900E+02, 0.15793400E+03, -.88423200E+02, -.48650300E+02, 0.15637400E+02, -.23444200E+02, 0.11166900E+03, -.80997600E+02, 0.49688600E+02, -.57173700E+03, 0.10833000E+04, -.54200200E+03, -.10060700E+03, -.54158000E+03, -.26394500E+03, -.21047700E+03, -.18424000E+03, -.18983400E+02, -.36485700E+03, -.16701900E+03, -.54625400E+03, -.26791300E+03, 0.13467900E+03, -.21248200E+02, 0.13491200E+03, -.50801800E+02, 0.67692500E+02, 0.33537700E+02, -.13825900E+03, 0.24023300E+03, 0.63387300E+02, 0.10495000E+03, -.11154700E+03, 0.56019500E+02, -.62311200E+02, 0.55585600E+02, -.63445500E+02, 0.51067300E+01, -.21110100E+02, -.39097400E+02, 0.42579500E+02, 0.21282800E+02, 0.12104900E+03, 0.23942200E+02, -.12570100E+02, -.15175700E+02, -.11879500E+02, -.72356400E+02, 0.33679100E+02, 0.48866700E+02, 0.86157600E+02, -.24904900E+02, 0.54115500E+02, -.16816800E+03, 0.24015700E+03, -.11963400E+03, 0.49299000E+02, -.11965000E+03, 0.59066100E+02, 0.20611200E+03, -.17302700E+03, -.22397000E+02, -.18449500E+03, 0.19697900E+03, -.30059900E+03, 0.14202600E+03, -.71172100E+02, -.66258400E+02, -.70813700E+02, 0.32657000E+02, 0.20350500E+02, -.35248800E+02, 0.18529200E+01, -.43954100E+02, -.42782000E+02, -.76191900E+02, -.55685600E+02, 0.27235700E+02, 0.92470700E+02, 0.28337400E+02, -.16902300E+02, 0.29467600E+02, 0.72401200E+02, 0.11749700E+03, 0.16856900E+03, 0.59468500E+02, -.98788500E+02, -.30069200E+02, 0.66066600E+01, 0.69286800E+02, 0.79600500E+02, -.21368200E+02, 0.31963100E+02, 0.26416000E+02, 0.74412800E+02, -.69227200E+02, -.15528400E+02, -.24089200E+02, 0.97630100E+02, -.15633900E+02, 0.12537600E+02, -.16099600E+03, 0.74011600E+02, -.21987000E+02, 0.13746900E+01, -.17262400E+03, -.34699000E+02, -.46582600E+02, -.46112000E+02, 0.21201200E+02, -.21174800E+02, 0.26330000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13623500E+01, -.68420700E+00, -.13717200E+01, -.17885000E+01, -.17858600E+01, -.75080900E-01, 0.14219800E+01, 0.34216200E-01, -.39876800E+01, -.10269400E+01, -.18194300E-01, 0.24352100E+01, -.12597600E+01, -.11798500E+01, 0.20501800E+01, -.23891500E+01, -.17074800E+01, 0.25361800E+00, 0.18351300E+01, 0.49686700E+00, -.30565400E+01, 0.13828300E+00, -.55008700E+00, 0.17712800E+01, 0.65202000E-02, 0.24054900E+00, 0.21936600E+01, -.70668100E+00, 0.52610100E-01, -.14404400E+01, 0.44363500E+00, -.37529500E-02, -.19088200E+00, 0.24563900E+01, -.12113300E+01, -.29667200E+01, -.10621500E+00, -.17801800E+00, 0.41172400E+00, 0.10533900E+01, 0.12271200E+01, 0.22675800E+00, -.79984600E+00, -.15897100E-01, -.94121300E+00, 0.31526200E+00, -.76367000E+00, -.62017300E-02, 0.23847000E+00, -.41059000E+00, -.18551500E+00, 0.12604000E+01, -.79631900E-02, 0.46478800E+00, 0.26457400E+00, -.40457000E-01, 0.46651600E+00, 0.91734600E+00, 0.14476100E-01, 0.10782200E+00, 0.26907300E+00, 0.16253900E+00, 0.10346700E+00, -.11562000E+01, 0.24236200E+01, -.22244000E+00, 0.37231800E+00, -.60449400E-01, -.64190600E+00, 0.57348800E-01, -.12108500E+00, 0.33076400E+00, -.37553200E+00, -.11274300E+00, -.49291900E+00, 0.15977000E+00, -.57291200E-01, -.60514600E+00, -.28388900E+00, -.36071200E+00, -.52469600E-01, 0.33439200E-01, 0.14968900E+00, 0.83670400E+00, 0.37990200E+00, -.69030900E+00, 0.71519700E-01, 0.91189900E+00, -.32751900E+00, -.46505300E+00, 0.10962100E+01, 0.51612600E-01, -.34328400E+00, -.10995600E+00, -.26470300E+01, 0.20744300E+01, 0.15902200E+01, 0.22476400E+01, 0.18380800E+00, 0.80637100E+00, -.77162700E+00, 0.16506900E+00, 0.91555400E-03, 0.18238000E+01, 0.10333800E+01, 0.84725500E-01, -.90886100E-01, 0.18918400E+01, 0.24764500E+00, 0.35383900E+00, 0.45833800E+01, -.22645200E+02, -.10945600E+04, 0.72556600E-01, 0.25075400E+03, -.53885800E+03, -.10027800E+04, -.19467100E+04, -.58306000E+03, -.48617700E+03, 0.10421900E+03, 0.49146800E+04, -.24680300E+04, -.73469500E+03, -.24568300E+04, -.17796900E+04, -.18462700E+04, 0.14702200E+03, 0.11348900E+04, 0.87563600E+03, -.17422200E+04, -.33177900E+04, -.31031900E+03, 0.15550500E+03, 0.17446300E+04, 0.15665800E+03, -.46828900E+03, 0.13499000E+03, 0.20001200E+04, 0.30662900E+04, 0.11479400E+04, 0.10266300E+03, -.57804300E+03, 0.11192600E+04, -.57145900E+03, 0.30486400E+04, -.55936400E+03, 0.39700800E+03, 0.35957800E+03, -.90722600E+03, -.14472900E+04, -.64766400E+03, 0.17903100E+03, -.20823000E+04, 0.13710200E+03, -.72418100E+02, -.21648300E+03, -.69622700E+02, -.86938100E+02, -.44251700E+02, 0.20478900E+03, 0.38105500E+03, 0.51306800E+02, -.60955400E+02, -.21427000E+03, -.58678400E+03, 0.30423800E+03, 0.38785700E+03, 0.28830700E+03, -.36725800E+03, 0.14586200E+03, -.95359700E+02, -.11338600E+03, 0.38175700E+03, -.13716800E+03, 0.24056600E+04, 0.20704500E+04, -.10351200E+04, -.18684700E+04, -.10356500E+04, -.21594000E+03, 0.28623800E+03, -.88678100E+03, -.10492000E+04, -.80072900E+03, 0.37349800E+03, 0.16556400E+04, -.32891700E+04, 0.16525500E+04, -.15444600E+04, 0.16443100E+04, -.39137100E+03, -.14948200E+02, 0.11525900E+04, 0.83816900E+03, 0.15079900E+04, -.59728800E+02, 0.31530800E+04, -.13271300E+03, 0.70035200E+02, 0.12548600E+04, 0.62576400E+02, 0.12207100E+04, 0.59758500E+03, -.20483200E+03, 0.17870400E+03, -.23267500E+04, 0.52249000E+03, 0.94138200E+03, 0.12594100E+04, -.64249400E+03, -.15061500E+03, -.62896700E+03, 0.34530600E+03, -.17788100E+03, 0.28818300E+03, 0.50366300E+03, -.61054500E+03, -.65036200E+02, -.14944500E+04, 0.14998000E+04, -.74281800E+03, 0.55456400E+03, -.75026200E+03, 0.52058600E+03, 0.17356800E+03, -.10894000E+04, -.11207000E+04, -.62942900E+03, 0.33706900E+03, 0.53841800E+03, -.39400000E+04, 0.19455000E+04, 0.17927100E+04, 0.19683300E+04, 0.58954500E+02, -.79601300E+03, 0.83279100E+03, -.47578400E+03, 0.16454200E+04, -.77389500E+03, 0.25669700E+04, -.17289400E+04, 0.86774600E+03, -.15647200E+03, 0.86370600E+03, -.48588600E+03, -.99412200E+03, 0.79604100E+03, 0.27217000E+03, 0.11941400E+04, -.67089800E+03, 0.10225100E+04, 0.75987400E+03, -.34382300E+03, 0.22686400E+03, -.38189600E+03, 0.57752400E+03, 0.32387000E+03, -.97746500E+03, -.13033000E+04, -.19708900E+04, 0.20758000E+03, 0.39719200E+03, 0.74236100E+02, 0.18804200E+03, -.65852700E+02, -.80012100E+02, 0.78605400E+02, 0.30842300E+03, 0.34504000E+03, -.89167700E+02, 0.65340000E+02, 0.28974400E+02, 0.54144500E+03, -.10696300E+04, -.10727700E+03, -.47243100E+03, 0.93243000E+03, -.92143600E+02, 0.61184300E+03, -.18659900E+03, 0.10989300E+04, 0.47540200E+02, 0.74249100E+03, 0.51628300E+03, -.90220100E+02, 0.33368600E+03, -.13199400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15375400E+01, -.17792400E+00, -.17330900E+01, 0.90850200E+00, -.47746600E+00, -.79973100E-01, -.83604200E+00, -.42661700E+01, -.12601400E+01, -.35003000E+00, 0.14215100E+00, 0.22470600E+01, -.31509000E+01, -.17314200E+01, -.34070800E+01, -.23820200E+01, -.10181200E+01, 0.14518300E+01, -.40566400E+00, 0.16997600E+01, -.27209900E+01, -.27263500E+00, 0.42366700E+00, 0.59364500E-01, 0.42338500E+00, -.80101800E-01, -.47551300E-01, 0.22848100E+00, 0.11417600E+01, 0.28767300E+01, 0.29212900E+00, 0.65814000E+00, -.42082900E-02, -.12578600E+01, 0.97212600E-01, 0.15651100E+01, 0.10358800E+00, 0.10150200E+01, 0.14910200E+00, -.11688200E+01, 0.29569900E+01, 0.13594800E+01, -.74965800E+00, 0.33471400E+00, 0.70589700E+00, -.80443700E-01, 0.60474400E+00, 0.14634400E-01, 0.13492400E+01, 0.83685500E+00, 0.65316100E-03, 0.23263600E+01, -.15571700E-01, 0.67657200E+00, 0.10474600E+00, 0.27993000E+00, -.13507000E+01, -.16901300E+01, -.28077200E-01, 0.11117500E+00, -.25598400E+00, -.64992500E-01, 0.53226900E-01, 0.24398400E+01, -.27386000E+01, 0.17518000E+00, 0.22088400E+00, 0.34025000E+01, 0.24968300E+00, -.52926700E-01, -.40993400E+01, -.66133700E+00, -.55130800E+00, -.81555700E+00, 0.59469800E+00, -.44351800E+00, -.19464800E+00, 0.36135000E+00, -.12984100E+00, -.70673500E-01, 0.11477400E+00, -.67906100E-01, -.48499400E+00, -.41762100E+00, 0.51900900E+00, -.24872100E+00, -.16631200E+00, 0.43000300E+00, 0.15341300E+00, 0.12874800E+00, 0.61902400E+00, 0.18344000E+00, 0.34294700E+00, 0.16940500E+00, -.23629200E+00, 0.22485800E+00, -.39874800E+00, 0.62680400E+00, -.30809900E+00, -.57607200E+00, -.81945400E-01, -.92144500E-01, 0.17812700E-01, -.10902500E+01, 0.80826300E+00, 0.22150900E+00, 0.55543600E-01, 0.11044300E+01, 0.90351000E+00, -.29382200E+00, -.31785000E+01, 0.39056300E+00, 0.16276100E+04, -.40754500E-01, -.53378000E+03, -.75699100E+03, 0.11509000E+04, 0.18134100E+04, 0.19023300E+03, -.74192200E+03, -.10673700E+04, -.42453400E+04, 0.21217000E+04, 0.32758900E+02, 0.21222800E+04, 0.12949300E+04, 0.74396000E+03, -.45811200E+03, -.15030400E+04, 0.29646400E+03, 0.54696500E+03, 0.29386000E+04, 0.64652500E+03, -.31790200E+03, -.19306600E+04, -.32441200E+03, 0.40518000E+03, 0.99860400E+03, -.19396200E+04, -.26140800E+04, -.79072700E+03, 0.98225300E+03, 0.13734800E+04, -.44454900E+04, 0.22291800E+04, 0.11175300E+04, 0.22225400E+04, 0.18160900E+04, 0.15392300E+04, 0.10534900E+03, -.17038100E+03, 0.68491000E+03, 0.16695700E+04, 0.96240700E+03, 0.21471200E+03, -.98194400E+02, 0.47386000E+03, -.10679200E+03, -.14805100E+03, -.63811300E+02, -.75273600E+02, -.39557800E+02, -.16992500E+03, -.42717400E+02, 0.21281900E+03, -.16321200E+04, 0.82336300E+03, 0.31892500E+03, 0.81818300E+03, 0.66241900E+02, 0.37185100E+02, 0.27411100E+03, -.56744400E+03, -.68104500E+02, -.90847000E+02, -.83902900E+03, 0.11016200E+04, -.54457400E+03, 0.99785600E+03, -.55047400E+03, 0.13008400E+03, -.79121000E+02, 0.20369800E+03, 0.14862000E+04, -.84210500E+02, -.23040100E+03, -.33157200E+04, 0.41787900E+04, -.20930500E+04, -.10156400E+04, -.20891800E+04, -.10166900E+04, -.82206700E+03, -.10323500E+04, -.10794000E+03, -.11689400E+04, -.82426200E+03, -.13379400E+04, -.28529100E+04, 0.14232800E+04, 0.44660000E+03, 0.14293900E+04, -.25843800E+03, 0.85101600E+03, 0.26216300E+03, -.70522900E+03, 0.13902800E+04, 0.89979100E+03, 0.45587700E+03, 0.31130300E+03, -.16094500E+03, -.84210500E+03, -.15622600E+03, -.71683000E+03, -.28650500E+03, -.12898300E+03, 0.12976500E+01, 0.16276400E+03, -.12429000E+03, 0.51194600E+03, -.72857200E+03, 0.37280200E+03, 0.31602600E+03, 0.36456700E+03, -.41434800E+02, -.38546600E+02, 0.68485700E+03, 0.11886200E+04, 0.34960100E+03, -.13767300E+03, -.88126800E+03, 0.15147800E+04, -.76403000E+03, -.55254900E+02, -.75608600E+03, 0.19050600E+02, 0.91778000E+03, -.12297200E+04, -.50764400E+03, -.13179100E+04, 0.92395500E+03, -.21549200E+04, 0.70864300E+03, -.35022200E+03, -.42108100E+03, -.35371800E+03, -.11568700E+03, -.15562400E+03, 0.44401800E+02, -.14558100E+02, -.33094400E+03, -.46203400E+03, -.24897800E+03, -.31441900E+03, 0.17009900E+03, 0.57645200E+03, 0.15872700E+03, 0.11864000E+03, 0.14807500E+03, 0.52684600E+03, 0.14141100E+04, 0.11037500E+04, 0.12219200E+03, -.99745800E+03, -.20941300E+03, 0.87243700E+02, 0.39268500E+03, 0.46443200E+03, -.15755500E+03, 0.24873200E+03, 0.20584700E+03, 0.40943200E+03, -.39418600E+03, -.12403000E+03, -.15392100E+03, 0.61043600E+03, -.20997800E+03, 0.21044200E+02, -.50126600E+03, 0.42363600E+03, -.10821500E+03, 0.46230000E+02, -.63741200E+03, -.32544200E+03, -.14621200E+03, -.37139300E+03, 0.69926700E+02, -.88876100E+02, 0.30256600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12326500E+01, -.43973700E+00, -.17502100E+00, -.13931400E+01, -.27460500E+00, 0.26766600E-01, 0.11166700E+01, 0.79416400E+00, -.13054100E+01, -.28202200E+00, -.12703700E+00, 0.74589100E+00, -.13361500E+01, -.79019200E+00, -.16842600E+01, -.11942900E+01, 0.40395700E+00, 0.64493300E+00, -.48352900E+00, 0.10121800E+01, 0.59705600E+00, 0.81082600E-01, -.32843900E+00, 0.59031300E+00, 0.87461500E-02, -.65085200E-01, 0.24144900E+01, 0.46413600E+00, 0.31323300E+00, -.29242800E+00, 0.43881000E+00, 0.47406100E+00, -.29816700E+00, 0.30367200E-01, -.45054400E+00, -.63127500E+00, 0.17369600E-01, -.14874100E+01, 0.82393300E+00, 0.10791900E-01, 0.97052000E+00, 0.86956600E+00, -.45500700E+00, -.45316300E-01, 0.50800100E-01, 0.19965700E+00, 0.21798100E+00, 0.69051900E-02, 0.29349500E+00, -.12223100E+00, -.65225900E+00, -.28126300E+00, -.13693700E+00, -.26258700E+00, -.18687800E+00, -.17778100E+00, -.25170100E+00, 0.10193100E+01, -.29036800E-01, -.58082600E-01, 0.27911100E-01, -.46256600E+00, 0.10554000E+00, 0.13228400E+01, -.47292400E+00, 0.12631900E+00, -.51517300E-01, 0.40616700E-02, 0.22385500E+00, -.94359100E-01, 0.14611700E+01, -.93459900E-01, 0.51104500E+00, -.18433200E-01, -.10047700E+00, -.57887200E+00, 0.73038300E-01, -.34539900E+00, -.23220100E+00, -.23778300E+00, -.56109300E-01, 0.32598300E+00, -.23765000E-01, 0.23321500E+01, -.30834900E+00, 0.25533300E+00, -.16273000E+00, 0.36657400E+00, 0.25646500E+00, 0.34261700E+00, -.15864100E+00, 0.16373100E-01, -.36758500E+00, 0.42781300E+00, 0.41986700E+00, -.45128600E+00, -.98095000E+00, -.10042100E+01, -.21477700E+00, 0.14455000E+00, 0.16111400E+00, 0.20011900E+00, 0.10260900E-01, -.12541300E+01, 0.19866900E+00, -.21202800E+00, 0.26233500E-02, -.35368700E+00, -.38481700E-01, 0.27598300E-02, 0.32403000E+00, 0.71017800E-01, 0.14407700E-01, 0.55932300E+01, -.84462100E+02, -.21651000E+01, 0.17992700E+03, 0.47214000E+03, 0.95392500E+02, -.13948400E+02, -.56212900E+03, 0.30640800E+03, -.15268400E+03, -.38243500E+03, -.15317600E+03, -.31795900E+03, -.26827900E+03, 0.10696900E+03, 0.33271900E+03, 0.18857100E+03, -.25751800E+03, 0.29938900E+03, -.35962500E+03, 0.18121200E+03, 0.41836700E+02, 0.17991000E+03, 0.13766800E+03, 0.93354100E+02, -.13182900E+03, -.52137100E+03, -.54397700E+02, 0.96006500E+02, 0.69606500E+03, 0.15226800E+04, -.75990300E+03, -.59045300E+03, -.76132100E+03, -.14645200E+03, 0.10417600E+03, -.39786200E+03, -.13364700E+03, -.59091400E+03, -.15481400E+02, -.65120800E+03, -.81731600E+02, 0.49614900E+02, -.89642700E+01, 0.40202800E+02, 0.19454900E+02, 0.30159800E+02, 0.71322400E+00, -.73991800E+01, 0.32637600E+02, 0.28519200E+02, 0.68633400E+02, -.40818500E+02, 0.23267800E+02, 0.45084700E+02, 0.19939500E+02, 0.69746900E+02, 0.91651800E+02, -.48193900E+02, -.70590200E+02, -.87296900E+02, 0.67696400E+02, -.62963500E+02, 0.47338500E+03, -.23377600E+03, -.17863900E+03, -.23672800E+03, -.17116400E+03, 0.92744800E+02, -.19470800E+03, -.10049100E+03, -.13111900E+03, 0.57282500E+02, 0.20020800E+03, -.52052000E+03, 0.25905600E+03, 0.15582000E+03, 0.26024100E+03, 0.91098500E+01, -.13107800E+01, 0.16520600E+03, 0.11835800E+03, 0.24687300E+03, -.13424100E+02, 0.43038700E+03, -.58684200E+03, 0.29120700E+03, 0.28935300E+03, 0.29313900E+03, 0.24451400E+03, 0.27633500E+03, -.13133600E+03, -.35988500E+03, -.77894800E+02, 0.24024600E+03, -.18005900E+03, -.63283200E+02, 0.29855300E+02, 0.61149200E+02, 0.31696900E+02, -.73270300E+02, 0.21747800E+02, -.14036100E+02, -.41903200E+02, 0.16024800E+02, 0.13727100E+02, 0.17215600E+03, -.13900600E+03, 0.72027700E+02, -.34713000E+02, 0.69477400E+02, -.34039800E+02, 0.71207500E+01, 0.52015500E+02, 0.13028800E+03, 0.91914600E+02, -.86588600E+00, -.16309400E+03, 0.60565000E+03, -.30523200E+03, -.35502900E+03, -.30295200E+03, -.26131600E+03, 0.58772600E+00, -.78152700E+02, -.25629400E+02, -.17546000E+03, -.14098300E+03, -.52186800E+02, 0.22497200E+03, -.11119500E+03, -.11807200E+03, -.11252000E+03, -.58307400E+02, -.99963500E+02, 0.31290300E+02, 0.44265500E+02, 0.54562200E+01, -.96787100E+02, 0.34053300E+02, -.32593400E+03, 0.16664900E+03, 0.85104500E+02, 0.16283300E+03, 0.43926800E+02, -.19643800E+02, 0.12597600E+03, 0.12639800E+03, 0.16709800E+03, -.27692100E+02, -.14004800E+03, 0.25696000E+01, 0.81064600E+00, 0.18222400E+02, 0.22003700E+02, 0.41739800E+02, 0.39328700E+02, 0.38456300E+02, 0.26063300E+02, -.18882700E+02, -.17244700E+01, 0.23619600E+02, 0.18108900E+03, 0.23796300E+02, 0.31454400E+02, 0.91707000E+02, 0.23855600E+02, 0.17417600E+02, 0.13924700E+00, 0.12430500E+03, 0.44417800E+01, 0.18694300E+02, -.31670300E+02, -.19250300E+01, 0.61484400E+01, 0.50665700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.31225800E+01, 0.58232600E+00, -.68868000E+01, 0.70153500E+00, -.44261300E+01, -.35111400E+00, -.25470100E+01, -.40213300E+01, 0.47671500E+01, 0.87756400E+00, 0.36150500E+00, -.10153600E+01, -.84245900E+00, 0.43822800E+00, -.89043100E+01, -.21422100E+01, 0.39112000E+00, 0.13796500E+01, -.44897400E+00, 0.15775200E+01, -.51265900E+01, -.11343900E+00, 0.18284100E+01, -.29611000E+00, 0.10951500E+01, 0.47053400E-01, 0.53156800E+01, 0.79480700E+00, 0.10703400E+01, 0.96178400E+00, 0.96554000E+00, 0.63713300E+00, 0.20571900E+00, -.17769100E+00, 0.88449900E+00, 0.43497200E+00, 0.95772700E-01, 0.11673700E+01, 0.36012800E+00, 0.57103100E+00, 0.37118900E+01, 0.23046300E+01, -.29972500E+01, 0.27459900E+00, -.30954900E+00, -.57842500E+00, -.40474000E+00, 0.22034000E-01, -.11257400E+01, 0.55873500E+00, -.18037100E+00, 0.54691100E+00, -.22995400E+00, -.13047100E+01, -.27456300E+00, 0.10965300E+00, -.22648000E+01, 0.27006500E+00, -.49808500E-01, 0.49250100E+00, -.52129600E+00, -.77371100E+00, -.44934600E+00, 0.16997500E+01, -.23305600E+00, -.15530400E-01, 0.65335700E-01, -.19604700E+01, -.19906600E+01, 0.25297700E-01, 0.10085200E+01, 0.90075700E-01, 0.48561300E+00, -.11294700E+01, 0.12238400E+00, 0.15168000E+00, 0.23142900E+00, 0.29942500E+01, -.35906100E+00, -.56736700E+00, -.47099700E+00, -.13945800E+01, -.21393400E+01, -.38583700E+01, -.19583800E+01, -.22060600E+00, 0.11897800E+00, 0.38084400E+00, 0.24349800E+00, -.78152000E+00, -.28376700E+01, -.16729000E+00, -.17818700E+01, -.76227300E+00, -.32925800E+01, 0.23192800E+01, -.14832100E+01, 0.21333000E+00, -.33697800E+00, 0.34799400E+01, 0.33080500E+00, -.42989700E+00, 0.27904600E-01, 0.53727000E+01, 0.14191600E+01, 0.77957200E+00, -.13700500E+01, 0.35013900E+01, 0.11022300E+01, -.64877000E+00, -.12756400E+02, -.52885700E+00, 0.16059200E+01, 0.70504300E-02, -.12703300E+04, -.25957400E+04, 0.13360600E+04, 0.10073800E+04, -.33329000E+03, -.23072000E+04, -.66163600E+03, 0.22797900E+04, -.11448800E+04, -.23543400E+04, -.11401100E+04, -.10409200E+04, -.36883700E+04, 0.29273300E+04, 0.44271400E+03, 0.17357900E+04, -.35328800E+04, -.28132700E+04, -.98193500E+03, 0.46566700E+03, 0.83543600E+03, 0.49039400E+03, 0.15410500E+04, 0.29288000E+04, -.14274800E+04, -.18355400E+04, 0.50326100E+03, 0.27223700E+04, 0.13491500E+04, -.23694800E+05, 0.11828600E+05, 0.13820300E+05, 0.11847300E+05, 0.18077000E+04, 0.10326400E+04, 0.29310300E+04, -.41284500E+04, 0.54159100E+04, 0.30564700E+04, 0.92373700E+04, -.93622500E+02, 0.17871600E+02, 0.47961800E+03, 0.46325700E+02, 0.35611000E+03, 0.54436500E+03, -.63003900E+03, -.74895300E+03, -.43507100E+02, 0.61534900E+03, 0.13426700E+03, -.29185100E+04, 0.14579200E+04, 0.64099700E+03, 0.14561000E+04, -.12552700E+04, 0.59376900E+03, 0.12228300E+03, -.70599900E+03, 0.11571200E+04, 0.33951800E+03, 0.30748900E+04, 0.23757800E+04, -.11944100E+04, -.19734400E+04, -.11877000E+04, -.23677900E+04, 0.84872000E+02, -.33845400E+02, -.33500300E+03, -.62409800E+03, 0.19599100E+02, 0.89219700E+03, 0.16039200E+05, -.80002500E+04, -.86335400E+04, -.80194600E+04, -.75433000E+03, -.68458500E+03, -.17067000E+04, 0.31310200E+04, -.39044300E+04, -.19578800E+04, -.74884300E+04, -.23449100E+04, 0.11755100E+04, -.83301800E+03, 0.11739800E+04, 0.30991400E+03, 0.21611400E+04, -.11755200E+04, 0.13061800E+04, -.70269500E+03, 0.17880200E+04, 0.30307000E+04, 0.80828400E+03, -.41008100E+03, -.16717300E+04, -.40444800E+03, 0.13679500E+03, -.11146600E+04, 0.66127400E+03, 0.59537300E+03, -.39120300E+03, -.10666500E+04, -.15668700E+04, -.99128400E+03, 0.49127300E+03, 0.55123400E+03, 0.49578800E+03, -.93384600E+03, -.15630100E+03, 0.34017600E+03, -.70569900E+03, -.55703400E+02, 0.25475800E+03, 0.21386200E+04, -.12878800E+05, 0.64304400E+04, 0.61163800E+04, 0.64401200E+04, 0.21082000E+04, 0.81817000E+03, 0.13807400E+04, -.19405800E+04, 0.23850700E+04, 0.21427700E+04, 0.43748000E+04, -.20175200E+04, 0.10077900E+04, 0.40322100E+03, 0.10091400E+04, -.22464800E+02, -.10674700E+04, 0.82157100E+03, 0.96652900E+02, 0.99093000E+03, -.83328500E+03, 0.43114600E+03, 0.11738600E+04, -.57443600E+03, -.71059900E+03, -.58613300E+03, -.22885200E+03, 0.10743300E+04, -.13972200E+04, -.10613300E+04, -.23844300E+04, 0.99788500E+03, 0.13074500E+04, 0.61646500E+02, 0.24735700E+03, 0.93469500E+02, -.46887800E+01, 0.15065600E+03, 0.38154500E+03, 0.38415800E+03, -.82364000E+01, -.10283600E+03, 0.48210100E+02, 0.50543100E+03, 0.11799900E+04, -.13823900E+04, 0.41252800E+03, 0.84911700E+03, -.14871800E+02, 0.52544900E+03, -.10011400E+02, 0.90655700E+03, -.11054600E+04, 0.84385600E+03, 0.16759600E+03, -.34385100E+03, 0.38411900E+03, 0.76211800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18293000E+01, -.10675600E+01, -.20247900E+01, 0.18132900E+01, -.21702500E+01, -.43773600E+00, -.15448200E+01, -.15015900E+01, 0.38508600E+01, 0.71334300E+00, 0.14034500E+00, -.80755900E+00, 0.90987900E+00, 0.76505900E+00, -.66846900E+00, -.68410100E+00, 0.40808300E+00, 0.39348200E+00, 0.68762000E+00, 0.12483300E-01, -.39345500E+00, -.10013600E+00, 0.52560500E+00, 0.12178200E+01, 0.40441500E-01, 0.65710200E-01, -.10728000E+01, -.14862800E+00, 0.32258800E+00, 0.11904700E+01, 0.15310000E+00, -.10438400E+01, 0.57748400E+00, -.25819100E+00, -.11340800E+01, -.53194200E+00, -.34830100E-01, -.29647900E+00, -.22154200E+00, -.84084400E+00, -.78833600E+00, -.36477900E+00, 0.12589800E+01, 0.19885300E-01, 0.51202200E+00, -.36475000E+00, 0.52938800E+00, -.97435500E-02, 0.48168100E+00, -.19332800E+00, 0.80288900E-01, 0.13873500E+01, -.53788100E-01, 0.69482000E+00, 0.34385000E+00, 0.11016900E+00, -.98386700E-01, -.18297300E+01, -.11209000E+00, 0.79342200E+00, 0.19542800E+00, 0.47059100E+00, -.39632000E-01, 0.10457400E+01, -.19360500E+01, 0.28114900E+00, 0.99653000E-01, 0.17924500E+01, 0.11348000E+01, -.11790500E+00, 0.82328000E+00, -.19523500E+01, 0.38963300E+00, -.25380800E+00, 0.19748900E+00, -.69999900E+00, 0.21330700E-01, 0.41477800E+00, 0.10843500E+00, -.52589300E+00, -.50472000E-01, -.81768300E+00, 0.25084800E-01, -.24471800E+00, -.29281300E+01, 0.20111200E+00, 0.39383500E+00, 0.17876400E+00, -.13328500E+00, 0.74081000E+00, -.53224000E-01, -.16290500E+00, 0.11602000E+00, -.58237300E+00, 0.18331400E+01, -.22794600E+01, -.24695600E+01, 0.33218700E-03, -.66372500E+00, 0.35409400E+01, -.28773900E+00, -.37206400E-01, 0.16412100E-01, 0.24221900E+01, 0.40279200E+00, -.58722700E+00, -.30846000E+00, 0.13351800E+01, -.21827500E+01, 0.21286000E+00, 0.41011800E+01, 0.57540500E+00, -.14621500E-01, 0.67617500E-02, 0.24011400E+00, 0.14687000E+04, 0.50214900E+03, 0.22168700E+04, 0.59152800E+03, 0.99722200E+03, 0.34803300E+03, 0.33444100E+04, -.16801000E+04, 0.19515200E+03, -.16722700E+04, 0.24847000E+03, 0.35981400E+03, -.10246700E+04, 0.23619800E+04, 0.50938800E+02, -.11334400E+03, 0.69937900E+03, -.31315300E+03, 0.16501600E+03, -.24129000E+03, 0.15640800E+03, 0.37274200E+03, -.13475400E+04, -.81667600E+03, -.27854300E+04, -.82505300E+03, -.81543100E+03, -.21788100E+03, 0.17473000E+05, -.87192400E+04, -.39314600E+04, -.87364900E+04, -.46182500E+04, 0.49841300E+03, -.17292300E+04, 0.19759200E+04, -.71020600E+04, -.82457200E+02, -.20890500E+04, 0.84784100E+03, -.37102600E+03, -.59367000E+03, -.42406300E+03, -.16536800E+03, -.50075300E+03, 0.31694300E+03, 0.64555000E+03, 0.19563100E+03, -.45813400E+03, -.59084800E+03, -.67505600E+02, 0.20344400E+02, 0.27616700E+03, 0.35317400E+02, 0.12662700E+04, 0.45889200E+03, -.44256100E+03, -.49983500E+03, -.57054300E+03, 0.52055000E+03, -.14302200E+03, -.43317400E+03, 0.20594900E+03, -.22728400E+02, 0.21656500E+03, 0.46100900E+03, -.15589800E+03, 0.86038100E+02, 0.30401800E+03, 0.61264900E+03, -.36693900E+03, -.29246100E+03, -.11476000E+05, 0.57303500E+04, 0.18941000E+03, 0.57380000E+04, 0.27654300E+04, -.72566900E+03, 0.12573800E+04, -.14153100E+04, 0.49173100E+04, -.45156500E+03, 0.26920300E+04, 0.86059200E+03, -.42056500E+03, 0.10561600E+04, -.43015300E+03, -.32245700E+03, -.21974200E+03, -.82042600E+02, -.23164600E+04, -.18247000E+04, 0.29024400E+03, -.24681000E+04, -.12025800E+04, 0.61465500E+03, 0.14427400E+04, 0.60127100E+03, -.29140000E+03, 0.23468300E+03, 0.29261500E+03, 0.19524200E+03, 0.50194600E+03, 0.12388100E+03, 0.88741800E+03, -.48572100E+03, 0.22565200E+03, -.30438500E+03, 0.24288400E+03, 0.61950400E+02, -.39540900E+03, 0.14843400E+03, 0.37605900E+03, 0.39870500E+03, -.56068000E+03, -.13674600E+04, 0.63664000E+04, -.31686000E+04, -.31409100E+04, -.31832000E+04, -.21437500E+04, -.39186900E+03, -.36202900E+03, 0.51621000E+03, -.25023800E+04, -.77447600E+03, 0.50177000E+03, 0.16815800E+04, -.84268400E+03, 0.22661200E+03, -.84067100E+03, 0.49300100E+02, 0.20950100E+03, 0.48626000E+02, 0.26104400E+03, -.67233600E+03, 0.81799000E+02, -.10006700E+04, -.98665600E+03, 0.49813300E+03, 0.24321700E+03, 0.49347200E+03, -.99267200E+02, -.54307600E+03, 0.11391100E+04, 0.66024500E+03, 0.94158100E+03, -.42096100E+03, -.14165600E+04, -.64892000E+02, -.11432900E+03, -.32945400E+03, -.36123500E+03, 0.68524400E+02, -.33364500E+03, -.34654500E+03, -.35096900E+03, 0.32860200E+03, -.56564600E+02, -.21843600E+03, 0.10421800E+04, 0.42358900E+03, 0.61139000E+03, -.15205400E+03, -.32756200E+03, -.24630300E+03, 0.31216500E+03, -.71603300E+02, 0.43291400E+03, -.22889600E+03, -.30918900E+03, -.54766500E+02, -.11468300E+03, -.84722500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13432000E+00, 0.10898100E+00, 0.12674600E+00, -.15678500E+00, -.12955500E+00, -.53478600E-01, 0.26804200E+00, 0.10958700E+00, -.43500100E+00, -.17859400E-01, -.63973600E-01, -.39248700E+00, 0.40932200E+00, 0.93994900E-01, -.18844900E-01, -.46278800E+00, 0.15059600E+00, 0.16984100E+00, -.41001800E-01, 0.23283700E+00, 0.67356000E-01, -.21125500E-01, -.19786300E+00, -.58146300E+00, -.13974700E-01, -.27198600E-01, 0.68296200E+00, -.15892100E-01, 0.26088100E+00, 0.59703600E+00, 0.25911400E-01, -.17904300E+00, 0.24170500E+00, -.69416900E-01, -.39443300E-01, 0.61644500E-01, 0.62664400E-03, 0.50391100E+00, -.10136000E+00, 0.33655300E+00, -.10890300E-02, 0.50757900E-01, -.33814200E+00, 0.65971600E-02, -.91153800E-01, 0.71239500E-01, -.51741800E-01, 0.28650900E-03, 0.76900700E-01, -.36028200E+00, -.30347300E+00, 0.82581800E+00, -.71707200E-01, 0.58837400E-01, 0.27545200E-01, 0.12653300E-01, -.12512600E+00, 0.88539900E+00, -.25078900E-02, 0.32142900E-01, -.26770500E-01, 0.32423500E-02, -.45073100E-01, 0.97550700E-01, -.21730000E-01, 0.26942600E-01, -.54316700E-02, -.77906800E-01, -.12072500E+00, 0.49558500E-02, 0.82854900E-01, 0.11459400E+00, 0.32020400E-01, -.23000600E-01, -.22043700E-01, 0.62372900E-01, 0.23856100E-01, 0.48972800E-01, 0.35301900E-01, 0.45143600E-01, -.11478000E-01, 0.82635500E-03, -.25578000E-01, -.45187800E-01, 0.80753400E-01, 0.48873900E-01, -.39026000E-01, -.17448900E-01, -.40220300E-01, 0.15052900E+00, -.20428600E+00, 0.11709100E-01, 0.23068800E-01, 0.10329200E-01, 0.13284000E+00, -.90403800E-02, 0.25863900E+00, 0.24949200E-01, 0.55944100E-01, -.49068600E-01, 0.39648600E-01, -.37976200E-01, -.78438800E-03, 0.10840400E+00, -.21514100E+00, -.16244300E-01, 0.56688400E-01, 0.11593100E+00, -.25522700E-01, 0.16334400E+00, 0.29232000E+00, -.11757300E+00, -.12260000E+00, -.60012400E-04, -.24958300E-01, -.28916100E-01, -.72070000E+02, -.18148000E+03, -.46396700E+02, -.49634900E+02, -.21870800E+02, -.15881800E+02, 0.60213200E+01, 0.22383500E+03, 0.79644800E+01, 0.26284800E+02, 0.46567500E+02, -.10224300E+03, -.70276100E+02, 0.22369800E+02, 0.10840700E+02, 0.14549000E+02, -.48470400E+02, 0.24924300E+02, 0.10798700E+03, 0.24303200E+02, -.26298200E+02, -.27378400E+02, 0.11219700E+03, 0.22910400E+03, 0.87473300E+02, 0.19146400E+02, -.14748100E+02, -.23713500E+03, 0.11806100E+03, 0.62071400E+03, 0.11857900E+03, 0.16589700E+03, 0.96714500E+02, -.64536200E+02, -.13808700E+03, -.11311300E+02, 0.78883800E+02, -.16522800E+03, -.51772000E+02, 0.24325300E+02, 0.52754100E+02, 0.25895100E+02, -.97524300E+01, 0.14606700E+02, 0.41105700E+01, -.79378300E+01, -.31679500E+02, 0.13754700E+02, 0.40437700E+02, -.20890800E+03, 0.10308800E+03, 0.83715600E+02, 0.10400800E+03, 0.15205200E+02, 0.64555200E+00, 0.41356800E+02, -.36451400E+01, 0.13511000E+03, -.64199900E+02, 0.16143000E+03, 0.26758800E+03, -.13596300E+03, -.14023400E+03, -.13381100E+03, 0.48579400E+02, 0.35606500E+02, -.75427500E+02, -.50701200E+02, -.12472500E+03, 0.49104100E+02, 0.95544500E+02, -.14598000E+03, 0.73759800E+02, -.41409800E+03, 0.72978100E+02, -.10194100E+03, -.60164500E+02, 0.75872700E+02, 0.63350700E+02, 0.11031600E+03, -.40639300E+02, 0.24273400E+03, 0.33610600E+03, -.16551900E+03, 0.89226400E+01, -.16821300E+03, 0.18898800E+02, -.57573900E+02, -.99806100E+01, 0.62207600E+02, -.22451000E+03, -.26037000E+02, -.25306300E+03, 0.30969200E+03, -.15420500E+03, -.89976300E+02, -.15481500E+03, -.42223500E+02, -.23051000E+02, -.83906600E+01, 0.79862200E+02, -.15976400E+03, 0.49549100E+01, -.14141800E+03, 0.19127100E+03, -.96766600E+02, 0.98225700E+02, -.95651600E+02, 0.11067000E+03, 0.28980300E+02, -.10800700E+03, -.79278100E+02, -.64252400E+02, 0.55934700E+02, 0.33751400E+02, 0.13769400E+02, -.68260200E+01, 0.84169000E+02, -.69531000E+01, -.17488700E+02, -.24429900E+02, -.35883100E+02, -.95786900E+01, -.39198100E+02, -.23280700E+02, -.25109100E+02, -.19808100E+03, 0.98533900E+02, -.55194800E+02, 0.99004200E+02, -.58155800E+02, -.64879000E+02, 0.77129500E+02, 0.10964800E+02, 0.87109000E+02, -.64667000E+02, 0.13389800E+03, 0.12479000E+03, -.60990200E+02, 0.97943500E+02, -.62481100E+02, 0.99845100E+02, 0.35343400E+02, -.10957000E+03, -.10996400E+03, -.16261500E+03, 0.35258000E+02, 0.26850500E+02, -.18716000E+02, 0.31314500E+02, 0.53075400E+01, 0.19027700E+02, -.39741100E+01, 0.34309800E+02, 0.38390100E+02, 0.16156600E+02, -.51659500E+01, -.17734600E+02, 0.59901700E+02, -.10563800E+03, -.23041600E+02, -.54560600E+02, 0.87265900E+02, 0.14627200E+02, 0.76865200E+02, -.23880200E+02, 0.99858300E+02, -.43968700E+01, 0.77379400E+02, 0.50256400E+02, -.99339700E+01, 0.24452300E+02, -.71846800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.48684000E+00, 0.24234500E+00, 0.70564200E+00, -.92662300E-01, -.73974800E+00, -.13430700E+00, 0.86871200E+00, 0.37939000E+00, -.10876100E+01, -.50674500E+00, 0.51982900E-01, -.50520500E+00, 0.89301500E+00, 0.18583500E+00, 0.88463200E+00, -.57221600E+00, -.92848600E-01, 0.29052700E+00, -.14445100E+00, 0.71929400E+00, -.56466400E+00, -.10496600E+00, -.11033400E-01, 0.61472300E-01, 0.10380400E+00, 0.10826200E+00, -.26301300E+00, -.22442300E+00, 0.91641100E-01, -.20909900E+00, -.78518500E+00, 0.30329400E+00, 0.67146100E+00, -.46027400E+00, 0.35146400E+00, 0.27142400E+00, 0.81446400E-03, 0.19669000E+00, -.40608400E+00, 0.77982600E+00, 0.23603000E+00, -.21527600E+00, -.10820800E+00, -.80809100E-01, 0.34925300E+00, 0.10528400E+00, -.87557600E-01, 0.13545900E-02, 0.32980900E+00, -.25657600E+00, 0.19782500E+00, 0.15299300E+00, -.10858000E+00, -.23733600E+00, 0.85863800E-01, -.10373800E+00, 0.22653600E+00, 0.21781500E+01, -.13519900E-01, -.57599800E+00, 0.15773500E-01, 0.14045300E+00, 0.88057200E-02, 0.20564900E+00, -.30819500E+00, -.19870500E-01, 0.62167700E-02, 0.76880000E+00, 0.43630800E+00, 0.23047600E+00, -.22174900E+01, -.18324900E+00, -.14341700E+00, 0.45904800E+00, 0.21165600E+00, -.39838800E-01, -.84294000E-01, -.71218200E+00, -.58063200E-01, 0.17550900E+00, -.36500900E-02, 0.66178400E+00, -.44709100E+00, -.99232000E+00, -.12751300E+00, -.71774700E-01, 0.24440100E-01, -.16026400E+00, 0.23405000E+00, -.93372800E+00, 0.17264500E+00, -.73876700E-01, 0.19784400E+00, -.15616700E+00, -.32230200E+00, 0.16121400E+00, -.81817600E+00, -.21520400E+00, 0.76315400E-02, 0.55619100E+00, 0.18366900E+00, -.18971600E+00, 0.52255700E-02, -.27645300E+00, -.52613100E+00, -.33395800E-01, -.14691600E+00, 0.56453000E+00, -.38802700E-01, -.20274300E+00, -.11636000E+01, -.24866200E+00, -.91051100E-01, 0.84857300E-03, 0.11386600E+00, -.24746400E-01, 0.10410100E+01, 0.19277200E+03, -.25909900E+02, 0.53644600E+02, -.69948000E+02, 0.70267900E+03, -.34817900E+03, -.68984700E+02, -.35138000E+03, 0.18826500E+02, -.61429100E+02, -.37326000E+03, -.36647300E+02, -.20964300E+02, -.58719200E+02, -.92012800E+02, 0.65352900E+02, -.30601700E+02, 0.39773900E+02, -.32789700E+02, -.36762300E+02, -.42184200E+02, -.16845600E+02, -.18699700E+03, -.14744700E+02, -.10338500E+03, 0.55547900E+02, 0.11081800E+04, -.55132400E+03, -.58895000E+03, -.55410400E+03, -.17646300E+03, 0.18393300E+03, -.11558500E+03, 0.13583600E+03, -.41236600E+03, 0.10441800E+03, -.79963700E+03, 0.24695400E+03, -.12494200E+03, -.61009500E+02, -.12329700E+03, -.58294000E+02, -.83071200E+02, 0.40826400E+02, 0.13216300E+03, 0.13896200E+02, -.81530800E+02, -.79613500E+02, -.47309600E+03, 0.24015700E+03, 0.22961300E+03, 0.23699900E+03, -.19263500E+01, 0.75524200E+02, 0.24673100E+02, -.30200500E+03, -.36250500E+03, 0.88992100E+02, -.56202000E+01, -.19961500E+03, 0.10530700E+03, 0.18545200E+03, 0.99827100E+02, -.26397600E+02, -.20343500E+03, 0.10530100E+03, 0.10664600E+03, 0.19124000E+02, -.21006300E+03, -.20600600E+03, -.14652200E+04, 0.72901800E+03, 0.60290600E+03, 0.73262600E+03, 0.26552100E+03, -.36914300E+02, 0.51095000E+02, -.22334100E+03, 0.48961800E+03, 0.56373800E+02, 0.73663400E+03, -.97191300E+03, 0.48047300E+03, 0.92939400E+03, 0.48619200E+03, 0.18398100E+03, 0.43042500E+03, -.29379200E+01, -.28755200E+03, -.21602700E+03, 0.42798100E+03, 0.16933900E+03, 0.41278000E+03, -.20764800E+03, -.19752800E+03, -.20643500E+03, -.35576500E+01, -.12932800E+03, -.49872700E+02, 0.70558300E+02, 0.57330000E+02, -.10182200E+03, -.17483400E+03, -.22772100E+03, 0.11900300E+03, 0.22002500E+03, 0.11388500E+03, -.19135400E+03, -.10066400E+03, 0.97749500E+01, 0.65178200E+02, 0.38879000E+02, -.14497800E+03, 0.56170400E+02, 0.79488600E+02, -.39467500E+02, 0.48590300E+02, -.39651400E+02, -.12847600E+03, 0.91168500E+02, -.49416400E+02, -.21433000E+02, -.14829400E+03, 0.10286700E+03, -.53236300E+03, -.17428700E+03, 0.88451500E+02, 0.18932100E+02, 0.87204600E+02, -.15186500E+02, -.85759400E+02, 0.20592500E+03, -.26668200E+02, -.18766200E+02, -.78945700E+02, -.10293000E+03, -.58571100E+02, 0.24538800E+02, 0.12448900E+03, 0.29419500E+02, -.15424200E+03, -.36579300E+02, 0.43424300E+01, 0.21988600E+03, 0.12222700E+02, -.97586000E+02, -.29291400E+02, -.25980400E+02, -.11483400E+02, -.18344500E+02, -.25592700E+02, -.89450700E+02, 0.84132000E+01, 0.98219500E+01, -.34083400E+02, 0.18922600E+02, -.72099700E+01, -.46525700E+02, 0.85805200E+02, 0.67468600E+01, 0.44509500E+02, -.12330300E+03, -.27882600E+02, -.17174500E+02, 0.51238500E+02, -.14763800E+03, -.13824800E+02, 0.43474700E+01, -.62588100E+02, 0.30301900E+02, 0.19525500E+00, 0.99898400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31497300E+00, -.17338500E+00, -.79089600E-01, -.29923100E+00, 0.25199200E-01, 0.42790000E-01, 0.39793500E+00, 0.18800300E+00, -.24507200E+00, -.13479300E+00, -.23807500E-01, 0.16854400E+00, -.49794600E+00, -.34935300E+00, -.76067400E-01, 0.17757000E-01, 0.91063200E-01, 0.54864200E-01, -.53929700E+00, -.32084100E-01, 0.20633700E+00, 0.21256100E-01, 0.24592300E-01, 0.49849800E+00, 0.26707900E-01, 0.96823100E-02, 0.40924000E+00, 0.62217500E-01, 0.63144800E-02, -.42365400E+00, 0.10062400E+00, 0.14826300E+00, -.11240800E+00, 0.14560000E+00, -.10121800E+00, -.45681100E+00, -.12251100E-01, -.59927800E+00, 0.24020100E+00, -.19525300E+00, -.18855700E+00, 0.78710200E-03, 0.34067300E+00, -.53754800E-01, 0.11460800E+00, 0.12016000E-01, 0.27282400E+00, -.21908800E-02, -.72834400E-02, 0.42753500E-01, 0.54387400E-01, -.50146200E+00, -.22923300E-01, -.92068500E-02, 0.20266400E-01, -.10303900E+00, -.22805300E+00, -.49998600E+00, -.58659700E-01, 0.22881400E+00, 0.36365500E-01, -.11005400E+00, -.27734500E-01, 0.41721000E+00, -.69764300E+00, 0.14503000E+00, -.11114000E+00, 0.30102900E+00, 0.35441100E+00, 0.10960100E-01, 0.11309100E+01, -.39975300E+00, 0.21341500E+00, -.10852600E+00, -.19732100E+00, -.27030700E+00, 0.17606400E-01, -.12208900E-01, -.11004200E+00, -.16475100E+00, -.45223000E-01, -.12815800E+00, -.35926200E+00, 0.52251500E+00, -.89738000E-01, -.28270200E+00, -.43824500E-01, 0.22330900E+00, 0.36239300E-01, 0.20733900E+00, 0.21161600E-02, 0.42017000E-01, -.11106700E+00, 0.19776300E+00, -.17020200E+00, -.82593900E-01, -.32353100E+00, 0.36470300E+00, -.10444100E+00, 0.29136000E-01, 0.21436800E-01, 0.24651500E-01, 0.92183300E-03, 0.19730100E-01, 0.12030200E-03, 0.25981500E-01, 0.99300700E-02, 0.27071400E-01, 0.11992300E+00, -.20208700E+00, 0.42467200E+00, 0.30084200E-01, -.25527200E-01, 0.11873200E-02, 0.50595700E-01, 0.11534400E+00, 0.16924500E+00, -.21108900E+00, -.52551900E+02, 0.54712300E+02, -.20371900E+03, -.24438900E+03, 0.12651200E+03, -.15177900E+03, 0.12224700E+03, -.10235400E+02, 0.23455400E+01, -.15288800E+03, -.28216300E+03, 0.10824400E+03, 0.50339200E+02, 0.97073900E+02, -.78918900E+02, 0.40093200E+02, 0.81450900E+02, 0.39608500E+02, -.33596600E+02, -.27175000E+02, 0.60480400E+02, 0.71040900E+02, 0.82163400E+02, -.88813400E+02, 0.21309300E+03, 0.11943600E+04, -.59561200E+03, -.74900700E+03, -.59715200E+03, 0.11180700E+03, 0.51161700E+02, -.27139700E+03, 0.13206300E+03, -.31193600E+03, 0.39478300E+01, -.10033300E+04, 0.82416000E+02, -.46665900E+02, 0.17011700E+02, -.41201300E+02, -.76821200E+01, -.11739400E+02, -.80183100E+01, 0.14861900E+02, -.13923200E+02, -.13572200E+02, -.26692700E+02, -.10583000E+03, 0.58017600E+02, 0.85427500E+02, 0.52924100E+02, -.36874300E+02, 0.28272400E+02, -.17497900E+02, -.12457400E+03, -.21169700E+03, 0.27384500E+02, -.75907200E+02, 0.60503900E+02, -.23505100E+02, 0.11843100E+03, -.30295200E+02, 0.75486700E+02, -.42518500E+02, 0.94912500E+01, 0.12351500E+03, -.47074200E+02, -.60310900E+02, -.13013900E+03, -.84497600E+03, 0.41986800E+03, 0.70443400E+03, 0.42246000E+03, 0.12623700E+01, 0.11396200E+03, 0.34031900E+02, -.15187100E+03, 0.20067500E+03, 0.12186300E+03, 0.69550000E+03, -.64611300E+03, 0.31646800E+03, 0.36048600E+03, 0.32267800E+03, 0.11823000E+03, 0.21742100E+03, 0.11245200E+03, 0.75572200E+02, 0.89012300E+02, 0.15608500E+03, 0.32694500E+03, 0.20884200E+03, -.10722800E+03, -.11908900E+03, -.10434700E+03, 0.16405200E+02, -.43736500E+02, -.19556900E+02, 0.16080500E+02, 0.97357900E+01, -.40902700E+02, -.61809800E+02, -.15653100E+03, 0.85071600E+02, 0.10629800E+03, 0.78228800E+02, 0.18624900E+02, -.30121300E+01, 0.14203200E+02, 0.70066800E+02, 0.63096300E+02, -.58407100E+01, 0.45279900E+02, 0.28150900E+02, -.15511300E+02, -.93940100E+02, -.14244800E+02, 0.53983000E+02, 0.49047500E+01, -.64248900E+02, -.12799700E+02, 0.25608500E+02, -.27062100E+02, -.27764300E+03, -.23954900E+03, 0.12159700E+03, -.34625700E+02, 0.11969100E+03, -.96224400E+02, -.13341800E+03, 0.11035700E+03, -.63749300E+02, 0.48997000E+02, -.10384000E+03, 0.18933000E+03, 0.82849500E-01, -.38300400E+01, 0.65656100E+02, -.23915600E+00, 0.30972500E+02, 0.92475800E+02, -.57710700E+02, 0.11337100E+03, -.65420100E+02, 0.49560500E+02, 0.12473100E+02, -.16576100E+02, 0.20272900E+02, 0.24324900E+02, 0.22198700E+02, -.41939000E+02, 0.47275800E+02, 0.45232400E+02, 0.20952100E+02, -.23971900E+02, -.84515100E+01, -.13778300E+02, -.21406200E+02, 0.14954100E+01, -.37145100E+02, -.52542700E+02, 0.22126400E+02, -.38850100E+01, -.98209400E+01, -.83112000E+02, -.29728000E+02, 0.99515500E+01, -.37903900E+01, 0.23730600E+02, 0.28831900E+02, 0.60233300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.85656700E+00, -.26754400E+00, 0.59921600E+00, -.16489800E-01, 0.53053400E+00, -.38066500E-01, -.20703600E+00, 0.95303400E+00, 0.29538200E-01, 0.33578800E+00, -.12170600E+00, 0.21557500E+01, 0.13232300E+01, 0.21987500E+00, 0.28913800E+01, -.86221200E+00, -.14047500E+01, -.17181300E+00, -.64967900E+00, -.10813700E+01, 0.36474400E+00, -.15732900E+00, 0.19773200E+00, -.20061600E+01, -.24359400E-01, 0.24977700E+00, -.26560500E+01, -.86392500E-02, 0.93005200E-01, 0.50763700E+00, -.23921300E+00, -.57164700E+00, 0.11680700E+01, 0.41136600E-01, 0.25189600E-01, -.66909200E+00, 0.98811800E-02, -.43563300E-01, -.86483900E-01, 0.10422500E+01, -.13523700E+01, -.35799700E+00, 0.53906900E-02, -.58457400E-01, -.15646200E-01, 0.99682500E-01, 0.27582000E+00, -.24123000E-03, -.11179600E+01, -.48297400E-01, -.67942000E+00, 0.14633600E+01, -.24712100E+00, 0.26418600E+00, 0.49665600E+00, -.27596200E-01, -.43338800E+00, -.19501900E+00, -.10100200E+00, 0.12672700E+01, 0.58075500E-01, -.23727200E-02, 0.34646000E-01, -.99951400E-01, -.16871100E+00, 0.10772900E+00, -.16976200E+00, -.19727300E+00, 0.22118600E+00, -.40444400E-01, 0.30646900E+00, -.44134800E+00, 0.18265900E+00, 0.36580500E+00, 0.27204500E+00, -.72060300E+00, -.43121100E-01, -.64326400E-01, -.56313500E-01, -.26032800E-01, 0.68119400E-01, -.56308700E-01, -.37550600E-01, 0.76940200E+00, -.83310200E-03, -.11619800E+00, 0.55944700E-02, -.11465500E+00, -.10733900E+00, 0.13171800E+00, -.20130600E+00, 0.93905200E-01, -.18233500E-01, 0.66890200E+00, -.74599200E+00, 0.71438400E+00, 0.52531200E+00, -.17748900E+00, 0.22123000E+00, 0.10755300E+00, -.22368900E+00, -.18456600E+00, 0.15009100E-01, -.44304600E+00, -.78030300E+00, -.12513300E+00, -.10320800E+00, 0.18040200E+00, 0.24246200E+00, -.26046800E+00, -.23074200E+01, -.13168200E+00, 0.10476200E+00, 0.81021000E-03, -.12750800E+00, -.29131100E+00, -.34975800E+01, 0.55380600E+00, 0.38382100E+00, -.26014000E+03, -.26769200E+03, 0.10825100E+04, -.55297200E+03, 0.43579200E+03, -.54126200E+03, -.16813200E+03, -.33556700E+03, -.15399200E+03, 0.32780700E+03, 0.48902100E+03, -.52007400E+03, -.26598300E+03, -.45613500E+03, 0.22740400E+03, 0.43283700E+03, 0.22806500E+03, 0.41336400E+02, -.17947100E+02, 0.13795200E+03, 0.29721900E+02, 0.22736800E+03, 0.25707900E+03, 0.22405800E+03, 0.55590300E+03, -.27868500E+03, 0.33215700E+04, -.27795300E+03, -.11974800E+03, 0.83797900E+03, -.45441100E+03, -.53014800E+03, -.12252300E+04, 0.85632000E+03, 0.47712100E+03, -.36836000E+03, 0.18277200E+03, 0.93500200E+02, 0.18414800E+03, 0.20053800E+02, 0.96741700E+02, -.19990200E+02, -.56876600E+02, 0.51371800E+01, 0.10646300E+03, 0.17417400E+03, -.93431300E+03, 0.45754600E+03, 0.34773200E+03, 0.46501900E+03, 0.55069800E+02, 0.14784200E+03, 0.43797600E+02, -.17706100E+03, 0.54266800E+03, -.43895800E+02, 0.11967800E+04, 0.16909700E+04, -.85965700E+03, -.98894800E+03, -.84548000E+03, -.23817600E+03, 0.25538500E+03, -.43344700E+03, -.14981500E+03, -.49772000E+03, 0.32776500E+03, 0.63558800E+03, -.11456500E+04, 0.57748900E+03, -.28859200E+04, 0.57282800E+03, 0.32669100E+02, -.73179500E+03, 0.51771400E+03, 0.37819700E+03, 0.11542700E+04, -.75583400E+03, 0.26632600E+03, 0.13768100E+04, -.67361200E+03, -.93178600E+02, -.68838900E+03, 0.64239700E+02, -.15044200E+03, -.45255000E+02, 0.59327200E+02, -.13807200E+04, 0.10451300E+02, -.11261700E+04, 0.72581700E+03, -.35810800E+03, -.92213000E+02, -.36291400E+03, -.66683100E+02, -.11444900E+03, 0.17734000E+03, 0.45475000E+03, -.43533000E+03, -.86586000E+02, -.54610600E+03, 0.56403700E+03, -.29312500E+03, 0.30899400E+03, -.28201700E+03, 0.13217300E+03, -.59899500E+01, -.32657700E+03, -.31575600E+03, -.16681500E+03, 0.20779100E+03, 0.13705000E+03, -.18334700E+03, 0.93576000E+02, 0.37567400E+03, 0.91691500E+02, -.29825800E+03, -.21048300E+03, 0.85806400E+01, -.15356000E+03, -.38280200E+03, -.12674700E+03, 0.12736300E+04, -.53654900E+03, 0.26581300E+03, -.85993100E+02, 0.26830400E+03, -.16782000E+03, -.35487300E+03, 0.33784700E+03, 0.87007500E+02, 0.30985500E+03, -.35942600E+03, 0.34886600E+03, 0.47322000E+03, -.22619400E+03, 0.26517300E+03, -.23659500E+03, 0.26965300E+03, 0.20549000E+03, -.35011500E+03, -.47380400E+03, -.78554900E+03, 0.29839200E+03, -.45453900E+02, -.72506300E+02, 0.14474200E+03, -.16001700E+02, 0.23818900E+02, 0.34137400E+02, 0.11159000E+03, 0.12297600E+03, 0.24524400E+02, 0.15647400E+02, -.75346900E+02, 0.24609600E+03, -.11627700E+03, -.16058700E+03, -.77084500E+02, 0.38056200E+03, 0.13973900E+02, 0.28741400E+03, -.22406900E+02, 0.49208000E+03, -.32896700E+02, 0.33986300E+03, 0.11730100E+03, -.77504100E+02, 0.13935800E+03, -.57160400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.82284700E+00, -.71709000E-01, -.11594000E+01, -.73883000E-01, -.12413400E+01, -.10147800E+00, 0.14502800E+00, -.18028900E+00, 0.16035500E+01, 0.30056800E+00, 0.12260400E+00, -.72958700E+00, 0.41187300E-01, 0.52321200E+00, -.26454400E+00, 0.36272700E+00, 0.36048800E+00, 0.43438100E-01, 0.58328000E+00, 0.61583300E+00, -.14450800E+01, -.38330800E-01, 0.12940600E-01, 0.95242900E-01, -.83606800E-01, -.12484400E+00, 0.11760000E+00, -.78148500E-01, -.42347700E+00, -.31389600E+00, 0.51286800E-01, 0.46051100E+00, -.90411800E-01, -.43024000E+00, 0.10973400E+00, 0.10640900E+01, 0.18844800E-01, 0.30160200E-01, -.73634500E-01, -.61158200E+00, -.74651300E+00, -.44876900E+00, 0.70960900E+00, -.40923300E-01, -.18551900E+00, -.33822400E+00, -.28880600E+00, 0.31236100E-02, -.89030700E+00, 0.51866200E+00, 0.63385500E+00, -.47304200E+00, 0.48449500E-01, 0.48067200E-01, 0.24490600E+00, -.38584700E+00, -.10801000E+01, -.37850900E-01, -.34349900E-01, 0.25755700E+00, 0.18508400E-01, -.54117600E+00, -.68354800E-02, 0.10312700E+01, 0.32006200E-02, 0.20593000E+00, -.12352900E+00, -.27572600E+00, -.34922100E+00, -.90016000E-01, 0.29392800E+01, 0.11570200E+00, 0.63549000E+00, -.41387500E+00, -.39380700E+00, 0.78062700E+00, 0.14015000E+00, 0.77082000E+00, 0.15069100E+00, 0.65568800E-01, -.85296300E-01, -.52527900E+00, 0.69545100E-01, 0.30107500E+00, 0.91970300E+00, -.23213100E+00, -.18175100E+00, 0.64078600E-01, 0.31246600E+00, 0.23355600E-01, 0.20510800E+00, 0.72325700E-02, -.35867900E+00, -.18508400E+00, -.49867200E+00, 0.47564000E-01, 0.71452000E+00, -.53415200E-01, 0.67218500E-01, -.12679800E+01, 0.52085200E-01, 0.73336200E-01, -.18100800E-01, 0.18921000E+00, 0.14629000E+00, 0.50572000E+00, 0.44942400E+00, -.78603900E+00, 0.77410900E+00, -.60557700E+00, -.42353100E+00, 0.11056700E+00, 0.50513000E+00, -.14482000E-02, -.11489500E+00, 0.70508900E-01, 0.97590000E+00, -.87346600E-01, -.26524500E+00, -.87625700E+00, -.81961000E+03, -.75323300E+02, 0.37147400E+02, 0.51440100E+03, 0.37759200E+02, -.38723900E+03, -.10727300E+03, -.51402900E+03, -.28211800E+03, 0.81041000E+03, -.75710200E+02, -.10070300E+04, -.42792600E+03, 0.21203900E+03, 0.66171000E+03, 0.21425100E+03, -.54620700E+02, -.17172200E+03, 0.35131000E+03, 0.35913400E+03, 0.34887500E+03, -.18147900E+03, 0.90376800E+03, 0.25039600E+04, -.12511200E+04, 0.20296300E+04, -.12519300E+04, 0.77183500E+03, 0.20798600E+04, -.15554000E+04, -.32342200E+03, -.16987700E+04, 0.18423100E+04, -.10521200E+04, -.13803500E+03, 0.65925400E+02, 0.10555200E+03, 0.69330600E+02, 0.79334200E+02, 0.22744200E+03, -.22984400E+03, -.17124200E+03, -.79239800E+02, 0.23037900E+03, 0.18735400E+02, 0.34249300E+03, -.16611900E+03, -.17241900E+02, -.17138100E+03, -.55631700E+03, -.12654900E+03, -.41866100E+02, -.93322000E+02, -.26244800E+02, -.15367600E+03, 0.12438000E+04, 0.25617000E+04, -.12790900E+04, -.11293900E+04, -.12809200E+04, -.34854800E+03, 0.55274300E+03, -.87060800E+03, -.52134900E+03, -.10291500E+04, 0.77511300E+03, 0.52693100E+03, -.23550500E+04, 0.11775500E+04, -.19396000E+04, 0.11774800E+04, -.52823500E+03, -.15062700E+04, 0.10642900E+04, 0.33975300E+03, 0.14516200E+04, -.13998900E+04, 0.14859000E+04, 0.18330500E+04, -.91709100E+03, -.76887900E+02, -.91720400E+03, 0.68199700E+02, -.51289000E+03, 0.36184200E+03, 0.50746700E+03, -.12282500E+04, -.52154400E+03, 0.65808400E+02, 0.52780400E+03, -.26891000E+03, 0.25802000E+03, -.26377100E+03, 0.44330300E+03, 0.18188000E+03, -.11642500E+02, 0.17370100E+03, -.34761300E+03, 0.14095800E+03, -.91528600E+03, 0.75132400E+03, -.37112200E+03, 0.53357900E+03, -.37572900E+03, 0.16833800E+03, 0.83793500E+02, -.40046900E+03, -.34893000E+03, -.26971100E+03, 0.39054900E+03, -.26907000E+03, -.59932200E+03, 0.29229700E+03, 0.55895600E+03, 0.29937300E+03, -.10112500E+03, -.16513100E+03, -.21738600E+03, -.18969400E+03, -.64640700E+02, -.11077100E+03, 0.13143100E+04, -.91058300E+03, 0.45854800E+03, -.24445300E+03, 0.45514700E+03, -.27592700E+03, -.45315900E+03, 0.26328500E+03, -.69603800E+02, 0.51296600E+03, -.39494700E+03, 0.97619600E+03, 0.85074000E+03, -.41502100E+03, 0.31237800E+03, -.42573200E+03, 0.28907800E+03, 0.50787500E+03, -.69449200E+03, -.74534900E+03, -.11825300E+04, 0.64072600E+03, -.95729100E+01, -.86797100E+02, 0.19522600E+03, 0.29128300E+02, 0.64853300E+02, -.36865900E+01, 0.25589100E+03, 0.26747800E+03, 0.62010800E+02, -.29078400E+02, -.79755800E+02, 0.26700200E+03, -.16066500E+03, -.11549800E+02, -.17690500E+03, 0.11710200E+03, 0.51532200E+02, 0.27547400E+03, -.10549700E+03, 0.27770000E+03, 0.15992000E+02, 0.28186000E+03, 0.18336600E+03, 0.88322700E+01, 0.22540200E+03, -.22931600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17105200E+00, -.76731400E-01, -.68369500E+00, -.17763600E+00, -.16659400E+00, 0.69455700E-01, -.34649000E+00, -.45491400E+00, 0.30801100E+00, 0.72990400E-01, 0.41321100E-01, 0.13159900E+01, -.31848200E-01, -.11136000E-01, -.18772200E+00, 0.16692600E+00, 0.14370400E-01, -.10540700E+00, -.46024000E-01, -.10655800E+00, 0.69640700E-02, 0.44276800E-01, 0.12620200E+00, 0.79608400E+00, 0.48639200E-02, 0.23546500E-02, -.20186200E-01, 0.79822100E-02, 0.27369200E-01, 0.25489800E-01, -.74295700E-02, -.17642800E+00, 0.83217500E-01, -.52996600E-01, 0.16054900E-01, 0.70074000E-01, 0.59582700E-02, 0.18754100E+00, -.14717000E+00, 0.34223500E-01, -.35749400E-01, 0.16370900E-01, 0.60818100E-01, 0.56370000E-01, -.11336300E-01, -.82922000E-01, 0.14938900E-01, 0.67293000E-04, 0.96775600E-01, 0.35222800E-03, 0.18281700E+00, 0.41551200E+00, 0.10726300E-01, 0.10648900E+00, 0.77359100E-01, 0.52653100E-01, 0.33467200E-01, -.32677000E+00, 0.76993800E-02, 0.38904400E-01, -.91826300E-02, 0.54766900E-01, -.54698300E-01, -.10753500E+00, 0.14072100E+00, -.76030800E-02, 0.15478500E-01, 0.10536600E-01, -.67857400E-01, 0.22082500E-02, 0.34510300E-02, 0.14009000E+00, -.75408500E-01, -.59161400E-01, -.36279800E-01, 0.10603300E+00, 0.15786600E-01, 0.52069100E-01, -.13718900E-01, 0.11654400E-01, -.12883300E-01, -.38915800E-01, -.30107700E-01, -.16506600E+00, -.13996500E+00, 0.53628100E-01, -.89146100E-01, -.18543800E-02, 0.81417400E-02, 0.84590800E-01, 0.34168500E-02, 0.25517000E-01, -.22570900E-01, 0.10750300E+00, 0.45370500E-01, -.10247600E+00, -.10026800E+00, 0.18199900E+00, 0.76984800E-02, 0.15566900E+00, -.65650000E-02, -.47535200E-02, 0.20142800E-02, -.84977600E-01, -.77676000E-01, -.21677000E-01, 0.92463400E-02, 0.51638100E-01, 0.13550100E-01, 0.40737100E-01, 0.11318200E+00, -.99064700E-02, -.67680800E-01, -.51018700E-04, -.19515300E-01, 0.62849100E-03, 0.63092800E+00, -.25048100E+00, 0.60194300E+00, -.88256100E-01, -.79303500E-01, 0.40077000E+03, -.20204700E+03, 0.88441300E+02, -.20043100E+03, -.44776000E+02, -.95146400E+02, -.17505400E+02, 0.16773500E+03, 0.64756900E+02, -.11182400E+03, -.26230100E+03, 0.95426500E+02, -.48675900E+02, -.19382000E+02, -.47839400E+02, 0.34679400E+01, -.31014400E+02, -.32020900E+02, 0.73306600E+01, -.15100800E+02, -.27637000E+02, -.11754800E+02, -.94886000E+03, 0.47421400E+03, 0.10932300E+04, 0.47440800E+03, 0.24390200E+03, 0.54946900E+03, 0.38221800E+02, -.90386500E+02, -.13149600E+03, 0.55625000E+03, 0.31524700E+03, 0.67629400E+02, -.29476700E+02, -.55633100E+02, -.33747900E+02, -.18473100E+02, -.22994600E+02, 0.55546900E+01, 0.12745200E+02, -.14880000E+01, -.16227200E+02, -.28031100E+02, 0.39562900E+02, -.20687500E+02, -.27208700E+02, -.19772900E+02, -.60526700E+02, -.54680300E+02, 0.65898000E+00, -.52423400E+02, 0.81520800E+01, -.36468600E+02, 0.14092100E+03, 0.36113300E+03, -.18249000E+03, -.14510800E+03, -.18053100E+03, -.84457200E+02, 0.34714900E+02, -.11536200E+03, -.14018000E+03, -.15263100E+03, 0.97409700E+02, -.86671000E+02, 0.25332800E+03, -.12571600E+03, -.87691900E+03, -.12664000E+03, -.14853600E+03, -.46163700E+03, 0.55115800E+02, 0.44390700E+02, 0.20588100E+03, -.42839500E+03, -.29165000E+02, 0.10497400E+03, -.50596400E+02, 0.19910600E+03, -.52173800E+02, 0.67837100E+02, 0.89807100E+02, -.13975800E+03, -.22478600E+03, -.31380100E+03, 0.11271700E+03, -.17158300E+02, -.81322200E+02, 0.40839800E+02, 0.10471600E+03, 0.40599600E+02, 0.48963700E+02, 0.47197800E+02, 0.16788700E+02, 0.37801500E+02, -.24703000E+02, 0.40149400E+02, -.83276600E+02, 0.13679600E+03, -.70300100E+02, 0.77176400E+02, -.68367400E+02, -.44503600E+02, -.37978600E+02, -.69365100E+02, -.17864400E+03, -.91020900E+02, 0.22290300E+02, -.88082500E+02, -.74712100E+03, 0.37283200E+03, 0.50564800E+03, 0.37370000E+03, 0.39994600E+02, 0.33644600E+02, 0.76799400E+02, -.14053500E+03, 0.86251400E+01, 0.10906800E+03, 0.28611100E+03, 0.85456700E+01, -.42834700E+01, -.84642500E+01, -.41991500E+01, -.13101600E+02, -.71240600E+02, 0.81328100E+02, 0.46106800E+02, 0.37708600E+02, -.88676800E+02, -.17099700E+02, 0.14459300E+03, -.68672100E+02, 0.36277700E+02, -.72130300E+02, 0.38162900E+02, 0.12032500E+03, -.14337100E+03, -.24425200E+03, -.19597300E+03, 0.16325800E+03, -.89399900E+02, -.14960600E+02, 0.18836700E+02, -.47382400E+01, -.32334200E+01, -.63536400E+01, 0.15610400E+02, 0.15480000E+02, -.75736100E+01, 0.45503300E+01, -.98032300E+01, 0.29443700E+02, 0.39386500E+01, -.26913300E+02, 0.41630100E+01, -.45331700E+02, -.57450000E+01, 0.28917400E+02, 0.92319000E+01, -.39688700E+02, -.15464500E+02, 0.16431600E+02, 0.29817300E+02, -.26318700E+02, 0.15983800E+02, -.26455200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13505000E+00, 0.41213100E+00, 0.61955500E+00, 0.11844200E+00, 0.29467000E+00, -.54526500E-02, 0.18332500E+00, 0.45991300E+00, -.57134100E+00, -.30010900E+00, -.30193200E-01, -.10505800E+01, 0.13016600E+00, -.46971400E+00, 0.22206700E+00, 0.11680900E+00, 0.45004100E+00, 0.13710000E+00, -.17661600E+00, 0.49448400E+00, 0.80320000E+00, 0.26365100E-01, -.25419200E+00, 0.31282600E+00, 0.10855200E-01, -.35554700E-01, -.14672900E+00, 0.73864800E-01, 0.28608100E+00, 0.45899400E+00, 0.51144200E-01, -.33687200E+00, -.21650000E-01, 0.13861600E+00, 0.57757100E-01, -.56840600E+00, -.10493600E-01, 0.62994800E+00, 0.18138300E+00, -.20231400E+00, 0.25381400E+00, 0.56567900E-01, -.16847000E+00, -.25310600E-02, 0.11169500E+00, 0.87134900E-01, 0.43835600E-01, -.60686900E-03, 0.11689500E+00, -.91330100E-01, -.14421000E+00, -.87997200E-01, -.37881600E-01, -.85497200E-01, 0.65823100E-02, 0.42851000E-01, 0.12818800E+00, 0.42158400E+00, -.82153100E-02, -.50981700E-01, 0.23777100E-01, -.69742700E-01, 0.46448000E-01, 0.18311200E-01, -.15477100E+00, 0.45080700E-01, -.36639000E-01, -.30434600E+00, 0.23559200E-01, -.43958000E-01, 0.23020200E+00, -.15080000E+00, 0.32927800E-02, -.42487800E-02, -.73311100E-01, 0.13303200E+00, -.38412200E-02, -.37648700E+00, 0.70964000E-01, 0.76492900E-01, 0.61817200E-01, 0.34182400E-03, 0.45480400E-01, 0.13299300E+00, 0.11865100E+00, -.21604900E+00, 0.80119800E-01, -.90057600E-01, -.12656300E-01, 0.29289100E-01, 0.13127100E+00, 0.40763900E-02, 0.13987600E+00, 0.18403500E-01, 0.12726400E-01, 0.20358500E-01, 0.19960400E+00, 0.94471700E-01, 0.25913600E-01, 0.38664900E+00, -.25750000E-01, 0.12074000E+00, 0.14391900E-02, 0.10886900E+00, -.14673500E+00, -.10061600E+00, 0.24210800E-01, 0.37472100E+00, -.24053400E+00, 0.60031900E-01, 0.61173100E+00, 0.93121700E-01, 0.90926400E-01, 0.15710600E-02, -.83290400E-02, -.23151200E-02, -.65880600E+00, 0.24450100E+00, -.47690600E+00, 0.19751400E+00, -.89991300E-01, 0.60736000E+00, 0.20186100E+01, -.42184000E+03, 0.75919700E-01, -.26621100E+03, -.21573400E+03, 0.20006700E+03, 0.27078500E+02, 0.10445300E+03, -.18054500E+03, 0.75447200E+02, -.24305300E+03, 0.12375100E+03, 0.10695500E+03, 0.12174600E+03, 0.21865000E+02, 0.35253500E+02, 0.14492700E+03, 0.50374600E+02, 0.94233500E+02, 0.22284600E+02, -.25471200E+02, 0.15601900E+04, -.78008000E+03, -.76100400E+03, -.78005400E+03, -.31010500E+03, -.73214300E+03, -.22503700E+03, -.20224200E+03, -.58769500E+02, -.70983600E+03, -.28454300E+03, -.11547000E+03, 0.53545500E+02, 0.75608500E+02, 0.57527900E+02, 0.48594500E+02, 0.65818200E+02, -.30906800E+02, -.42687200E+02, -.35364300E+01, 0.53366300E+02, 0.32091000E+02, -.30406100E+01, 0.19505300E+01, 0.48039900E+02, 0.11233000E+01, 0.44778300E+02, 0.87333900E+02, 0.83687000E+01, 0.13287600E+03, 0.75633800E+02, 0.21732800E+02, -.44161000E+02, -.35230100E+02, 0.19726000E+02, -.12949700E+02, 0.17551800E+02, -.65691500E+01, 0.35653100E+02, 0.18879600E+02, 0.10017300E+03, 0.54010500E+02, -.29919900E+02, 0.34914400E+03, -.28923600E+03, 0.14366600E+03, 0.47145400E+03, 0.14457700E+03, 0.92393300E+02, 0.63905100E+03, 0.77768400E+02, 0.21793000E+03, -.15733700E+03, 0.50485300E+03, -.49451400E+02, -.14494700E+03, 0.70558500E+02, -.19311800E+03, 0.71917500E+02, 0.84588600E+02, -.18081700E+02, 0.12314500E+03, 0.32096200E+03, 0.18413900E+03, -.73457800E+02, 0.26525100E+02, 0.28661300E+03, -.14280500E+03, -.12346600E+03, -.14319700E+03, -.18952800E+02, -.47007200E+02, -.18013100E+02, -.75600800E+01, -.10862600E+03, -.41820600E+02, -.35788600E+02, 0.29981300E+02, -.13115800E+02, -.82942500E+02, -.15044300E+02, 0.94041800E+02, 0.93971700E+02, -.94706400E+01, 0.15173600E+03, 0.66119800E+02, 0.87784400E+02, 0.16684500E+03, 0.71462500E+03, -.35563800E+03, -.57237800E+03, -.35756000E+03, -.13674000E+03, -.13366700E+03, 0.11690700E+02, 0.10173600E+03, 0.79524100E+02, -.23955200E+03, 0.89513900E+02, -.21841000E+03, 0.10871000E+03, -.56502200E+02, 0.10908700E+03, -.48391300E+02, -.19239500E+02, -.47023000E+02, -.67960400E+02, 0.86601000E+02, 0.34965000E+02, 0.20188800E+03, -.11203200E+03, 0.50778600E+02, -.24131600E+01, 0.55726500E+02, 0.38492900E+02, -.96801800E+02, 0.11061100E+03, 0.19503800E+03, 0.59864500E+02, -.13670400E+03, 0.18014500E+03, 0.10272300E+02, 0.14566600E+02, 0.47726800E+01, 0.83493900E-01, 0.37689800E+02, 0.33098300E+02, 0.37582400E+02, 0.10205700E+02, -.46887600E+01, 0.72936000E-01, 0.36138900E+02, -.31699200E+02, 0.15026100E+02, -.29069300E+02, 0.26185000E+03, 0.50670100E+01, 0.38942100E+02, -.44398600E+02, 0.29950700E+03, 0.41299700E+01, 0.63727800E+02, 0.67679600E+01, 0.25296600E+02, 0.30288300E+02, 0.20135800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.61708700E+00, -.10153900E-01, -.21915500E+00, -.86867500E+00, 0.14531300E+00, 0.10455700E+00, 0.44524500E+00, -.63175100E+00, -.17477800E+01, -.37732800E+00, -.84263000E-01, 0.10587700E+01, -.28855000E+01, -.11079000E+01, -.88352900E+00, -.95185000E+00, -.27338500E+00, 0.10757400E+01, -.80509600E-01, 0.71390400E+00, -.39576500E+00, 0.57806000E-01, -.95113400E-01, 0.16522700E+01, 0.10795200E+00, 0.11597900E-01, 0.11599700E+01, -.78562000E-01, 0.28493700E+00, -.83343300E+00, -.60986100E-02, -.26008500E+00, -.15475300E+00, 0.98251700E+00, -.19561600E+00, -.31307900E+00, -.12863600E-01, -.30452700E+00, 0.99740000E-01, -.25953600E+00, 0.49058700E+00, 0.13524200E+00, 0.31923100E+00, 0.84056900E-02, -.40224100E-01, 0.42104700E-01, 0.27837800E+00, -.37011700E-02, 0.56663600E-01, 0.24714700E+00, 0.14307300E+00, -.64238600E+00, 0.51550300E-01, 0.18659100E+00, 0.27894200E-01, -.20742100E-01, -.20663300E+00, -.94552600E+00, -.45630500E-01, 0.40091000E+00, -.13428400E-01, -.30281400E+00, 0.45359100E-01, 0.11335800E+00, 0.41749300E+00, 0.12350100E+00, -.76997000E-01, -.41237300E+00, -.45786600E+00, -.41374200E-02, 0.60206800E+00, -.13875200E+00, 0.10206200E+00, -.11445200E+00, -.20880700E+00, -.15907600E+00, -.13826500E-01, 0.88800900E-01, -.17655000E+00, -.34272900E+00, -.70856200E-01, -.17809700E-02, -.20899300E+00, 0.15376600E+01, -.93410200E+00, 0.73860700E+00, -.21511900E+00, -.46344500E-01, 0.27712200E+00, 0.25700700E+00, -.19057200E+00, 0.71537300E-01, -.12758700E+00, 0.18496400E+00, 0.36191500E+00, -.67416900E+00, -.41907900E+00, -.50063400E+00, -.51211700E-01, 0.66995500E+00, 0.36740400E-01, 0.13125700E+00, 0.83793300E-02, -.11815900E+00, -.25685200E+00, -.32572500E+00, 0.30213000E-01, -.67194300E+00, -.44948000E+00, 0.31491700E+00, -.23256400E+00, -.10448200E+00, 0.72842200E-02, 0.53434000E-03, -.18200000E+00, -.12434100E+00, -.24755500E+01, -.20610300E+00, -.84750200E+00, 0.42575100E+00, 0.69056300E+00, 0.18146600E+01, 0.26927000E+00, -.83365300E+03, 0.78689700E-01, -.14822400E+03, -.28631400E+03, 0.67060000E+03, 0.16477000E+03, -.50918400E+03, -.28000300E+03, 0.16104900E+04, -.15992700E+03, 0.84795200E+02, -.24915700E+03, 0.80179500E+02, 0.42631200E+02, 0.16676700E+03, 0.37168600E+01, -.65104600E+02, -.81842400E+02, 0.14658500E+03, -.12524100E+03, -.36367400E+04, 0.18138900E+04, -.11703000E+04, 0.18184100E+04, -.56802800E+03, -.22492400E+04, 0.12624000E+04, -.55663000E+03, 0.24112000E+04, -.20718900E+04, 0.97750900E+03, 0.23061200E+02, -.13187600E+02, 0.12173100E+03, -.11718400E+02, 0.57263000E+00, -.26837100E+02, 0.12887900E+03, 0.10382600E+03, -.29773000E+02, -.58856200E+02, 0.51391400E+02, -.63004900E+03, 0.31125600E+03, 0.15829000E+03, 0.31395400E+03, 0.57259200E+03, 0.21297900E+03, 0.16573000E+03, 0.22215100E+03, 0.21318900E+03, 0.69610300E+02, -.14464700E+04, -.16651600E+04, 0.83186600E+03, 0.70924100E+03, 0.83251500E+03, 0.11756200E+02, -.35576400E+03, 0.57730200E+03, 0.25008300E+03, 0.61714400E+03, -.64386100E+03, 0.34445800E+03, 0.34477200E+04, -.17226300E+04, 0.15575200E+04, -.17239000E+04, 0.40399900E+03, 0.19300400E+04, -.10098600E+04, 0.29868700E+03, -.20047700E+04, 0.17034400E+04, -.15410200E+04, -.19303100E+04, 0.96582400E+03, 0.15791400E+03, 0.96459300E+03, 0.32080300E+03, 0.74513700E+03, -.45791700E+03, -.26069300E+03, 0.10775400E+04, 0.68543700E+03, -.77238600E+03, -.78584100E+02, 0.43179200E+02, -.48027300E+03, 0.39403400E+02, -.58518600E+03, -.29297600E+03, -.26337500E+02, -.26193200E+03, 0.45472800E+02, -.18874300E+03, 0.10930000E+04, -.95412100E+03, 0.47527200E+03, -.40430900E+03, 0.47700700E+03, -.33466200E+02, -.44265600E+02, 0.40799500E+03, 0.37787200E+03, 0.46523900E+03, -.32456200E+03, 0.52840800E+03, 0.15700100E+03, -.73204000E+02, -.49704400E+03, -.78757700E+02, 0.90776800E+02, 0.37062700E+03, 0.16252000E+03, 0.42764700E+02, 0.40258100E+03, 0.13936900E+03, -.10506900E+04, 0.32768200E+03, -.16781400E+03, 0.36757700E+02, -.16397200E+03, 0.13909400E+03, 0.29084100E+03, -.13910900E+03, 0.31277800E+01, -.23412500E+03, 0.30502100E+03, -.39706600E+03, -.95542900E+03, 0.46649400E+03, -.17299900E+03, 0.47742100E+03, -.11630700E+03, -.48690600E+03, 0.55552900E+03, 0.57357400E+03, 0.93695900E+03, -.68410500E+03, 0.19405300E+03, 0.10131500E+03, -.14525700E+03, -.41303100E+02, -.66005000E+02, 0.57880900E+02, -.12812600E+03, -.12451400E+03, -.54722900E+02, 0.40824800E+02, 0.77297000E+02, -.14407700E+03, 0.85814500E+02, -.28556000E+02, 0.90103900E+02, 0.21216800E+03, -.52760100E+02, -.13156500E+03, 0.58735400E+01, 0.15134900E+03, -.51598300E+02, -.12012800E+03, -.93861800E+02, 0.15720500E+02, -.15178200E+03, 0.20308700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16529700E+01, 0.27781600E+00, 0.12207700E+01, 0.26694100E+01, 0.32490100E+01, 0.19667700E+00, -.24679100E+01, -.21986000E+01, 0.83283100E-02, 0.34429300E+00, 0.30261300E-01, 0.35338200E+01, -.28388900E+01, -.12502900E+01, 0.13907500E+00, -.12303500E+01, -.22110900E+01, -.28682800E+00, -.51837200E+00, -.21480500E+01, -.31136000E+00, -.32366000E-01, 0.83516700E+00, -.23937100E+01, 0.42906000E+00, 0.20154900E+00, -.17743900E+01, 0.17362500E+00, -.58230100E+00, -.16818500E+01, -.99044300E+00, 0.45979200E+00, -.44387000E+00, 0.86853300E+00, 0.90225200E+00, -.94793000E+00, -.29960900E-01, -.45812900E-01, -.53714300E+00, -.12896000E+01, 0.62345500E-01, 0.82353200E-01, 0.14232500E+01, -.13935600E-01, -.33897800E+00, 0.16298900E+00, 0.65938500E+00, -.18216700E-01, -.94738900E+00, 0.81975100E+00, 0.12488500E+00, -.39117700E+01, 0.29180900E+00, 0.62226300E+00, 0.38573200E+00, -.13634800E+00, -.30575600E+00, 0.14623200E+01, -.37036400E-01, 0.12583600E+01, 0.84775500E-01, -.15524000E+00, 0.20384400E+00, -.56768700E+00, 0.64862100E+00, 0.28489000E+00, -.31116600E+00, -.44696400E+00, -.85929300E+00, -.18138400E+00, -.23671100E+01, 0.53835000E+00, -.11501600E+01, -.79184000E-01, 0.20656600E-01, 0.64943200E-01, -.23604500E-01, -.12614200E+00, 0.10355600E+00, -.23011700E+00, 0.13498900E+00, -.46119000E+00, -.18763600E-01, 0.58065800E-01, -.47141000E+00, 0.47370600E+00, -.14120800E+00, 0.10508100E+00, 0.81099800E-01, 0.38693500E+00, 0.47966600E-01, 0.16502200E+00, 0.10258800E+01, -.19206000E-01, -.94014500E-01, 0.34553100E+00, 0.12546500E+01, 0.91658300E-01, 0.25066500E+00, 0.19382000E+00, 0.44765300E-01, 0.52505200E-01, 0.18467500E-01, 0.15276300E+01, -.24404600E+00, 0.36338900E+00, -.11785500E+00, 0.22786400E+01, 0.45152000E+00, 0.47732000E+00, 0.11277600E+00, 0.20401000E-01, -.14925900E+00, 0.37313800E-02, 0.11319000E+00, -.80934900E-01, 0.83541600E+00, 0.57662600E+00, -.31110600E+00, 0.39643200E-01, 0.24255300E-01, -.21536800E+01, -.43327100E+00, -.48738800E+00, 0.57000000E+01, -.59083000E+01, -.17475500E+03, 0.37251200E+02, -.35735100E+03, -.42851100E+03, -.14591400E+03, 0.79640600E+03, -.11777300E+03, 0.62071300E+02, -.11783000E+03, 0.59263100E+02, 0.47123900E+02, 0.11860100E+03, -.16150800E+03, -.11903400E+03, -.10436800E+02, 0.76031400E+02, -.32588900E+02, -.30193700E+04, 0.15132300E+04, 0.10760900E+04, 0.15097500E+04, 0.78089700E+03, -.92846700E+01, 0.66450900E+03, -.42900500E+02, 0.61511900E+03, 0.11936100E+03, 0.17247800E+03, 0.50429300E+02, -.31246800E+02, -.26673100E+02, -.25120500E+02, -.35014800E+02, -.10061500E+03, 0.87162800E+02, 0.89905300E+01, 0.14528700E+02, -.10477800E+03, 0.66125400E+02, -.10099000E+04, 0.50176000E+03, 0.31941600E+03, 0.50168800E+03, 0.21640700E+03, 0.86852800E+02, 0.17462200E+03, -.22630200E+03, 0.16054300E+03, -.50852400E+01, -.62994800E+03, -.65746300E+03, 0.32801900E+03, 0.43978400E+03, 0.32861600E+03, 0.30376000E+02, -.44975200E+03, 0.35631900E+03, 0.17891300E+03, 0.21787700E+03, -.43932700E+03, -.43003600E+03, 0.13657600E+04, -.68507300E+03, -.38564000E+03, -.68295200E+03, -.34233800E+03, 0.25982900E+02, -.44019200E+03, -.17669600E+03, -.31535600E+03, 0.52965300E+02, -.31446100E+03, -.15203100E+04, 0.76056400E+03, 0.10350900E+04, 0.75917700E+03, 0.33868500E+03, 0.92727200E+03, -.45800300E+03, -.26079700E+03, 0.21417200E+03, 0.90292900E+03, -.37515100E+03, 0.78306800E+03, -.38792600E+03, -.64342800E+03, -.39134200E+03, -.34170600E+03, -.28156500E+03, -.91769000E+02, 0.15558100E+03, -.19264400E+03, -.18277900E+03, 0.14484700E+03, -.43181600E+03, 0.21510200E+03, 0.14998500E+03, 0.21581400E+03, -.21705200E+03, -.18503100E+03, 0.12664400E+03, -.17922600E+01, 0.16994200E+03, -.20313100E+03, 0.32716700E+03, -.59178400E+03, 0.30199600E+03, 0.40211000E+03, 0.29545200E+03, 0.19877800E+03, 0.24924100E+03, -.13947100E+02, -.12955800E+03, -.18005200E+03, 0.30546500E+03, -.84686500E+03, -.74028900E+02, 0.35874500E+02, -.25537200E+02, 0.36824500E+02, -.63907100E+02, -.82861700E+02, 0.23971400E+03, 0.17289200E+01, -.15626300E+03, -.13767000E+03, -.10545300E+03, -.13693100E+03, 0.61237800E+02, 0.12888200E+03, 0.67964200E+02, -.22121200E+02, 0.10498900E+03, -.13361300E+03, 0.14446300E+03, 0.19885900E+03, 0.49198800E+02, -.40196200E+01, -.33619300E+02, -.10820800E+02, 0.32604600E+02, 0.22086500E+02, -.67273500E+02, -.22408000E+01, -.77078400E+01, 0.25814000E+02, -.31914900E+02, -.15462300E+02, -.24780200E+02, 0.45375000E+02, -.18042800E+03, 0.28728300E+02, -.12235200E+03, 0.29330800E+02, 0.14358000E+02, 0.69916600E+02, -.23205400E+03, -.20513200E+03, 0.28191500E+02, -.49670600E+02, -.27106700E+02, -.59077600E+02, 0.83838400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.67316200E+00, 0.42049400E+00, 0.14063600E+01, 0.66050600E+00, 0.72184200E+00, 0.73767400E-01, 0.32819900E+00, 0.76431000E+00, -.91377800E+00, -.56653600E-01, 0.38609200E-01, -.19781300E+00, 0.21571300E+01, 0.74856900E+00, 0.16737500E+01, -.86257600E+00, -.25598600E+00, -.40395900E+00, 0.16035700E+00, -.16920800E+00, 0.55732100E+00, 0.71909800E-02, 0.42287500E+00, 0.19906300E+00, 0.92023200E-01, -.92068800E-01, -.93658800E+00, 0.53598100E-01, 0.94212600E-02, -.76760900E+00, -.21102800E-01, -.77125000E+00, -.57059900E-01, 0.34658800E+00, -.18365900E+00, -.48047300E+00, -.31339400E-02, 0.50307200E-01, -.26762900E+00, -.45787200E+00, -.17851400E+00, -.12994700E+00, 0.72217600E+00, -.90223100E-02, -.12640500E-01, 0.75773700E-01, -.34336100E-01, -.38215400E-02, -.36882000E+00, 0.81615800E-01, 0.19550100E+00, -.75133700E+00, 0.73039100E-01, -.90985700E-01, 0.47288700E-02, 0.23538400E+00, 0.17919400E+00, 0.12196900E+00, 0.29676700E-01, -.16246900E+00, 0.89240000E-02, -.88691800E-01, -.52731200E-01, -.91410600E+00, 0.12845700E+01, 0.21825200E-01, 0.16005200E-01, -.11190000E+01, -.81330800E+00, -.17843800E-01, -.28625400E+00, -.10436000E+00, 0.30190500E-01, 0.17278900E+00, 0.64491600E-01, 0.61363700E-01, -.36033100E-01, -.13657000E+00, 0.56135800E-02, -.69738000E-01, 0.17689500E-01, 0.17157800E+00, -.16820900E+00, -.37126600E+00, 0.16763300E+00, 0.35479200E+00, -.11233800E+00, -.23692000E+00, 0.21506700E+00, -.52137500E+00, 0.26091800E+00, 0.49266800E-01, 0.67927800E+00, -.48200800E-01, -.13914000E+00, -.21509100E+00, -.32813700E+00, -.36208400E+00, -.10536800E-01, 0.30820800E+00, 0.12316900E+00, -.56032600E-01, 0.84726900E-02, -.43042200E+00, -.52716300E+00, -.11283900E+00, 0.60399600E-01, 0.17641700E+00, -.46679400E-01, -.94435300E-01, 0.84375200E-01, -.45148600E-01, 0.10864900E+00, 0.28561800E-02, -.85722100E-01, -.27647300E-01, 0.65106100E+00, 0.62400600E+00, -.34960600E+00, -.12217600E+00, 0.26954800E+00, 0.23121900E+01, 0.32976700E+01, -.35174600E+00, -.51313000E-02, 0.50986600E+03, 0.21476400E+03, 0.63425100E+02, -.54945400E+02, -.38731100E+03, 0.19863300E+03, 0.57974600E+03, 0.48176300E+03, -.24614800E+03, -.40634400E+03, -.24097000E+03, 0.46281100E+01, 0.32092400E+02, -.33153700E+03, -.19627600E+03, -.28617900E+03, 0.85269800E+02, -.30323000E+02, -.25657000E+04, 0.12826700E+04, -.12062800E+04, 0.12828400E+04, -.30396500E+03, -.25223200E+03, 0.98604200E+03, 0.56932100E+03, 0.76696400E+03, -.18884800E+03, 0.23098400E+03, 0.26144300E+03, -.13135100E+03, -.14177400E+03, -.13053400E+03, -.78089000E+02, -.17686300E+03, 0.12071700E+03, 0.13045900E+03, 0.52076200E+02, -.15592300E+03, -.89756600E+02, -.24074700E+03, 0.12229800E+03, 0.38474400E+02, 0.12038900E+03, 0.30254200E+03, 0.97806000E+02, -.10707300E+03, -.26541500E+03, -.24234300E+03, 0.20914100E+03, -.64942200E+03, -.90367600E+03, 0.45317000E+03, 0.39773100E+03, 0.45186400E+03, 0.14160200E+03, -.29851000E+03, 0.36389500E+03, 0.26510700E+03, 0.44992400E+03, -.42551400E+03, -.73967700E+03, 0.12417200E+04, -.62037700E+03, 0.15239400E+04, -.62084500E+03, 0.48100600E+03, 0.21297000E+03, -.74710400E+03, -.59000100E+03, -.50406000E+03, 0.30674300E+03, -.27683700E+03, -.14520600E+04, 0.72344200E+03, 0.37950700E+03, 0.72625600E+03, -.25364600E+02, 0.55174400E+03, -.24912300E+03, -.55976700E+03, 0.46381300E+03, 0.55850700E+03, 0.17128700E+03, -.85347400E+03, 0.42464400E+03, -.11632600E+01, 0.42669300E+03, -.12246700E+03, -.86310400E+02, 0.13319500E+03, -.51797100E+02, 0.46635100E+03, -.10648700E+03, 0.73328100E+03, -.86394700E+03, 0.43227100E+03, -.20729500E+03, 0.43199500E+03, -.27222600E+03, -.29690800E+03, 0.36144300E+03, 0.42023500E+02, 0.29127500E+03, -.47409300E+03, 0.13115600E+02, -.10031000E+04, 0.49961400E+03, 0.38875600E+03, 0.50164900E+03, 0.34117000E+03, 0.21699800E+03, 0.11738700E+03, -.12827700E+03, 0.82782600E+02, 0.26095000E+03, -.64706600E+03, 0.69119200E+03, -.34423500E+03, 0.25327800E+03, -.34555500E+03, 0.86408100E+02, 0.35755300E+02, 0.43138400E+02, 0.11869400E+03, -.36269000E+03, 0.17899200E+01, -.66074900E+03, -.48374000E+03, 0.24374500E+03, -.22073500E+03, 0.24198500E+03, -.17429400E+03, 0.19035900E+02, 0.19063500E+03, 0.17702700E+03, 0.46241400E+03, -.60221600E+02, -.23878600E+03, 0.71616000E+02, -.12085200E+03, -.39899200E+02, -.61523600E+02, -.24125200E+02, -.13264600E+03, -.14806100E+03, -.71444700E+02, 0.39441100E+02, 0.72149700E+02, -.18654900E+03, 0.15270600E+03, -.63560800E+02, 0.14839300E+03, -.46576600E+03, -.58990600E+02, -.20561200E+03, 0.13261600E+03, -.62993700E+03, -.56475000E+02, -.20001000E+03, -.12398200E+03, -.64304500E+02, -.13020800E+03, 0.60217300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11157200E+01, -.29228300E+00, -.10682500E+01, 0.78806300E+00, -.35791000E+00, -.87429800E-01, -.56181300E+00, -.10855800E+01, 0.10720800E+01, 0.23855900E+00, 0.67336300E-01, 0.30994300E+00, -.12103000E+01, -.30317100E+00, -.53747500E+00, -.70444500E+00, -.27998700E+00, 0.62726000E+00, 0.20243800E+00, 0.99837200E+00, 0.51253800E-01, -.14863400E+00, 0.41843900E+00, -.94205100E-01, 0.64770600E-01, -.28745700E-01, -.11250800E-01, 0.18458600E+00, -.35356300E+00, -.10280600E+01, 0.30040900E+00, 0.11663200E+00, -.11915500E+00, -.14984100E+00, -.20913000E+00, -.56446200E+00, -.26496700E-01, -.11432400E+01, 0.56976200E+00, -.73091500E+00, -.77321700E+00, 0.25945100E+00, 0.11254100E+01, 0.17107000E+00, -.39893100E+00, -.41548100E+00, 0.16450800E+00, -.32207800E-02, -.85182500E+00, 0.51503800E+00, -.43761700E+00, -.22730600E+01, 0.90123100E-01, -.13832700E+00, -.80031000E-01, 0.10572800E-01, -.90044000E-01, -.10377400E+01, -.11089300E-01, 0.67965400E+00, 0.24058900E-01, -.63130100E+00, 0.43687100E+00, -.32573100E+00, 0.13534400E+01, 0.18913200E+00, -.24649900E+00, -.25587600E+01, -.12411200E+01, -.28943300E+00, 0.16752700E+01, 0.11190400E-01, 0.37976400E+00, -.10373800E+00, -.12236400E+00, 0.12124000E+00, -.21315100E-03, 0.45605800E+00, 0.10540400E+00, -.65716000E-01, 0.13813500E+00, -.49445600E+00, 0.85914800E+00, 0.23158300E+01, 0.11712400E+01, -.22745700E+00, 0.18798600E-01, 0.20253800E+00, 0.46567600E-01, 0.56005600E+00, 0.20627200E+00, 0.12062700E+00, -.54753600E+00, 0.14675000E+00, -.46074300E+00, 0.40663700E+00, 0.18418800E+01, -.27965900E+00, 0.50304200E+00, -.10023000E+01, -.41304400E-03, -.29369300E-02, -.59244900E-02, 0.98415400E+00, -.17587800E+00, -.32751500E-01, -.22684900E+00, -.65348400E+00, 0.10139700E+01, -.42587900E+00, -.46243500E+01, -.70505800E+00, 0.20252000E+00, -.46120800E-02, -.70086500E-01, -.38264800E+00, -.13950800E+01, -.18700400E+01, 0.13611600E+01, -.24418300E+00, 0.39039600E+00, -.13429200E+00, -.49031900E+01, 0.11107800E+01, 0.24346600E-01, -.57984400E+00, -.31306400E+03, -.44975300E+02, -.35445300E+03, 0.21174900E+03, -.47751500E+03, -.58320200E+03, -.67073000E+03, 0.32949800E+03, 0.72412400E+03, 0.33572000E+03, 0.81069400E+02, -.13471300E+02, 0.35780000E+03, 0.12409500E+03, 0.24232300E+03, 0.17730200E+02, 0.80629300E+02, 0.80983400E+04, -.40456800E+04, 0.10881100E+03, -.40491100E+04, -.62174400E+03, -.54961600E+03, -.88526800E+03, 0.12141600E+04, -.17009100E+04, -.25193400E+03, -.30260300E+04, -.64814900E+03, 0.29260700E+03, 0.38741500E+03, 0.32358300E+03, 0.19112300E+03, 0.31656500E+03, -.25526100E+03, -.27338100E+03, 0.14851300E+02, 0.30870300E+03, 0.25897100E+03, -.10897400E+04, 0.54337700E+03, 0.24999000E+03, 0.54331300E+03, -.23266600E+03, 0.28449700E+03, 0.36723600E+02, -.19471400E+03, 0.15498400E+02, 0.27636300E+03, 0.16530700E+04, -.95414200E+03, 0.47497500E+03, 0.12642000E+03, 0.47697300E+03, -.52094800E+03, 0.14168500E+03, 0.24700700E+03, 0.27189100E+03, 0.98607000E+02, 0.17582100E+03, 0.23966600E+04, -.60287100E+04, 0.30128200E+04, -.34027500E+03, 0.30142900E+04, 0.82759900E+02, -.16260600E+03, 0.11516600E+04, -.60041500E+03, 0.16773000E+04, -.28701000E+03, 0.24419900E+04, 0.22656400E+04, -.11325200E+04, -.13844200E+04, -.11337100E+04, -.67366600E+03, -.10347300E+04, 0.67757500E+03, 0.13950600E+04, -.21615000E+03, -.83587500E+03, -.33611200E+03, 0.42570500E+03, -.21226900E+03, -.28390500E+03, -.21268000E+03, 0.26769000E+03, -.39997800E+03, 0.21238000E+03, 0.28799000E+03, 0.21204600E+03, -.44302300E+03, -.72705700E+03, 0.54861800E+02, -.27037200E+02, 0.26075600E+03, -.27516600E+02, 0.11958600E+03, 0.24252700E+03, -.18439400E+03, 0.22251400E+03, -.35836600E+03, 0.32510900E+03, 0.59070900E+03, 0.13736500E+04, -.68343300E+03, -.90790700E+03, -.68721000E+03, -.27056400E+03, -.48724300E+03, 0.20090100E+03, 0.71829800E+03, 0.18682700E+03, -.22533100E+03, 0.35164400E+03, -.68179100E+03, 0.34204100E+03, 0.10906900E+03, 0.34071900E+03, 0.14688700E+03, 0.43764700E+03, -.23483900E+03, -.28143300E+03, 0.20725100E+01, 0.42818300E+03, 0.34793600E+03, 0.14074600E+04, -.71029800E+03, -.51046300E+03, -.70419100E+03, -.31693200E+03, -.42654600E+03, -.48172800E+02, 0.42088400E+03, -.61023900E+03, -.35923400E+03, 0.29402900E+03, -.99387600E+02, 0.86642500E+02, -.90286100E+02, -.71807400E+02, -.17273300E+03, -.18418600E+03, -.16780800E+03, -.44299500E+02, 0.92086100E+02, -.10991600E+03, -.10537600E+03, 0.11670200E+02, -.10448200E+03, 0.86201600E+01, 0.16796500E+03, -.66768100E+02, -.77991600E+02, -.46521000E+02, 0.13729400E+03, -.12838400E+02, 0.61999700E+02, -.54614600E+02, 0.19597000E+03, 0.80467700E+02, 0.97988300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12869600E+01, -.74712100E+00, -.16680400E+01, 0.12802800E+01, -.24564200E+01, -.44497500E+00, -.43240800E+00, -.52606400E+00, 0.27929100E+01, 0.82838400E+00, 0.16681500E+00, -.30567200E+01, 0.25940900E+01, 0.15937100E+01, -.80202100E+00, 0.19572600E+01, 0.18412600E+01, -.23601100E+00, -.28284600E+00, 0.84326700E+00, 0.54660800E+00, 0.86967500E-01, -.12776100E+00, 0.26332000E+00, -.22509600E-01, -.52931700E-01, 0.69639100E+00, -.31931000E-01, -.12764600E+00, -.82276600E+00, -.60929600E+00, 0.67877600E+00, -.68610600E-01, 0.81239100E+00, 0.34911900E+00, 0.41400600E+00, 0.57955700E-02, -.72770700E+00, 0.40711200E+00, -.71707700E+00, 0.17340800E-01, -.20846200E+00, 0.19294600E-01, -.26296100E+00, 0.23737600E+00, 0.89778000E+00, 0.50053100E-01, -.26692000E-02, -.10059100E+01, 0.59784000E+00, 0.27414600E+00, -.19645800E+00, 0.16291100E+00, 0.63438800E+00, -.53664100E-01, -.44112900E+00, -.77041900E+00, -.24026600E+01, -.45280300E-01, 0.10484100E+01, -.68916900E-01, 0.55226900E-01, 0.16177200E+00, -.35576400E+00, -.27796800E+00, 0.66688800E-01, -.58723300E-01, -.28880000E+00, -.13435100E+00, -.16833900E+00, -.94684700E+00, -.63043100E+00, -.48410400E+00, -.69793900E-01, 0.18358400E+00, -.53717100E+00, 0.96767300E-02, 0.28257600E+00, 0.20584600E+00, -.49728300E+00, 0.19447400E-01, -.45859200E+00, 0.86357000E-01, 0.65921100E+00, -.16530900E+01, 0.59459900E+00, 0.38647600E+00, -.14969300E+00, -.12399300E+00, 0.85886500E+00, -.26907700E-01, -.11205600E+00, 0.11039300E+01, -.48287200E+00, 0.16777800E+01, -.17766500E+01, -.11748500E+01, -.58770600E+00, -.44179400E+00, 0.13487700E+01, -.28771500E-01, -.56497200E+00, 0.82794300E-02, 0.15821100E+01, 0.30243300E+00, -.65863200E+00, -.63674300E-01, -.26701900E+00, -.14473800E+01, 0.65724100E+00, 0.23303800E+01, -.21578500E+00, -.62272600E+00, 0.31444300E-02, 0.13601800E+00, 0.28973000E+00, 0.70060900E+00, 0.11346600E+01, -.54600700E+00, 0.61971700E-01, -.94716800E-01, -.13151900E+01, -.46755600E+01, 0.19575300E+01, 0.25534000E-01, -.14022700E+01, 0.28871500E-01, -.54516900E+03, -.20124300E+03, 0.12076600E+04, 0.60179300E+02, -.15476700E+04, -.13428100E+03, 0.59435000E+02, 0.33591400E+03, 0.67452500E+02, 0.24863200E+02, -.12650600E+03, 0.22376500E+03, 0.19033500E+03, 0.35083000E+03, -.63053600E+02, 0.67091100E+02, 0.12019800E+05, -.60057600E+04, -.29177300E+04, -.60098500E+04, -.10680100E+04, 0.13664900E+04, -.24892000E+04, 0.14116900E+04, -.51815500E+04, 0.13064900E+04, -.18116600E+04, -.33080800E+03, 0.14227000E+03, -.16836000E+03, 0.16461600E+03, 0.80566500E+02, 0.52878700E+02, -.14394400E+03, -.95821300E+02, 0.22125200E+03, 0.78707400E+02, -.72063300E+01, 0.97358500E+03, -.48461900E+03, -.35694600E+02, -.48674000E+03, -.32960000E+03, 0.15479600E+03, -.53573400E+03, -.32276500E+03, -.36253700E+03, 0.27566500E+03, 0.15687000E+04, 0.21602600E+04, -.10790900E+04, -.93499400E+03, -.10802000E+04, 0.23743100E+03, 0.47278700E+03, -.79874900E+03, -.54662200E+02, -.42498000E+03, 0.64785900E+03, -.68023100E+03, -.76507500E+04, 0.38245800E+04, 0.12222400E+04, 0.38253200E+04, 0.52496600E+03, -.10644100E+04, 0.15799100E+04, -.78002500E+03, 0.34903000E+04, -.11842600E+04, 0.20303500E+04, 0.16757300E+04, -.83970700E+03, -.70993500E+03, -.83860900E+03, -.33633900E+03, -.77054300E+03, 0.12434400E+04, 0.11724900E+04, -.11119000E+04, -.87328300E+03, 0.11289400E+04, -.98556800E+03, 0.49364900E+03, 0.10947300E+04, 0.49292600E+03, 0.82936700E+03, 0.34349700E+03, 0.44327600E+03, 0.45961200E+03, 0.37606900E+03, 0.74999900E+02, -.56965800E+03, 0.12077000E+04, -.60247500E+03, 0.26307600E+02, -.60392000E+03, 0.25365500E+03, 0.23727800E+03, -.64072400E+03, -.43770700E+03, -.36612400E+03, 0.69152500E+03, -.59992100E+03, 0.16057000E+04, -.80378700E+03, -.93991100E+03, -.80315900E+03, -.51276400E+03, -.91592800E+03, -.16089800E+03, 0.23838300E+03, -.70285400E+03, -.85530800E+03, 0.27922700E+04, -.10105800E+04, 0.50837500E+03, 0.15275400E+03, 0.50515800E+03, -.44964000E+03, -.81684900E+03, 0.32573300E+03, -.13570500E+03, 0.42231000E+03, -.64067300E+03, 0.10508000E+04, 0.90230700E+03, -.44984500E+03, -.63638000E+01, -.45154100E+03, 0.47810700E+03, 0.89269500E+03, -.64417200E+03, -.60384900E+03, -.14793500E+04, 0.10933500E+04, -.34905700E+03, -.76867900E+02, 0.23700800E+03, 0.23853100E+02, 0.49875100E+02, 0.46769400E+02, 0.20450500E+03, 0.19164000E+03, 0.66863800E+02, -.22958900E+02, -.73492300E+02, 0.21216300E+03, -.15987200E+03, 0.48290600E+01, -.15199300E+03, -.25105900E+02, 0.54802100E+02, 0.15624800E+03, -.42990800E+02, 0.33250100E+02, 0.34210100E+02, 0.23680000E+03, 0.16394400E+03, -.48080400E+02, 0.31337000E+03, -.45331000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.47295200E+00, -.22580300E+00, -.59224800E+00, 0.19338300E+00, 0.21124100E+00, 0.88571300E-01, -.60603200E+00, -.85051300E+00, 0.27147800E+00, 0.24492800E+00, 0.77944300E-02, 0.25346100E+01, 0.78387800E-01, -.24155700E+00, 0.22851700E+00, -.13315900E+01, -.10146700E+01, -.24682600E+00, 0.29937900E+00, -.11208000E+01, -.44776500E+00, 0.52270500E-01, -.79335500E-01, -.59233500E+00, 0.90404900E-01, -.40869700E-02, -.12001000E+01, 0.24035900E+00, -.26621100E+00, -.66289300E+00, -.56786000E-01, 0.32594300E+00, -.14819100E+00, -.48989600E+00, 0.18644700E+00, 0.17398300E-02, 0.38761100E-02, -.62621500E+00, 0.15148800E+00, -.21948600E+00, 0.29212300E+00, 0.34432900E+00, 0.13421500E-01, 0.51512000E-01, 0.42908500E-01, -.12945000E+00, -.40239300E-01, 0.91103900E-03, 0.14938400E-01, 0.26985500E+00, 0.18409200E+00, -.35219700E+00, -.79723300E-02, -.31404900E+00, -.26760100E-01, -.23728900E-01, 0.15658500E+00, -.43332300E+00, -.15935600E-01, -.20448100E+00, -.19484400E-01, -.90258300E-01, -.49009200E-01, 0.17776000E+00, -.26545300E+00, -.19872100E-01, -.41606900E-01, -.52234300E-01, -.11121900E-01, 0.96432400E-01, 0.27058400E+00, 0.68496400E+00, -.45083100E-01, -.42739300E-02, -.32115100E+00, 0.48912000E+00, -.23359900E-01, -.42166300E+00, 0.12454800E+00, 0.11670300E+00, -.25158900E-01, 0.34623000E+00, -.18748300E+00, -.23913200E+00, 0.56958600E+00, 0.20688300E+00, -.45357800E-01, -.31099500E+00, 0.81241100E-01, -.35320300E-01, -.28502200E+00, -.28175100E-01, -.30986500E+00, -.10075800E+00, -.18334900E-01, 0.29701800E+00, 0.27261800E+00, -.69079500E+00, 0.13028100E+00, -.45119600E+00, -.53590200E-01, 0.13544300E+00, -.31932200E-02, -.25394500E+00, 0.23310200E+00, -.94963000E-01, 0.52353900E-02, -.20734200E+00, 0.33524900E+00, 0.29493800E+00, 0.60797700E+00, -.92914900E-01, -.14999000E+00, -.10870800E-02, -.23241800E-01, -.81650400E-01, 0.79405300E+00, -.12706900E+00, -.76550500E+00, -.31698400E+00, 0.21808400E+00, 0.78298800E-01, -.74302900E+00, 0.58807600E+00, 0.12489600E-01, -.23553400E+00, 0.90854500E-01, -.27025600E-01, 0.19398700E+03, 0.24811000E+03, -.28307100E+02, -.39103300E+03, -.24633900E+03, 0.12216400E+03, 0.16835300E+03, 0.12332900E+03, 0.16207000E+02, 0.22712400E+02, 0.93050500E+02, 0.35122800E+02, 0.12496700E+03, 0.25122600E+02, 0.10634000E+03, 0.20973200E+04, -.10452100E+04, -.26319100E+03, -.10486400E+04, 0.41633700E+02, 0.37104900E+03, -.43010900E+03, 0.29756300E+03, -.10584600E+04, 0.30272700E+03, -.53669900E+03, -.29330300E+03, 0.13512500E+03, 0.47145100E+02, 0.14657600E+03, 0.20970900E+02, 0.56846800E+02, -.14526100E+01, -.74389100E+02, 0.50306400E+02, 0.58758000E+02, 0.12589800E+03, 0.26325900E+03, -.13094800E+03, -.78029000E+02, -.13182500E+03, -.13295300E+03, -.36535200E+02, -.10101500E+03, -.31838200E+02, 0.49031600E+02, -.19019300E+02, 0.52156800E+03, 0.79778900E+03, -.39815700E+03, -.30414300E+03, -.39893000E+03, -.30812800E+01, 0.19401200E+03, -.32950500E+03, -.11830000E+03, -.29520300E+03, 0.23649900E+03, 0.61657100E+01, -.14704100E+04, 0.73361000E+03, -.50684000E+02, 0.73518100E+03, -.98354500E+02, -.38176800E+03, 0.36441500E+03, -.16059200E+03, 0.76672700E+03, -.32527000E+03, 0.56684100E+03, 0.59098900E+03, -.29628400E+03, -.16281000E+03, -.29585800E+03, -.65931900E+02, -.17453300E+03, 0.19434700E+02, -.50523700E+02, -.34784100E+03, -.15151900E+03, 0.11572800E+03, -.98481300E+02, 0.49000800E+02, 0.17633400E+03, 0.49310100E+02, 0.15096300E+03, 0.11991400E+03, 0.39405900E+02, 0.12614500E+03, -.61893800E+02, 0.80068100E+02, -.27026400E+03, 0.41425900E+03, -.20540900E+03, -.73934700E+02, -.20716600E+03, 0.69796700E+02, 0.27734300E+02, -.20625200E+03, -.20448700E+03, -.18247500E+03, 0.10866000E+03, -.10407300E+03, 0.66857600E+03, -.33351400E+03, -.25115000E+03, -.33443800E+03, -.89728400E+02, -.17124500E+03, -.56834600E+02, 0.11596500E+03, -.29077100E+03, -.17066200E+03, 0.25048100E+03, 0.75544300E+01, -.24355200E+01, -.15053500E+02, -.38588600E+01, -.79398900E+02, -.94369400E+02, 0.28818800E+02, 0.26728000E+02, 0.29779800E+02, -.92247100E+02, 0.12424800E+03, 0.31027800E+03, -.15589000E+03, -.41634300E+02, -.15533600E+03, 0.10037200E+03, 0.85510500E+02, -.16012900E+03, -.24521900E+03, -.28854200E+03, 0.14481000E+03, -.33744500E+02, -.34415700E+02, 0.40653000E+02, 0.13901800E+02, 0.35135000E+02, 0.27981100E+02, 0.41995700E+02, 0.40811200E+02, 0.35405400E+02, -.13962100E+02, -.32221300E+02, 0.66065700E+02, -.54523300E+02, 0.23151500E+02, -.57726700E+02, -.50900500E+01, 0.29812600E+02, 0.52717500E+02, -.65722500E+01, 0.34663600E+01, 0.17134300E+02, 0.44644600E+02, 0.43583300E+02, -.30506500E+02, 0.41390900E+02, -.39475800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.97899600E+00, 0.18253800E-01, -.25392000E+00, -.25592800E+00, -.40990500E+00, 0.60518800E-01, 0.51545600E+00, -.24850300E+00, 0.91592500E+00, -.17007300E+00, 0.55251200E-01, -.20969900E+01, -.49981600E+00, 0.17855300E+00, -.11563100E+01, 0.71576800E+00, 0.14467800E+01, 0.14929000E+01, -.10087000E+00, 0.31682000E+01, -.58194600E+00, 0.36816900E-01, -.57705700E-01, 0.17661100E+01, -.11383800E+00, 0.14331800E+00, 0.10104600E+01, -.28171500E+00, 0.30845400E+00, -.74754500E+00, 0.79798400E+00, -.11865800E+01, -.62445100E-01, 0.10034900E+01, -.81450900E+00, 0.27611700E+00, 0.27574700E-01, 0.30116500E+00, 0.26115500E+00, -.43348000E+00, 0.10818900E+01, 0.18699100E+00, -.18451300E+00, 0.53863100E-01, 0.16523900E+00, -.18235500E+00, -.55211700E+00, 0.11311200E-01, -.29104000E+00, 0.69300600E+00, 0.12141500E+01, -.69889000E+00, 0.10514100E+00, -.62524200E+00, -.20559700E+00, 0.41831000E+00, -.32001000E+00, -.15404800E+01, 0.78674700E-01, -.10266300E+00, -.14826100E+00, 0.46554300E+00, -.21002700E+00, -.15108500E+01, -.39277800E-01, -.18580200E+00, 0.11725400E+00, 0.32340500E-01, 0.25322400E+00, -.84277300E-01, -.14212300E+01, 0.40584600E+00, -.56708100E+00, 0.20961600E+00, 0.20041000E+00, -.52815900E+00, -.34110300E-01, -.18498900E+00, -.79956700E-01, -.22602500E+00, 0.51847300E-01, 0.14138600E+00, 0.14950100E-01, -.79271400E-01, -.98144500E+00, 0.40397300E+00, 0.13856400E+00, -.33743500E+00, 0.67411700E-01, 0.16391700E-01, 0.16359000E-01, -.68626600E-01, 0.39836100E+00, -.19402100E+00, 0.78660500E+00, -.78637000E+00, -.11230700E+01, -.61937200E+00, -.26386100E+00, 0.34469600E+00, 0.82791900E-01, -.47471000E+00, 0.99016600E-02, 0.37967800E+00, 0.24497200E+00, -.17173100E+00, -.46880100E-01, -.89150100E+00, -.85892400E+00, 0.18805800E+00, -.58677600E+00, -.17548200E+00, -.33087000E+00, 0.18761600E-02, 0.27109500E+00, 0.15067200E+00, -.80080400E+00, 0.11225100E+01, -.20511900E+01, 0.26327400E+00, -.25845700E-01, -.27060900E+01, 0.19003700E+01, -.11542400E+01, -.88840400E-02, 0.56820100E+00, -.53678400E+00, 0.56318300E-01, -.34678600E+00, -.76534600E+03, -.12215000E+03, 0.15340600E+04, 0.20245800E+02, -.53632200E+01, -.27570500E+03, -.10002800E+02, -.60930600E+01, 0.15901100E+03, -.78511400E+02, -.18108400E+02, -.16343300E+03, 0.15070100E+03, -.79589000E+02, -.94980700E+02, 0.47313000E+02, -.15731400E+04, 0.47511300E+02, 0.70941800E+03, -.28486300E+03, 0.18370600E+03, 0.35993100E+03, 0.97129200E+03, -.27295200E+03, -.18377700E+04, -.20326900E+03, 0.10974700E+03, 0.16824000E+03, 0.10168700E+03, -.39343800E+02, 0.73669000E+01, 0.12334800E+03, 0.10134600E+03, -.49047300E+02, -.22860000E+02, 0.26812900E+03, -.10123800E+04, 0.50742500E+03, 0.27315700E+03, 0.50524600E+03, 0.48148000E+03, 0.11468100E+03, 0.20268200E+03, -.16472500E+03, -.28503600E+02, 0.33934200E+01, -.11711300E+04, -.16058900E+04, 0.80477200E+03, 0.89033800E+03, 0.80291300E+03, 0.75647500E+02, -.37216600E+03, 0.48419200E+03, 0.11890200E+03, 0.33337300E+03, -.44410600E+03, 0.67693300E+02, -.32394100E+03, 0.16018400E+03, 0.16100700E+04, 0.16194800E+03, -.57485200E+03, 0.10426200E+03, -.15153300E+02, -.38156800E+03, -.52060800E+03, 0.18781000E+03, 0.10288400E+04, -.16285900E+04, 0.81357800E+03, 0.56386100E+03, 0.81399500E+03, 0.36011300E+03, 0.64237300E+03, -.35052500E+03, -.71043700E+03, 0.89298400E+03, 0.70906500E+03, -.98791900E+03, 0.17388800E+03, -.87289000E+02, -.38790000E+03, -.86885100E+02, -.58363000E+03, -.22012400E+03, -.56803200E+02, -.74857300E+02, 0.14171000E+03, -.11974000E+03, 0.78525700E+03, -.26277900E+03, 0.13367200E+03, 0.71114300E+02, 0.13136000E+03, 0.23133000E+03, 0.15478700E+03, 0.11090600E+03, 0.39778300E+03, -.44911800E+02, 0.22303700E+02, -.59005700E+02, 0.15946900E+04, -.79782200E+03, -.51785200E+03, -.79747900E+03, -.11187600E+03, 0.44067400E+03, -.23835200E+03, 0.26761200E+03, -.19415800E+03, 0.34440800E+03, -.23558100E+04, 0.22998100E+03, -.11550500E+03, -.18705600E+03, -.11506400E+03, 0.80455000E+02, 0.31128400E+03, -.14352200E+03, -.43920700E+02, -.21143000E+03, 0.20001900E+03, -.19838500E+03, -.21268700E+03, 0.10524200E+03, 0.68378500E+02, 0.10618400E+03, 0.10230100E+03, -.29355900E+03, 0.37787900E+03, 0.64965000E+03, 0.66068000E+03, -.36939400E+03, -.28744200E+03, -.28335300E+02, -.61572300E+02, 0.78069100E+02, 0.10356400E+03, -.10367800E+03, -.95187300E+02, -.94131000E+02, 0.10737100E+03, -.76934700E+02, -.18474200E+02, -.12353500E+03, -.76849800E+02, -.50933700E+02, -.70560200E+02, -.17679400E+03, 0.10270300E+03, -.80425100E+02, -.15773200E+02, -.28802200E+03, -.63684300E+02, -.96326200E+02, -.59829100E+02, 0.93024300E+02, -.13031400E+03, 0.64038100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.39681100E+00, -.84744800E+00, -.12642400E+01, 0.69137600E+00, -.58996000E+00, -.15469500E+00, -.69477700E+00, -.76581100E+00, 0.13581400E+01, 0.25214800E+00, -.39869100E-01, 0.12837600E+01, -.16047900E+01, -.43150500E+00, -.64579700E+00, -.62620000E+00, -.47571100E+00, 0.25853500E+00, 0.20227000E+00, -.12852400E+00, -.68942500E+00, -.24524200E-02, -.10299900E-01, -.33380800E-01, -.13776900E-01, 0.34791500E-01, -.13745800E+00, 0.42498700E-01, -.44322700E+00, 0.52396000E+00, 0.47161800E-01, 0.66816000E+00, 0.16618800E-01, -.87706100E+00, 0.13841600E+00, 0.54401000E+00, 0.10119800E-01, -.37789700E+00, 0.35267600E+00, -.79467800E+00, -.34393100E-01, 0.12079200E+00, 0.36287100E+00, 0.91549900E-01, 0.86773000E-01, -.36735600E+00, -.14100000E+00, 0.35492200E-02, -.68360300E+00, 0.68221000E+00, 0.57631500E+00, -.14994800E+01, 0.83152700E-01, -.40274100E+00, 0.21651200E-01, 0.43578100E-01, -.45796100E+00, -.36443800E+00, 0.11610400E-01, 0.62377500E-01, -.21280400E-02, -.23432300E+00, -.11926400E-01, 0.83649900E+00, -.61507400E+00, 0.12100800E-01, -.98931500E-02, -.98649200E-01, -.32729500E-01, -.15463300E+00, 0.11052500E+01, 0.19584500E+00, 0.44810400E+00, 0.13521200E-01, 0.10516000E+00, -.28819700E+00, 0.72863300E-01, 0.73455400E+00, 0.12086400E+00, 0.84489000E-01, 0.45197800E-01, 0.16266300E+00, 0.16347100E-01, 0.20497700E+00, 0.39809600E+00, 0.61987100E-01, 0.68841200E-01, -.12088300E+00, 0.13123800E+00, -.32518600E+00, 0.30203200E+00, -.20629800E-01, 0.58600800E+00, -.24208800E+00, -.69640500E-01, -.35988200E-01, -.11370500E+00, -.46831800E+00, 0.79047400E-01, -.50785500E+00, -.12948500E-01, -.13760800E+00, 0.14601900E-02, -.20496000E+00, -.28368400E+00, -.67626800E-01, 0.14694300E+00, -.27153600E+00, -.87354400E-01, -.11430400E+00, 0.22697200E+00, -.31951400E-02, 0.11798300E+00, 0.19434100E-02, -.20296600E-01, 0.24683800E-01, -.33617200E-01, 0.45776100E+00, -.93445900E+00, -.12659800E+00, 0.22371500E+00, -.28056000E+00, 0.63301600E+00, -.37157800E-02, 0.64356100E-02, 0.51592000E-02, -.29944500E+00, 0.26704000E+00, -.72877700E+00, 0.16738600E-01, -.78784800E+02, -.14473300E+03, -.37744700E+03, 0.18764100E+03, 0.24917700E+03, 0.18897100E+03, 0.23088700E+02, 0.27075500E+02, 0.17288400E+03, 0.64280600E+02, 0.15437900E+03, 0.16349100E+02, 0.95407500E+02, 0.15673600E+04, -.78154600E+03, 0.18495500E+03, -.78364100E+03, 0.48058100E+02, -.60906800E+03, -.25457300E+02, 0.21323700E+03, -.13471300E+03, -.40932500E+03, -.11151300E+04, -.33095700E+03, 0.15999000E+03, 0.14654500E+03, 0.16537600E+03, 0.55457800E+02, 0.12475200E+03, -.42710300E+02, -.10961000E+03, 0.58214900E+01, 0.10946700E+03, 0.17286900E+03, -.21517800E+03, 0.10787700E+03, 0.33655500E+02, 0.10627000E+03, -.11957400E+03, 0.11036000E+02, 0.76017800E+02, 0.60189100E+02, 0.14130300E+03, -.36066200E+02, 0.50459800E+03, 0.73479800E+00, -.48540400E+00, -.16658200E-01, -.43317400E+00, -.24219800E+03, 0.11100600E+03, -.89899600E+02, -.88931600E+02, -.17589500E+03, 0.11952000E+03, 0.99864500E+03, -.13451400E+04, 0.67093400E+03, -.13117600E+03, 0.67252400E+03, -.16018900E+03, 0.25151000E+03, 0.27802300E+03, -.93116500E+02, 0.31626100E+03, 0.12823400E+03, 0.83610600E+03, 0.11203300E+04, -.56042400E+03, -.44026800E+03, -.56076800E+03, -.22224200E+03, -.42280900E+03, 0.91838900E+02, 0.35359000E+03, -.16345100E+03, -.32597500E+03, -.41907600E+03, 0.38265800E+03, -.19234200E+03, -.16926800E+03, -.19121100E+03, 0.76610600E+01, -.11427100E+03, -.29833900E+02, 0.53315700E+02, -.13684400E+03, -.83193600E+02, -.37013100E+03, 0.11814400E+03, -.58190700E+02, 0.22129800E+02, -.59131100E+02, 0.49278100E+02, 0.67273500E+02, -.12743800E+03, -.12413600E+02, -.13351300E+03, 0.86211400E+02, 0.25908200E+03, 0.34535100E+03, -.17223900E+03, -.16627900E+03, -.17293800E+03, -.59952500E+02, -.27020400E+03, 0.16445100E+03, 0.19053800E+03, 0.15896900E+03, -.17412100E+03, -.30402400E+03, -.23159300E+03, 0.11663700E+03, -.28896200E+02, 0.11566900E+03, 0.10891800E+03, 0.24942000E+03, -.13094800E+03, -.11368100E+03, 0.13865700E+02, 0.23431400E+03, 0.12736600E+03, 0.47376200E+03, -.23792800E+03, -.13589000E+03, -.23719900E+03, -.93645100E+02, -.24379600E+03, -.13543800E+02, 0.34463800E+02, -.21172800E+03, -.21830200E+03, 0.17991000E+03, -.34021400E+02, 0.26985200E+02, -.19257100E+02, -.19267800E+00, -.35005200E+02, -.37353500E+02, -.27694800E+02, 0.69710300E+01, 0.19544200E+02, -.44426000E+02, -.12618900E+02, -.28514200E+02, 0.36836500E+02, -.30717300E+02, 0.17296800E+03, -.21311800E+01, 0.21165100E+01, -.31488400E+02, 0.12936700E+03, 0.41785900E+02, 0.18724800E+02, 0.26509400E+01, 0.30288100E+02, 0.21718000E+02, -.84181100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18469200E+01, 0.15880900E+00, -.63139900E+00, 0.23138300E+01, 0.12895400E-02, -.13850000E+00, -.19241200E+01, -.29191900E+01, 0.89800600E+00, 0.39105700E+00, 0.22594100E+00, 0.11547300E+01, -.26766300E+01, -.21098800E+00, 0.19938000E+01, 0.40436000E+01, -.25379900E+01, -.70003000E+00, 0.25680300E+00, -.17623100E+01, -.42160900E+01, -.23069300E+00, 0.12699200E+01, -.14272000E+01, 0.50621700E+00, 0.33794100E+00, -.31233500E+01, -.70474300E+00, -.11619500E+01, -.40633000E+00, -.58026600E+00, 0.32128200E+00, 0.80342000E-01, 0.11406800E+00, 0.82261900E+00, 0.62379600E+00, -.48247100E-01, 0.57383600E+00, -.27174700E+00, -.26486800E+00, -.13006800E+01, -.12888600E+01, 0.89485700E+00, -.59302000E-01, 0.57595700E+00, 0.39230600E+00, 0.43294800E+00, -.19513500E-01, -.37563200E-01, 0.11171100E+01, 0.33390700E-02, -.73296300E+00, 0.14369900E+00, 0.85345700E+00, 0.18880700E+00, 0.29926800E+00, -.47380100E-01, -.34703800E+01, -.17412800E+00, 0.83056700E+00, -.73319000E-02, 0.21145800E+00, 0.26918800E+00, -.54722200E-01, -.10737000E+01, 0.87162600E-01, 0.86598500E-01, 0.25270200E+01, 0.45180400E-01, 0.74919400E+00, -.93201800E+00, 0.23199600E+01, -.82763700E+00, -.17545100E+00, -.61201000E+00, 0.71653700E-01, -.22960300E+00, -.42615300E+00, 0.11586900E+00, 0.15004300E+00, -.20451000E+00, 0.79522600E+00, 0.19009200E+00, 0.16270600E+01, 0.17316500E+01, -.59039100E+00, 0.20941200E+00, 0.46028900E+00, -.38568100E+00, 0.25870800E+00, -.52948100E+00, 0.28014100E+00, 0.55377600E+00, -.53948800E+00, 0.69103600E+00, 0.89178400E+00, 0.37569800E+01, 0.49381600E+00, 0.63026000E+00, -.14594700E+01, -.69017900E-01, 0.77792700E+00, -.23046200E+00, 0.30939700E+01, -.49178100E+00, 0.10148400E+01, -.14369500E+00, 0.20376400E+01, 0.16669700E+01, 0.40330300E+00, -.31041200E+01, -.26040600E+00, 0.42482500E+00, 0.15755900E+00, -.97849000E-01, -.37141100E+00, 0.23587100E+01, 0.81289000E-01, -.30761000E+01, -.14094300E+01, 0.69293400E+00, 0.44258100E+01, 0.46706700E+00, 0.11518300E+01, -.14793600E-01, 0.12247500E+01, 0.16138300E+01, -.23788600E+00, 0.17335800E+01, -.10787200E+00, -.16169300E+01, -.19087200E+04, -.80463800E+03, 0.41246300E+03, 0.63820700E+03, 0.40095400E+03, -.15407800E+03, -.29069500E+03, 0.56000100E+03, 0.29282100E+03, 0.84222000E+03, -.41260600E+03, 0.33004600E+03, -.49290400E+04, 0.24689600E+04, 0.18531600E+04, 0.24641400E+04, 0.25921000E+03, -.16220700E+03, 0.63411700E+03, -.10492600E+04, 0.13482300E+04, 0.41918600E+03, 0.45441800E+04, 0.11667100E+03, -.54484000E+02, 0.24899800E+03, -.46539300E+02, 0.12612000E+02, -.20725300E+02, -.10004700E+03, -.43895200E+01, -.76060700E+02, -.44225800E+02, -.15745500E+03, 0.63629400E+03, -.32045000E+03, -.69692300E+02, -.32174000E+03, -.85895100E+03, -.28572700E+03, 0.17657200E+03, 0.39969200E+03, 0.76608400E+03, -.53743300E+03, 0.12847100E+04, 0.21294600E+04, -.10659600E+04, -.65074000E+03, -.10638100E+04, 0.16226200E+03, 0.12934800E+03, -.65538900E+03, -.29692900E+03, -.78191600E+03, 0.18114000E+03, -.13079000E+04, 0.33414700E+04, -.16743900E+04, -.11710100E+04, -.16704100E+04, -.16596500E+03, -.33188100E+02, -.24938700E+03, 0.85193200E+03, -.81773400E+03, -.44657500E+03, -.31095800E+04, 0.15509300E+04, -.77179000E+03, -.25861600E+03, -.77163900E+03, -.20346600E+03, -.28259200E+03, 0.21743400E+03, 0.71032200E+03, -.20522600E+03, -.33337300E+03, 0.11399700E+04, 0.17590000E+04, -.87697200E+03, -.51691000E+03, -.88038300E+03, 0.33989500E+03, 0.25097400E+01, -.28258300E+03, 0.25875900E+03, -.10081900E+04, 0.15018700E+03, -.17587700E+04, 0.83818500E+03, -.41720900E+03, 0.24532300E+03, -.41881300E+03, 0.58567800E+02, -.60368200E+02, -.32310800E+03, -.36590700E+03, -.97765000E+02, 0.17120500E+03, 0.79814100E+02, -.26269200E+03, 0.13473100E+03, 0.42734800E+03, 0.13389300E+03, -.97343600E+02, -.54684500E+02, -.23643900E+03, -.25749900E+03, 0.17634700E+03, 0.16604600E+03, 0.17566300E+04, -.12563400E+04, 0.62725800E+03, -.14090700E+03, 0.62843600E+03, -.55738200E+02, -.66792100E+02, -.26578600E+02, -.14106700E+03, 0.63321700E+03, 0.17418300E+02, 0.79289500E+03, 0.56794000E+03, -.28595100E+03, 0.38690200E+03, -.28256500E+03, 0.31524700E+03, 0.21159200E+03, -.46844300E+03, -.78564300E+03, -.78979400E+03, 0.23594500E+03, 0.41445500E+03, -.44725400E+02, 0.14316300E+03, 0.12501200E+03, 0.55455600E+02, 0.13869300E+03, 0.38882400E+03, 0.39387100E+03, 0.62581200E+02, -.12518100E+03, -.36149200E+02, 0.38017800E+03, -.23466500E+03, 0.31699900E+02, -.23557800E+03, 0.28332500E+03, 0.56762200E+02, 0.41139400E+03, -.98699800E+02, 0.36362800E+03, -.79508600E+02, 0.39173300E+03, 0.19620700E+03, -.54722600E+02, 0.18412100E+03, -.77570100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.74901600E+00, 0.60624700E+00, -.37595700E-01, -.72495700E+00, 0.56210700E+00, 0.30556800E+00, 0.84821200E+00, 0.36275200E+00, 0.42219900E+00, -.30686400E+00, 0.59841300E-01, -.14857100E+01, -.62601100E+00, -.31426000E+00, -.10598900E+01, 0.10217700E+01, 0.82129800E+00, 0.30677700E+00, -.32806400E+00, 0.11655500E+01, 0.62110000E+00, 0.92879500E-02, 0.44890800E+00, 0.29250300E+00, -.35138200E-01, -.14760800E+00, 0.18405200E+00, 0.26975000E-01, -.13292100E+00, -.73782700E-01, 0.30754500E+00, -.11243400E+00, -.23781200E+00, 0.45700900E+00, -.32139800E+00, 0.25302000E+00, -.15380300E-01, 0.31022200E-01, -.47261300E+00, 0.72283300E+00, -.66314500E+00, -.30934200E+00, -.15888800E+00, -.12947100E+00, 0.10469900E+00, 0.11907900E-01, -.21992700E+00, -.34034900E-02, 0.25388600E+00, 0.43863400E+00, 0.11236000E+01, 0.15778600E+01, 0.23086400E+00, 0.57775300E+00, 0.69668300E-01, 0.64627500E-02, -.54380000E+00, 0.51365300E+00, 0.39791500E-01, -.20071400E+00, -.10538800E+00, -.11409000E-01, -.13050800E+00, 0.47954400E+00, 0.97040700E+00, -.22246200E+00, 0.13669500E+00, 0.64031800E+00, -.15395500E+00, 0.21895800E+00, -.17774800E+00, 0.11172600E+01, -.86787000E-01, -.89801400E-01, 0.87207900E-02, 0.16158900E+00, 0.78442900E-01, 0.60629500E+00, 0.45710800E-01, 0.17933700E+00, -.19856600E+00, 0.34208600E+00, -.27761800E+00, -.88062800E+00, -.92725300E+00, 0.86603200E+00, -.29524500E+00, 0.10694900E+00, -.28095600E-01, -.32611000E+00, 0.39457900E+00, -.30293100E-01, -.26003000E+00, -.19204400E+00, -.73638300E+00, 0.34733400E+00, 0.97989000E+00, -.94500200E-01, 0.97905400E-01, 0.90437400E-01, -.54663700E-01, -.31981900E+00, 0.11091400E-02, 0.10669200E+01, 0.11971600E+00, 0.15016100E+00, -.88810700E-01, -.69304000E+00, -.37835400E+00, 0.32125100E+00, -.63574300E-01, -.96150000E-01, -.17041000E+00, 0.97898300E-04, -.89235800E-01, -.68703600E-01, 0.14377200E+01, 0.26524200E+00, 0.73775000E+00, 0.13756500E-01, -.15500900E+00, 0.15125600E+01, 0.56633900E+00, 0.16594200E+00, -.47369000E-02, 0.41338900E-01, -.46120900E+00, -.14065800E+00, 0.18764700E+00, -.38915600E+00, 0.98182000E+00, 0.20963700E+00, 0.66302700E+03, -.33826900E+03, -.39800600E+03, -.33131700E+03, 0.82985000E+02, 0.99901000E+02, -.28101400E+03, -.13275900E+03, -.51452200E+03, 0.19271400E+03, -.17372000E+03, 0.56646100E+04, -.28345300E+04, -.14924500E+04, -.28322400E+04, -.25942000E+03, 0.10567300E+04, -.87175700E+03, 0.12760900E+04, -.17670300E+04, 0.78897600E+03, -.28078100E+04, 0.22905600E+03, -.10276400E+03, -.22896800E+03, -.11691500E+03, -.81439900E+01, -.79652300E+02, 0.54961700E+01, 0.82972100E+02, 0.45754100E+02, -.34932800E+02, -.19172500E+03, 0.16976000E+03, -.84096700E+02, -.98876600E+02, -.82052500E+02, 0.35103100E+03, 0.18114200E+03, -.30107600E+03, -.24988500E+03, -.62970500E+03, 0.38082300E+03, -.26107200E+03, -.14203000E+04, 0.70896100E+03, 0.44793700E+03, 0.70996800E+03, 0.29846200E+03, -.10352900E+03, 0.46216300E+03, 0.41155400E+03, 0.59821300E+03, -.69007300E+02, 0.33421800E+02, -.39836400E+04, 0.19951000E+04, 0.58184700E+03, 0.19917700E+04, 0.21614400E+02, -.10135400E+04, 0.64219800E+03, -.87490000E+03, 0.12734300E+04, -.74600900E+03, 0.23155200E+04, -.52073300E+03, 0.26070800E+03, -.18013000E+03, 0.25974100E+03, -.10848900E+03, -.14763400E+03, 0.15964400E+03, -.19138600E+03, 0.20875600E+03, -.11851200E+03, 0.52756400E+03, -.11121800E+04, 0.55532700E+03, 0.58702700E+03, 0.55624300E+03, 0.10143900E+03, 0.14975300E+03, 0.19866600E+03, -.10639300E+03, 0.73633500E+03, 0.28307900E+02, 0.64197600E+03, 0.42761500E+02, -.24861800E+02, -.33300700E+02, -.21420500E+02, 0.22190500E+03, 0.25414100E+03, 0.69467400E+02, 0.37610800E+03, -.29623000E+03, 0.14495500E+03, -.62576300E+03, 0.59287500E+03, -.30042000E+03, -.41851200E+03, -.29690400E+03, 0.15642900E+02, -.51419900E+02, 0.37439300E+01, 0.21873600E+03, -.19070200E+03, -.19557700E+02, -.10867800E+03, 0.85875900E+03, -.42847400E+03, 0.85806200E+02, -.42938400E+03, -.86652500E+02, -.52540400E+02, -.10313400E+03, 0.13366600E+03, -.25910700E+03, -.10166700E+03, -.38709100E+03, 0.13308000E+03, -.57412000E+02, -.26526200E+03, -.66731000E+02, -.37167900E+02, 0.23701000E+02, 0.29207600E+03, 0.73770900E+03, 0.38352200E+03, 0.22217900E+02, -.56205200E+03, -.15388100E+02, -.40888100E+02, -.22278700E+02, -.14457400E+02, -.11048200E+03, -.18112900E+03, -.19408300E+03, -.18002800E+02, 0.23237400E+02, -.15133300E+01, -.20323000E+03, 0.91268200E+02, -.29537000E+02, 0.97148900E+02, -.39764600E+03, -.96292100E+01, -.24704500E+03, 0.53153700E+02, -.44797900E+03, 0.18773800E+02, -.20174300E+03, -.11261000E+03, 0.82367500E+02, -.63480300E+02, 0.90942000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.55594500E+00, 0.31751900E+00, -.62617500E+00, 0.19037200E+00, -.88115000E+00, -.42956000E-01, 0.34857100E+00, 0.59310700E+00, -.10725800E+00, -.21876400E-01, 0.16043000E+00, -.11989400E+01, 0.32658000E+01, 0.63908100E+00, 0.12759000E+01, 0.40081400E+00, 0.45718600E+00, -.43259800E+00, -.24799100E+00, 0.49115200E+00, 0.14945000E+01, -.70341000E-01, -.39098500E+00, -.17518800E+01, -.24388400E+00, -.10583200E+00, -.59652800E+00, 0.61086400E-01, -.89322200E+00, -.80088700E+00, 0.11966400E+00, 0.64931000E+00, -.57025800E+00, -.48398500E+00, 0.27619500E-01, 0.20722000E+00, -.16272400E-01, -.94711800E+00, 0.31121900E-01, -.34716400E+00, -.78985400E-01, 0.15468100E+00, 0.57880100E+00, -.84069100E-01, 0.64234500E-01, 0.12687700E+00, 0.37573400E+00, -.67705000E-02, -.12479000E+01, 0.46869300E+00, -.86162300E-01, -.10449800E+01, 0.53982600E-01, -.14164600E+00, -.99912500E-01, 0.20968200E+00, 0.12912000E-02, -.83028200E-01, -.26515100E-01, 0.36407300E+00, 0.10476000E-01, -.25224100E-01, -.11304400E-01, 0.46967500E+00, -.54302200E+00, 0.93559300E-01, -.65070100E-02, 0.57291100E+00, -.53652200E-01, -.57772500E-01, -.10072000E+01, 0.10867500E+00, -.41730400E-01, 0.17405100E+00, 0.30072400E+00, -.63736400E+00, -.18067200E-02, 0.15233600E-01, -.12146300E+00, 0.13473900E+00, 0.97026100E-01, 0.62473000E-01, 0.24035100E+00, 0.67446200E+00, 0.67459200E+00, -.40974800E+00, 0.81815400E-01, 0.11345700E-01, -.17061800E+00, 0.42506300E+00, -.82117700E+00, 0.22215500E-01, -.77682400E+00, 0.36524400E+00, -.21536700E+00, 0.54518000E+00, 0.94054100E+00, 0.31129900E-01, 0.21753200E-01, -.29090600E+00, -.32985200E-01, 0.12692700E+00, -.39887500E-02, 0.62192500E-01, 0.11166700E+00, 0.16057600E+00, -.59837300E-03, -.40543200E+00, -.22400400E+00, -.73105700E-01, -.15312800E+01, 0.12687700E-02, 0.18774400E+00, -.10135800E-02, 0.30670500E-01, 0.39458200E-01, -.19580100E+01, -.80941600E+00, -.68829700E+00, -.19660000E+00, 0.83178400E-01, -.12784000E+01, -.12665500E+01, 0.39182700E+00, -.89432400E-02, -.84729500E-01, 0.28849500E+00, 0.30094900E+00, 0.69733300E+00, 0.24725800E+00, -.90060200E+00, -.11743600E+00, -.53731100E-01, 0.77395100E+01, 0.25418700E+03, -.40149500E+00, -.10543400E+03, -.14723900E+03, 0.19509800E+03, 0.17469300E+03, 0.98596400E+02, -.21436400E+03, -.10049200E+03, -.58064500E+04, 0.29014900E+04, 0.28471100E+04, 0.29031500E+04, 0.34771200E+03, -.57235600E+03, 0.65459800E+03, -.14613800E+04, 0.21880700E+04, -.36574100E+03, 0.20340000E+04, 0.27525800E+03, -.10966700E+03, 0.20692500E+03, -.13561700E+03, -.10057100E+02, 0.92190200E+02, -.69036500E+02, 0.10977500E+02, -.21037200E+03, 0.66550200E+02, -.80691100E+02, -.12714800E+03, 0.66718100E+02, 0.93216700E+02, 0.63000900E+02, -.26024700E+03, -.15197600E+03, 0.38500700E+03, 0.31588700E+03, 0.20727600E+03, -.32549200E+03, 0.44744800E+02, 0.43842400E+03, -.21699100E+03, 0.14877300E+03, -.21905300E+03, -.22732900E+03, -.28878900E+02, 0.84112700E+01, -.10072300E+03, -.42220500E+03, 0.21847400E+01, 0.41569100E+03, 0.34240600E+04, -.17128400E+04, -.16611900E+04, -.17119500E+04, -.17638100E+03, 0.54705800E+03, -.32752200E+03, 0.10135900E+04, -.12989700E+04, 0.38159000E+03, -.16142000E+04, 0.38223900E+03, -.19105200E+03, 0.45120400E+03, -.19011200E+03, 0.14864000E+03, 0.15104900E+03, -.38107500E+03, -.12748700E+03, -.28815600E+03, 0.12345200E+03, -.48576400E+03, 0.14475600E+04, -.72713300E+03, -.45026800E+03, -.72399000E+03, -.47633600E+01, -.72887500E+02, -.39368300E+03, -.86386400E+02, -.65862000E+03, 0.75035600E+02, -.80791700E+03, -.92859000E+02, 0.49561700E+02, 0.34775600E+03, 0.46518900E+02, 0.82222200E+02, -.27708700E+02, 0.31226900E+02, -.11573000E+03, -.49206200E+02, 0.16407700E+02, 0.50133600E+03, -.13882400E+04, 0.68898400E+03, 0.10325800E+04, 0.69465000E+03, 0.74863900E+01, 0.15742900E+03, 0.17104600E+03, -.18697500E+03, 0.52076200E+03, 0.23058600E+03, -.18113200E+03, -.50324200E+03, 0.25167900E+03, -.21591500E+03, 0.25179300E+03, 0.85465500E+02, 0.93146400E+02, 0.51858400E+02, -.54953400E+01, 0.28833900E+03, 0.73982000E+02, 0.54439100E+02, 0.91594700E+02, -.38484200E+02, 0.30088100E+03, -.45322600E+02, 0.62471600E+02, -.69878900E+01, -.21276400E+03, -.30777800E+03, -.18807200E+03, -.61655100E+02, 0.38168000E+03, -.13928100E+02, 0.27097800E+02, 0.23471500E+01, -.12769800E+02, -.49558300E+02, 0.11079100E+03, 0.13879000E+03, -.26186000E+02, -.24624600E+01, -.14165800E+02, 0.84128300E+02, -.58368600E+02, 0.43616900E+02, -.45063700E+02, 0.41276800E+03, -.24999500E+02, 0.14100300E+03, -.99947400E+02, 0.52510700E+03, -.11443500E+02, 0.82749200E+02, 0.11803200E+03, 0.54953200E+02, 0.19619700E+02, 0.21227300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.78888200E+00, -.90939200E+00, -.59202500E+00, -.39207200E+00, 0.18772100E+00, 0.57877100E-01, 0.98301700E+00, 0.74113100E+00, -.10230100E+01, -.30974400E+00, -.13733500E+00, 0.43262800E-01, 0.75807900E+00, -.76018500E+00, 0.10701800E+01, 0.46412400E-01, 0.92861300E-01, -.68877300E+00, -.57737200E+00, -.12085200E+01, 0.16211100E+01, 0.70887100E-01, -.49172800E+00, 0.10175100E+00, 0.12908000E-01, 0.91267800E-02, 0.94155600E+00, 0.71310600E-01, -.22846100E+00, 0.13668400E+00, -.18757800E+00, 0.74108900E+00, 0.11419200E+00, 0.49917900E-01, 0.26723200E+00, 0.23995400E+00, 0.94963900E-02, -.41666900E+00, -.39360700E-01, -.64728700E+00, -.25456500E+00, 0.14405300E+00, 0.10080300E+01, 0.34810800E-01, 0.15585300E+00, -.90170500E-01, 0.74224800E+00, -.48347100E-02, -.95836400E-01, 0.65834800E+00, 0.45090500E+00, -.12051900E+01, 0.15632700E+00, 0.19781900E+00, -.48080400E-01, -.21052700E+00, -.44459000E+00, -.14117500E+01, -.56549300E-01, 0.50553000E+00, -.35185400E-01, -.94583700E-01, 0.29021500E-01, 0.10450100E+01, -.19128600E+01, 0.26250400E+00, -.21235500E+00, 0.12887500E+00, 0.15116900E+00, -.17624800E+00, 0.52469200E+00, -.92082200E+00, 0.11576900E+00, -.23713600E+00, -.38270200E-01, 0.15293800E+00, 0.20158200E-01, 0.45810300E+00, 0.67842600E-01, 0.40107300E-01, 0.13545800E+00, -.61392000E+00, -.22770500E+00, 0.48451100E+00, -.96381100E+00, -.58097300E+00, 0.13043100E+00, 0.24070600E-01, -.11313000E-02, 0.58655000E+00, 0.84755800E+00, 0.88933900E-01, 0.53677200E+00, 0.45151000E-01, -.14295400E+00, 0.14745700E+00, 0.11166200E+01, 0.31559400E-01, 0.20772200E+00, 0.12553000E+00, -.55355000E-01, -.13224500E+00, 0.95487100E-02, 0.93343100E+00, -.63367800E+00, -.96556100E-01, -.35492100E+00, 0.84463900E+00, 0.65495800E-01, 0.60376400E-01, -.80580500E+00, -.26154900E+00, -.29280500E+00, -.50897300E-03, 0.12791900E+00, -.19900600E+00, 0.94781000E+00, 0.10911200E+01, -.10550600E+01, 0.18912000E+00, 0.26413100E+00, -.16877100E+01, -.83571600E+00, 0.29911100E+00, 0.24098100E-02, 0.26194200E+00, 0.25490400E+00, -.19123700E-03, 0.31260900E+00, 0.11981800E+00, -.40293600E-01, 0.13123300E+00, 0.16736300E+00, 0.95030000E-01, -.21231200E+03, 0.10030600E+00, 0.95629100E+02, 0.54416400E+02, -.12794900E+03, -.11254300E+03, -.15069000E+03, 0.58136300E+02, 0.77598600E+02, -.56562000E+02, 0.28788900E+02, 0.23116500E+04, 0.28319300E+02, 0.50065700E+03, 0.68797700E+03, -.12575900E+03, -.26513000E+03, -.59499200E+03, 0.48683900E+03, -.48024400E+03, 0.32633400E+03, -.15821500E+03, -.35264700E+03, -.16468800E+03, -.91564100E+02, -.26843800E+03, 0.16322400E+03, 0.13769600E+03, 0.89381700E+02, -.22963400E+03, -.18142400E+03, -.88789400E+02, 0.39836000E+02, -.12103200E+03, 0.45709300E+02, 0.12473300E+03, -.40628700E+02, 0.13091700E+02, 0.10027400E+03, 0.11743200E+03, -.11077600E+02, -.13057000E+03, 0.23123700E+03, -.11821700E+03, -.10265300E+03, -.11571700E+03, 0.14913100E+03, 0.76600000E+02, -.87462500E+02, 0.15123400E+03, 0.16105600E+03, 0.15258500E+03, -.59615100E+03, 0.82817200E+02, -.39976500E+02, -.24870100E+04, -.41440000E+02, -.44010300E+03, -.69591800E+03, 0.14176200E+03, 0.17488600E+03, 0.39537300E+03, -.49933700E+03, 0.65058300E+03, 0.10145100E+03, -.48877500E+02, 0.13045200E+03, -.51074700E+02, -.23594800E+03, -.17384100E+03, -.11480300E+03, -.68040800E+02, -.25123000E+02, -.13407200E+03, 0.11628700E+03, 0.58694400E+02, -.25448600E+02, 0.62675100E+02, -.29262600E+02, -.12648500E+03, 0.76643000E+02, -.71667900E+02, -.61624000E+02, 0.15912900E+02, 0.72707700E+02, 0.72610700E+02, 0.16601600E+03, -.86288000E+02, 0.51961700E+02, -.83030300E+02, -.43560600E+02, 0.38866500E+02, -.40129300E+01, 0.16104400E+03, -.45059800E+02, -.99111600E+01, -.52133700E+03, -.82661000E+02, 0.46201100E+02, 0.16518900E+03, 0.41070500E+02, 0.64335500E+02, -.72773100E+02, -.90251100E+02, -.24717400E+03, -.22429800E+03, -.86527400E+02, -.28064400E+02, 0.73423500E+03, -.36890400E+03, -.46700300E+02, -.36712800E+03, -.53959800E+02, -.19476400E+01, 0.23929500E+02, 0.23909100E+03, -.12340400E+03, -.91723800E+02, -.14765700E+03, 0.15419100E+03, -.79386200E+02, -.12359900E+02, -.77204500E+02, -.68477000E+02, -.54707500E+02, -.19383500E+02, 0.17936900E+03, 0.37655400E+03, -.79058900E+01, -.39877100E+03, -.39824900E+02, -.80460800E+01, -.50613800E+01, -.19549600E+02, 0.74987200E+01, -.37899000E+01, -.89041800E+01, -.22774700E+02, 0.45293500E+01, -.16837000E+02, 0.23619300E+01, 0.71628600E+02, -.11652800E+02, 0.59104200E+02, 0.15242500E+03, -.93519500E+01, -.10750300E+02, 0.31278100E+02, 0.19511700E+03, -.16934100E+02, -.10307300E+02, -.82925500E+02, -.19242500E+02, -.49944800E+02, 0.34486200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28801800E+01, 0.79725800E+00, -.15620200E+00, 0.38536200E+01, 0.12702400E+01, -.99972600E-01, -.36883200E+01, -.49497800E+01, 0.18953100E+01, 0.67835700E+00, 0.28475200E+00, 0.20436400E+01, -.47391600E+01, -.20769000E+00, 0.48166500E+00, 0.24906000E+01, -.28104500E+01, -.22496600E+00, 0.68099200E+00, -.17155000E+01, -.48788800E+01, -.33471600E+00, 0.23121000E+01, -.46999900E+00, 0.57019100E+00, 0.72629200E+00, -.64078200E+01, -.10316600E+01, -.15849600E+01, -.11102800E+01, -.12012400E+01, -.22698300E+00, 0.14347900E+00, -.10270600E+01, -.14092800E-01, 0.27346300E+00, 0.22631000E-02, -.34629300E+00, -.52160900E+00, -.57461200E+00, -.25786900E+01, -.20157500E+01, 0.23178000E+01, 0.10448500E+00, 0.30442900E+00, 0.51599000E-01, -.66347100E-01, -.90396600E-02, -.40018100E-01, 0.27565300E+00, 0.27456100E+00, -.65610200E+00, 0.17942700E+00, 0.51276600E+00, 0.21700500E+00, 0.57014900E+00, 0.13299300E+01, -.30689100E+01, 0.74522700E-01, 0.23661300E+00, 0.15822700E+00, 0.86487600E+00, 0.16368400E+00, -.28950700E+01, 0.14834100E+01, -.39698000E-01, -.48445500E-01, -.15865900E+01, -.40387500E+00, -.15481500E+00, -.24636200E+01, -.25692300E+01, 0.11688000E+00, 0.10428400E+01, 0.47124000E+00, -.32305000E+00, -.44399400E+00, -.88475600E+00, 0.20283900E+00, -.14788500E+00, 0.50431100E+00, -.10041000E+01, 0.13620600E+01, -.19921500E+00, -.59230100E-01, -.34954300E-01, -.20767100E+00, -.38345500E+00, 0.20908800E+00, -.14625300E+00, 0.32635300E+00, 0.37091900E+00, 0.25691200E+00, 0.52119900E+00, -.69122100E+00, -.28910400E+00, -.14724500E+01, 0.14256500E+01, -.89591500E-01, 0.91571000E+00, -.18159600E+00, -.34426700E+00, 0.52164600E-01, -.11972700E+01, -.74552000E+00, -.59036400E+00, -.41921600E-01, -.12883500E+00, -.96070400E-01, -.72638500E+00, 0.22331000E+01, -.28571500E+00, -.70897000E+00, 0.16231500E-01, 0.20715400E+00, 0.18651900E+00, 0.10023800E+01, 0.60694000E-01, 0.27940800E+01, 0.54094000E+00, -.29536900E+00, -.25013700E+01, -.12258400E+01, -.24998300E+00, 0.72473000E-01, -.46236400E+00, -.29123000E+00, 0.69738800E-01, 0.59289500E+00, 0.31148400E+00, 0.55938200E+00, -.28343900E+00, 0.29097000E+00, -.24451700E+00, 0.14519900E+00, 0.59986800E+01, -.15590500E+02, -.76092900E+02, -.90350900E+02, -.16103200E+02, 0.11004600E+03, -.12029700E+03, 0.10178300E+03, -.62253100E+04, 0.31096400E+04, 0.28437400E+04, 0.31126900E+04, 0.74859200E+03, 0.21504300E+03, 0.76993200E+03, -.10900300E+04, 0.14421900E+04, 0.41020800E+03, 0.18625900E+04, -.71498000E+02, 0.36021200E+02, -.48509500E+02, 0.42466200E+02, 0.92427500E+01, 0.10387600E+02, -.82366600E+01, -.44337500E+02, 0.71552700E+02, -.47978300E+01, 0.30107300E+02, 0.26502200E+03, -.13296700E+03, -.17224800E+03, -.13628300E+03, -.27886500E+03, -.27251700E+03, 0.21991500E+03, 0.24386300E+03, 0.22244200E+03, -.28035200E+03, -.22451500E+03, 0.10039600E+04, -.50187900E+03, -.11178200E+03, -.50191900E+03, -.33464100E+03, 0.29559700E+02, -.25972900E+03, -.28447800E+03, -.46157300E+03, 0.54537500E+02, -.74195100E+03, 0.33874000E+04, -.16927000E+04, -.16021200E+04, -.16937500E+04, -.24259400E+03, -.34351800E+02, -.46482700E+03, 0.63884000E+03, -.76763200E+03, -.12255000E+03, -.10996700E+04, 0.82963000E+02, -.41905100E+02, 0.56123600E+03, -.42484100E+02, 0.81388300E+02, 0.23867800E+03, -.39131100E+03, -.32593300E+03, -.16879200E+03, 0.25765500E+03, -.14406800E+03, 0.20690200E+03, -.10389800E+03, -.12670300E+03, -.10330400E+03, -.48576600E+02, 0.29714300E+02, -.18170900E+03, -.14051000E+03, -.26314800E+03, 0.78762800E+02, -.15549300E+03, -.85649800E+02, 0.43213100E+02, 0.12410600E+03, 0.42696800E+02, -.36358100E+03, -.28655200E+03, 0.25533100E+02, -.40175400E+03, 0.24219200E+02, -.24598300E+03, -.59674100E+02, -.29102700E+04, 0.14555600E+04, 0.16600400E+04, 0.14550100E+04, 0.41794800E+03, 0.19060400E+03, 0.22714700E+03, -.59939100E+03, 0.65341600E+03, 0.32824900E+03, 0.38427700E+03, -.13945600E+03, 0.68579300E+02, -.24711100E+02, 0.69368500E+02, 0.20699900E+03, 0.11357900E+03, 0.61355200E+02, 0.23206400E+02, 0.89232300E+02, 0.64986300E+02, 0.22555700E+01, -.67117700E+02, 0.30155600E+02, 0.13922100E+03, 0.32839900E+02, -.20621200E+03, 0.18772300E+02, -.24772800E+03, -.64126100E+03, -.19294000E+03, 0.53552900E+02, -.12126200E+03, 0.20447600E+02, -.35385800E+01, -.53792500E+02, -.52290400E+02, 0.32646500E+01, 0.95163700E+02, 0.98985200E+02, -.49387900E+02, 0.53038100E+02, 0.24276400E+02, 0.55679000E+02, 0.75525700E+02, 0.39223800E+02, 0.63576100E+02, 0.12880200E+03, -.48141800E+02, 0.63235200E+02, 0.94118100E+01, 0.14209600E+03, -.19702300E+02, -.49381700E+01, 0.30422200E+02, -.48052800E+02, -.76875500E+01, -.56203800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.47766600E+00, 0.49371900E+00, 0.46494600E+00, 0.33383300E+00, 0.15623900E+00, 0.12995000E-01, -.22158100E+00, 0.26505300E+00, 0.40435700E+00, 0.19407400E+00, 0.55551300E-01, -.19330000E+01, 0.36244600E+00, 0.72593900E+00, -.10445600E+01, 0.69356900E+00, 0.52686100E+00, 0.67544900E+00, -.12052800E+00, 0.96590100E+00, -.12820000E+01, -.28051600E-01, 0.41081700E+00, -.81939400E+00, -.84777900E-01, -.59330500E-01, -.86723800E-01, -.12196500E+00, 0.18566700E+00, 0.35838700E+00, 0.25064400E+00, -.39289500E+00, 0.45604500E-02, 0.98065600E+00, -.58665400E-01, 0.31196000E+00, -.12756100E-02, 0.72663300E+00, -.13222400E+00, -.19610800E+00, 0.12445900E+01, -.82995400E-02, -.28878900E+00, -.18445900E-01, -.37439800E-01, -.10203700E+00, -.52062500E-01, 0.17571300E-02, -.26821700E+00, 0.24453300E-01, 0.15729000E+00, 0.28361400E+00, -.33406300E-01, -.15216500E+00, -.14110700E-01, -.28756900E-01, -.16441100E+00, -.59874600E-01, -.10652300E-01, 0.48871300E-02, -.61560300E-01, 0.16971500E-01, -.70809500E-01, 0.20175800E+00, -.40245600E+00, -.96816600E-01, -.18317100E-01, 0.45406300E-01, 0.25023600E+00, 0.73035600E-01, 0.38498400E+00, 0.42968200E-02, 0.14468000E-01, -.20179800E+00, -.65966400E-01, 0.41022600E-01, 0.45020000E-01, 0.72529000E+00, -.82407500E-01, 0.19198100E-01, -.82080500E-01, -.46616900E-01, -.53153600E+00, -.46616100E+00, -.35948100E+00, -.26642600E+00, 0.84390700E-01, 0.13730900E+00, -.19420700E+00, 0.22545700E-01, -.61467400E+00, -.12436600E-01, -.17209000E+00, 0.20330700E-01, -.79879600E+00, 0.83540300E+00, 0.17457700E+00, 0.43042300E+00, 0.30786900E-01, -.17750200E+00, -.40673700E-02, -.96002900E-03, -.35421900E-02, 0.74240600E-01, 0.80807000E-01, 0.14693200E+00, -.53917700E-01, -.97026200E-01, 0.10950300E+00, -.54946700E-01, -.80192200E+00, -.17824700E-01, 0.59732900E-02, -.20401500E-02, -.49019000E-01, -.18666300E+00, -.11960500E+01, -.16875200E+00, 0.46680700E+00, 0.40731400E+00, -.12192100E+00, 0.10861300E+01, 0.41370200E+00, -.37089800E+00, -.27719800E-02, 0.26716800E+00, -.19833000E+00, 0.15560800E+00, -.86652500E+00, 0.34117900E+00, 0.38361100E+00, -.81951000E-01, -.29499400E+00, -.11096700E+00, -.39966800E+00, -.11722600E-01, 0.55209900E+02, 0.39029200E+02, -.77426000E+01, -.36906500E+02, -.15944700E+03, 0.50859800E+02, -.12161500E+02, 0.14482200E+04, -.72393200E+03, 0.91373700E+03, -.72411700E+03, -.26393400E+03, 0.19826500E+03, -.10916100E+03, 0.11776800E+03, -.33764000E+03, -.56832600E+02, -.42567500E+03, 0.27646900E+03, -.13230800E+03, -.98156400E+02, -.13823700E+03, -.51399400E+00, -.73938100E+02, -.29580400E+01, 0.74150200E+02, 0.49136100E+01, -.48221100E+02, -.21521400E+03, -.63284400E+02, 0.28664300E+02, -.96709700E+02, 0.33736300E+02, 0.98302600E+02, 0.29774500E+02, 0.94954100E+01, 0.85417900E+02, -.10831800E+03, 0.10055100E+03, -.38108800E+02, -.75399900E+03, 0.37461300E+03, 0.10007100E+03, 0.37700200E+03, 0.20881900E+03, -.71656700E+01, 0.24823000E+03, 0.19331300E+03, 0.37752900E+03, 0.79814800E+01, 0.10958900E+03, -.79677700E+03, 0.39951500E+03, -.12642300E+04, 0.39839400E+03, 0.67641600E+02, -.31127900E+03, 0.13415700E+03, -.11906800E+02, 0.20175400E+03, -.96130100E+02, 0.40371700E+03, 0.20106100E+03, -.98539200E+02, -.19622600E+03, -.10041800E+03, -.26908500E+03, -.33168300E+03, 0.78521600E+02, 0.12684800E+03, 0.81860700E+02, -.27863100E+03, 0.90070500E+02, -.10861500E+03, 0.56753700E+02, 0.10760900E+03, 0.54289100E+02, 0.13673000E+01, 0.12578800E+02, -.38414500E+02, -.13782300E+03, 0.18431200E+03, -.19134000E+01, 0.13040400E+03, -.55018700E+02, 0.24645300E+02, 0.97431000E+01, 0.27522200E+02, 0.84694200E+02, 0.11458500E+03, 0.11166400E+03, 0.29690300E+03, -.39304400E+02, -.23349600E+02, -.29800800E+03, 0.58847800E+03, -.29189800E+03, -.39169400E+03, -.29421100E+03, 0.10079800E+02, 0.29195900E+02, -.38519600E+02, 0.14714100E+03, -.14637200E+03, -.40014200E+02, -.72207300E+02, 0.64835200E+03, -.32522900E+03, 0.43318500E+02, -.32415500E+03, 0.17273000E+02, 0.15590100E+03, -.95639600E+02, 0.18102700E+03, -.13201400E+03, 0.89165000E+02, -.30996400E+03, 0.13050200E+03, -.64770100E+02, -.16579300E+03, -.65182800E+02, -.17368100E+03, -.22031300E+03, 0.14972100E+03, 0.38029600E+03, 0.42907300E+03, -.20988100E+03, -.21557800E+03, -.15821100E+02, -.51558300E+02, -.51397300E+02, -.66744000E+02, -.27759100E+02, -.11484900E+03, -.11439800E+03, -.67275800E+02, 0.51079300E+02, -.54292500E+01, -.89945200E+02, 0.87072800E+02, 0.64915200E+01, 0.85622600E+02, 0.10908200E+02, -.59104900E+02, -.10090100E+03, 0.31005800E+02, 0.72876200E+02, 0.29663300E+02, -.83062700E+02, -.91070500E+02, 0.64296100E+02, -.72898700E+02, 0.49069900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11633800E+01, -.30712300E+00, -.27503600E+01, 0.71104900E+00, -.26970000E+01, -.35225700E+00, -.85524900E+00, -.11162300E+01, 0.38762600E+01, 0.98099800E+00, 0.23833800E+00, -.16681500E+01, 0.13334700E+01, 0.20693800E+01, -.14966200E+01, 0.10201900E+01, 0.12013100E+01, 0.25178400E-01, -.77459700E-02, 0.89834300E+00, -.15798000E+01, 0.26102500E-01, 0.40144000E+00, 0.46765500E+00, 0.37848600E-01, -.23205500E-02, 0.25043200E-01, -.82026700E-01, -.51263900E+00, -.11884600E+01, -.36092400E+00, 0.81147200E+00, -.29774400E+00, -.47538700E+00, 0.40002300E+00, 0.77732400E+00, 0.22282300E-01, -.44851900E+00, 0.25434600E-01, -.33578500E+00, 0.26927000E+00, -.23769700E-02, -.21179800E+00, -.10088500E+00, 0.36393000E+00, 0.53588900E+00, -.32300300E+00, 0.15830200E-02, -.53362100E+00, 0.94430500E+00, 0.13368500E+01, 0.16849900E+01, 0.19834300E+00, 0.69454200E+00, 0.13827100E+00, 0.20848000E+00, -.81043300E+00, -.15895700E+01, 0.17781200E-01, 0.42278100E+00, -.19848000E+00, -.19233500E+00, -.87136900E-01, -.12159800E+01, 0.26815100E+01, -.85039100E-01, 0.16962500E+00, -.76359200E+00, -.12681800E+01, 0.11572900E+00, -.19636700E+01, 0.54838600E+00, -.41156600E+00, 0.18208300E+00, 0.17730400E+00, -.31195900E-01, -.99310000E-02, -.11554000E+00, 0.19695300E+00, 0.16288700E+00, -.12628000E-01, 0.43701100E+00, 0.39652500E+00, 0.79769800E+00, 0.17499800E+01, 0.44941600E+00, -.57731300E-01, -.21130000E+00, -.10156000E+00, -.23693300E+00, -.27622300E+00, 0.31306300E-01, 0.64762900E+00, 0.15185200E+00, 0.25727700E-01, -.27607500E+00, 0.54736500E-02, -.36183600E-02, -.32237700E-01, -.37189300E+00, -.15811500E+00, -.22493500E+00, -.49804100E-03, -.44393900E+00, -.58764900E+00, -.13451100E+00, 0.12769300E+00, -.67091200E+00, 0.88531000E-01, -.21956200E+00, -.65464500E+00, 0.52409000E-01, 0.38945800E+00, 0.10655600E-03, -.21724300E+00, -.12878100E+00, -.18552100E+01, -.13263400E+00, 0.22949100E-01, 0.37012900E+00, -.11121900E+00, 0.11666500E+01, 0.51390300E+00, 0.81463500E+00, -.52382500E-02, -.15792600E+00, 0.20162100E+00, -.39715000E-01, 0.61564700E+00, -.65144600E+00, -.29060000E+00, -.16076000E-01, -.28954600E-02, -.22453500E+00, -.10370900E+01, -.17274700E-01, 0.10402500E+01, -.17022700E+03, 0.10008400E+03, 0.20553200E+03, 0.15628900E+03, -.19107900E+03, -.62108500E+01, -.58949100E+04, 0.29442600E+04, 0.37911400E+04, 0.29474600E+04, 0.74305600E+03, 0.25612200E+03, 0.55680900E+03, -.99932000E+03, 0.11096200E+04, 0.61186900E+03, 0.24377700E+04, 0.41994300E+03, -.18904500E+03, -.21507200E+03, -.21068900E+03, -.96048200E+02, -.16635600E+03, 0.96627900E+02, 0.12391500E+03, -.64013300E+02, -.16342800E+03, -.17345000E+03, 0.35393500E+03, -.17480200E+03, -.13243600E+03, -.17838600E+03, -.28857300E+03, -.18600200E+03, 0.17482900E+03, 0.28833000E+03, 0.39728500E+03, -.33999700E+03, 0.18894100E+03, 0.20135300E+04, -.10053700E+04, -.40591800E+03, -.10068000E+04, -.43217700E+03, 0.34378600E+03, -.77348400E+03, -.83483900E+03, -.89263600E+03, 0.43363700E+03, -.20600000E+03, 0.30283300E+04, -.15126900E+04, -.24422500E+04, -.15141600E+04, -.40555300E+03, -.24435000E+03, -.17842900E+03, 0.60457800E+03, -.40541600E+03, -.49124000E+03, -.11446600E+04, 0.84273300E+03, -.42249600E+03, 0.51553300E+03, -.42135600E+03, 0.51596000E+02, 0.14109000E+03, -.45111600E+03, -.45419800E+02, -.39623100E+03, 0.93606300E+02, -.53038700E+03, -.96783100E+02, 0.45964400E+02, 0.35418500E+03, 0.48397400E+02, -.16029100E+02, 0.52928500E+02, -.70809300E+02, -.12724100E+03, -.38120800E+03, 0.13759500E+03, -.20779900E+03, 0.26531600E+03, -.13158900E+03, 0.18818200E+03, -.13265000E+03, -.40725100E+02, -.52872800E+02, -.18658100E+03, -.50168300E+03, -.52449600E+02, 0.13251000E+03, -.23696900E+02, -.23112100E+04, 0.11513700E+04, 0.15689100E+04, 0.11555600E+04, 0.11300300E+03, 0.11984200E+03, 0.87481200E+02, -.51217500E+03, 0.42718700E+03, 0.23806000E+03, 0.10463900E+04, -.42014100E+03, 0.21028600E+03, -.18011000E+03, 0.21012900E+03, 0.24846300E+02, -.48010400E+02, 0.15073800E+03, 0.85912700E+02, 0.26905800E+03, -.74976400E+02, 0.29014500E+03, 0.42379100E+03, -.20615700E+03, 0.15896800E+03, -.21184300E+03, 0.23409100E+03, 0.33043000E+03, -.64038500E+03, -.10796700E+04, -.63470400E+03, 0.41155000E+03, -.14027700E+03, -.19072900E+02, 0.78155400E+02, -.25544800E+02, -.38259900E+02, 0.68528000E+02, 0.16864700E+03, 0.17914500E+03, -.45747000E+02, 0.24178700E+02, -.13552500E+02, 0.14249000E+03, -.41451400E+02, 0.29753100E+02, -.29606000E+02, 0.27541200E+03, -.37201200E+02, 0.14533200E+03, -.10569800E+03, 0.30306200E+03, -.58640800E+02, 0.78895800E+02, 0.16643100E+03, -.59195900E+02, 0.62143400E+02, -.12226400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11950700E+01, -.13412700E+01, 0.37914600E+01, 0.67664700E+00, 0.31976000E+01, 0.24519100E+00, 0.84900800E+00, 0.96444500E+00, -.30104300E+01, -.65860700E+00, -.38932000E+00, 0.20589200E+01, -.82150100E+00, -.16955300E+01, 0.16694600E+01, -.24655200E+00, -.73409500E+00, -.33227600E+00, -.42652100E+00, -.61361800E+00, 0.22604800E+01, 0.15027400E+00, -.87555500E+00, 0.57609100E+00, -.56685300E-02, 0.10013400E+00, 0.13437100E+01, 0.95357400E-01, 0.29668700E+00, 0.17957500E-01, 0.28558600E-01, 0.24568400E+00, -.15510600E+00, 0.13171100E+01, -.26986900E+00, -.11764100E+01, -.34788900E-01, -.84977300E+00, 0.88089400E+00, -.22085600E-01, -.18225800E+00, 0.90545000E-01, 0.29473400E+00, -.14022500E+00, -.30990300E+00, 0.33944500E+00, 0.65972700E+00, -.40423800E-02, -.38261900E+00, -.69510500E-02, -.47094800E+00, -.18674500E+00, -.18930800E-01, 0.11910000E+01, 0.10700200E+00, -.44688300E+00, 0.49844700E-01, 0.13183900E+00, -.65409700E-01, 0.53642700E+00, 0.76148800E-01, -.37018100E+00, 0.38072100E+00, 0.13265700E+01, -.10048300E+01, 0.39784600E+00, -.26259300E+00, -.16009300E+00, 0.94156100E-01, -.24462400E+00, 0.64255300E+00, -.10352800E+01, -.21687800E+00, -.63249400E+00, -.41040600E+00, 0.35920300E+00, 0.57209700E-01, -.40397800E+00, -.15860700E+00, -.17437400E+00, 0.13662600E+00, -.10561700E+01, 0.42707900E+00, 0.65486100E+00, -.34104700E+00, -.68676800E+00, -.77051300E-01, 0.13323500E+00, -.65658800E-01, 0.93061700E+00, 0.24408800E+00, 0.15376700E+00, -.59619300E+00, 0.31337800E+00, 0.23920500E+00, 0.17251000E+00, 0.20583100E+01, 0.11722000E+01, 0.41354400E+00, 0.35097600E+00, -.19780000E+00, 0.55758900E+00, -.41777500E-02, 0.10305000E+01, 0.42034100E-01, 0.60969500E-01, 0.16633900E+00, 0.11979100E+01, 0.37440200E+00, 0.49782100E+00, 0.52660600E+00, 0.23552300E-01, 0.78367100E-01, -.29641400E-02, -.20327400E+00, -.18730800E+00, 0.54232200E+00, -.90941900E+00, 0.11293100E+01, -.90185200E-01, -.42661700E+00, 0.12357600E+01, -.25388300E+01, 0.36886900E+00, 0.22722000E-01, -.60601200E+00, 0.67341000E+00, -.53506100E+00, -.47955700E+00, -.11992000E+01, 0.93442200E-02, -.17908900E+00, -.91789100E+00, 0.12046600E-01, 0.77346100E+00, 0.54961000E-01, -.95427600E-01, -.88738300E+00, 0.23019600E+03, 0.29886100E+03, 0.26102900E+03, 0.12210900E+02, -.14540400E+03, 0.20973900E+04, -.10488100E+04, -.18773400E+04, -.10486500E+04, -.44761400E+03, -.15048700E+03, -.39853600E+03, 0.79974200E+03, -.85184500E+03, 0.41392300E+03, 0.59205700E+03, -.17539800E+03, 0.87220400E+02, 0.79317200E+02, 0.87201400E+02, 0.45396200E+02, 0.13155000E+03, -.47791100E+02, 0.22757200E+02, -.36224000E+02, 0.10483100E+03, 0.11294100E+03, 0.46132900E+03, -.22892300E+03, 0.99194900E+02, -.23247500E+03, 0.81298200E+02, 0.16464500E+03, -.19518800E+03, -.95352700E+02, 0.10303300E+03, -.42755000E+02, 0.14618500E+02, 0.33903500E+03, -.16833800E+03, 0.31258400E+03, -.16958900E+03, -.67405500E+02, 0.60312000E+02, -.34894400E+03, -.77432800E+03, -.40433100E+03, 0.14238100E+03, 0.23357200E+03, -.18485300E+04, 0.92363600E+03, 0.19834700E+04, 0.92421900E+03, 0.21040600E+03, 0.13986700E+02, 0.39342000E+03, -.61409300E+03, 0.80482700E+03, -.45919400E+03, -.53319400E+02, 0.79683900E+03, -.39886500E+03, -.43366800E+02, -.39907900E+03, 0.21037000E+03, 0.18685000E+03, -.21360100E+02, 0.34386200E+03, -.26634900E+03, 0.55349300E+02, -.54146300E+03, -.83634100E+03, 0.41905200E+03, 0.73493200E+03, 0.41829800E+03, 0.84601200E+02, -.15683500E+01, 0.30030500E+03, 0.14056100E+03, 0.44047800E+01, 0.39694100E+02, 0.35738200E+03, 0.66759700E+03, -.33335800E+03, -.10087300E+03, -.33386200E+03, 0.48078200E+03, 0.38709800E+03, -.43397300E+03, -.37078100E+03, -.28983200E+03, 0.65961000E+03, 0.74574700E+01, 0.96418600E+03, -.48383100E+03, -.25773600E+03, -.48237400E+03, -.33134300E+03, 0.91223000E+02, -.20649500E+03, 0.25107200E+03, -.32110600E+03, 0.15980300E+03, 0.10569900E+04, -.11085100E+04, 0.55480200E+03, -.76433100E+02, 0.55413400E+03, -.18619100E+03, -.28280200E+03, 0.11201000E+03, -.21933600E+03, 0.26266700E+03, -.17408600E+03, 0.69327800E+03, 0.40688500E+03, -.20250400E+03, 0.47620300E+02, -.20378400E+03, 0.65273300E+03, 0.54095200E+03, -.46207600E+03, -.58882700E+03, -.92783100E+03, 0.55379800E+03, -.36057200E+01, -.32044200E+02, 0.12175900E+03, 0.15519900E+02, 0.47965800E+02, 0.69380000E+02, 0.73603100E+02, 0.75875100E+02, 0.62465000E+02, -.14403800E+02, -.39177500E+02, 0.58968900E+02, -.18059300E+03, -.20291900E+02, -.15166300E+03, -.93107600E+02, 0.50271600E+02, 0.41131500E+02, -.15376000E+03, -.20437000E+03, -.75674000E+02, 0.58883900E+02, 0.24545000E+03, -.29705000E+02, 0.14857600E+03, -.85284700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25612900E+01, 0.10380600E+00, 0.16097800E+01, -.74367200E+00, 0.23160300E+01, 0.11118000E+00, -.28979500E-01, -.34666800E+01, -.57123600E+01, -.37225700E+00, 0.12240800E+01, 0.10120800E+02, -.21460900E+01, 0.56413000E+00, 0.51891200E+01, -.47278200E+01, -.53708800E+01, 0.59426700E+00, 0.54585000E+00, -.94492500E+00, -.31521100E+01, -.93473200E+00, 0.25577200E+00, -.40170000E+01, 0.34464400E+00, -.24619100E+00, -.11938700E+01, -.20565900E+00, 0.35304600E+00, -.17628400E+01, -.21332100E+00, 0.43869300E+00, -.15829100E+01, 0.97663200E+00, 0.11374700E+01, -.90627300E+00, -.93822700E-01, 0.30408300E+00, 0.36339500E+00, -.90742600E+00, 0.73120100E+00, 0.44185900E+00, -.10118200E+01, -.10078800E+01, 0.14004000E+00, 0.67768900E+00, 0.28393300E+00, -.16040700E-01, -.56362900E-01, 0.17968200E+01, 0.41135600E+00, -.54298800E+01, 0.41863400E+00, -.28021900E+00, 0.76050000E+00, -.36968800E+00, -.11525500E+01, 0.10259300E+01, -.63849100E-01, 0.11684700E+01, 0.10095300E+00, -.26765100E+00, -.53714200E+00, 0.10347400E+01, -.28005200E+01, -.29770300E+00, -.39902500E+00, -.84638300E+00, -.43923500E+00, -.67018200E-01, 0.65868100E+00, -.36869400E+00, 0.72082800E+00, 0.41219900E+00, 0.51743300E+00, -.49843500E+00, -.11308600E+00, -.20008300E+00, 0.73926000E+00, 0.43249300E+00, 0.16990400E+00, 0.12658300E+01, 0.97720700E+00, 0.22107300E+01, 0.11318100E+01, 0.22364400E+00, 0.83548500E+00, 0.32086100E+00, -.10579600E+01, 0.15382600E+00, -.57924600E+00, -.12748700E+00, 0.63041600E+00, 0.63148000E-01, 0.10433200E+01, -.50281500E+00, -.87081300E+00, -.13187200E+01, -.95156100E-01, 0.28208000E+00, -.14502600E+00, -.64849000E+00, 0.14096500E-01, 0.48825000E+00, -.10571900E+00, -.55424000E+00, -.64755100E+00, -.59144700E-01, 0.64726700E+00, 0.17494700E+01, 0.40782800E+01, -.29700500E+00, -.15212400E+01, 0.51155100E-03, 0.20753800E+00, -.19830000E+00, 0.34668700E+01, -.26678500E+00, 0.18481700E+01, 0.13289900E+00, -.90635500E+00, -.81879300E+00, -.52830100E+01, 0.38336600E+00, 0.68466400E-01, -.15808500E+01, -.10320900E+00, -.61050300E+00, 0.27236800E+01, -.35868800E+00, -.55917000E+00, -.24309900E-01, -.88464700E+00, -.14019100E+01, -.15493600E+01, 0.11296700E+00, -.58044300E+00, 0.13424100E+01, 0.72052500E+00, -.32133100E+03, -.51598000E+03, 0.11543000E+02, -.21723100E+03, 0.12481100E+05, -.62424400E+04, -.14423200E+04, -.62404200E+04, -.23324800E+04, -.82531800E+03, -.13184000E+04, 0.66075600E+03, -.21704600E+04, -.20367600E+04, -.26675700E+04, 0.93884000E+03, -.45550000E+03, -.21014900E+03, -.47166500E+03, -.95194600E+02, -.48911900E+03, 0.14671100E+03, 0.42306400E+03, 0.69187800E+02, -.41772900E+03, -.74053600E+03, -.14211200E+04, 0.69872900E+03, 0.21293400E+03, 0.71799500E+03, 0.74117700E+03, 0.52589200E+03, -.31732300E+02, 0.77729100E+02, -.57205100E+03, 0.77084000E+03, 0.43974600E+03, -.46302500E+04, 0.23059000E+04, 0.24032900E+03, 0.23148600E+04, 0.15351000E+04, -.48701100E+03, 0.16864600E+04, 0.22008900E+04, 0.25968000E+04, -.70012500E+03, 0.85854200E+03, -.55523000E+04, 0.27816900E+04, -.16922500E+04, 0.27760300E+04, 0.90779800E+03, 0.36110000E+03, 0.69694700E+03, -.60972500E+01, 0.67933100E+03, 0.11584200E+04, 0.11624300E+04, -.11191400E+04, 0.56712200E+03, -.17796300E+04, 0.55815800E+03, -.85047500E+03, -.14207600E+04, 0.13211600E+04, 0.69946400E+03, 0.11163100E+04, -.12050200E+04, 0.12901300E+04, 0.82968800E+03, -.40668500E+03, -.63166400E+03, -.41453700E+03, 0.16010900E+03, -.11288600E+03, -.16906800E+03, -.19331700E+03, 0.81044800E+03, -.22832100E+03, 0.12136100E+03, -.62743900E+03, 0.30325300E+03, -.20194000E+02, 0.31360500E+03, 0.23713600E+03, 0.38613100E+03, 0.59351700E+03, 0.17356600E+04, 0.20113700E+03, -.31174200E+03, -.26285400E+03, 0.51060200E+04, -.25434000E+04, -.36865800E+04, -.25538300E+04, -.53208100E+03, -.71906000E+03, -.94641200E+02, 0.98257900E+03, -.62271300E+03, -.11111500E+04, -.33210100E+03, 0.23101100E+04, -.11601600E+04, 0.34660500E+03, -.11552600E+04, -.44436600E+02, 0.47407900E+03, -.48525500E+03, 0.55245200E+03, -.58343700E+03, 0.37332300E+03, -.11084400E+04, -.54394200E+03, 0.27028000E+03, -.47577500E+03, 0.27136500E+03, -.75126800E+03, -.14135100E+04, 0.16601400E+04, 0.28897400E+04, 0.24859000E+04, -.16078900E+04, -.74371900E+02, 0.32723000E+02, -.24059400E+03, -.57843800E+02, -.16548800E+03, -.13515900E+03, -.43757200E+03, -.44292600E+03, -.16364700E+03, 0.58245600E+02, 0.38541400E+02, -.25447200E+03, 0.23536300E+03, 0.67878100E+01, 0.22959300E+03, 0.32512300E+03, -.13595400E+03, -.23822300E+03, 0.18311800E+03, 0.66363400E+03, 0.27838200E+03, -.79627100E+02, -.45542000E+03, 0.27766900E+03, -.29445700E+03, 0.30202500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34591100E+00, 0.61374900E+00, 0.14100100E+01, 0.70478200E+00, 0.24307900E+00, -.11001500E+00, 0.22747600E+00, 0.53407600E-02, -.51707700E+00, 0.67565600E-01, -.19615900E-01, -.64278700E+00, 0.23594000E+00, 0.29681500E+00, -.82813400E+00, 0.13002600E+01, 0.83423200E+00, -.57644900E+00, -.12154700E+00, -.69817100E+00, 0.14939600E+00, -.44858000E-01, 0.69411100E-01, 0.74459500E+00, 0.12811000E-01, -.61594500E-01, -.49439900E-02, 0.22389800E+00, 0.41771200E-02, -.14208800E-01, 0.47017500E+00, -.40783500E+00, -.57820800E+00, -.17370200E+00, -.68790300E+00, -.13712700E+01, -.39937600E-01, -.67570800E+00, 0.70530700E+00, -.50240400E+00, -.11937300E+00, 0.91941400E-01, 0.58053800E+00, 0.69130000E-01, -.10391800E-01, -.10567800E+00, 0.14141500E+00, -.23066600E-02, 0.84691400E-01, -.11487500E-01, 0.16954800E+00, 0.24600000E+00, 0.24228000E-01, 0.20860500E+00, 0.91529700E-01, 0.70555000E-01, 0.10077200E+00, -.82024700E+00, -.49936000E-02, 0.18606700E+00, 0.39923200E-01, 0.65119700E-01, -.11045200E-01, -.36345900E-01, 0.20068500E+00, 0.27368300E-01, 0.50401000E-01, 0.15586500E+00, -.86657600E-01, -.28400900E-01, 0.39917400E+00, -.25493900E-01, -.11469200E-02, -.15226100E+00, -.12092000E+00, -.15967300E-01, 0.15291500E-01, 0.19440400E+00, -.10004500E+00, -.80347900E-01, -.88212300E-02, -.17178700E+00, 0.16610200E+00, 0.24174300E+00, 0.17959600E+00, -.21107800E+00, -.79082900E-01, 0.16719700E+00, 0.50914700E-02, 0.14476500E+00, 0.17597900E-01, 0.31006300E-01, -.47015500E+00, 0.62740700E-01, 0.86086500E-01, -.41779100E+00, -.34552600E+00, 0.18621100E+00, -.13737800E-02, -.25839700E-01, 0.98375100E-01, 0.26953200E-01, 0.12303400E-02, 0.24933900E-01, -.26163300E+00, -.54610400E-01, -.38106700E-01, -.63502300E-01, 0.65021700E-01, -.67401800E-01, -.89244600E+00, -.23625500E+00, -.16693900E+00, -.36242400E-03, 0.34638700E-01, -.33336500E-01, 0.93087700E+00, 0.15079100E+00, 0.56731200E+00, -.22362000E-01, -.10732100E+00, -.12573300E+00, -.86160200E+00, 0.14520400E+00, -.48002000E-02, 0.23962600E-02, -.66477300E-01, 0.14577100E+00, 0.14417100E+00, 0.84619200E-01, 0.19640000E+00, 0.10026800E+00, 0.18604900E+00, 0.32495300E+00, 0.21492000E+00, 0.57002500E-02, 0.37391700E+00, -.14901200E+00, -.13707300E+00, -.14668900E-01, 0.10721700E+03, 0.29618100E+01, 0.60757900E+00, -.71371800E+03, 0.35688900E+03, -.46100300E+03, 0.35688300E+03, -.11236100E+03, -.17466100E+03, 0.77962200E+02, 0.20461100E+02, 0.52353000E+02, 0.73850700E+02, 0.84795400E+03, -.28765200E+03, 0.13324900E+03, 0.36585000E+02, 0.14240200E+03, 0.31909700E+02, 0.82001500E+02, -.26964900E+02, -.79836500E+02, 0.61335200E+02, 0.63327500E+02, 0.16315100E+03, 0.15465800E+03, -.76108800E+02, 0.34766300E+02, -.78270700E+02, -.46136600E+02, 0.19149100E+02, -.55863900E+02, -.52325600E+02, 0.91889800E+02, -.26707500E+02, 0.11172800E+03, 0.44370400E+03, -.22034900E+03, -.62740200E+02, -.22191300E+03, -.26736400E+03, -.79749500E+01, -.17279800E+03, -.24993700E+03, -.23561200E+03, -.17990900E+01, 0.14474600E+02, 0.32118300E+03, -.16137700E+03, 0.73966700E+03, -.16061100E+03, 0.15602400E+03, 0.21193700E+03, -.75088400E+02, -.63231700E+02, 0.16603600E+02, -.43306700E+01, -.51419800E+03, 0.15683300E+03, -.79942900E+02, -.36626200E+02, -.78651200E+02, 0.12506000E+03, 0.13103800E+03, 0.36460700E+01, 0.41761500E+02, -.72925800E+02, 0.94695000E+02, -.14369600E+03, -.29034700E+03, 0.14460500E+03, 0.13993600E+03, 0.14522800E+03, 0.34324800E+02, -.76798900E+01, 0.11533900E+03, 0.78863400E+02, -.38524700E+02, -.62029500E+01, 0.82177300E+02, 0.10527700E+03, -.51115900E+02, -.12378000E+03, -.52654500E+02, -.13243700E+03, -.74713700E+02, -.87233300E+02, -.24982800E+03, 0.15569700E+00, 0.34765300E+02, 0.14222600E+03, -.47246200E+03, 0.23635300E+03, 0.24636300E+03, 0.23606900E+03, -.10519100E+02, -.20143800E+02, 0.28064600E+02, -.98674200E+02, 0.10081000E+03, 0.40899600E+02, 0.69379400E+03, -.37711500E+03, 0.18885900E+03, 0.73634400E+01, 0.18855800E+03, 0.20830000E+02, -.72768800E+02, 0.10413800E+02, -.11376400E+03, 0.56832200E+02, -.22842600E+02, 0.18474800E+03, -.95675900E+02, 0.44394800E+02, 0.45482900E+02, 0.47760400E+02, 0.36311700E+02, 0.98433000E+02, -.76994700E+02, -.33539300E+03, -.33017300E+03, 0.11044900E+03, 0.12444800E+03, 0.34816600E+02, 0.31750100E+02, -.15578900E+02, 0.41559300E+01, 0.59557900E+02, 0.49230400E+02, 0.47695100E+02, 0.10535500E+02, 0.15898300E+02, 0.18369000E+02, 0.43372300E+02, -.10723800E+02, 0.15700900E+02, -.11331200E+02, 0.45546000E+01, 0.35620800E+01, 0.38112600E+02, -.11919200E+02, -.35358300E+02, 0.12777200E+01, 0.34927800E+02, 0.55890700E+02, -.59484700E+02, 0.46089100E+02, -.60251900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15873300E+01, 0.14048200E+01, 0.74840400E+00, 0.27871800E+00, 0.26529100E+00, 0.28545900E+00, 0.17260100E+00, 0.26223500E+01, 0.19892100E+01, -.41199500E-01, -.65822800E+00, -.74709800E+01, 0.35682200E+00, 0.21672600E+00, -.50577200E+01, 0.34315500E+01, 0.38607600E+01, 0.60256500E-01, -.13360900E+01, 0.14572100E+01, 0.28463700E+01, -.35044000E+00, 0.16740300E+01, 0.19589500E+01, 0.11867900E+00, -.46016100E+00, 0.40672800E+00, 0.11314100E+01, 0.52364400E+00, 0.10864300E+01, -.11826100E-01, -.78058900E+00, 0.10965700E+01, 0.27314000E+00, 0.55506000E+00, 0.40075000E+00, 0.22663200E-01, 0.19876900E+01, -.83811000E+00, 0.99910600E+00, -.31206200E+00, -.46992200E-01, -.56871600E+00, 0.94547300E-01, -.93430400E-01, -.40375000E+00, 0.35010200E-01, 0.22270700E-02, -.30385600E+00, -.16615400E+00, 0.48800300E+00, 0.11636100E+01, -.66747100E-01, -.85772200E-01, 0.22181800E+00, 0.11660700E+00, -.17995000E+00, -.34309700E+00, 0.12663800E-02, 0.11388600E+00, -.93943100E-01, 0.14804100E+00, -.30787700E+00, -.15354500E+00, -.57011800E+00, -.59869200E-01, -.45535600E-01, -.16326700E+00, 0.13115700E+00, 0.27780400E-01, 0.60591900E+00, 0.35566800E+00, -.36725200E+00, -.64553100E+00, -.38782900E+00, 0.86944000E+00, 0.16166700E+00, 0.44135400E+00, 0.65830800E-01, 0.60107300E-01, -.12623400E+00, 0.11227000E+00, -.81567300E+00, -.16853200E+01, -.64579600E+00, 0.19003100E+00, 0.82194400E-01, -.83099300E+00, -.15179500E+00, 0.16646500E+00, -.11497500E+01, -.89775900E-01, -.75984800E+00, -.94877900E-01, -.22626800E+00, 0.86196000E+00, -.13957400E+00, -.72157600E+00, 0.25756100E+00, 0.36977000E+00, -.90613400E-01, 0.73277800E-01, 0.65802700E-02, -.28778100E+00, -.32882100E+00, -.51257800E+00, -.19699500E+00, 0.56518500E+00, 0.35982800E+00, 0.37136600E+00, -.10465100E+01, -.74198100E-01, -.12362900E-01, -.36767300E-02, -.18688000E+00, -.11452500E+00, 0.18194200E+01, -.11686000E+01, 0.12228400E+01, -.46408700E+00, -.61959000E+00, 0.62221000E+01, 0.10191800E+01, 0.42360300E-01, -.14454100E-01, 0.61363700E+00, 0.72030700E+00, -.32248200E+00, 0.18712300E+01, -.16813200E+00, -.51102500E+00, -.31115600E+00, -.99703000E+00, 0.51888400E+00, -.30681000E+00, -.80692700E-01, 0.79574500E+00, 0.64784400E+00, 0.63149600E-01, 0.34884900E+00, 0.18319700E+01, 0.62552100E+02, -.58486300E+02, 0.20901200E+04, -.10481100E+04, -.30099400E+04, -.10452400E+04, -.83088500E+03, 0.42831700E+03, -.12488100E+03, 0.88583600E+03, -.44369400E+03, 0.48897500E+03, -.63251300E+03, 0.41264900E+01, -.21280000E+02, 0.75410100E+02, 0.11481700E+01, 0.10631800E+03, 0.13969000E+03, -.20047800E+03, -.44930300E+02, -.80672400E+02, 0.15510100E+03, -.10766800E+02, 0.23169100E+03, -.12018300E+03, 0.30885800E+02, -.11555300E+03, 0.13580900E+03, 0.14533900E+03, -.27750200E+03, -.29192900E+03, -.37890800E+03, 0.27466100E+03, -.56692600E+03, -.64950600E+03, 0.32087000E+03, 0.10825500E+03, 0.32512500E+03, 0.16551500E+03, -.14052500E+03, 0.20714500E+03, 0.64832500E+02, 0.34091200E+03, -.20583300E+03, 0.14327600E+02, -.12559100E+04, 0.63008300E+03, 0.24422700E+04, 0.62811200E+03, 0.72615900E+03, -.36918500E+03, 0.63353400E+01, -.57989600E+03, 0.19256000E+03, -.35362200E+03, 0.11727300E+03, -.48917900E+03, 0.24846200E+03, -.19569700E+03, 0.24657000E+03, -.60153100E+02, 0.59505700E+02, 0.28387500E+03, 0.12297600E+03, 0.31673900E+03, 0.33728200E+02, 0.33741200E+03, -.52176600E+03, 0.26608700E+03, 0.11623500E+03, 0.26045600E+03, 0.21073000E+01, 0.33074400E+02, 0.15601900E+03, 0.48916700E+02, 0.41512700E+03, -.77399100E+02, 0.41903900E+03, -.31126600E+02, 0.11414400E+02, -.84815600E+02, 0.15726300E+02, 0.22472500E+02, 0.58737200E+02, 0.98317400E+02, 0.25963300E+03, 0.70043600E+02, 0.37862800E+01, 0.98528200E+02, 0.11633300E+04, -.57772900E+03, -.69993100E+03, -.58053200E+03, -.10700300E+03, 0.24425900E+03, -.27568200E+03, 0.16515500E+03, -.40171100E+03, 0.30640300E+03, -.53360100E+03, -.78524400E+02, 0.36662100E+02, 0.15000500E+03, 0.39501400E+02, -.90397500E+02, -.14236900E+03, -.13137000E+02, -.11086900E+03, -.49580000E+02, -.78685100E+02, -.18043700E+02, -.95363100E+01, -.24183400E+01, -.19500700E+03, 0.56151100E+01, -.11908600E+02, 0.17360000E+03, 0.61328100E+02, 0.33584100E+03, 0.13018800E+02, 0.13592700E+03, 0.21974400E+03, 0.11341200E+02, -.33420600E+02, 0.71863100E+01, -.14902400E+02, 0.14574200E+02, -.25319500E+02, -.40830700E+02, 0.73410800E+01, -.63315800E+01, 0.25096700E+02, -.59094200E+02, 0.15142300E+02, -.78205800E+02, 0.20085700E+02, -.44702500E+03, -.23756600E+01, -.93375400E+02, 0.49197000E+02, -.52130000E+03, -.55733300E+02, -.38985200E+02, -.59515500E+02, -.27816100E+02, 0.12889600E+02, 0.64987500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20564200E+01, 0.16871700E+01, 0.42434700E+01, -.18565800E+01, 0.50909500E+01, 0.89100900E+00, 0.55689400E+00, 0.15169700E+01, -.50671900E+01, -.11681000E+01, -.64820300E-01, 0.13142500E+01, -.78070000E+00, -.11158100E+01, 0.10412000E+01, -.15288200E-02, -.62762300E+00, -.30369000E+00, 0.41963200E-01, -.19262300E+00, 0.22285000E+01, 0.42726300E-01, -.28010900E+00, -.16407900E+00, 0.43939200E-01, 0.78156800E-01, 0.52507700E+00, 0.65189300E-01, 0.13484000E+00, -.45573700E+00, 0.58963600E+00, -.66364100E+00, -.60115700E+00, 0.27450400E+00, 0.48176400E+00, -.13353700E+01, -.62842700E-02, 0.16956000E+01, 0.74764700E-01, -.47228200E-02, 0.19238900E+01, 0.83355600E+00, -.46909700E+00, 0.35948400E+00, 0.31716300E+00, -.53460800E-01, 0.38493600E+00, 0.11469800E-02, 0.15506900E+01, 0.46334600E+00, -.59594200E+00, 0.56680100E+00, -.35413400E-01, -.13945400E+00, -.38091000E+00, 0.12186200E+01, 0.95629500E+00, -.90552200E+00, 0.18040600E-01, -.61819300E+00, -.49702200E+00, -.21793000E+00, -.34148200E-01, -.84558200E+00, -.56429300E+00, -.14253100E+00, -.21743600E+00, -.21551800E+01, -.73407900E+00, 0.15958700E+00, -.38170400E+01, -.49503300E+00, -.96316000E+00, -.62597900E-01, -.30269800E+00, 0.55640900E+00, -.17074700E+00, -.20163000E+01, -.53149000E+00, -.71865100E-01, 0.10983400E+00, -.20254100E+00, 0.12445600E+00, 0.40016300E+00, 0.13018600E+01, -.13041000E+01, -.22076600E-01, 0.11069500E+00, -.21805500E+00, -.55387900E+00, 0.53738800E+00, 0.18560100E+00, -.54025600E+00, 0.72285900E+00, -.30857900E+01, 0.31154500E+01, 0.27823600E+01, 0.25330800E+01, 0.94128000E+00, 0.99717600E+00, -.48873600E+00, 0.53082700E+00, 0.66148600E-02, 0.38477700E+00, -.27868500E+00, 0.65033300E+00, -.26368400E+00, 0.22520700E+01, 0.14340500E+01, -.51681500E-01, -.28311400E+01, 0.41108800E+00, 0.62352900E+00, -.51050200E-02, -.16021600E+00, -.57038700E+00, -.18754300E+01, -.18857200E+01, 0.18520300E+00, 0.42332700E+00, -.50564500E+00, -.25110700E+01, -.62567300E+01, 0.31976400E+01, 0.10065700E-01, -.17110600E+01, 0.10148900E+01, 0.39369500E-01, 0.58350700E+00, -.16909000E+01, -.11406600E+01, 0.81165200E+00, 0.73780900E+00, -.11156100E+01, -.14646000E+01, 0.12362900E+00, 0.26434600E+01, 0.24668600E+00, -.11714600E+01, -.74751500E+00, 0.23543000E+00, -.94045700E+00, -.33590300E+03, 0.40821800E+04, -.20366600E+04, -.16311100E+04, -.20408600E+04, 0.89343100E+03, -.16979400E+03, -.99531300E+03, -.21754700E+03, -.16170200E+04, 0.16741600E+03, -.58298300E+04, 0.28917600E+03, -.10338600E+03, 0.13497000E+03, -.15054500E+03, -.41761400E+02, -.23026500E+02, 0.56119100E+01, -.89019500E+01, -.30425500E+03, -.29711200E+01, 0.87520300E+02, -.89435600E+03, 0.44407200E+03, 0.65736700E+03, 0.44880400E+03, 0.23985500E+03, 0.34953000E+03, -.74560100E+02, -.45859200E+03, -.18507700E+03, 0.17408300E+03, -.34993500E+03, 0.13273900E+03, -.70579300E+02, 0.25666700E+03, -.66909400E+02, -.11474000E+03, -.25656600E+03, 0.10234500E+03, 0.66123400E+03, 0.10504100E+02, -.19891400E+03, 0.12272000E+04, -.22952300E+04, 0.11498500E+04, 0.81720000E+03, 0.11474200E+04, -.70434900E+03, 0.16909500E+03, 0.55473500E+03, 0.53105200E+02, 0.85427400E+03, -.56884100E+02, 0.31872500E+04, -.11850900E+04, 0.59798700E+03, 0.75952400E+03, 0.59018000E+03, 0.48108100E+03, 0.51052500E+03, -.32469900E+03, -.21700000E+03, -.14233500E+03, 0.42412900E+03, -.29096600E+02, 0.28444600E+04, -.14180500E+04, -.11701200E+04, -.14216900E+04, 0.51436100E+02, -.48997500E+02, -.45956300E+03, 0.62795900E+03, -.76402700E+03, -.29648800E+02, -.11092100E+04, 0.23365800E+03, -.12065800E+03, 0.46648900E+03, -.11700500E+03, 0.12004700E+03, 0.10080600E+03, -.10221100E+03, 0.55164800E+03, 0.22013200E+02, 0.24989700E+03, 0.10270500E+04, 0.23197800E+04, -.11609400E+04, -.82583900E+03, -.11614100E+04, -.35537800E+03, -.57339400E+03, -.28109100E+03, -.24733400E+03, -.10066800E+04, -.31907000E+03, -.36191000E+04, -.55853000E+03, 0.27986100E+03, -.36525600E+03, 0.27911100E+03, -.41696700E+03, -.52026800E+03, 0.27060300E+03, -.33308200E+03, -.16431800E+03, -.43814600E+03, 0.48339900E+03, 0.19790900E+03, -.82348500E+02, 0.33638500E+03, -.99840200E+02, 0.34576700E+03, 0.21461700E+03, 0.24651300E+02, 0.11417500E+04, 0.94277600E+02, 0.29297800E+02, 0.11334100E+04, -.11968500E+03, 0.10855300E+03, 0.15027200E+03, 0.13303000E+03, -.50082700E+02, 0.19561300E+03, 0.20755000E+03, 0.12826700E+03, -.14771400E+03, -.86688200E+02, 0.18357000E+03, -.12556800E+03, -.12462700E+03, -.12495000E+03, 0.61079600E+03, 0.12401300E+03, 0.23359700E+03, -.47752100E+02, 0.45307200E+03, -.13127800E+03, 0.29277500E+03, -.24605600E+02, -.19773600E+03, 0.82092600E+02, 0.25198500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16121600E+01, -.61538100E-01, 0.17307500E+01, -.57431200E+00, 0.21132800E+01, 0.18039400E+00, 0.46226200E-01, -.20552800E+01, -.50726300E+01, -.77268000E+00, 0.89139100E+00, 0.37636300E+01, -.18804900E+00, 0.17529000E+00, 0.17727200E+01, -.11392400E+01, -.18061800E+01, 0.45072900E+00, -.48921900E-02, 0.52488500E-01, 0.36291800E+00, -.35217000E-01, -.10700100E+00, -.10998500E+01, -.55941700E-01, 0.96185800E-01, 0.84585500E+00, -.41740200E+00, -.24857800E-01, -.14427600E+01, 0.95362300E+00, -.60196200E+00, -.12945500E+01, 0.13779000E+01, -.10598900E+01, -.27523000E+01, -.10076200E+00, -.13646900E+01, 0.93735800E+00, -.50390700E+00, 0.47539100E+00, 0.36796300E+00, -.22623800E+00, -.12389600E+01, 0.42257200E+00, 0.11873000E+01, 0.10527300E+01, -.15681100E-01, 0.85215100E+00, -.17891000E-02, -.10649200E+01, -.97859300E+00, 0.96266500E-01, 0.64533300E+00, -.92475400E+00, 0.15103400E+00, 0.12693700E+01, 0.23313400E+01, -.51016200E-01, 0.18877400E+00, 0.27173200E+00, -.17439500E+00, 0.16778900E+00, 0.17786500E+00, 0.87240800E+00, -.53133400E+00, 0.32836200E+00, -.43354100E+00, -.48476300E+00, 0.15809900E+00, -.49805200E+00, -.12021300E+01, 0.28197400E+00, -.36101400E+00, -.83432500E-01, -.17547600E+00, -.11398300E+00, 0.73076500E+00, -.39239000E+00, -.36410100E+00, -.11307500E+00, -.93679800E+00, -.21581600E+00, -.85742100E+00, -.10187300E+01, 0.11555500E+00, -.60954400E+00, -.13244800E+00, 0.33964800E-01, 0.51505800E+00, 0.68442300E+00, 0.28927600E+00, 0.20691400E+00, 0.72672300E+00, -.79416400E+00, -.11661900E+01, 0.58410000E+00, 0.10823400E+01, 0.43271900E+00, 0.29113600E+01, 0.12776200E+00, 0.17765200E+00, 0.17317300E-01, 0.31063000E+01, -.90126700E+00, -.15320400E+00, -.97322200E+00, 0.16406100E+01, 0.76091700E+00, -.27590400E+00, -.76475400E+01, -.85306600E+00, 0.52273100E-01, -.51935700E-02, 0.90143000E-01, -.52717300E+00, -.22531800E+01, -.11457300E+01, 0.33074600E+01, 0.15317100E+01, -.15167700E+01, -.11997600E+01, -.52743100E+01, 0.10260700E+01, 0.76577600E-02, -.76975900E+00, 0.77805800E+00, 0.33524800E+00, -.32161800E+00, -.23039200E+00, 0.10252100E+01, -.48009100E-01, 0.14818400E+01, 0.15374500E+01, 0.13780900E+01, -.62115300E-01, -.20724000E+01, -.10069400E+01, -.68590400E+00, -.14683400E+00, 0.15026400E+01, -.10500400E+00, 0.16234300E+00, -.59506200E+04, 0.29729200E+04, 0.25159600E+04, 0.29751200E+04, 0.67399500E+03, 0.18739800E+04, 0.40800700E+03, -.11353900E+04, 0.11222900E+04, 0.14034700E+04, 0.43162200E+03, 0.64272700E+03, -.34350900E+03, 0.24585300E+02, -.31469800E+03, -.27551400E+02, -.11984300E+03, -.98752500E+02, 0.95341600E+02, -.11980000E+03, -.84679700E+02, -.35578200E+03, 0.79680800E+03, -.40449100E+03, -.51317000E+03, -.39702900E+03, -.21072800E+03, -.29022800E+03, 0.62821300E+02, 0.39827700E+03, 0.45528100E+03, -.31420700E+03, -.93852300E+03, 0.13602200E+04, -.68472300E+03, -.89391300E+03, -.67965400E+03, 0.20881200E+03, 0.30403300E+03, -.61624300E+03, -.57976300E+03, -.12120200E+03, 0.23118100E+03, -.23868300E+04, 0.47499700E+04, -.23725900E+04, -.24302700E+04, -.23748400E+04, -.29743200E+03, -.12271300E+04, -.67306900E+03, 0.74407400E+03, -.11633900E+04, -.90806300E+03, -.46945300E+02, -.98747800E+03, 0.49719300E+03, 0.28666200E+03, 0.49552800E+03, -.60071900E+02, 0.10067300E+03, 0.96494300E+02, -.12327200E+03, 0.38055200E+03, 0.13844800E+03, 0.78890000E+03, -.91298800E+03, 0.46182900E+03, 0.26769600E+03, 0.45607800E+03, -.11546700E+03, 0.12565900E+03, 0.36615200E+02, -.40907400E+03, -.55445400E+02, 0.20636400E+03, 0.62980400E+03, -.25987800E+03, 0.12528000E+03, 0.79340400E+02, 0.13006200E+03, 0.31840300E+02, -.16885700E+03, 0.32606300E+03, 0.28813500E+03, 0.60686900E+03, -.33088000E+03, -.77942000E+03, -.60419500E+03, 0.30865600E+03, 0.35754700E+03, 0.30332100E+03, 0.48016600E+03, 0.93155800E+03, -.69813900E+03, -.82120700E+03, -.40524700E+03, 0.64035800E+03, -.13455900E+04, 0.94603700E+03, -.47599500E+03, -.12815300E+03, -.47299300E+03, -.96133900E+02, -.45465300E+02, -.30855700E+02, 0.34196800E+03, -.72818100E+02, -.14119700E+03, -.35169800E+03, -.44549000E+03, 0.21277300E+03, 0.10684700E+03, 0.22334500E+03, -.19906100E+02, 0.53096600E+02, 0.32374200E+02, -.26516900E+03, 0.57530500E+03, 0.13963000E+03, -.62097200E+02, 0.47242700E+02, -.72583400E+02, 0.47690800E+02, -.36562800E+02, 0.24182400E+03, 0.14009100E+03, 0.12284300E+03, -.45609400E+02, -.52092600E+02, 0.65027600E+02, 0.13838200E+03, 0.51771900E+02, -.32653500E+02, 0.51782500E+02, -.15286500E+03, -.31230900E+02, 0.80693700E+02, 0.24824400E+02, -.85833600E+02, -.27290100E+02, 0.51972900E+02, -.43505400E+02, -.18254900E+03, -.10174500E+03, -.79471800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17739700E+01, 0.12685200E+01, -.22798100E+01, 0.18959000E+00, -.15833600E+01, 0.39528100E-01, -.99600200E+00, -.92456800E+00, 0.32061600E+01, 0.23617900E+00, 0.32855500E+00, -.40460800E+01, -.83567300E+00, 0.19590600E+01, -.49564600E+01, 0.13896400E+01, 0.16328900E+01, 0.11772900E+01, -.38085600E+00, 0.17838100E+01, -.39030000E+01, -.73345300E-01, 0.22935400E+01, 0.14280300E+01, 0.10829600E+00, -.27615000E+00, 0.75669400E+00, -.56920900E+00, 0.57133500E-01, 0.14215900E+01, 0.17860300E-01, -.80626100E+00, 0.31343200E+00, 0.27385900E+00, -.77176200E+00, 0.22891000E+01, -.72082000E-02, 0.18257900E+01, -.18852000E+01, 0.15146300E+01, -.92473400E+00, -.11259100E+01, -.71579600E+00, -.37893700E+00, -.37823500E+00, -.93446800E-01, -.42110300E+00, -.64695500E-02, 0.89215100E+00, -.66396200E+00, 0.22183000E+01, 0.74611000E+01, 0.31196500E+00, 0.25730200E+01, 0.41313900E+00, -.16279700E+01, -.76307000E+00, 0.17540200E+00, 0.28406100E-01, -.31434800E+00, 0.98646000E-01, 0.12572600E+01, -.20718400E+00, 0.99558100E+00, -.12789700E+01, -.32823100E+00, 0.44823000E-01, 0.17043500E+00, 0.61605700E+00, 0.29277500E+00, 0.17815500E+01, 0.18612300E+00, 0.22376500E+00, -.77835300E+00, -.46350100E+00, 0.10334300E+01, 0.19332800E+00, 0.14020500E+01, 0.16369400E+00, 0.55707600E+00, -.22279900E+00, -.19215900E+00, -.14935400E+01, -.35872900E+01, 0.11477600E+01, -.13548100E+01, 0.12439000E-01, 0.13703800E+00, -.65223600E+00, 0.43264100E+00, -.12786400E+01, -.21533000E-03, -.48942700E+00, 0.11203900E+00, -.17891400E+01, 0.20980300E+01, 0.15152400E+01, 0.20642900E+01, 0.40087200E-01, -.10299700E+01, -.19616200E-01, -.12314700E+00, -.23676400E-01, 0.13139700E+01, 0.56147900E+00, 0.74913800E+00, -.12055600E+00, 0.12911300E+01, 0.12837800E+01, 0.91499800E-01, 0.49910300E+00, 0.26300600E+00, -.81735400E-01, -.87354400E-02, -.50997600E-01, -.27493100E+00, 0.30130200E+01, -.26531700E+00, 0.98034600E+00, -.22089800E+00, -.68176400E+00, -.13677700E+01, -.19254300E+01, 0.17543700E+00, -.11428200E-01, -.20447800E+00, 0.53464500E+00, 0.47959500E+00, -.13332400E+01, -.34195900E+00, -.68973300E+00, -.11187500E+00, -.55866100E+00, 0.12823400E+00, 0.12202900E+01, -.39938400E-01, -.65491700E+00, -.56722800E+00, 0.11180300E+00, 0.94840400E-02, -.78773300E+00, 0.25692700E+00, -.25891200E+00, 0.48183400E+00, 0.75283200E+01, 0.10219900E+04, 0.13926600E+00, 0.74061400E+03, -.69256700E+01, -.17792400E+03, 0.40234800E+02, -.46738000E+03, 0.57265000E+03, -.58974300E+02, -.40436000E+03, 0.24305900E+03, 0.78425800E+02, 0.19760000E+03, 0.28618300E+02, 0.15166800E+03, 0.82031900E+01, -.15941700E+03, 0.33554500E+01, 0.13177300E+03, 0.25380000E+03, -.69231800E+02, 0.41878900E+02, 0.26412400E+03, 0.35121100E+02, -.83167500E+02, 0.54217500E+02, 0.28397000E+01, -.24751600E+03, -.28623500E+03, 0.18447300E+00, 0.45279500E+03, 0.36044800E+03, -.17642300E+03, 0.42365400E+03, -.18058200E+03, -.20421500E+03, -.15765200E+03, 0.19081600E+03, 0.33066800E+03, -.45454200E+03, -.70121200E+02, 0.11264800E+04, -.63339300E+03, 0.31333200E+03, -.55187100E+03, 0.31658400E+03, -.54056100E+03, 0.53563300E+01, 0.24005500E+03, -.11121500E+03, 0.51273900E+03, -.37618100E+03, -.10992700E+03, 0.34317700E+03, -.17395400E+03, 0.56638600E+03, -.17289200E+03, 0.31906100E+03, 0.33468600E+03, -.55265900E+03, -.31071900E+03, -.50122600E+03, 0.29329700E+03, -.59556500E+03, 0.11891400E+04, -.60206700E+03, -.17399800E+03, -.59425800E+03, 0.19047600E+03, 0.83515100E+02, -.27980200E+03, 0.27433800E+03, -.42025800E+03, 0.10010800E+03, -.83919600E+03, 0.16289800E+03, -.77895800E+02, 0.24275200E+03, -.81535200E+02, 0.70493700E+02, -.72335300E+02, -.38485900E+02, -.99518600E+02, -.35950100E+03, 0.11405700E+03, 0.42366000E+03, -.14227600E+04, 0.70167500E+03, 0.89779800E+03, 0.71043800E+03, -.25749800E+02, -.39755100E+03, 0.38106700E+03, -.13934800E+03, 0.19400000E+03, 0.10418000E+02, 0.47173900E+03, -.47714300E+03, 0.24417500E+03, -.11452000E+03, 0.23856000E+03, -.51853900E+02, -.10862000E+03, 0.32296200E+02, -.25788100E+03, -.88551700E+01, -.88339800E+02, 0.14849400E+03, 0.54415700E+03, -.24962600E+03, 0.19470600E+02, -.27249200E+03, 0.24225400E+03, 0.28720500E+03, -.25089400E+03, 0.75724100E+01, -.56623400E+03, 0.24059000E+03, 0.10598100E+03, -.62172500E+02, 0.10318200E+03, 0.64442600E+02, 0.11168300E+03, -.10642900E+03, 0.58492600E+02, 0.72831300E+02, 0.10435000E+03, -.62846000E+02, -.69387600E+02, 0.84037800E+01, -.10962900E+03, -.15155400E+02, -.11142300E+03, 0.16216700E+03, 0.95605900E+02, 0.44968400E+02, -.21483900E+02, 0.67604800E+02, -.74792900E+02, 0.48093400E+01, 0.56076300E+02, -.24664400E+02, 0.80326400E+02, 0.49196600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10151700E+01, -.45167800E+00, -.11164500E+01, -.24375900E+01, -.14198800E+01, 0.16270800E+00, 0.20436000E+01, 0.19335200E+01, -.19975400E+01, -.96604100E+00, -.13278200E-01, -.10318900E+01, 0.24957700E+01, -.31001800E+00, 0.28460000E+01, -.57945800E+00, -.13433400E+00, -.87650200E-01, 0.65994200E-01, 0.42539700E+00, 0.14550200E-01, 0.43083100E-01, -.78473200E+00, -.45201700E+00, -.69493800E-01, 0.17101600E+00, -.10070900E+01, -.32414100E+00, 0.10083700E+00, 0.25289600E+00, -.99849500E+00, 0.65771100E+00, 0.10174100E+01, -.41897800E+00, 0.98100300E+00, 0.19218500E+01, 0.60879300E-01, 0.95606300E+00, -.39412400E+00, 0.89765500E+00, -.68847800E+00, -.71781700E+00, -.78384000E+00, -.27578400E+00, 0.31608600E+00, 0.26138800E-01, -.33002600E+00, 0.11992800E-01, -.16445600E+01, 0.18556200E-01, -.28403000E+00, -.11440400E+01, -.17543600E+00, -.41756600E+00, 0.47314400E-01, -.65476800E+00, -.51976100E+00, 0.10488100E+01, -.15936100E-01, 0.10433800E+00, -.11941300E+00, 0.28652100E-01, 0.22382200E+00, 0.13344300E+01, -.28650300E+01, -.10692600E+00, -.18871000E+00, 0.15990400E+01, 0.14425700E+01, -.32781300E-01, -.19627700E+01, -.73434900E+00, -.43469700E+00, 0.84872700E-01, 0.32291800E+00, -.34540900E+00, -.23590400E-01, -.24897700E+00, -.16629700E+00, -.73698700E-02, 0.10089200E+00, -.16232800E+00, -.34882100E+00, -.16437900E+01, -.51786200E+00, 0.44703700E+00, -.32193900E+00, -.77810600E+00, 0.28450600E+00, 0.38755600E+00, -.64794900E+00, 0.11047000E+00, 0.31015000E-01, 0.19756700E+00, 0.12173000E+01, -.94597000E+00, -.86457700E+00, -.33610000E+00, -.41204300E+00, 0.10711500E+01, 0.54208500E-01, 0.11875200E+00, 0.24410100E-01, 0.11721900E+00, -.38296700E+00, -.40860100E+00, -.16008100E+00, 0.56603200E+00, -.12345300E+01, 0.29678400E+00, 0.25099400E+01, 0.21717100E+00, -.28498800E+00, 0.62114500E-02, 0.12595200E+00, 0.29508900E+00, 0.22542200E-01, 0.12022900E+01, -.27717100E+01, -.32221800E-01, 0.13289200E+00, -.62393000E+00, 0.34624800E+01, -.11060900E+01, 0.11178900E-01, 0.13069500E+01, -.80822500E+00, 0.34015000E+00, -.16450500E-01, 0.58856400E+00, 0.91662900E+00, -.14506000E+00, -.66684500E+00, 0.38906100E+00, -.20674600E-01, 0.44180400E-01, 0.18139800E+00, 0.10710900E-01, 0.16852800E+00, 0.10279300E+00, -.43647900E-01, 0.23192600E+00, 0.21970700E+00, -.98571100E-01, -.47881600E+00, 0.19614300E+04, 0.80930500E-01, 0.19508400E+03, 0.44625200E+03, -.27264800E+02, 0.21375300E+03, -.33045500E+03, 0.47135500E+03, 0.78418100E+03, -.20736000E+03, 0.10571300E+03, 0.46200400E+02, 0.10216200E+03, 0.20012300E+02, 0.10836600E+02, 0.33239000E+02, -.63418400E+02, 0.57410400E+02, 0.87497000E+01, 0.37701200E+02, 0.32780400E+03, -.16393800E+03, -.22780200E+03, -.16326100E+03, -.11797600E+03, -.18435500E+03, 0.57353600E+02, 0.13017800E+03, 0.69574000E+02, -.13516100E+03, 0.63237200E+01, -.40447100E+02, 0.21447700E+02, 0.20948600E+03, 0.20043600E+02, 0.16896300E+03, 0.13908800E+02, 0.88304600E+02, -.12370600E+02, -.15531100E+03, 0.89231000E+02, -.18992400E+02, -.41588000E+03, 0.20765300E+03, -.17119600E+04, 0.20786700E+03, -.15375900E+03, -.40117800E+03, 0.81251700E+02, -.19090500E+03, 0.37934200E+03, -.36594100E+03, -.14021600E+03, 0.50242700E+03, -.25305200E+03, 0.24550400E+03, -.25210800E+03, -.95250600E+02, -.81713200E+02, -.30347800E+03, -.97525600E+02, -.12351300E+03, -.46720800E+02, -.19735700E+03, 0.28928300E+01, -.20239300E+01, 0.15285200E+03, -.12499000E+01, 0.46299500E+02, 0.97020700E+02, -.91359600E+02, -.25375800E+02, -.96208700E+02, 0.11619500E+03, -.12887300E+02, 0.32320900E+03, -.16214100E+03, -.34048700E+02, -.16167600E+03, 0.80181800E+02, 0.91873300E+02, -.84699600E+02, -.15576900E+03, -.33276800E+03, 0.91461800E+02, -.26260400E+03, -.72480500E+03, 0.36374700E+03, 0.37048300E+03, 0.36186800E+03, 0.15749500E+03, 0.10464100E+03, 0.48631100E+02, 0.22303500E+02, 0.68887800E+02, 0.22583500E+03, 0.10564200E+04, -.17640300E+02, 0.85087700E+01, 0.13741100E+03, 0.87211700E+01, 0.13433900E+03, 0.20549600E+03, -.88185700E+02, -.51810300E+02, -.11054200E+03, 0.16679100E+03, 0.30966400E+02, 0.34600500E+03, -.17561300E+03, -.84737900E+02, -.17337200E+03, -.74261000E+01, -.20431100E+02, -.16072100E+03, -.21001100E+03, -.13885900E+03, -.78374100E+01, -.33578200E+03, -.56973000E+02, 0.10538800E+02, -.27646800E+02, -.10053200E+02, -.28857400E+02, -.65702400E+02, -.65905200E+02, -.82803400E+01, 0.27509000E+02, -.40761600E+02, -.53944000E+02, 0.73290700E+01, 0.16219000E+02, 0.10008100E+02, -.68502800E+02, -.85132000E+01, -.65178600E+02, 0.35271300E+01, -.58802800E+02, -.22305900E+02, -.98444800E+02, 0.95265500E+01, 0.41080300E+02, -.53392100E+01, 0.85159600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26819000E+01, -.96169900E+00, -.67440700E+00, -.34111700E+01, -.28716800E+01, -.98161300E-01, 0.33389700E+01, 0.36431500E+01, -.36979300E+01, -.13532700E+01, -.93575300E-01, -.96197500E+00, 0.26272600E+01, -.32118000E-01, 0.28646300E+01, 0.27314700E+00, 0.24442900E+00, -.14352500E+01, 0.17150500E+01, -.62001700E+00, -.25904100E+01, 0.44507100E+00, -.18459400E+01, 0.16052600E+01, -.27943000E+00, 0.11833400E-01, 0.26220400E+01, -.70059500E+00, -.13693800E+00, -.62615400E-01, -.25936500E+00, 0.10004800E+01, -.85639300E-01, -.38849000E+00, 0.32722900E+00, 0.10276400E+01, 0.55550200E-01, 0.15956500E+01, -.14418300E+00, 0.63475100E+00, 0.22547200E+01, -.64721200E-01, -.20578300E+01, -.16121600E+00, 0.32215700E+00, 0.43339200E+00, -.88050600E+00, 0.16246800E-01, 0.71854700E+00, -.53344400E+00, 0.42235900E+00, 0.26548800E+01, -.21429700E+00, -.47690000E+00, -.15841400E+00, -.19573100E+00, 0.13217700E+00, 0.77963600E+00, 0.39107400E-01, -.15324800E+01, -.93922600E-01, 0.61820000E+00, -.50504400E+00, 0.12936400E+01, -.23883200E+01, -.48439300E+00, 0.56194100E+00, 0.38111600E+01, 0.19657200E+01, 0.38240900E+00, -.12359100E+01, 0.99452900E-01, -.33910000E+00, -.65027200E-01, -.69311900E-02, 0.20841600E+00, 0.10565900E+00, -.19963000E+00, -.18984600E+00, -.11243100E+00, -.33421000E+00, 0.60360800E+00, -.17885800E+01, -.39175000E+01, -.18563300E+01, -.28575700E+00, 0.20826700E+00, -.98242000E-01, 0.19142600E+00, -.14279400E+01, 0.17799300E-01, -.37176700E+00, 0.15037800E+01, -.88069400E+00, -.13839500E+00, 0.78530000E+00, -.36329600E+01, -.15232200E+00, -.10974800E+01, -.10640700E+01, -.12057000E+00, -.21796300E+00, -.11898600E-01, -.21436300E+01, 0.17625100E+01, 0.52653200E+00, 0.46995000E+00, -.47260200E+00, -.74093000E+00, 0.45001400E+00, 0.95271100E+01, 0.14481300E+01, -.34196000E+00, 0.63860400E-02, 0.23972700E+00, 0.81705400E+00, 0.36163800E+01, 0.21114700E+01, -.34765400E+01, -.80944500E+00, 0.16435400E+00, -.39795200E+01, 0.42047200E+01, -.16974400E+01, -.29948700E-02, 0.30711200E+00, -.15089400E+01, 0.19583300E+00, -.73028300E+00, 0.19460500E+00, 0.66094400E+00, -.34597700E+00, -.63005100E-01, 0.16402600E+00, -.21272900E+00, 0.33531100E-03, -.14867800E+01, 0.77233100E-01, 0.33936700E+00, 0.16167900E+00, -.13356500E+01, -.34270600E-01, 0.18957800E+00, 0.24609700E+00, 0.14739700E+00, 0.17172000E-01, 0.55004900E+01, -.47063500E+03, 0.17530200E+03, 0.23371600E+03, 0.64751700E+03, 0.46967000E+02, -.43217700E+02, 0.11977100E+04, 0.13597600E+03, -.78483700E+02, -.15102000E+03, -.65748500E+02, 0.51862700E+01, -.64615500E+02, -.14386000E+02, 0.65830100E+02, 0.91930200E+02, -.64466200E+02, -.15611300E+03, 0.22594800E+03, -.11064600E+03, -.21278000E+03, -.11277400E+03, 0.42700500E+02, -.85521100E+02, -.42147600E+02, 0.91723400E+02, 0.17400000E+02, 0.21357800E+02, -.41893800E+02, -.62011500E+02, 0.34070500E+02, -.17514000E+03, 0.31199000E+02, 0.47341900E+03, 0.13801100E+03, -.19469400E+03, -.21955300E+03, 0.17533200E+03, 0.15395900E+03, -.51264300E+03, -.42073300E+03, 0.20938900E+03, 0.13844300E+03, 0.21042500E+03, 0.40609200E+03, -.30355800E+03, -.25532500E+02, -.43790500E+03, 0.14836200E+03, -.65816200E+02, -.50994000E+03, -.13051100E+03, 0.62438100E+02, -.30145200E+03, 0.65909700E+02, -.20732700E+03, -.14799800E+03, 0.23757000E+03, -.42226400E+02, 0.27095300E+03, -.12516800E+03, 0.34848100E+03, -.10015600E+04, 0.49880300E+03, 0.37220300E+03, 0.50062100E+03, 0.34776400E+02, 0.20811800E+02, 0.18962500E+03, -.14237000E+03, 0.38127000E+03, -.21985600E+02, 0.45748000E+03, 0.27628800E+03, -.13305700E+03, -.20531100E+03, -.13810300E+03, 0.29727800E+01, 0.14447300E+03, -.17853300E+03, -.26216500E+03, -.65362500E+02, 0.75948000E+02, -.37632100E+03, 0.51828300E+02, -.26438400E+02, -.18647800E+03, -.25415900E+02, 0.10205100E+03, 0.79480500E+02, 0.16577100E+02, 0.21487100E+03, 0.12586100E+03, -.19233100E+02, 0.82069900E+03, 0.18669400E+03, -.92717500E+02, 0.16938400E+03, -.93346900E+02, 0.28999900E+02, 0.50815100E+02, 0.29305300E+02, 0.20919900E+03, 0.86915700E+02, 0.27775300E+02, -.51970500E+02, 0.11346500E+02, -.87288600E+01, -.74909600E+02, -.54782900E+01, -.81657000E+02, -.83051600E+02, 0.10215100E+02, -.29602400E+03, 0.10255900E+03, -.20159800E+02, -.30286200E+03, -.14193600E+02, -.41588000E+02, -.49302000E+02, -.55610900E+02, 0.88513000E+01, -.48240700E+02, -.59134700E+02, -.47991800E+02, 0.48024000E+02, 0.65996800E+01, -.40456900E+02, 0.50125400E+02, -.13667000E+02, 0.51355200E+02, -.34180700E+03, -.43372900E+02, -.65108100E+02, 0.85645400E+01, -.31708200E+03, 0.15536800E+02, -.63554600E+02, 0.20044900E+02, 0.49900600E+02, -.22738800E+02, -.52377700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26135100E+01, 0.35278400E+01, 0.41666300E+01, -.41077100E+01, 0.51209400E+01, 0.13006200E+01, 0.12333000E+01, 0.30677800E+01, -.35380900E+01, -.10132200E+01, 0.19976500E+00, -.53859100E-01, 0.26230400E+01, 0.44051800E+00, 0.23820800E+01, 0.88915800E+00, -.28601800E+00, -.22326600E+01, 0.20646400E+01, -.23208700E+01, -.20536300E+01, 0.43951500E+00, -.18569500E+01, -.90571200E+00, -.27337500E+00, -.18706500E-01, 0.18849200E+01, -.65317200E+00, -.36718000E+00, -.89260200E+00, -.29677400E+00, 0.82654600E+00, -.90626000E+00, 0.44944100E+00, 0.15688600E+01, -.12478700E+00, 0.20997500E-01, 0.35748700E+01, -.56155000E+00, 0.17389100E+00, 0.28196100E+01, 0.10063500E+00, -.22441600E+01, -.33158200E-01, -.33571500E-01, 0.62861200E+00, -.10035200E+01, 0.77241200E-02, 0.92954700E+00, -.50509300E+00, -.83323000E+00, 0.53088700E+00, -.22524700E+00, -.92692800E+00, -.26327300E+00, 0.22575400E+00, 0.45498400E+00, 0.39049600E+01, 0.33513000E-01, -.15866300E+01, -.19804700E+00, 0.25582000E-01, -.62663200E+00, -.57622100E+00, 0.11017100E+00, -.23740400E+00, 0.17184600E+00, 0.79436600E+00, 0.22833600E+00, 0.49193700E+00, -.26644200E+01, 0.86015300E+00, -.11931900E+01, 0.79900200E-02, -.56112600E+00, 0.17196900E+01, -.40587300E-02, -.15199200E+01, 0.11093800E+00, 0.65950800E-01, -.25482200E+00, 0.11079000E+01, -.17745200E+01, -.29557600E+01, 0.57871500E+00, -.41193600E+00, 0.19676300E+00, 0.67977000E+00, 0.11439100E+00, -.23481300E+01, 0.99870500E+00, -.20755500E+00, 0.19897400E+01, -.12368000E+01, -.18326100E+01, 0.20051100E+01, -.12538700E+01, 0.16127800E+01, -.55556800E-02, -.18016500E+01, -.13367200E+00, -.86995900E-01, -.17660300E-01, -.11129000E+01, 0.69553800E+00, 0.10185300E+01, 0.67827800E+00, 0.12332000E+01, 0.70079600E+00, 0.24375700E+00, 0.54180100E+01, 0.99759000E+00, -.14667400E+00, -.13677900E-02, 0.20616700E-01, -.65494900E-01, 0.34467000E+01, 0.21026000E+01, -.24143900E+01, -.20194300E+00, -.26988000E+00, -.17004300E+01, 0.59449000E+01, -.24149600E+01, -.22961500E-01, 0.13239400E+01, -.10291400E+01, -.46583700E-01, -.13602600E+01, 0.24170700E+00, 0.72530700E+00, -.24494300E+00, -.57240400E+00, 0.48370500E+00, 0.35837400E+00, 0.59673600E-02, 0.47501100E+00, -.22683200E+00, 0.11125300E+00, -.95005800E-01, 0.75025200E+00, 0.70249200E-02, 0.51318400E+00, 0.18947100E+00, 0.11627500E+01, -.44989900E+00, -.40262500E-01, -.17006900E+04, 0.54479700E+03, 0.51926400E+03, 0.93644600E+03, 0.16683600E+03, -.42165200E+03, 0.36055400E+04, 0.56625200E+03, -.36096700E+03, -.24010300E+03, -.27486100E+03, -.47247000E+02, -.31751900E+03, 0.76502100E+02, 0.29227600E+03, 0.16581000E+03, -.29482100E+03, -.59434000E+03, 0.57997600E+03, -.30409300E+03, -.72461500E+03, -.28952000E+03, 0.59251400E+02, -.27717900E+03, -.35193900E+02, 0.46597500E+03, 0.38771300E+03, -.37400100E+02, -.34419700E+03, -.48620300E+03, 0.23599700E+03, -.74711800E+03, 0.24369600E+03, 0.86221700E+03, 0.31987800E+03, -.36493200E+03, -.61209000E+03, 0.65167500E+03, 0.19381600E+03, -.20565700E+04, 0.44122600E+03, -.22023600E+03, -.40952100E+03, -.22043800E+03, 0.12639300E+04, -.53984700E+03, -.40831000E+03, -.52075100E+03, -.23578500E+03, 0.19005900E+03, -.18509700E+04, -.33771500E+03, 0.17213400E+03, -.93352700E+03, 0.17086700E+03, -.60190700E+03, -.56975500E+03, 0.81113900E+03, 0.24099000E+03, 0.74831300E+03, -.44489300E+03, 0.10437500E+04, -.31103800E+04, 0.15694200E+04, 0.91436200E+03, 0.15547000E+04, -.12236400E+03, 0.43220600E+02, 0.56719000E+03, -.58133900E+03, 0.10164400E+04, -.25564300E+02, 0.17475000E+04, 0.30468700E+03, -.16591700E+03, -.72120400E+03, -.15221900E+03, -.98154200E+02, 0.22401700E+03, -.17243000E+03, -.41049800E+03, 0.14433200E+03, -.13369400E+03, -.11093500E+04, 0.96915000E+03, -.46266000E+03, -.11088900E+04, -.48305400E+03, 0.26077300E+03, 0.66038700E+03, -.30017400E+03, 0.46242000E+03, -.91495200E+02, 0.10449300E+03, 0.21855000E+04, 0.11226000E+04, -.56948700E+03, 0.48607800E+03, -.56135300E+03, 0.18225800E+03, 0.29058800E+03, -.93052500E+02, 0.59534000E+03, -.54492900E+02, 0.20377000E+03, -.51807700E+03, -.65515400E+03, 0.28575700E+03, -.26895300E+03, 0.32815700E+03, -.43058800E+03, -.48478900E+03, 0.33666600E+03, -.55447200E+03, 0.79343600E+03, -.33735800E+03, -.77540100E+03, 0.78389200E+02, -.18832200E+03, -.18549000E+03, -.23719900E+03, 0.15742700E+03, -.20850500E+03, -.24135800E+03, -.22553800E+03, 0.18193900E+03, 0.98300000E+02, -.10470600E+03, 0.22248200E+03, 0.37245300E+02, 0.23062200E+03, -.75934100E+03, -.20329400E+03, -.18541800E+03, 0.83525200E+02, -.57021700E+03, 0.12931700E+03, -.18260500E+03, -.42309300E+02, 0.10220800E+03, -.16748300E+03, -.17052300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.81446900E+00, -.71864900E+00, -.16247000E+01, -.93748500E+00, -.12955000E+01, -.55168000E-01, 0.87074100E+00, -.97881400E+00, -.50994400E+00, -.14403700E+00, -.12320300E+00, 0.85900700E+00, -.20134500E+01, -.67269600E+00, -.58825600E+00, -.97250700E+00, -.29515500E+00, 0.87925700E+00, -.66221300E-01, 0.94614400E+00, -.10982900E+01, -.40493500E-01, 0.16120500E+00, 0.15245200E+01, 0.14336100E+00, 0.12222400E+00, 0.71266300E+00, -.63011100E-01, 0.80921400E-01, -.70958400E+00, -.48190700E-01, -.13118600E-01, 0.69205900E-02, 0.18595500E+00, -.33740900E+00, 0.42797200E+00, 0.14667200E-01, -.71044200E+00, 0.25491500E+00, -.49726800E+00, 0.58485600E+00, 0.18548600E+00, 0.35029900E+00, 0.15378900E+00, -.16300100E-01, -.19933500E+00, -.12295200E+00, 0.38275200E-02, -.42748700E+00, 0.55774400E+00, 0.89785400E+00, -.27980600E+00, 0.14351000E+00, 0.14232500E+00, 0.90956300E-01, -.18320700E+00, -.50753200E+00, -.22689700E+01, 0.18504700E-01, 0.44160000E+00, -.69074800E-01, 0.93113600E-01, 0.40396600E-01, 0.29894300E-01, -.33720900E+00, -.81515700E-01, 0.65102400E-01, -.80128400E-01, -.11520600E+00, -.16326000E+00, 0.14054400E+00, 0.95827400E-01, -.11051600E-01, -.36604100E-01, 0.19111200E+00, -.50581500E+00, 0.44998200E-01, 0.30572000E+00, 0.90263200E-01, -.50811000E-01, 0.60161300E-01, -.18182900E+00, 0.39947500E+00, 0.46423400E+00, -.29371500E+00, 0.32095300E+00, 0.63492500E-01, -.30879800E+00, -.17604400E+00, 0.81700100E+00, -.47110500E+00, -.77210800E-02, 0.38022200E+00, 0.24705800E+00, 0.10803500E+01, -.34327000E+00, -.22202500E+00, -.63871900E+00, -.43421400E+00, -.64939000E+00, -.17535200E-01, -.10247300E+00, 0.40798600E-03, -.80849900E+00, 0.54281000E+00, -.52831300E-01, 0.11770000E+00, -.65243800E+00, -.31239000E+00, 0.29703500E+00, 0.19072600E+01, 0.26927500E+00, -.79522900E-01, 0.23895500E-02, 0.49372600E-01, 0.22396300E+00, -.52852800E+00, 0.76065000E+00, -.21499300E+01, -.10158000E+00, 0.41137600E+00, -.20563500E+01, 0.44861500E+00, -.18171700E+00, 0.58091700E-02, -.19888400E+00, -.45784300E+00, 0.31864800E+00, -.63224500E+00, 0.34074700E+00, -.30809200E-01, -.88068300E-01, -.48130000E+00, -.56875800E+00, -.13142500E+00, -.52400900E-02, -.78344000E-01, -.81599000E-01, -.20917200E-01, 0.25442400E-01, -.34618400E+00, -.39416500E+00, 0.64421100E-01, 0.29279200E+00, -.11468400E+00, -.40333300E+00, 0.34008100E-02, 0.16841300E+00, -.86189200E+03, 0.36223000E+03, 0.42349100E+03, 0.31893400E+03, -.26558100E+03, 0.12572200E+03, -.25907700E+03, 0.15995100E+03, 0.65334200E+02, 0.12668100E+03, 0.60064800E+02, 0.17815400E+03, -.62506400E+02, -.12207400E+03, -.30198600E+02, 0.15860300E+03, 0.20760000E+03, -.22262700E+03, 0.11791700E+03, 0.24264300E+03, 0.10971500E+03, 0.42158900E+02, 0.90493200E+02, -.48079500E+01, -.21270700E+03, -.21873600E+03, 0.64105600E+02, 0.22698500E+03, -.48250200E+03, 0.24530600E+03, 0.71712700E+03, 0.24108600E+03, -.87329600E+02, -.17239400E+03, 0.43580900E+03, 0.29931500E+03, -.11637700E+03, -.86852500E+02, 0.12551700E+04, -.64082000E+03, 0.31965800E+03, 0.55458500E+03, 0.32037100E+03, 0.74114500E+02, 0.58915700E+03, -.13332200E+03, -.39811000E+03, 0.50418000E+01, 0.21502700E+03, -.26776800E+03, 0.76529000E+03, -.38516400E+03, 0.32695100E+03, -.38307800E+03, 0.49834000E+02, 0.12510800E+03, -.39987200E+03, -.15719900E+02, -.36608300E+03, 0.89171700E+02, -.65717400E+03, 0.87899500E+03, -.44681500E+03, -.21241600E+03, -.43938400E+03, -.20149000E+02, -.96713500E+02, -.12395800E+03, 0.24119200E+03, -.23514700E+03, -.78370000E+02, -.57190700E+03, 0.72192200E+01, 0.14930400E+01, 0.92878100E+02, -.36287400E+01, 0.15257700E+03, 0.61949800E+02, 0.34627800E+02, 0.11054600E+03, -.15629500E+03, 0.18032200E+03, 0.51216300E+03, -.25410800E+03, 0.11787100E+03, 0.24244500E+03, 0.12666800E+03, -.12750700E+03, -.19323300E+03, 0.18815900E+03, 0.17615000E+03, 0.14865700E+03, 0.13277300E+03, 0.11221400E+03, -.79775500E+03, 0.40202700E+03, -.15611500E+02, 0.39895700E+03, 0.31393700E+02, 0.36063200E+02, 0.33830300E+01, -.32958500E+03, 0.29265200E+02, 0.83738500E+02, 0.20389600E+03, 0.60781900E+03, -.28881200E+03, -.91899100E+02, -.30398000E+03, 0.14945500E+03, 0.13669600E+03, -.24537600E+03, 0.12837900E+03, -.46060300E+03, 0.65834600E+02, 0.19065000E+03, -.79122700E+02, 0.65078100E+02, 0.20236000E+02, 0.51941800E+02, -.10124300E+03, -.37949700E+02, -.26782000E+02, 0.56220900E+02, -.18424100E+02, -.69137100E+02, -.90529400E+02, -.54914300E+02, -.10712400E+02, -.56696200E+02, 0.71711000E+02, 0.45788600E+02, -.62592200E+02, -.32027500E+02, -.69952400E+02, -.74780400E+02, -.57224800E+02, 0.79820500E+01, 0.32415700E+02, 0.77414000E+02, 0.86910000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13289200E+01, 0.67053700E+00, -.42506600E+00, -.27832600E+01, -.38117600E+00, 0.28055900E+00, 0.20309500E+01, 0.11327800E+01, -.38365700E+01, -.11414600E+01, -.10161100E+00, -.86255300E+00, -.35455300E+00, -.13762400E+01, 0.82033100E+00, -.40403200E+00, 0.12415100E+00, 0.81317600E+00, 0.33182000E+00, 0.14053900E+01, 0.80251900E-01, -.26371300E-01, -.50262000E+00, 0.65671100E+00, -.89397800E-01, 0.89129500E-01, 0.15029600E+01, -.18437100E+00, 0.47872500E+00, -.60428500E+00, 0.66908200E+00, -.12562500E+01, 0.45036000E+00, 0.21093400E+01, -.94872500E+00, -.51396200E+00, 0.16867700E-02, -.11078000E+00, 0.68667000E-01, 0.11210300E+01, 0.71903200E+00, 0.62487800E+00, -.88869000E+00, 0.75556400E-01, -.10504700E+01, -.32888000E+00, 0.19925900E+00, 0.25142100E-02, -.25578400E+00, 0.14177800E+00, 0.18861100E+00, -.37673900E+00, 0.86279200E-02, -.22552000E+00, 0.18572100E-01, -.50365500E+00, -.29964700E+00, 0.14522200E+01, -.53799400E-02, 0.12758800E+00, 0.36431000E-01, -.24471900E-01, 0.11923300E+00, 0.12413000E+01, -.23436800E+00, -.56476500E-01, 0.21591700E-01, 0.97333100E+00, 0.37225800E+00, 0.55975600E-01, -.82281800E+00, 0.18405700E+00, 0.28953000E-01, 0.82249300E-01, 0.21252100E+00, -.23427600E+00, 0.69475200E-01, 0.34109800E+00, 0.10046300E+00, 0.68935700E-01, -.62210700E-01, 0.24187500E+00, -.50672400E+00, -.13889600E+01, -.48185400E+00, 0.51230900E+00, -.27020500E+00, -.39520000E+00, 0.28472900E+00, -.12971800E+00, -.52415700E+00, -.19018300E-02, 0.34974400E+00, 0.12032200E+00, 0.27199200E+00, -.20915800E+00, -.19197800E+00, -.13069000E+01, -.13077100E+00, 0.92394600E+00, 0.26691900E+00, 0.69988500E+00, 0.21848300E-02, -.87826700E+00, -.94773200E+00, -.15427400E+00, -.39118700E+00, 0.13663900E+01, -.28271700E+00, 0.59893300E+00, 0.10772900E+01, 0.10829100E+00, 0.20802200E+00, 0.20513900E-02, -.20617800E+00, 0.60604700E-01, 0.76611100E+00, 0.23203200E+00, -.62804000E-01, -.10016600E+00, -.30317500E-02, 0.36049200E+01, 0.29223300E+01, -.34915300E+00, -.20830300E-02, 0.65161500E+00, -.91098600E-01, -.28286700E+00, -.50127200E+00, -.40388600E+00, 0.33502700E+00, 0.15926700E+00, -.24358800E+00, 0.98338700E-01, -.55800700E-02, 0.81541500E-01, 0.59369200E+00, -.43479200E+00, 0.24352000E+00, -.12223100E+00, -.57884300E+00, 0.22786300E+00, 0.12908200E+00, -.21948200E+00, -.50754000E+00, 0.57919800E+00, 0.23226200E-01, -.10717300E+00, -.14536200E+00, -.43447100E+03, -.29109000E+03, -.14735900E+03, 0.67024600E+02, 0.77388100E+03, -.24743200E+03, 0.11091200E+03, -.86423000E+02, 0.11939200E+03, -.23814900E+02, 0.29467800E+02, 0.41803900E+02, -.48659100E+02, 0.72972200E+02, 0.11878200E+02, 0.16538800E+03, 0.77879000E+02, -.34722100E+02, 0.74325800E+02, -.39590500E+02, -.38025500E+02, 0.38276600E+02, -.19506900E+02, 0.91113700E+01, 0.53799900E+02, -.50836100E+02, 0.63732500E+03, 0.12370400E+04, -.61525800E+03, -.35123100E+03, -.61879600E+03, -.24528600E+03, 0.19061000E+03, -.30862400E+03, -.14637700E+03, -.48040600E+03, 0.18273800E+03, 0.21196900E+03, 0.31088200E+03, -.15629400E+03, -.14952900E+02, -.15553900E+03, -.61650200E+02, 0.11681500E+03, 0.18980400E+03, 0.24849100E+03, 0.31421200E+02, -.45345500E+02, -.53120400E+03, 0.26519300E+03, -.13543400E+03, 0.10026300E+03, -.13376100E+03, 0.16468900E+03, 0.12853600E+03, -.11946100E+03, -.27471000E+02, -.25193400E+03, 0.83075100E+02, -.29233800E+03, -.23131800E+03, 0.11252100E+03, 0.31500100E+03, 0.11592500E+03, 0.73782800E+02, 0.82855500E+02, 0.76616400E+02, 0.15686000E+02, -.54966100E+02, 0.86998000E+02, -.22076100E+03, 0.33867900E+02, -.12542900E+02, -.21329900E+02, -.17020300E+02, -.48844600E+01, -.59775400E+02, -.14486200E+02, -.14674900E+03, 0.12000300E+02, 0.61867800E+02, 0.26550100E+03, 0.37550100E+02, -.22197800E+02, 0.10059500E+03, -.19538400E+02, -.12200500E+03, -.19703500E+03, -.91991600E+02, -.32179700E+02, 0.67701200E+02, -.24880800E+03, 0.70253800E+03, 0.73024100E+02, -.34850300E+02, -.19072700E+03, -.36590200E+02, -.74053500E+02, -.20635800E+03, -.12194400E+02, 0.10345700E+03, 0.15633400E+03, -.19603700E+03, -.55261400E+01, -.24505300E+03, 0.12245400E+03, 0.18300600E+03, 0.12209300E+03, 0.13075000E+03, 0.20243000E+03, -.49764700E+02, -.27609000E+03, -.16408000E+03, 0.23588900E+03, 0.25628500E+03, 0.64652400E+02, 0.55424600E+02, 0.19892000E+02, 0.44532900E+02, 0.70874500E+02, 0.98416700E+02, 0.10591800E+03, 0.39920700E+02, -.20395700E+02, 0.31663000E+02, 0.90979100E+02, -.52382100E+02, 0.41649400E+02, -.52290200E+02, 0.19319400E+03, 0.35641400E+02, 0.10226500E+03, -.61919000E+02, 0.25913600E+03, 0.19592900E+02, 0.70798300E+02, 0.96937000E+02, -.25677100E+02, 0.33222400E+02, -.84218700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19076100E+01, -.30898600E+01, -.46148800E+01, 0.26829900E+01, -.73225100E+01, -.13080700E+01, 0.49368300E+00, -.12895300E+01, 0.14916700E+01, -.32928900E-01, 0.45146900E-01, -.53014100E+01, 0.64983000E+01, 0.12556600E+01, 0.82553000E+00, -.27102500E+01, 0.18429300E+01, 0.17551900E+01, -.98629600E+00, 0.20376700E+01, -.13796100E+00, -.76981900E-01, 0.17220100E+00, 0.31738000E+00, -.15031200E+00, -.13025400E+00, 0.44396200E+00, -.30669000E+00, 0.94986300E+00, 0.21710800E+01, 0.16998600E+00, -.17176500E+00, 0.87999200E+00, 0.27761600E+00, -.17362200E+01, 0.30556600E+00, -.68193900E-01, -.13823500E+01, 0.12711600E+00, 0.94340300E+00, -.63600800E+00, -.33792600E+00, -.52307600E+00, -.52104600E+00, 0.49258300E-01, 0.70240000E+00, 0.29767200E+00, -.10167300E-01, 0.45908600E+00, -.30842400E+01, -.18230600E+01, 0.10560900E+01, -.37702300E+00, -.44921300E+00, -.43638000E+00, -.77503000E+00, 0.44307400E+00, 0.62830900E+01, -.44790700E-01, -.13872500E+01, 0.34732900E+00, -.20332700E+00, 0.26969600E+00, 0.14456900E+01, -.53979300E+00, -.34317200E-01, 0.16376600E+00, 0.79983700E+00, 0.55356900E+00, 0.25319700E+00, 0.30351100E+01, 0.31468300E+00, 0.16421300E+01, 0.59204800E+00, 0.11975100E+00, -.30948500E+00, -.11882000E+00, 0.89537900E+00, -.61140400E+00, 0.73643400E-01, -.20853700E+00, 0.23970900E+00, -.79417000E+00, -.15852900E+01, -.78468500E+00, -.16625700E+00, 0.11964800E+00, -.24641500E+00, 0.42267900E+00, -.10016400E+01, -.59083400E+00, -.22894100E+00, -.89281500E+00, -.51702700E+00, 0.10040600E+01, -.79550300E+00, -.27402900E+01, -.21193800E+01, -.14786300E+00, 0.11879700E+01, 0.10928800E+01, 0.28391100E+00, 0.19791600E-02, -.28564300E+00, -.11118600E+00, -.70946100E-01, -.39397300E+00, 0.95908000E+00, 0.72303400E+00, -.64157300E+00, -.20255400E+01, -.39855100E+00, -.91088600E-01, 0.95329800E-03, 0.11872400E+00, -.57441500E+00, -.24341900E+01, 0.15254700E+01, 0.17796100E+01, 0.19193400E+01, -.62136000E+00, 0.19991800E+01, 0.16492200E+01, 0.50102000E+00, -.85701000E-03, 0.41075200E+00, -.11751100E+00, 0.27999200E+00, 0.19399600E+01, 0.66037300E+00, -.13190300E+00, 0.59388900E+00, 0.23203400E+01, 0.47305300E+00, -.86730200E+00, 0.37527600E-01, 0.97823600E-01, 0.74073000E+00, -.10470000E+01, -.22456700E+00, 0.24142600E+00, -.18208300E+00, 0.55970100E-01, -.13658900E-01, 0.20076900E+00, 0.30272900E+00, 0.69630400E-02, 0.54604400E+00, 0.15897100E+01, 0.57003600E+00, -.12476100E+04, -.21756500E+03, -.51629600E+03, -.25670100E+04, 0.90944300E+03, -.49690900E+03, -.23433200E+02, -.45388900E+03, -.97144600E+02, -.30057400E+03, 0.39053100E+02, 0.25900800E+03, -.14110900E+03, -.25798700E+03, -.43977700E+03, -.16867300E+03, 0.67158200E+02, -.16772800E+03, 0.88655000E+02, 0.10541800E+03, 0.42046900E+02, 0.65886300E+01, 0.28126900E+03, 0.46981200E+03, -.13532900E+01, -.73088600E+03, -.79795500E+03, 0.38704000E+03, -.69128200E+03, 0.39900500E+03, -.12055100E+03, 0.73724300E+02, -.23590100E+03, -.31876200E+03, 0.92876500E+03, -.13104000E+03, -.79315800E+03, 0.22698200E+04, -.11322700E+04, -.13232400E+04, -.11349300E+04, -.24055600E+03, 0.70427900E+02, -.31186400E+03, 0.10546300E+04, -.64553400E+03, 0.28719000E+03, 0.13139200E+04, -.48248200E+03, 0.24960400E+03, -.10918400E+04, 0.24095400E+03, -.42046100E+03, -.72720200E+03, 0.84451500E+03, 0.70967400E+03, 0.68845600E+03, -.61237700E+03, 0.69989600E+03, -.44038700E+03, 0.23642300E+03, -.32018500E+03, 0.22023800E+03, -.22938800E+03, -.14634800E+03, 0.55994800E+02, -.35292600E+03, 0.19276700E+03, -.11356800E+03, 0.76395300E+03, -.72493000E+03, 0.35221500E+03, -.37948000E+02, 0.36242400E+03, -.19883400E+03, -.19725700E+03, 0.31369900E+03, 0.56250800E+03, 0.83910400E+03, -.54531200E+03, -.44484800E+03, 0.10054700E+04, -.48236600E+03, -.96190700E+03, -.50278100E+03, 0.16311700E+03, 0.23453000E+02, -.26741600E+03, -.57473000E+03, -.35863700E+03, -.39770100E+03, -.24355900E+04, 0.12304700E+04, -.62210400E+03, -.47262100E+01, -.61546700E+03, 0.45837500E+02, 0.22663700E+03, -.17670600E+03, 0.24382300E+03, -.23999700E+03, 0.20381000E+03, -.17721200E+03, -.11285300E+04, 0.54042400E+03, 0.14941600E+02, 0.56400700E+03, -.45436500E+03, -.59822100E+03, 0.72837300E+03, 0.61786200E+03, 0.11552800E+04, -.57151400E+03, 0.34027300E+03, 0.15139900E+03, -.13684200E+03, -.34367500E+02, -.12321200E+03, 0.22692200E+03, -.29294300E+02, -.44521000E+02, -.12937400E+03, 0.31269900E+02, 0.11792400E+03, 0.71521900E+02, 0.13796200E+03, 0.42330800E+02, 0.13883100E+03, 0.43872500E+03, -.10868600E+03, 0.37265300E+02, 0.53860600E+02, 0.50992100E+03, 0.17603400E+03, 0.10421000E+03, -.15362000E+03, -.18600900E+03, -.12414600E+03, -.46802000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.80908100E+00, -.36237000E+00, 0.91055800E-01, -.38240000E-01, -.12483500E+01, -.22915400E+00, 0.37950000E+00, 0.57450100E+00, 0.53052000E+00, 0.12979900E+00, 0.60539600E-02, -.10503100E+01, 0.20873200E+01, 0.92285300E+00, 0.51589900E+00, 0.24642700E+00, 0.61544500E+00, -.68502400E-02, 0.57201700E+00, -.62815000E-01, -.55796000E+00, 0.44789100E-01, -.69038400E+00, 0.56468700E+00, -.16919700E+00, 0.15090700E+00, 0.14668000E+01, -.28085300E+00, 0.46744800E+00, -.51620200E+00, 0.12727000E+00, -.23450000E+00, 0.55730300E+00, 0.13161300E+01, -.11513000E+00, 0.29433800E+00, 0.41940200E-01, -.33376800E+00, 0.59208700E+00, 0.11886800E+01, 0.25409100E-02, -.51894200E-01, -.15561000E+01, -.64371000E-01, -.60868100E+00, 0.18638300E+00, -.61981000E+00, 0.16069400E-01, -.76179800E+00, -.64903500E+00, -.50888200E+00, 0.85699100E+00, -.19608000E+00, -.67846300E+00, -.38525600E+00, -.57846400E+00, -.25767100E-01, -.74301800E+00, 0.43282600E-01, -.55414800E-02, -.98874800E-01, 0.76380800E-01, -.10012600E+00, -.11217100E+01, 0.11639800E+01, -.18285400E+00, 0.68283700E-01, -.34160200E+00, -.24833000E+00, 0.77074600E-01, -.41930900E+00, 0.51885200E+00, -.78852500E-01, 0.14726300E+00, 0.74340000E-01, -.18915600E+00, 0.54201900E-02, 0.79682200E-01, -.28473900E-01, -.66993800E-02, -.64337200E-01, 0.20886400E+00, 0.15119800E+00, 0.16840400E+00, 0.54347600E+00, 0.45030000E+00, -.27531200E-01, -.28188000E+00, 0.39482800E-01, -.29487200E+00, -.25961400E+00, -.45519300E-01, -.16125200E+00, 0.52951600E-01, 0.23694700E-01, -.16696600E+00, 0.41916700E+00, -.94283100E-01, -.78145900E-01, -.44283400E+00, -.99660700E-01, -.39311000E+00, -.13109200E-01, 0.46001800E+00, 0.22330000E+00, -.19726800E+00, 0.78479700E-01, -.16046700E+01, -.26721800E+00, -.80224300E-01, -.76048000E+00, -.26154500E+00, -.15867900E+00, -.45442600E-02, -.86802200E-02, -.48417800E-01, -.14056900E+01, -.17412800E+00, -.71137300E+00, -.11486400E+00, 0.23203100E+00, 0.25771000E+00, -.23717800E+00, -.13119000E+00, -.47529600E-02, 0.37455100E-01, -.40439100E+00, 0.11379100E+00, 0.67817300E+00, 0.45488700E+00, 0.45248800E+00, -.21897800E+00, -.37477600E+00, -.28074300E-01, -.54961800E+00, -.73304000E-01, 0.18526900E+00, 0.39712000E+00, 0.25916800E+00, 0.23042300E+00, 0.20032500E+00, 0.27440400E+00, -.20054800E+00, -.25005500E+00, -.17268000E+00, 0.28036100E-01, -.10742200E-01, -.12624100E+00, -.59992600E-01, 0.32186200E+00, 0.36925200E+00, 0.50895400E+03, 0.10126000E+03, 0.19645100E+03, -.10059500E+03, 0.69375200E+02, 0.77401900E+02, 0.53707500E+02, 0.50505500E+02, 0.77914600E+02, -.50158200E+02, -.50014900E+02, -.15514400E+02, 0.73465900E+02, 0.16724100E+02, 0.87431400E+02, -.43164700E+02, 0.37371500E+02, -.43296600E+02, 0.68282100E+02, -.20622300E+01, 0.50594300E+02, 0.72913300E+02, -.20612800E+03, 0.44180900E+02, -.53922300E+03, -.55429200E+03, 0.27676200E+03, 0.43503900E+03, 0.27740300E+03, 0.34226200E+03, -.12705500E+03, 0.52972300E+03, 0.50961600E+03, 0.91773400E+02, -.11663000E+03, -.28100600E+03, -.15623900E+03, 0.78870000E+02, 0.17964700E+03, 0.78237100E+02, 0.10073200E+03, 0.70654500E+02, -.23476400E+02, -.13598100E+02, -.29804800E+03, 0.41030200E+02, -.24651000E+03, 0.34916500E+03, -.17369500E+03, 0.21041800E+03, -.17310800E+03, -.17241100E+03, -.28248500E+02, -.80205100E+02, 0.20480500E+03, 0.69808700E+02, -.58682900E+02, -.12644200E+03, 0.62057300E+03, -.31206700E+03, -.13026500E+03, -.31060000E+03, -.48661100E+02, 0.38134600E+02, -.14347900E+03, 0.18191800E+02, -.14712400E+03, -.13057400E+02, -.13661300E+03, -.16176900E+02, 0.55340400E+01, 0.17205900E+03, 0.82145400E+01, 0.18356100E+03, 0.14054800E+03, 0.10159700E+03, 0.24244100E+03, -.87909000E+02, 0.20169800E+03, -.54120300E+02, -.90695300E+02, 0.42841100E+02, 0.12967200E+03, 0.46161200E+02, 0.28558200E+02, 0.28449100E+03, -.48753200E+02, 0.11462000E+03, 0.92677600E+02, 0.41775900E+03, 0.34589200E+01, -.74681700E+03, 0.37359300E+03, 0.93966000E+02, 0.37362800E+03, 0.44802100E+02, 0.48965000E+02, 0.27844100E+02, -.25681900E+03, 0.60335700E+02, 0.85063700E+02, 0.29981600E+03, 0.43900600E+03, -.21343600E+03, -.70627600E+02, -.21883900E+03, 0.86945800E+02, 0.11184900E+03, -.15646100E+03, 0.23585000E+03, -.18365900E+03, 0.61208700E+02, -.20203500E+03, -.87809000E+02, 0.18890100E+02, 0.22965000E+02, 0.16770900E+02, -.11563000E+03, -.15188800E+02, -.78346400E+01, 0.23747200E+02, -.22039600E+02, -.51996200E+02, -.40079300E+02, -.18141900E+02, -.57298400E+02, -.19368600E+02, -.34658300E+02, 0.19292600E+02, -.32887100E+02, -.11877600E+01, -.24486000E+02, -.10319700E+03, -.27253700E+02, -.33222000E+02, 0.10617200E+03, 0.48686000E+02, 0.11722200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11989500E+01, 0.16020000E+01, 0.20231000E+01, -.20531100E+01, 0.32288200E+01, 0.68955500E+00, 0.44082000E+00, 0.11209200E+01, -.11919800E+01, -.21128600E+00, -.55480400E-03, 0.55674800E+00, -.74284800E+00, -.47003400E+00, -.36043400E+00, -.21850200E+00, 0.15221000E+00, 0.47710100E-01, -.22830900E+00, 0.16493100E+00, 0.10393800E+01, 0.12961900E+00, -.41523400E+00, -.38612800E+00, -.26269200E-01, -.87394500E-01, 0.13970700E+01, 0.29096900E+00, 0.77094100E-01, -.95046500E+00, 0.30834500E+00, 0.36215800E+00, -.58141700E+00, 0.88853300E+00, 0.11082700E+01, -.29387200E+00, 0.36445500E-01, 0.14260100E+01, -.13390500E+00, 0.14338600E+00, 0.12500400E+01, 0.61217400E+00, -.85367900E+00, 0.13190600E+00, 0.61835200E-01, -.38987700E+00, -.61266600E-01, 0.80857800E-02, -.12275400E+00, 0.16086900E+01, 0.11654900E+01, -.37031400E+00, 0.12534800E+00, -.10528200E+00, 0.12493900E+00, 0.41812800E+00, -.11143500E+01, -.12629300E+01, -.23978300E-01, 0.48001500E+00, -.31325800E+00, -.34087900E+00, -.44123000E+00, 0.74607300E+00, -.74149700E+00, 0.16382100E+00, -.17108900E+00, 0.15849300E+01, 0.14213200E+00, 0.10933500E+00, -.18376100E+01, 0.50216000E+00, -.82842000E+00, -.43296200E+00, -.32910900E+00, 0.63485200E-01, 0.85892300E-02, 0.80608200E-01, -.84760000E-01, -.24936200E+00, -.81256700E-01, 0.35596400E+00, -.98573300E+00, 0.13296200E+00, 0.45744400E-01, 0.92328300E+00, -.32736100E+00, 0.63867200E-01, 0.12540600E+00, 0.26015200E-01, 0.54245600E-01, 0.15044400E+00, 0.58064800E+00, -.49797200E-01, 0.10562000E+00, -.83057000E-01, 0.13719500E+01, 0.63785800E+00, 0.93047800E-01, -.45308100E+00, -.27499200E+00, 0.30773900E+00, -.47824600E-02, 0.30952200E+00, 0.26210000E+00, 0.30930900E+00, 0.29762400E+00, -.58436700E+00, -.28299700E+00, 0.37669100E+00, 0.27437100E+00, -.13688700E+00, 0.60906600E-01, 0.15713900E-02, -.18090100E+00, -.14263800E+00, 0.19517200E+00, 0.13375900E+00, -.10701500E+01, -.18079600E+00, 0.47563600E+00, 0.13219600E+01, -.70905300E+00, 0.10792600E+01, 0.26943800E-01, -.67510700E+00, -.39324000E+00, 0.31585800E+00, 0.37384100E-01, 0.10603900E+00, 0.37832500E+00, 0.97956800E-01, -.19599900E+00, -.79937300E+00, -.10631500E+01, 0.46060400E-01, 0.48665300E+00, 0.86569000E+00, 0.50545000E-01, 0.35360400E+00, -.76762900E+00, 0.31316600E+00, -.22652200E+00, 0.22340300E+00, 0.52318200E+00, -.39405500E+00, 0.28815800E-01, -.24283500E+00, 0.36636400E+00, 0.21553800E+00, -.36130200E-02, 0.22334700E+00, -.52507200E+03, -.10809000E+04, -.21604400E+02, -.10556700E+01, 0.68195700E+02, 0.10503700E+02, -.44125400E+02, -.91895800E+02, 0.10216000E+03, 0.31873700E+02, 0.38282500E+01, -.80693900E+02, -.67844200E+02, -.18986500E+03, 0.98104500E+02, -.20144700E+03, 0.94030900E+02, -.24048900E+02, -.17472400E+03, 0.10705100E+03, 0.88360500E+02, 0.40530800E+03, -.14963100E+03, -.62430200E+02, -.23270300E+02, 0.14954200E+02, -.22056100E+03, 0.11487200E+02, -.31380300E+03, 0.70707200E+02, -.21940200E+03, -.18953200E+03, 0.10452600E+03, 0.74697300E+02, -.40710500E+03, 0.26727500E+02, -.14367200E+02, -.21938400E+02, -.13455800E+02, 0.10979900E+02, 0.10686600E+03, -.12131100E+03, -.55278100E+02, -.15363300E+02, 0.44993100E+03, 0.11446300E+04, -.58358300E+03, 0.28862900E+03, -.11032000E+03, 0.29056000E+03, 0.93720700E+02, 0.23559300E+02, 0.87108700E+02, -.35281000E+03, 0.15223600E+03, 0.89705900E+02, 0.43921000E+03, -.43975700E+03, 0.21826500E+03, -.22545500E+03, 0.22012200E+03, -.13741000E+03, -.10556800E+03, 0.14577000E+03, -.21350000E+00, 0.49606900E+02, -.36399900E+02, 0.39687300E+03, -.16290300E+03, 0.83197400E+02, -.28979200E+03, 0.81334400E+02, -.27204700E+03, -.18531600E+03, -.43609200E+02, -.27619000E+03, 0.16313700E+03, -.28289200E+03, -.20358400E+03, 0.13401700E+03, -.68987900E+02, -.19203700E+03, -.67569500E+02, 0.11445000E+03, 0.54836100E+02, -.62455000E+02, -.10445700E+02, 0.56125000E+02, -.25035200E+03, -.31547000E+03, 0.57994400E+03, -.28932200E+03, 0.28154300E+02, -.29022300E+03, 0.10524700E+03, 0.12549200E+03, -.29943500E+02, 0.14474400E+03, -.17473300E+03, 0.73241300E+02, -.21204000E+03, -.62016500E+03, 0.30844200E+03, 0.94531100E+02, 0.30945100E+03, -.24589700E+03, -.31756000E+03, 0.25739700E+03, -.23021300E+03, 0.37062400E+03, -.26902400E+03, -.12123900E+03, 0.64739500E+02, -.68629400E+02, -.83105300E+02, -.83331900E+02, 0.63527500E+02, -.81160300E+02, -.89746100E+02, -.92707900E+02, 0.82324600E+02, 0.46032100E+02, -.36207900E+02, 0.93091800E+02, 0.76071000E+02, 0.96371400E+02, -.82654500E+02, -.85530800E+02, -.45874500E+02, 0.49951800E+02, -.54327500E+02, 0.11533400E+03, -.46321700E+02, -.40322200E+02, -.11754300E+02, -.87051600E+02, -.89749400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22795100E+01, 0.11433400E+01, 0.10221200E+01, 0.10254100E+01, 0.10088900E+01, 0.28414300E+00, -.61465000E+00, 0.21173600E+01, 0.25395300E+01, 0.12042500E+00, -.11633300E+01, -.39922600E+01, -.27522500E+01, -.94165900E+00, -.66221100E+01, 0.44474200E+01, 0.20108400E+01, -.97784300E+00, -.23833400E+00, -.57889400E+00, -.44414900E+00, 0.43867100E+00, 0.14347200E+01, 0.22577100E+01, 0.19538000E+00, 0.10054200E-01, -.12726200E+01, 0.53813300E+00, -.82817000E+00, 0.49692200E+00, 0.24773600E+00, -.62895900E+00, 0.48401700E+00, -.23997800E+01, -.10853800E+01, 0.25820600E+00, 0.32218400E-01, -.11776700E+01, 0.11663100E+00, 0.27710100E+00, -.12826200E+01, -.38574100E+00, 0.10721200E+01, 0.46614500E-01, 0.38769200E+00, -.32914800E-01, -.55589500E+00, 0.10265400E-01, 0.11005400E+00, -.47384700E+00, 0.46223600E+00, 0.29862400E+01, -.37527500E-01, 0.96641300E-01, -.79543000E+00, 0.15840100E+00, 0.13772500E+01, -.26865600E+01, 0.10496100E+00, -.83170100E+00, 0.14016500E+00, 0.74888900E+00, 0.21690100E+00, -.17179200E+01, 0.13839200E+01, -.31324800E+00, 0.30896500E+00, -.16552200E+01, 0.23024600E+00, -.90773500E-01, 0.24481100E+01, -.10083100E+01, 0.33990800E+00, -.50816000E+00, -.36935600E+00, 0.84259400E+00, 0.17082400E+00, 0.15772300E+00, 0.13300600E+00, 0.16805400E+00, -.48445700E-02, -.13048300E+01, 0.46055900E+00, -.20960200E+01, -.27733700E+00, -.48102400E+00, -.47701300E+00, -.11697500E+01, 0.41301400E+00, 0.24025900E+00, -.49591100E+00, 0.92791000E-01, -.83691900E+00, 0.92889800E+00, -.52066800E+00, 0.10027200E-01, -.17283400E+01, 0.25175900E-02, -.28223900E+00, 0.11700900E+00, 0.36340100E-01, 0.97186200E-02, 0.99960900E-02, -.26509800E+01, -.18557600E+00, -.49928700E+00, -.12189400E-01, -.14647500E+01, 0.17891200E+00, -.55846800E+00, 0.18732200E+01, -.21056100E+00, -.56850000E+00, 0.26849600E-02, 0.21810500E+00, 0.24818900E+00, 0.15900500E+01, 0.56337700E-01, 0.18244800E+01, -.98361400E-01, 0.46183500E+00, -.21592000E+01, -.23225400E+01, 0.10691500E+01, 0.18143500E-01, -.67593800E+00, -.51022200E+00, 0.23079700E+00, 0.13600700E+01, 0.30163800E+00, 0.64660600E+00, 0.24051500E+00, 0.13833800E+01, -.22704000E+00, 0.18197800E+00, -.19517000E-01, -.16941100E+01, 0.26097200E+00, -.57988700E+00, -.22076500E-01, -.23203700E+00, -.71894700E+00, -.47432400E+00, -.27373700E+00, -.22961600E+00, -.19435700E+00, -.53351600E-02, -.15303900E+00, -.61154200E+00, -.27732000E+00, -.98561000E-01, 0.28907800E+00, -.59186100E+00, -.23939200E+04, 0.14635500E+03, -.66772000E+02, 0.16493700E+03, -.75079700E+02, 0.10679200E+03, 0.16378900E+03, -.23061600E+03, -.94871800E+02, -.17960500E+03, 0.17394700E+03, 0.36868100E+02, 0.61434100E+01, -.39700200E+01, -.62867200E+02, -.23398000E+01, 0.55056400E+02, -.39189700E+02, 0.27080000E+02, -.46288600E+02, 0.64163200E+02, -.42131700E+02, -.65316900E+03, -.54397400E+03, 0.27051600E+03, 0.36001800E+03, 0.27180100E+03, -.23350100E+03, -.24589200E+02, 0.66030600E+02, -.19029900E+03, 0.22308400E+03, 0.45159000E+02, 0.76035500E+03, 0.47221400E+03, -.23482800E+03, -.19331400E+03, -.23619400E+03, 0.53053500E+02, -.14903600E+00, -.20406500E+03, -.36473200E+02, -.22157300E+03, -.30311800E+01, 0.13539200E+04, -.34522100E+03, 0.17450000E+03, 0.20603100E+03, 0.17151900E+03, 0.34040800E+02, 0.25538200E+02, -.15506000E+03, -.15565800E+03, 0.14092700E+03, 0.48134200E+02, 0.78094300E+02, 0.41388300E+03, -.20487300E+03, -.31497300E+03, -.20671000E+03, -.89312800E+02, -.93155700E+02, -.12377800E+03, 0.33510800E+02, -.95739900E+02, -.31705700E+02, 0.53440500E+02, -.69379000E+02, 0.32860500E+02, -.35229600E+01, 0.34595700E+02, -.33587000E+02, 0.43718300E+02, 0.14794800E+03, 0.35912200E+03, 0.21100900E+03, -.41162100E+02, 0.34841700E+03, 0.12682500E+04, -.63496300E+03, -.60359000E+03, -.63472000E+03, 0.35870900E+02, 0.14829600E+03, -.42748500E+03, -.99874900E+02, -.48490300E+03, 0.10337700E+03, -.22090200E+04, 0.38518700E+03, -.19297700E+03, -.15610200E+03, -.19276900E+03, 0.37479700E+02, 0.82281600E+02, -.11576000E+03, -.57225600E+02, -.22495100E+03, 0.36898800E+02, -.15432100E+03, -.26406200E+03, 0.13620300E+03, 0.52231900E+02, 0.13153400E+03, -.18017600E+03, -.12955900E+03, 0.14810100E+03, 0.37697500E+03, 0.44514900E+03, -.14366100E+03, 0.75833400E+03, -.31768600E+01, -.35977700E+02, -.32860100E+02, -.56005000E+02, 0.78264500E+02, -.55968000E+02, -.57943200E+02, -.37328800E+02, 0.32289800E+02, 0.61797400E+01, -.72952200E+02, 0.74034700E+02, 0.61639300E+01, 0.72100400E+02, 0.93664400E+02, -.44208200E+02, -.86899400E+02, -.25550000E+02, 0.94467300E+01, 0.51832200E+01, -.70366600E+02, -.70058900E+02, -.97314300E+02, -.53877400E+02, 0.63581600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.67799700E+00, -.51010800E+00, -.89592700E+00, -.12502900E+01, -.34082100E+00, 0.25749500E-01, 0.31262800E+00, 0.59355700E+00, -.27179300E+00, -.29411200E+00, -.81855100E-01, -.54781800E+00, -.15648300E+00, -.46948200E+00, 0.15464800E+01, 0.40120000E+00, -.17037100E+00, -.16732800E+00, -.14418300E+00, 0.22645100E+00, -.31722800E+00, 0.20939900E-01, 0.34984400E-01, 0.91066300E+00, 0.14758600E-01, 0.17990000E+00, 0.47285300E+00, -.24411300E+00, 0.16815100E+00, 0.17768400E+00, -.22202100E+00, 0.84991300E-01, 0.67873000E+00, 0.55774200E+00, 0.15655600E+00, -.38401300E+00, 0.21106700E-01, 0.29552300E+00, -.18723900E-01, 0.98050400E+00, -.97087200E-01, -.86231700E-01, -.61284200E+00, -.85224900E-03, -.13074500E-01, 0.14228000E+00, 0.14881500E-01, 0.65708100E-02, 0.49746600E-01, -.23372000E+00, -.23695300E+00, 0.29191000E-01, -.72491400E-01, -.46049200E-01, 0.70669400E-01, -.90380700E-01, 0.15595100E+00, 0.20886200E+00, 0.36919700E-01, 0.14231100E+00, 0.82436900E-01, 0.14948100E+00, 0.63042000E-01, -.84154200E+00, 0.49792000E+00, 0.48674000E-02, -.31642200E-01, -.40491800E+00, 0.15526700E+00, -.14356400E+00, -.51673500E+00, -.46784600E+00, -.20461600E+00, 0.22387400E+00, -.27153200E-01, -.25900200E+00, -.11934400E+00, -.49717400E+00, -.49997500E-01, -.21868700E+00, 0.16820200E+00, -.11865400E+00, -.15750800E-01, 0.40383800E+00, -.18288400E+00, -.48587600E+00, 0.10478500E+00, 0.31021300E+00, 0.86554900E-01, -.16230600E-01, 0.10717400E+01, 0.10642000E+00, 0.12436900E+00, -.11843300E+00, -.62727400E+00, -.57119800E-01, -.27004800E+00, 0.49354700E+00, 0.12557700E+00, 0.84364100E+00, 0.16381400E-01, 0.12012500E+00, 0.14128500E-01, 0.21230700E+00, -.24562100E+00, -.27925200E+00, -.13240000E+00, 0.10873700E+01, -.25350300E+00, 0.36229100E-01, -.10052900E+01, -.11103900E+00, 0.10681400E-01, 0.12736400E-02, 0.63244600E-01, -.82190000E-01, -.61140000E-01, 0.51855800E+00, 0.11075100E+00, 0.32374400E+00, -.22080800E+00, -.13349500E+00, 0.13705300E+00, -.29269900E+00, -.82360400E-04, 0.31251100E+00, -.89576900E-01, 0.11387100E+00, -.14617300E+00, 0.23317000E+00, 0.45601700E+00, 0.49531800E-01, -.16243800E+00, 0.26564600E+00, 0.34221200E+00, 0.12877100E-01, 0.61994200E-01, -.24810400E+00, -.10543800E+00, 0.40121800E-02, 0.50487200E+00, -.59209800E-01, 0.12723200E+00, 0.88192000E-01, -.11179400E+00, 0.15912400E+00, -.13288800E-02, 0.96982400E-01, 0.10496000E+00, 0.27100600E-01, -.74966100E-01, -.39839300E+00, -.24157000E+00, -.83405600E-01, -.27441300E+03, 0.13613100E+03, 0.97680100E+02, 0.13719900E+03, 0.39035800E+02, 0.79304000E+02, -.23717500E+02, -.10385800E+03, 0.95953300E+01, 0.73312600E+02, 0.77630300E+02, 0.85873400E+02, -.43970000E+02, -.66147400E+02, -.42877000E+02, -.40793600E+02, -.49492500E+02, 0.28057300E+02, 0.55390800E+02, 0.35559000E+02, -.50075400E+02, -.90286700E+02, -.20802600E+02, 0.95031400E+01, 0.36680800E+02, 0.10425700E+02, -.21552500E+03, 0.34432400E+02, -.10933800E+02, -.81694000E+02, -.11231900E+03, 0.18624900E+02, 0.13496500E+03, 0.82761900E+02, -.41273800E+02, 0.71561000E+02, -.41365900E+02, -.22276400E+01, 0.71179100E+02, -.68454200E+02, -.14735600E+02, -.37405100E+02, 0.41819900E+02, 0.79442800E+02, 0.98579900E+01, -.41631500E+01, 0.23611600E+02, -.47293000E+01, 0.67259700E+02, 0.21139900E+02, -.14414900E+02, 0.14704500E+02, 0.28747100E+02, 0.15412500E+02, 0.16655500E+02, -.13824000E+03, 0.70371400E+02, -.27880400E+02, 0.69080500E+02, -.22571500E+02, -.15134100E+02, 0.27754200E+02, -.36837100E+02, -.19292400E+02, -.25586100E+01, 0.14282700E+03, 0.99402800E+02, -.52421900E+02, -.13246500E+03, -.49682600E+02, -.88656300E+02, 0.23786800E+02, -.52064000E+02, -.90920200E+02, -.10721700E+03, 0.22468000E+02, -.28202000E+02, -.31384500E+03, 0.15789300E+03, 0.10074100E+03, 0.15701500E+03, 0.85105200E+02, 0.13298400E+03, 0.11168900E+02, -.35996200E+02, 0.59391300E+02, 0.11380800E+03, 0.31172600E+03, -.88279100E+02, 0.43582100E+02, 0.47636500E+02, 0.44180900E+02, 0.14196400E+03, 0.93043700E+02, -.35391000E+02, -.96461100E+02, -.58442600E+02, 0.86749600E+02, -.40072300E+02, -.91374900E+02, 0.44762800E+02, -.45449100E+02, 0.45789200E+02, -.82138800E+02, -.68964100E+02, 0.39168400E+02, -.39940600E+02, -.47594700E+02, -.72015700E+02, -.18845700E+02, 0.10877300E+02, -.93465000E+01, -.24656400E+02, -.14037900E+02, 0.13204600E+02, -.33062000E+02, -.33985900E+02, -.11573100E+02, 0.25102200E+02, 0.55033800E+01, -.26281600E+02, 0.19483200E+02, 0.25585400E+02, 0.20317300E+02, -.28599100E+02, -.15930800E+02, -.28840800E+02, 0.11915600E+01, -.39646200E+02, 0.19150900E+02, -.35863800E+02, -.11258800E+02, 0.76395400E+01, -.36530900E+01, -.42259200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.37033200E+01, -.31215600E+00, 0.12814600E+01, -.35448800E+01, 0.48788200E+00, 0.21144300E+00, 0.29065900E+01, 0.38568600E+01, -.19956400E+01, -.58735500E+00, -.40973300E+00, -.42169500E+00, 0.38672900E+01, -.11555300E-01, 0.42019400E+01, -.77681400E+01, 0.19395000E+01, 0.15578400E+01, -.51775600E-01, 0.28020100E+01, 0.66656700E+01, 0.23050700E+00, -.18224700E+01, 0.43054100E+01, -.72058500E+00, 0.13334800E+00, 0.10241900E+01, -.26665000E-01, 0.15411300E+01, -.60609000E+00, -.52146200E+00, -.88778400E+00, 0.13355600E+01, 0.16968800E+00, -.82341400E+00, -.74067100E+00, -.15121300E-01, -.22056800E+00, -.30342600E+00, 0.23267800E+01, -.64857100E+00, 0.24038700E+00, -.12270800E+01, 0.10341100E+00, -.60129700E+00, -.52719200E+00, -.72131600E+00, 0.14459600E-02, -.58359800E+00, -.16277200E+01, 0.57576000E+00, 0.23712300E+01, -.36480600E+00, -.13160600E+01, 0.17575200E+00, 0.20822800E+00, 0.36368000E+00, 0.48810400E+01, 0.29187700E-01, -.11002300E+01, 0.90460600E-01, 0.13332800E+00, -.59669700E+00, -.57832100E+00, 0.20450100E+01, -.24070500E-01, -.28153600E+00, -.42449900E+01, 0.19903300E+00, 0.41773200E+00, 0.50830900E+01, -.18493400E+00, 0.20209900E+01, 0.18758100E+01, 0.18994500E+01, -.16475100E+01, 0.39368100E+00, 0.17671200E+01, 0.90941300E+00, 0.12643400E+01, -.35251300E+00, 0.97061800E+00, 0.62981300E+00, -.15335200E+01, -.95116800E+00, 0.15656900E+01, 0.76569500E+00, -.81262100E+00, -.11718800E+01, -.11125400E+00, -.30870400E+01, -.40622200E+00, -.31105400E+00, 0.78059400E+00, 0.13413800E+01, 0.49262700E+00, -.14660600E+01, -.23972100E+01, -.28089300E+00, -.11317700E+01, 0.45154200E-01, -.13488100E+01, -.10009300E+00, -.53988700E+01, -.16058900E+01, -.12482400E+01, 0.98902200E+00, -.63077300E+01, -.32840200E+01, -.16486200E+00, 0.96926600E+01, -.29872000E+00, -.19544000E+01, 0.71196200E-01, -.39872700E+00, 0.61343900E+00, 0.55955000E+00, -.31254100E+00, 0.94868900E+00, -.49404900E+00, 0.10566600E+01, -.10648500E+01, -.21260500E+01, 0.77340000E+00, -.32261500E-01, -.97792500E+00, -.10509900E+01, 0.57124000E+00, 0.62787400E+00, 0.14074100E+00, -.15133500E+01, -.47247100E-01, 0.28824900E+00, -.77510600E+00, -.23326300E+01, -.11385400E+00, 0.13782700E+01, 0.19842400E+01, 0.40387600E+00, 0.19651300E+00, -.15769600E+01, 0.99897000E+00, -.52792300E-01, -.98770100E+00, -.52760000E+00, 0.57430800E+00, -.20168600E-01, 0.90004900E-01, 0.13892000E+01, 0.26651200E+01, 0.14625400E+01, 0.19023200E+01, 0.96732500E+00, 0.66250100E+00, -.14433700E+01, 0.13423800E+03, -.31360400E+03, 0.13268900E+02, -.49438300E+02, -.26617100E+02, 0.54395300E+02, 0.13240100E+03, 0.23496100E+03, -.56649900E+02, -.10840400E+02, -.14357800E+02, 0.21395600E+02, 0.91805600E+02, 0.23863500E+00, -.24060100E+03, -.99440000E+02, 0.47775000E+02, -.67751000E+02, -.13641400E+03, 0.57441500E+01, 0.97053800E+03, 0.25971400E+03, -.12176000E+03, -.16468600E+03, -.12885900E+03, 0.58010100E+03, -.15356600E+03, -.12555200E+02, 0.44640800E+03, -.13220900E+03, -.21361900E+03, -.17145400E+03, -.14391400E+04, 0.71729000E+03, 0.45386300E+03, 0.71993600E+03, 0.90126700E+02, 0.56461400E+02, 0.31455000E+03, -.61481900E+02, 0.52767800E+03, 0.17337500E+03, 0.48073400E+03, -.75428400E+03, 0.37211400E+03, -.57811500E+02, 0.38138400E+03, 0.62726700E+02, 0.18491700E+03, 0.99148600E+02, -.58661800E+03, 0.10173700E+03, 0.17387600E+03, 0.39386000E+03, 0.11876800E+04, -.61232400E+03, -.46058100E+03, -.59481400E+03, 0.37519700E+03, 0.49163700E+02, -.23376600E+03, 0.20387000E+03, -.33390100E+03, 0.54580900E+01, -.11557200E+04, 0.27681400E+03, -.13330400E+03, 0.30534400E+03, -.13809100E+03, 0.31804700E+02, -.17074100E+03, -.26034800E+03, -.52877000E+03, -.42966500E+03, -.10569500E+03, -.39202000E+03, -.26901900E+04, 0.13223400E+04, 0.13227800E+04, 0.13479000E+04, -.12478900E+03, -.51210900E+03, 0.87869500E+03, -.12707900E+03, 0.92995500E+03, -.21723800E+03, 0.92479700E+03, -.87241000E+03, 0.44287100E+03, 0.30143700E+03, 0.43660000E+03, 0.36912800E+02, 0.46317000E+02, 0.20568300E+03, -.68163400E+02, 0.17706200E+03, 0.10924400E+03, 0.77577300E+02, 0.95733400E+03, -.43442800E+03, -.12335000E+03, -.47705600E+03, 0.24009000E+03, 0.11908000E+03, -.33857000E+03, -.54765000E+03, -.78052800E+03, 0.38888100E+02, -.10519100E+04, -.13488600E+03, 0.23097600E+02, 0.30345900E+02, 0.69556400E+02, -.23860000E+03, 0.90751500E+02, 0.89020300E+02, 0.54276100E+02, -.30806800E+02, -.93700000E+02, 0.72123700E+02, -.81884800E+02, -.10413600E+03, -.84135200E+02, -.17762300E+03, 0.57719400E+02, 0.10538400E+03, 0.86392200E+02, -.15413700E+03, -.55401400E+02, 0.81830000E+02, 0.41871200E+02, 0.91699000E+02, 0.68135600E+02, 0.25337000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.74724600E+00, 0.36051900E+00, 0.13823600E+01, -.59381500E+00, -.97846200E-01, -.16342600E-01, 0.12299100E+01, 0.21423200E+01, 0.25678400E+00, -.23097800E+00, -.28117000E-01, -.48250600E+01, -.81441000E+00, 0.75902800E+00, -.18392100E+01, 0.35109800E+01, 0.23399300E+01, -.90322400E-01, -.30409000E+00, 0.94881800E+00, 0.89179600E+00, -.80249100E-01, 0.30108800E+00, 0.71714200E+00, -.16477500E+00, -.91868900E-01, 0.26295600E+01, -.21612000E+00, 0.32017800E+00, 0.14038300E+01, 0.69909900E-01, -.30864500E+00, 0.63867300E+00, 0.69877200E+00, -.31094700E+00, -.89614300E-01, -.69780300E-01, 0.46202200E+00, 0.51789400E-01, 0.39796100E+00, -.99034200E+00, -.78309900E+00, 0.11377800E-01, -.96331600E-01, -.21547100E+00, 0.52296600E-02, -.50592100E-01, -.91698000E-02, 0.14245900E+00, -.13202100E+01, -.80824400E+00, -.13485700E+01, -.72858900E-01, -.76294600E+00, -.42321200E+00, -.41508600E+00, -.19277400E+00, 0.31025000E+01, -.35059600E-01, -.45969500E+00, 0.95118000E-01, -.23840200E-01, 0.33225800E-01, 0.10743200E+01, -.13706700E+01, -.23451000E-01, 0.27088800E-01, 0.77619700E+00, 0.73582400E+00, 0.76581700E-01, 0.62208900E+00, -.64240900E-01, 0.40260400E+00, -.39872500E-01, -.58882700E-01, -.78457400E+00, 0.15674000E+00, -.11322200E+00, 0.23280500E+00, 0.11724500E+00, -.79626300E-01, 0.45661200E+00, -.33638100E+00, -.39235100E+00, 0.31122100E+00, 0.46253700E+00, -.12445200E+00, -.17409700E+00, 0.86485000E-01, -.41039800E+00, 0.32419200E-01, -.23113200E-01, 0.38569600E+00, 0.63854300E-01, 0.32225500E+00, -.35173800E+00, -.86356400E-01, -.34305200E+00, 0.36714600E-01, 0.21877400E+00, -.42414300E-01, 0.10249300E-01, -.15346200E-02, -.63221500E+00, -.33099000E+00, -.93894400E-01, -.10795800E+00, -.24372400E+00, 0.70493200E-01, -.10598400E+00, -.35268400E+00, 0.64233800E-01, 0.74503300E-01, -.80162400E-03, 0.51106000E-02, -.18541100E-01, -.11296200E+01, -.81995500E-01, -.32212400E+00, 0.92170300E-01, 0.18833800E+00, 0.27536200E+00, 0.12764300E+01, -.45649600E+00, -.12418700E-01, 0.70626600E+00, -.89362300E-01, -.14717900E+00, 0.33591600E+00, 0.13804700E+00, 0.24442500E+00, -.13323800E+00, -.33442600E+00, 0.19705000E+00, 0.15139600E+00, -.42553200E-01, 0.19648800E-01, -.15162400E-01, 0.17768400E+00, 0.29179100E-01, -.15455500E+00, 0.16516300E+00, -.60213800E-02, -.13423100E+00, -.10510300E+00, 0.37875400E+00, -.12642100E-01, -.83826800E-01, -.43709300E+00, -.30376200E+00, -.10083400E+00, -.53033900E-01, -.26868400E+00, 0.15115700E+00, 0.75698500E+00, -.15278400E+00, -.14970300E+03, 0.15410000E+01, -.32296600E+02, -.50674500E+02, 0.92522400E+02, 0.80061700E+02, 0.91697700E+02, -.50690000E+02, -.48995500E+01, -.23616700E+02, 0.14589300E+02, 0.12905200E+02, 0.10218600E+02, -.32331100E+02, -.22135500E+01, -.60440600E+01, 0.92132700E-01, -.45487900E+02, 0.25431000E+02, 0.39266900E+03, 0.11102700E+03, -.53111400E+02, -.10255200E+03, -.55335600E+02, 0.14036400E+03, 0.11953900E+02, -.55866000E+02, 0.98475900E+01, 0.19881400E+01, 0.20923400E+02, -.20643200E+03, -.29597900E+03, 0.14732200E+03, 0.93283900E+02, 0.14806100E+03, 0.18728400E+02, -.35294600E+02, 0.11421100E+03, 0.40080300E+01, 0.12208900E+03, -.12235300E+02, 0.71864900E+02, -.71714800E+02, 0.33718900E+02, -.94274400E+02, 0.36708000E+02, -.17554300E+02, -.70407200E+01, 0.60055400E+02, -.84391300E+02, -.66989000E+01, -.99518300E+01, 0.14378700E+02, -.22629900E+03, 0.11009500E+03, 0.15697100E+03, 0.11296000E+03, 0.56834700E+02, 0.21801700E+02, 0.53704900E+02, -.25567400E+02, 0.10645100E+03, -.13445000E+02, -.16049700E+03, -.64584800E+02, 0.36397700E+02, 0.81680100E+02, 0.32359600E+02, 0.12421600E+02, -.34064800E+02, -.31109400E+02, -.13285400E+03, 0.14642100E+02, 0.28345600E+01, -.11703400E+03, -.47152700E+03, 0.23333700E+03, 0.24765600E+03, 0.23628700E+03, 0.20822200E+02, -.15100700E+03, 0.19858600E+03, 0.70469500E+01, 0.22976000E+03, -.11715000E+03, 0.61608900E+02, -.10815700E+02, 0.65908700E+01, 0.83515300E+01, 0.55084900E+01, -.41589000E+02, -.28713800E+02, 0.38285400E+02, 0.95427500E+02, 0.11111200E+03, -.26256600E+02, -.34272900E+02, 0.83263500E+02, -.40235200E+02, 0.14296100E+02, -.41283300E+02, 0.35008900E+02, 0.34943100E+02, -.30643600E+02, -.17913600E+03, -.76158800E+02, 0.64532500E+02, -.19865700E+03, -.25759100E+01, 0.33033900E+01, -.18433500E+01, 0.96227500E+01, -.40977100E+02, 0.14845800E+02, 0.15748300E+02, 0.54924800E+01, 0.15183800E+01, -.12533700E+01, 0.16962500E+02, -.16167100E+02, -.53198700E+01, -.15830600E+02, -.10510800E+02, 0.84482400E+01, 0.22489900E+02, 0.26727400E+01, -.66372000E+00, 0.10228300E+02, 0.13895700E+02, 0.33777500E+02, 0.12967500E+02, 0.60041200E+01, -.35764800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36032700E+01, 0.33528000E+00, -.10759700E+01, 0.51278100E+01, 0.11551700E+01, -.25333900E+00, -.45877100E+01, -.72123500E+01, 0.13198300E+01, 0.93697600E+00, 0.33671000E+00, 0.54811300E+01, -.38705200E+01, -.85281000E+00, 0.48063100E+01, -.20039600E+00, -.63583000E+01, 0.58777200E+00, 0.67103400E+00, -.17741200E+01, -.85706600E+01, -.66125700E+00, 0.22204000E+01, -.21933300E+01, 0.93700800E+00, 0.11797100E+01, -.71928900E+01, -.21300600E+01, -.14927000E+01, -.10211500E+01, -.21586700E+01, 0.18945300E-01, 0.21624100E+01, 0.40069300E+00, 0.12385300E+01, 0.72932400E+00, -.32447900E+00, 0.12639600E+01, -.11776600E+01, 0.17779300E+01, -.34161100E+01, -.29450100E+01, 0.88572000E+00, -.10662300E+00, 0.83883700E+00, 0.64930000E+00, 0.69105100E+00, -.33717000E-01, -.71423300E+00, 0.60631800E+00, 0.25194000E+00, 0.11556500E+01, -.13907000E+00, 0.94702500E+00, 0.79423200E+00, 0.43501500E+00, -.65704200E+00, -.35945300E+01, -.31078500E+00, 0.15356500E+01, 0.56136900E-02, 0.71381500E+00, 0.84701500E-01, -.21227100E+00, -.21770500E+01, 0.49084100E+00, -.82808500E+00, -.69794800E+00, 0.91533100E+00, 0.14153500E+00, -.23623000E+01, -.58304600E+01, 0.19026300E+01, 0.30082700E+01, 0.17719300E+01, -.24878500E+01, -.10612800E+01, -.11127800E+01, 0.23963800E+00, -.30833000E+00, 0.36476300E+00, -.13912900E+01, -.22586200E+00, -.17331700E+01, -.21189500E+01, -.49713400E+00, 0.27715900E-01, -.27639300E+00, 0.13226400E+00, -.10783500E+00, -.21528600E+00, 0.99730800E-01, -.13478000E+01, 0.12004500E+01, -.23762700E+01, 0.39168400E+00, -.53570600E+01, 0.13677900E+01, -.77573700E+00, 0.34318500E+01, -.13019900E+00, -.10203400E+01, 0.36370700E+00, -.42183800E+01, -.15131500E+00, -.16234400E+01, 0.86226500E-01, -.86002300E+00, -.22014400E+01, -.10695100E+01, 0.31705600E+01, 0.39609500E+00, -.42277600E+00, 0.78043900E-01, 0.96152800E-01, 0.46938600E+00, -.29607400E+01, -.78489600E+00, 0.64597300E+01, 0.22876900E+01, -.14017300E+01, -.40817700E+01, -.59760100E+00, -.11532100E+01, 0.23815300E-01, -.95199000E+00, -.12369600E+01, 0.48565900E-01, 0.59135500E+00, -.39361400E-01, 0.11661600E+01, -.12823600E+01, 0.13615500E+00, 0.10442700E+01, 0.12518700E+01, -.38175500E+00, -.38284100E+00, 0.51780700E+00, -.45994700E+00, -.92381400E-01, 0.30350500E+01, 0.11682900E+00, 0.22711100E+00, -.96349000E-01, -.77349800E+00, 0.12698600E+00, 0.17736700E-01, 0.13763500E+00, -.34389200E+00, -.32492900E+00, -.10374600E-01, 0.26443100E+00, -.10095100E+01, 0.25792100E+00, 0.28074800E+01, 0.26966600E-01, 0.16770600E+00, 0.22944100E+02, 0.47431500E+02, 0.49094300E+02, -.85771700E+01, 0.47988400E+02, 0.65783000E+02, 0.45211700E+02, -.80066800E+02, -.90340500E+02, 0.50661800E+02, 0.71666700E+02, 0.41125100E+02, 0.44909300E+02, 0.13066500E+02, 0.82424500E+01, -.13232000E+03, -.25931400E+03, 0.87426900E+02, 0.26127400E+03, -.48393200E+03, 0.24528500E+03, 0.14682000E+03, 0.24150900E+03, 0.20234800E+03, -.24623900E+03, 0.34920500E+03, 0.36215700E+03, 0.28075500E+03, -.26195200E+03, 0.13594300E+02, -.44986000E+02, 0.21571600E+02, -.97083500E+02, 0.22166200E+02, 0.18637000E+02, 0.61818500E+02, 0.48594200E+01, 0.16692900E+02, -.15128400E+02, 0.81544100E+02, -.37816400E+03, -.19266000E+03, 0.93598600E+02, 0.64582700E+02, 0.91542100E+02, 0.69876200E+01, 0.49759200E+02, -.12460900E+03, -.37583800E+03, -.19164000E+03, 0.13801300E+03, -.68793200E+02, 0.19888900E+03, -.10562800E+03, -.31067700E+02, -.98540700E+02, 0.10013400E+03, 0.36043400E+02, -.14068200E+03, -.48446400E+02, 0.13044000E+03, 0.36199800E+02, -.30688800E+03, -.66642500E+03, 0.34062900E+03, 0.23411300E+03, 0.33279000E+03, 0.12510900E+02, -.32587300E+03, 0.34277000E+03, 0.11687500E+03, 0.25029200E+03, -.41893600E+03, 0.38939400E+02, -.73192600E+03, 0.35938800E+03, 0.23436100E+03, 0.36403700E+03, 0.54168900E+02, -.29603700E+03, 0.26297000E+03, -.22643100E+02, 0.29932200E+03, -.22131100E+03, -.47270100E+03, 0.62496900E+03, -.30966300E+03, -.56753800E+02, -.31320600E+03, -.14074500E+03, -.22175300E+02, -.58971600E+02, 0.19787400E+03, -.24797800E+02, -.52923700E+02, -.31136600E+03, -.22443800E+03, 0.12011600E+03, 0.20114400E+02, 0.10995200E+03, -.76858300E+02, -.47784600E+01, 0.17835700E+03, 0.14957700E+03, 0.28069900E+03, -.35165100E+00, 0.10152100E+02, 0.51350300E+02, -.32664900E+02, -.31958000E+02, -.36859300E+02, -.74303000E+02, -.35362600E+02, -.30911200E+02, -.30881100E+02, 0.31128800E+02, 0.27045300E+02, -.67115500E+02, 0.36885700E+02, 0.95460300E+01, 0.36083100E+02, -.52282300E+02, -.30708700E+02, -.52753800E+02, 0.70527300E+02, -.40796500E+02, 0.31247600E+02, -.76120200E+02, -.27999600E+02, 0.73924700E+01, -.59030500E+02, -.23652900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13343700E+01, 0.20452000E+00, 0.10502500E+01, 0.24301500E+01, 0.40892100E+00, -.17067700E+00, -.12662800E+01, 0.13228500E+01, 0.49855800E+01, 0.13124800E+01, 0.13870500E+00, -.22880200E+01, 0.12526800E+01, 0.22465400E+01, 0.43173000E+00, 0.63199400E+01, -.53379100E-01, -.21391900E+01, 0.50823800E+00, -.21011400E+01, -.26224100E+01, -.21118000E+00, 0.13819700E+01, -.32412100E+01, -.70214200E-01, 0.37604900E-01, -.35270600E+01, -.28297400E+00, -.20308000E+01, -.87041400E-01, 0.74874700E+00, -.94206900E-01, 0.12025500E+00, -.66940200E+00, -.59540900E+00, 0.44578100E+00, -.33053200E-01, -.13720800E+01, -.70547700E-01, -.14709000E+00, -.25303000E+01, -.14401300E+01, 0.16767900E+01, -.21525600E+00, 0.13798300E+00, 0.51510200E-01, 0.35589900E+00, -.78546200E-02, -.73343300E-01, -.60669400E-01, 0.63032800E+00, 0.46441800E+00, 0.18659000E+00, 0.49601600E+00, -.65944500E-01, -.17640200E+00, 0.65482800E+00, -.30372400E+01, 0.24178100E-01, 0.12043900E+00, 0.16690600E+00, 0.86669700E+00, -.46835000E-01, -.66245900E+00, -.15570700E+01, -.27897300E+00, -.27438600E+00, -.89674500E+00, 0.14182000E+01, -.15410200E-01, 0.42355200E+01, -.86069100E+00, 0.10530900E+01, 0.15746900E+00, -.10603900E+01, -.27213400E+00, -.94814600E-01, -.13823300E+00, -.19504400E+00, -.15393600E+00, 0.13089400E+00, -.84290300E+00, 0.72539300E-01, 0.48220300E-02, 0.59442000E-01, -.92039100E+00, -.49737000E-01, -.20085800E+00, 0.11923700E+00, 0.80049400E+00, -.75733500E+00, 0.13517300E+00, -.12405300E+01, 0.46935000E+00, -.78684900E+00, 0.45783400E+00, -.12859800E+01, 0.56541700E+00, -.24066100E+00, 0.68061200E+00, -.11172400E+00, -.48527700E-01, 0.24283500E-01, -.13001000E+01, 0.71579900E-01, -.56360700E+00, 0.12037400E+00, 0.22064600E+00, -.36426300E+00, -.43732800E+00, 0.14549700E+01, 0.15233400E+00, 0.93073200E-01, 0.48167500E-02, 0.41650000E-01, 0.24547600E+00, -.93653000E+00, -.46008300E+00, 0.18726000E+01, 0.26252000E+00, -.10706100E+00, -.15638100E+01, -.27416200E+01, 0.71801500E+00, 0.35647600E-01, -.93276800E+00, 0.57843200E-01, 0.27200400E+00, 0.48602700E+00, -.96202500E-01, -.27660100E+00, -.27545500E+00, -.15397100E+00, 0.23501900E+00, 0.79772700E+00, 0.13157700E-01, -.71917000E+00, -.14755400E+00, 0.46952400E-01, 0.17346000E+00, 0.64855700E+00, -.20422800E+00, -.15687500E+00, 0.30831600E+00, -.25501800E+00, -.48230100E+00, 0.10623100E-01, -.31834200E+00, -.63459000E-01, -.14834500E+00, -.41615800E+00, 0.15162200E+00, 0.22057900E+00, 0.11824300E+00, 0.11366800E+01, -.12629000E-01, 0.13534600E+01, 0.38277900E-01, 0.92943500E+02, 0.13270300E+03, -.22175900E+03, -.84539400E+02, 0.62117000E+02, 0.11504500E+03, 0.48686500E+02, 0.20395800E+03, -.10980500E+03, -.52600400E+02, -.99455900E+02, 0.19574900E+02, -.40265500E+01, -.22287600E+02, 0.92937400E+01, -.84951800E+02, 0.93225900E+01, -.56045900E+03, -.28386800E+03, 0.13565400E+03, 0.10237100E+03, 0.14176200E+03, -.10242500E+03, -.20242900E+02, 0.26305400E+02, -.20918800E+03, 0.70596800E+02, -.28075200E+02, 0.69765200E+03, 0.22516400E+03, -.11156700E+03, -.21444800E+03, -.11269600E+03, -.72528200E+02, -.62880400E+02, 0.92062800E+01, 0.52280800E+02, -.78409800E+02, -.59436300E+02, -.24541500E+03, 0.40748900E+03, -.19890400E+03, -.60126700E+02, -.20520800E+03, -.13646300E+03, -.19050700E+03, -.41759000E+02, 0.20643600E+03, -.30518100E+02, -.14199200E+03, -.17759300E+03, 0.25152000E+03, -.11888700E+03, -.88741800E+02, -.12546900E+03, -.15082600E+02, 0.24581000E+02, -.15208700E+03, -.79524500E+02, -.13238600E+02, 0.45926400E+02, 0.18986000E+03, 0.44887800E+02, -.30645100E+02, 0.32054300E+02, -.22587000E+02, -.13457400E+02, 0.33321300E+02, 0.66267000E+02, 0.19715900E+03, -.23879000E+02, -.80690900E+02, 0.21788800E+03, 0.54700400E+03, -.26566900E+03, -.28458100E+03, -.27417400E+03, -.72468500E+02, 0.38250900E+02, -.15973000E+03, 0.19227300E+02, -.19940500E+03, 0.33493600E+02, -.40082100E+03, 0.25231800E+03, -.12961000E+03, -.12363300E+02, -.12652100E+03, 0.42020600E+02, 0.95152900E+02, -.12322700E+03, -.37468800E+02, -.87690500E+02, 0.89778300E+02, 0.29780300E+02, -.17538300E+03, 0.80214200E+02, 0.11948900E+01, 0.86909300E+02, -.14492600E+03, -.60053800E+02, 0.55306300E+02, 0.24019300E+03, 0.17334800E+03, -.79682600E+02, 0.46577700E+03, 0.25938100E+02, -.16784200E+02, -.15473600E+02, -.20508000E+02, 0.41274800E+02, -.12438600E+02, -.11934300E+02, -.52193800E+01, 0.15238500E+02, 0.17318800E+02, -.28018600E+02, 0.31866700E+02, 0.79953500E+01, 0.30345200E+02, 0.22394700E+02, -.10835700E+02, -.40080300E+02, -.12136400E+02, 0.32240600E+02, 0.32050500E+01, -.35860300E+02, -.26525300E+02, -.17204600E+02, -.11908500E+02, 0.38610500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.81475000E+00, -.51771500E+00, -.15160800E+01, 0.44472900E+00, 0.57922500E-01, 0.18362100E-01, -.10957300E+01, -.17763400E+01, -.18650400E+00, 0.23044500E+00, 0.15928800E-01, 0.44263100E+01, 0.14137000E+01, -.63835900E+00, 0.90037900E+00, -.42246700E+01, -.19010600E+01, 0.20161200E+00, 0.29449400E+00, -.68105800E+00, -.55443100E+00, 0.91648300E-01, -.49638300E+00, -.75037500E+00, 0.10205700E+00, 0.91348300E-01, -.13180400E+01, 0.25386300E+00, -.71202800E-01, -.83338200E+00, 0.13270600E+00, 0.22757500E+00, -.28724000E+00, -.37871500E+00, 0.17282400E+00, -.10269500E+00, 0.41026500E-01, -.33303300E+00, -.11127700E+00, -.20237500E+00, 0.12957800E+01, 0.10274000E+01, -.22666200E+00, 0.85883400E-01, 0.48229400E-01, -.82614600E-01, 0.41262800E-01, 0.46215300E-02, -.78402000E-01, 0.67428000E+00, 0.65657200E+00, 0.55559800E+00, 0.34746200E-01, 0.33896400E+00, 0.31297300E+00, 0.19878600E+00, -.11375600E+00, -.16432000E+01, 0.58050800E-02, 0.31043100E+00, -.11119700E+00, -.98906200E-01, -.75475200E-01, -.50786900E+00, 0.72086400E+00, 0.26115200E-01, -.13254800E+00, -.11341600E+01, -.50650500E+00, -.13722500E-01, -.14824300E+00, -.46353100E-01, -.16758100E+00, 0.13544100E+00, 0.12524400E-01, 0.25526100E+00, -.10561400E+00, -.19287600E+00, -.10490200E+00, -.94448100E-01, 0.40636600E-01, -.21514100E+00, 0.26932500E+00, 0.44168600E+00, -.11365200E+00, -.49229100E+00, 0.15052700E+00, 0.45890000E+00, -.18651200E+00, 0.31722000E+00, 0.40820400E-01, -.20364800E-02, -.51143500E+00, -.21328200E+00, -.52748700E+00, 0.74287800E+00, 0.30947400E+00, 0.63132600E+00, -.59890000E-03, -.70370800E+00, -.17629500E-01, 0.65722300E-01, -.56447200E-02, 0.65615800E+00, 0.60509400E+00, 0.23921600E+00, 0.14244400E+00, 0.40235400E+00, 0.19815300E+00, 0.22937500E+00, 0.68719800E+00, 0.42826600E-02, -.11327700E+00, -.30763200E-03, -.60123300E-01, -.33023700E-01, 0.18072900E+01, -.17222600E+00, 0.22990400E+00, -.30420800E+00, -.64833800E-01, 0.37226400E+00, -.63757700E+00, 0.47386900E+00, -.38908500E-02, -.29161700E+00, 0.27828500E+00, 0.92934200E-01, 0.35197100E+00, -.88117100E-01, -.65999000E+00, 0.16902700E+00, 0.29840300E+00, 0.11483500E+00, 0.10104100E+00, 0.20459800E-01, 0.17483700E+00, -.10862900E+00, -.21598700E+00, -.10041300E+00, 0.64859100E+00, -.25871300E+00, 0.10335800E+00, 0.35319900E-01, 0.36902100E-01, -.41999600E+00, 0.15250200E-02, 0.19905600E+00, 0.34321800E+00, 0.61501200E-01, 0.91270100E-01, 0.41468600E-02, -.52835800E-01, -.57843900E-01, -.28781400E+00, 0.13074600E+00, -.96845000E+00, -.42562700E-01, 0.44329200E-01, 0.27198000E+02, 0.23700600E+02, 0.10881300E+02, -.17402500E+02, 0.22477500E+02, -.95664000E+01, -.23298700E+00, 0.31113100E+01, 0.13410100E+02, -.71970200E+00, -.22361500E+02, -.61879500E+01, -.76197600E+01, -.24803400E+02, 0.29633400E+01, -.90464800E+01, 0.20951000E+03, 0.17557000E+03, -.85693200E+02, -.79315900E+02, -.87834600E+02, 0.41578900E+02, 0.21524900E+02, 0.16759100E+02, 0.85818800E+02, -.31492400E+02, 0.76309200E+01, -.80186900E+02, 0.95062500E+02, -.48138000E+02, -.37243800E+02, -.47546000E+02, 0.27786500E+01, 0.47521700E+02, -.42412800E+02, -.34681000E+01, -.42344800E+02, 0.29732500E+02, -.56977900E+02, 0.40634500E+02, -.22043700E+02, 0.17196800E+01, -.20507700E+02, 0.12642700E+02, 0.74183900E+01, -.10919200E+02, -.32860200E+02, -.73098800E+02, 0.18325600E+02, -.59779100E+02, -.44377700E+02, 0.19119000E+02, 0.45619300E+02, 0.22232900E+02, 0.50907900E+01, 0.93577000E+01, 0.17779600E+02, 0.43992200E+01, -.12578000E+02, 0.13101300E+02, -.11396100E+03, -.18413800E+03, 0.95390200E+02, 0.61966800E+02, 0.92058500E+02, 0.52948400E+02, -.84079100E+02, 0.99503200E+02, 0.48132200E+02, 0.13056800E+03, -.74027700E+02, -.10152900E+02, -.76197200E+02, 0.34871900E+02, 0.90728500E+01, 0.37968800E+02, -.30403600E+02, -.51715900E+02, 0.21210200E+02, -.15017200E+02, 0.31900900E+02, -.55342400E+02, -.81663900E+02, 0.46560900E+02, -.21829500E+02, -.34434000E+02, -.23261900E+02, -.51973500E+02, -.38529800E+02, -.39229100E+01, 0.16136500E+02, 0.28289300E+02, -.33758400E+02, -.50724500E+02, -.42859500E+02, 0.24879000E+02, 0.24177900E+02, 0.21382600E+02, 0.68698000E+02, 0.46719200E+02, 0.27840900E+02, -.21050200E+02, 0.56109500E+01, 0.60031300E+02, -.30984000E+02, 0.53920300E+01, 0.86836000E+01, 0.10252000E+02, 0.13230700E+02, 0.23418200E+00, 0.96744800E+01, 0.97995700E+01, 0.10219200E+02, -.10733600E+02, -.21139500E+00, 0.49250400E+01, -.16541700E+02, 0.21232500E+01, -.16744700E+02, -.55151700E+01, 0.10128800E+02, 0.83007300E+01, 0.65589800E+01, -.90309900E+01, 0.36788500E+01, 0.11549700E+01, 0.20685100E+01, -.70034100E+01, 0.53639500E+01, -.19475800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26907000E+01, -.18670200E+01, -.74741600E-02, -.99535600E+00, 0.76903800E-01, -.19067200E+00, 0.67660500E+00, 0.24936100E+00, -.21753700E+01, 0.14368300E+00, -.66153000E+00, 0.10045700E+02, 0.23101400E+01, -.18075500E+01, 0.86079100E+01, -.70218400E+01, -.47721000E+01, -.70199800E+00, 0.17770400E+01, -.27918700E+01, 0.22763000E+01, -.28745200E-01, -.27787900E+01, -.49938300E+00, 0.75355900E-01, 0.69261700E+00, -.86612200E+00, -.69097200E-01, 0.71235000E+00, 0.77489200E+00, -.11283800E+01, -.50356100E+00, 0.38358200E+01, -.16519000E+01, 0.13950600E+01, 0.67644000E+00, 0.53220600E+00, 0.15287400E+01, -.35267700E+00, 0.53632400E+01, -.19690900E+01, 0.79028000E+00, -.38330600E+01, -.67775500E-01, -.55345500E+00, 0.42522400E+00, -.88990900E+00, 0.24883100E-01, -.26600500E+01, -.98286000E+00, -.21526900E+01, 0.38333900E+01, -.91458500E+00, -.14159800E+01, 0.25290900E+00, -.30414800E+00, -.34521300E+00, 0.28013400E+01, -.12118600E+00, 0.26831700E+00, -.13418200E+00, -.33928200E+00, 0.55557100E-01, -.95521400E-01, 0.15225400E+01, -.55896900E+00, 0.31648700E+00, -.19453800E+01, -.46712100E+00, 0.41366300E+00, 0.11906900E+01, 0.25791200E+01, 0.32985900E+00, 0.62329400E+00, 0.91613900E-01, 0.15119300E+00, 0.12096600E+00, 0.10167800E+00, 0.37984500E+00, 0.57074700E+00, -.32659800E+00, 0.13920100E+01, 0.38896500E-01, 0.26668600E+00, 0.22367400E+01, -.18775000E+00, 0.23135500E+00, 0.41513200E+00, -.19980500E+00, 0.27718700E+00, -.18072800E+01, -.41022500E+00, -.11044000E+01, -.43983400E+00, -.18843000E+00, 0.89838200E+00, -.11875400E+01, -.15148000E+01, -.32268400E+00, -.19413800E+01, 0.36280900E+00, 0.25309600E+00, -.48574700E-01, -.28683100E+01, 0.10508200E+01, -.37531800E+00, 0.19704700E+00, -.48779300E+00, 0.18072700E-01, 0.51336900E+00, 0.37397100E+01, 0.36508300E+00, -.16615500E-01, -.11136100E-01, -.19806800E-01, 0.22785500E+00, 0.11100000E+01, -.60388600E+00, -.24880500E+01, -.15530800E+01, 0.11576000E+01, 0.22271800E+00, 0.29853700E+01, -.11372900E+01, -.70071400E-01, 0.14833200E+01, 0.13706400E+00, -.18713100E+00, -.11107000E+01, 0.14106100E+00, -.15080400E+01, -.86778300E+00, -.32103400E+01, -.68847800E+00, -.16567400E+00, -.21811600E+00, 0.61091200E+00, -.70173800E+00, 0.10173700E+01, 0.19555600E+00, -.27552400E+01, -.11557700E+00, -.19616300E+00, -.66212300E+00, 0.84828100E-02, 0.55802300E+00, -.71911900E-01, -.62776300E+00, -.26206700E+01, -.89450500E+00, -.11441100E+01, -.46425900E+00, -.10508600E+01, 0.92903500E+00, 0.43815900E+00, -.41608800E+00, 0.28805400E+01, 0.17632600E+00, -.91958800E+00, 0.13343100E+01, -.25683000E+03, -.11599300E+03, 0.44722800E+02, -.20350800E+02, 0.13335000E+03, 0.29500400E+03, -.16382100E+03, -.22640800E+03, -.14549900E+03, -.51513400E+02, -.37771700E+02, 0.20535400E+02, 0.28968300E+03, 0.52735900E+03, -.15737000E+03, -.10112700E+04, -.36444200E+03, 0.17002300E+03, 0.11064700E+03, 0.18276900E+03, -.66869100E+03, 0.11537000E+03, -.35863900E+03, -.96936400E+03, 0.11081100E+02, 0.20871300E+03, 0.73435900E+03, -.59363700E+03, 0.29801300E+03, -.66586400E+02, 0.29704900E+03, -.17237600E+03, -.38991800E+03, 0.32930100E+03, 0.16864800E+01, 0.31649300E+03, -.34374500E+03, 0.65513600E+03, 0.13793500E+04, -.68015500E+03, -.51027000E+03, -.68663600E+03, -.40974700E+03, -.62155800E+03, 0.22832400E+03, 0.98532900E+03, 0.18217900E+03, -.61762300E+03, -.24729400E+03, 0.29368300E+03, -.13235900E+03, -.24702500E+03, -.14748500E+03, -.34548000E+03, -.13093300E+03, -.25172000E+02, -.21631000E+02, -.15887500E+03, -.16706600E+02, 0.58964900E+03, 0.80409000E+03, -.42235300E+03, -.18559700E+03, -.40180700E+03, -.48638200E+02, 0.41011800E+03, -.36868800E+03, 0.13725000E+03, -.41837300E+03, 0.33659300E+03, -.39452900E+02, 0.16818800E+04, -.82369400E+03, -.42139500E+03, -.83926400E+03, -.34361100E+03, 0.34364900E+03, -.56401800E+03, 0.69617300E+02, -.60026000E+03, 0.23848600E+03, 0.16949600E+03, -.19966500E+03, 0.91943000E+02, 0.10482300E+03, 0.10006400E+03, 0.33624400E+03, 0.32911500E+03, -.18825100E+03, -.27445800E+03, -.14333000E+03, 0.32505300E+03, 0.20743200E+03, -.53711800E+02, 0.90005400E+01, 0.56445800E+02, 0.28073300E+02, -.18314600E+03, -.14204000E+03, -.13744500E+03, 0.19263200E+03, -.72727800E+02, -.15553000E+03, 0.48141800E+03, 0.68357600E+01, 0.31947700E+01, -.42198500E+01, -.50531100E+01, 0.11720500E+03, -.14307100E+02, -.21202300E+02, 0.44058300E+01, 0.55114800E+01, 0.20122100E+01, 0.13662200E+02, 0.21097800E+02, 0.38093900E+02, 0.19926400E+02, 0.12347700E+03, -.19350100E+01, -.24886500E+02, -.76749400E+02, 0.14059000E+03, 0.14336000E+02, 0.42747400E+02, -.13705800E+02, 0.94666700E+01, 0.31864600E+02, 0.61592400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.89371400E+00, 0.84191500E+00, 0.19815000E+01, 0.25023100E-01, 0.69751200E-01, -.98908500E-01, 0.10167200E+01, 0.86800200E+00, -.14853100E+01, -.12192400E+00, -.36635400E-01, -.72249600E-02, 0.15096600E+01, 0.10621200E+01, 0.83779800E+00, 0.42170500E+00, 0.35179400E+00, -.32346600E+00, -.58702900E-01, -.19726600E+00, 0.47749400E-01, -.24718600E-01, -.46575800E+00, 0.55186600E+00, 0.17433200E-01, 0.37339200E-01, 0.28386700E-01, -.59450300E-01, 0.42388000E+00, 0.85740400E-01, -.37051400E+00, -.48395200E+00, 0.48721100E+00, -.43901800E+00, 0.20999000E+00, 0.60571600E+00, 0.33636400E-01, 0.66934600E+00, -.19011700E+00, 0.22801800E+00, -.53443500E+00, -.26298600E+00, 0.86191200E-01, 0.16016400E-01, 0.37355500E-01, -.19564800E+00, -.30018100E+00, 0.78157300E-02, -.94644000E-01, -.21536400E+00, 0.50408200E+00, 0.16215300E+01, -.13760500E+00, 0.42329200E+00, 0.26924600E+00, -.22350900E+00, -.38976900E-01, -.55877800E-01, -.99894300E-02, 0.31357100E-01, -.21544600E-01, -.61249200E-01, 0.11219200E+00, 0.10759200E+01, -.72497200E-01, 0.51469100E-01, 0.66021400E-01, 0.12987500E+01, 0.26190900E+00, 0.76214100E-01, -.94151400E+00, -.29474800E+00, -.44144500E-02, -.49379000E-01, -.23400900E-01, 0.22377800E-01, 0.19978100E-01, -.15924400E+00, -.19554400E+00, -.42945700E-01, -.42559600E-01, -.89079500E-02, 0.38302100E+00, -.12720000E+00, 0.18108800E+00, 0.28424400E+00, -.35467200E+00, -.23136700E-01, 0.15549200E+00, 0.34887400E-01, -.40298700E+00, 0.56420700E-01, -.87234700E+00, 0.32874900E+00, 0.43460000E+00, -.54856900E+00, -.14355400E+00, 0.60117800E+00, 0.15700100E-01, 0.75763500E+00, 0.10008000E+00, 0.12215300E+00, -.82338700E-03, -.65382200E-01, 0.14987400E-01, 0.12755200E+00, -.38728200E-01, 0.48016700E+00, 0.29107900E+00, -.22478900E+00, -.22991200E+01, -.25772300E+00, 0.43071200E-01, -.30475300E-02, 0.11802100E+00, -.38386200E-02, -.66793000E+00, -.68565600E+00, 0.12676100E+01, 0.21001300E-01, 0.13671000E+00, -.11047600E+01, -.36401800E+01, 0.77403600E-01, 0.15035100E-01, -.93051700E+00, -.97818800E-01, 0.33788200E-01, -.76131900E+00, 0.10711500E+00, 0.37468100E-01, -.72974400E-01, -.93613100E+00, -.92202900E+00, -.56087300E+00, 0.82171100E-02, 0.95330800E+00, -.47545200E-01, 0.72303600E-01, 0.68067100E-01, 0.36387500E+00, -.20539100E+00, 0.37957200E-01, 0.18384200E-01, -.26303900E+00, -.35146300E+00, 0.67721700E-02, -.21300800E+00, 0.25107000E+00, 0.10513600E+00, -.88158600E-01, 0.20038300E+00, 0.35110800E+00, -.78598700E-01, 0.40581200E-01, -.72631100E-01, -.28271300E+00, 0.11538600E+00, -.20653700E+00, -.89297500E+00, -.88659900E-01, 0.30050900E+02, 0.48027900E+02, -.99187000E+01, 0.57152000E+01, -.44238600E+02, 0.18485900E+02, 0.36729300E+02, 0.23302600E+02, -.66320800E+02, 0.18872600E+02, 0.14222300E+02, -.38004100E+02, -.10949300E+02, 0.19956000E+02, 0.60564500E+02, -.36707600E+03, 0.18063200E+03, 0.71022000E+02, 0.18375900E+03, -.14137100E+02, -.13282500E+03, 0.88027700E+02, -.18057200E+02, 0.12580600E+03, -.16344200E+03, 0.16098400E+03, -.28062600E+03, 0.13984000E+03, -.82426400E+02, 0.14041000E+03, -.75688600E+02, -.76441200E+02, 0.12468900E+03, 0.11054400E+02, 0.12381900E+03, -.49768500E+02, 0.12911100E+03, -.21445500E+01, 0.28606800E+01, -.11692100E+03, 0.23473300E+01, -.72099400E+02, -.99470700E+02, 0.61637300E+02, 0.15324000E+02, 0.52174100E+01, -.62484100E+02, 0.28244800E+02, 0.30790800E+03, -.15197200E+03, -.12518400E+03, -.15422300E+03, 0.31396400E+02, -.22329600E+02, -.10605700E+03, 0.50191900E+01, -.22221800E+02, 0.86764600E+01, -.14103600E+03, -.88682400E+02, 0.39553500E+02, 0.14765900E+03, 0.44443700E+02, -.17844400E+02, -.73635700E+02, 0.51405600E+02, 0.50390100E+02, -.54060400E+02, -.14440100E+03, -.57561700E+02, -.35587800E+03, 0.18203800E+03, 0.22160300E+03, 0.17863000E+03, -.18695900E+03, -.18839900E+03, 0.15340700E+03, -.14264800E+02, 0.11898700E+03, -.13291200E+03, 0.96973100E+02, 0.62413900E+02, -.32921300E+02, 0.96006100E+02, -.31083300E+02, 0.47542400E+02, 0.12713200E+03, -.65912800E+02, -.29351400E+02, -.11131400E+03, 0.12842300E+03, -.56088400E+02, 0.38489400E+02, -.24757800E+02, -.22325000E+02, -.18714700E+02, -.56949100E+02, -.82052200E+02, 0.39049900E+02, 0.83027200E+02, 0.12841500E+02, -.11298900E+03, -.93036000E+02, 0.21813000E+01, -.16018100E+02, -.65890900E+01, -.49836100E+01, -.51322900E+02, -.14573300E+02, -.17041000E+02, -.46715900E+01, 0.65372900E+01, -.30049600E+01, -.22881200E+02, 0.62524000E+01, 0.23485500E+00, 0.59893100E+01, -.16898500E+02, -.41574800E+01, -.18735500E+02, 0.36140000E+02, -.67931600E+01, 0.19506800E+02, -.16179500E+02, -.27851700E+02, 0.24524000E+02, -.20315600E+02, 0.19131600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10854800E+01, -.85460100E+00, -.23241700E+01, -.14912400E+01, -.20476900E+01, -.49555200E-01, 0.12138100E+01, -.82298600E-01, -.37487500E+00, -.22480000E+00, -.16177500E+00, -.10348500E+01, 0.44863200E-01, -.10850400E+01, 0.37635500E+00, -.59562200E+00, 0.48392500E+00, 0.16056500E+00, 0.77227500E-01, 0.24871900E+00, 0.43713200E+00, 0.10821700E-01, -.32908700E+00, 0.17212800E+01, 0.12564400E+00, 0.10027200E+00, 0.59086600E+00, 0.40916800E-01, 0.25431600E+00, 0.25967900E-01, -.30843600E+00, -.24488100E+00, 0.33110500E+00, -.12572800E+00, 0.16064100E+00, 0.91895300E+00, 0.53290300E-01, 0.46735500E+00, -.15059100E+00, -.22953200E+00, 0.69684200E-01, 0.52357300E-01, 0.37724500E+00, 0.10877100E-01, 0.42972100E+00, -.17734600E-01, -.20036100E+00, 0.81720700E-02, -.91687500E+00, 0.11315000E+01, 0.16898000E+01, 0.74244200E+00, 0.20999800E+00, 0.45219200E+00, 0.82516600E-01, -.30631900E+00, -.79832200E+00, -.27208200E+01, 0.26015200E-01, 0.59327200E+00, -.94841700E-01, 0.18648700E+00, 0.10267600E-01, 0.63357700E+00, -.27250700E+00, -.10502100E+00, 0.15093100E+00, 0.80825600E+00, -.64908200E-01, -.11434400E+00, -.77119500E+00, 0.29249700E+00, -.18991800E+00, 0.13604500E+00, 0.35880000E+00, -.81354100E+00, -.37476900E-02, 0.30704600E+00, -.10538900E+00, 0.49325900E-01, 0.10148800E+00, -.98376800E-01, 0.33048100E+00, 0.29832200E+00, -.11450200E+00, -.17533800E+00, -.21609100E-01, -.15494700E+00, -.18491100E+00, 0.73262100E+00, -.32936900E+00, 0.52566500E-01, -.23493800E+00, 0.49066800E+00, 0.89727800E+00, -.27659100E+00, -.79978400E+00, -.28962800E+00, -.49271100E+00, -.51549400E+00, 0.10762300E-01, 0.28054800E-01, 0.10011000E-01, -.17075300E+01, -.14950700E+00, -.37261400E+00, -.18311000E+00, -.66032500E+00, -.54255900E+00, 0.28802600E+00, 0.21662600E+01, 0.22793000E+00, -.34819800E+00, 0.33810400E-02, 0.42791400E-01, 0.17753600E+00, 0.11319600E+01, 0.11276800E+01, -.23960100E+01, -.24169300E+00, 0.19933200E+00, -.29524200E+01, 0.16120200E+01, -.58441900E+00, -.16714300E-01, 0.76199500E+00, -.49827900E+00, 0.30740400E+00, 0.31017800E+00, 0.48757300E+00, -.36679600E+00, 0.25356800E+00, 0.23380100E+00, 0.22088000E+00, 0.23882800E-01, 0.43747900E-01, 0.57183800E+00, -.21338800E-01, -.24858800E+00, 0.30514400E-02, 0.87361600E+00, -.32259300E+00, 0.80513300E-01, 0.37937200E+00, -.36824200E-01, 0.39595800E+00, 0.71821200E-02, 0.89325900E-01, 0.12957900E+01, 0.29916500E+00, 0.29991600E+00, -.23906800E+00, 0.10968200E+00, -.10190500E+00, 0.93591200E-01, 0.94253700E-02, 0.49174600E+00, 0.40470900E-01, 0.24663700E+00, 0.25080200E+00, 0.73709800E-01, -.59902500E+00, -.47627300E+02, 0.10080500E+01, 0.45641600E+02, -.11294600E+03, 0.54217100E+02, 0.62782800E+02, 0.55880700E+02, -.13829600E+02, -.10336700E+01, 0.19398000E+02, -.48796000E+02, -.59606800E+02, 0.12201000E+02, -.17448600E+03, -.12043100E+03, 0.58332200E+02, 0.13066500E+03, 0.60455400E+02, -.20733600E+02, -.54343300E+02, -.97721600E+01, 0.11434400E+03, 0.24457300E+02, -.76116300E+02, 0.41472300E+02, -.67845000E+03, 0.33902400E+03, 0.25492400E+03, 0.33934600E+03, 0.76935400E+01, -.72445300E+02, 0.20023300E+03, -.19697800E+02, 0.27872200E+03, -.13929100E+02, 0.13194300E+03, -.10400900E+03, 0.53643900E+02, 0.72054400E+02, 0.53570000E+02, 0.35191000E+02, 0.72220400E+02, -.16273400E+02, -.52178300E+02, 0.13942100E+02, 0.49376300E+02, 0.40477600E+02, 0.40452700E+03, -.19931500E+03, -.19200600E+03, -.20258700E+03, 0.31876300E+02, 0.17954600E+02, -.10676700E+03, 0.64945400E+02, -.19886300E+02, 0.43037200E+01, -.12006900E+03, 0.23829900E+03, -.12361900E+03, 0.81049700E+02, -.11901400E+03, -.92919600E+02, 0.45253600E+02, -.20020300E+03, -.16553700E+03, -.29598900E+03, 0.60041900E+02, 0.17961300E+03, -.69669800E+03, 0.35078300E+03, 0.41737000E+03, 0.34915400E+03, -.93919400E+02, -.17388900E+02, 0.17925800E+03, 0.40140900E+01, 0.25379900E+03, 0.50768500E+02, 0.31170600E+03, -.27456800E+03, 0.13590300E+03, 0.86200900E+02, 0.13753400E+03, 0.16533400E+02, -.25175700E+02, 0.82539900E+02, -.87056100E+02, -.99984400E+01, -.29584900E+01, 0.67708300E+02, 0.14480600E+03, -.76933600E+02, 0.20585200E+02, -.71683900E+02, -.10351000E+02, 0.27015900E+02, -.92619500E+02, 0.11248900E+01, -.17329700E+03, -.21490300E+02, 0.36167800E+02, -.37330600E+02, 0.68396700E+01, 0.54383800E+01, 0.10889000E+02, -.94345000E+02, 0.23111100E+02, 0.22071200E+02, 0.16847800E+02, -.41229200E+01, -.18301700E+02, 0.13173300E+02, -.10216200E+02, -.20488600E+02, -.10186400E+02, -.48535700E+02, 0.13891500E+02, 0.23907800E+02, -.64714700E+01, -.32206400E+02, -.28105800E+02, 0.24139100E+02, 0.13430700E+02, 0.68825700E+02, 0.18493300E+02, 0.56574500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16489400E+01, 0.26554200E+00, 0.18480000E+01, -.34427500E+00, 0.77316300E+00, 0.53272500E-01, 0.23027200E+00, 0.31181000E+01, 0.10521700E+01, 0.43196700E+00, -.11269500E+00, -.14434900E+01, 0.10675000E+01, 0.13811000E+01, 0.49359900E+01, 0.38049200E+01, -.13210400E-01, -.14976800E+01, 0.29594500E+00, -.22943500E+01, 0.18793600E+01, 0.23561300E+00, 0.14312800E+00, 0.90781700E-01, -.25288500E+00, 0.17885100E-01, -.21716600E+01, -.44910600E+00, -.13960800E+01, -.29925100E+01, -.57922000E+00, -.49488200E+00, -.55580700E+00, 0.12626100E+01, -.10658700E+00, -.17265000E+01, -.82127700E-01, -.11475500E+01, -.35868100E-01, 0.59499700E+00, -.35088000E+01, -.18658600E+01, 0.14394600E+01, -.35390700E+00, -.41532900E+00, 0.29766900E+00, -.32481300E+00, -.12504300E-01, -.12326400E+01, -.12739600E+00, -.14033300E+00, -.22948000E+01, 0.86265700E-01, -.21705100E+00, -.98124600E-01, 0.84421400E-01, 0.14018300E+01, 0.43924700E+00, 0.41355100E-01, 0.30785200E+00, 0.28957800E+00, 0.96046400E-01, 0.98554900E-01, -.28190400E+01, 0.31265400E+01, -.34624500E-01, -.98427100E-01, -.15422200E+01, -.75895600E+00, -.18792500E-01, 0.47893200E+00, 0.10221400E+01, -.34757500E+00, 0.56387600E+00, -.10711000E+00, -.31112600E+00, -.73961000E-01, -.49779000E-01, -.23690400E+00, -.16195500E+00, 0.40846100E-01, -.63064600E+00, 0.54126600E+00, 0.24271900E+00, -.13762300E+01, 0.42124100E+00, -.37446400E-01, -.82679500E+00, 0.83260400E-01, 0.14221600E+00, -.22485500E+00, 0.14358700E-01, -.51522500E+00, 0.15387700E+00, -.80112100E-02, -.71031900E+00, 0.38821100E+00, -.45909100E+00, 0.40950000E+00, 0.11957700E+01, -.58354300E-01, 0.17919600E+00, 0.19370200E-02, 0.14016000E+01, -.10203700E+01, -.43500300E+00, -.11258800E+00, -.15371500E+01, -.12611300E+01, 0.24619600E+00, 0.22456400E+01, -.52077000E+00, -.10130300E+01, 0.17597300E-02, -.13919900E+00, -.21207400E+00, -.40594800E+01, -.30670200E-01, 0.19714200E+01, 0.13603000E+01, -.83159900E+00, 0.14957400E+01, -.86699200E+00, -.28375700E+00, 0.52047400E-01, -.10798700E+01, -.39948900E+00, -.18417300E+00, -.16455600E+01, -.25815300E+00, 0.11162900E+01, -.30105600E+00, -.47039000E-01, -.56172100E+00, -.83376200E+00, 0.67093200E-01, 0.10085000E+00, 0.79868200E-02, 0.21786000E+00, 0.79834300E-01, -.46868800E+00, -.67121800E-01, -.28540900E+00, 0.91435100E-01, 0.11751000E+00, -.16573900E+00, 0.16978800E-01, -.27665500E+00, -.71942900E+00, 0.44274500E-01, -.21523600E+00, -.23087700E-01, 0.22611000E+00, -.42497400E-01, -.12295700E+01, 0.20066300E-01, -.40963500E+00, 0.10234200E+00, -.44192100E-01, 0.45593400E+00, 0.50465600E-01, 0.11153400E+01, 0.13224400E+01, 0.19728900E+02, -.80794000E+02, 0.81585100E+02, -.38811400E+02, -.13484900E+03, -.40391900E+02, 0.18771100E+03, -.35752200E+01, -.21285700E+02, 0.14002900E+03, 0.17749200E+03, -.36478800E+02, -.21384100E+03, 0.43175600E+03, -.21355200E+03, -.14788900E+03, -.21636600E+03, -.12394300E+03, 0.20288400E+03, -.86620200E+02, -.13493900E+03, -.11882200E+03, 0.30113800E+03, -.21968000E+03, 0.13221000E+04, -.65871900E+03, -.23101200E+03, -.66132100E+03, 0.12069600E+03, 0.12764300E+03, -.44038600E+03, 0.11049700E+01, -.57121900E+03, 0.53696300E+02, -.31741400E+03, -.10986200E+02, 0.43903000E+01, 0.13172100E+03, 0.19411300E+01, 0.99410700E+02, 0.66343400E+02, -.15038600E+03, 0.31569000E+02, 0.11581600E+03, 0.29379100E+02, -.84839200E+01, -.71407500E+03, 0.35637100E+03, 0.19366200E+03, 0.35775600E+03, -.16246300E+03, -.40817800E+02, 0.22970900E+03, -.41901800E+02, 0.17375000E+02, -.48375600E+02, 0.51411600E+03, 0.10204000E+03, -.44909700E+02, -.46194400E+03, -.51341100E+02, 0.58772200E+02, 0.12746000E+03, 0.11433700E+03, 0.23559800E+03, 0.34319400E+03, 0.16883900E+03, -.24062600E+03, 0.21682500E+04, -.10866800E+04, -.11678800E+04, -.10858500E+04, 0.43989000E+03, 0.43013600E+03, -.68206300E+03, 0.32797100E+02, -.79724000E+03, 0.25746700E+03, -.61135600E+03, 0.28274600E+03, -.14010700E+03, -.19878100E+03, -.14200300E+03, 0.12490400E+02, -.54853400E+02, -.59357600E+02, 0.71901600E+02, 0.34478100E+02, -.10125000E+03, 0.23959800E+02, -.23058900E+03, 0.12274200E+03, -.36014000E+02, 0.11357900E+03, -.86986000E+01, -.62174000E+02, 0.89337200E+02, 0.10176300E+03, 0.35758600E+03, 0.22608600E+01, 0.86401600E+02, 0.35870900E+02, -.28879700E+01, -.99953000E+01, -.15988200E+02, 0.23058400E+03, -.23067100E+02, -.18246200E+02, -.24475300E+02, 0.95994000E+01, 0.28035000E+02, 0.14578000E+02, 0.21962800E+02, 0.22147300E+02, 0.22837800E+02, 0.12533800E+03, -.20515800E+02, -.93981300E+01, -.31829100E+02, 0.91960000E+02, 0.51558900E+00, 0.46514900E+00, -.33658200E+02, -.13843700E+03, -.14943400E+02, -.51645300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.66383200E+00, 0.10162800E+00, -.57103000E+00, 0.38443800E+00, 0.10070100E+01, 0.12535300E+00, -.82273100E+00, -.63337200E+00, 0.67692100E-01, 0.17043200E+00, -.27682300E-01, 0.23035400E+01, -.16552800E+01, -.42245100E+00, -.27474500E-01, -.92715200E+00, -.14344200E+01, -.18639100E+00, 0.18897300E+00, -.83617300E+00, -.57632900E+00, 0.85283400E-02, 0.56805500E+00, -.91485400E+00, 0.16983800E+00, -.62911200E-01, -.86795500E+00, 0.17969300E+00, -.43647100E+00, -.79557200E+00, -.55012200E+00, 0.69637400E-01, -.34302800E+00, -.54930500E+00, 0.36938100E+00, 0.13192000E+00, -.99832100E-03, 0.77541800E-01, -.47796300E+00, -.92233000E+00, 0.40146700E+00, 0.26519500E+00, 0.90498300E+00, 0.35378900E-01, -.20084800E+00, -.91399400E-02, -.51018900E-01, -.66994100E-02, -.74311700E+00, 0.88228200E+00, 0.55817900E+00, -.15102400E+01, 0.21245700E+00, 0.35604500E+00, 0.26437300E+00, -.59883800E-01, -.41999200E+00, -.26969100E+00, -.92504900E-02, 0.67173800E+00, 0.42750700E-01, 0.52373200E-01, 0.25247900E-01, -.30033000E+00, 0.50439100E+00, 0.38344300E-01, -.50370000E-01, -.33500800E+00, -.49920200E+00, -.79636600E-01, -.54959600E+00, 0.82079800E+00, -.57137900E+00, 0.48481800E-01, 0.13366300E+00, -.43373500E+00, 0.71512800E-02, 0.16982100E+00, 0.66708900E-01, -.32873600E-01, 0.43330000E-01, -.20630500E+00, 0.15818500E+00, 0.19329600E+00, -.32298000E+00, -.92162600E-02, 0.17475000E-01, 0.29310200E+00, -.23864900E+00, 0.66526900E+00, -.55465500E+00, 0.43497000E-01, 0.16880700E+00, 0.20281600E+00, 0.31806500E+00, 0.29859000E+00, 0.23164300E+00, -.60481900E-01, -.14215900E+00, -.80353900E+00, 0.83469800E-01, 0.89267300E-01, -.13451400E-02, 0.94866400E-02, 0.35509300E+00, 0.41223500E+00, -.11042700E-01, 0.30658000E+00, 0.34644900E+00, 0.23621900E+00, 0.32479400E+00, 0.97805600E-01, -.12466700E+00, 0.45752000E-03, 0.80625500E-01, 0.11866000E+00, 0.72922300E+00, -.17634000E+00, -.17848900E+00, -.20372700E+00, -.47553800E-01, -.27782000E+01, -.14186200E+01, -.14361800E+00, 0.79012200E-02, -.29408900E+00, 0.37576100E-01, 0.63570300E-01, -.80696500E+00, 0.21314300E-03, -.97580900E+00, 0.36574900E-01, -.51821300E+00, -.44175100E+00, -.36218200E+00, 0.76545700E-01, 0.10078700E+01, -.42505300E+00, 0.19687000E+00, -.15104900E+00, -.95521200E+00, -.38230100E+00, 0.15371900E+00, 0.23469000E+00, 0.11263400E+00, 0.13926700E-01, 0.11908600E-01, -.13584000E+00, 0.20584000E+00, 0.67532600E-01, -.19944400E+00, -.30035600E+00, -.30776400E-01, -.31722200E-01, 0.20408100E+00, -.13660500E+00, 0.82334400E+00, 0.45011500E-01, -.15294100E+00, -.65834000E+00, 0.16646100E+00, 0.61723500E-01, 0.30716000E+00, -.36141000E+00, -.53930500E+02, -.14379900E+03, 0.77251000E+02, 0.66101500E+01, 0.70594800E+02, 0.81919300E+02, -.35513300E+01, 0.59638400E+01, 0.14652100E+02, 0.15505400E+03, -.35628100E+02, 0.17576900E+03, 0.28609000E+03, -.13862200E+03, -.22209500E+03, -.14340200E+03, 0.70385500E+01, 0.41328200E+02, -.79787100E+02, 0.37932500E+02, -.19400700E+02, 0.33255900E+02, -.14003100E+03, 0.39843300E+03, -.19942500E+03, -.96494500E+02, -.19941200E+03, 0.43911100E+02, 0.94367000E+02, -.19289500E+03, -.22939100E+02, -.14858400E+03, 0.53207400E+02, 0.12917300E+02, -.27434500E+03, 0.13372800E+03, -.49000500E+02, 0.13456900E+03, 0.66925400E+02, 0.67625400E+02, 0.95814900E+02, -.71960300E+02, 0.11209700E+03, 0.61029800E+02, 0.19133100E+03, -.17342400E+03, 0.81680800E+02, -.62996200E+02, 0.87237400E+02, -.83098600E+02, -.65926300E+02, 0.13719100E+03, 0.37424300E+02, -.13366200E+02, -.45380700E+02, 0.84148300E+02, -.25108100E+02, 0.19515500E+02, -.15872600E+03, 0.12319800E+02, 0.34026700E+02, -.35032400E+02, 0.13757300E+02, -.20753500E+02, 0.14767700E+03, -.29893000E+02, -.87067700E+02, 0.20860200E+03, -.10985400E+03, -.23365900E+03, -.10555800E+03, 0.19478400E+03, 0.14103200E+02, -.13595400E+03, -.10322000E+03, -.34170000E+02, -.33551100E+02, 0.11172000E+03, 0.86114800E+02, -.40637400E+02, -.49356700E+02, -.43496900E+02, -.35373100E+02, -.66887500E+02, 0.44246000E+01, 0.72651300E+02, 0.80096700E+02, -.73910300E+02, 0.92880200E+02, -.95070100E+02, 0.54270200E+02, 0.13881200E+02, 0.46286800E+02, 0.43898000E+02, -.39333100E+01, 0.78564100E+02, -.46660200E+02, 0.55126400E+02, 0.94077700E+01, -.96189900E+02, 0.24680500E+02, 0.54930800E+01, 0.58357200E+01, 0.22701700E+01, 0.77993200E+02, 0.24826800E+02, 0.21538700E+02, -.90616600E-01, -.65265100E+01, 0.15069000E+02, 0.39755900E+02, -.24199400E+01, 0.75441900E+01, -.19077200E+01, 0.22622900E+02, 0.12027000E+01, 0.43201400E+02, 0.55746600E+01, 0.18121500E+01, 0.18602900E+02, 0.54918500E+02, 0.77299000E+01, -.58701400E+02, 0.45610200E+01, -.45115600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15470700E+01, -.80231900E+00, 0.58006000E+01, 0.11664000E+01, 0.31254500E+01, -.17997200E-01, 0.10651900E+01, -.64572500E+00, -.53277200E+01, -.70517300E+00, -.10775000E+00, 0.51636800E+01, -.13846100E+01, 0.36695300E+00, 0.14957300E+01, -.29281100E+01, -.18256100E+01, 0.13953100E+01, 0.43543900E+00, 0.81088100E+00, -.13394700E+01, -.20176700E+00, -.48145500E+00, 0.19617400E+01, -.58276700E-01, 0.46367700E+00, 0.10010400E+01, -.55785500E+00, 0.90954700E+00, 0.92139900E+00, 0.54265900E+00, -.82246900E+00, 0.61686000E+00, 0.11412800E+01, -.14884900E+01, -.10227700E+01, -.22940300E-01, -.10158300E+01, 0.54911800E+00, 0.61780600E+00, 0.24354500E+00, 0.21375200E+00, -.23268900E+00, 0.16821400E+00, -.18835600E+00, -.33596100E+00, 0.13242300E+00, 0.39078300E-02, 0.11588400E+01, -.59176300E+00, 0.14452300E+00, 0.22709900E+01, -.10904600E+00, 0.80375600E+00, 0.34531300E+00, 0.18249700E+00, 0.87307400E+00, -.96113100E+00, 0.37563200E-01, -.72462300E-01, 0.30478200E+00, 0.32199100E+00, 0.12020200E+00, 0.32955600E+00, -.49878000E+00, 0.15240600E+00, 0.23837400E+00, 0.11311500E+01, 0.85806800E+00, -.36439800E+00, -.16442100E+00, -.24320800E+01, 0.32733900E+00, 0.16027500E+00, -.17070700E+00, -.19847400E-01, -.22599300E+00, -.11405900E+01, -.38699900E+00, -.50039400E+00, 0.36644600E+00, -.64594400E-01, 0.63432100E+00, 0.17562400E+01, -.34234900E+00, -.10145100E+01, 0.35249500E+00, 0.71358900E+00, 0.68797000E-01, -.18375400E+00, 0.17880400E+01, 0.11351300E+00, -.27137300E+00, -.33991500E+00, 0.33498800E+00, -.96934100E+00, 0.46016800E+00, 0.45244500E+00, 0.24001500E+00, 0.79983400E+00, 0.79387900E-01, -.71435300E-01, 0.88628800E-02, 0.30190900E+01, 0.11860500E+00, -.82299400E-01, -.46978500E+00, -.11417100E+00, -.39967400E+00, -.24683800E+00, -.37710300E+01, -.76223100E+00, -.47570800E+00, -.20088100E-02, 0.34064100E+00, -.15845400E+00, -.15145400E+01, 0.33700700E+00, -.12129700E+01, 0.34485200E+00, 0.29447500E+00, -.36499900E+01, -.29232700E+01, -.21377300E+00, 0.17216900E-01, 0.10554500E+00, -.40439000E+00, 0.45767700E+00, -.18974200E+01, 0.12062900E+01, 0.15872100E+01, 0.42913400E-01, -.11585400E+00, -.32096300E+00, -.29158600E+00, 0.39960800E-02, 0.77338100E+00, -.14490700E+00, -.32623100E+00, -.29387400E-01, -.35913000E+00, -.11947600E+00, 0.93088500E-01, 0.67001000E-01, 0.24838700E-01, 0.22200800E+00, -.97559100E-04, -.12495400E+00, -.83327600E+00, -.52187700E+00, -.50260900E+00, -.65898300E+00, -.23970000E+00, -.53229300E-01, 0.44464900E+00, -.15122000E+00, 0.23183300E+00, 0.33255000E-02, -.23323600E+00, 0.44199700E+00, 0.17081300E+00, 0.48790300E+00, 0.11647200E+00, 0.27658000E+00, -.37545700E+00, -.40785900E+03, 0.20706300E+03, 0.13144900E+03, 0.20328700E+03, 0.70155000E+02, -.94114500E+01, 0.67581400E+02, -.78452000E+02, 0.11307700E+03, -.25301100E+02, 0.26558500E+03, 0.11474600E+03, -.54744300E+02, -.39068500E+02, -.57587600E+02, 0.12422700E+03, -.26493200E+02, 0.15415300E+02, 0.24812300E+03, 0.71608300E+02, -.39893400E+02, -.38541000E+02, 0.16243100E+03, -.81072000E+02, -.12665000E+02, -.81323400E+02, 0.15433900E+02, 0.42996700E+02, -.10046400E+03, 0.23090200E+01, -.68586600E+02, 0.50643600E+02, -.30875900E+02, -.29355100E+03, 0.14489300E+03, 0.22267700E+02, 0.14534000E+03, 0.38984700E+02, 0.56990100E+02, 0.95014400E+02, -.14665600E+03, 0.12564800E+03, 0.52230400E+02, 0.16483000E+03, 0.37291600E+03, -.18986700E+03, -.31508600E+03, -.18616400E+03, -.52396600E+01, -.83851000E+02, 0.32309300E+01, 0.16156700E+03, -.84105900E+02, -.71688700E+02, -.19533800E+03, 0.88026000E+02, -.40451400E+02, 0.13523000E+02, -.44136800E+02, 0.39963500E+02, -.30547200E+02, -.53676800E+02, -.83016100E+02, 0.31575700E+02, -.61706300E+01, 0.30974500E+02, -.30888200E+02, 0.12132700E+02, -.38616100E+02, 0.14723200E+02, -.35782500E+01, -.92108500E+02, 0.20858200E+02, -.58628500E+02, 0.30584800E+01, -.67157500E+02, 0.58211400E+02, -.16524500E+03, 0.83975000E+02, -.35331400E+02, 0.82423700E+02, -.94442800E+02, -.80141400E+02, 0.10372800E+03, 0.35693600E+02, -.28993000E+01, -.81138500E+02, 0.13678600E+03, 0.25690800E+03, -.12444400E+03, -.31230600E+02, -.12910600E+03, 0.65814500E+02, 0.14615600E+02, -.82399900E+02, -.79880400E+02, -.57696400E+02, 0.49589700E+00, -.13008300E+03, -.39442400E+02, 0.80237500E+01, 0.84116400E+01, 0.11715000E+02, -.20008000E+02, 0.33161000E+02, 0.34012700E+02, 0.12457800E+02, -.84200000E+01, -.25094700E+02, 0.39772800E+02, -.14916000E+02, -.28050500E+02, -.14273600E+02, -.19246300E+02, 0.12597300E+02, 0.64141500E+02, 0.81307200E+01, -.26277500E+02, -.17818600E+02, 0.65930300E+02, 0.60416300E+01, -.67978900E+01, -.62528500E+01, 0.93507000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.51134300E+00, 0.21773500E+00, 0.47878700E+00, -.65179900E+00, 0.65861500E+00, 0.16486900E+00, 0.81289100E+00, 0.82028300E+00, -.83817200E+00, -.49747200E+00, -.13008100E+00, -.88515600E+00, -.11451800E+00, -.78876800E+00, 0.20169800E+00, 0.62967200E+00, 0.46400700E+00, -.20908700E+00, -.10891400E+01, -.28713200E+00, 0.30441200E+00, 0.87625700E-02, -.91058700E-01, -.48727000E-02, 0.12744200E-01, -.13226200E-01, -.96754200E-01, 0.14021700E-01, -.35901800E-03, 0.11155500E-01, 0.95477000E-01, -.83766000E-02, -.13150700E+00, -.13244600E+00, -.85660200E-01, -.37748900E+00, -.14598000E-01, -.22323400E+00, 0.13851200E+00, -.46572700E+00, -.16148300E+00, -.47248000E-01, 0.60512200E+00, 0.53666800E-01, 0.11100700E+00, -.17516500E+00, 0.41101900E-01, -.12298700E-02, 0.15942200E+00, 0.17728000E-01, -.39262900E-01, -.36962400E-01, -.21050600E-01, 0.71380500E-01, -.11624600E-01, 0.19709600E+00, 0.18429900E+00, 0.51465700E-01, -.10331200E-01, -.22322200E+00, 0.11251300E+00, 0.25064300E+00, -.21832200E+00, 0.12717500E+00, -.12125200E+01, 0.10715600E+00, -.11134800E-01, -.74898000E-01, 0.36806600E+00, -.96166800E-01, 0.10832000E+01, -.58423300E+00, 0.37878700E+00, 0.29371100E-01, -.20904100E-01, -.79696200E-01, -.59159300E-01, -.12265300E+00, 0.27671800E-01, -.35151300E-02, 0.94901800E-01, -.45161200E-02, -.41160200E-01, -.16496700E+00, 0.10235000E+00, -.50540000E+00, 0.22885200E+00, 0.33447700E+00, -.14981200E+00, -.69496900E-01, 0.41380400E+00, 0.14009300E-02, -.27867300E+00, -.28883900E+00, 0.65628000E-01, -.13665500E+00, -.21409800E+00, 0.36950300E+00, 0.18564800E+00, -.33424000E+00, -.39543300E-01, 0.14666000E+00, -.23364300E-02, -.37601200E-01, -.34431000E+00, -.43887100E-01, 0.11759300E+00, 0.69109600E-01, -.19888100E+00, -.15470200E+00, 0.50505500E+00, -.44189400E-01, -.12349800E+00, -.74572100E-03, -.14862900E-01, 0.72992800E-01, 0.10810700E+01, 0.95703600E-01, 0.23224600E+00, 0.39480700E-01, -.32418700E+00, -.85295200E+00, -.54049600E+00, -.70691200E-01, -.14865900E-03, -.25902000E+00, 0.41878700E-01, -.22436800E+00, 0.26858700E+00, -.21854400E+00, -.10486800E-01, 0.14307400E+00, 0.38906900E+00, 0.21922200E+00, 0.53171900E+00, 0.28320900E-01, -.17351200E+00, -.22531500E+00, 0.10208500E+00, 0.92250000E-02, 0.55879100E+00, 0.71215000E-01, -.98132800E-01, 0.11535200E+00, 0.87110600E-02, -.25738800E+00, 0.14793000E-01, -.84854500E-01, 0.28188800E+00, 0.25010900E+00, 0.76681900E-01, 0.19744600E+00, 0.20141700E+00, -.93444500E-01, -.15154100E+00, -.75662200E-02, 0.38609900E-01, -.81259800E-02, 0.23864000E+00, -.42050900E-01, -.96296600E-01, -.14808000E+00, 0.42994800E+00, -.11911900E+00, 0.58283500E+00, -.24050100E+00, -.37958500E+01, -.14833700E+02, 0.10992300E+01, -.12265900E+00, 0.55474300E+01, 0.12787700E+01, 0.25692200E+02, 0.33907500E+02, 0.92473400E+01, 0.56950900E+02, -.10934200E+03, 0.52169100E+02, 0.88819100E+01, 0.54730100E+02, -.65784200E+02, 0.19829400E+02, -.17295600E+02, -.15443000E+03, 0.16994800E+02, 0.30035000E+02, 0.22363900E+03, 0.79808400E+02, -.39321900E+02, -.56860700E+02, -.39872300E+02, -.18079000E+02, -.58580500E+02, 0.28476000E+02, 0.23205300E+02, -.37108500E+02, -.40917800E+02, -.26435400E+02, 0.16625000E+03, -.81341100E+02, -.83344000E+02, -.82681500E+02, -.74846400E+02, -.10898600E+03, -.12502100E+02, 0.10965500E+03, 0.64291000E+02, -.10861900E+03, -.82152600E+02, -.10052000E+03, 0.53761400E+02, 0.51376600E+02, 0.50171200E+02, -.15792100E+02, -.99176400E+01, 0.12758700E+01, -.30997400E+02, 0.38136800E+02, -.17915200E+02, 0.38959200E+02, 0.27619700E+02, -.17596200E+02, -.11070700E+02, -.13769800E+02, -.10134300E+02, 0.52622800E+02, 0.22110600E+02, 0.60264100E+02, 0.19293900E+01, 0.32855400E+02, -.26877300E+02, 0.37521300E+03, -.18331900E+03, -.15446500E+03, -.18739800E+03, -.95783600E+01, 0.54870800E+02, -.75503500E+02, 0.43528400E+02, -.14735300E+03, 0.45908800E+02, -.20747000E+03, 0.36333300E+02, -.19864200E+02, 0.30483400E+02, -.18104500E+02, 0.83086600E+02, 0.93255100E+02, -.56723700E+02, -.30444300E+02, -.59327000E+02, 0.83497900E+02, -.87424600E+02, -.45590800E+02, 0.18417900E+02, -.25731700E+02, 0.23006100E+02, -.59735600E+02, -.42964300E+02, 0.18633200E+02, 0.38281100E+02, 0.71913700E+02, -.36344400E+02, 0.11966700E+03, 0.13554900E+01, -.91790100E+01, -.13597400E+02, -.14630500E+02, 0.16522100E+02, -.20061400E+02, -.17288000E+02, -.14687500E+02, 0.13474900E+02, 0.29645200E+01, -.63894200E+01, 0.14825400E+02, -.50648300E+01, 0.15004400E+02, 0.25875900E+02, -.14444900E+02, -.98000700E+01, -.72856500E+01, 0.32087300E+02, -.32176100E+01, -.11873000E+02, -.11211500E+02, -.92527700E+01, -.97375800E+01, 0.49812100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.69242800E+00, -.79528000E+00, -.71587300E+00, -.46223600E+00, -.62659600E+00, -.81850600E-02, 0.86949700E+00, -.53526500E-01, -.12433200E+00, -.14496800E+00, -.12064100E+00, -.30773100E+00, -.16969300E-01, -.69138000E+00, 0.37925100E+00, -.26735800E+00, 0.17832500E+00, -.84527000E-01, -.32285500E+00, -.58120300E-01, 0.66226500E+00, 0.18459500E-01, -.29762000E+00, 0.78310100E+00, 0.84028800E-01, 0.61931600E-01, 0.50340100E+00, 0.67073400E-01, 0.62283200E-01, -.32071600E+00, -.87936200E-01, 0.17615200E+00, 0.12302100E-01, -.42156400E+00, 0.85768000E-01, 0.95241600E-01, 0.10373800E-01, -.55454000E+00, 0.36415400E+00, -.36887100E+00, -.37275100E+00, -.15451100E-01, 0.72793100E+00, -.22582500E-01, 0.33048600E+00, -.17383200E+00, 0.14063900E+00, 0.40780200E-02, -.27810600E+00, 0.78780500E+00, 0.13706600E+01, 0.13749200E+01, 0.10386700E+00, 0.85540300E+00, 0.68009300E-01, 0.19175400E+00, -.54478900E+00, -.34637600E+01, -.30640800E-01, 0.40383000E+00, -.15484300E+00, 0.33283400E+00, -.38532200E+00, 0.40777400E+00, -.16789600E+01, 0.79038800E-01, 0.27243100E-01, 0.86338300E+00, 0.29930500E+00, -.23932100E-01, 0.40234600E+00, -.66923700E+00, 0.36735600E-02, -.28833600E+00, -.50366200E-01, -.84608900E-01, -.43196000E-03, 0.48185500E+00, -.16866700E+00, -.17909800E+00, -.21586600E-01, -.70394200E+00, -.27743900E+00, -.61768100E+00, -.78228100E+00, -.41447100E+00, 0.63892500E-02, -.31917400E-01, -.82019200E-01, 0.57780400E+00, -.46152400E+00, 0.35427800E-01, -.64968000E+00, 0.20200600E+00, 0.26752800E+00, 0.63668100E-01, -.36354900E+00, 0.90581400E+00, -.22175600E+00, -.28777400E+00, -.75764900E-01, -.12080100E+00, -.31700500E-02, 0.99503900E-01, -.87594900E-01, -.71315000E-02, -.22722100E+00, 0.32956000E+00, 0.53707400E+00, -.29909100E+00, -.12174900E+00, -.11005900E+00, -.15960500E+00, -.14883400E-02, 0.21712800E-01, -.80440900E-04, 0.19334900E+01, -.25430200E+00, 0.14893700E+01, -.21132100E+00, -.31315200E+00, -.82321200E-01, -.12751500E+01, -.35067100E+00, 0.75225800E-02, -.26229100E+00, 0.26214500E+00, -.40528100E+00, 0.11154300E+01, -.20961200E+00, -.61097700E+00, -.14780100E+00, 0.38108200E-01, 0.40720200E-02, -.12670900E+00, -.11299000E-01, -.24230900E+00, 0.24806800E+00, 0.30884000E+00, 0.21980500E+00, 0.93228800E+00, -.78634500E-01, -.25848000E+00, 0.68128200E-01, -.16147300E+00, 0.80221000E-01, -.41279700E-02, -.54351300E-01, 0.51198700E+00, -.10930200E+00, 0.35954500E+00, 0.28256500E+00, -.18835800E+00, 0.41351300E-01, -.13232500E+00, -.11364000E-02, 0.46347500E+00, 0.22689100E-01, 0.73453700E-01, -.56775400E+00, -.11864800E+00, -.44708500E+00, 0.24131000E+00, -.32548200E+00, 0.64638300E+00, -.39199900E+00, 0.11497900E+01, 0.69279200E+02, -.99828700E+00, 0.76891900E+02, 0.29109300E+02, -.66491900E+01, -.37280700E+02, -.51062100E+02, 0.25060100E+01, -.42661200E+03, 0.10224200E+03, -.51752900E+02, 0.11131100E+03, -.51140900E+02, 0.87869400E+02, -.69079800E+02, 0.20513300E+03, 0.35726100E+03, -.17958000E+02, -.65869000E+02, -.40230000E+03, -.86395400E+02, 0.44042400E+02, 0.54235100E+02, 0.43176900E+02, 0.26894700E+02, 0.18128900E+02, -.85871300E+01, -.19744800E+02, 0.72972100E+01, 0.20823700E+02, -.57003400E+02, 0.88992700E+02, -.43359600E+02, 0.32449500E+03, -.44797800E+02, 0.35473100E+02, 0.14695300E+03, -.15404800E+03, -.67049000E+02, -.22012500E+03, 0.15049900E+03, -.89980900E+02, 0.53824200E+03, -.26863500E+03, -.15732000E+03, -.26906600E+03, -.27531100E+02, 0.23940800E+02, -.10139000E+03, 0.11301000E+03, -.18832500E+03, 0.33704200E+02, -.72913400E+02, -.79504800E+02, 0.38946600E+02, 0.56804600E+02, 0.39719000E+02, 0.39359700E+02, -.84997200E+02, 0.59415200E+02, 0.39956500E+02, 0.35209700E+02, -.45112800E+02, 0.73632600E+02, 0.24943400E+03, -.12581400E+03, -.28946400E+02, -.12482500E+03, -.11436600E+03, -.45691600E+02, -.32382100E+02, 0.62973400E+02, -.13034400E+03, -.43468000E+02, -.34219200E+02, -.12520500E+03, 0.62524500E+02, -.74197800E+02, 0.62520900E+02, -.11713200E+03, -.16452800E+03, 0.10402100E+03, -.17661000E+02, 0.44522900E+02, -.14849400E+03, 0.15127400E+03, 0.10160900E+02, -.27734700E+01, 0.10778000E+03, -.52626800E+01, 0.10336300E+03, 0.12772700E+03, -.95046800E+02, 0.85792300E+02, -.46572900E+02, 0.10827500E+03, -.81053700E+02, -.19177900E+02, 0.24584700E+02, 0.28809900E+02, 0.22923400E+02, -.29783600E+02, 0.33446000E+02, 0.35394300E+02, 0.23017800E+02, -.28077400E+02, -.13330400E+02, 0.10724700E+02, -.20962500E+02, -.11277600E+02, -.21722800E+02, 0.22552500E+01, 0.22591700E+02, 0.14511800E+02, 0.16816300E+02, 0.27262400E+01, -.44400800E+02, 0.21966200E+02, -.75190200E+01, 0.18240300E+02, 0.24210800E+02, 0.36900400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45791200E+01, -.14129300E+01, 0.22341100E+01, -.70642400E+01, -.21118100E+01, 0.30747500E+00, 0.75602600E+01, 0.12034400E+02, -.41932700E+01, -.16245700E+01, -.65517900E+00, -.73021100E+01, 0.97989900E+01, 0.17830900E+01, 0.71064200E+01, 0.74403700E+01, 0.39238300E+01, -.44554700E+01, -.40820200E+00, -.21473100E+01, 0.61988800E+01, 0.78978900E+00, -.31929000E+01, 0.15825500E+01, -.72838300E+00, -.12128800E+01, 0.13903400E+01, 0.38756500E+00, 0.67900000E+00, 0.14854800E+01, -.33733100E-01, 0.43933200E+00, -.25432500E-01, -.53915700E+00, 0.63361100E+00, 0.15782200E+01, -.19798200E+00, 0.32015400E+00, 0.11027300E+01, -.18521500E+01, -.61006700E+00, -.75796100E+00, 0.11621500E+01, -.95078300E-01, 0.48200000E+00, -.41307900E+00, 0.13707600E+00, 0.28137700E+00, -.72428800E+00, -.62152100E+00, -.86912800E+00, -.42045000E+01, -.25752200E+00, -.17160800E+01, -.98559500E+00, -.10133500E+01, 0.60214400E+00, -.40860700E+00, -.55231000E+00, -.17966800E+01, -.29273800E+00, -.70260400E+00, 0.10520900E+01, 0.47302100E+01, -.67907700E+01, -.61347300E+00, -.44701700E+00, 0.20030200E+01, 0.29982000E+01, -.72474600E-01, 0.19611100E+01, -.13646000E+01, 0.94812800E+00, -.59804100E+00, -.39058000E+00, 0.39869700E+00, 0.19515000E+00, 0.15391100E+01, -.94188200E+00, -.12593400E-01, -.30608600E+00, -.86807900E+00, -.13999100E+01, -.39985000E+01, -.15519600E+01, 0.23092300E+00, -.16753000E+01, -.13612200E+01, 0.15587200E+01, -.27034100E+00, 0.14743000E+01, -.79917900E+00, -.26063300E+01, 0.95363400E+00, -.89349900E+00, -.20994100E+01, -.25582000E+01, -.14859900E+01, -.41321900E+00, 0.17030900E+01, 0.17618400E+00, -.10620400E+00, -.49639000E+00, -.25584000E+01, -.59077500E-01, -.16671100E+01, -.17155200E+01, -.31701600E+01, 0.10840300E+00, 0.42426400E+00, 0.52749400E+00, -.71779200E+00, -.12585900E+01, -.26718000E-02, 0.93329300E-01, -.23577900E+00, 0.86161900E+00, -.15596300E+01, 0.58167000E+01, 0.13199200E+01, -.19499200E+01, -.44130300E+01, -.93061400E+01, 0.74217200E+00, 0.32229100E+00, -.31699700E+01, -.17089600E+01, -.21926400E+00, 0.25276700E+01, -.21145500E+01, 0.48286000E+01, -.15184200E+01, 0.43002700E+00, 0.10260400E+01, 0.19621000E+01, -.63564200E-01, -.56512200E+01, 0.44901100E+00, 0.13547000E+01, 0.17638200E+01, 0.84537700E+00, 0.16124000E+01, -.89548500E+00, 0.38758300E+00, 0.70271600E+00, -.87148700E+00, -.23981000E+00, -.65144200E+00, -.33424100E+00, 0.12751200E+00, 0.34621800E+00, 0.30445400E+01, 0.21587600E+01, -.17525300E+00, -.54478400E+00, -.47346100E+00, 0.24329700E+01, 0.59886900E+00, 0.93579600E+00, 0.20445500E+01, 0.75894700E+00, -.17898200E+01, 0.65161300E+00, -.49889300E+00, -.13352700E+01, -.13606000E+00, -.14262500E+00, -.79836300E-01, 0.23134900E+02, -.16501900E+02, 0.11327300E+03, -.14683000E+03, -.10039200E+03, -.24096900E+02, 0.38553800E+02, 0.38434900E+03, 0.10913000E+04, -.54127500E+03, -.75610900E+03, -.54689100E+03, 0.33363600E+03, 0.56880200E+03, -.75978700E+03, -.66457000E+03, -.44935000E+03, 0.50063000E+03, 0.19202200E+03, 0.15516500E+04, -.77590600E+03, -.52782300E+03, -.77528100E+03, -.99132200E+02, -.77906400E+02, -.33381400E+03, 0.11017700E+03, -.56793800E+03, -.15295300E+03, 0.35696100E+02, -.14815100E+04, 0.73543800E+03, -.13082700E+03, 0.73684400E+03, 0.29867300E+03, 0.21306900E+03, 0.10411000E+03, -.37954200E+03, 0.51080300E+03, 0.99567500E+02, 0.62580600E+03, -.13533200E+04, 0.67809600E+03, 0.62897100E+03, 0.67770300E+03, 0.26429200E+03, -.20305000E+02, 0.36883100E+03, -.39163400E+02, 0.23388600E+03, -.45328400E+02, 0.51294900E+03, 0.78875600E+03, -.38419400E+03, -.45201800E+03, -.39499300E+03, 0.19102000E+03, 0.43659400E+03, -.19554700E+03, 0.11304300E+03, -.77072800E+01, 0.39541300E+03, -.80593800E+03, 0.19455000E+04, -.96744900E+03, -.11320400E+04, -.97541000E+03, 0.11558000E+03, -.26999600E+02, -.31651500E+03, -.69892800E+02, -.61552500E+03, -.14590500E+03, -.18459000E+03, -.20259500E+03, 0.10166700E+03, 0.49001200E+02, 0.10590700E+03, 0.98893600E+02, 0.11549900E+03, -.99232100E+02, 0.85262300E+02, 0.52208300E+02, 0.13180000E+03, 0.44074100E+03, 0.26243900E+03, -.14015600E+03, -.12747800E+03, -.13433400E+03, 0.15691500E+03, -.21068800E+03, 0.14956200E+03, -.12495200E+03, 0.47115000E+02, -.22788600E+03, -.52380900E+03, -.40576300E+02, 0.14872300E+02, 0.66902100E+02, 0.50091900E+02, 0.26347700E+03, 0.67493800E+02, 0.61840200E+02, 0.47811000E+02, -.70198800E+02, -.82090400E+01, 0.12455700E+03, -.55287800E+02, -.47197800E+02, -.58351900E+02, 0.16756200E+03, 0.47883100E+02, 0.10507200E+03, -.97050500E+02, 0.13647800E+03, 0.28431200E+02, 0.11616200E+03, 0.78935300E+01, -.19951200E+03, 0.30909200E+02, -.43746000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.17920300E+01, -.14496500E+01, -.67912900E+00, 0.66543600E-01, -.10759600E+01, -.43286200E+00, 0.34384100E+00, -.40125000E+01, -.36724900E+01, 0.17787600E-01, 0.66307200E+00, 0.57675000E+01, -.22426800E+00, 0.11953500E+00, 0.33741500E+01, -.43119700E+01, -.26438300E+01, 0.95074400E+00, 0.66563500E+00, 0.76631100E-01, -.77065600E+00, -.98471600E+00, -.29906600E+00, -.12316300E+01, 0.32212200E+00, 0.77546300E-01, -.39638000E+00, 0.19512200E+00, 0.66927800E+00, 0.24641500E-02, -.85727300E+00, -.14198000E+00, 0.11013100E+01, 0.38971000E+00, 0.60359400E+00, 0.68544800E+00, 0.15236000E-01, 0.94128600E-01, -.61871800E-01, 0.14064700E+00, 0.25598100E+00, 0.38745400E+00, 0.36788500E-01, 0.61522600E+00, -.74096800E+00, -.54379000E+00, 0.78631900E+00, -.38861400E-02, 0.17350600E+00, -.31474600E+00, -.83992300E+00, -.11783400E+01, -.16661800E+00, 0.39598600E+00, 0.14413400E+01, -.35910300E+00, -.98955200E-02, -.21286200E+00, -.56644500E-01, 0.67078300E+00, 0.26566800E-01, -.23217500E+00, 0.93875500E-01, 0.18912400E+01, -.25475400E+01, 0.38203800E+00, -.38355900E+00, 0.80223600E+00, 0.15918800E+00, -.21460300E+00, -.80570700E+00, -.41304200E+00, -.16354800E+00, 0.18513400E-01, 0.16024600E+00, -.86385600E+00, -.44401000E-01, -.79088600E+00, -.20364200E+00, -.31968500E-02, 0.23289500E+00, -.44050300E+00, 0.82900800E+00, 0.11625000E+01, 0.11853000E+01, -.69081900E+00, 0.30235300E-01, -.28779800E+00, -.51584100E+00, 0.18534500E+01, -.16752700E+01, 0.15405000E+00, -.67989100E+00, 0.91681800E+00, 0.17883400E+01, -.27729400E+00, 0.81710000E+00, 0.92391300E-02, -.30177700E+00, -.72211400E+00, -.43840300E-01, 0.28330300E+00, 0.75806200E-04, -.52701900E+00, 0.23674700E+00, -.25580300E+00, 0.26864300E+00, -.37452600E-01, 0.58921300E-01, 0.97198400E+00, 0.27582700E+01, 0.16570800E+00, -.30828600E+00, 0.47449000E-03, -.12723100E+00, 0.18536100E+00, 0.39989000E+01, -.11101700E+01, -.18297200E+01, -.15699700E+01, 0.40988200E+00, -.12268800E+01, -.16356300E+01, 0.17324100E-01, -.21541300E-02, 0.50673100E+00, 0.42056000E+00, -.11780600E+00, 0.21351900E+01, 0.19638700E-01, -.12546800E+01, -.26037300E+00, -.17175400E+01, 0.78240900E+00, 0.10130400E+01, 0.16293800E-01, -.20986400E+00, -.45475800E+00, 0.80287100E+00, 0.40248200E+00, 0.12775300E+01, 0.18396300E+00, 0.16041700E+00, 0.17206700E+00, -.25987300E+00, 0.17519700E+00, -.66189500E-02, 0.64029400E-02, 0.13264000E+01, 0.32080000E+00, 0.20825100E+00, -.94520800E-01, 0.47737300E+00, 0.12686600E+00, 0.13809200E+01, 0.45018700E-01, 0.43933300E+00, 0.16046100E+00, 0.35015000E+00, -.21139200E+00, 0.13969800E+00, -.68410200E+00, -.39278200E+00, -.35436900E-01, 0.66506900E+00, -.65871000E-01, 0.14186800E+01, 0.19821000E+01, 0.67563100E-01, -.31022500E+03, -.29442700E+02, -.14421300E+02, -.82763700E+02, -.37012400E+03, 0.12023600E+03, 0.10287900E+04, -.33218900E+03, 0.16631600E+03, -.18014600E+03, 0.16692400E+03, 0.15343100E+03, -.54175100E+02, -.24298500E+03, -.28496400E+03, 0.42938700E+02, -.15552200E+03, 0.39179100E+03, -.74169700E+03, 0.36762500E+03, 0.90409300E+02, 0.37122700E+03, -.67683900E+02, 0.47881100E+02, 0.27857900E+03, 0.19611400E+02, 0.34760800E+03, 0.77445300E+02, 0.20754900E+03, -.28647800E+03, 0.14158100E+03, -.44330200E+03, 0.14896400E+03, -.31566900E+02, -.12971000E+03, 0.32667800E+03, 0.12374300E+02, 0.16047300E+03, -.13168500E+03, 0.23086500E+03, -.75418400E+03, 0.37624800E+03, 0.38569300E+03, 0.37591700E+03, 0.25119600E+03, 0.11164700E+03, 0.13049800E+02, -.27151100E+03, 0.42453200E+03, 0.58477500E+01, -.33894300E+03, 0.82725900E+02, -.43670400E+02, 0.29168300E+03, -.40826300E+02, -.13942700E+03, 0.41114100E+02, -.20832000E+03, -.29655000E+03, -.30292200E+03, -.49207800E+01, -.18768100E+03, -.29413800E+04, 0.14729000E+04, 0.12268500E+04, 0.14735100E+04, 0.34872100E+02, -.23520600E+03, 0.77040400E+03, -.16640500E+03, 0.10500400E+04, -.64622700E+02, 0.71056700E+03, 0.10931400E+02, -.54956800E+01, 0.20807400E+03, -.47928400E+01, 0.39500000E+02, 0.15127500E+03, -.14223300E+02, 0.34454700E+02, -.42166200E+02, 0.15742500E+03, -.25266600E+03, 0.26516200E+03, -.14146900E+03, -.19586700E+03, -.12972100E+03, -.17527500E+03, -.96853200E+02, 0.39377600E+01, -.28871200E+03, -.24184600E+03, -.87388600E+02, -.33592900E+02, -.24879700E+01, -.32817400E+02, -.32574600E+02, -.40705100E+01, -.17205200E+03, -.36327100E+02, -.41619900E+02, -.40803500E+01, 0.32120600E+02, -.29015600E+01, -.23866100E+02, -.13440400E+01, -.13229000E+02, -.14193200E+01, -.15851200E+03, -.46162000E+01, -.90302000E+01, 0.25037600E+02, -.13726300E+03, 0.44918700E+02, -.58041600E+02, 0.31402500E+02, 0.89482300E+02, -.34555600E+02, -.24587100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12405600E+01, 0.11471700E+00, 0.62575600E+00, 0.20682300E+01, 0.24612700E+00, -.18991400E+00, -.13748000E+01, 0.55807200E+00, 0.39643800E+01, 0.98187500E+00, 0.16909400E+00, -.14459300E+01, 0.20156600E+01, 0.18069500E+01, 0.24996900E+00, 0.34661300E+01, 0.11578200E+00, -.19075500E+01, 0.39874100E+00, -.14606300E+01, -.12702200E+01, -.13355800E+00, 0.10397000E+01, -.15982500E+01, -.30856200E-01, 0.63124500E-01, -.28301400E+01, -.98063800E-01, -.10078900E+01, 0.53685100E+00, 0.26166800E+00, -.66003300E-01, -.16442500E-01, -.14307000E+01, -.35152300E+00, 0.23276500E+00, 0.40355100E-02, -.46830000E+00, -.15483400E+00, -.46940600E+00, -.12213400E+01, -.66292900E+00, 0.10838900E+01, 0.96196900E-01, 0.53752500E-01, -.18982400E+00, -.18149900E+00, 0.38144600E-03, 0.29428200E+00, -.37762300E+00, 0.51730900E-01, 0.31438300E+00, 0.46219900E-01, -.24264500E-01, -.33849800E-01, 0.20628300E+00, 0.93434600E+00, -.70801100E+00, 0.97388700E-01, -.55161800E+00, 0.62006600E-01, 0.55623500E+00, 0.98872400E-01, -.10483700E+01, 0.36959300E+00, -.20198200E+00, -.97996400E-02, -.10387000E+01, 0.41825600E+00, -.63284600E-01, -.20657000E-01, -.12261500E+01, 0.38872000E+00, 0.40937500E+00, 0.13465200E+00, -.22017200E-01, -.65052800E-01, -.47032600E+00, 0.12496200E+00, 0.14551600E+00, 0.17345800E+00, -.38064900E+00, 0.12353500E+01, -.32686600E+00, 0.52296700E+00, -.42660300E+00, 0.27804600E-01, 0.23892600E+00, -.13965500E+00, 0.23272400E+00, -.80830800E-01, 0.30169000E-01, -.10523100E+00, 0.13379600E-01, 0.24377000E+00, -.30437800E+00, -.13636500E+01, 0.73463600E+00, -.27170700E+00, -.39686500E+00, 0.56950000E-01, -.24028600E+00, 0.69125700E-02, -.96545200E+00, 0.21802300E+00, -.23114400E-02, 0.19539200E+00, 0.37112000E+00, 0.26583000E+00, -.69951100E+00, 0.29841700E+01, 0.23792600E+00, -.19324300E+00, 0.39234400E-02, 0.24342700E+00, 0.53230100E+00, 0.30143100E+01, -.25110600E+00, 0.22430900E+01, -.57999400E+00, -.10720200E+00, -.38760300E+01, -.20088100E+01, -.55375700E+00, 0.21492200E-01, -.47984800E+00, -.77569000E-01, 0.57124200E-01, 0.93322500E-02, 0.34723500E-01, -.55124800E+00, -.47478400E-01, -.41270100E+00, -.57477500E+00, 0.52831100E+00, 0.31486900E-01, -.30283300E+00, -.87820600E-01, -.23691600E-01, -.10635300E+00, 0.19822700E+00, -.40717500E+00, 0.90993100E-01, -.33848800E+00, -.60936900E+00, 0.67144900E-01, -.73514500E-02, -.14141500E-02, 0.56529400E-01, 0.13539200E+00, 0.35875000E-01, 0.75252100E+00, -.12000200E+00, 0.41836000E+00, 0.50774400E+00, 0.13478000E+00, 0.47369000E-01, -.20822200E-01, 0.27558700E+00, 0.65069300E+00, 0.68540300E-01, 0.91255800E+00, 0.47353600E-01, 0.47299100E+00, -.10792800E+00, 0.12679400E+00, -.16519000E+01, 0.79133100E+00, 0.66378600E-01, 0.47946000E+00, 0.53560200E+02, -.10322100E+02, -.90251500E+01, -.33234000E+02, 0.62332400E+02, 0.40934600E+03, -.36027400E+03, 0.17952600E+03, 0.64356700E+02, 0.17984100E+03, -.25973500E+03, -.12618100E+02, 0.50901100E+02, -.20269300E+03, 0.11585000E+03, 0.28239400E+02, 0.71215900E+03, -.15703900E+03, 0.78805000E+02, 0.21470000E+02, 0.78341300E+02, -.69156100E+02, -.15244300E+03, 0.13751500E+03, 0.40449200E+02, 0.56866600E+02, -.13228200E+03, -.29060300E+02, 0.21283000E+03, -.10565400E+03, -.24581800E+03, -.10831600E+03, -.49612300E+02, -.17913500E+03, 0.27101000E+02, 0.64464000E+02, -.19103200E+02, -.14471200E+03, -.19727100E+03, -.38145600E+03, 0.19120300E+03, 0.22804700E+03, 0.19112000E+03, 0.88173800E+02, -.68442300E+01, 0.51244000E+02, -.59608100E+02, 0.19797400E+03, -.33785500E+01, 0.27594100E+02, -.31645000E+03, 0.15878800E+03, 0.20874000E+02, 0.15807700E+03, -.51095200E+02, -.37660100E+02, 0.18618700E+03, 0.11381900E+03, 0.78444800E+02, -.79002700E+02, 0.20998300E+03, 0.17275800E+03, -.87267300E+02, -.44741700E+02, -.87379800E+02, -.29193000E+02, -.87400200E+02, 0.51310600E+02, 0.74835000E+02, -.16678100E+02, -.11165600E+03, -.23506500E+03, 0.52617200E+03, -.26270900E+03, -.48894900E+02, -.26352500E+03, 0.10635100E+03, 0.11409600E+03, -.16394100E+03, 0.88995100E+02, -.56172500E+02, 0.69485800E+02, -.51259200E+03, -.29897200E+03, 0.15270700E+03, -.15602400E+02, 0.14870300E+03, -.13242700E+03, -.51381600E+02, 0.20525600E+03, 0.11400700E+03, 0.21235000E+03, -.85122100E+01, 0.29903800E+03, 0.68908800E+02, -.20802000E+02, -.24371800E+02, -.37650300E+02, 0.18264300E+02, -.62132000E+02, -.55057900E+02, -.38024900E+02, 0.24171800E+02, 0.40407300E+02, -.47991800E+02, 0.40259000E+02, 0.36284200E+02, 0.38888200E+02, 0.46546500E+02, -.38052400E+02, -.51760000E+02, -.16828800E+02, 0.61367000E+02, 0.60430500E+02, -.56332100E+02, 0.20737600E+01, -.95767900E+01, -.40541900E+02, -.43923100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.64404500E+00, 0.63248000E+00, 0.84647100E+00, -.55624800E+00, -.45832600E+00, 0.10353300E+00, 0.10974600E+01, 0.20136500E+01, -.43105600E+00, -.32780200E+00, 0.15989900E+00, -.20446000E+01, 0.20948100E+01, 0.80490100E+00, 0.56284000E+00, 0.21921400E+01, 0.89965200E+00, -.12574400E+01, 0.59594400E-02, -.14186700E+00, -.24045700E+00, -.60438000E-02, -.42879800E-01, -.85556500E-01, 0.16376900E-02, -.16731900E-01, -.37698200E+00, 0.77870600E-02, -.91098500E-01, 0.71134500E-01, -.13914300E+00, 0.75218700E-02, -.19219500E+00, -.53749400E+00, 0.14266400E+00, 0.56239800E+00, 0.15546100E-01, 0.24460700E+00, -.24058800E+00, -.64004300E+00, 0.27654700E+00, -.18404000E-01, 0.36852700E+00, 0.27889000E-01, 0.20538400E+00, -.11404100E+00, -.45656900E-01, 0.31297200E-03, 0.16409900E+00, 0.18894100E+00, 0.48992800E+00, 0.21502400E+00, 0.59479200E-01, 0.16759300E+00, 0.86913000E-01, 0.11729100E+00, 0.14221700E-01, -.34923700E+00, 0.18861000E-01, -.19316100E+00, 0.21581700E-02, 0.21487500E+00, -.18930200E+00, 0.75661700E-01, -.55822100E+00, -.62858100E-01, 0.10164800E+00, 0.50630700E+00, 0.33776300E+00, -.11831900E-01, 0.35144500E-01, -.11168300E+00, -.15360200E-01, 0.63296400E-01, -.28649100E-01, 0.38624900E+00, -.40810000E-02, -.10562200E+00, 0.99727900E-01, 0.79312800E-01, 0.30873100E-01, 0.36347500E+00, -.46685200E-01, -.24393700E+00, -.51753000E+00, 0.42463600E-01, 0.70247100E-01, 0.13759600E+00, -.45990900E-01, -.11141400E-01, -.92383200E-01, -.41283000E-01, 0.17213800E+00, -.11510900E+00, 0.40581100E+00, -.32997100E+00, -.10098300E+01, 0.13591000E-01, -.21524100E+00, -.31007900E+00, 0.65089400E-01, -.16757400E+00, 0.11411800E-03, -.12247900E+00, 0.28467000E+00, 0.15047200E-01, -.83678600E-01, -.23656000E+00, 0.93014700E-01, -.15212200E+00, 0.91613300E+00, 0.17424500E-01, -.28004400E+00, 0.44750400E-03, 0.14070400E+00, 0.12332700E+00, 0.15501400E+01, 0.46020600E+00, -.19531300E+00, -.15408700E+00, 0.11600500E-01, -.13397700E+01, 0.59438800E+00, -.75410400E+00, 0.71298300E-04, 0.15893000E+00, -.29548300E+00, -.30923200E-01, -.75706000E-01, 0.49547900E+00, 0.29049200E+00, -.94039300E-02, 0.29783100E+00, -.26322900E+00, 0.10460900E+00, -.31282200E-01, -.38450400E+00, 0.21925000E+00, -.33123100E+00, -.27436500E-01, 0.53525000E+00, -.15435500E+00, 0.70476100E-01, 0.78021200E-01, -.18508200E+00, -.86512200E-02, -.84091100E-02, 0.22506300E+00, 0.39584800E+00, -.17719500E+00, 0.53641700E-01, 0.32801400E-01, -.25504100E+00, -.37540100E-01, -.26609700E+00, 0.58506900E-01, -.36759400E+00, -.14663900E-01, 0.14496600E+00, -.51068500E-02, -.13192900E+00, -.20469300E+00, 0.15507600E+00, 0.41086600E-01, 0.17993500E+00, -.27073100E-01, 0.22922900E-01, 0.79919800E+00, 0.57632500E-01, 0.23609400E+00, 0.44639300E+00, 0.24155100E+02, 0.17733400E+02, 0.74580100E+02, -.10885900E+02, -.12913300E+03, -.35081400E+03, 0.17543700E+03, 0.17779800E+03, 0.17556200E+03, -.59632200E+02, -.91382700E+02, 0.77099700E+02, -.38184100E+02, 0.11683500E+03, -.67404900E+02, -.12735500E+02, -.28336900E+03, 0.14149500E+03, 0.81060500E+02, 0.14172300E+03, 0.77701100E+02, -.19926500E+02, 0.56323800E+02, -.16642700E+02, 0.98741100E+02, 0.36109500E+00, 0.48159000E+02, 0.79772200E+02, -.40004900E+02, -.98840500E+02, -.39083500E+02, -.79923800E+02, -.77087200E+02, 0.78328700E+02, 0.10028000E+03, 0.69131500E+02, -.69348400E+02, 0.19645100E+02, 0.14380200E+03, -.72065200E+02, -.10081600E+03, -.72076200E+02, -.33107300E+02, -.44425800E+02, -.16326600E+02, 0.25194500E+02, -.42849900E+02, -.25895900E+02, 0.20774700E+02, -.10923800E+01, 0.22948200E+00, 0.11477700E+02, 0.61899900E+00, -.22444900E+02, -.17599400E+01, -.13161300E+02, 0.10244600E+02, -.17563500E+02, -.30340700E+01, -.73966600E+01, 0.79909100E+02, -.39950200E+02, 0.10550600E+02, -.39503100E+02, -.11644400E+02, 0.57781300E+02, -.21676200E+02, 0.18070900E+02, -.59027400E+02, 0.61750500E+02, -.58863900E+02, -.10541600E+03, 0.52658800E+02, 0.51757100E+02, 0.52654500E+02, 0.58029100E+02, 0.86495800E+02, -.14257100E+02, -.83014000E+02, -.55304200E+02, 0.85206000E+02, 0.15737100E+02, 0.51384400E+02, -.25291100E+02, -.29734400E+02, -.25317600E+02, -.53581100E+02, -.47654000E+02, -.38636800E+01, 0.18339300E+02, -.24596800E+02, -.47306400E+02, -.15777400E+01, -.95033200E+01, -.83455100E+01, -.13928400E+02, -.13102800E+02, -.17523300E+02, -.25420300E+02, -.26433100E+02, -.12828200E+02, 0.14157900E+02, -.88297900E+01, -.28617100E+02, 0.15511700E+02, -.18473000E+01, 0.16202900E+02, -.11495400E+02, -.12418600E+02, -.30773700E+02, 0.11904800E+02, -.58446800E+01, 0.16804500E+01, -.20130800E+02, -.15442300E+02, 0.16407900E+02, -.21706800E+01, 0.12933400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.74455600E+00, 0.48821200E+00, -.25312800E+00, -.46533900E-02, -.11075500E+01, -.64357500E-01, 0.18796100E+00, -.31557600E+00, 0.35987800E+00, 0.66509300E-01, 0.26326200E+00, -.14129300E+01, 0.15314300E+01, 0.63909800E+00, -.95694500E+00, 0.16860600E+01, 0.12606000E+01, -.19717200E+00, -.47878400E+00, 0.86960600E+00, 0.18665300E+01, -.14245900E+00, -.30767100E+00, -.18693600E+01, -.21161900E+00, 0.10373200E+00, -.11779700E+00, 0.43393600E+00, -.75541800E+00, -.43831700E+00, 0.76593900E+00, 0.77854400E+00, -.10130700E+01, -.12832400E+01, -.57616000E-03, 0.27795700E+00, 0.24900700E-01, -.10561800E+01, 0.66888400E+00, -.63795900E+00, 0.12584400E-01, 0.40807300E+00, 0.25548900E+00, 0.61955500E-01, 0.26160500E+00, -.32038000E+00, 0.10874100E+00, 0.87250300E-02, -.49201400E+00, 0.76950400E+00, 0.95490700E-01, -.88596500E+00, 0.46495800E-02, -.59266700E+00, -.24947400E+00, 0.36558200E+00, -.15201800E+00, -.11145800E+01, 0.21388400E-01, -.29319900E-01, -.12474800E+00, -.40437400E-01, -.15453400E+00, 0.10318800E+01, -.17650300E+01, -.36626500E-02, 0.47024100E-01, 0.13441500E+01, 0.79786700E+00, -.14381400E+00, -.38149600E+00, -.12863900E+00, 0.17462600E+00, 0.48459400E-01, 0.76357600E-01, -.89113400E+00, 0.10600900E+00, 0.35880800E-01, -.29737200E+00, 0.36784100E-01, 0.97732000E-01, 0.30979000E+00, 0.55029700E-01, 0.92233400E+00, 0.12953900E+01, -.10747700E+01, 0.15326000E+00, 0.31486100E+00, -.21483800E+00, 0.48842500E+00, -.85611600E+00, 0.39220500E-02, 0.13282100E+00, 0.84906500E-01, 0.59149900E-01, 0.21725800E+00, 0.65637100E+00, -.79769400E-01, -.86091700E-01, -.31747400E+00, 0.20444100E+00, 0.17314400E+00, -.65009100E-02, 0.99272500E+00, 0.22542500E+00, 0.46579000E+00, -.41658200E-01, -.16382900E-01, -.25211300E+00, -.74923500E-01, -.17007900E+01, -.14822100E+00, 0.54301600E-01, 0.12159400E-02, 0.18877700E+00, 0.15985400E+00, -.23617900E+00, -.48588500E+00, -.33522200E+00, -.29995300E+00, -.11525500E+00, -.43757700E+00, 0.16477400E+00, -.54191800E+00, -.41210600E-02, 0.52926100E+00, 0.38967100E-01, 0.26366000E+00, -.56138300E+00, 0.56727900E+00, -.70209200E+00, -.11848700E-01, -.38319500E+00, 0.47063200E+00, -.83900900E+00, 0.68917500E-01, 0.88978400E+00, -.28161100E+00, 0.11128700E+00, -.10143200E+00, -.83576400E+00, -.19516400E+00, 0.98204500E-01, -.14167600E+00, -.21757400E+00, 0.37527700E+00, 0.10517400E-01, -.24229100E+00, -.70950200E+00, -.45695700E-01, -.27837000E+00, -.21805200E+00, -.11412000E+00, 0.11746700E+00, -.39443900E+00, -.68557000E-01, 0.24035400E+00, -.67674100E-01, -.19034500E+00, 0.18378100E+00, 0.17032300E+00, 0.47653800E+00, -.64663700E-01, 0.21650200E+00, 0.81637000E+00, 0.11030800E+00, 0.75859000E+00, 0.39132900E-01, -.60123100E-01, 0.13540500E+00, -.57140000E+00, -.47545600E-01, -.40461800E+02, -.66214900E+02, 0.18564100E+02, 0.10845500E+02, -.26991900E+03, 0.13394000E+03, 0.14776300E+03, 0.13471800E+03, -.75944300E+02, -.35129500E+02, 0.31120300E+02, 0.72622900E+01, 0.14556300E+03, -.26466200E+02, 0.23975500E+03, -.36836200E+03, 0.18389400E+03, 0.10329700E+03, 0.18414600E+03, -.56059200E+02, -.86844500E+02, 0.13216300E+03, -.45396700E+01, 0.16628500E+03, -.75331800E+02, 0.11241700E+03, -.12718200E+03, 0.64798700E+02, -.92290600E+02, 0.62634600E+02, 0.83747400E+02, -.22057400E+02, 0.16697200E+01, -.13840900E+03, -.86295000E+01, 0.69089900E+00, -.79509000E+01, -.32278800E+02, 0.16517600E+02, 0.32248800E+02, 0.16363900E+02, 0.29440100E+02, 0.52575300E+01, -.25645800E+02, -.12042000E+02, 0.13201000E+03, 0.18404900E+02, 0.42355800E+02, -.48658300E+01, 0.10330700E+01, 0.55733600E+02, 0.23549500E+01, -.33546100E+02, -.23481700E+02, 0.34681700E+01, 0.14693200E+02, -.81032500E+02, -.55026800E+02, 0.34267400E+02, -.50002900E+03, 0.24908800E+03, 0.26399300E+03, 0.24938700E+03, -.73089600E+02, -.13922100E+03, 0.14840100E+03, -.41894300E+02, 0.26218700E+03, -.12684700E+03, 0.20457700E+03, 0.19832200E+03, -.99144200E+02, -.14744100E+01, -.98934400E+02, 0.34522800E+02, 0.44892500E+02, -.68297200E+02, 0.23632600E+02, -.92254600E+01, 0.26154100E+02, -.18240600E+03, -.56670000E+02, 0.29596800E+02, 0.17198300E+02, 0.27948700E+02, -.41815900E+02, -.40919400E+02, 0.96487300E+02, 0.73120600E+02, 0.43242300E+02, -.36942600E+02, -.56996500E+02, 0.21664600E+02, -.71531400E+01, -.13961800E+02, -.46695300E+01, -.30318600E+02, -.14420700E+02, -.17650000E+02, -.44948100E+01, 0.14537000E+02, 0.12448700E+02, -.34625400E+02, 0.73713500E+01, 0.26110700E+02, 0.62212900E+01, -.18273500E+02, -.43563000E+01, -.32907700E+02, -.71612800E+01, -.11326800E+02, 0.46866900E+02, -.34721400E+02, -.44864000E+01, 0.33246100E+02, -.13369200E+02, -.67318600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57267600E+00, 0.78741900E+00, 0.14743700E+01, -.72615600E+00, 0.25926200E+00, 0.11444700E+00, 0.90146300E+00, 0.11404100E+01, -.10064900E+01, -.50962400E+00, 0.77503100E-01, -.26081400E+01, 0.18198200E+01, 0.40719900E+00, 0.54491600E+00, 0.10322900E+01, 0.92824900E+00, -.10647700E+00, -.42472500E+00, 0.62031200E+00, 0.18706500E+00, -.20397400E-01, -.13370100E+00, -.21004400E+00, -.74930100E-02, -.28963300E-01, -.31570600E+00, -.13486200E+00, 0.24429000E+00, -.38338400E+00, -.47857100E+00, 0.26721900E-01, 0.58995900E-01, 0.26744000E+00, 0.34336400E+00, 0.48488200E-01, -.20628600E-02, 0.48850800E+00, -.22914000E+00, 0.77824600E+00, 0.41058200E+00, -.28243100E+00, -.52543400E+00, -.20000700E+00, 0.17816700E+00, 0.32386900E+00, -.50585300E-01, 0.16245600E-02, 0.28595900E+00, -.21537800E+00, -.32106200E+00, 0.95042000E+00, -.10798800E+00, 0.14248800E+00, -.53942800E-01, -.14614500E+00, 0.14480400E-01, 0.14278800E+01, -.30128400E-01, -.47690800E+00, -.10084100E+00, 0.19326900E+00, -.12679200E+00, -.12358900E+00, -.12509400E+01, 0.27953100E-01, -.15208800E+00, -.47004000E-01, 0.47574300E+00, 0.17942000E+00, -.15217900E+01, -.51633600E+00, -.34919100E+00, 0.26674900E+00, 0.14401300E-01, 0.34438400E+00, -.12458800E+00, -.11764200E+01, 0.44313500E-01, 0.29995700E-01, 0.15757400E-01, 0.92683400E-01, -.38280800E+00, -.82973200E+00, -.47177400E+00, -.16692100E+00, 0.10363800E+00, 0.37114400E-01, 0.90288900E-01, -.25579800E+00, 0.22065600E+00, -.49194200E-01, 0.24015400E+00, -.25952000E+00, 0.75716300E-01, -.76515900E-01, -.69238800E+00, -.10256800E+00, -.85702700E-01, 0.25943400E+00, 0.58261200E-01, -.78523000E-01, 0.48203800E-02, 0.25790400E+00, -.16254100E-01, 0.48809800E-01, -.14485100E+00, 0.62385500E+00, -.74679700E-01, -.18871600E+00, -.16657400E+00, 0.52091200E-01, -.32360100E-01, 0.78883600E-03, 0.16336900E+00, 0.17291700E+00, 0.12951600E+01, 0.47783000E+00, -.83808100E-02, -.18229200E+00, -.44741900E-01, -.45555100E+00, 0.46781400E+00, -.45091300E+00, -.54207100E-02, 0.20100600E+00, -.39340500E-02, -.15479300E-01, -.18720000E+00, 0.20787700E+00, -.12448900E+00, -.61176800E-04, -.58946300E-02, 0.10399300E+00, 0.41270000E+00, -.53600100E-02, -.29059100E+00, -.13599700E+00, -.11732600E+00, -.20438900E-01, 0.36554600E+00, 0.14604400E+00, -.34267200E-02, 0.11509800E+00, -.20720800E-01, 0.96379900E-01, 0.51065300E-02, -.58355700E-02, 0.23568600E+00, -.12239100E+00, -.60932300E-02, -.15522200E+00, 0.43279300E-01, -.11884800E+00, -.25011800E+00, 0.87600600E-02, -.15537800E+00, 0.90111300E-02, 0.73287900E-01, -.34965700E+00, -.90360600E-01, -.10498800E+00, -.14986500E+00, -.13073500E+00, 0.36937800E+00, -.17324200E+00, 0.51818900E+00, 0.28760800E+00, 0.19256900E-01, 0.10378300E+00, 0.73403800E-01, 0.94804200E+00, -.25493200E+00, -.75034600E+02, 0.16906800E+02, 0.12077900E+02, 0.16181700E+03, -.81720200E+02, -.71367300E+02, -.81048100E+02, 0.51024500E+02, 0.70413500E+02, -.35814100E+02, 0.89264900E+02, -.24605500E+02, 0.49854100E+02, 0.36987000E+02, -.39777100E+02, 0.20280000E+02, 0.66324200E+02, 0.19864800E+02, -.62290800E+02, 0.47968100E+01, 0.25747100E+02, -.26630300E+01, 0.15467300E+02, 0.86592000E+01, 0.11368100E+02, -.84277700E+02, 0.43366900E+02, 0.21489200E+02, 0.41533500E+02, 0.68091000E+02, 0.12577900E+02, 0.79971200E+01, -.52813900E+02, -.29543700E+02, 0.18795800E+02, 0.31875500E+00, -.79412900E+02, 0.40038400E+02, 0.53503400E+02, 0.39844800E+02, 0.52242200E+02, 0.38546000E+02, -.82082100E+01, -.21669600E+02, 0.59529800E+02, 0.20851500E+02, 0.26613900E+02, 0.17369300E+02, -.98025500E+01, 0.24011500E+02, -.87369800E+01, 0.16784400E+02, 0.10752600E+02, -.34363000E+01, 0.25631900E+01, -.17369900E+02, 0.10581900E+02, 0.53740900E+02, -.24687700E+03, 0.12249500E+03, 0.10172500E+03, 0.12306400E+03, -.22460600E+02, -.88643600E+02, 0.75323800E+02, -.10406100E+02, 0.11423200E+03, -.74483900E+02, 0.10235900E+03, 0.82453000E+02, -.41245400E+02, -.38662000E+02, -.41114100E+02, -.46378200E+02, -.58727100E+02, -.93754800E+00, 0.40874300E+02, 0.21349500E+02, -.63149900E+02, -.48697400E+02, 0.22818500E+02, -.10267600E+02, -.59790500E+00, -.11671600E+02, 0.45147600E+02, 0.19595300E+02, 0.78340200E+01, 0.31753700E+02, 0.14200800E+02, 0.17223400E+02, -.26632100E+02, 0.67043000E+01, 0.48592800E+01, 0.13056000E+02, 0.14265000E+02, -.10450600E+02, 0.13536100E+02, 0.12808300E+02, 0.14122200E+02, -.12944100E+02, 0.45695800E+01, 0.91551500E+01, -.13778600E+02, 0.12210600E+02, -.14879800E+02, 0.24706300E+01, 0.13871700E+02, 0.11050300E+02, -.15874500E+02, 0.33009900E+01, 0.17943000E+02, 0.27647700E+01, 0.10644300E+02, 0.73706500E+01, -.48621700E+01, -.42762600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.28941800E+01, -.45354800E+00, 0.62609500E+01, -.14532100E+01, 0.37620500E+01, 0.37985300E+00, 0.30585800E+01, 0.55176700E+01, -.38961100E+01, -.89056500E+00, -.37078500E+00, -.90012200E+00, 0.46695700E+01, 0.12324400E+00, 0.75592800E+01, 0.43354100E+00, 0.13707700E+01, -.11347200E+01, 0.22292100E+00, -.39460400E+00, 0.73966000E+01, 0.12699000E+00, -.26675200E+01, -.36292800E+00, -.16504500E+01, -.13595300E-01, -.29240500E+01, -.45377100E+00, -.63603100E+00, 0.52264100E-01, -.43147000E+00, -.54300000E+00, 0.24513400E+00, -.47279100E-01, -.67218900E+00, 0.40377800E+00, -.97029400E-01, -.43313700E+00, -.64512300E+00, 0.16163800E+00, -.26961100E+01, -.16579000E+01, 0.17044300E+01, -.33505400E+00, 0.12745100E+00, 0.27039800E+00, 0.28087900E+00, -.21623500E-01, 0.81646300E+00, -.39865600E+00, 0.62606800E+00, 0.75044800E+00, 0.29458300E+00, 0.13164700E+01, 0.63189300E-01, -.49617600E+00, 0.14899900E+01, -.53491600E+00, 0.18945200E-01, -.67412600E+00, 0.35965600E+00, 0.89965600E+00, 0.14919800E+00, -.39795700E+00, -.10810300E+01, -.20810800E+00, 0.51574300E-01, 0.10880400E+00, 0.17260900E+01, 0.14585400E-01, 0.34079800E+01, 0.98393700E+00, 0.28375600E+00, 0.56301700E-02, -.68479000E+00, 0.47111000E+00, 0.22587500E+00, -.16244500E+01, 0.63166400E+00, 0.88591300E+00, 0.10125300E+00, 0.95421300E+00, 0.14348200E+01, 0.18367700E+01, 0.28106900E+01, -.59897700E+00, 0.22311800E+00, -.17142500E+00, -.94041200E+00, 0.93570600E+00, -.19042800E+00, -.87044500E-01, 0.16135100E+00, 0.68436000E+00, 0.14191000E+01, 0.55261500E+00, 0.28681100E+01, 0.31597000E+00, 0.40762900E+00, -.35112700E+01, -.29015300E+00, 0.86475700E-02, -.47372600E-01, -.27636400E+01, -.99391800E+00, -.67500000E-01, 0.10333100E+01, -.19732600E+01, 0.90694200E-02, 0.51448700E+00, 0.88697400E+01, 0.30579700E+00, -.11819700E+01, -.90756400E-02, -.67186600E+00, 0.50654300E-01, 0.45256600E+01, 0.47225400E-02, -.18201700E+01, -.16254500E+01, 0.69627800E+00, -.94218800E+00, 0.17573300E+00, 0.70805800E+00, -.52422400E-01, 0.11903400E+01, 0.11994700E+01, 0.28964800E-01, 0.27689600E+01, -.34525100E+00, -.22983000E+01, 0.10735500E+00, -.43291500E-01, 0.11543200E+01, 0.78934300E+00, -.74256000E-01, -.15631400E+01, -.10321700E+00, -.72893000E-01, -.82386300E-02, 0.92463600E+00, 0.16800800E-01, 0.41276100E-01, -.37053300E+00, 0.63824100E-01, 0.72546900E+00, -.41263500E-01, 0.89394600E-01, -.98574700E+00, -.93153900E+00, 0.38136500E-02, 0.43408100E+00, -.80473600E+00, 0.52644300E+00, -.11936500E+01, -.87123900E-01, -.24897100E+01, -.16962600E-01, -.12434000E+01, -.50649300E+00, -.12093100E+00, 0.29015000E+01, -.24553900E+01, 0.45072300E+00, -.10322300E+01, 0.78184800E-01, -.22843300E+01, -.45426400E+00, -.31531700E+00, -.17506600E+00, -.12688800E+01, -.41922500E+01, -.15211500E+01, -.10137500E+01, 0.75049400E+02, 0.64302800E+03, -.82283900E+03, 0.40932900E+03, 0.32228200E+03, 0.41111300E+03, -.41357800E+03, 0.16016200E+03, -.32257900E+03, -.52165500E+03, 0.48665900E+03, 0.23475500E+03, 0.14669800E+04, -.23178200E+04, 0.11577100E+04, 0.91174300E+03, 0.11591100E+04, 0.10852000E+03, -.49821700E+03, 0.87568700E+03, 0.34927000E+02, 0.96691800E+03, -.35121900E+03, 0.38929300E+03, 0.34774400E+03, -.17092400E+03, -.11703400E+04, -.17397700E+03, -.21313200E+03, -.57599300E+03, 0.56098800E+03, 0.21965400E+03, 0.39606800E+03, -.56206100E+03, -.20735800E+03, -.96813900E+03, 0.48797800E+03, 0.45746200E+03, 0.48418100E+03, 0.11810000E+03, -.15825600E+02, 0.20477700E+03, -.79895200E+02, 0.70786900E+03, -.91328000E+02, 0.14946500E+03, 0.32914400E+03, -.16848100E+03, 0.64234400E+02, -.16460700E+03, -.21695300E+03, 0.22689500E+03, -.35234900E+03, -.30715600E+03, -.43588500E+03, 0.26102300E+03, 0.31117100E+03, -.18082300E+04, 0.90210500E+03, 0.98896500E+03, 0.90369000E+03, 0.69552500E+01, -.24255700E+03, 0.60594600E+03, -.19975400E+02, 0.96217300E+03, -.22412500E+03, 0.39924700E+03, 0.82826700E+02, -.41794600E+02, 0.15147800E+03, -.39832600E+02, 0.44146800E+03, 0.30766600E+03, -.21223900E+03, -.11095300E+03, 0.18535900E+03, 0.26103100E+03, -.79549600E+03, -.20735900E+03, 0.10709800E+03, 0.72414100E+01, 0.10357500E+03, -.26848400E+03, -.30135200E+02, 0.28098800E+03, -.13682500E+03, -.16879000E+03, 0.92705900E+02, 0.35489200E+03, 0.46495000E+02, -.69386500E+01, -.65706500E+02, -.49064500E+02, -.11591100E+03, -.57559100E+02, -.62160100E+02, -.47121400E+02, 0.66841300E+02, 0.33803100E+02, -.66238100E+02, 0.51369700E+02, 0.39877000E+02, 0.48180600E+02, -.60971800E+02, -.45255400E+02, -.61197900E+02, -.12503400E+03, 0.15204500E+02, 0.13607500E+03, -.63397800E+02, 0.86718400E+02, 0.14235600E+03, 0.37309600E+02, -.63131200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14691700E+01, 0.57486100E+00, 0.10673500E+01, -.29172900E+01, 0.10295000E+01, 0.43262700E+00, 0.20210200E+01, 0.11519100E+01, -.58249900E+01, -.15857500E+01, -.11931300E+00, 0.22322500E+01, -.25483500E+01, -.13083400E+01, 0.31195500E+00, -.24128000E+01, -.12310600E+01, 0.11501900E+01, 0.50383700E+00, 0.57820300E+00, -.10001300E+01, -.72428700E-01, -.10429200E+00, 0.95026200E+00, 0.24882700E-01, 0.26574700E-01, 0.62120900E+00, -.12389000E+00, 0.66514100E+00, -.57324400E+00, 0.71183100E+00, -.14814400E+01, -.23710900E+00, 0.10522800E+01, -.11341600E+01, -.11825500E+01, -.39498000E-01, -.36448600E+00, 0.30742500E+00, -.56104300E-01, 0.16791300E+00, 0.37356100E+00, 0.26563200E+00, 0.24956600E+00, -.70485800E+00, -.56326100E+00, -.20433700E+00, -.11364900E-02, 0.12192700E+00, -.55799500E-01, 0.12337800E+00, -.52615900E-01, 0.63599700E-01, -.59481900E-01, -.55866900E-01, -.28081200E-01, -.35130500E-03, -.11267100E+01, 0.14369400E-01, 0.88297600E-01, -.70207700E-02, -.17960200E+00, 0.17450000E+00, -.65090900E+00, 0.12211000E+01, -.21460000E-01, -.38999400E-01, -.97288000E+00, -.59427400E+00, -.95646100E-02, 0.58091800E+00, -.64870900E-01, 0.24165300E+00, 0.11769900E+00, 0.13143800E+00, -.42516200E+00, -.30268500E-01, 0.33047200E+00, 0.68814500E-02, -.12361200E-01, 0.61320100E-02, -.17779200E+00, 0.33672900E+00, 0.95187900E+00, 0.12136800E+00, -.17086300E+00, 0.12699800E+00, 0.10847900E+00, -.99054900E-01, 0.66747300E-01, 0.53679700E+00, -.10092800E-01, 0.33116300E+00, -.54582400E-01, 0.15632000E-01, -.11208300E+00, -.61357000E+00, -.13441900E-01, 0.52645800E-01, -.46136900E+00, -.21258600E+00, -.35261100E+00, 0.62315600E-02, -.19534600E+00, 0.22007100E+00, -.22284900E+00, -.10458700E+00, -.47525900E+00, 0.59932200E+00, -.21962600E+00, -.13460600E+01, -.15724600E-01, 0.10256300E+00, -.36737700E-03, 0.58749600E-01, -.39126500E-01, -.11319200E+01, -.10747000E+01, 0.65566700E+00, 0.23192300E+00, -.77659500E-02, -.23842600E+01, -.39926200E+01, 0.10284300E+01, 0.73775700E-02, -.83163400E+00, 0.41693100E+00, 0.38861300E+00, 0.35183700E+00, 0.40920400E-01, -.69334400E+00, 0.13765300E+00, 0.21674900E+00, -.18810600E+00, -.47308100E+00, 0.44149400E-02, 0.19537900E+00, 0.45274600E+00, -.68708800E+00, 0.10137400E+00, 0.13903200E+01, -.61254600E+00, 0.16969900E+00, 0.66582700E+00, -.27478500E+00, -.27266500E+00, 0.86338800E-02, 0.86538500E-01, 0.14117600E+01, 0.50616000E+00, 0.34084000E+00, -.60055200E-01, 0.24395300E+00, -.34723800E+00, 0.36015600E+00, 0.76145000E-01, -.71497600E+00, 0.10827000E+00, 0.31294300E+00, 0.94522100E+00, -.91346100E-01, 0.86274400E-01, 0.11428900E+01, 0.29219900E+00, -.63443000E+00, 0.17745700E+00, -.74908100E+00, -.79043200E+00, -.21399600E-01, -.13927700E+00, 0.16291000E+00, 0.51855100E-01, 0.91726300E-01, -.65284200E+00, 0.22255800E+00, -.37289200E+03, 0.14665500E+03, -.73470800E+02, -.27705900E+02, -.73110500E+02, 0.26042500E+03, -.45391500E+02, 0.15074600E+03, 0.31294400E+03, -.89757000E+02, -.45994300E+02, -.20658200E+03, 0.62466300E+02, -.30505600E+02, -.45893700E+02, -.31176300E+02, 0.99669600E+01, 0.12894400E+03, -.13311500E+03, -.70891500E+02, -.70081200E+02, 0.14563700E+03, 0.99475700E+01, -.28523100E+03, 0.14309800E+03, 0.39629800E+03, 0.14357400E+03, 0.10202600E+03, 0.21217100E+03, -.19712600E+03, -.21673800E+03, -.14958400E+03, 0.21469200E+03, 0.97092800E+02, 0.54829300E+03, -.27510500E+03, -.22133200E+03, -.27436300E+03, 0.91872500E+01, 0.16496500E+02, -.87342300E+02, 0.12357900E+03, -.22959300E+03, 0.22171700E+02, -.11618100E+03, 0.12716600E+03, -.62882900E+02, 0.35095300E+02, -.63510400E+02, 0.86203000E+02, 0.34898400E+02, 0.26504000E+02, 0.10581300E+03, -.19149100E+02, 0.31421600E+02, -.20267400E+03, 0.40606300E+03, -.20336200E+03, -.11397500E+03, -.20243300E+03, -.78359600E+02, -.34934300E+02, -.76221900E+02, 0.23883800E+02, -.25931900E+03, 0.36573400E+02, -.30870000E+02, -.89420400E+02, 0.44615400E+02, -.56050600E+02, 0.44630400E+02, -.19751600E+03, -.16286600E+03, 0.12451300E+03, 0.27417900E+02, -.59379200E+02, -.14804600E+03, 0.30829500E+03, 0.25722600E+03, -.12899500E+03, 0.19705300E+02, -.12824900E+03, 0.10503300E+03, 0.19151300E+02, -.10499000E+03, 0.15264400E+03, -.50270500E+01, -.39103000E+02, -.28481700E+03, -.42973000E+02, 0.12070400E+02, 0.32565800E+02, 0.32553000E+02, -.21154900E+02, 0.22398000E+02, 0.23716800E+02, 0.32286900E+02, -.32240700E+02, -.29102200E+02, 0.15966500E+02, -.27782700E+02, -.20185400E+02, -.28280900E+02, 0.30869100E+02, 0.31388200E+02, 0.10549000E+02, 0.31131100E+02, 0.17846700E+02, -.38773600E+02, 0.30102500E+02, -.32839200E+02, -.23404500E+02, -.57956600E+01, 0.59076200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24692800E+01, 0.87717300E+00, 0.34218000E+00, 0.23163500E+01, 0.33671900E+00, -.25058400E-01, -.18247900E+01, -.72839800E+00, 0.26979300E+01, 0.47971100E+00, 0.23581000E+00, -.23107700E+01, 0.33165900E+01, 0.17685700E+01, 0.97607000E+00, 0.25073800E+01, 0.25674300E+00, -.14262500E+01, 0.82291300E+00, -.18235100E+01, -.59850500E+00, -.76468000E-01, 0.41416300E+00, -.16058100E+01, -.12493900E+00, -.79244500E-01, -.32346800E+01, -.49924600E+00, -.39550300E+00, 0.10968100E+01, -.35945100E+00, -.89362200E+00, 0.23632900E+00, -.25697500E+00, 0.68823600E+00, 0.12670600E+01, 0.20725200E-02, 0.27919100E+01, -.14340700E+01, -.49356500E+00, -.10013300E+01, -.10572100E+01, 0.69100100E+00, 0.10407200E+00, -.25988700E+00, -.51630000E+00, -.51688900E+00, -.44770500E-02, -.42779300E+00, 0.76319400E-01, 0.11878200E+01, 0.42084600E+00, 0.30183800E+00, 0.43892200E+00, 0.21426000E+00, 0.89163500E-01, 0.45709800E+00, -.15941800E+01, 0.14237400E+00, -.85270400E-01, -.80234800E-01, 0.83812800E+00, -.21018600E+00, -.23448100E+01, 0.69582200E+00, -.34232200E+00, 0.16041800E+00, -.16782200E-01, -.32611600E+00, -.60634200E-01, -.25951000E+01, 0.15602000E+00, -.12781300E+01, -.63439600E+00, -.23464500E+00, 0.17658300E+01, -.68714800E-02, 0.70868800E+00, 0.30420600E+00, 0.29791700E+00, 0.15339100E+00, -.95943000E+00, -.67648800E-01, -.47635100E+01, 0.55725900E+00, -.70069800E+00, 0.21027400E+00, -.63786100E+00, -.34183000E+00, -.57862600E+00, 0.64884700E+00, 0.29905200E-01, 0.82104500E+00, -.96634700E+00, -.10059300E+01, 0.84909700E+00, 0.22321400E+01, 0.21838000E+01, 0.48717900E+00, -.20347300E+00, -.26978400E+00, -.23384200E+00, -.11354400E-01, 0.34500000E+01, -.11169300E+00, 0.69600200E+00, -.13904000E+00, 0.17926300E+01, 0.69188600E+00, 0.26631800E-01, -.21994000E+01, -.22708800E+00, 0.17564500E+00, 0.41509200E+00, -.25458500E-01, -.41622700E+00, 0.15361400E+01, -.25882900E+00, 0.98704300E+00, 0.26058200E+00, -.20801300E+01, 0.21549300E+01, -.59439600E+00, -.11986300E+01, 0.48901200E-01, -.63693400E+00, 0.60650500E+00, 0.15222900E+00, -.20423200E+01, -.48341800E+00, 0.58838500E+00, -.21148300E+00, -.35542100E+00, 0.36963200E+00, -.79942100E-01, 0.10349100E+00, 0.47537700E+00, -.47262500E+00, 0.18719100E+00, -.21773200E+00, -.16893300E+00, 0.42169000E+00, -.11874400E+00, 0.18131600E+00, 0.36558100E+00, -.83948100E-01, 0.37440100E-01, -.95273900E-02, -.65109900E+00, 0.49068000E-01, 0.96267300E-01, 0.57116800E-01, 0.93445600E-01, -.50126400E+00, -.14673700E+01, 0.67260100E-01, -.11028600E+01, -.15602500E+00, -.17243300E+00, -.25769800E+00, -.43639300E+00, 0.10841100E+01, -.22160000E+00, -.21018300E+00, 0.82410200E+00, 0.16591800E-01, 0.10595300E+01, -.50175300E+00, -.40403900E-01, -.80545400E+00, 0.43015700E+00, -.26926100E+01, -.58477100E+00, -.28731000E+00, -.13219200E+00, 0.14607800E+01, -.10464500E+04, 0.52287100E+03, 0.60319900E+03, 0.52350000E+03, -.49087300E+03, -.10003600E+03, -.23052800E+03, -.47257000E+03, 0.41976700E+03, -.10726800E+03, 0.27837900E+03, -.21755800E+04, 0.10851800E+04, 0.90218000E+03, 0.10880300E+04, 0.31536300E+03, -.17088600E+03, 0.56094300E+03, -.11241200E+03, 0.88043400E+03, -.88571000E+02, 0.55623800E+03, 0.42612100E+03, -.21318700E+03, -.72777700E+03, -.21017900E+03, -.18151900E+03, -.33956800E+03, 0.35462300E+03, 0.37901900E+03, 0.30865300E+03, -.35414200E+03, -.25516000E+00, -.44204800E+03, 0.22372400E+03, 0.59991000E+02, 0.22047300E+03, -.13593300E+03, -.71868900E+02, 0.61155900E+02, -.16442600E+03, 0.35973700E+03, -.42367300E+02, 0.30497800E+03, 0.38753900E+03, -.19965100E+03, -.27235000E+02, -.19348700E+03, -.25277400E+03, 0.11080000E+03, -.47417500E+03, -.27579900E+03, -.44922900E+03, 0.65379900E+02, 0.26261200E+03, -.19662900E+04, 0.98349700E+03, 0.92814200E+03, 0.98435800E+03, 0.19475700E+03, 0.38814400E+03, 0.21447700E+03, -.20166700E+03, 0.79593100E+03, 0.36586900E+03, 0.70901000E+03, -.49329900E+03, 0.24604200E+03, 0.31204900E+03, 0.24751700E+03, 0.42694800E+03, 0.38044300E+03, -.10845800E+03, -.40049500E+03, -.57289100E+02, 0.40538200E+03, -.35270800E+03, -.96268800E+02, 0.47292200E+02, -.92275100E+02, 0.49674500E+02, -.33624100E+03, -.23339900E+03, 0.10687900E+03, -.59112900E+02, -.25352200E+03, -.26204800E+03, 0.51330300E+03, 0.47997700E+01, -.34554400E+02, -.12764500E+03, -.87056500E+02, -.92641100E+02, -.52787100E+02, -.67043400E+02, -.84622000E+02, 0.12978500E+03, 0.10595600E+02, -.90107400E+02, 0.89287000E+02, 0.35072400E+02, 0.92210600E+02, -.16355700E+03, -.81683900E+02, -.83983400E+02, -.52450900E+02, -.12894100E+03, 0.62437700E+02, -.80036500E+02, 0.13534000E+02, 0.15254600E+03, 0.33027200E+02, 0.34360700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16565400E+01, 0.28933100E+01, 0.16955200E+01, -.27764000E+01, 0.46783000E+01, 0.12042400E+01, -.19357500E+00, 0.70602400E+00, 0.28393500E+00, -.43944800E-01, -.22512300E-01, -.21117400E+01, 0.28051000E+01, -.72827200E+00, 0.14427600E+01, -.10078400E+00, 0.71907000E+00, -.83572500E+00, 0.48028500E-01, -.92921800E+00, 0.30797000E+01, 0.33630300E-01, -.87281700E+00, -.29781500E+00, 0.37552300E-01, -.92155100E-01, 0.55832500E-01, 0.27515100E+00, 0.47237000E+00, 0.20406300E+00, -.42335700E+00, -.50878000E+00, 0.17525200E+00, -.21716600E+00, 0.94059400E+00, -.67520100E-01, 0.20315300E-01, 0.14467800E+01, -.82562100E-01, 0.50637100E+00, -.52002700E+00, 0.28770600E-01, -.38858900E+00, -.20122100E+00, 0.16041400E+00, 0.37729300E+00, -.10039700E+00, 0.36541500E-02, -.87794200E+00, 0.46753700E+00, -.56047100E-01, 0.43759500E+00, 0.28097400E-01, 0.18049700E+00, -.33681300E+00, -.24099500E+00, -.29715900E+00, -.12147600E+01, -.22092100E-01, 0.26544800E+00, -.14844200E+00, 0.42891600E-01, -.67310900E-01, 0.87857800E+00, -.71571400E+00, -.72139800E-01, 0.39180800E-01, 0.64543400E+00, -.39839100E-01, 0.97698400E-01, -.11294900E+01, 0.21546800E+00, -.53298000E-01, 0.17300500E+00, 0.23919100E+00, -.55678300E+00, -.27785000E-01, 0.44004500E+00, -.10044200E+00, 0.91643600E-02, -.33448100E-01, 0.24796600E+00, -.11156000E+00, -.17218200E+00, 0.18062000E+00, 0.17330500E+00, 0.39938700E-01, -.25811800E-01, -.27823400E+00, 0.12864700E+00, -.99296900E+00, 0.32414800E-02, -.50364300E+00, 0.17687100E+00, 0.99708800E-01, 0.20999200E+00, -.47016900E+00, 0.61580300E+00, -.13255700E+00, -.36585400E-01, -.14662000E+00, -.88510000E-01, 0.14772400E-02, -.97742100E+00, 0.21435800E+00, -.26820100E+00, -.71601100E-01, -.18274800E+00, 0.32704000E-01, 0.13279000E+00, -.27304600E+00, 0.88274400E-01, -.34300400E-01, -.30038200E-02, -.61601700E-01, -.88245400E-01, 0.66069900E-01, -.50687200E+00, 0.48724200E+00, 0.72697700E-01, -.63037600E+00, 0.85938100E+00, 0.49670800E+00, -.53254700E+00, -.14236700E-01, 0.39868200E+00, -.21012500E-01, -.58901000E-01, 0.59024200E+00, 0.86582900E-01, -.68599100E-01, 0.87426100E-01, 0.15016000E-02, 0.41740600E+00, -.27695500E+00, 0.84860400E-02, 0.93997200E+00, 0.12587100E-01, -.73606700E-01, 0.81941000E-01, 0.19304200E+01, 0.15281200E+00, -.22337000E+00, 0.47847700E-01, 0.21245700E+00, 0.20129300E+00, 0.40129300E-02, -.11834800E+00, 0.37311400E+00, -.41130700E-01, 0.44676000E+00, 0.13997700E+00, -.68824300E-02, -.11115500E+00, -.65435800E-01, -.85068700E-01, 0.68230900E+00, 0.23213100E-01, 0.45926200E-01, -.66414400E-01, 0.14908700E-01, -.19679900E+00, 0.88252900E+00, 0.58788100E-01, -.12949400E+00, 0.10172200E+00, 0.63404300E+00, 0.85785600E+00, 0.73499500E-02, -.15348500E-01, 0.70274400E-01, 0.77875300E+00, -.47470800E-01, 0.11664500E+01, -.17134800E+00, -.64378500E+00, 0.83116200E-02, 0.53452200E+01, -.17863100E+02, -.57565500E-01, 0.85285700E+02, -.31111300E+02, -.67645100E+01, -.67102600E+02, -.94080400E+02, -.23194300E+02, 0.16885300E+03, 0.72089600E+02, -.36797200E+02, -.99700600E+02, -.36067300E+02, 0.51558400E+02, 0.59078600E+02, -.81167500E+02, -.34357300E+02, -.43718700E+02, 0.65065800E+02, -.33909800E+01, -.15403000E+03, 0.75212800E+02, 0.15407500E+03, 0.76572000E+02, 0.39809900E+02, 0.11116600E+03, -.10547000E+03, -.13324000E+03, -.56717900E+02, 0.95585000E+02, 0.43500700E+02, 0.42063300E+02, -.21432000E+02, 0.11408900E+02, -.20942000E+02, -.13224300E+02, -.25115200E+01, 0.27040600E+01, 0.13345700E+01, -.60847700E+02, -.72532500E+00, -.43438800E+02, 0.23868500E+03, -.12272900E+03, -.28244400E+02, -.11938900E+03, 0.58723400E+02, 0.89097300E+02, -.40569900E+02, 0.51708500E+02, -.82600500E+02, 0.76050600E+02, -.18001100E+03, 0.27391300E+03, -.13526600E+03, -.67224600E+02, -.13716000E+03, 0.55450300E+02, 0.11127600E+03, -.87277800E+02, -.43188900E+02, -.17969800E+03, 0.13823600E+03, -.11573600E+03, -.74419100E+02, 0.37011800E+02, -.11844000E+02, 0.37176100E+02, -.42019500E+02, -.23271500E+02, 0.50875700E+02, 0.17017000E+01, -.12756900E+01, -.27867000E+02, 0.95078300E+02, 0.17506600E+03, -.91583200E+02, 0.81065400E+00, -.87785100E+02, 0.23982300E+02, 0.19222200E+01, -.32746700E+02, 0.37312600E+02, -.49867400E+02, -.13610200E+02, -.67496200E+02, -.35499200E+02, 0.82835600E+01, -.13477800E+00, 0.80915200E+01, 0.14521100E+02, 0.12190200E+02, 0.13249700E+02, 0.81614200E+01, -.33518000E-01, -.20937700E+02, 0.17450800E+02, -.75635000E+01, -.26082700E+02, -.73945700E+01, 0.24953100E+02, 0.81273500E+01, 0.16358500E+02, 0.10943500E+02, 0.18014800E+02, -.31270900E+02, 0.19354700E+02, -.14738400E+02, -.33766500E+02, 0.76832600E+01, 0.29125600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.60378700E+00, -.11080600E+00, -.74115100E+00, -.45896600E+00, 0.40674800E+00, 0.17439100E+00, -.25491700E+00, -.22084400E+00, -.12040800E-01, 0.14657200E+00, -.67318700E-03, 0.18862600E+01, -.29388100E+00, -.26860300E+00, 0.43853800E+00, -.10985600E+01, -.11731500E+01, -.25777200E+00, 0.29027700E+00, -.64651700E+00, -.47739500E+00, -.54630500E-01, 0.38285600E+00, -.82601200E+00, 0.46964400E-01, 0.64448500E-02, -.35986000E-01, 0.35377700E-01, -.77046500E-01, -.26030500E+00, -.41771000E-01, -.93593900E-01, 0.11548700E+00, 0.21780000E+00, -.89933500E-01, -.42609200E+00, -.14936400E-01, -.34381400E-01, -.49425800E+00, 0.15946200E+00, 0.20594400E+00, 0.21285700E+00, 0.30472200E+00, -.36823000E-02, -.23682800E+00, 0.10208800E+00, -.10310700E+00, -.56339300E-02, 0.38784900E-01, -.15640200E+00, -.15865400E+00, -.29143400E+00, 0.41932300E-01, -.11209300E+00, 0.79814700E-02, 0.35803700E-01, 0.21817500E+00, 0.58037100E+00, 0.11416200E-01, 0.34326700E-01, 0.11833100E+00, 0.15037700E+00, -.24739700E-01, -.99636000E+00, 0.14794000E+01, -.61864500E-01, 0.10259500E+00, -.36878200E+00, -.44884400E+00, 0.66966800E-01, -.29158300E+00, 0.44358200E+00, -.72313300E-01, 0.14033200E+00, -.92901200E-01, -.16935400E+00, -.33260800E-01, -.32696500E-01, -.24267800E-02, -.39577300E-01, -.18570200E-01, 0.30469000E+00, 0.59945100E-01, 0.62192300E+00, 0.47221900E+00, -.11495100E+00, 0.11485600E+00, 0.25318600E+00, -.74904000E-01, -.21831200E+00, 0.76178200E-02, -.40039200E-01, -.37884300E-01, -.24733700E+00, -.58072500E+00, 0.17873000E-01, -.95866300E-01, 0.10201400E+00, 0.17285600E+00, 0.34161200E+00, 0.20324000E-01, 0.14366700E+00, -.17291600E-02, 0.10590300E+00, -.31194400E+00, -.11701300E+00, 0.22268900E-01, 0.49296200E+00, -.59833800E-01, 0.86827600E-02, -.23158000E+00, -.80043600E-01, 0.11886900E+00, 0.13410800E-02, -.59473200E-01, -.77784000E-01, 0.13383900E+00, 0.22457100E+00, -.90875000E-01, 0.59037200E-01, -.53193000E-01, 0.44101300E+00, -.17634000E-01, 0.31709700E+00, -.77744500E-02, -.88118800E-01, 0.18837600E+00, 0.43106000E-01, 0.12194200E+00, -.16605800E+00, -.23979300E+00, 0.11563600E-01, -.21157200E+00, 0.24775000E-01, -.48339500E-01, -.11037200E-01, 0.59868500E+00, 0.73046400E-01, -.13689100E+00, -.46324700E-01, 0.43946300E+00, 0.67169700E-01, 0.30922700E-01, -.32957200E-01, 0.12466600E+00, 0.30546700E-01, -.35200400E-02, -.50152000E-01, -.12539900E+00, -.82157200E-01, -.51253400E-01, -.17112800E+00, 0.60476700E-02, -.34426000E-01, 0.21315400E+00, -.15985900E-01, -.20243200E-02, 0.43389300E-01, -.10415100E+00, 0.86021900E-01, 0.57031400E-01, 0.15489400E+00, -.32468900E+00, -.80753300E-01, 0.62131900E-01, 0.75180200E-01, 0.37680800E+00, -.13102600E-01, -.44189600E-01, 0.44102900E-01, -.10244400E+00, -.40985300E+00, -.25455800E+00, -.12157300E+00, -.17029800E+00, -.26404200E+00, 0.72091800E-02, -.84967000E-01, 0.72989600E+02, -.57590900E-01, -.61671700E+02, 0.75158300E+02, -.72086900E+02, 0.30209200E+02, 0.16921900E+02, 0.86047600E+02, 0.21506900E+03, -.61819100E+03, 0.30890100E+03, 0.28276100E+03, 0.30916800E+03, 0.36051400E+02, -.83045000E+02, 0.16666900E+03, -.32767300E+02, 0.24438500E+03, -.49960400E+02, 0.16639000E+03, -.13962400E+03, 0.70543200E+02, -.67671700E+02, 0.69782000E+02, 0.62354000E+02, 0.18952300E+02, 0.31573900E+02, -.90445500E+02, 0.19579000E+02, 0.14710100E+02, 0.17136900E+02, -.55278100E+02, 0.28901300E+02, 0.91446800E+01, 0.27663800E+02, 0.42288100E+02, 0.70207500E+01, 0.33232300E+02, 0.42992700E+02, 0.93320400E+02, 0.72814000E+01, 0.27198700E+02, 0.21326100E+03, -.10822700E+03, -.45398700E+02, -.10665500E+03, -.30927600E+02, 0.89304000E+02, -.13169700E+03, -.65930000E+02, -.18347900E+03, 0.94849600E+02, 0.79234600E+02, -.33060400E+03, 0.16498100E+03, 0.22471800E+03, 0.16524000E+03, -.28623100E+02, -.38257700E+02, 0.10243100E+03, -.21464900E+02, 0.16933900E+03, -.25616000E+02, 0.24361700E+03, -.10525800E+03, 0.52320500E+02, 0.45450500E+02, 0.53100300E+02, 0.55813800E+02, 0.21067700E+02, -.58650500E+01, -.67446900E+02, 0.22516100E+02, 0.28661200E+02, -.89678900E+02, 0.13945700E+02, -.73251600E+01, 0.23122500E+02, -.70874800E+01, -.10678500E+02, -.24870700E+01, 0.56719600E+02, 0.50941700E+02, -.69992400E+02, -.15290700E+02, -.11111000E+02, -.52067500E+01, 0.56558000E+01, -.53493500E+01, -.26659800E+01, -.26003200E+02, 0.17020300E+01, -.33196500E-01, -.23213700E+01, 0.59933500E+01, -.47454900E+00, -.84758500E+01, 0.49095800E+01, 0.12074900E+02, 0.39582800E+01, -.61876500E+01, -.21189100E+01, -.70206600E+01, -.33426600E+02, 0.36018500E+01, 0.24100200E+02, -.19431200E+01, 0.12075100E+02, 0.32372800E+02, 0.17687800E+02, 0.16148300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.17100500E+01, -.10700500E+01, -.25873100E+01, -.24751800E+01, -.25206700E+01, -.57752300E-02, 0.19407600E+01, 0.18204700E+01, 0.21934200E+00, -.42081800E+00, -.27854100E+00, -.34856300E+01, 0.15770400E+01, -.11966700E+01, 0.20232100E+01, 0.10716600E+01, 0.13251600E+01, -.43528100E+00, -.29156600E+00, 0.63366400E+00, 0.23148500E+01, 0.76995000E-01, -.56768900E+00, 0.20485900E+01, 0.48217100E-01, -.21494700E+00, 0.13739100E+00, 0.18614800E+00, 0.28485400E+00, 0.26839700E+00, -.38055100E+00, -.21274000E+00, 0.38553900E+00, -.62545400E+00, 0.32116500E+00, 0.11008500E+01, 0.53354700E-01, 0.52014000E+00, -.64243900E-02, 0.57776500E+00, -.95766100E+00, -.38770400E+00, 0.57308300E-01, -.18112700E+00, 0.65698900E+00, 0.21683400E+00, -.23057700E+00, 0.10352900E-01, -.80840200E+00, 0.93158100E+00, 0.15496300E+01, 0.19147500E+01, 0.77763600E-01, 0.33105300E+00, -.10038200E+00, -.26189800E+00, -.86195500E+00, -.26872000E+01, -.22486100E-01, 0.39142000E-01, -.15966900E+00, 0.99693100E-01, 0.85615400E-02, 0.23910500E+01, -.16867900E+01, -.13924300E+00, 0.17393100E+00, 0.20908300E+01, 0.63394700E+00, 0.15535500E+00, 0.59153600E-01, -.77318900E-01, 0.72015400E+00, 0.36365100E+00, 0.68678500E+00, -.13963600E+01, -.15289600E-01, 0.12482000E+01, -.27319900E+00, 0.15072700E+00, -.95099300E-01, -.68143600E-01, -.10792000E+00, -.97804800E+00, -.75796900E+00, 0.11899100E+00, -.19999600E+00, -.49292700E+00, -.11783300E+00, 0.42104700E+00, -.13224100E+01, -.11539700E-02, -.10872900E+01, 0.76365300E+00, 0.38764900E+00, 0.21515900E+00, -.15152100E+01, -.22223000E+00, -.67603600E+00, -.63433200E+00, -.64778500E-03, -.19026900E+00, 0.97826300E-03, -.29107100E+01, 0.67226700E+00, -.43648700E+00, -.12855400E+00, -.16694900E+01, -.20735800E+00, 0.14433200E-02, 0.14841600E+01, 0.17978400E+00, -.32901400E+00, -.17544900E-02, 0.55030700E-01, 0.21943800E+00, 0.71143500E+00, -.35620500E+00, 0.10166300E+01, -.11899700E+00, -.41929300E+00, -.12234400E+01, -.44299900E+00, -.63068000E+00, -.28895900E-02, -.25838100E+00, -.56273300E+00, -.19468600E-01, 0.95302000E+00, 0.25698100E+00, 0.89816300E-01, -.10517800E+00, 0.42585100E+00, 0.15301700E+00, -.48575000E+00, -.32454200E-01, -.35437500E+00, 0.28576300E+00, -.56864000E-01, 0.26762700E+00, 0.97386500E+00, 0.35247100E-02, -.38676500E+00, 0.17681000E+00, 0.12893900E+00, -.51095700E-02, -.13843500E-02, -.21053000E+00, 0.58110400E+00, -.12417900E+00, 0.35763100E+00, 0.31531200E+00, 0.10651400E+00, 0.90790400E-01, 0.64970000E-01, -.12115000E+00, 0.11751500E+01, 0.10214400E+00, 0.18377700E+00, -.26817200E+00, 0.10590800E+00, -.74297500E+00, 0.11155300E+01, -.12411800E+00, 0.13987400E+00, -.20640500E-01, 0.56275000E+00, 0.94248700E+00, 0.79262600E-01, 0.47387200E-01, 0.41159100E+00, 0.62644600E+00, -.36534400E+00, 0.41284300E+00, -.17733600E+00, -.49837200E+00, -.56602400E-01, 0.74890800E-01, 0.70569300E-01, 0.56388800E+01, 0.15224500E+03, -.19350400E+01, -.66647100E+02, -.53236900E+02, 0.33002200E+01, -.81670700E+01, -.64471400E+02, -.10994300E+03, 0.54560200E+02, -.24304600E+02, 0.54988700E+02, 0.16183100E+02, -.11692700E+02, 0.23561100E+02, -.12607600E+02, 0.53967000E+02, 0.38039500E+01, 0.10194600E+03, -.13167800E+03, 0.65269100E+02, -.60639000E+01, 0.66190400E+02, 0.12610200E+02, 0.88388400E+01, -.19043200E+02, -.11223400E+03, 0.10771100E+02, 0.86478400E+01, 0.58393200E+02, 0.35298000E+02, -.18110100E+02, 0.18457400E+02, -.17725100E+02, -.39132700E+01, -.12497100E+02, -.22545400E+02, -.29359000E+02, 0.24853300E+00, -.41480000E+01, -.18988700E+02, 0.16655900E+03, -.82476000E+02, 0.47626100E+02, -.83247100E+02, 0.64058600E+02, 0.42792600E+02, -.49143800E+02, 0.49601400E+02, -.57340300E+02, 0.16957200E+02, -.25462500E+03, -.33147400E+02, 0.17189000E+02, 0.56008500E+02, 0.16767600E+02, 0.99952200E+01, -.29555600E+02, 0.33171900E+01, -.39743100E+02, 0.36166700E+02, -.14265800E+02, -.24014400E+02, -.72276600E+02, 0.35952400E+02, 0.21847100E+02, 0.36122000E+02, -.24030700E+02, 0.27807200E+02, 0.17288200E+02, 0.12236300E+02, 0.17982000E+02, 0.21956300E+02, 0.11997500E+03, 0.23503100E+03, -.11974200E+03, -.24689400E+02, -.11734700E+03, 0.39272800E+02, -.27922000E+02, -.59207100E+02, -.60295200E+01, -.60037200E+02, -.39544900E+02, -.22158700E+03, -.32654400E+02, 0.36903800E+01, 0.65883800E+01, 0.18288100E+02, -.81103200E+01, 0.24492700E+02, 0.21030200E+02, 0.18500900E+02, -.67969700E+01, -.20298400E+02, 0.96351900E+01, -.19263500E+02, -.16013600E+02, -.19782400E+02, -.81302000E+00, 0.18425800E+02, 0.91069100E+01, 0.44709100E+01, -.21114500E+00, -.53679400E+01, 0.11310300E+02, -.13578900E+02, 0.14378800E+01, 0.64252900E+01, 0.16608000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.51085900E+00, -.42304300E+00, -.77545400E+00, 0.30425800E+00, 0.77730000E-02, 0.63074900E-01, -.63085200E+00, -.62343900E+00, 0.62530500E+00, -.37222400E-01, 0.57188400E-01, 0.15185200E+01, 0.38122700E+00, -.49558900E+00, 0.51668400E+00, -.13851500E+01, -.78927200E+00, 0.13171900E-01, 0.21949500E+00, -.53256700E+00, -.29493700E+00, 0.48887300E-01, -.76668700E-01, -.68293800E+00, 0.56591400E-01, 0.91528400E-03, -.18270500E+01, 0.19962600E+00, -.42946200E+00, -.99028800E+00, -.56740900E-01, 0.87317200E+00, -.29129800E+00, -.26928400E+00, 0.15278400E+00, -.37997100E+00, -.17301200E-01, -.12202900E+01, 0.53093300E+00, 0.20793500E+00, 0.19572200E+00, 0.21583300E+00, -.51441700E+00, -.13682100E+00, 0.11933000E+00, 0.86806500E-01, -.13608500E+00, 0.15326700E-02, -.21323000E+00, 0.28710700E+00, -.11222800E+00, -.11046100E+01, -.26478200E-01, -.51993900E+00, -.17016300E+00, -.80116400E-01, 0.10129000E+00, 0.65063200E+00, -.17583800E-01, -.37352500E+00, -.17071000E-03, -.14674600E+00, -.14875400E-01, 0.15292000E+00, -.33792800E+00, -.72415800E-01, -.64814100E-01, 0.41464900E+00, 0.31609800E+00, 0.17654000E+00, -.33926000E+00, 0.51690400E+00, -.76214300E-01, 0.19783800E+00, -.19598500E+00, 0.21292700E+00, -.92085200E-01, -.50912600E+00, 0.73250500E-01, 0.60029600E-01, -.32272700E-01, 0.43910700E+00, -.32764500E+00, -.62309000E+00, 0.24021300E+00, 0.49343700E+00, -.89092400E-01, -.49107100E+00, 0.29221700E+00, -.43524000E+00, 0.18130000E+00, -.42683800E-01, -.14168400E+00, -.19080100E+00, 0.21250800E-01, 0.39467400E-01, -.27426800E+00, -.10582500E+01, 0.86398800E-01, -.10612800E+00, -.64666500E-01, 0.12556000E+00, 0.23195200E-02, -.34696100E+00, 0.39587800E+00, -.12051100E+00, -.10309400E+00, -.35329000E+00, 0.29527100E+00, 0.59122300E-01, -.50857100E-01, -.16170200E-01, -.17674900E-01, -.61499200E-03, 0.86368300E-02, -.79467700E-01, -.97600000E+00, -.90465700E-03, -.58161900E+00, -.83808600E-01, 0.21846700E+00, 0.13128000E+00, -.76381700E+00, 0.58208400E+00, 0.19731500E-01, -.33777200E+00, -.87639300E-02, -.54997500E-01, 0.86461200E+00, -.10647100E-01, 0.13567400E+00, -.32070700E-02, 0.18412000E-01, -.16537800E+00, -.97062300E-01, 0.12039900E-01, -.19727700E+00, 0.65871000E-02, 0.37972000E-01, -.27619000E-02, -.43079000E+00, -.15353200E+00, -.94406400E-02, -.15440400E-01, -.90280000E-01, 0.53304800E-01, 0.81704700E-04, -.41162200E-01, -.23342100E+00, -.13201900E+00, -.11960700E+00, -.54079400E-01, -.18751000E+00, 0.17465000E+00, 0.18079900E+00, -.27453200E-01, 0.24910500E+00, -.19311700E-01, -.14923100E+00, -.19749400E+00, 0.53225100E-02, 0.20222600E+00, -.24172700E+00, -.22836400E-01, 0.10323900E+00, 0.24908300E-01, 0.13573800E+00, 0.13271400E+00, 0.80408900E-02, -.32848100E-01, -.20806700E-01, -.39288800E+00, 0.40545700E+00, -.17414200E+00, 0.12466000E+00, 0.39938200E+00, 0.25260900E-01, 0.86397300E-01, -.37639900E+00, 0.56386600E-02, -.11579000E+03, 0.62836400E+00, -.14105000E+02, 0.65335200E+01, 0.19200900E+01, -.16575400E+02, -.31553300E+02, -.18365600E+01, 0.65912700E+00, 0.49439400E+02, 0.89734200E+00, 0.23109800E+02, 0.10843800E+02, 0.65633700E+01, 0.94615900E+01, 0.71619800E+01, 0.17336600E+01, -.23946000E+02, 0.13849900E+03, -.69639200E+02, -.88406500E+02, -.69220600E+02, -.43676400E+02, -.44424400E+02, 0.60137500E+02, 0.10182900E+03, 0.25746800E+02, -.41747900E+02, -.18320100E+02, -.79580700E+02, 0.40230000E+02, -.17022900E+02, 0.39775700E+02, -.66047400E+01, 0.14125400E+01, 0.13283300E+02, -.20460100E+02, 0.22226000E+02, -.34162400E-01, 0.49530100E+02, -.97196900E+02, 0.48146500E+02, -.44860400E+02, 0.48605500E+02, -.63175900E+02, -.53961000E+02, -.86060500E+00, -.48259300E+02, 0.16659000E+02, -.54997800E+02, 0.14166800E+03, -.23490800E+03, 0.11776200E+03, 0.56807500E+02, 0.11750200E+03, 0.49386400E+02, 0.46360900E+02, 0.18236700E+02, -.20214300E+02, 0.85366200E+02, 0.35020300E+02, 0.95953300E+02, -.36707800E+02, 0.18289600E+02, 0.47343900E+02, 0.18193100E+02, 0.49317000E+02, 0.40791100E+02, -.28184500E+02, -.58662400E+02, -.21476000E+02, 0.54989200E+02, -.23118100E+02, -.97560200E+02, 0.48179000E+02, -.31261400E+02, 0.48810300E+02, -.48158900E+02, -.16881200E+02, 0.30119000E+02, -.26692400E+02, -.15483500E+02, -.19313900E+02, 0.13275500E+03, 0.17904300E+02, -.65707600E+01, -.12047200E+02, -.15960700E+02, 0.70212000E+01, -.96401100E+01, -.10043600E+02, -.16066700E+02, 0.12082100E+02, 0.11662900E+02, -.77931200E+01, 0.16444700E+02, 0.11561800E+02, 0.17213600E+02, -.17158800E+02, -.15839400E+02, -.69404900E+01, 0.21230000E+01, -.15932200E+02, 0.83690100E+01, -.10893300E+02, 0.10819500E+01, 0.56543700E+01, 0.33871800E+01, -.88460000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10773900E+01, -.17160400E+00, 0.11361700E+01, 0.13745100E+01, 0.98817700E+00, -.13891200E+00, -.69813000E+00, -.82516000E+00, -.23265600E+00, 0.55332600E+00, -.12363300E+00, 0.28578100E+01, -.13258600E+00, 0.32424100E+00, 0.18378200E+01, -.13754500E+01, -.16550900E+01, -.29743200E+00, 0.70497300E-01, -.13446400E+01, -.83006300E-01, 0.24889400E-01, 0.29615500E-01, -.20918400E-01, 0.10866800E+00, -.89010800E-02, -.78618000E+00, -.10978500E+00, 0.15085700E-01, -.51906600E-01, -.65852700E+00, 0.12909500E+00, 0.32654400E+00, 0.34545700E+00, 0.29513500E+00, -.22117900E+00, -.18594400E-01, -.41229700E-01, -.46136100E+00, -.10586000E+00, 0.26801000E-01, 0.16907700E+00, 0.90265500E+00, 0.30254000E-01, -.17072700E+00, 0.20927500E-01, 0.68284500E-01, -.69107600E-02, -.70465400E+00, 0.92090800E+00, 0.49781500E+00, -.34609500E+00, 0.13525300E+00, 0.89412100E+00, 0.44251800E+00, 0.10421500E+00, -.17982500E+00, -.20966400E+00, -.34484800E-01, 0.63806000E+00, 0.20680700E+00, 0.61338800E-01, 0.51517000E-01, -.29591800E+00, 0.63228500E+00, 0.25247500E+00, -.63909600E-01, -.10951000E+01, -.66982300E+00, -.19162000E+00, -.12784000E+00, -.57659000E+00, 0.77523300E-01, 0.40117700E+00, 0.33292700E+00, -.56364500E+00, -.15473200E+00, -.33646300E+00, 0.71228000E-01, 0.35911800E-01, 0.25033400E+00, 0.12227000E+00, 0.71383300E+00, 0.19409600E+01, 0.13336800E+01, -.55360300E+00, 0.21372600E+00, 0.65819500E+00, -.33295300E+00, 0.51060000E-01, 0.43612000E-01, 0.17316400E+00, -.56608000E-01, 0.41580000E+00, -.52459200E+00, 0.70552200E+00, 0.10638400E+01, 0.95351700E+00, 0.21412300E+00, -.41885500E-01, -.10610900E+00, 0.31608100E+00, 0.27400100E-02, -.39703700E+00, -.39256400E+00, -.83577800E-01, 0.44228000E-01, 0.58996500E+00, -.53083100E-01, -.33913400E+00, -.68864000E+00, -.71364600E-01, 0.52293000E-01, -.13173100E-02, -.52327800E-01, -.12364900E+00, -.11165500E+01, -.88683200E-01, 0.79052100E-01, 0.12216800E+00, 0.18404000E+00, 0.88284000E+00, -.51976700E-01, 0.18169600E+00, -.36067700E-03, 0.14958000E+00, 0.42546000E+00, -.10493100E+00, -.58301900E+00, 0.13221600E+00, -.28470100E+00, 0.45099000E-02, 0.44992900E-01, -.24075200E+00, -.56656400E+00, -.17911500E-02, 0.55813400E+00, 0.12542500E+00, -.67445900E-01, -.24985400E+00, -.64868300E+00, -.20519000E+00, -.17700000E-01, -.12660700E+00, 0.10873800E+00, 0.26553700E+00, -.67092300E-02, -.54456400E-01, -.95282700E+00, -.35469700E+00, -.17205400E+00, -.53013900E+00, -.67751300E+00, 0.69503300E-01, 0.16780600E+00, 0.36599400E-01, 0.29832700E-01, -.73781800E-01, -.14968400E+00, -.77165700E+00, -.15598500E+00, 0.59715100E-01, 0.44243300E+00, 0.16580000E+00, 0.28450100E+00, 0.97578600E-01, -.44499200E+00, -.10862700E+01, -.29843800E-01, -.36540700E+00, -.49279900E+00, 0.10719900E+01, -.84418000E+00, 0.16353300E+01, 0.16958200E+00, -.40310600E+00, 0.75896700E-01, 0.19405800E-01, 0.11919100E+01, 0.21144800E-01, -.10181100E+01, -.28475600E+03, 0.36969300E+03, 0.20800200E+03, -.47455400E+02, -.27227200E+03, -.48720000E+03, 0.82752400E+03, -.41375700E+03, -.59238200E+03, -.41388600E+03, -.12569700E+03, 0.40912600E+02, -.19103400E+03, 0.51972800E+02, -.32282000E+03, 0.13430800E+02, -.22407800E+03, 0.64822500E+03, -.32573200E+03, 0.42698600E+03, -.32375600E+03, -.15000100E+03, 0.30726500E+02, -.40226100E+03, 0.10614600E+02, -.39102300E+03, 0.80419400E+02, -.32143100E+03, 0.74537100E+03, -.37522100E+03, -.23128600E+03, -.37279300E+03, -.14138900E+03, 0.73230400E+01, -.23859500E+03, -.20367000E+02, -.29092900E+03, 0.55620700E+02, -.39281600E+03, -.62867900E+03, 0.31637100E+03, 0.17311500E+03, 0.31441500E+03, 0.26780300E+02, -.33531200E+03, 0.40787600E+03, 0.23952100E+03, 0.30709700E+03, -.39473900E+03, -.74862500E+02, 0.70325600E+03, -.35102400E+03, -.25705100E+03, -.35137100E+03, -.19701200E+03, -.10483200E+03, -.16758200E+03, 0.10155200E+03, -.32144700E+03, -.91602300E+02, -.43535500E+03, 0.47749300E+03, -.23834000E+03, -.94662300E+02, -.23963900E+03, -.15731200E+03, -.53350800E+02, -.10615800E+02, 0.15886100E+03, -.12688500E+03, -.72142900E+02, 0.17751500E+01, -.18009000E+03, 0.89931000E+02, 0.77867400E+02, 0.90417500E+02, -.31571800E+02, 0.67498500E+02, -.12094800E+03, 0.10389400E+03, 0.24912800E+03, 0.51795100E+02, 0.76401200E+02, 0.28509800E+02, -.15356700E+02, -.56885800E+01, -.13638900E+02, -.52453600E+01, -.62753800E+01, 0.19208500E+01, -.14366200E+02, 0.55387400E+01, 0.10400300E+02, -.21242300E+02, 0.12980500E+02, -.53955600E+01, 0.14243500E+02, 0.31472000E+02, -.15631300E+02, -.20563800E+02, 0.11071700E+03, 0.23634300E+02, -.63999800E+02, -.29135500E+02, -.65686200E+02, -.24132200E+02, -.53188200E+02, 0.12798900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.83534200E+00, 0.26990600E+00, 0.21971600E+00, 0.12826900E+01, -.39589800E+00, -.14024100E+00, -.39885200E+00, 0.94563200E+00, 0.28117800E+01, 0.65796500E+00, 0.18374900E+00, -.37929400E+01, 0.33665400E+01, 0.18058500E+01, 0.53079900E+00, 0.20764200E+01, 0.11334900E+01, -.53997200E+00, -.11710000E+01, 0.73565400E+00, 0.26358200E+00, -.94267100E-01, 0.11032900E+01, -.11520900E+01, -.37266800E-01, 0.31827000E-01, 0.99528100E-01, 0.36894300E-01, -.28201900E-01, 0.31671900E+00, 0.13719900E+00, -.22338400E-01, 0.14112900E+00, -.48033500E-01, 0.19680900E+00, -.16674800E+00, 0.75312000E-02, 0.40813100E+00, -.74403000E-01, 0.39413300E-01, -.36446700E-01, 0.50874000E-01, -.77823000E-01, 0.50344000E-01, 0.20894700E-01, -.17566200E+00, -.11642400E-03, 0.15779100E-02, -.27648000E+00, -.42166800E-02, 0.23727100E-01, -.20322700E+00, -.54083700E-01, -.38504200E+00, -.60629700E-01, 0.13010600E+00, -.52113200E-01, 0.14328300E+00, -.62622600E-02, 0.15118000E-01, -.45925100E-01, 0.17886000E-01, -.61722100E-01, -.15717000E+00, -.25716300E+00, -.48741800E-01, -.45839800E-01, -.18175200E+00, 0.24420600E+00, 0.23803600E-01, 0.46743200E-01, -.91816000E-01, -.42650400E-02, -.22982000E-01, 0.10159100E+00, -.25165500E+00, 0.20768600E-01, 0.65011600E+00, -.86132200E-01, 0.52448800E-01, -.13121500E-01, -.74620900E-02, -.39572300E+00, -.29865700E+00, 0.48255900E+00, -.83536600E+00, 0.26739700E+00, 0.54307200E+00, -.38347400E+00, -.13768300E+00, -.45440500E+00, -.11102900E-01, -.18070200E+00, -.28597300E-01, -.12735700E+01, 0.12220200E+01, 0.52210100E+00, 0.12139500E+01, 0.65453500E-01, -.56667500E+00, -.59917000E-01, 0.38507900E-01, -.10493600E-01, -.10638800E+00, 0.23295000E+00, 0.23806200E+00, 0.30286000E-01, -.26025000E+00, 0.21364700E+00, -.40886900E+00, -.24241900E+00, 0.22854300E-03, 0.13313600E-03, -.10196100E-02, -.11337700E-01, -.45808200E-01, 0.25980700E+00, -.42577900E+00, 0.57830200E+00, -.22086800E+00, 0.38516600E-01, -.20829100E-01, -.20794700E-01, -.16886800E+00, -.14161000E-01, 0.56441600E+00, 0.27031600E+00, 0.25206100E+00, -.24937300E+00, 0.15147300E+00, -.65226600E+00, -.41149800E-01, -.31638800E+00, 0.11574700E+00, -.16081800E+00, -.16142900E-01, 0.66844700E+00, -.29313900E-01, -.47984600E-01, -.10694200E+00, -.51997100E+00, -.73179700E-01, 0.17538400E+00, -.65071900E-02, -.25533300E+00, 0.41698500E-01, 0.11789600E-02, 0.81852000E-01, 0.25920000E+00, 0.33796300E+00, -.33720500E-01, 0.86150400E-02, -.91596500E-01, 0.38026400E-01, -.77098200E-01, 0.62621800E-01, -.54347300E+00, 0.18194500E-01, -.18458200E+00, -.49296200E-01, -.54050200E-01, 0.37851300E+00, -.25521500E+00, -.35564500E-01, 0.22182000E+00, -.28683300E+00, 0.30378200E+00, -.50648700E+00, -.43900800E-01, -.41548100E-02, -.63470100E+00, -.15480600E+00, 0.10098200E+01, -.40677600E-01, 0.96396400E-01, 0.39285700E-01, 0.12901400E+00, 0.77865500E-01, -.12687900E+01, -.54745700E-02, 0.11412900E+01, -.31664600E+00, 0.17373000E+03, 0.13007700E+03, -.78394700E+02, 0.70885600E+02, 0.20747400E+03, 0.10019600E+03, -.49068800E+02, -.49212200E+02, -.50105300E+02, -.27082500E+02, -.34477600E+01, -.33232800E+02, 0.21773400E+01, -.72165100E+02, -.18133800E+01, -.97830400E+02, -.63024400E+02, 0.32138000E+02, 0.23926800E+03, 0.31053700E+02, 0.36746700E+02, 0.10275900E+03, -.15340900E+03, -.14459700E+03, -.15371300E+03, 0.11098200E+03, -.66294500E+02, 0.22487600E+03, -.11290000E+03, -.44110500E+02, -.11235500E+03, 0.10735800E+02, 0.44686500E+01, 0.47119000E+01, 0.10940500E+03, -.10645300E+03, -.11109100E+01, -.15332300E+03, -.78470300E+02, 0.40731600E+02, -.12710700E+02, 0.39168500E+02, 0.21310600E+02, 0.26158700E+02, 0.97086000E+02, 0.37427400E+02, 0.39186600E+02, 0.71984100E+02, 0.39927600E+02, 0.65134400E+03, -.32635800E+03, -.18656700E+03, -.32580600E+03, -.10529100E+03, -.75170700E+02, -.16888000E+02, 0.13263300E+03, -.29790200E+03, -.61611700E+02, -.23051600E+03, 0.94324300E+02, -.47096700E+02, -.11078500E+03, -.47199700E+02, -.84519100E+02, -.10322900E+03, 0.60512100E+02, 0.66015500E+02, 0.12106400E+02, -.10996700E+03, -.17359200E+02, -.82195900E+02, 0.42937600E+02, 0.10978000E+03, 0.40731400E+02, 0.22692800E+02, 0.82348200E+02, 0.26565700E+01, 0.71039900E+02, 0.65885800E+02, 0.10128200E+03, 0.12833300E+02, -.44551500E+00, 0.10350400E+02, 0.19364200E+02, 0.30861000E+01, -.93626200E+01, -.21971900E+02, -.13742600E+02, 0.26531100E+01, -.19121500E+02, -.30737200E+01, -.97416900E+01, -.88789300E+00, -.18556400E+01, -.18308500E+01, 0.41925900E+02, 0.19077600E+01, -.11253800E+02, 0.43795100E+01, 0.41518600E+02, -.12714600E+02, -.83313900E+00, 0.13751300E+01, -.17318500E+02, -.42950800E+01, 0.76778800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.35520800E+01, -.38803300E+01, -.56390400E+01, 0.41212400E+01, -.71024800E+01, -.14715600E+01, -.11596800E+01, -.36180300E+01, 0.14954500E+01, 0.35284400E+00, -.16898700E-01, 0.17847700E+01, 0.26502400E+01, -.17693200E+00, -.42593000E+01, -.38336900E+01, -.13654100E+01, 0.11804600E+01, -.12728400E+00, 0.40779300E+00, -.51197900E+01, -.27049700E+00, 0.25372000E+00, -.86738600E+01, 0.30146200E+00, 0.18149400E+00, -.19484600E+01, 0.77412000E+00, -.14930000E+01, -.22117500E+00, 0.48696900E+00, 0.25048200E+01, -.55652300E+00, -.30163700E+01, -.26676900E+01, -.15187200E+01, -.31268900E-01, -.76673600E+01, 0.30536900E+01, -.28257500E+00, 0.49310500E+00, 0.12516300E+01, -.25907400E+00, -.53901100E+00, 0.44116500E-01, 0.10819400E+01, 0.54726700E-01, 0.10876300E-01, -.89345900E+00, -.20610500E+01, -.33823300E+01, 0.24968100E+00, -.61186800E+00, -.69515700E+00, -.69974500E+00, -.13176700E+01, 0.72556000E-01, 0.31432800E+01, -.11315000E+00, -.76959100E-01, 0.36494000E+00, 0.11233900E+00, 0.78165000E+00, 0.21309500E+01, -.33317300E+01, 0.11124800E+00, -.30165800E+00, 0.43378900E+01, 0.24525700E+01, 0.25600300E+00, -.11289000E+01, -.17026200E+01, 0.10028500E+01, 0.12877000E+01, 0.92837100E+00, -.29984700E+01, -.47888600E+00, 0.13995500E+01, -.73961700E+00, -.13249700E+00, 0.20449900E+00, -.12119900E+01, -.28751200E+00, -.13085800E+01, -.37164600E+00, 0.66325200E-02, -.49423700E+00, -.18225800E+01, 0.88832700E+00, 0.36047300E+00, -.34414100E+00, 0.26467600E+00, -.15067000E+00, 0.11511200E+01, 0.69435900E+00, -.16116300E+01, -.18568800E+01, -.21247100E+01, 0.11456200E+00, 0.29519900E+01, 0.26029000E+00, 0.16714600E+00, 0.54823200E-01, -.18812500E+01, -.14497100E+01, -.10887200E+01, -.49400400E+00, 0.11894700E+01, 0.56210000E-01, -.76270200E+00, -.28921300E+01, -.58190000E-01, 0.32570900E+00, 0.27137800E-02, 0.38464800E+00, -.37051600E-01, -.52770100E+01, 0.80062000E+00, 0.92670500E-01, 0.14763900E+01, -.18836500E+00, -.39399400E+01, -.14439100E+00, -.90179400E+00, 0.43976200E-01, 0.31474200E+00, -.16031500E-01, 0.20691900E+00, -.13568700E+01, 0.83964500E+00, 0.72204700E+00, -.36525400E+00, -.44395200E+00, 0.47552300E+00, 0.69723700E+00, 0.48568000E-01, -.11643800E+01, -.10255900E+01, -.32957900E+00, -.28485100E+00, -.12583100E+01, 0.76752700E-01, -.18617600E+00, 0.18740900E+00, 0.10027500E+00, 0.15337400E+01, 0.61569800E-02, -.49093500E+00, -.96709300E+00, -.10480300E+01, -.35416100E+00, -.66895500E+00, -.25348200E+00, -.13228700E+00, 0.12352200E+01, -.29706600E+00, 0.17384100E+01, 0.11381900E+00, -.36352400E+00, -.33288800E+01, 0.31979700E-01, 0.15373600E+00, -.32753400E+00, 0.38143500E+00, -.93721300E+00, 0.37324800E+00, -.11150100E+00, 0.12175000E+01, 0.41439000E-01, -.21680600E-01, 0.18934800E+01, -.28667700E+01, -.25205300E+01, -.29594100E+01, 0.88455700E-01, 0.54322900E+00, 0.17102400E+00, -.68011700E+00, -.18863500E+01, -.91143100E-01, -.25469500E+01, -.62343600E+00, -.10140600E+01, 0.54518000E+03, 0.37343000E+03, -.10170600E+03, -.19966100E+02, -.12157600E+04, 0.60548200E+03, 0.31714600E+03, 0.60790500E+03, -.84519100E+02, -.72040400E+02, 0.31026600E+03, -.92126600E+02, 0.60031700E+03, -.90336500E+02, 0.49646800E+03, -.17751500E+03, 0.91241500E+02, -.39739900E+03, 0.87342500E+02, 0.58007800E+02, -.12070600E+03, 0.37784600E+03, -.15876100E+03, -.16081600E+03, -.58605000E+01, 0.15168200E+03, 0.18981600E+03, -.93990800E+02, -.18168600E+03, -.94572900E+02, -.44995000E+02, 0.14240600E+02, -.41367200E+02, -.46486700E+02, 0.19364600E+03, 0.96911200E+02, -.46314300E+02, -.87506300E+02, 0.31678500E+02, 0.11053500E+03, 0.43597600E+02, -.11660600E+02, -.20390200E+03, -.21998600E+02, 0.99684800E+02, -.59014900E+02, -.31710900E+03, 0.27801600E+03, -.21996300E+04, 0.10984300E+04, 0.10342700E+04, 0.10989400E+04, -.22838500E+03, -.60838400E+03, 0.45342700E+03, -.35100800E+03, 0.10610800E+04, -.56090000E+03, 0.11846200E+04, 0.35290300E+03, -.17778700E+03, 0.49469900E+02, -.17573800E+03, -.16984200E+03, -.68266800E+02, -.11136600E+03, -.22246700E+02, -.25062300E+01, -.45148600E+02, -.86862600E+02, -.84217600E+02, 0.36956300E+02, 0.63519200E+02, 0.41332400E+02, 0.92120700E+01, -.30303900E+02, 0.29134600E+03, 0.34325900E+03, 0.26086100E+02, -.65932300E+02, -.14596100E+03, 0.71968400E+02, -.17469100E+01, -.31394100E+02, -.10901200E+02, -.74606300E+02, 0.47027000E+02, 0.22171300E+02, -.11759400E+02, 0.32497900E+02, 0.36407500E+02, -.50809200E+02, 0.19564700E+02, 0.10437700E+03, 0.16496100E+02, -.61890900E+02, -.12886300E+02, -.41614600E+02, 0.13032900E+02, -.57792100E+02, 0.16296900E+03, -.27716600E+02, -.30032300E+02, 0.88100400E+02, -.45642600E+01, -.53420400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.32654800E+01, 0.34692200E+01, 0.52645900E+01, -.44453200E+01, 0.63678900E+01, 0.13823600E+01, 0.16929400E+01, 0.48138100E+01, -.10890800E+01, -.42916600E+00, -.86214100E-01, -.27727900E+01, -.55035500E+01, 0.66900300E-01, -.14773100E+01, 0.40847700E+01, 0.31725800E+01, -.67550200E+00, -.49722000E+00, 0.12238000E+01, 0.50559200E+01, 0.28587200E+00, 0.68808600E+00, 0.98957400E+01, -.38987200E+00, -.15548100E+00, 0.35006900E+01, -.29725900E+00, 0.14494400E+01, 0.28018300E+00, -.30112900E-01, -.26327200E+01, 0.99487300E-01, 0.21131500E+01, 0.10490500E+01, 0.83587100E+00, -.46461100E-01, 0.49820800E+01, -.23767100E+01, -.14418900E+01, 0.17098700E+00, -.82588800E+00, 0.21204500E+01, 0.69058700E+00, -.18060500E+00, -.14784900E+01, 0.82804000E-01, -.23367200E-01, 0.12964000E+01, 0.13490000E+01, 0.35752800E+01, -.10786200E+01, 0.68504100E+00, 0.47603000E+00, 0.48152800E+00, 0.89093500E+00, 0.51156900E+00, -.40728900E+01, 0.75229600E-01, -.47113800E-01, -.12836100E+00, 0.32677200E+00, -.57522600E+00, -.11982000E+01, 0.17145100E+01, -.16079500E+00, -.55520500E-02, 0.95916200E+00, -.23403100E+00, 0.32770700E+00, -.22378900E+01, 0.22426100E-01, -.16594000E+01, -.14392100E+01, -.86897900E+00, 0.19149800E+01, 0.16835200E+00, 0.21605200E+01, -.94265800E+00, -.14055500E+00, -.26948200E+00, 0.99887000E+00, -.19725900E+00, 0.61799000E+00, 0.70918200E-01, 0.29527100E+00, 0.19324300E+00, 0.74570400E+00, -.24565600E+00, 0.42682600E+00, -.85086500E+00, -.28844500E+00, -.22125700E+00, -.11618300E+01, 0.18735100E+01, -.10183800E+01, -.54390300E+00, -.83794200E+00, -.21803800E+00, -.51725200E+00, 0.39061000E+00, 0.49899500E+00, -.37452900E-01, 0.20361500E+01, 0.78277600E+00, 0.25990400E+00, -.64301000E-01, 0.92484700E+00, 0.27888300E+00, 0.93506000E+00, 0.42106800E+00, -.41511600E+00, -.15648000E+00, -.22819500E-03, -.17308300E+00, -.27429600E+00, 0.11906700E+01, 0.18711400E+00, 0.52027700E+00, 0.33892800E+00, -.48931000E+00, 0.68296000E+01, -.17387300E+01, 0.21348500E+01, 0.16072900E-01, -.93448000E+00, -.21518500E+00, 0.44904900E+00, 0.22823900E+01, 0.12199000E+00, 0.92956000E-01, 0.91297400E+00, 0.80937700E+00, -.30254600E+00, -.13960200E+01, 0.13790100E+00, 0.11944400E+01, 0.68997300E+00, -.17245600E+00, 0.46280200E+00, 0.74325000E+00, 0.35390500E+00, -.10142000E+00, 0.77335600E-01, -.21413300E+00, -.53816400E+00, 0.66274300E-01, -.12672700E+00, 0.15270900E+01, 0.15567800E+01, 0.49969200E+00, 0.57233200E+00, 0.12132100E+01, -.22086000E+00, 0.11147900E+01, 0.44461000E+00, 0.30696100E-01, -.50309200E+00, 0.12503800E+01, -.78522700E+00, -.55539300E+00, -.11070200E+01, 0.18365900E+01, -.65814500E+00, 0.13386200E+01, -.84514800E+00, 0.93317800E+00, -.92878700E+00, 0.10491700E-01, -.51852500E+00, 0.17421100E+01, 0.62413300E+00, -.13756200E+01, -.36218900E+00, -.68648700E+00, 0.21842200E+00, 0.20315700E+00, -.23016700E+00, 0.27573900E+00, -.97511000E-01, -.24042100E+01, -.59903900E+00, -.59487400E+00, -.14424700E+00, 0.26680400E+03, 0.34100400E+02, -.36130300E+03, -.44686900E+03, 0.22154500E+03, -.17846500E+03, 0.22348400E+03, -.14521200E+03, -.23488500E+03, 0.31582800E+03, 0.60605800E+02, 0.25667600E+03, -.22685800E+03, 0.12397200E+03, 0.10426600E+04, -.52213600E+03, -.35562200E+03, -.52186900E+03, -.31297900E+03, -.46209200E+03, 0.13252000E+03, 0.24480900E+03, -.27979200E+03, -.37054700E+03, -.40159100E+03, 0.99814300E+02, -.51400200E+02, 0.99696900E+02, -.49697100E+02, -.16463600E+03, -.46797900E+01, -.10148200E+03, -.11984100E+03, 0.13851900E+03, 0.30489100E+02, -.15386600E+03, -.31412200E+03, 0.15560100E+03, 0.38729800E+03, 0.15705500E+03, 0.99070900E+02, -.19049600E+03, 0.15215900E+03, 0.25434300E+03, 0.25123000E+03, -.22538300E+03, -.27379000E+03, -.10631900E+03, 0.54047400E+02, 0.27410500E+03, 0.52337400E+02, -.53284400E+03, -.44429900E+03, 0.12241700E+03, -.72015000E+01, 0.16784800E+03, -.46373600E+03, -.28022400E+03, 0.47950900E+03, -.24005000E+03, -.20077400E+03, -.23870300E+03, -.26711200E+03, -.40396200E+02, -.29350000E+02, 0.16204400E+03, 0.21841000E+02, -.64179800E+02, -.63625300E+02, 0.25805900E+02, -.18878300E+02, 0.15139300E+03, -.12834100E+02, 0.43924100E+01, 0.77690200E+02, -.10022600E+03, 0.60970700E+02, 0.14586500E+03, 0.15994800E+03, -.27397900E+02, 0.21496400E+02, 0.79884300E+01, 0.13785600E+02, 0.31771600E+02, -.70946200E+02, 0.27439300E+02, 0.22748400E+02, 0.32190700E+02, -.13376800E+02, 0.53184500E+00, -.35435100E+02, -.32621200E+02, 0.40723300E+02, -.34634800E+02, 0.54136800E+01, 0.30469000E+02, -.33672300E+02, 0.16128700E+02, 0.34151400E+02, 0.50902300E+02, -.31768700E+02, -.27964800E+02, 0.67379600E+02, -.27145600E+02, -.20096900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.52406500E+00, -.48960700E+00, -.54569000E+00, 0.37616300E-01, -.70833200E-01, -.64894400E-01, -.48264200E+00, -.10806200E+01, -.32918200E+00, -.72179400E-01, -.18852300E-01, 0.14398700E+01, 0.95790500E-01, -.48551200E+00, -.95155100E+00, -.15652800E+01, -.49549000E+00, 0.22922600E+00, 0.67253400E-01, -.36517800E+00, -.53958000E+00, 0.14157600E-01, -.43711200E-01, -.24178400E+00, 0.92891400E-01, -.21320300E-01, -.11495500E+01, 0.15997500E+00, 0.16159100E+00, 0.12962100E+00, 0.11636700E+00, 0.11137500E+00, -.92483900E-01, -.31752400E+00, -.32296400E+00, -.25069200E+00, -.24640600E-01, -.65083000E+00, 0.27967400E+00, -.20508400E+00, 0.35122600E+00, 0.28667100E+00, -.37337800E-01, -.12931300E-01, 0.18479400E-01, 0.14730300E-01, 0.12362300E-01, -.30853400E-02, 0.16742600E+00, -.22537500E+00, -.19429400E+00, 0.40036900E-01, -.36696500E-01, -.12299800E+00, -.51866200E-01, -.23555800E-01, 0.17670900E+00, 0.18555500E+00, -.22617600E-01, -.17473600E+00, 0.29378500E-01, -.18068200E-01, 0.27833800E-01, 0.60967700E-01, -.21578000E-01, -.68162400E-01, 0.61147800E-01, 0.22365600E+00, 0.40715600E-01, 0.11326700E+00, 0.27488400E+00, 0.20407600E+00, -.93429300E-02, -.20073500E+00, -.31929200E+00, 0.46177900E+00, 0.16446200E-01, -.13178500E+00, 0.41285300E-01, 0.13527900E-01, -.80883200E-01, 0.25706300E+00, -.22697300E+00, -.64087100E-01, 0.21101200E+00, 0.20119000E+00, -.11791900E+00, -.29556300E-01, 0.12707500E+00, -.89965600E-01, -.83130300E-01, -.22302200E-01, -.29315500E-01, -.97670600E-01, 0.12647500E+00, -.97233100E-01, -.23350800E+00, -.40020300E+00, -.76148600E-01, -.56178300E+00, 0.49171200E-01, -.17259400E-01, -.54742700E-02, -.61549700E-02, 0.29452500E+00, 0.73021700E-01, -.51559400E-01, -.44053400E+00, 0.41519600E+00, 0.88164500E-01, 0.14341700E+00, -.93259800E-01, -.14481400E+00, -.10619700E-02, 0.50085000E-01, 0.31678400E-01, 0.13425400E+01, -.16866000E+00, -.19322400E+00, -.42322700E+00, 0.25425100E+00, 0.13174900E+00, -.83254900E+00, 0.43007800E+00, 0.88451800E-02, -.19246800E+00, -.14398200E+00, 0.19389900E+00, 0.84253400E-01, 0.16581800E+00, 0.42680300E+00, -.25219300E-01, -.47021700E-01, -.14819900E+00, 0.38506200E-02, -.18126600E-01, 0.19239100E+00, 0.25181400E-01, -.61674900E-01, 0.28678200E-01, -.17679800E+00, -.10132600E+00, 0.30146000E-01, -.68450300E-02, -.45548600E-01, -.29449200E+00, -.26028500E-02, -.21872700E-02, -.25668700E+00, -.12950800E+00, -.26527800E+00, -.43709000E-02, -.74521000E-01, 0.79833400E-01, 0.31134600E+00, -.66860800E-01, 0.75418500E-01, 0.84287900E-02, 0.28043500E-01, 0.43166800E+00, 0.54709500E-01, 0.52870600E-01, 0.42635100E-01, -.22936100E-02, -.26693300E+00, 0.42938800E-01, -.88387000E+00, -.58377300E+00, 0.29829900E-03, -.11484000E+00, -.12787600E+00, -.24405800E+00, 0.16851900E+00, -.42391500E+00, 0.11022700E+00, 0.10476600E+00, 0.41275700E-01, 0.84805000E-01, -.20461700E+00, 0.24107700E-02, -.41352800E+00, -.14872100E-01, 0.45969700E+00, 0.20358700E-01, 0.36034300E-01, -.41039800E+02, -.18076100E+03, 0.21823300E+03, -.10908100E+03, -.92184800E+01, -.10916400E+03, 0.61857500E+01, 0.26716400E+02, -.49488700E+02, 0.21565800E+02, -.91357700E+02, 0.24089900E+02, -.49885400E+02, 0.91890100E+02, -.46699300E+02, -.61094700E+02, -.45897200E+02, -.38832700E+02, -.47940100E+02, 0.28097300E+02, 0.11288900E+03, 0.97823000E+02, -.52643000E+02, 0.78613500E+01, -.80783600E+02, 0.40512700E+02, 0.82967800E+00, 0.40365000E+02, 0.17725500E+02, 0.66587500E+00, -.92044200E+01, -.31191700E+02, 0.39328800E+01, -.76737500E+01, 0.72090500E+02, -.13167800E+03, 0.66738200E+02, -.19478900E+02, 0.65855000E+02, -.94807100E+01, -.57705000E+02, 0.44079500E+02, -.42704700E+01, 0.57055200E+02, -.75143300E+02, 0.51431300E+02, -.21414800E+02, 0.11237700E+02, -.90100000E+02, 0.10791100E+02, 0.92896800E+02, 0.71740900E+02, -.42522400E+02, 0.12061100E+02, 0.96782200E+01, 0.54636600E+02, -.47049000E+02, -.53191200E+02, 0.26668300E+02, 0.71187900E+02, 0.26244800E+02, 0.72922500E+02, 0.80123900E+02, -.58030000E+02, -.60690900E+02, -.46280000E+02, 0.89930100E+02, 0.14266300E+02, -.41981300E+02, 0.20382900E+02, -.74394200E+02, 0.21057500E+02, -.20071700E+02, -.36041000E+02, -.54247300E+01, -.49678100E+02, 0.39833200E+01, -.48211700E+02, 0.70601300E+02, 0.92924400E+01, -.85753700E+01, -.14709700E+00, -.32869000E+01, 0.17348800E+02, -.71423300E+01, -.74505000E+01, -.35095000E+01, -.15413100E+00, 0.69733900E+01, 0.59034100E-01, 0.30058600E+01, -.79141200E+00, 0.38615100E+01, -.13743100E+02, -.31496300E+01, 0.63949200E-01, 0.28009900E+01, -.15233100E+02, -.56716900E+01, -.89726400E+01, -.16290500E+01, -.23738200E+01, -.11578300E+01, -.92291200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.62767700E+00, -.45822900E-01, -.76364300E+00, -.22298000E+00, -.10180900E+01, -.14888800E+00, 0.37894200E+00, -.26285100E+00, -.89148100E+00, 0.70100500E-01, 0.80130000E-01, -.11108800E+00, 0.90718100E+00, 0.41054500E+00, 0.53974500E+00, -.22915700E-01, 0.93080100E-01, 0.11659600E+00, -.26062300E+00, 0.56254900E+00, 0.57642400E+00, -.57863900E-01, -.22412900E+00, -.37284400E+00, 0.12475100E-01, -.26978600E-01, 0.68622100E+00, -.33741200E-01, -.14793100E+00, -.39015100E+00, -.24209500E+00, 0.55469000E+00, 0.16602800E+00, 0.32992100E-01, 0.19453800E+00, 0.59771500E+00, 0.27168400E-02, -.64224600E+00, 0.80359700E-01, 0.58126200E+00, -.34979600E+00, 0.50615500E-01, -.35440400E+00, -.18023800E+00, -.17782100E+00, 0.31145700E+00, 0.55663700E+00, -.37699500E-02, -.24402500E+00, 0.24960000E+00, -.35312200E+00, 0.48190300E-01, 0.91272300E-01, 0.56923400E+00, -.17663300E+00, -.24717900E+00, -.28775000E+00, -.24697700E-01, -.26510800E-01, 0.33700100E-01, -.10158400E+00, -.18461500E+00, 0.59499900E-01, 0.88372600E+00, -.54385300E+00, -.15575600E-01, -.57986800E-01, 0.23217000E+00, -.31847400E-01, 0.91800900E-01, -.39146400E+00, -.10014100E-01, 0.22189600E+00, 0.12304800E+00, 0.16385800E+00, -.45281100E-01, 0.31237000E-01, 0.21379900E+00, 0.12601900E+00, 0.23236000E+00, -.25623400E-01, 0.21284500E+00, -.10810400E-01, -.28815200E-01, 0.30653400E+00, 0.35962400E+00, -.10506200E+00, -.35043000E+00, 0.51830800E-02, 0.39445600E-01, -.47911800E+00, 0.52112400E-02, 0.25157400E+00, 0.19295300E+00, 0.44004000E-01, 0.16699800E+00, 0.75114200E-01, -.31084300E+00, -.43527700E-01, -.16680900E+00, -.32548100E-01, 0.17781900E-01, 0.15866800E-02, -.13305600E+01, -.32443500E+00, -.18320900E+00, 0.15544300E+00, -.79610900E-01, 0.10691400E+00, 0.10572900E+00, 0.11954500E+01, 0.15954900E+00, 0.16525700E+00, 0.13048600E-02, -.19117400E+00, -.58289200E-01, 0.33478700E+00, 0.16702200E+00, -.44752400E-02, -.66015300E-01, 0.58275300E-01, 0.21516500E+01, 0.14057700E+01, 0.21482200E+00, -.21784600E-03, 0.20391900E+00, 0.31588300E-01, -.15544400E+00, 0.39535000E+00, -.52587500E+00, 0.11868500E+00, -.24359300E-01, -.60447900E-01, -.40819800E-01, -.17096700E+00, 0.11195100E-02, 0.14471000E+00, 0.18581200E+00, 0.13437300E+00, 0.30534000E-01, -.20806300E+00, 0.89264300E-01, 0.19213400E-01, -.69715100E-01, -.80217700E-01, 0.27854400E+00, -.27148300E-02, 0.55963200E-01, 0.27198800E+00, 0.25689300E+00, 0.19094100E+00, 0.27698300E-01, -.66574000E-01, -.49971500E-02, 0.26956300E+00, 0.10800100E-01, 0.22521500E+00, 0.31215500E-01, 0.19283000E-01, -.70713800E-01, 0.51153400E-01, -.93738900E-01, 0.34523400E+00, 0.58952500E-01, -.15267100E+00, -.36494900E-02, -.80816700E+00, -.26010300E+00, 0.74156100E-02, -.41819000E-01, 0.85018000E-01, -.62203300E-01, -.12021100E-01, 0.21755400E-01, 0.44095600E-01, 0.13082100E+00, 0.17234600E-04, 0.75526800E-01, 0.41605000E+00, 0.11940900E-01, -.72231400E+00, 0.22531000E+00, 0.11863200E+00, -.37312300E-01, 0.87866400E-01, 0.44337300E+00, -.25256200E+03, 0.91781600E+02, -.45741000E+02, 0.19296300E+02, -.45891500E+02, 0.31134100E+02, 0.30704700E+02, -.31673000E+02, 0.59918100E+01, -.40717600E+02, 0.18382900E+02, -.33570000E+02, 0.20474400E+02, -.10376900E+02, -.21424600E+02, -.10085000E+02, -.20988400E+02, -.51599300E+01, 0.84709600E+02, 0.11617500E+03, 0.48856400E+02, -.14469300E+02, 0.32828700E+02, -.22935800E+03, 0.11540600E+03, 0.77527300E+02, 0.11463800E+03, 0.67585800E+01, 0.11513300E+02, 0.64688000E+02, -.74693100E+01, 0.29404300E+02, -.67862200E+01, 0.11562400E+03, -.95124500E+02, 0.47356000E+02, -.19915000E+02, 0.47574200E+02, 0.19108300E+01, -.11059600E+02, 0.13890600E+02, -.37389700E+02, 0.65580300E+02, 0.25213600E+02, 0.50889900E+02, -.47042200E+02, 0.23614300E+02, -.20394700E+02, 0.23648700E+02, 0.53468900E+02, 0.47195600E+02, -.28008300E+01, 0.88389200E+01, 0.12821200E+02, 0.28126900E+02, 0.41731600E+02, -.75042900E+02, 0.37517100E+02, 0.10000400E+02, 0.37424600E+02, 0.13396600E+02, -.10141800E+02, 0.38431600E+01, -.19258300E+02, 0.32567900E+02, -.58331200E+01, 0.35864800E+02, -.36374500E+02, 0.18524000E+02, -.24986300E+02, 0.18242900E+02, 0.20175400E+02, 0.31138100E+02, -.33766200E+01, -.85393800E+02, -.42323500E+02, 0.54285400E+02, -.29755200E+00, 0.10387600E+02, 0.44415700E+01, 0.30676300E+00, -.53275200E+01, 0.13587700E+02, -.10339900E+02, -.96239600E+01, -.54305700E+01, -.71691300E+00, 0.63055000E+01, 0.30057200E+01, 0.27198400E+01, 0.33002400E+01, 0.30833000E+01, 0.23172400E+01, -.53231600E+01, 0.23376900E+01, -.69631900E+01, 0.25139800E+00, -.11487900E+01, -.26750700E+01, 0.17627300E+02, -.48815600E+01, 0.89288700E+01, -.24076000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54738500E+00, 0.11823600E+00, 0.45948400E-01, -.67433500E+00, 0.59920900E+00, 0.16213400E+00, 0.55660200E+00, 0.86202800E+00, -.62897800E+00, -.49867800E+00, -.84674400E-01, 0.10702100E+00, -.40822400E+00, -.59904400E+00, 0.34026400E+00, -.17131700E+00, -.11513700E+00, -.38500100E+00, -.83365500E+00, -.93370900E+00, -.46535500E+00, -.42276800E-01, 0.19985600E+00, 0.46625600E-01, 0.47143300E-01, -.18102600E-01, -.36030300E+00, 0.25134700E-01, -.16283800E+00, 0.10348900E+00, 0.63459500E-01, 0.42751900E-01, -.92112600E-01, -.87277800E+00, -.67001400E-02, -.56634500E+00, -.17895400E-01, 0.26667700E+00, -.21735600E+00, -.78531600E-01, -.37479200E+00, -.38849700E-01, 0.47774200E+00, 0.12798500E+00, -.66143100E-02, -.38669400E+00, 0.25004500E+00, -.42237400E-02, 0.48601300E+00, -.20712700E+00, 0.27866300E+00, -.62481000E+00, 0.40948500E-01, -.24430200E+00, 0.12668000E+00, 0.10351500E+00, -.13098900E+00, -.50924700E+00, -.94922500E-02, 0.38824300E+00, -.17019500E-01, 0.12527500E+00, -.11783300E+00, -.69127700E+00, 0.75899700E+00, 0.58868100E-01, 0.61364500E-01, 0.87636200E+00, -.18405900E+00, 0.74810400E-01, -.11049500E+01, 0.11237500E+00, -.11144900E+00, -.39232100E-01, 0.17887500E-01, -.49628700E-01, 0.39038500E-01, 0.24867200E+00, 0.15193200E-02, -.47198400E-01, -.67684100E-01, -.11049100E+00, -.96097000E-01, -.13871400E-01, -.43426900E+00, 0.17225600E+00, 0.26205300E-01, -.20212100E+00, 0.53239600E-01, -.21701600E-01, -.19312600E+00, -.56044700E-01, 0.24957700E+00, -.68656200E-01, 0.20024500E-01, 0.60843700E-01, -.31872800E+00, -.23515500E+00, -.13656700E+00, -.23615700E+00, -.27897100E-01, -.33019200E+00, -.39863300E-03, 0.11960200E+00, 0.31817100E+00, 0.42939100E-02, -.98788400E-02, -.56715200E+00, 0.18804200E+00, -.98850200E-02, 0.26107900E-01, -.17934300E-01, -.50927800E-01, 0.13355700E-03, 0.41934500E-01, 0.11762500E-01, -.29966000E-01, -.17087900E+00, 0.26680200E+00, -.50540800E-01, 0.68490600E-02, 0.71982900E+00, 0.53363900E+00, -.31468000E+00, 0.51824200E-02, 0.23925400E+00, 0.51843600E-02, 0.55552200E-01, -.25536100E+00, 0.16766800E+00, 0.81558800E-01, -.18050800E+00, -.34571500E+00, -.43112100E-02, -.24413900E+00, -.13120300E-01, -.42692800E-02, 0.15740100E+00, 0.37062000E-01, 0.10196700E+00, -.10110500E+00, 0.83947200E-01, -.57876900E-01, -.21969900E-01, -.33000400E-01, 0.18412900E-01, -.12572200E-02, 0.24263200E-01, -.96725300E-01, -.20181300E+00, -.48477900E-01, -.10949500E+00, -.78976100E-01, 0.62325400E-01, -.17275600E+00, 0.62737300E-02, -.10740700E+00, -.41604500E-02, -.18993100E+00, 0.39565600E+00, 0.60985200E-01, 0.98874900E-01, -.32293200E+00, -.22544500E-01, -.20222900E+00, 0.15733400E+00, 0.20652600E-01, -.69390900E-01, 0.68298300E-02, -.94021600E-01, -.24772400E+00, 0.32439600E+00, 0.53488400E+00, 0.83219200E+00, -.14040900E+00, -.24724200E+00, -.15182500E-01, 0.87288500E-01, -.21602500E+00, 0.27697200E-01, 0.36060600E+00, -.96828500E-01, 0.34498100E-01, -.56218700E-01, -.52886200E-01, -.37995100E+00, 0.72260300E-01, -.26274200E+03, 0.13134900E+03, 0.75110500E+02, 0.13139100E+03, 0.60996100E+02, -.14214200E+02, 0.56902000E+02, -.14224000E+02, 0.10087500E+03, 0.30693900E+01, 0.43018900E+02, 0.11271300E+03, -.56705400E+02, -.19857000E+02, -.55794400E+02, -.37744300E+02, -.60333600E+01, -.13689000E+02, 0.25602600E+02, -.31406400E+02, -.60450000E+01, -.57721600E+02, -.14671900E+03, 0.73931100E+02, 0.73334200E+02, 0.73230000E+02, -.26720100E+01, 0.43839600E+01, 0.57926700E+02, 0.11820700E+02, 0.63260800E+02, 0.30704500E+01, 0.37310700E+02, 0.63699300E+01, -.22865000E+01, 0.10272300E+02, -.31370800E+01, -.13054600E+02, 0.91496700E+01, -.94418600E+01, -.51401900E+01, -.15728400E+02, 0.63236700E+01, -.26383300E+02, -.12666600E+03, 0.63679700E+02, 0.83455600E+02, 0.63686700E+02, 0.30956000E+02, 0.54141300E+01, 0.27803700E+02, -.10544700E+02, 0.41628300E+02, 0.21915700E+02, -.68355600E+01, -.49320300E+02, 0.24578100E+02, 0.19980900E+02, 0.24535500E+02, 0.31937200E+01, -.25608600E+01, 0.13531900E+02, -.18557300E+02, 0.52481900E+01, 0.36437300E+01, 0.41219600E+02, 0.13932900E+01, -.16986900E+01, 0.26955000E+01, -.45802900E+00, -.31970100E+02, 0.40332300E+01, 0.25217700E+01, 0.58986800E-01, -.34947900E+02, 0.22995800E+01, 0.44746300E+02, 0.25581600E+01, 0.11172000E+01, -.13892000E+01, -.30943700E+01, -.86347200E+01, 0.20580400E+01, 0.35416500E+01, -.31290100E+01, 0.14007100E+01, 0.30809500E+01, 0.19792300E+01, 0.49068400E+01, -.69745500E+00, 0.49099100E+01, 0.56221500E+01, -.30990200E+01, 0.18695300E+01, -.23944300E+01, 0.10918000E+02, -.52061800E+01, 0.57010900E+01, 0.14157000E+01, 0.19629900E+00, 0.61641900E+01, 0.49110300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18918800E+01, -.24440600E+01, -.26012200E+01, 0.31243900E+01, -.33745600E+01, -.91561700E+00, -.10422800E+01, -.21997700E+01, 0.31260700E+01, 0.93040000E+00, -.95055300E-01, 0.10413600E+00, -.19523700E+01, -.44329400E-01, -.22195900E+01, 0.21454000E+00, 0.34264200E+00, 0.10290400E+01, -.17107800E+01, 0.63189800E+00, 0.11375600E+01, -.31408600E+00, 0.13684800E+01, -.53694400E-01, 0.16658100E+00, -.18289900E-01, -.23515500E+01, 0.60608500E+00, -.38989400E-01, 0.96291300E+00, 0.98135300E-01, -.26088900E+00, 0.14424300E+00, -.10832200E+01, -.67547000E+00, 0.30254100E+00, 0.57338200E-03, -.21511800E+01, 0.31315700E+00, -.15854200E+01, -.16062400E+01, -.16705000E+00, 0.23337100E+01, 0.87537300E-01, 0.45647300E+00, -.69870000E+00, 0.88242900E+00, -.58908700E-02, -.57660500E+00, 0.60555700E+00, 0.12399100E+01, -.14112300E+01, 0.19090800E+00, 0.37736500E+00, 0.43863800E+00, 0.71229900E-02, -.65416200E+00, -.30603400E+01, -.38008300E-01, 0.13916500E+01, 0.28984200E+00, 0.45793900E+00, -.60293000E-02, 0.18229300E+00, -.14992200E+01, 0.37077400E+00, -.10463000E+00, 0.66752400E+00, 0.78882900E+00, -.51706600E+00, 0.23306000E+01, -.16529300E+01, 0.98298400E+00, 0.68376200E-01, 0.60758900E+00, -.13143600E+01, 0.18798900E-01, 0.14767000E+01, 0.15564100E+00, -.16448400E+00, 0.26368300E+00, -.92116300E+00, 0.65153100E+00, 0.11494600E+01, -.15873700E+01, -.20430200E+00, 0.34574000E+00, -.18939000E+00, -.31452900E-01, 0.15113600E+01, -.67157000E+00, 0.11137700E-01, -.60151500E+00, 0.25290300E+00, 0.22459300E+01, -.24730200E+01, -.14968000E+01, -.10317400E+01, -.62196200E+00, 0.10844600E+01, 0.15306200E+00, -.29615900E+00, 0.95385200E-02, 0.10728000E+01, -.18300500E-01, -.50407700E+00, -.43745200E+00, -.96772700E+00, -.95108800E+00, -.67894000E+00, -.15176100E+01, -.32453100E+00, 0.42760100E-02, 0.31239600E-02, 0.27989000E+00, 0.76609600E+00, 0.78239900E+00, -.60594300E+00, 0.13040400E+01, -.57465500E+00, 0.13237300E+00, -.17882400E+01, -.33878400E+01, 0.39692300E+00, 0.14084000E-01, -.82531900E+00, 0.54510600E+00, 0.12779400E+00, -.33336600E-01, 0.29306400E+00, -.89262400E+00, 0.44050400E-01, 0.26873400E+00, -.67577100E-01, 0.35481700E+00, 0.11640200E-01, -.62221000E+00, -.17874600E+00, -.46413700E-01, -.45874900E-01, -.87116400E+00, 0.26765600E+00, -.27554400E+00, 0.15856500E+00, -.66042000E+00, 0.41376500E+00, 0.39675700E-01, -.49861700E+00, 0.60526300E+00, 0.46243200E-01, -.59661900E-01, -.26110800E+00, 0.43938900E-01, -.35211700E+00, -.11675100E+00, 0.41097200E-02, 0.31177300E+00, -.38270700E-01, 0.32759000E+00, -.80878900E+00, -.10924800E+00, -.77593100E+00, 0.26404600E+00, -.39878700E+00, 0.98694100E+00, -.40861600E+00, 0.13890200E+00, 0.10823900E+01, 0.99423800E-01, 0.18968200E+00, 0.96218000E+00, 0.13411200E+01, -.12083900E+01, 0.32912500E+00, 0.17981600E+00, 0.82619300E-01, -.77218000E-01, -.30754800E-01, -.87594500E+00, -.20558500E-01, 0.25513300E+00, -.16967200E+00, -.47642400E+00, 0.82948900E-01, 0.21571900E-01, -.67387200E+00, -.49029500E+00, 0.68389800E+00, 0.57027000E+01, 0.28768600E+02, -.19230000E-01, -.89307900E+02, 0.22644800E+02, -.60721800E+02, -.31371700E+02, 0.17899700E+01, 0.32838600E+01, 0.97013600E+02, -.41005600E+03, 0.20536800E+03, 0.65669800E+02, 0.20465500E+03, 0.13439200E+03, 0.59012200E+02, 0.75386400E+00, -.11195000E+03, 0.12407100E+03, 0.59376900E+02, 0.17854800E+03, 0.18106400E+03, -.91843400E+02, -.10710800E+03, -.90445900E+02, 0.39306600E+02, -.97808900E+01, -.51917700E+02, 0.18115100E+02, -.58256100E+02, 0.61967300E+01, -.26589700E+02, -.65647000E+01, 0.40299500E+01, 0.10149700E+02, 0.32536400E+01, 0.88093600E+01, -.10848100E+02, 0.13175300E+02, -.12328000E+02, -.19406000E+02, -.22423800E+02, 0.10507500E+03, -.99733500E+02, 0.49099100E+02, 0.10039200E+02, 0.49626200E+02, -.31694600E+02, -.43170700E+02, 0.81742500E+01, -.19148200E+02, 0.54875000E+02, -.43598800E+02, 0.10233700E+03, -.50926500E+01, 0.18761300E+01, 0.16650000E+02, 0.26026900E+01, 0.12759600E+02, 0.32035800E+02, -.27945100E+02, 0.39842600E+01, -.64084200E+02, 0.35395200E+02, -.80322400E+02, 0.39196100E+02, -.19959200E+02, -.75661100E+01, -.19739800E+02, 0.21187000E+02, -.48763500E+02, 0.31342800E+01, -.26416100E+01, 0.17908700E+02, -.72850300E+02, 0.21848900E+01, -.35409000E+01, -.83063900E+01, -.33046800E+01, 0.58723900E+00, -.51712800E+01, 0.20827900E+01, -.16584200E+01, 0.60929100E+00, 0.34223400E+01, -.15438200E+01, -.34020400E+00, -.28625600E+01, 0.39933600E+01, -.26984100E+01, -.99286600E+01, 0.58343900E+00, 0.34176300E-01, -.89503700E+00, -.24168900E+02, 0.17758800E+02, -.17714100E+01, 0.21358700E+01, 0.50119700E+01, -.18248700E+02, 0.26796900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.96141300E+00, -.14149500E+00, 0.39056100E+00, 0.25831700E+01, 0.41989800E+00, -.28290600E+00, -.20229800E+01, -.11856900E+01, 0.28866100E+01, 0.87956700E+00, 0.11867800E+00, 0.24337800E+00, -.13116200E+00, 0.75622500E+00, -.60169000E+00, 0.33361800E+00, -.80068300E-01, -.70693100E-01, 0.14196200E+00, -.66076600E+00, -.11005500E+00, -.69460200E-01, 0.41770600E+00, -.62817900E+00, -.52491500E-01, -.96254300E-01, -.10250800E+01, 0.91693000E-01, -.42012500E+00, 0.24356200E+00, 0.37798400E+00, 0.21591100E+00, -.34953600E+00, -.19312800E-01, -.20809800E+00, -.70449500E+00, -.35086000E-01, -.59688900E+00, 0.34215600E+00, -.37827300E+00, -.22719600E+00, 0.15758800E+00, 0.36511800E+00, 0.43342700E-01, -.25694100E+00, -.14516800E+00, 0.19967300E+00, -.53705700E-02, -.23613200E+00, 0.47549700E+00, -.28007200E+00, 0.88972300E-01, 0.52429700E-02, 0.26791900E+00, 0.14074100E+00, 0.34911200E+00, -.65001800E-01, -.63393900E+00, -.51344500E-01, 0.43390700E+00, 0.19953700E-01, -.23762200E+00, 0.15109900E-01, -.18604600E+00, 0.35514200E+00, 0.12048000E+00, -.10570200E+00, -.15009200E+01, -.79421500E+00, -.57319100E-01, 0.10516700E+01, -.27920100E-01, 0.18264200E+00, -.22410100E-01, -.20029900E+00, -.53602700E-01, -.89971100E-01, -.45911300E+00, -.50112100E-01, -.25986600E-01, 0.80513100E-01, -.38217700E+00, 0.53809300E+00, 0.12960900E+01, 0.12851300E+01, -.72150100E+00, 0.59237200E-01, 0.46825500E+00, -.33366600E+00, 0.42832100E+00, 0.10324200E+00, 0.13685400E+00, -.12259000E+01, 0.26661800E+00, -.11740500E+01, 0.12805400E+01, 0.87574000E+00, 0.18826900E+01, 0.23128200E+00, 0.39187100E+00, -.45987600E+00, 0.47225000E-02, 0.11227700E-01, 0.63917700E+00, -.27908100E+00, -.35631200E+00, -.17692100E+00, 0.17152200E+01, 0.23310300E+00, -.32010300E+00, 0.29599200E+00, 0.21343100E+00, 0.55958800E-01, 0.34314000E-03, -.24998800E-01, -.13335500E+00, -.52444000E+00, -.38503700E+00, 0.14922400E+01, 0.26460400E+00, -.32267400E+00, 0.17009600E+01, 0.79228100E+00, -.13181900E+00, -.16452700E-01, 0.70891700E+00, 0.80168300E+00, -.48474900E+00, 0.15630200E+01, 0.10212100E-01, -.97790600E+00, 0.17143300E+00, 0.54748800E+00, 0.84571400E+00, 0.82434600E+00, 0.65969300E-02, -.42133100E+00, 0.23516200E-01, 0.26428900E-01, 0.16207600E-02, 0.12618000E+01, 0.23228400E+00, -.31622300E+00, -.28916800E+00, 0.87455900E-01, 0.19924100E+00, -.70701100E-04, -.12616300E+00, -.36870900E+00, -.31708900E+00, 0.20804100E+00, 0.12536700E+00, -.13625200E+00, 0.11406500E+00, -.34990000E+00, -.60792500E-02, 0.25762900E+00, -.79619900E-01, 0.21314500E+00, 0.11449700E+01, 0.10300400E+00, 0.15232000E+00, 0.63474700E+00, 0.39637300E+00, -.69773400E-01, 0.34227500E-01, -.12980500E+00, -.36502400E+00, -.16525800E-01, -.18800900E-01, -.31715000E+00, 0.54536400E+00, 0.84882200E+00, 0.12039400E+01, -.12161000E-01, -.20468000E+00, -.86762600E-01, 0.26128800E+00, 0.34654800E+00, 0.26395300E-01, 0.28974200E+00, 0.46080100E+00, -.32667200E+00, -.27004700E+00, 0.27330000E-01, -.82759000E+00, 0.12598900E+01, 0.17673800E-01, 0.60728100E-01, 0.91227800E+02, -.15943000E-01, 0.52726600E+02, 0.63872900E+02, -.34336500E+02, -.16122000E+02, -.11043400E+02, 0.51611900E+02, -.40661000E+02, -.12610900E+03, 0.62837600E+02, -.42391200E+02, 0.62593300E+02, 0.39605900E+02, 0.32694600E+02, 0.44695900E+02, -.29695800E+02, 0.38942300E+02, 0.33239600E+02, 0.41641800E+02, -.21463100E+03, 0.10826600E+03, 0.64033900E+02, 0.10740400E+03, -.12719100E+02, -.15021100E+02, 0.72133900E+02, -.71118600E+00, 0.90371900E+02, -.29245700E+02, 0.93946200E+02, -.10026600E+03, 0.50406900E+02, 0.44331300E+01, 0.50076400E+02, -.28438800E+01, -.11761900E+02, 0.55828000E+01, -.57492400E+02, 0.42868700E+02, -.18970400E+00, 0.43477700E+02, -.16089100E+03, 0.80740900E+02, 0.95833700E+01, 0.80273500E+02, 0.17185900E+03, 0.48150600E+01, 0.78870300E+01, -.65595300E+01, 0.14362400E+03, -.11447900E+02, 0.20394000E+02, -.16249600E+02, 0.78284700E+01, 0.34020000E+02, 0.80911900E+01, 0.38539700E+02, 0.14595700E+02, -.44307600E+02, -.10991000E+02, 0.14620800E+03, 0.21214900E+02, 0.62574800E+02, -.16544200E+03, 0.80923400E+02, 0.17819400E+02, 0.82414400E+02, 0.30399400E+01, 0.21761600E+02, 0.74941300E+02, -.23543200E+02, 0.67509100E+01, 0.35518100E+02, 0.44318300E+02, 0.25560800E+02, 0.27477700E+01, 0.20706900E+02, 0.13785100E+02, 0.85306000E+01, 0.22439000E+01, -.10649800E+01, 0.12887900E+02, -.21068100E+02, 0.15631700E+02, 0.12585000E+01, -.99481600E+01, 0.11532200E+02, -.97937700E+01, -.19449800E+02, 0.13223800E+02, 0.18623400E+01, -.97883300E+01, -.23312700E+02, 0.16976700E+02, 0.48816300E+01, 0.25537900E+02, 0.44548100E+01, 0.25230100E+02, -.29166700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19418300E+01, 0.64822300E+00, 0.72938000E+00, 0.24300000E+01, 0.20336300E+01, 0.60124100E-01, -.23066800E+01, -.21996100E+01, 0.32869900E+01, 0.11311200E+01, 0.96319600E-01, 0.34055900E+00, -.10303200E+01, 0.43523600E+00, -.21126100E+01, 0.59169700E+00, 0.13767600E+00, 0.35568900E+00, -.14550500E+01, -.63933300E+00, 0.17514400E+01, -.29455400E+00, 0.11989400E+01, -.17898200E+01, 0.12382000E+00, -.96715400E-01, -.28251200E+01, 0.62178700E+00, -.82156300E-01, 0.57293900E+00, 0.71758200E-01, -.42697000E+00, -.30055400E+00, -.42896100E+00, 0.17262200E+00, -.48758200E+00, -.27688200E-01, -.69651100E+00, 0.16902800E-01, -.17218000E+01, -.13110300E+01, -.84276000E-01, 0.20085600E+01, 0.13043800E+00, 0.18566800E+00, -.46355100E+00, 0.79277900E+00, -.12554200E-01, -.42547400E+00, 0.31560500E+00, 0.53556000E-01, -.28580900E+01, 0.11985900E+00, -.65550900E-01, 0.32712100E+00, 0.21648000E+00, -.20134500E+00, 0.10429100E+00, -.43175100E-01, 0.11022800E+01, 0.25511600E+00, -.49291900E-01, -.26799100E-01, -.12124600E+01, 0.54511900E+00, 0.53048600E+00, -.38223500E+00, -.16816400E+01, -.57023100E+00, -.38475500E+00, 0.13303700E+01, -.89761600E+00, 0.39446700E+00, 0.14287200E+00, 0.11204000E+00, 0.45065100E-01, -.76249200E-01, 0.29724900E+00, 0.30833900E+00, 0.90703100E-01, 0.32254700E+00, -.40521300E+00, 0.64221600E+00, 0.18663600E+01, 0.81749700E+00, -.59486800E+00, 0.33163200E+00, 0.42038900E+00, -.63903500E-01, 0.50419300E+00, 0.23502800E+00, 0.13324600E+00, -.53137300E+00, -.25990400E-02, 0.39742100E+00, -.88312400E+00, 0.76825200E+00, 0.51034900E+00, 0.35015100E+00, 0.13429200E+00, 0.10763800E+00, -.17773900E+00, 0.22200700E-02, 0.16276300E+01, -.85184400E+00, 0.26412900E-01, -.23348500E+00, 0.29923400E+00, 0.45960000E+00, -.10150500E+01, -.50860000E+01, -.63726200E+00, 0.26173300E+00, -.36604100E-02, 0.91690700E-01, -.35757400E-02, 0.77858100E+00, -.60874000E+00, 0.18271700E+01, -.23747700E+00, -.45929900E-01, -.45358800E+00, -.16535500E+01, -.16576500E+00, -.78595300E-02, 0.17603600E+00, 0.10053400E+01, -.16021800E+00, -.63100100E-01, 0.23240300E+00, -.90121000E+00, 0.12311600E+00, 0.19960800E-01, 0.28908200E+00, 0.94364500E+00, -.57352100E-02, 0.61866100E+00, -.27603900E+00, -.27892100E+00, -.25338600E+00, 0.75518200E+00, 0.27410100E+00, 0.58633300E-02, 0.72285000E-01, -.30483900E+00, 0.29126800E+00, 0.18097100E-01, -.70852200E-01, 0.56763600E+00, 0.11580100E-01, 0.57029200E-01, -.42631100E+00, -.22428500E+00, -.39131800E+00, 0.15454200E+00, 0.68061000E-01, -.47564800E+00, 0.12468600E-01, 0.57528400E-01, -.32605600E+00, -.17451500E+00, -.17041500E+00, 0.77438200E-01, -.84421300E-01, 0.41060000E+00, -.15510400E+00, 0.35142200E+00, 0.10295300E+01, 0.56611900E-01, 0.21637000E+00, 0.60234100E+00, 0.97834200E+00, -.58738100E+00, -.14409200E-03, 0.14053300E+00, 0.30272200E-01, -.66920900E-01, -.10966200E+00, -.90023400E+00, -.21708800E-01, 0.14478900E+01, -.15531900E+00, -.17322300E+00, -.96168700E-02, -.79586300E-01, -.78276300E+00, -.77332000E+00, 0.16133100E+01, 0.82418000E-01, 0.42045500E+00, 0.55652500E+01, -.14408400E+03, 0.29852800E+02, -.47456300E+02, -.39891900E+02, -.86168800E+00, 0.47871600E+01, 0.76542000E+02, -.42265800E+03, 0.21258100E+03, 0.10328200E+03, 0.21033200E+03, 0.18549200E+03, 0.73885600E+02, 0.32953200E+02, -.97393700E+02, 0.46140700E+02, 0.79114000E+02, 0.15465600E+03, 0.17560400E+03, -.88599000E+02, -.65005700E+02, -.87556900E+02, 0.10662100E+02, 0.19481800E+02, -.73317500E+02, -.67233200E+01, -.82189300E+02, 0.29881300E+02, -.11783700E+02, 0.16026200E+02, -.13058100E+02, 0.29366700E+02, -.81018200E+01, 0.73273300E+02, 0.59260600E+01, 0.16366500E+02, 0.17849500E+02, -.18970600E+02, 0.11859800E+02, 0.15847200E+03, -.18232100E+02, 0.78515200E+01, 0.51245600E+01, 0.84197000E+01, -.11294600E+03, -.57658800E+02, 0.10072900E+02, 0.63107800E+01, 0.46287900E+01, -.62938200E+02, 0.10335500E+03, 0.15132300E+03, -.75872700E+02, -.71019000E+02, -.75224300E+02, -.64579900E+02, -.43832100E+02, -.33703000E+02, 0.54813000E+02, -.68508000E+02, -.61340900E+02, -.18000300E+03, 0.76502000E+02, -.37083500E+02, 0.11054900E+02, -.38683800E+02, 0.99234900E+02, 0.77658000E+01, -.15082900E+02, -.11881500E+01, 0.18704900E+02, 0.53617000E+01, -.49432000E+02, 0.17294000E+01, 0.30416900E+01, -.41679200E+01, 0.93901500E+01, -.31265500E+01, 0.13071400E+01, -.36175700E+01, 0.96972800E+01, 0.44296300E+01, -.25258700E+01, 0.25821300E+01, -.14761600E+02, 0.15449600E+02, -.15043300E+02, 0.24827900E+01, 0.94509000E+01, 0.28239500E+01, -.94248000E+01, -.11541800E+02, 0.29836700E+02, -.64345700E+01, 0.16064700E+02, 0.29659200E+01, -.29805100E+02, -.12303600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.38934600E+01, -.12907900E+01, -.14394500E+01, -.35406600E+01, -.34732700E+01, -.20046100E+00, 0.34663900E+01, 0.19807600E+01, -.68250800E+01, -.20277200E+01, -.14243800E+00, 0.16215100E+01, 0.24453200E+00, -.14044800E+01, 0.37974500E+01, -.31031800E+01, -.14449600E+01, 0.93359100E-01, 0.29663200E+01, 0.14165300E+01, -.41315700E+01, 0.43822000E+00, -.21344000E+01, 0.35225000E+01, -.63715900E-01, 0.42236500E+00, 0.53967900E+01, -.13132700E+01, 0.13199800E+00, -.14468000E+01, -.33548400E+00, 0.86903600E+00, 0.62553100E+00, 0.81830800E+00, -.30567000E+00, 0.78313000E+00, 0.32911000E-01, 0.12626500E+01, -.11105700E+00, 0.34059000E+01, 0.27457000E+01, 0.26073900E+00, -.37802100E+01, -.23391200E+00, -.35929700E+00, 0.96779000E+00, -.14744000E+01, 0.20184500E-01, 0.85141600E+00, -.37687500E+00, -.24739100E-01, 0.56497500E+01, -.21024300E+00, 0.30916100E+00, -.57664100E+00, -.26777500E+00, 0.37744000E+00, -.45803500E+00, 0.49353200E-01, -.20583900E+01, -.48601000E+00, 0.69391300E-01, 0.36169400E-01, 0.22250700E+01, -.68637700E+00, -.96984200E+00, 0.74752100E+00, 0.28851000E+01, 0.73664200E+00, 0.82621000E+00, -.27905200E+01, 0.16514000E+01, -.64137900E+00, -.42013500E-01, -.14231300E-01, -.31341000E+00, 0.98126000E-01, -.63303000E+00, -.49912300E+00, -.81653400E-01, -.63282100E+00, 0.92483300E+00, -.11853700E+01, -.33899700E+01, -.11314400E+01, 0.10406900E+01, -.54376100E+00, -.72758500E+00, -.16925000E-02, -.10927500E+01, -.54355800E+00, -.26845700E+00, 0.11874700E+01, 0.12686700E+00, -.91767700E+00, 0.19574000E+01, -.16271700E+01, -.84560900E+00, -.75027900E+00, -.42227100E+00, -.23261100E+00, 0.31670400E+00, -.93006800E-02, -.38109200E+01, 0.16258100E+01, -.11644000E+00, 0.50929700E+00, -.87938300E+00, -.10264500E+01, 0.18511600E+01, 0.10204400E+02, 0.12797300E+01, -.52043700E+00, 0.51761900E-02, -.21577700E+00, 0.15806800E-01, -.18907900E+01, 0.11399000E+01, -.33995600E+01, 0.52895500E+00, 0.82861700E-01, 0.10474400E+01, 0.32973900E+01, 0.40312200E+00, 0.80410900E-02, -.37501000E+00, -.20207600E+01, 0.39272500E+00, 0.14165800E+00, -.40682500E+00, 0.17952200E+01, -.27093800E+00, 0.76272700E-01, -.54380300E+00, -.21594100E+01, -.17771500E-01, -.96526500E+00, 0.75542100E+00, 0.43204000E+00, 0.46231800E+00, -.13713500E+01, -.56328500E+00, -.21075700E-01, -.14649100E+00, 0.58334900E+00, -.50577600E+00, -.41332500E-01, 0.13205300E+00, -.12237100E+01, 0.22215300E-02, -.88152000E-01, 0.82389500E+00, 0.32229600E+00, 0.80175400E+00, -.22978000E+00, -.11726300E+00, 0.97254900E+00, -.44405500E-02, -.12420900E+00, 0.52659800E+00, 0.30781800E+00, 0.30720600E+00, 0.66386700E-01, 0.22751900E+00, -.71349800E+00, 0.32280400E+00, -.62762000E+00, -.22399800E+01, -.18025800E+00, -.48059500E+00, -.12487200E+01, -.19712100E+01, 0.12550000E+01, -.80203300E-01, -.32980000E+00, -.10354900E+00, 0.99571400E-01, 0.22763700E+00, 0.21081800E+01, 0.50997300E-01, -.30647300E+01, 0.31918400E+00, 0.20920900E+00, -.29684500E-01, 0.19644600E+00, 0.14759900E+01, 0.16133400E+01, -.32882200E+01, 0.23727600E+00, -.11409700E+01, 0.43733000E+00, 0.40260800E+03, -.79335200E+02, 0.14846500E+03, 0.11664700E+03, 0.14095200E+01, -.77884900E+01, -.25253100E+03, 0.12011200E+04, -.60396800E+03, -.31372200E+03, -.59764700E+03, -.52403800E+03, -.22262500E+03, -.63055200E+02, 0.28161400E+03, -.15058000E+03, -.23023600E+03, -.44892900E+03, -.53820600E+03, 0.27171200E+03, 0.20378600E+03, 0.26840900E+03, -.47142400E+02, -.51400400E+02, 0.21072400E+03, 0.45055900E+01, 0.25062500E+03, -.85589300E+02, 0.52930900E+02, -.76288700E+02, 0.50411300E+02, -.69407100E+02, 0.38379800E+02, -.18689000E+03, -.22105300E+02, -.37308200E+02, -.50049500E+02, 0.66141800E+02, -.34689000E+02, -.42015100E+03, 0.92275700E+02, -.42571900E+02, -.24928800E+02, -.44172700E+02, 0.32545300E+03, 0.12926000E+03, -.20540800E+02, 0.42154200E+01, -.52408900E+01, 0.14174000E+03, -.33491700E+03, -.36515000E+03, 0.18324400E+03, 0.18566500E+03, 0.18173600E+03, 0.17398400E+03, 0.11526900E+03, 0.69117300E+02, -.14306500E+03, 0.22790300E+03, 0.15816100E+03, 0.49979400E+03, -.25601400E+03, 0.12461200E+03, -.14846600E+02, 0.12915600E+03, -.26220900E+03, 0.47595900E+00, 0.56974800E+02, 0.77816100E+01, -.38253800E+02, 0.18197200E+02, 0.15202300E+03, 0.50978700E+01, -.47680600E+01, 0.18478700E+02, -.20003300E+02, 0.89609100E+01, -.37269300E+01, 0.88206300E+01, -.21200600E+02, -.19301400E+02, 0.11340100E+02, -.90927400E+01, 0.36216300E+02, -.35713700E+02, 0.36784300E+02, -.61554300E+01, -.20509000E+02, -.94023600E+01, 0.22901500E+02, 0.36033900E+02, -.73434500E+02, 0.14664000E+02, -.35987900E+02, -.62534700E+01, 0.86384300E+02, 0.23182800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12128500E+01, 0.30670300E-01, -.12178700E+01, -.17576500E-01, -.79063500E+00, -.13118400E-01, 0.17664000E+00, -.86980300E-01, 0.15203600E+01, 0.16387800E+00, 0.82014000E-01, -.77675400E+00, -.83863800E+00, 0.95192100E-01, -.51896700E+00, 0.25676400E+00, 0.24747300E+00, 0.47114500E+00, 0.75500200E+00, 0.15003600E+01, -.86978500E+00, -.22864900E-01, 0.25284000E+00, 0.39929100E+00, -.92477700E-01, -.10679700E+00, 0.68387000E+00, -.64083000E-01, -.44651900E+00, -.11904800E+01, 0.53230800E+00, 0.18377800E+00, -.10706900E+00, 0.92405700E-01, -.25336500E+00, 0.38571200E+00, 0.36258900E-02, -.64759500E+00, 0.25890200E+00, -.14882200E+00, -.80914400E+00, -.12911500E+00, 0.52591400E+00, 0.98911000E-01, -.43653000E+00, -.53834800E+00, -.22185500E+00, 0.39399200E-02, -.95854800E+00, 0.95096100E+00, 0.85204900E+00, 0.53297500E+00, 0.11545300E+00, 0.38006800E+00, 0.13227800E+00, 0.11284600E+00, -.12302500E+01, -.31546100E+01, -.35330500E-01, 0.82060300E+00, -.15247700E+00, -.49673000E+00, -.32212100E-01, 0.77960800E+00, 0.25798000E+00, 0.90113900E-01, -.13204600E-02, -.13237900E+00, -.51396100E+00, -.11677500E+00, 0.28178600E+01, 0.33244700E-01, 0.45884100E+00, -.63468500E+00, -.34654400E+00, 0.19744900E+00, 0.15017400E+00, 0.13169800E+01, -.15683900E-01, -.31885100E+00, -.17043000E+00, -.11598000E+01, 0.25062000E+00, 0.61975700E+00, -.13929300E+00, 0.20942500E+00, -.25582000E+00, 0.61166100E-01, 0.16879700E-01, 0.96287400E+00, -.37328100E+00, 0.61125500E-01, -.61557000E+00, 0.43028500E-02, -.22220600E+00, 0.98624200E-01, 0.12122200E+01, 0.74320800E+00, -.33791100E-02, -.47391600E+00, -.21712700E+00, 0.18848500E-02, -.14896200E-01, 0.16606300E+01, 0.56223700E+00, 0.25367100E+00, 0.12488700E+00, -.44463800E+00, 0.57195400E+00, -.20738600E+00, -.55014700E+00, 0.35840000E-01, 0.29641700E+00, -.27750700E-02, -.10280900E+00, -.27869300E-01, -.14828400E+01, -.14938100E+01, 0.10706300E+01, -.26209900E+00, 0.41867200E+00, 0.75909700E+00, -.16216400E+01, -.81837600E-01, 0.13545700E-01, -.19179500E+00, 0.69049200E+00, -.85876300E+00, 0.14707500E+01, -.16730100E+00, -.13271300E+01, -.15233500E+00, -.28445200E+00, -.19260100E+00, -.44702900E+00, 0.24178400E-01, -.43031600E+00, 0.14908700E+00, 0.74896700E+00, 0.26283100E+00, -.37963200E+00, -.45152100E-01, -.24687500E+00, -.23491800E+00, -.41104500E+00, 0.34325100E+00, -.10870900E-02, -.31956300E+00, -.28855300E+00, -.22023100E-02, 0.16448900E+00, 0.44031900E+00, -.83052800E-01, 0.18585900E+00, -.24325600E+00, -.27216000E-01, 0.29863800E+00, 0.55674300E-03, -.69595300E-01, -.35063600E+00, 0.34616000E-02, -.23161400E+00, 0.31469300E-01, -.14553500E+00, 0.67923700E+00, -.23464400E+00, 0.88006400E+00, 0.34341600E+00, -.64580400E-02, 0.15930600E+00, -.19494400E+00, 0.46704400E+00, 0.62826000E+00, -.18413300E-01, -.21881500E-02, 0.34636700E+00, -.14372500E+00, 0.19490800E-01, -.28271900E+00, -.11331400E-01, 0.11656400E+01, -.86962200E-01, -.22792500E+00, -.11100100E+00, 0.17645900E+00, -.11327800E+01, 0.64680000E+00, 0.95269300E-02, 0.12118300E+00, 0.65180000E+00, -.46307000E-02, -.97885100E-01, -.91058600E+02, 0.66091800E+02, 0.38510400E+02, -.38552900E+01, -.59756200E+02, 0.38023100E+02, 0.20143000E+03, -.10072200E+03, 0.19769700E+02, -.10052900E+03, -.71556400E+02, -.35109900E+02, -.11962200E+03, 0.19306200E+02, -.11594200E+02, -.38690700E+02, -.11557900E+03, 0.19187400E+03, -.95481800E+02, -.43616400E+02, -.95992700E+02, 0.25467500E+02, 0.11224000E+02, -.70222900E+02, 0.21496900E+02, -.38831300E+02, 0.12778600E+02, -.94614800E+02, -.26903100E+02, 0.14618300E+02, -.79770300E+01, 0.13467900E+02, -.28595200E+02, -.13919900E+02, 0.73512700E+01, 0.11785700E+02, -.24367200E+02, -.36762400E+02, -.19860400E+02, 0.33982500E+03, -.17010400E+03, -.15900500E+03, -.16973600E+03, 0.10235500E+01, 0.15913200E+02, -.53254600E+02, 0.12127900E+03, -.10441200E+03, 0.37620500E+01, -.87633300E+02, 0.13974300E+02, -.67479200E+01, 0.47054100E+02, -.72318800E+01, 0.72797500E+02, 0.49261200E+02, -.12084600E+02, -.16252100E+02, -.67636000E+02, 0.42906700E+02, -.58459300E+02, -.58666300E+02, 0.31320200E+02, -.88425100E+01, 0.29400100E+02, -.28874800E+02, 0.32072700E+01, -.28039600E+02, 0.33472800E+02, 0.52411900E+02, -.14120300E+02, 0.34977600E+02, -.34148100E+01, -.83743900E+01, -.14234600E+01, -.92023900E+01, -.25119200E+01, 0.74253400E+00, 0.56322100E+01, -.93229500E+01, 0.16817600E+01, 0.17231800E+01, 0.59808000E+01, 0.10814700E+02, -.15431600E+02, 0.10562000E+02, -.26125600E+01, -.90393800E+01, 0.57474500E+01, 0.43871800E+01, 0.79293500E+01, -.27008300E+02, 0.32871100E+01, -.99637700E+01, 0.12343300E+02, -.76321500E+01, 0.16653300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12172500E+01, 0.51359900E+00, -.41958100E+01, -.24219100E+00, -.16150400E+01, 0.22641500E-01, -.14324000E+01, -.98408400E+00, 0.30809200E+01, 0.49579800E+00, 0.16458300E+00, -.57456200E+00, -.46997000E+00, -.37726500E+00, -.89362700E+00, 0.45562900E+00, -.35516000E+00, -.82342200E+00, -.90133600E-01, -.12754300E+01, -.29594600E+00, -.66996500E-01, 0.64222900E+00, -.24337100E+01, 0.11630100E+00, -.16521800E+00, -.24500500E+01, 0.40091800E+00, -.12395200E+01, -.12457400E+01, -.75380800E+00, 0.87020900E+00, -.93097800E+00, -.24142200E+01, 0.11983000E+01, 0.63253800E+00, 0.82522900E-02, 0.35275500E+00, -.46110900E+00, -.14657600E+01, 0.13104300E-01, -.92545600E-02, 0.10887000E+01, 0.19630700E-01, 0.34212000E+00, -.95921400E-01, -.46755600E+00, -.29305800E-02, -.13872400E+01, 0.13418800E+01, 0.60658800E+00, -.75087800E+00, 0.11292700E+00, -.31633900E+00, 0.60854900E-01, 0.24609500E+00, -.82001900E+00, -.56561900E+00, -.56510800E-01, 0.35244400E+00, -.14358400E+00, -.13513300E+00, -.38405600E+00, 0.12268800E+00, -.21696400E+00, 0.51910700E-01, -.53005700E-01, -.37597200E+00, -.63832200E+00, 0.13670600E+00, -.30460500E+00, 0.79313900E+00, -.23590000E+00, 0.15405800E+00, 0.96816600E-01, -.47818700E-01, 0.19634800E-01, 0.26405300E+00, 0.18723900E+00, 0.29369200E+00, -.41370900E-01, 0.63914100E-01, -.33787700E+00, -.50722600E+00, 0.11888700E+01, -.43438100E+00, 0.37207200E-01, 0.18339600E+00, -.16045700E+00, 0.45945000E-01, -.92527800E+00, 0.48417600E-02, 0.11306200E+00, 0.10933900E+00, -.47085700E+00, 0.45682700E+00, -.81370100E+00, 0.86205000E+00, -.23770100E+00, -.77729200E+00, -.59023100E-01, -.35651100E-01, -.52234500E-02, -.88312500E+00, 0.43916300E-01, 0.20345600E+00, 0.18159300E+00, 0.59225800E+00, 0.51963300E+00, -.47968600E+00, 0.19251600E+01, 0.35600600E+00, 0.24558700E-02, 0.12176700E-02, 0.84968400E-01, 0.24019700E+00, 0.18251700E+01, -.16266300E+00, 0.49585200E+00, -.41717900E+00, -.16640400E+00, -.46436400E+00, 0.10074800E+01, -.79066100E+00, -.44208300E-02, 0.38378000E-01, 0.66139800E+00, -.39381600E+00, 0.86370700E+00, -.55910700E-02, -.22609700E+01, -.37926200E+00, -.45964900E+00, 0.30446100E+00, 0.38107400E+00, -.17434100E-01, -.12310700E+01, 0.14735400E-01, 0.35665600E+00, 0.67065200E-01, -.81725700E+00, -.80579300E-01, -.64230400E-01, 0.75722400E-01, 0.94944700E-01, -.18459100E-01, -.12764100E-01, 0.72615000E-01, 0.16211200E+00, -.17515100E+00, 0.87651600E-01, -.28757300E+00, -.40775600E+00, 0.45286200E-01, 0.49262700E-01, 0.26464300E-01, 0.26090700E+00, 0.72034700E-01, 0.49940900E-01, -.94828800E+00, -.98836900E-01, -.51743400E-01, 0.79530000E-01, -.21168700E+00, 0.13977200E+01, -.68235200E+00, 0.25042900E+00, 0.54701100E+00, 0.74920900E-02, 0.17509900E+00, -.50923000E+00, 0.15530800E+01, 0.59479300E-01, 0.13939100E+01, 0.18690100E+00, -.32089000E+00, -.17807700E+00, 0.26290700E+00, 0.13339800E+01, 0.53141000E-01, -.25254200E+00, 0.74028100E+00, -.11534800E+00, -.11302600E+00, 0.13704100E+00, 0.41430700E+00, 0.69757600E+00, 0.40299200E+00, 0.69690200E-01, 0.49501800E+00, 0.64703200E-02, -.54740500E-01, -.36089700E-01, -.42405800E+02, -.28254800E+02, -.48226900E+01, 0.71457000E+00, 0.10020600E+03, -.21479000E+03, 0.10714300E+03, 0.13179200E+03, 0.10823500E+03, 0.44301900E+02, 0.10909500E+03, -.68019800E+02, -.53870900E+02, 0.65633900E+02, 0.83774400E+02, 0.12303700E+03, 0.12842200E+03, -.64532400E+02, -.29872200E+02, -.64395400E+02, 0.13998900E+02, 0.36319800E+01, -.18707600E+02, 0.37108800E+02, -.56907600E+02, 0.17743400E+02, -.60131400E+02, 0.11613000E+03, -.56358200E+02, -.61320600E+02, -.57990300E+02, -.17060500E+02, 0.42758300E+02, -.27219700E+02, 0.17548800E+02, -.32696600E+02, 0.33274000E+02, -.53308200E+02, 0.10325600E+02, -.49107300E+01, -.30025800E+02, -.46848500E+01, 0.17929300E+02, 0.73762400E+02, -.41904700E+02, -.41372900E+02, -.54326700E+02, 0.78310800E+02, 0.12208500E+03, -.43030400E+02, 0.21788600E+02, 0.35713700E+01, 0.21448800E+02, 0.21199800E+02, -.17206500E+02, 0.34683500E+02, -.79969900E+00, -.81885600E+02, -.19395100E+02, -.71283200E+02, 0.63103800E+02, -.30444800E+02, -.17098000E+02, -.31168300E+02, -.25061600E+02, -.38175700E+02, -.18717100E+01, 0.39262700E+02, 0.23161600E+02, -.60751000E+02, -.46042000E+02, -.18491200E+02, -.71920200E+01, -.16409900E+02, -.18541100E+02, 0.10823400E+02, 0.27828500E+01, 0.39070700E+01, -.18166400E+02, 0.16505800E+02, -.67369200E+01, 0.94686400E+01, 0.17507200E+02, -.16258500E+02, 0.17926500E+02, 0.10733800E+02, -.18140700E+02, 0.90720900E+01, 0.38979700E+01, 0.24855900E+01, -.25210000E+02, 0.11604300E+02, -.17057100E+02, -.14346600E+02, -.14318800E+02, 0.25017200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.32692700E+01, 0.25358600E+01, 0.52248400E+01, -.26247600E+01, 0.62710000E+01, 0.10655600E+01, 0.10932100E+01, 0.20932900E+01, -.52526800E+01, -.83055200E+00, -.22855200E+00, 0.51532700E+01, -.40444300E+01, -.94070700E+00, 0.17200300E+01, -.13210200E+01, -.29297500E+01, -.58304200E+00, 0.22791800E+00, -.11964800E+01, -.37721700E+00, 0.55194300E-01, 0.42612700E+00, -.12268100E+01, 0.15994900E+00, -.13884900E+00, -.73703400E+00, 0.37270200E+00, -.44427600E+00, -.13549400E+01, 0.13728500E+00, -.17428800E+00, -.78507500E+00, -.11290300E+01, 0.19672400E+01, 0.42944700E+00, 0.84947400E-01, 0.33102200E+01, -.11581500E+01, 0.32294300E+00, 0.18960700E+01, 0.99906500E+00, -.65721700E+00, 0.64958600E+00, 0.11512600E+00, -.68289400E+00, -.11331300E+01, 0.16659400E-01, 0.70301900E+00, 0.17770100E+01, 0.14804700E+01, -.86418900E+00, 0.17490100E+00, -.13325900E+01, -.30184300E-01, 0.13671800E+01, -.41940100E+00, 0.28926600E+00, 0.14749200E+00, -.76050700E+00, -.48577300E+00, -.33162300E+00, -.83198600E+00, -.23936600E+01, 0.35548900E+01, -.46481000E-01, -.73772400E-01, -.22025900E+01, -.21864300E+01, 0.26513700E+00, -.28139800E+01, 0.24470500E+01, -.65534500E+00, 0.66988000E+00, 0.24583900E+00, 0.50994100E+00, -.88246300E-01, -.65093700E+00, 0.20362600E+00, 0.93416400E+00, 0.96730500E-01, 0.14696500E+01, 0.14863700E+00, 0.88600100E+00, 0.45455400E+01, -.39552400E+00, -.12720100E+00, 0.15170400E+00, -.16465900E+00, -.14840900E+01, -.95327600E-01, 0.14537000E+00, 0.82422200E+00, 0.59088600E+00, -.26316800E+01, 0.37876700E+01, 0.24389400E+01, 0.10462800E+00, 0.81353500E+00, -.36208400E+01, 0.31124200E+00, -.45522400E+00, 0.33789900E-02, -.24742100E+01, -.11432500E+01, 0.83444100E+00, -.16915500E+00, 0.10166000E+01, 0.33008700E+01, -.69456600E+00, -.50293000E+01, -.61394500E+00, -.14394000E+00, -.26764200E-02, 0.77139700E-01, -.10563800E+01, 0.30631000E+01, 0.15167400E+01, -.10764200E+01, -.47928900E+00, 0.74462200E+00, -.49442500E+01, 0.10141200E+02, -.47628200E+01, -.89695600E-01, 0.47038800E+01, 0.13861000E+01, -.16587000E+01, 0.37764300E+01, 0.10846000E+01, -.32697400E+01, -.91251300E+00, -.87323400E+00, 0.15539100E+01, 0.31978500E+01, -.28916200E+00, -.35153000E+01, 0.90585900E+00, 0.35136300E+00, 0.40241300E+00, 0.24275800E+01, -.56863800E+00, -.25117700E+00, 0.29534000E+00, 0.82769000E+00, -.59302900E+00, -.11382600E+00, 0.98010300E+00, 0.11558400E+00, -.23366400E+01, 0.26279800E-01, -.77490500E+00, -.17624600E+01, 0.63227000E+00, 0.78565000E+00, 0.41469200E+00, -.15522600E+01, 0.33399300E-01, -.60342900E+00, 0.65839600E+00, -.20817400E+00, 0.15042600E+01, -.61514300E+00, 0.54031700E+00, 0.20566500E-01, -.20191600E-02, -.15827100E+00, -.74585900E+00, -.90389100E-01, 0.12963300E+00, -.19624900E+01, 0.67208200E+00, 0.30682500E+01, 0.16270500E+01, -.51465700E-01, -.53062500E+00, -.17426000E-01, -.62717500E+00, 0.11557600E+01, 0.87295700E-01, 0.43192700E+01, 0.85464800E+00, 0.18415700E+01, -.88622800E+00, 0.18781300E+00, 0.68986200E+00, -.84092600E+00, 0.32192200E+01, 0.16424400E-01, -.43855400E+00, 0.11891000E-01, -.11413000E+00, -.17206900E+01, -.16002900E+01, -.53273700E+02, 0.14128300E+02, -.27782700E+02, 0.15988100E+03, 0.57027900E+02, -.23383600E+02, 0.41890800E+03, -.28182500E+02, 0.14783900E+03, 0.29983000E+03, -.16288300E+03, 0.69684100E+02, -.40139900E+03, 0.29621100E+03, -.23709600E+03, -.70667600E+03, 0.36163800E+03, 0.46804800E+03, 0.35326300E+03, -.13360500E+03, 0.10490800E+03, 0.11204600E+03, -.33608700E+02, 0.26268200E+03, 0.87631000E+02, 0.28679200E+03, 0.55000300E+02, -.40498100E+02, -.13411600E+03, -.27523800E+02, 0.43438600E+02, 0.13694300E+03, -.12056800E+02, 0.22316900E+02, -.30822300E+02, 0.17034700E+03, 0.83769900E+02, -.21985000E+03, 0.10746300E+03, 0.88569300E+02, 0.11022000E+03, 0.35969600E+03, 0.15919100E+03, -.97883700E+02, 0.46929200E+02, 0.20194500E+03, 0.72988700E+02, 0.60182900E+03, 0.38260200E+03, -.19033800E+03, -.61019400E+02, -.19090300E+03, 0.78908600E+02, -.20874700E+03, -.47683100E+02, 0.94194400E+02, 0.12436100E+03, -.28642800E+03, -.34787300E+03, -.46276700E+03, 0.24197100E+03, 0.13016900E+03, 0.23124800E+03, 0.63446500E+02, 0.18474900E+03, 0.22872400E+03, 0.21199900E+03, 0.14092200E+03, 0.25456700E+03, -.66024200E+02, 0.60910300E+02, 0.27120300E+02, -.18956500E+02, -.28019600E+02, 0.64456600E+02, -.53090700E+01, -.48472000E+01, -.28837300E+02, 0.18974000E+02, 0.43369200E+02, 0.38572400E+02, 0.27948800E+02, 0.35954000E+02, 0.27132500E+02, 0.55723200E+02, -.28340700E+02, 0.40717600E+02, -.36842200E+02, 0.45970900E+02, -.12046800E+02, 0.13818600E+02, 0.46064200E+02, -.45170000E+01, 0.36905000E+01, -.42751200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34771800E+01, -.20478200E+01, 0.70960700E-01, 0.55753300E+00, -.29742000E+00, -.51985900E+00, -.12104700E+00, -.57956800E+01, -.59769900E+01, -.20413000E+00, 0.19319300E+01, 0.84236100E+01, 0.13759800E+01, 0.14733400E+01, 0.61695300E+01, -.30616500E+01, -.38635900E+01, 0.37800800E-01, -.48483700E-02, -.14827000E+01, -.44760800E+00, -.12232500E+01, -.11304700E+01, -.57901800E+01, 0.24469500E+00, -.32177000E+00, -.11359100E+01, 0.64102300E-01, -.55871700E+00, -.31339000E+01, -.95552400E+00, 0.15738700E+01, -.20889500E+01, 0.21532300E+01, 0.15000100E+01, -.21450300E+01, -.14393000E+00, -.19345100E+01, 0.15512900E+01, -.42055300E+01, 0.48938700E+00, 0.76189600E-01, 0.25453500E+01, -.49756200E+00, -.43452000E+00, 0.22362600E+00, 0.18534100E+01, -.31490300E-01, -.10377100E+01, 0.36759100E+00, -.20682600E+01, -.12522400E+02, 0.61340200E-01, -.74824800E+00, 0.46100700E+00, -.11337100E+01, 0.39046100E+00, 0.76338700E+01, -.20712400E+00, 0.71844500E+00, 0.38662700E+00, -.15669200E+01, 0.58250100E+00, 0.35335800E+01, -.56160000E+01, 0.69224000E+00, -.14975600E+01, -.24304100E+01, -.22383000E+00, -.33932700E+00, 0.30666700E+01, -.10909500E+01, 0.14223700E-01, -.11703200E+01, -.84651700E+00, 0.13638100E+01, 0.21023100E-01, -.15356500E+00, -.11404100E+00, 0.11179000E+00, 0.23298200E+00, -.10491400E+01, -.67167500E-01, -.44069100E+00, 0.11388900E+01, -.10799600E+01, -.50307100E+00, -.83654600E+00, 0.13132500E+00, 0.93943200E+00, 0.96227900E+00, 0.42310100E+00, -.10459500E+01, 0.98335400E+00, -.60735100E+00, -.11475500E+01, 0.28821900E+01, 0.63773800E+00, 0.90359800E+00, 0.26301400E+01, -.21176400E+00, 0.39593800E+00, 0.26097700E-01, 0.45913700E+01, -.25097500E+01, -.96279200E+00, -.10918500E+01, 0.25529400E+01, 0.70782100E+00, 0.24394400E+00, -.70601600E+01, -.12098900E+01, -.16088700E+00, -.40761900E-02, -.14943300E+00, -.91829800E+00, -.41544600E+00, -.48698100E+00, 0.24840000E+01, 0.95939800E+00, -.72766300E+00, 0.18074800E+01, -.79638300E+01, 0.25583300E+01, 0.19427200E-01, -.12010200E+01, 0.14999600E+01, -.65945700E+00, 0.30116000E+01, -.17549600E+01, 0.36644900E+00, -.12674900E+00, 0.24710500E+00, 0.16985800E+01, 0.35174600E+01, -.54974800E-01, -.34125800E+01, -.72156600E+00, 0.12398000E+01, 0.55140100E+00, 0.23840400E+01, 0.10028400E+01, -.11354700E+01, -.56794800E+00, 0.68141400E+00, -.56789700E+00, -.84120800E-02, -.71389200E+00, -.12609700E+01, -.25499500E+00, 0.66113000E+00, 0.16766500E+01, 0.11952100E+01, 0.13956700E+01, -.16007100E+01, -.83968900E-01, 0.43987900E+00, 0.99044600E-01, -.96145500E-01, -.82122700E-01, 0.17742900E+00, -.43325900E+00, -.13932600E+01, -.52351500E+00, 0.76606700E+00, -.57643400E+00, 0.43931100E+01, 0.18313400E+01, -.69982900E-01, 0.10994100E+01, -.20322800E+00, -.23790900E+01, -.52390500E+00, -.26073300E+01, -.81076500E+00, -.71163300E+00, -.72193900E+00, -.75708700E+00, 0.31344300E+01, -.10626800E+00, -.25218000E+01, -.24136000E+00, -.12835300E+01, 0.84392200E+00, -.54908100E+00, -.55057700E+00, 0.48718900E+01, 0.17419200E+00, 0.13969100E+00, -.23737400E+01, -.39741600E-01, 0.65496400E+00, -.53239400E+00, 0.32809800E+00, -.46392000E-01, -.12727500E+03, 0.86637100E+02, -.31474800E+03, -.86251500E+03, 0.43334900E+03, 0.21661000E+03, 0.42554000E+03, 0.40552100E+03, 0.14900600E+03, -.37557000E+03, -.58054700E+03, 0.55130100E+02, 0.20074300E+03, 0.74208800E+02, 0.84648900E+03, -.42666500E+03, -.36608500E+03, -.42194200E+03, -.28103700E+02, -.58942400E+02, -.31174700E+03, -.75708900E+01, -.20791500E+03, -.16530000E+02, -.37577400E+03, 0.33259200E+03, -.16944400E+03, 0.45031900E+02, -.16675200E+03, 0.16221500E+03, -.22507400E+02, 0.44226000E+01, 0.21452000E+03, -.80995500E+02, -.13430100E+03, -.69089700E+03, 0.14694900E+04, -.73718500E+03, -.74427600E+03, -.73832500E+03, -.13076200E+02, -.78611400E+02, -.17506600E+03, 0.23558900E+03, -.47371900E+03, -.51442700E+02, -.96805300E+03, 0.19067300E+03, -.95305300E+02, -.36754700E+02, -.94675700E+02, 0.40965000E+02, 0.18941300E+03, -.23804700E+03, -.67756800E+02, -.26216800E+02, 0.14143500E+03, 0.21094100E+03, 0.28413100E+03, -.13700400E+03, -.53279400E+02, -.14435900E+03, 0.15139400E+03, -.19325100E+03, -.64774300E+02, 0.25262700E+03, 0.19550400E+03, -.22860400E+03, -.10816700E+04, -.31842200E+02, -.24708700E+01, 0.12599600E+03, 0.13922600E+03, 0.92670000E+01, 0.43034700E+02, 0.35190200E+02, 0.13838700E+03, -.12474700E+03, -.30471900E+02, 0.30956500E+02, -.12606600E+03, -.17000100E+02, -.12852800E+03, -.57879200E+02, 0.13895900E+03, 0.32179300E+02, 0.30744000E+02, -.42519300E+02, 0.24048300E+02, 0.24218700E+02, -.67817300E+02, -.62866700E+01, -.16152300E+02, 0.17303000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.73021500E+00, 0.15075600E+00, -.55114400E+00, 0.41948100E+00, 0.11402500E+01, 0.15165300E+00, -.90797800E+00, -.51450300E+00, 0.36509500E+00, 0.12399600E+00, -.16684900E-01, 0.20418600E+01, -.17363700E+01, -.39988700E+00, -.17180000E+00, -.56361400E+00, -.13521900E+01, -.24104100E+00, 0.22666200E+00, -.86990700E+00, -.97762500E+00, 0.33082000E-01, 0.63688400E+00, -.97602800E+00, 0.14463700E+00, -.46525200E-01, -.98280100E+00, 0.97341600E-01, -.58684100E+00, -.83828400E+00, -.60047600E+00, 0.43988900E+00, -.35634700E+00, -.42655700E+00, 0.33890000E+00, -.32370200E+00, -.23303300E-01, -.26426400E+00, -.10971300E+00, -.79553100E+00, 0.46300900E+00, 0.16208800E+00, 0.49567800E+00, 0.58322300E-02, -.18917200E+00, 0.99986600E-01, -.84783100E-01, -.72975600E-02, -.61679100E+00, 0.50984100E+00, 0.81017400E-01, -.19141300E+01, 0.13067500E+00, -.28180600E-01, 0.17000300E+00, -.11796700E+00, -.19912900E+00, 0.13186100E+01, -.10451700E-01, 0.39189100E+00, 0.43886900E-01, -.67108500E-01, 0.95988200E-01, -.46878900E+00, 0.65548400E+00, 0.85765800E-02, -.11747700E+00, -.76954600E+00, -.53795300E+00, -.12755300E-01, -.10509500E+01, 0.75589500E+00, -.61467500E+00, 0.14316200E+00, 0.15417600E+00, -.10947400E+00, -.10593100E-01, -.17089000E+00, 0.18045900E+00, 0.10411200E+00, 0.48551100E-01, -.93522900E-03, 0.52164300E-01, -.11929300E+00, -.26944700E+00, 0.28768800E+00, -.10238000E-01, -.25112900E-01, -.97509800E-01, 0.26634700E+00, -.30456800E+00, 0.32783500E-01, 0.48200000E+00, 0.78234800E-01, 0.29923400E-01, 0.25336100E+00, 0.25235000E+00, -.18003100E+00, -.13414000E-01, 0.59129000E-01, 0.67767600E-01, 0.48248100E-01, 0.69635600E-02, 0.12803200E+00, -.19406400E+00, 0.16528200E+00, 0.30322500E-01, 0.96072500E+00, -.64778300E-01, 0.28978600E+00, 0.14822000E+01, 0.16363300E+00, -.86123000E-01, 0.34033200E-02, 0.28426200E-01, 0.57943600E-01, 0.77798700E+00, 0.65465400E+00, -.70521200E+00, 0.62738700E-01, -.10274200E+00, -.66798900E+00, 0.10283700E+01, -.22947600E+00, 0.10313600E-01, 0.57264000E-01, -.14281200E+00, 0.38359600E-01, -.72713300E+00, -.54906900E-01, -.20739200E-02, 0.28768700E-01, -.17366000E+00, -.25914100E+00, 0.26597400E-01, 0.50847400E-01, 0.30926400E+00, -.25195800E+00, 0.97100300E-01, -.15256700E+00, -.10966100E+01, -.12374200E+00, 0.16759900E+00, 0.40667900E-01, 0.95110100E-01, 0.60494500E-01, 0.56723700E-02, 0.28266700E-01, -.13729600E+00, 0.39013900E-02, -.19481200E+00, -.39237400E+00, -.18242400E+00, -.40880800E-01, 0.28981800E+00, -.48517900E-01, 0.22871100E+00, 0.61052700E-02, -.16505700E-01, -.38246100E+00, 0.64921900E-01, 0.17052300E+00, 0.29320800E+00, 0.64279100E-02, 0.39110600E+00, 0.13188900E+00, -.83905800E+00, -.11921800E+00, 0.29100600E-02, 0.41324300E-01, 0.28329700E+00, 0.50161500E-01, -.43093800E+00, -.42361100E+00, 0.17682800E-01, 0.69290900E-02, 0.71178700E-01, -.35080200E-01, 0.12229100E+00, -.16842700E-01, -.77868100E+00, 0.98102100E-01, 0.26562000E+00, 0.41355100E-01, 0.13294900E+00, 0.85694600E+00, 0.12044800E+00, 0.33110300E+00, 0.93448800E-03, 0.16999400E+00, 0.43199300E-02, -.98384700E-01, -.51731300E-01, 0.35230300E+00, 0.73966300E-01, -.33715000E-01, 0.62812500E+01, 0.14890600E+02, -.82240500E+02, 0.41145200E+02, 0.93354100E+00, 0.40661100E+02, 0.27674000E+02, 0.16913800E+02, -.66261000E+01, -.46520000E+02, 0.10890200E+02, 0.13934700E+02, 0.20592900E+02, 0.29761800E+02, -.15340200E+02, -.19746700E+02, -.14768800E+02, 0.77012900E+01, -.10137400E+02, 0.56700500E+00, 0.20342200E+01, -.70441100E+00, -.96724300E+01, -.22832500E+02, 0.36264000E+02, -.18306300E+02, 0.70892300E+01, -.18173500E+02, -.56113100E+01, -.34929400E+01, -.12718800E+02, -.82120500E+01, -.24899400E+02, -.20104700E+01, -.68583900E+02, -.26809200E+02, 0.13305200E+02, 0.30421600E+02, 0.13090900E+02, -.23767800E+02, -.20650700E+02, 0.89938400E+01, -.16451900E+02, 0.20923200E+02, -.11423400E+02, 0.19088600E+02, -.59676900E+02, 0.29758600E+02, 0.14876500E+02, 0.30061000E+02, 0.15608900E+01, 0.10761900E+02, 0.29318300E+01, -.13175200E+02, 0.36515200E+02, 0.16122100E+02, 0.72505500E+02, 0.52255300E+02, -.26370500E+02, -.25480800E+01, -.26328900E+02, 0.23674100E+02, 0.28278000E+01, -.15309300E+02, -.15669100E+02, -.44337600E+02, -.56307300E+00, -.12724900E+03, -.55545700E+01, 0.33944200E+01, 0.91621200E+01, 0.10571300E+02, -.37649600E+01, 0.50687200E+01, 0.35053300E+01, 0.10671500E+02, -.91542900E+01, -.33994800E+01, 0.14405100E+01, -.11160200E+02, -.34712000E+01, -.11484600E+02, -.25435300E+00, 0.10648100E+02, 0.17289800E+01, 0.21202400E+01, 0.13293400E+00, 0.11884000E+01, 0.49484400E+01, -.33794700E+01, 0.25573300E+01, 0.11470300E+02, 0.14635200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10885300E+01, 0.47377200E+00, 0.10538700E+01, 0.13885800E+01, 0.13444600E+01, 0.54177900E-01, -.10643600E+01, 0.10579800E+00, 0.31542000E+01, 0.78192700E+00, 0.19640200E-01, -.19586600E+01, 0.12564100E+01, 0.94450200E+00, -.15282000E+01, 0.20882900E+01, 0.13437600E+01, -.52884500E+00, -.15178300E+01, -.94370700E+00, 0.20893100E+01, -.53735400E-01, 0.43194200E+00, -.15355300E+01, -.48218500E-01, -.18197200E+00, -.21036600E+01, 0.51331600E+00, -.81406100E-01, 0.13098800E+01, -.27337100E+00, 0.79091200E-01, -.38528800E-01, -.18510400E+01, 0.81066600E+00, 0.15808100E+01, 0.58006000E-01, 0.14450000E+00, -.28919500E+00, -.11852100E+01, -.85754800E+00, -.32526500E+00, 0.87850600E+00, -.68693000E-02, 0.86894000E+00, -.23008300E+00, 0.65465300E+00, 0.10981200E-02, 0.23869400E+00, -.15460100E+00, 0.15914300E+00, -.12324900E+01, -.41741200E-01, -.51700000E+00, -.33441500E-01, 0.16986500E+00, -.75423200E-01, 0.13733300E+00, -.90316300E-02, -.94130400E-01, 0.21316500E-01, 0.24411700E+00, -.31107100E+00, 0.10155400E+00, -.18266500E+01, 0.29889800E+00, -.21298000E+00, 0.66024900E+00, 0.96693900E+00, -.12751500E+00, 0.47246100E+00, -.87257500E+00, 0.44619300E+00, 0.14953000E+00, 0.38830200E+00, -.79936900E-01, 0.29807700E-01, 0.44035000E+00, 0.24751000E+00, 0.20377000E+00, 0.98873700E-01, -.37820600E-01, -.37593400E+00, -.88429200E+00, -.73207300E+00, -.34030100E-01, 0.29832800E+00, -.43294800E+00, 0.27962700E+00, -.13668300E+00, -.42768800E+00, -.12964200E+00, 0.46868400E+00, -.34232600E+00, 0.19631000E+01, -.17047000E+01, -.21055000E+01, -.12330100E+01, -.31681400E+00, -.79666600E+00, 0.43615100E+00, -.37881300E+00, -.57834300E-02, -.10648600E+01, -.29398000E+00, 0.18401400E+00, 0.28704400E+00, -.16120500E+01, -.29171700E+00, -.73947300E+00, -.19157100E+01, -.34242500E+00, 0.15144200E+00, -.61326900E-04, 0.11923100E+00, 0.42172200E+00, 0.16156600E+01, 0.30191100E+00, -.30170000E+00, -.54602600E+00, 0.61315700E-01, -.16050400E+01, 0.79101900E+00, -.61083400E+00, -.51719200E-02, 0.98507100E-01, 0.30163600E-01, 0.12773200E-01, -.58615900E+00, 0.13130800E-01, -.74656300E-01, -.10435100E+00, 0.67094500E-01, 0.31284300E+00, 0.61792000E+00, -.13400500E-01, -.53546400E+00, -.25357500E+00, 0.30854900E-01, -.14525200E+00, -.51435900E+00, 0.23013100E+00, 0.37580900E-01, 0.13948300E+00, -.10197600E+00, 0.78665700E-01, 0.89751900E-02, 0.30196300E-01, 0.14854900E+00, -.89868900E-01, -.12205600E+00, -.25506900E+00, -.12520200E+00, -.24072100E+00, -.14544200E+00, 0.53805700E-01, -.92098500E-01, -.51068800E-01, 0.19381900E+00, -.45822400E+00, -.15039700E+00, -.59916100E+00, -.15523500E-01, -.32432100E+00, 0.74287800E+00, -.43122800E+00, 0.29872700E+00, 0.64192400E+00, 0.94581600E-01, 0.38239300E-01, 0.51879000E+00, 0.10354900E+01, -.78111800E+00, 0.62556000E+00, 0.24320900E+00, 0.15682500E+00, 0.12439200E-01, -.30556800E-02, -.99987400E+00, 0.37988900E-02, 0.69543100E+00, -.45365900E-01, -.69834100E-01, 0.93855100E-01, -.89507100E-02, -.33903800E+00, -.45365700E+00, 0.29850800E-01, 0.34184400E-01, 0.49497100E-01, 0.22427800E-02, -.96107400E-01, -.18787200E+00, 0.75161300E+00, -.23901300E+00, -.25004000E+00, 0.10285800E+01, -.10865600E+03, -.11940700E+03, 0.61387600E+02, 0.10132400E+03, 0.58978600E+02, 0.13145900E+03, 0.71262700E+02, -.12716200E+03, -.10252900E+03, -.88039400E+02, 0.96345000E+02, -.98575000E+02, -.10190600E+03, 0.52591100E+02, 0.57662400E+02, 0.51105600E+02, -.44662000E+02, 0.11210600E+02, -.23626000E+02, -.22071300E+02, 0.58812300E+02, 0.17141300E+02, 0.39942700E+02, 0.24705800E+02, -.16350700E+02, -.13308000E+00, -.12410400E+02, 0.41546000E+02, 0.12283500E+02, 0.26627000E+02, 0.56607500E+02, 0.51458800E+00, -.14604300E+02, -.72362000E+02, 0.24307500E+03, -.12259400E+03, -.15405000E+03, -.12193300E+03, 0.12400900E+03, 0.11916300E+02, -.41825000E+02, 0.83735300E+02, -.78314200E+01, -.10996200E+02, -.17795800E+03, 0.16646500E+03, -.83090800E+02, 0.19301500E+01, -.83341000E+02, 0.42303600E+02, 0.31708900E+02, -.95458800E+02, -.10776500E+02, -.13357400E+02, 0.65885500E+01, -.32838900E+02, -.13293100E+03, 0.69440900E+02, 0.17910400E+02, 0.66161700E+02, 0.83962000E+01, -.37478500E+02, 0.85334400E+02, 0.12234800E+03, 0.12393400E+03, -.24923000E+02, -.10602100E+03, 0.19151800E+02, -.11146000E+01, 0.20775800E+02, 0.24226600E+02, 0.13507700E+02, 0.15641100E+01, 0.72877900E+00, 0.23500900E+02, -.20510400E+02, 0.99829300E+01, 0.97340200E+01, -.19413400E+02, 0.15118500E+02, -.19763300E+02, -.11462900E+02, 0.24053800E+02, 0.10589500E+02, -.14827200E+01, -.10108000E+02, 0.16845700E+02, -.25238600E+01, -.26773200E+01, 0.28599500E+01, -.10732800E+02, -.14672400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10003400E+01, 0.89280200E+00, 0.17300900E+01, 0.94208600E+00, 0.34149900E+00, 0.68273000E-01, 0.55465100E+00, 0.11752000E+01, -.31550800E+00, 0.67813200E-01, 0.11749600E+00, 0.75449000E+00, 0.11819200E+01, 0.10870400E+01, -.37812600E+00, 0.29493600E+00, -.81668900E-01, -.71968200E+00, 0.51161100E+00, -.60335400E+00, -.29093000E+00, -.96272300E-01, 0.34863400E+00, -.74631900E+00, 0.54058600E-01, -.92641200E-01, -.14304000E+01, 0.77233400E-01, 0.85097000E-01, 0.17695900E+00, -.20130600E+00, -.81333100E+00, 0.15153400E+00, -.66700900E+00, -.41002600E+00, 0.21626400E+00, -.19278600E-01, -.10948500E+00, -.21442100E+00, -.10387800E+01, -.52399300E+00, -.41405900E+00, 0.11274000E+01, -.39102500E-01, -.84989800E-01, -.21825700E-01, -.39320700E+00, -.52754000E-02, 0.39424100E+00, -.64560600E+00, -.59055000E-01, 0.18184100E+00, 0.48891800E-03, 0.20674100E+00, 0.30299200E-01, -.11251600E+00, 0.66459600E+00, 0.14963700E+01, 0.33306300E-01, -.74540300E+00, 0.65462800E-01, 0.23544800E-01, 0.13501000E+00, -.37335700E-01, 0.10259600E+01, -.23459100E+00, 0.98088900E-01, -.20753700E+00, -.88667800E-01, 0.22738500E+00, 0.35025300E+00, 0.20701800E+00, 0.17052100E+00, -.82063800E-01, -.30414600E+00, 0.84736300E+00, 0.62555000E-01, -.21768500E+00, 0.10211800E+00, 0.17924300E+00, -.15511100E+00, 0.58715400E+00, 0.52076900E+00, -.56745600E-01, -.29351700E+00, 0.11367200E+01, -.50153600E+00, 0.67912800E-01, 0.24219900E+00, -.45070800E+00, 0.31804700E+00, -.20165400E-01, -.62168200E+00, -.99766900E-01, 0.11026000E-01, -.74317700E+00, -.34693400E+00, 0.29632800E+00, 0.16665600E+00, 0.84126000E+00, -.28624600E-01, -.26040300E+00, 0.54524600E-02, 0.45081600E+00, -.48987400E+00, -.11411700E+00, -.28064300E-01, -.76182900E-01, -.25758900E+00, -.66719100E-01, 0.88666200E+00, -.23751200E+00, -.43561900E+00, 0.48939400E-04, 0.74855200E-01, -.85783400E-02, 0.66778600E+00, 0.50939700E+00, 0.21731400E+00, 0.10420600E+00, 0.60735200E+00, -.20798900E+01, -.27239600E+01, 0.71485600E+00, 0.15664100E-01, -.10386200E+01, -.40347000E+00, 0.78928900E-01, -.19823900E+00, 0.27024300E-01, 0.30165100E+00, 0.17664200E+00, 0.35789900E+00, -.11487400E+01, 0.17430100E+00, -.11711000E-01, 0.35043700E+00, 0.47898700E+00, -.28356300E+00, 0.39531800E-01, 0.72948400E+00, -.36563800E+00, 0.13782300E+00, -.73075800E-01, -.26636300E+00, -.52671400E+00, -.87177300E-02, -.27087500E-01, 0.27949800E+00, 0.62395500E-01, -.14808300E-01, 0.60912100E+00, 0.43580400E+00, 0.48494600E-01, 0.37248800E+00, 0.63820500E-01, -.32248500E+00, 0.94260600E-01, 0.25040500E+00, 0.11215700E+00, -.16941000E+00, 0.41701300E+00, -.26493200E+00, -.22903300E+00, -.11525800E+01, 0.15983300E+00, -.19005000E+01, -.98630300E+00, 0.16399300E-01, -.36364500E+00, 0.30430900E+00, -.10150500E+01, -.97181600E+00, -.11027100E+00, 0.33868800E+00, 0.55209500E+00, 0.31041400E+00, 0.11410700E+00, -.34277500E-01, 0.15792000E-01, 0.89698900E+00, 0.27783400E+00, 0.59666300E+00, -.15125800E+00, 0.19714600E+00, 0.98295700E+00, -.65797700E+00, -.79615900E+00, -.61039200E-02, -.36920000E+00, 0.25075400E-02, -.14063900E-01, -.29383900E+00, 0.39843000E+00, 0.70932100E-01, -.13396200E+00, -.79631500E+00, -.20179800E+00, -.38777300E+03, 0.19474400E+03, 0.40794300E+02, 0.19243900E+03, 0.15762700E+03, 0.90896300E+02, -.39604300E+02, -.18403000E+03, 0.17487900E+02, 0.10643200E+03, 0.38639000E+02, -.20806700E+03, 0.10439700E+03, 0.63747500E+02, 0.10433100E+03, -.20591400E+02, -.17646200E+02, 0.63688200E+02, 0.32209200E+01, 0.11199600E+03, -.27044600E+02, 0.96776800E+02, 0.44306200E+02, -.23155100E+02, -.68223100E+00, -.22301000E+02, -.36707500E+02, -.58761600E+01, 0.49499400E+01, 0.17586100E+00, -.73896200E+01, -.19504500E+02, -.13883400E+03, 0.22905900E+03, -.11518300E+03, -.12126500E+03, -.11522100E+03, 0.13328000E+02, -.13069500E+03, 0.24483800E+01, 0.28097700E+02, 0.51202900E+02, -.13434200E+03, -.20004000E+02, -.27484000E+01, 0.10638700E+01, 0.52541300E+02, 0.13545700E+01, 0.99060600E+02, 0.79149500E+02, -.10548400E+03, -.36109700E+02, 0.10708600E+03, 0.66887100E+02, 0.20048500E+03, -.16493200E+03, 0.81752800E+02, 0.45440000E+02, 0.81680100E+02, -.23957300E+02, -.44979200E+02, 0.10012200E+03, 0.23512800E+02, 0.43118400E+02, -.30305600E+02, -.24113000E+03, 0.31853700E+02, 0.19645400E+01, 0.19949900E+02, 0.20977300E+02, 0.20844800E+02, 0.79622700E+01, 0.32597200E+01, 0.20081000E+02, -.19797200E+02, 0.20845400E+02, 0.11641700E+01, -.15885600E+02, 0.22777500E+02, -.16615600E+02, 0.34309300E+01, 0.20686700E+02, 0.22366800E+01, -.21902100E+01, 0.29211100E+01, 0.42233800E+02, 0.25640500E+01, -.19693300E+01, -.49701400E+01, 0.18444900E+02, -.26280200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.75011000E+00, 0.22398100E+00, 0.60636000E+00, -.66226500E+00, 0.22098700E+00, 0.80460400E-01, 0.47610500E+00, 0.86544900E+00, -.96980400E+00, -.28021600E+00, -.74148800E-01, -.39950100E+00, 0.78719300E+00, 0.62165500E-01, 0.47659300E+00, 0.27782400E+00, 0.16741400E+00, -.24584600E+00, -.26525400E-01, -.27927100E+00, -.27882600E-01, 0.12984700E+00, -.22484800E+00, 0.37412400E+00, -.47417400E-01, 0.34421700E-01, 0.38484000E+00, -.20689100E+00, 0.35877600E+00, 0.48377900E+00, -.10642100E+00, -.21729100E+00, 0.21678500E+00, 0.60175600E+00, -.17106700E+00, -.36441800E-01, 0.70785800E-03, 0.53963700E+00, -.35305700E+00, 0.12160000E+01, 0.44251000E+00, -.17625800E+00, -.11471500E+01, -.15185300E+00, 0.59153100E-01, 0.47079000E+00, -.19602800E+00, 0.90252400E-03, 0.73432500E+00, -.70803300E+00, -.10216600E+00, 0.21319500E+01, -.99239000E-01, 0.22554800E+00, 0.89710300E-02, -.19629500E-01, 0.36276100E+00, 0.86702100E+00, 0.17485300E-01, -.51328500E+00, -.16386700E-01, 0.41201400E+00, -.14718900E+00, -.19611300E+00, 0.90138100E-01, -.22586700E+00, 0.23820200E+00, 0.15373700E+01, 0.55035000E+00, 0.28004800E+00, -.15719400E+01, 0.37085300E+00, -.45199000E+00, 0.63236700E-01, -.14313900E-02, -.46646100E-01, -.18820400E-01, -.60539900E+00, -.15953600E+00, 0.16434200E-01, -.14021700E+00, 0.34081300E+00, -.33701200E+00, -.12322800E+01, -.61709700E+00, 0.35522600E+00, -.14466300E+00, -.14261600E+00, -.13129800E+00, -.11706400E+00, -.26710900E+00, -.55863800E-01, -.39801900E-01, 0.57272100E-01, 0.13731000E+00, 0.10599100E+00, -.53375300E+00, 0.33412900E+00, -.21213000E+00, 0.87880800E+00, -.46739900E-01, 0.10231600E+00, 0.46428700E-02, -.56978800E+00, 0.16894800E+00, -.92642900E-01, 0.11121300E+00, 0.78204500E+00, -.65450100E+00, 0.62071400E+00, 0.33171400E+01, 0.42799100E+00, -.23112700E+00, 0.25412000E-02, -.11663500E-01, 0.73804300E-01, 0.15839200E+00, 0.10255500E+01, -.87340300E+00, 0.34635600E+00, -.29366300E+00, 0.11706900E+01, 0.29020200E+01, -.36785000E+00, -.12342700E-01, 0.35053100E+00, -.63273000E+00, -.21558700E-02, 0.27659100E+00, -.56663900E-01, 0.46172700E-01, 0.34838400E-01, -.10803600E+00, -.12098700E+00, -.23167300E+00, 0.75012000E-02, 0.17366800E+00, 0.39069500E-02, 0.50562000E-01, 0.44578900E-01, -.85165600E-01, -.61423600E-01, -.36460700E-01, -.17036600E+00, 0.67982300E-02, -.58134600E-02, -.34886600E-02, -.49782800E-01, -.29853300E+00, 0.63477700E-01, 0.24075100E-01, 0.12771700E+00, -.24188500E-01, 0.11207300E+00, 0.14191500E+00, -.29477900E-01, 0.66301200E-02, 0.60281700E-02, -.13448900E+00, 0.21137000E+00, 0.66632600E-01, 0.21862000E+00, 0.15271400E+00, 0.18554600E+00, -.44791700E+00, 0.15598700E+00, -.44284800E+00, -.51343200E+00, -.38143200E-01, -.77351100E-01, -.15016700E+00, -.55726500E+00, 0.21189700E+00, -.66744500E+00, -.10195000E+00, -.11809100E+00, -.62527800E-01, -.89738800E-01, 0.63522500E+00, -.84155100E-02, -.70408300E+00, 0.63144200E-01, -.12620000E-01, -.15231300E-01, 0.43407500E-01, 0.29070700E+00, 0.14846900E+00, 0.18601500E+00, -.14890600E-01, 0.21046500E+00, -.43118000E-02, 0.44848800E-01, -.37964500E-01, -.84171300E-01, -.17697800E+00, 0.51150400E-02, 0.36386900E+00, -.29860100E+00, -.13117000E+00, 0.19439300E+01, 0.13174100E+03, -.54109700E+00, 0.57402400E+02, 0.64488200E+02, -.68221100E+02, 0.41200100E+00, -.11205700E+03, 0.75560800E+02, -.76016900E+02, -.80223500E+02, 0.41730600E+02, 0.83202800E+02, 0.40222600E+02, -.44291700E+02, 0.24147100E+02, -.11267800E+02, -.15790900E+02, 0.13763900E+02, 0.25195900E+02, 0.39692600E+02, 0.20472500E+02, -.15259900E+02, -.26829900E+02, -.10289900E+02, 0.20392000E+02, 0.24946200E+02, 0.14965800E+02, 0.42100200E+02, 0.11005900E+02, 0.24919200E+02, 0.27862100E+02, 0.16530500E+03, -.83950600E+02, -.83882500E+02, -.82913100E+02, 0.84668600E+02, 0.37660600E+02, -.60252700E+02, 0.63838400E+02, -.37379700E+02, 0.16061400E+02, 0.32803400E+02, 0.14824400E+03, -.73826600E+02, -.37200900E+02, -.74161800E+02, 0.21463400E+02, -.40679600E+02, -.33945000E+02, 0.19806900E+02, -.22885900E+02, -.71995200E+02, -.98599600E+02, -.96715100E+02, 0.52652300E+02, 0.22681500E+02, 0.48070900E+02, 0.11924700E+02, 0.20430800E+02, 0.47689600E+02, 0.82098900E+02, 0.76433100E+02, 0.39082200E+02, -.26641000E+02, 0.15956600E+02, 0.35279500E+01, -.50513400E+01, -.48145500E+01, 0.19065200E+02, -.37411000E+01, -.38993400E+01, -.50541400E+01, 0.52916300E+01, 0.97992700E+01, 0.72946800E+01, 0.54519200E+01, 0.14741700E+02, 0.52098300E+01, 0.85614100E+01, -.47929700E+01, 0.73202200E+01, -.50959500E+01, 0.84427200E+01, 0.46453700E+01, -.30578800E+01, 0.24556100E+01, -.31987100E+01, -.13955800E+02, -.10297100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21493900E+01, 0.24945100E+01, 0.10039600E+01, -.22568400E+01, 0.13051200E+01, 0.49829100E+00, 0.48786400E+00, -.12968700E+01, -.17291700E+01, -.15845600E+00, 0.32308400E+00, -.13859700E+01, -.42381800E+01, -.10731900E+00, -.35931600E+01, 0.21754700E+01, 0.14483100E+01, 0.12907800E+01, 0.22414600E+00, 0.31571900E+01, 0.83893300E+00, -.21693100E+00, 0.11073300E+00, -.14650100E-01, 0.95655700E-01, 0.18727200E+00, 0.19598800E+01, 0.24807200E+00, -.29525300E+00, -.75235800E+00, 0.79025400E+00, -.13037100E+00, -.95463800E+00, 0.52603900E+00, 0.18502900E+01, 0.24921100E+01, 0.17732500E+00, 0.40245900E+01, -.11433300E+01, 0.13505200E+00, 0.18144000E+01, 0.48514700E+00, -.87111800E+00, 0.54237100E+00, 0.40765500E+00, -.73676100E+00, -.80179700E+00, 0.29596700E-01, 0.75446900E+00, 0.33405200E+01, 0.30665500E+01, 0.13737200E+01, 0.47059700E+00, 0.33398000E+00, 0.22773700E+00, 0.99387800E+00, -.24427200E+01, -.43168100E+01, 0.13828500E+00, 0.83405600E-01, -.72026000E+00, -.98065000E-01, -.96118900E+00, 0.23684100E+01, -.24430900E+01, 0.49891400E-01, -.11030100E+00, 0.16641100E+01, 0.63572200E+00, -.19983600E+00, -.69379700E+00, 0.53370700E-01, -.23563700E+00, -.13056600E+00, 0.27044700E+00, -.43678500E+00, 0.47642000E-01, 0.69000000E+00, 0.63027000E-01, -.20746500E+00, 0.48646500E-01, -.33266600E+00, -.23215800E+00, -.64605000E+00, -.17303400E+01, 0.76885900E+00, -.14974400E+00, 0.12365900E+00, -.53253500E-02, 0.52198800E+00, -.27431000E+00, 0.80257000E-01, 0.12381300E+01, -.18705400E-01, 0.41368800E-01, 0.81975900E+00, 0.10304500E+01, -.10443100E+01, -.95044900E-01, -.90081000E-01, 0.33929600E+00, 0.17507100E+00, 0.19742500E-01, 0.12414800E+01, 0.21004400E+00, 0.67524500E+00, -.61078000E+00, 0.24320300E+01, 0.43947600E+00, 0.79054800E+00, -.40157500E+00, 0.31085300E-01, -.20474000E+00, 0.67299200E-02, 0.30753800E+00, -.29240400E-01, 0.19693700E+01, 0.13360700E+01, -.14676900E+01, -.97244100E-01, 0.10484300E+00, -.42964900E+01, 0.29818100E+01, -.20647300E+01, -.25132700E-02, 0.12601900E+01, 0.11861600E+00, -.25370800E+00, -.58587800E+00, 0.98368500E+00, -.14553400E+01, 0.84562900E-01, -.33077000E+00, -.51017600E+00, 0.38904800E+00, 0.63956600E-01, 0.28144600E+00, -.29189600E+00, -.20222700E+00, -.26182700E+00, -.46895500E+00, -.88485000E+00, 0.42248600E+00, 0.41975500E+00, -.34576300E+00, 0.25812200E+00, -.13599100E-02, 0.24080900E+00, 0.70110800E+00, -.61072200E+00, -.33101300E+00, -.12999200E+01, -.76202900E+00, -.68814200E-02, 0.67060000E+00, 0.72137900E-01, 0.71718000E-01, -.10372600E-01, -.12486700E+00, -.10012900E+01, -.16662600E+00, 0.15344600E+00, 0.13878400E+00, -.19931400E+00, 0.93609500E+00, -.10204200E-01, 0.16286700E+01, 0.12802300E+01, -.16409300E-01, 0.24489600E+00, -.17262900E+00, 0.14188600E+01, 0.87308400E+00, 0.83329300E+00, 0.77814500E-01, -.10893700E+00, -.39410900E-01, -.45783000E+00, -.54296400E+00, -.20957200E-01, 0.10254800E+01, 0.35250900E+00, 0.66260900E-01, -.75838300E-01, -.40207300E+00, -.14214400E+01, 0.51635200E+00, 0.11535100E+01, -.12743000E+00, -.31864700E+00, -.90539900E-02, -.16794100E+00, -.21036400E+00, -.82584300E+00, 0.25408500E+00, -.48896200E-01, 0.26640100E+00, -.30272400E+00, -.62073800E-01, 0.26101200E+01, -.36170000E+03, -.12919000E+00, -.12738800E+03, -.17664800E+03, 0.87473100E+02, -.11683100E+03, 0.22918900E+03, -.17606000E+03, 0.16716100E+03, 0.38210000E+03, -.19830900E+03, -.26551400E+03, -.19098900E+03, 0.64769200E+02, -.92850400E+02, -.29338300E+02, 0.18618000E+02, -.69619600E+02, -.65735200E+02, -.19530300E+03, -.90483800E+02, 0.60052700E+02, 0.73716600E+02, 0.45251200E+02, -.40836000E+02, -.12258100E+03, -.19434800E+02, -.60233300E+02, -.12317800E+02, -.17952900E+03, -.23963500E+03, -.34757000E+03, 0.17614300E+03, 0.16272600E+03, 0.17351600E+03, -.14537000E+03, -.11102500E+03, 0.13946900E+03, -.14869400E+03, 0.11037700E+03, -.59165900E+02, -.24737800E+03, -.31541100E+03, 0.15744900E+03, 0.12321400E+03, 0.15802100E+03, -.52384300E+02, 0.19827300E+03, 0.24260900E+02, -.61995300E+02, 0.53779900E+02, 0.28702000E+03, 0.33140000E+03, 0.26178600E+03, -.14032900E+03, -.68480500E+02, -.13080900E+03, -.80103600E+02, -.14731000E+03, -.10784800E+03, -.15445700E+03, -.14446700E+03, -.21098200E+03, -.30136000E+02, -.37679800E+02, -.20014100E+02, 0.30970100E+02, 0.33446300E+02, -.44507200E+02, 0.15310100E+02, 0.12699800E+02, 0.33786700E+02, -.31341900E+02, -.26749000E+02, -.29001100E+02, -.30460800E+02, -.25775900E+02, -.29431200E+02, -.42689300E+02, 0.33090900E+02, -.28527200E+02, 0.30350600E+02, -.42635300E+02, 0.73942400E+01, 0.15386700E+01, -.30274000E+02, 0.10797900E+02, 0.33713400E+02, 0.29936100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21803900E+01, -.45869800E+00, -.21991500E+01, -.41281800E+01, -.49982500E+01, -.29747700E+00, 0.38968900E+01, 0.33363300E+01, -.13338500E+01, -.70684100E+00, -.48387500E-02, -.61267600E+01, 0.47505100E+01, 0.12009100E+01, 0.29600300E+01, 0.23542200E+01, 0.29623600E+01, 0.32009300E+00, 0.14352600E+00, 0.30133000E+01, 0.22659500E+01, -.48126600E-01, -.11727800E+01, 0.32616800E+01, -.32194100E+00, -.73873400E+00, 0.18546100E+01, -.34011100E+00, 0.11794500E+01, 0.13652700E+01, 0.27684600E+00, -.63974600E+00, 0.66484600E+00, 0.11774400E+01, -.82980400E+00, 0.11196600E+01, -.69290500E-01, -.13179200E+00, 0.44669800E+00, 0.14747800E+01, -.12509200E+01, -.85602700E+00, -.12169900E+01, -.35931800E+00, 0.36432600E+00, 0.68292800E+00, 0.44631600E+00, -.89273000E-02, 0.10028200E+01, -.10583500E+01, -.97786600E+00, 0.15052100E+01, -.24914200E+00, -.40039600E+00, -.44221500E+00, -.38067300E+00, -.16231400E+00, 0.13174400E-01, -.18934200E+00, -.92515000E+00, 0.86113700E-03, -.36160500E+00, 0.42789200E+00, 0.31406900E+01, -.20630500E+01, -.11082400E+00, 0.58493100E-01, 0.22328400E+01, 0.11559100E+01, 0.74685200E+00, 0.29924400E+01, -.60734200E+00, 0.19402400E+01, 0.77995300E+00, 0.89221600E+00, -.11736700E+01, -.52625300E-01, 0.16883700E+01, 0.53818500E-01, 0.30733400E+00, -.56329300E+00, -.17362000E-01, -.79858000E+00, -.20288200E+01, -.22301900E+01, 0.58136200E+00, -.92823400E-01, -.31842200E+00, 0.12461600E+00, -.61158100E+00, 0.38306100E-02, -.30557800E+00, -.47078300E+00, 0.17322600E-02, -.18104500E+00, -.60680300E-01, -.22556300E+01, -.10522300E+01, -.83091000E+00, 0.41667700E-01, 0.21194500E+00, -.53025800E+00, -.32926400E-01, -.20027900E+01, 0.57946100E+00, -.29636300E+00, -.30378200E+00, -.31390900E+01, -.14940300E+01, -.31802700E+00, 0.14812800E+01, 0.15439100E+00, -.32384700E+00, -.13818200E-01, 0.21643500E-01, 0.34183600E+00, -.46719600E+00, 0.16324800E-01, 0.28665100E+01, 0.75757100E+00, -.84107200E+00, 0.94934000E-01, 0.47905700E+00, -.37432600E+00, -.39823900E-01, -.52642900E+00, -.15985400E+01, 0.70444200E+00, 0.32133200E+00, 0.65237100E+00, 0.22252000E+01, -.27955300E-01, 0.19736200E+01, 0.61803400E+00, -.95258700E+00, -.19679700E+00, 0.37042800E+00, 0.11042600E+01, -.11527700E+01, 0.82200800E-01, 0.15346700E+01, 0.35274700E+00, 0.40005300E-01, 0.28163300E+00, -.35256200E+00, 0.34662200E-01, -.18407000E-01, 0.95627700E-01, 0.90088100E+00, 0.63356500E+00, 0.27915700E+00, 0.28398800E+00, 0.41581300E+00, -.15515700E+00, 0.38440100E+00, 0.70449600E-01, -.38059000E+00, 0.29557000E+00, 0.43303200E+00, 0.42412600E+00, -.12339600E+00, -.39250300E+00, 0.11788100E+01, 0.39666800E+00, -.17657700E+00, 0.35581600E+00, 0.72428300E+00, 0.44083600E+00, 0.21702400E+00, 0.21075500E+00, 0.24614300E+00, 0.40812200E+00, 0.70897700E+00, -.49421200E+00, -.90147200E-01, 0.26372800E+00, 0.17045000E+00, -.12584500E-01, -.79043000E+00, 0.13061100E+00, 0.24492400E+00, -.24816600E+00, 0.94189400E-01, -.33307600E-01, 0.25700900E-01, -.63715100E+00, 0.97552800E+00, -.76604200E+00, -.64835700E-01, -.52067600E+00, 0.25422700E-01, -.10060300E+00, 0.65499800E+00, -.10766600E+01, 0.42604200E-01, -.22721900E-01, 0.15539100E+01, 0.87527600E+00, 0.16645600E+00, -.14854100E+01, -.57624500E-01, 0.11222300E+02, -.64628100E+02, 0.35777300E+02, 0.32465500E+02, 0.53229400E+02, 0.85051200E+01, 0.27579700E+02, 0.79490400E+02, -.77664000E+02, 0.37875600E+02, 0.91133800E+02, 0.37567200E+02, -.39329900E+02, 0.18893300E+02, 0.34047700E+02, 0.40082200E+01, 0.15938700E+02, 0.32303300E+02, 0.25755200E+02, -.90006200E+02, 0.46701700E+02, -.31629300E+02, 0.45503300E+02, -.54197600E+01, 0.82675500E+01, 0.18902800E+02, 0.10452300E+01, 0.45702300E+02, -.69223700E+01, 0.98470900E+02, -.64236000E+02, 0.32785400E+02, 0.18961700E+01, 0.35449200E+02, 0.13564600E+03, 0.32373800E+02, -.50232400E+01, 0.19231100E+01, -.14788100E+01, 0.38556400E+02, -.42586700E+02, 0.15072800E+03, -.75017400E+02, -.18069400E+02, -.76340700E+02, -.15931700E+01, -.42570900E+02, 0.42300700E+01, 0.68290000E+02, -.42012400E+02, -.51344400E+02, -.16457400E+03, -.67401800E+02, 0.33773300E+02, 0.25427100E+01, 0.36226800E+02, -.66565400E+02, -.18627000E+02, 0.53928000E+02, 0.33952700E+02, 0.83599700E+02, -.23806500E+02, 0.21410300E+03, 0.13641800E+02, -.12099500E+02, -.27048900E+02, -.34834700E+02, 0.95661100E+01, -.41019500E+01, -.41775000E+01, -.35137200E+02, 0.26749200E+02, 0.10610600E+02, -.42229600E+01, 0.35271000E+02, 0.63991200E+01, 0.36229300E+02, 0.12719500E+02, -.35324700E+02, -.44503200E+01, -.36386900E+01, 0.12187200E+02, -.28197400E+01, -.28035500E+01, 0.71325400E+01, -.17288600E+02, -.22155800E+02, 0.30948800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21682900E+01, -.12576200E+01, -.16813200E+01, -.14346300E+01, -.26357700E+01, -.37840500E+00, 0.12034300E+01, -.16940700E+01, -.38998000E+01, -.79803700E+00, 0.96774900E+00, 0.37559000E+01, 0.57063900E+00, 0.47715100E+00, 0.28524200E+01, -.21966900E+01, -.18794000E+01, 0.37153800E-01, 0.13600700E+01, -.77080200E-01, -.25009600E+01, -.61872600E+00, -.62106700E+00, -.17717900E+01, 0.23182300E-01, -.23518600E-01, 0.82560800E+00, -.14928200E+00, -.10211100E+01, -.32565200E+01, -.77410700E+00, 0.14876200E+01, -.17021500E+00, 0.16742300E+01, 0.76299100E+00, -.20382600E+01, -.59621300E-01, -.33978100E+00, 0.45743500E+00, 0.22790100E+01, 0.32138800E+00, -.12787400E+00, -.33182500E+01, -.14407300E+01, -.25254500E+00, 0.17377500E+01, -.18705600E+00, -.51585900E-02, -.12765100E+01, -.22546900E+00, -.97980200E+00, -.10951600E+01, -.31248000E+00, -.41312200E+00, 0.82382300E-01, -.10205100E+01, -.14512200E+00, 0.10554700E+02, -.12821900E+00, -.38420000E+00, 0.49136000E+00, -.17358600E+00, -.66748200E+00, 0.37795500E+01, -.89162600E+00, -.11315900E+00, 0.26767900E+00, 0.43262700E+01, 0.75373900E+00, 0.64811500E+00, -.31129500E+00, 0.18006100E+01, -.36548900E+00, -.32808700E+00, 0.36116800E-01, -.55187100E+00, 0.23765900E+00, 0.14703500E+01, -.97212300E-01, -.70789200E-02, -.64102500E+00, 0.31038100E-01, -.11460800E+01, -.37412800E+01, -.31370800E+01, 0.11351400E+01, -.50609200E+00, 0.74360000E-01, -.70453400E-01, -.39492400E+00, -.37339200E+00, -.24837000E+00, 0.15390100E+00, -.87356900E+00, 0.62351100E+00, -.87888200E-02, -.23177300E+01, 0.18294400E+00, -.57753300E+00, -.39445000E+00, -.16802200E+00, -.36845000E+00, -.24441000E-02, -.40557500E+00, 0.57666100E+00, 0.12215600E+00, 0.39755100E+00, -.31061400E+00, -.98197500E+00, 0.13440100E-01, 0.63520900E+01, 0.70976200E+00, -.32745000E+00, 0.50844300E-02, 0.14641100E+00, 0.76064900E+00, 0.42506100E+01, 0.10991500E+01, -.92032000E+00, -.93003200E+00, 0.53867100E-01, -.67768700E+00, 0.38077200E+01, -.19811000E+01, 0.11859000E-02, 0.66012800E+00, -.41845400E+00, -.82324200E+00, 0.72576000E+00, -.39346800E-01, -.82639800E+00, -.26085600E+00, -.81554600E+00, -.15120400E+00, -.10240600E+00, 0.52059500E-01, 0.33598200E+00, 0.50880400E+00, 0.87848600E+00, 0.29540500E+00, -.16667800E+00, 0.61533100E+00, -.37022600E+00, -.44614400E+00, -.13146600E+00, 0.47510200E+00, 0.11432300E-01, -.32866100E+00, -.41502200E+00, -.42297600E+00, -.10371700E+00, -.38509800E+00, -.16608800E-01, -.64383500E-01, -.85777100E+00, 0.59821100E-02, 0.17534000E+00, 0.46718300E-01, 0.86385300E-01, -.67075900E+00, -.59587800E-01, -.52778100E+00, -.16723100E+00, -.47766300E+00, 0.20957500E+01, -.51325900E+00, 0.29451500E+01, 0.15193200E+01, 0.48589700E-01, 0.32799500E+00, -.15265900E+00, 0.24793800E+01, 0.50606600E-01, 0.23994600E+01, -.22047900E+00, -.42233900E+00, -.78811800E-01, 0.70992800E-01, 0.14531300E+00, 0.34622500E-01, 0.65125700E-01, 0.20377200E-01, -.29378600E+00, 0.65819000E-02, 0.32595300E-01, -.78290700E+00, -.97351800E-01, -.57656000E+00, 0.16057200E+00, -.15303000E-01, 0.12572800E-01, 0.96421600E-01, -.36697300E+00, 0.14657900E+01, -.18100000E+00, -.90690300E-01, -.70299400E-01, -.18116200E+01, -.21089800E+00, 0.22168600E+01, 0.31987100E+00, -.70136600E-01, 0.15990700E+03, 0.35352700E+02, -.18680100E+03, -.11848900E+03, -.87596600E+02, 0.69945900E+02, -.27214900E+03, -.49114800E+03, 0.25032100E+03, 0.14242700E+03, 0.24564200E+03, -.98740700E+01, 0.32355800E+00, 0.54371600E+02, -.23457200E+02, 0.27133900E+03, -.15855500E+02, 0.13921800E+03, -.17638000E+03, 0.84747200E+02, 0.12264900E+03, 0.88158100E+02, 0.48414400E+02, -.23049400E+02, 0.75738400E+02, -.78342300E+01, 0.33179800E+02, -.54230100E+02, -.22072100E+02, 0.99637700E+02, -.50532400E+02, -.14612500E+03, -.49960200E+02, 0.23643500E+03, -.25628600E+02, 0.36691700E+00, 0.11986900E+03, 0.17738500E+03, -.63431200E+02, -.51248800E+03, 0.13936400E+03, -.70182600E+02, 0.86788900E+02, -.69952600E+02, 0.10228500E+03, 0.90936300E+02, -.16080800E+03, -.45315900E+02, 0.12421500E+03, 0.81400900E+02, 0.57852400E+02, -.33064300E+03, 0.16552100E+03, 0.25997400E+02, 0.16513500E+03, 0.31438800E+02, 0.63468500E+01, 0.14234000E+03, 0.73025200E+02, 0.11487800E+03, 0.36713800E+02, -.33239800E+02, 0.39203800E+02, 0.44639400E+01, 0.71285700E+02, 0.68350200E+02, -.11933600E+02, 0.95473000E+01, 0.11655400E+02, 0.66708400E+02, -.71507000E+02, 0.26765800E+02, 0.26174000E+02, -.60582700E+02, 0.77040900E+01, -.61442000E+02, -.44807300E+02, 0.67830600E+02, 0.28606100E+02, -.18728000E+02, -.45983000E+02, 0.14356700E+02, 0.94783100E+01, 0.32209400E+02, 0.29579800E+02, 0.25051100E+02, -.42933600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11706400E+01, 0.37854000E+00, 0.16915400E+01, -.19145800E+01, 0.16473400E+01, 0.41333900E+00, 0.11980800E+01, 0.13321800E+01, -.42736500E+01, -.10348900E+01, -.66316500E-01, 0.99480100E+00, -.39072200E+00, -.83510500E+00, 0.17698600E+01, -.35300000E+00, -.60146100E+00, 0.89778300E-01, 0.52456900E+00, 0.43250600E+00, 0.67395100E+00, -.67548700E-02, -.33440400E+00, 0.82775200E+00, -.34662000E-01, -.49030200E-01, 0.88854500E+00, -.16987200E+00, 0.41453200E+00, -.11833100E+01, 0.82794300E+00, -.10276400E+01, -.54633700E+00, 0.17516000E+01, -.10155800E+01, -.27048800E+01, -.94449800E-01, -.75150700E+00, 0.11083200E+01, -.68583600E+00, 0.11888100E+01, 0.75899700E+00, 0.39367500E+00, 0.29336900E+00, -.50760200E+00, -.20901500E+00, 0.55965900E+00, -.93572500E-02, 0.60526800E+00, 0.29501600E+00, -.85841500E+00, -.11846700E+00, 0.47211900E-01, 0.55675100E+00, -.24467800E+00, 0.68702400E+00, 0.56900000E+00, -.27763400E+01, -.54302000E-01, 0.60792200E+00, -.23165300E+00, -.18606200E+00, 0.26190600E+00, -.97162000E+00, -.97009200E-01, -.15511800E-01, -.15415900E+00, -.21171600E+01, -.89735200E+00, -.63017900E-01, -.15023800E+01, -.11996500E+01, -.50595300E+00, -.10875900E+00, -.24537500E+00, -.73202400E-01, -.15427800E+00, -.10297400E+01, -.15202400E+00, -.54256400E+00, 0.98370900E-01, -.77179400E+00, 0.68583300E+00, 0.16154000E+01, 0.14445300E+00, -.27008000E+00, 0.39490800E-01, 0.38280800E+00, -.30675500E+00, 0.88496500E+00, 0.84538700E+00, 0.17245600E+00, -.38395100E-01, 0.21672100E+00, -.34972400E+00, -.65990000E+00, 0.10862300E+01, 0.15198400E+01, 0.45335100E+00, 0.16708300E+01, -.32997500E+00, 0.83212600E-02, 0.86583200E-02, 0.26413700E+01, -.48516300E+00, -.49298500E+00, -.49117700E+00, 0.61230700E+00, -.28399600E-01, 0.44923100E+00, -.16284600E+01, -.44016000E+00, -.43943800E+00, -.39553300E-02, -.66454200E-01, -.37134400E+00, -.10419400E+01, -.15032800E+01, 0.26552500E+01, 0.88968800E+00, -.10297200E+01, -.87612700E-01, -.42008500E+01, 0.60330100E+00, 0.56699100E-02, -.51250200E+00, 0.40842000E+00, -.41187600E+00, 0.79349600E+00, -.64217800E+00, 0.28268500E+00, 0.35639200E-01, -.14108500E+00, 0.14703600E+00, 0.27552300E+00, 0.45475500E-02, 0.49253900E+00, 0.56994000E-01, 0.35038800E+00, 0.19748200E+00, 0.18514800E+01, 0.50443900E-01, -.78265300E-01, 0.27746100E-01, -.27928300E+00, 0.68004000E-01, -.11558100E-02, -.39147400E+00, -.37832700E+00, 0.18683300E+00, 0.13522800E+00, 0.52316600E+00, 0.13108500E+00, -.24072900E+00, -.39152600E-01, -.27524000E-02, -.38808300E+00, 0.74979000E-01, 0.23924500E+00, 0.69193600E-01, -.12339200E+00, 0.11906200E+01, 0.49041600E+00, 0.41160900E+00, 0.21172400E+00, 0.24899800E+00, -.38907500E+00, -.99297200E+00, -.71363200E-01, -.11366600E+00, -.78168800E+00, 0.43324900E+00, 0.12735900E+01, 0.17221300E+01, 0.18624700E+00, 0.39893000E+00, 0.19187000E+00, 0.47756600E+00, -.50650800E+00, 0.70198800E-01, 0.85699600E+00, 0.20627800E+00, 0.65200800E+00, -.32954100E+00, 0.82948900E-01, 0.19555300E+00, 0.27341500E+00, 0.11781800E+01, -.59486700E-01, -.28902800E+00, 0.19104300E-01, -.69045600E-01, 0.18294400E+00, 0.50672000E+00, 0.33602900E+00, -.50448900E-01, 0.14926800E+00, 0.10776700E+00, -.11260300E+00, -.11622200E+01, 0.15251400E+00, -.64275000E-01, -.32020400E-01, -.37957800E+02, 0.45548500E+02, 0.42284900E+01, -.62946800E+02, -.64842400E+01, -.40226800E+02, -.29277100E+02, 0.16859100E+02, -.27030000E+01, 0.14717300E+02, -.37030700E+02, 0.17802400E+01, -.28355300E+02, -.27250900E+02, 0.34735300E+02, -.76020300E+01, 0.39053100E+02, -.41728200E+02, 0.15588500E+02, -.14755300E+02, 0.20810700E+02, 0.27698600E+02, 0.28870600E+01, 0.27983000E+02, 0.23945800E+02, 0.18303900E+02, 0.24208000E+01, 0.10134500E+03, 0.32003200E+03, -.16057200E+03, -.10986400E+03, -.16017800E+03, 0.28139800E+02, -.38654200E+02, -.10582400E+03, 0.36877000E+02, -.38914500E+02, -.60860300E+02, 0.11570100E+02, 0.13680200E+03, -.68977700E+02, 0.92206500E+01, -.68235200E+02, 0.58985500E+02, 0.30027800E+02, -.11972700E+03, -.21953500E+02, 0.74838800E+02, 0.94676600E+01, -.39204900E+02, -.24720000E+03, 0.12292000E+03, 0.74662900E+02, 0.12331900E+03, 0.32859800E+02, 0.40118500E+02, 0.11954900E+03, 0.10123800E+03, 0.10753600E+03, 0.62702600E+02, 0.30881700E+02, 0.31843400E+02, 0.85058100E+01, 0.16417300E+02, 0.83455500E+01, 0.26711500E+02, 0.66856100E+00, -.37968800E+01, 0.71613700E+01, -.16444600E+02, 0.19259900E+02, 0.19584300E+01, -.47683200E+01, 0.27382900E+02, -.54709800E+01, 0.11996400E+02, 0.72828300E+01, 0.34908600E+01, -.91615300E+01, 0.11999500E+02, 0.33021400E+02, -.51395200E+01, 0.14099100E+02, -.10104100E+01, 0.10848100E+02, -.24438400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.60949300E+00, 0.11778200E+01, 0.19473800E+01, -.92615500E+00, 0.81066900E+00, 0.21008200E+00, 0.89207500E+00, 0.10415400E+01, -.15023200E+01, -.28163300E+00, 0.51628900E-01, -.16171000E+01, 0.21479400E+01, 0.66117900E+00, 0.75480500E+00, 0.94197200E+00, 0.71785400E+00, -.42378100E+00, -.38258000E+00, -.42206500E-01, 0.98882200E+00, -.52044900E-01, -.14761900E+00, -.20833000E+00, 0.35947400E-01, -.61505300E-01, -.20623500E+00, 0.26456200E-01, 0.53391600E+00, -.31635400E+00, -.29341400E+00, -.75143900E+00, 0.55842700E-01, 0.50048800E+00, 0.22783300E+00, 0.11716500E+00, 0.14049700E-01, 0.88467200E+00, -.62603200E+00, 0.50042300E+00, 0.32290600E+00, -.13645100E+00, -.31356100E+00, -.84729900E-01, 0.15103500E+00, 0.23541400E+00, 0.15745400E+00, -.13467800E-02, 0.67997000E+00, -.31703700E+00, 0.12778200E+00, 0.21131600E+01, -.62051700E-01, 0.53512800E+00, 0.12071400E+00, 0.36537700E-01, 0.13273600E+00, -.47622200E-01, -.25442700E-01, -.11328800E+00, -.46827800E-01, 0.49177900E+00, -.28669700E+00, -.28341200E+00, -.93217200E+00, 0.28001700E-02, 0.39240000E-01, 0.10882100E+01, 0.59497500E+00, 0.17628100E+00, -.13949600E+01, -.35365500E+00, -.54850600E+00, -.18493900E-01, -.52466600E-01, 0.24686900E+00, -.76698400E-01, -.74353200E+00, -.15402600E+00, -.67067600E-01, -.41978200E-01, -.98460100E-01, -.31013800E+00, -.98187700E+00, -.10198400E+01, -.17589400E+00, -.20577000E-01, 0.13084300E+00, -.12355300E+00, 0.19367000E+00, -.37975600E+00, -.10218900E-01, -.55347600E+00, 0.19918400E+00, 0.38287200E+00, -.22589200E+00, -.59888800E+00, 0.65578500E+00, -.24793200E+00, 0.10790100E+01, 0.19198100E-02, 0.17551600E+00, 0.22490600E-02, 0.28094300E+00, 0.36288400E+00, 0.83797800E-01, -.24646700E+00, 0.90693500E+00, -.10680500E+00, -.19038900E-01, 0.37184800E+00, 0.21148600E+00, -.11490900E+00, -.12608200E-02, 0.15136200E+00, 0.19807600E+00, 0.70922800E+00, -.18120600E+00, 0.11415900E+01, 0.11382100E+00, -.40627600E+00, 0.60877000E+00, 0.62663700E+00, -.53982700E+00, -.15610800E-01, 0.15186700E+00, 0.27128100E+00, -.37541900E+00, 0.63803900E+00, 0.16185700E+00, -.13937200E+01, -.50529100E-01, -.57830500E-01, -.73284400E-02, 0.25555900E+00, -.16495000E-01, -.28346300E+00, -.48979600E-01, -.10587900E+00, -.93263300E-02, 0.21867000E+00, 0.13348500E+00, -.31400300E-01, 0.96344500E-01, -.25187200E-01, -.19074500E-01, 0.43189000E-02, 0.19538200E-01, 0.22523400E+00, -.14634900E+00, -.25510200E-01, -.93570300E-01, 0.36500800E-01, -.87424800E-01, -.29383800E+00, 0.88580200E-02, -.17084600E+00, -.95203300E-03, 0.21907000E-01, 0.79322900E-03, -.35351100E-01, -.23990400E+00, -.30480700E+00, -.13975500E+00, 0.72585700E-01, -.10619700E+00, 0.40191400E+00, 0.62762200E+00, 0.45184300E-01, 0.11222000E+00, 0.34975100E+00, 0.56196100E+00, -.36197600E+00, 0.44664500E+00, 0.40882400E-01, 0.16496600E+00, 0.30016200E-01, -.17439700E-01, -.56859500E+00, -.10902800E-01, 0.64109800E+00, -.16414400E+00, -.10911800E+00, 0.57200000E-01, -.73564200E-01, -.29847300E+00, -.21954100E+00, 0.36260900E-01, 0.80559500E-02, -.17322000E-01, -.16795300E-02, -.68592000E-01, 0.10133600E+00, -.40811400E+00, 0.15747400E+00, -.13908500E-01, -.24175000E+00, 0.10480800E-01, 0.32317400E+00, -.69284800E+00, -.15630200E+00, 0.13225700E-01, -.11400800E+00, 0.15324500E+00, -.71568600E+02, -.50400100E+02, 0.45368900E+02, -.43417100E+01, 0.11833500E+02, 0.16514900E+03, -.84154200E+02, -.73700800E+02, -.82586200E+02, 0.70845100E+01, -.16580000E+02, -.41510900E+02, 0.10022300E+02, -.58405400E+02, -.38171900E+01, -.95074000E+02, 0.35442400E+02, -.14451100E+02, 0.59778900E+01, -.17696700E+02, 0.62296000E+01, -.16499400E+02, 0.10610300E+01, 0.32435500E+02, -.29423100E+01, -.36773000E+02, -.10473600E+03, -.18143500E+02, 0.94646700E+01, -.14670000E+02, 0.90548400E+01, -.50126100E+01, 0.40354600E+02, 0.17305200E+02, -.13294900E+02, -.33879800E+02, 0.49834500E+02, -.15085100E+03, -.80157700E+02, 0.40298600E+02, 0.16060600E+02, 0.40033100E+02, -.14567300E+02, 0.44237200E+02, 0.26820200E+02, -.28768800E+02, -.76080300E+02, 0.59004000E+02, 0.24575300E+02, 0.15224100E+03, -.76411200E+02, -.49317300E+02, -.75984600E+02, -.20076000E+02, -.59697000E+02, -.68694100E+02, -.13171100E+02, -.22676000E+02, -.81542300E+02, -.36181700E+02, -.25800000E+02, -.88980900E+01, 0.11859100E+01, 0.63127100E+01, -.12503300E+02, 0.23795700E+01, 0.42221900E+01, 0.67099800E+01, -.11061000E+01, -.17024900E+02, -.23410700E+01, -.64966400E+01, -.18162900E+02, -.61029900E+01, -.18729900E+02, 0.67168500E+01, -.29414800E+01, 0.14568000E+02, -.18904500E+02, -.18705700E+02, -.34760300E+00, -.24386500E+02, 0.17194800E+01, -.77843100E+01, 0.21863000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.59854100E+00, 0.12346800E+00, -.10210000E+01, -.49897400E+00, -.28129800E+00, 0.81752100E-01, -.29201900E+00, -.25040500E+00, 0.75740300E+00, 0.39641700E-01, 0.17207200E-01, 0.64713400E+00, -.10293100E+01, -.31180600E+00, -.95926000E+00, -.10151500E+00, -.18222200E+00, 0.25663900E-01, -.24854900E-01, -.18416600E+00, -.57540400E+00, -.63841500E-01, 0.19930800E+00, -.60713000E+00, 0.93255400E-02, -.53703300E-02, -.23439500E+00, 0.19272300E+00, -.15731100E+00, 0.21080000E+00, 0.19257900E+00, 0.12092300E+00, -.14295700E+00, -.49268700E+00, -.24940800E-01, 0.27196300E+00, 0.98799500E-02, -.62922500E-01, -.61698700E-01, 0.21426700E+00, -.66626300E+00, -.11920200E+00, -.23448600E+00, -.59445100E-01, -.16206800E+00, -.18081300E+00, -.25119800E+00, 0.22623700E-02, 0.84762200E-02, -.24139700E+00, 0.32793800E+00, 0.74049000E+00, 0.98935000E-03, -.18314800E+00, -.69747700E-01, -.28041900E+00, -.19411800E+00, 0.45183600E+00, 0.15909200E-01, -.99342500E-01, -.73445600E-01, -.29065600E-01, 0.29825000E-01, 0.45598300E+00, 0.60797300E+00, -.18060900E+00, 0.10333200E+00, 0.86881700E+00, -.26647400E-01, 0.20149000E+00, -.39434300E+00, 0.98301700E+00, 0.19840400E-01, -.91441000E-01, -.10612300E+00, 0.18018200E+00, 0.76905100E-01, 0.46864600E+00, -.73476000E-01, 0.13269700E+00, -.17291300E+00, 0.29747800E+00, -.11445300E+00, -.63124000E+00, 0.30936900E+00, 0.59463300E+00, -.32268600E+00, -.20608100E+00, 0.14496100E+00, -.23853200E+00, -.45134300E+00, -.41455500E-01, -.57922700E+00, -.11698500E+00, -.20218000E+00, 0.84642800E-01, 0.94042000E-01, -.34534800E+00, 0.14081300E-01, -.23856000E+00, 0.43059700E-01, -.49068900E-01, -.14187400E-02, -.32614700E-01, -.23689300E+00, 0.16766800E-01, -.19518400E-01, -.99090000E-01, 0.77333200E-01, 0.58770900E-01, 0.14580700E-01, -.56323500E-01, -.18208400E-01, 0.43743900E-03, -.43854300E-01, -.63365700E-01, 0.38276800E+00, 0.33673300E+00, -.35848300E+00, -.10578000E+00, 0.24196000E+00, 0.19855500E+00, 0.28471900E+00, 0.25166100E+00, -.50112400E-02, 0.85376500E-01, -.37780700E-01, 0.44400400E-01, 0.71025900E+00, 0.51423600E-01, -.31636100E+00, 0.81291100E-01, 0.11050200E+00, -.67548200E-01, -.17257500E+00, -.49293300E-02, 0.21266400E+00, 0.30686100E+00, -.10922700E+00, 0.28631500E-01, 0.18870300E+00, -.14536900E-01, 0.35262900E-01, -.87049100E-01, -.28209200E-01, 0.32428900E-01, -.36847500E-02, 0.17604400E-01, 0.13407100E+00, 0.10179000E+00, 0.97407400E-01, 0.19495200E+00, 0.82134700E-01, 0.88325400E-02, -.61266900E-02, 0.10146500E-01, -.61921400E-02, 0.12423400E-01, 0.82204200E-01, -.51244600E-01, -.34760100E-02, 0.64729000E-01, -.20866300E-01, -.30335200E-02, 0.10349900E+00, -.67953000E-01, 0.32232500E-01, 0.51586500E+00, 0.15991400E-02, 0.14202600E+00, 0.33496500E+00, -.90155900E-01, -.20222700E+00, -.20235100E+00, 0.13099500E+00, 0.34530200E+00, -.49776400E-01, 0.49249600E-01, 0.18673500E+00, -.24874600E-02, 0.34736900E+00, 0.10139300E+00, -.38796100E+00, -.89665100E-01, 0.39400600E-01, -.10564300E+00, 0.38033400E+00, -.48958100E+00, -.47985400E-01, -.10425900E+00, 0.31944700E-02, -.23767300E-01, -.27728200E+00, 0.25022000E+00, -.16059500E-01, -.78791100E-01, -.71879600E+00, -.27937900E+00, 0.51051300E+00, 0.11400200E+00, -.56766700E-01, -.32821500E-01, 0.11214700E+00, -.17018600E+00, 0.63229000E+00, -.31533000E+02, -.61577000E+02, 0.11327400E+02, -.12691600E+02, 0.62186100E+02, -.31143800E+02, -.23502700E+02, -.31021500E+02, -.27699000E+02, -.32100600E+01, -.20315500E+02, -.13908200E+02, -.11047000E+02, 0.88419300E+01, -.14821200E+02, 0.53716000E+01, -.46057600E+01, -.16056100E+02, -.27183900E+01, 0.26220000E+02, -.29057900E+01, -.13755700E+02, -.97821900E+01, -.19035400E+02, -.10015400E+02, 0.10016800E+02, 0.46481500E+01, -.24201400E+01, 0.14016700E+02, -.25266900E+01, 0.27154700E+02, -.14868200E+02, -.25537000E+02, 0.41010500E+01, 0.27851000E+02, -.21639500E+02, 0.93370600E+02, 0.36525900E+02, -.18416000E+02, 0.59413700E+01, -.17941300E+02, -.24491700E+01, -.31291700E+01, -.22700700E+02, 0.71819300E+01, 0.44857200E+02, -.60993900E+01, -.10304100E+02, -.36805600E+02, 0.18087400E+02, 0.22941000E+02, 0.18248700E+02, 0.40338900E+02, 0.24793200E+02, 0.22856800E+02, 0.36274100E+02, 0.92789800E+01, 0.22468800E+02, -.54520900E+02, 0.56763900E+01, 0.34286000E+01, 0.11931900E+02, 0.81427900E+01, 0.52842200E+01, 0.56765700E+01, 0.24054000E+01, 0.76531100E+01, -.11864200E+02, 0.25217600E+01, 0.20902100E+01, -.76641900E+01, 0.66767700E+01, -.80823200E+01, -.77137800E+01, 0.75538000E+01, 0.29006600E+01, -.14987400E+01, -.76187000E+01, 0.87533400E+01, 0.32482200E+01, 0.70794800E+01, 0.59118800E+01, 0.71293300E+01, -.49590800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.44052500E+01, 0.89177200E+00, 0.43107400E+01, 0.19384600E+01, 0.71541500E+01, 0.97955000E+00, -.22989900E+01, 0.49230200E+01, 0.38833000E+01, 0.29463800E+00, -.22772300E+00, 0.12125900E+01, -.77028400E+00, 0.17297000E+00, -.59276100E+00, 0.52229500E+01, -.11477700E+01, -.46991200E+01, -.38968700E+00, -.70306900E+01, -.19785200E+01, 0.77620700E+00, 0.12678700E+01, -.56911800E+01, -.18448900E+00, -.91501800E+00, -.46889500E+01, 0.66211800E+00, -.23367200E+01, -.32344400E+01, -.97957400E-01, 0.15560700E+01, -.32549400E+01, 0.20765200E+00, 0.78785900E+00, -.46741700E+01, -.21038300E+00, -.85094600E+00, 0.31305600E+00, -.41605200E+01, 0.91272300E+00, 0.59536700E-01, 0.27504800E+01, 0.28492200E+00, -.60876800E+00, -.59570500E+00, -.59441400E+00, -.33678600E-01, -.92518900E+00, 0.26388800E+00, 0.47133200E+00, -.57515800E+01, 0.23235200E+00, -.88910800E+00, 0.43606800E+00, 0.63702600E+00, -.11148000E+00, 0.48580500E+01, -.71686700E-01, 0.13849600E+01, -.23870200E-01, -.79905600E+00, -.25181900E-01, -.49899200E+01, 0.60683900E+01, 0.44026400E+00, -.68471400E+00, -.37291100E+01, -.30308600E+01, 0.28116600E+00, -.24114700E+01, 0.27816800E+01, -.28777100E+01, -.12026400E+01, -.15204600E+01, 0.27514700E+01, 0.15536500E+00, -.73520200E+00, 0.84437200E-01, -.16606900E+00, -.26587400E+00, -.85636600E+00, -.62260800E+00, -.92252600E+00, 0.13254700E+01, 0.20541800E+00, -.47926600E+00, 0.23994100E-01, 0.49560000E+00, -.86064200E+00, 0.12061000E+01, 0.98209000E-01, -.64544500E-01, -.69456900E+00, -.11450400E+01, -.39180100E+00, 0.23082500E+01, 0.29714800E+01, 0.11030700E+01, 0.26420500E+00, -.67190000E+00, -.14174900E+00, -.21753300E-01, 0.34069400E+01, -.59050900E+00, 0.30706700E+00, 0.87921300E+00, 0.12861700E+01, 0.11465500E+01, -.31073900E+00, -.43847000E+00, 0.86503900E-01, 0.35842800E+00, -.13730100E-01, -.35430600E+00, -.37306300E+00, -.95086100E+00, -.11200200E+01, 0.24769300E+01, 0.43875200E+00, -.45681600E+00, 0.40906100E+01, -.52383600E+00, -.87920200E-01, -.49986500E-02, -.50177600E+00, 0.12509300E+01, -.11046300E+01, -.29931700E+00, -.14969400E+01, -.78514400E+00, -.64681500E+00, -.19312900E+01, 0.25937200E+00, 0.22027900E+01, -.79969800E-01, -.10025900E+01, -.98648500E+00, 0.14673700E+01, -.66418600E-01, 0.25547500E+00, 0.75350600E+00, -.15132800E-02, -.42814900E+00, 0.82919600E-01, -.66503300E+00, -.23908300E-01, 0.35813700E+00, -.48708800E+00, 0.13237500E+00, 0.79345000E-01, 0.81989900E+00, -.99277700E-01, -.13058700E-01, -.83835800E+00, 0.16000900E+00, -.16811100E+01, -.70090200E-03, -.37505400E+00, -.10639500E+01, -.37362300E+00, 0.45331400E+00, -.25364100E+01, -.53804800E+00, 0.51074900E+00, -.84337600E+00, 0.12587600E+01, 0.83853900E+00, 0.98516300E-01, 0.61098900E-01, -.64838700E+00, 0.12588300E+01, 0.40959800E+00, 0.25731700E+01, -.55818700E-01, -.68287200E+00, -.33790400E-01, 0.24987100E+00, -.24218300E+01, 0.76339700E-01, 0.34006300E+01, -.46376800E+00, 0.54635400E+00, 0.19044100E+00, -.33331500E+00, -.94645200E+00, -.15453400E+01, 0.17724300E+01, -.48315400E-01, -.27993200E+00, 0.27501000E-01, -.66350500E-01, 0.43971600E+00, -.18843700E+00, 0.20991900E+00, 0.14721600E+00, -.17585000E+01, 0.34296400E+00, 0.25716600E+00, -.23363400E+00, -.50437700E-01, 0.44295100E+00, 0.32183500E-01, -.45327300E+00, -.99649700E+00, 0.16084400E+01, 0.22694500E+03, -.56476300E+02, 0.10291000E+03, 0.30411400E+03, -.15428600E+03, -.17127200E+03, -.15209800E+03, 0.13747100E+03, -.12576400E+02, -.61895000E+02, 0.43886200E+02, -.13185900E+03, -.42661600E+02, -.19432800E+03, 0.11425400E+03, -.47465200E+02, 0.71592600E+02, -.57046700E+02, -.25330700E+02, 0.92347400E+01, -.32134000E+02, -.13280100E+02, -.53146600E+02, 0.58726600E+02, -.12039100E+03, -.36479900E+03, 0.18431000E+03, 0.17151200E+03, 0.18231500E+03, -.26562700E+03, 0.10219300E+03, 0.11120100E+03, -.14905900E+03, -.29722700E+02, 0.14383200E+03, -.95332200E+02, -.39411100E+03, 0.19704800E+03, -.52280200E+01, 0.19777500E+03, -.53894100E+02, 0.25445200E+02, 0.14327000E+03, -.88926600E+02, -.42858500E+02, 0.79023700E+02, 0.67297300E+02, 0.33311500E+03, -.17087200E+03, -.78197500E+02, -.16606500E+03, 0.11399700E+02, 0.27648600E+02, -.20860000E+03, -.20943900E+03, -.23981800E+03, 0.47205100E+01, -.10335900E+00, -.68469000E+02, 0.61002200E+01, -.26566200E+01, 0.10751900E+02, -.39794500E+02, -.36383900E+01, 0.59710300E+01, 0.12825600E+02, 0.22554500E+01, -.41539800E+02, 0.33111800E+01, -.17630200E+02, -.59559100E+02, -.16878700E+02, -.11571900E+02, 0.12539400E+02, 0.15277500E+01, 0.13346000E+02, -.11425000E+02, -.66334200E+02, 0.75179100E+01, -.23389000E+02, -.27972900E+00, 0.22748800E+02, 0.41851900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20110300E+01, 0.15768100E+00, 0.67850000E+01, 0.64228300E-02, 0.61226700E+01, 0.56049700E+00, 0.14055600E+01, 0.18591000E+01, -.70111400E+01, -.12409500E+01, -.42247400E+00, 0.66762900E+01, -.25097300E+01, -.12829600E+01, 0.26834500E+01, -.23484300E+01, -.35407700E+01, -.84835700E+00, -.21098500E+00, -.31225100E+01, -.23445300E+01, -.26800300E-02, 0.24899800E+00, -.87411400E+00, 0.21498100E+00, -.24862200E-01, -.14156900E+01, 0.97150900E-01, 0.13685100E+00, -.10077600E+01, -.35969400E+00, -.25766200E+00, -.45058500E+00, 0.21465900E+00, -.39542900E+00, -.27301700E+01, -.91382000E-01, -.12042800E+01, 0.53265500E+00, -.11339300E+01, 0.94420300E+00, 0.48224100E+00, 0.86933200E+00, 0.35781300E+00, -.64341900E+00, -.77707700E+00, -.51212400E+00, -.68494300E-02, -.17074300E+00, -.43045900E+00, 0.69674500E+00, -.13503100E+01, -.24449800E-01, -.78379600E+00, 0.33818500E+00, -.29086300E+00, 0.49879500E+00, 0.14552100E+01, -.71551900E-02, 0.59820400E+00, 0.45338700E+00, -.82190500E-01, 0.19760700E+00, -.38272400E+00, 0.23687200E+01, -.23662100E-02, 0.30587800E+00, 0.75066300E+00, -.75189700E+00, -.94323600E-01, -.37459700E+00, 0.22813000E+00, -.37443200E-01, 0.93747900E-01, -.58742700E-01, -.14630600E+00, -.67582500E-01, 0.42138100E+00, -.33085800E+00, -.39883700E+00, 0.41359400E-02, -.96383900E-01, -.37414200E+00, -.24861000E+00, -.94326000E+00, -.65494200E+00, 0.25009500E+00, -.41329600E-01, 0.36943800E+00, -.62773200E+00, 0.59520300E+00, -.11153200E+00, -.42997700E+00, -.34663000E+00, -.34772400E+00, -.37771600E+00, -.13556200E+01, -.83630100E+00, -.26642800E+00, -.10906100E+01, 0.17273500E+00, -.14729200E+00, -.21562300E-01, 0.38682200E+00, 0.89612700E+00, 0.28745400E+00, -.14011600E+00, -.31154300E+01, 0.11132700E+00, -.43959000E+00, -.31779000E+01, -.35122800E+00, 0.38449600E-01, -.64970600E-02, 0.11601100E+00, 0.75371000E-01, -.19072900E+01, -.12922800E+01, 0.38843500E-01, -.12377000E+00, -.51861100E-01, -.42460200E+00, -.18807600E+01, -.21187400E-01, 0.18950900E-01, -.86838600E+00, -.21773700E+00, 0.26974200E-01, -.89696900E+00, 0.53032200E+00, 0.17063300E+00, -.63746000E-01, 0.44129400E+00, 0.39948300E-02, -.10524800E+01, 0.39612800E-01, -.13779500E+01, -.15601200E+00, 0.16269600E+00, 0.21677200E+00, -.20091600E+01, 0.30194400E+00, -.43937300E+00, 0.22168100E+00, 0.58994000E+00, -.44643500E+00, 0.33577100E-01, -.36246600E+00, -.86336000E+00, 0.11293300E+00, -.35217100E+00, 0.53072700E+00, 0.71556700E+00, 0.22251100E+00, -.13937200E+01, -.21363600E+00, 0.10557100E+01, -.15145400E+00, 0.15246900E+00, -.15861300E+00, 0.10101800E+00, -.39182100E+00, -.62772900E-01, -.18709000E+00, 0.76638200E+00, 0.29182900E+00, 0.24414900E+01, 0.74612000E+00, 0.30509400E-01, 0.76152600E-01, -.15100800E+00, 0.28671000E+00, -.33036000E+00, 0.64105800E+00, -.33959000E+00, -.12253000E+01, -.22856200E+00, -.84207600E-01, -.81105900E+00, -.96486800E-02, 0.51884300E+00, -.63358700E+00, -.13962000E+01, 0.14139900E+00, -.27840600E+00, -.30814000E+01, -.95783800E+00, -.49551200E+00, -.57750200E-01, -.13841000E+01, -.16894200E-01, 0.16723900E+00, 0.47384500E+00, 0.31025400E-01, -.15011200E+00, 0.18158000E+00, 0.48089700E+00, -.43851800E-01, 0.13328800E+00, -.82052100E+00, 0.30631400E-01, 0.45273100E-01, 0.41331000E-01, -.54396700E+00, 0.18651900E-01, -.11242200E+01, -.40574900E+00, 0.28801700E+02, -.11463400E+02, -.99453800E+02, 0.53760800E+02, 0.23189300E+02, 0.49728100E+02, -.47758800E+02, 0.36012700E+02, -.54706300E+02, -.38100400E+02, 0.11455700E+03, 0.32317700E+02, 0.84226600E+02, -.16156100E+03, 0.77688800E+02, 0.10547800E+02, 0.80763400E+02, 0.34955700E+02, -.15657800E+02, 0.61069300E+02, 0.41206200E+01, 0.26742900E+02, -.43550800E+02, 0.17357800E+03, 0.20628900E+02, -.91693300E+01, -.45299700E+02, -.10279500E+02, 0.13278000E+03, -.48021400E+02, -.84497300E+02, 0.27157100E+01, 0.11858400E+03, -.74475900E+02, 0.10673500E+03, 0.18566300E+03, -.93351300E+02, 0.70938200E+02, -.92784800E+02, 0.10432900E+03, 0.72870500E+02, -.15176300E+03, -.40766600E+02, 0.68802400E+02, 0.60876600E+02, -.15416000E+03, -.39627100E+03, 0.19437700E+03, 0.78324400E+02, 0.19804200E+03, -.56516600E+01, 0.51164400E+02, 0.17021400E+03, 0.13126400E+03, 0.16975600E+03, 0.51418500E+02, 0.29365600E+03, 0.47596400E+02, -.34434900E+01, 0.78134300E+01, -.46650000E+01, 0.26274400E+02, -.93483300E+01, -.11920300E+02, -.68066300E+01, -.82286900E+01, 0.30922200E+02, 0.13961400E+01, 0.11935200E+02, 0.22627900E+02, 0.12200600E+02, 0.17410300E+01, -.62412200E+01, 0.49617800E+01, -.10375200E+02, 0.12831500E+01, 0.19074000E+02, -.15843900E+02, 0.26604200E+02, 0.30340600E+01, 0.82536000E+01, -.24406600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19106200E+01, -.61412300E+00, -.27227100E+01, -.57446600E+00, -.35309200E+01, -.55381600E+00, 0.49839900E+00, -.39392300E+01, -.22930400E+01, -.36517500E-01, 0.55998400E+00, 0.14954800E+01, 0.33991000E+00, 0.75131900E-01, 0.14638600E+01, -.43967000E+01, -.56184200E+00, 0.25950400E+01, 0.33197800E+00, 0.33874000E+01, 0.11513500E+01, -.13160300E+01, -.87568400E-01, 0.25387000E+00, 0.30913100E+00, 0.20898600E+00, 0.12069800E+01, 0.15603300E+00, 0.73285200E+00, 0.24512400E+00, -.62388800E+00, -.28179300E+00, 0.11039700E+01, 0.10289700E+01, 0.39217000E+00, 0.11735700E+01, 0.51692700E-01, 0.27638200E+00, -.40130800E+00, 0.93774400E+00, -.45678100E+00, 0.11982600E+00, -.50258100E+00, -.27661100E+00, -.20024300E+00, 0.54877000E+00, 0.85159700E+00, -.24371700E-02, -.41731500E+00, 0.17097600E+00, -.58559100E+00, -.11295700E+01, 0.85774300E-01, 0.78922300E+00, 0.14361700E+00, -.70280900E+00, -.21345000E+00, 0.78084300E+00, -.12132500E-01, 0.41279900E+00, 0.14041600E+00, 0.53610100E-01, 0.24108300E+00, 0.22320900E+01, -.21441400E+01, -.78460800E-01, 0.63715500E-01, 0.16400600E+01, 0.67849400E+00, -.19464100E+00, -.99206000E-01, -.36902800E-01, 0.14002400E+00, -.28321800E-01, 0.44028000E+00, -.62327400E+00, 0.44126500E-01, 0.68581400E+00, 0.22381000E-01, -.74845200E-01, 0.51168000E-01, -.24504400E+00, -.51035000E-01, -.42700100E+00, -.11102800E+01, 0.71915000E+00, -.16064100E+00, -.38746800E+00, -.40843800E-01, 0.90776500E+00, -.10093300E+01, 0.60047200E-01, 0.39012300E+00, 0.45870900E+00, 0.56329600E+00, 0.52793000E+00, 0.52666600E+00, -.16400100E+01, -.32429700E+00, 0.39398800E+00, 0.28188400E+00, 0.10785200E+00, 0.22949300E-01, 0.20548600E+00, 0.15058700E+00, -.10546100E-01, -.64185900E+00, 0.15069700E+01, -.89509300E-01, 0.78977100E+00, -.26614400E+00, 0.22323400E-01, -.15128000E+00, 0.66880600E-02, 0.20422800E+00, 0.35421100E-01, 0.84794700E+00, 0.80185000E+00, -.15022100E+01, -.31063400E+00, 0.25312000E+00, -.21859500E+01, 0.18235100E+00, -.15368100E+00, 0.46300800E-02, 0.65130300E+00, -.24385300E-01, 0.45322500E+00, 0.16582800E+00, 0.93898900E+00, -.64849100E+00, 0.35292100E+00, 0.28471600E+00, -.43677500E-01, -.25052900E+00, 0.80760200E-01, 0.72238000E+00, -.70136600E-01, -.59186000E+00, -.19636200E+00, -.26488700E+00, -.42433900E+00, 0.17842100E+00, 0.14631000E+00, -.43060200E-02, 0.36910700E+00, 0.14207500E-01, 0.36202700E-02, 0.30905700E+00, -.14701500E+00, -.17706700E+00, -.78952600E+00, -.89456900E-01, 0.21311900E+00, 0.40938700E+00, -.10964700E+00, 0.99263200E+00, -.10068800E-01, 0.40008300E-01, -.35801300E+00, 0.21510900E+00, -.84543000E+00, 0.48726900E+00, -.20315900E+00, 0.30618900E+00, 0.17521000E+00, 0.45562000E+00, 0.81040800E+00, 0.22482800E-02, 0.27443500E+00, 0.42021200E+00, 0.76586400E+00, 0.91841200E-01, -.92166100E-01, -.21876800E-01, 0.20141400E+00, -.87414600E-01, 0.46161500E-01, -.36124700E+00, -.53975900E-01, -.64321900E+00, 0.96932200E-01, -.42376700E+00, 0.11104600E+00, -.23278000E+00, -.66119100E+00, 0.14551500E+01, 0.28049400E+00, -.13460400E+00, -.64116500E+00, -.12739300E-01, -.58592900E-01, 0.27921700E+00, -.45896800E+00, -.96340400E-01, 0.52672700E-01, -.29876700E+00, -.44503300E+00, 0.41081900E+00, -.29579500E+00, -.19937200E+00, -.13115400E+00, -.10906000E+00, 0.49752600E-01, 0.12661800E+01, 0.87471600E+00, -.22749400E+00, 0.23846800E+00, 0.13537700E+03, 0.77614800E+01, -.45969600E+01, 0.61853200E+00, -.37531500E+01, 0.48419500E+01, -.26519900E+02, 0.28666300E+01, -.36461200E+00, 0.23640100E+02, -.24406600E+02, -.58117400E+02, -.37017400E+02, 0.20531500E+02, 0.44917000E+02, 0.18456900E+02, -.28780900E+02, -.13547500E+02, -.16396000E+01, -.15941400E+02, 0.56044700E+00, -.21313300E+02, -.36758100E+02, -.20074200E+03, 0.10116600E+03, 0.89476300E+02, 0.10002400E+03, 0.61729500E+02, 0.11453600E+02, 0.50796400E+02, -.16995200E+02, 0.81183300E+02, 0.18865400E+02, -.12997100E+03, -.78737400E+01, 0.41397400E+01, 0.96873400E+01, 0.42085800E+01, 0.70545500E+01, 0.89808600E+01, 0.13662200E+02, 0.25389900E+02, 0.50587000E+02, 0.16678400E+02, -.20655400E+02, 0.30468300E+02, -.16715500E+02, -.15555100E+02, -.15490900E+02, -.46889300E+02, -.22837100E+02, -.97162400E+01, -.12170800E+02, -.26626700E+02, -.16009600E+02, -.15893900E+02, -.66921800E+01, -.99131300E+00, 0.15401200E+02, 0.12165100E+02, -.17381600E+02, 0.53896000E+01, 0.58029700E+01, 0.12511500E+02, -.15597900E+02, -.38535100E+01, -.75696300E+00, -.11109200E+02, -.49239000E+01, -.10530300E+02, -.14702300E+02, 0.12215400E+02, -.48586800E+00, 0.56247400E+01, -.15150600E+02, -.66153100E+01, 0.60646800E+01, -.49326500E+01, 0.96131600E+01, 0.98937400E+01, 0.50181900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24761500E+01, 0.99957700E+00, -.50095000E+01, 0.53937300E+00, -.33670500E+01, -.22042100E+00, -.21917400E+01, -.27541100E+01, 0.46142600E+01, 0.68521800E+00, 0.33584400E+00, -.33045100E+01, -.20511100E+01, 0.63943900E+00, -.62378400E+01, 0.20363500E+01, 0.15351100E+01, 0.27634600E+00, -.46327000E-01, 0.76422000E+00, -.24206700E+01, -.28840200E-01, 0.19629100E+01, 0.87969500E+00, 0.64174600E+00, -.16672300E+00, 0.85312100E+00, 0.62190200E+00, -.15537800E+00, -.41741300E+00, 0.46079600E+00, 0.50456300E+00, -.10816900E+01, -.68535800E+00, 0.20784300E-01, 0.64887900E+00, 0.11005800E-01, -.62943100E+00, 0.24791400E+00, -.10165000E+01, 0.87447200E+00, 0.44605800E+00, -.43802500E-01, 0.11992100E+00, -.19276600E-01, -.36248900E+00, -.47603300E+00, 0.29233600E-02, 0.12045100E+00, 0.95957800E+00, 0.60626400E+00, -.89264700E+00, 0.30858500E+00, -.24009100E+00, -.51038000E+00, 0.53417000E+00, -.79028900E-01, -.13880000E+01, 0.11373000E+00, -.61455500E+00, -.29095200E+00, -.25189800E+00, -.11099100E+00, -.61814000E+00, 0.21963300E+01, -.31983500E+00, 0.40198300E+00, -.11970200E+01, -.22883700E+01, 0.74162000E-01, -.14649400E+01, 0.13329500E+01, -.23993500E+00, -.76358800E+00, -.21868900E+00, 0.81653400E+00, 0.10789100E+00, 0.20921700E+01, -.32262600E+00, -.19828000E+00, -.23819300E+00, -.47000900E+00, -.27937000E+00, -.23347800E+01, -.31890800E+00, 0.13013500E+01, -.50047700E+00, -.48012800E+00, 0.56194800E+00, -.16752300E+01, -.96272900E+00, 0.34161300E-01, -.26656000E+00, -.70335900E+00, -.12965900E+01, 0.29594700E+00, -.12757300E+00, 0.81048600E+00, -.11462000E+00, 0.17489900E+01, -.18665600E-01, -.50500300E-01, 0.10404600E-01, 0.22004300E+01, 0.18411600E+00, 0.17922900E+00, -.62349000E+00, 0.54853000E+00, 0.59179800E+00, -.75906400E+00, -.54961500E+01, -.55934700E+00, 0.52070600E+00, 0.52316600E-02, 0.48228200E+00, 0.27178100E-01, 0.46268300E+00, -.10662700E+00, 0.83188100E+00, -.11784200E+00, 0.33142000E+00, 0.29362800E+00, -.55222700E+00, 0.96517300E+00, 0.78549400E-02, -.54234000E-01, 0.16497600E+00, -.18998000E-01, 0.21407200E+01, 0.54807600E-02, -.19184000E+00, 0.16718900E+00, 0.11119500E+01, 0.20850900E+00, -.12162900E+01, -.97609500E-04, 0.29718700E+00, 0.58631100E+00, -.93616400E+00, -.14978000E+00, 0.10318200E+01, -.42005300E+00, 0.55860100E-01, -.19886700E+00, -.42688700E+00, 0.59732900E+00, -.10278500E-01, -.92589200E-01, -.35717700E+00, -.45595600E+00, 0.41342300E-01, -.47136200E-01, -.56394800E+00, 0.37439300E+00, -.91008900E+00, -.52203500E-01, 0.88608500E-01, 0.41961300E-01, -.82707100E+00, -.10295200E+01, 0.94846800E-01, 0.10754700E+01, -.58612200E+00, 0.28762100E+00, 0.71829400E+00, -.19600200E+00, 0.15103800E+01, 0.69356300E+00, -.76730300E-01, -.89231000E-01, -.94671500E+00, -.66924600E+00, 0.22960500E+01, 0.49862700E+00, 0.30688200E-01, 0.24278600E-01, -.38335300E-01, 0.28262000E+00, 0.60388200E-01, 0.85922900E-01, 0.11623900E+00, -.96451400E-01, -.26034400E+00, -.33392100E-01, -.91089000E-01, -.48794600E-01, 0.11096800E+01, -.18684300E+01, -.17831500E+00, -.96145300E+00, 0.12771000E-01, 0.24634900E+00, -.90295100E+00, -.11387000E+01, -.54318600E-01, -.17285000E-01, -.18199600E+00, 0.27232100E+00, -.66333400E+00, -.63912800E+00, -.33839600E+00, 0.11730700E+00, -.23463300E+00, -.15949000E+01, 0.87875200E+00, 0.10719600E+01, -.30429300E+00, 0.68319000E+00, -.79875500E+00, -.32253200E+03, 0.16284700E+03, 0.11856800E+03, 0.16124900E+03, 0.43284500E+02, -.31940500E+02, 0.99615600E+02, 0.22594100E+02, 0.17055600E+03, -.75906800E+02, -.17158400E+02, -.13886400E+03, 0.71009600E+02, 0.10668500E+03, 0.69383100E+02, -.98408100E+02, 0.23298900E+02, 0.21698100E+02, -.36360300E+02, 0.42153200E+02, 0.37235500E+02, -.44402400E+02, 0.24608500E+03, -.12304000E+03, -.12200100E+03, -.12283900E+03, -.11483000E+02, -.29232500E+02, 0.73533700E+01, 0.81622700E+02, 0.20531700E+02, -.32438100E+02, -.42405100E+03, -.19096400E+02, 0.86107300E+01, 0.63854700E+02, 0.94305200E+01, 0.11893900E+03, 0.51681500E+02, -.95124000E+02, -.30908700E+02, 0.16189800E+03, 0.58295400E+02, 0.17712300E+03, -.41373800E+03, 0.20293900E+03, 0.70201400E+02, 0.20657300E+03, -.82651000E+02, 0.40108900E+02, 0.13939400E+03, 0.10719800E+02, 0.77228000E+02, 0.86299800E+02, 0.45800500E+02, 0.31682300E+02, 0.65664400E+01, 0.55538300E+02, 0.36430600E+02, -.95171100E+01, 0.74398800E+01, 0.10890700E+02, 0.35586200E+02, -.56003200E+02, 0.28251700E+02, 0.73090300E+01, -.28150300E+02, 0.42895400E+01, -.28103400E+02, -.63059400E+01, 0.35750000E+02, 0.75606400E+01, -.14873700E+02, -.68017700E+01, 0.36724000E+01, 0.13858900E+02, 0.15930400E+02, 0.92161000E+01, 0.38581500E+02, -.21033100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19926900E+01, -.19892100E+01, -.39257400E+01, 0.23928700E+00, -.47056100E+01, -.62776500E+00, 0.34149100E+00, -.32434000E+00, 0.22021600E+01, -.11942500E+00, -.17757000E-01, -.36510100E+01, 0.28321900E+01, -.54390100E+00, -.64147400E+00, -.21274600E+00, 0.19173800E+01, 0.70211900E+00, -.27907200E+00, 0.10111300E+01, 0.44553600E+00, -.68933100E-01, -.59670500E+00, 0.96649700E+00, -.17629000E+00, 0.14551300E+00, 0.62579100E+00, -.10169000E+00, 0.86982100E+00, 0.20889900E+01, 0.15270200E+00, -.24749500E+00, 0.10877500E+01, -.14277000E+00, -.20552500E+01, -.26769000E+00, -.51040500E-01, -.30991200E+01, 0.14287600E+01, 0.88891300E+00, -.21725900E+01, -.84296200E+00, -.64249800E+00, -.61387000E+00, -.68478200E-01, 0.78289600E+00, 0.50662800E+00, -.38832000E-02, 0.12911200E-01, -.34386200E+01, -.29978700E+01, 0.38633000E+00, -.53682400E+00, -.74957000E+00, -.67432700E+00, -.13759700E+01, 0.19437500E+01, 0.28205200E+01, -.36319400E-01, -.10237600E+01, 0.48428500E+00, 0.18388800E+00, 0.94437600E+00, 0.68945100E+00, -.10828500E+01, -.37693300E+00, 0.25653500E+00, 0.16454600E+01, 0.16229600E+01, 0.13909900E+00, 0.19584300E+01, -.39376200E+00, 0.87513500E+00, -.74656600E-03, -.10059400E+00, -.26289900E+00, 0.53023100E-01, 0.24860300E+00, -.45749000E+00, -.65992000E-02, -.15069000E+00, 0.14032800E-01, -.24740100E-01, -.40197100E+00, -.10701600E+01, -.95886200E-01, -.17558000E+00, -.56174000E+00, 0.33643500E+00, 0.15552800E+00, 0.99274000E-01, -.15806700E+00, -.14592200E+01, -.38473000E-01, 0.70427000E+00, -.12427600E+01, -.16441900E+01, -.97159800E+00, -.23981100E+00, 0.54464000E+00, 0.62461200E-01, -.17887100E+00, -.27008800E-02, -.66120800E+00, 0.19520900E+00, -.59069900E+00, 0.20651200E-01, -.21848700E+01, -.76493000E+00, -.16742200E-01, 0.83434200E+00, -.99125400E-01, -.17982300E+00, 0.64168900E-03, -.25216900E-01, 0.18739500E+00, -.37539700E+00, -.56366000E+00, 0.99041900E+00, 0.52514500E-01, -.24869700E+00, 0.18223500E+01, -.27946400E+01, 0.12928200E+01, 0.19713200E-01, -.10310000E+01, -.80543300E+00, 0.51574800E+00, 0.48597200E+00, -.26418300E+00, 0.19581500E+01, 0.12506600E+00, 0.82825100E+00, 0.56629800E+00, -.14913500E+00, 0.14177000E-01, -.73569200E+00, -.59197500E-01, -.11348300E+00, 0.36050000E+00, 0.40870100E+00, 0.60014500E+00, -.22625400E+00, -.13051200E+00, 0.49443500E-01, -.13254800E+00, 0.17476700E-01, -.22271400E+00, 0.68911000E-01, 0.63229900E+00, 0.17486300E+00, 0.90489400E+00, 0.10645900E+01, -.12517700E+00, -.31402700E+00, -.71607700E-01, 0.84803000E-01, 0.20792500E-01, 0.47002800E+00, 0.10808200E+01, 0.21651400E+00, -.50940300E+00, 0.30802200E+00, 0.22378000E+00, -.10919700E+01, 0.19446700E+00, -.26233700E+01, -.68083100E+00, 0.69524700E-01, -.27038100E-01, 0.14098000E+01, -.19479200E+01, -.15778900E+01, -.21719900E+01, 0.65972400E-01, 0.13457200E+01, 0.32268700E+00, -.38931400E+00, -.10573300E+01, -.46909400E-01, -.13344500E+01, -.86688100E+00, -.13731900E+00, -.13194300E-01, 0.53054700E+00, 0.18031500E+01, -.73101000E+00, -.15184200E+01, 0.76764700E-01, -.89310100E+00, 0.58562600E-02, 0.10879200E+00, 0.15669800E+00, 0.75790600E+00, 0.13215500E-01, -.16803900E+00, -.64509300E+00, 0.32333000E+00, 0.16818600E+01, -.42253300E+00, 0.19227700E+00, 0.62202400E-01, -.26610900E+00, -.11523100E+00, -.60935500E+00, -.71687100E+00, 0.28172100E-01, -.25965400E+00, -.10730600E+00, -.83019300E-01, 0.79381500E+01, -.77638800E+01, 0.20735900E-01, -.13065900E+02, 0.22968200E+02, -.49636300E+02, -.17105700E+02, 0.28315100E+02, 0.22904000E+02, -.21737600E+01, 0.87171300E+00, -.14526000E+02, 0.25585000E+02, -.44822100E+00, 0.13334500E+03, 0.43707000E+02, 0.10335300E+02, 0.53222200E+01, -.39736000E+02, 0.54853700E+02, 0.14930900E+03, -.15472400E+03, 0.83313300E+02, 0.72063600E+02, 0.77288300E+02, 0.12788500E+03, 0.54434900E+02, -.19173000E+02, 0.16103800E+00, 0.91675400E+02, 0.38838500E+02, -.27616600E+02, 0.28443400E+02, -.17175700E+02, 0.42825000E+02, -.13854100E+02, -.13646300E+02, -.16908700E+02, -.34908600E+02, -.30490700E+02, 0.63091400E+02, -.15355100E+02, -.20046900E+03, 0.92191800E+01, -.13554500E+02, -.14942800E+02, -.46515500E+01, 0.16923100E+03, 0.13417700E+03, 0.22463600E+02, 0.65735200E+02, -.17090700E+02, 0.14063300E+03, 0.28068000E+02, -.13885400E+02, 0.12984600E+02, 0.34535700E+02, 0.27834800E+02, -.13735300E+02, 0.10816100E+02, 0.78794800E+01, 0.26597100E+02, -.35121300E+02, -.85273100E+01, 0.21790100E+02, -.29144600E+02, -.20713000E+02, -.30233000E+02, -.26092300E+02, 0.26615400E+02, 0.23676900E+02, -.11807700E+02, -.26442700E+02, -.24383100E+02, 0.10337700E+02, 0.27656900E+02, 0.22967200E+02, 0.20833500E+02, -.54782400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.53056900E+00, -.68186200E+00, -.95460600E+00, -.37905900E+00, -.79282900E+00, -.51978800E-01, 0.75492700E+00, -.58118000E+00, 0.72378300E-01, -.49392400E-01, -.89940900E-01, 0.43935800E+00, -.90077900E+00, -.32862200E+00, -.19257800E+00, -.36296400E+00, -.10561300E+00, 0.37308100E+00, -.45508900E+00, 0.42551800E+00, -.51566500E+00, -.44907100E-01, 0.13731900E+00, 0.87661400E+00, 0.75941700E-01, 0.98426700E-01, 0.40943000E+00, -.38854500E-01, 0.41489900E-01, -.32453200E+00, -.42474300E-01, 0.73127600E-01, 0.13492200E+00, -.14277000E+00, -.22936400E+00, 0.27512500E+00, 0.76403400E-02, -.72764400E+00, 0.16400800E+00, -.11687400E+00, -.14138700E+00, -.70460200E-02, 0.36042400E+00, 0.41366300E-01, 0.32699300E-01, -.89110700E-01, 0.10219200E+00, 0.13672500E-02, -.11997500E+00, 0.16041800E+00, 0.52999600E+00, 0.12698700E+00, 0.43541800E-01, 0.23085100E+00, 0.94013800E-01, -.27348500E-01, -.26295300E+00, -.17831700E+01, -.99752400E-02, 0.27792900E+00, -.28503900E-01, 0.17683400E+00, -.14270900E+00, -.27841600E+00, -.42969500E+00, 0.32992100E-01, 0.36527100E-01, 0.27966000E+00, 0.27238500E-01, -.50993000E-01, 0.32098000E+00, -.27009100E+00, -.27076700E-01, -.16195100E+00, -.55324700E-01, 0.48698900E-01, 0.99205000E-02, 0.40659500E+00, -.34404600E-01, -.17978500E+00, -.21029200E-01, -.40278800E+00, -.27742000E+00, -.43188100E+00, -.47961600E+00, -.17360400E+00, 0.35073900E-01, -.69555400E-01, 0.12091000E+00, 0.11998700E+00, 0.48594200E-01, -.13092600E-01, 0.89636500E-01, -.78411800E-01, 0.14979100E+00, -.39981100E-01, -.35865700E+00, -.68519500E-01, -.22678700E+00, -.61173400E+00, 0.37443600E-01, -.12705200E+00, -.56330800E-02, 0.13545700E+00, 0.28610400E+00, 0.13136800E+00, -.14785500E+00, -.24675000E+00, 0.45013000E+00, -.19083500E+00, -.82169500E+00, -.10826400E+00, 0.13021500E-01, -.12001900E-02, 0.59451200E-01, 0.36410200E-01, 0.42897800E+00, -.22124000E+00, 0.57316500E+00, -.20095100E+00, 0.69429800E-01, -.62883400E+00, -.15144100E+01, 0.22162000E+00, 0.77805700E-02, -.35681900E+00, 0.24091400E+00, -.53871500E-01, 0.30731400E+00, -.11662900E+00, -.44166100E+00, -.12253100E+00, -.10218300E+00, -.63759800E-01, -.12561500E+00, -.10044600E-01, -.35612100E+00, 0.11864600E+00, 0.15673100E+00, 0.80406100E-01, -.22436600E+00, -.61753000E-01, -.97632800E-01, 0.76980900E-02, -.77620800E-01, -.76597500E-01, -.13176700E-02, -.65806600E-01, -.18061700E+00, -.13157000E+00, -.54448500E-01, 0.19810900E+00, -.88185500E-01, 0.79523000E-01, -.20438000E+00, -.44408600E-01, 0.25326900E+00, -.27568200E-01, -.36580900E-01, -.35794200E-01, -.61929700E-02, -.51009900E-01, -.10327600E+00, -.14249800E+00, 0.28013000E+00, -.16629400E+00, 0.40187800E+00, 0.21725600E+00, -.11276100E-01, -.26168400E-01, -.46007300E-01, -.27102700E+00, 0.10295600E+00, -.38773700E+00, 0.14592200E-01, 0.37833900E-01, -.72474600E-01, -.50757800E-01, -.10349700E+00, -.81979500E-02, 0.42964700E+00, -.14086400E+00, -.97731700E-01, -.22562100E-01, 0.25933000E-01, -.34411100E+00, -.30121100E+00, -.20375800E+00, 0.28820500E-01, 0.10478300E+00, -.34437200E-02, 0.29933000E-01, 0.12109700E+00, 0.50561100E-01, -.13604100E+00, -.51202200E-02, 0.20186700E+00, 0.28530400E-01, -.77520600E-01, 0.44843400E+00, 0.44044400E-01, 0.14917800E-01, 0.31910700E-01, 0.86326200E-01, -.18888100E+00, -.56995200E+00, -.63826700E-01, 0.87495900E-01, 0.22577200E-01, -.48875200E-02, -.79943000E-01, -.16715900E+02, 0.21151700E-02, 0.79263700E+01, -.51455800E+00, 0.16550300E+01, 0.69506400E+00, -.44000500E+01, 0.53272700E+01, 0.16735900E+02, 0.24733100E+02, -.13244300E+02, -.13057600E+02, -.12362400E+02, 0.16327600E+02, 0.84812700E+01, 0.52803600E-01, -.47750300E+01, -.17860100E+02, 0.11122300E+02, 0.61069000E+01, -.11571500E+03, 0.58333300E+02, 0.60059100E+02, 0.57827000E+02, 0.51022700E+01, -.28366400E+00, 0.18854900E+02, -.26240300E+02, 0.31729500E+02, 0.60833000E+01, 0.61791200E+02, -.45298800E+02, 0.22488100E+02, 0.10422100E+02, 0.22815500E+02, -.65742700E+01, -.52071100E+01, 0.13413300E+02, -.81860400E+01, -.51906500E+01, -.10724100E+01, -.14917400E+00, 0.62330700E+02, -.31580200E+02, -.15330200E+02, -.31130900E+02, 0.25264800E+02, 0.71857000E+01, -.16461900E+02, -.61915700E+01, -.33946700E+02, 0.32170800E+00, -.20259700E+02, -.75138700E+01, 0.18895200E+01, 0.12499900E+01, 0.49623900E+00, -.23683300E+01, 0.20871800E+01, 0.18318100E+01, 0.52240400E+00, -.13254100E+01, -.46090600E+01, 0.33650000E+01, -.17246300E+01, -.50671300E+01, -.20168300E+01, 0.22825700E+00, 0.46784100E+00, 0.33528900E+01, -.71958200E+00, 0.23179600E+00, -.49879100E+01, 0.27024500E+01, 0.96229100E+00, 0.43994400E+00, 0.19692500E+01, 0.39218900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12914400E+01, -.37634700E+00, -.12666800E+01, 0.21006400E+01, -.14168400E+01, -.38235500E+00, -.13638300E+01, -.21528400E+01, 0.26625400E+01, 0.10047900E+01, 0.22960500E+00, -.14946000E+01, 0.10132800E+01, 0.12412000E+01, -.19622100E+01, 0.87118700E+00, 0.12277600E+01, 0.24036400E+00, -.28211900E+00, 0.89436200E+00, 0.24639800E+00, 0.17310500E-02, 0.85064700E-01, -.22124400E+00, 0.98767400E-01, 0.22335700E+00, 0.80839100E+00, 0.40882200E-01, -.25183700E+00, -.98661500E+00, -.59912100E+00, 0.70988700E+00, -.10246100E+00, 0.58544300E+00, 0.77633000E+00, 0.73292500E+00, 0.49823900E-01, -.41836800E-01, 0.78270400E-01, -.74681200E+00, 0.51801500E+00, 0.89747400E-01, -.11815100E-01, -.13851300E+00, 0.24646800E+00, 0.92953000E+00, -.14772100E+00, 0.27401100E-02, -.93948700E+00, 0.83111300E+00, 0.22442600E+00, -.26541500E+00, 0.16398600E+00, 0.59977200E+00, 0.18538800E-01, -.28471200E+00, -.47076900E+00, -.84639100E+00, 0.24305500E-01, 0.59658800E+00, -.65123700E-01, -.15612400E+00, 0.87507700E-01, -.92641000E+00, 0.73753000E+00, 0.13774300E+00, -.12606500E+00, -.19296900E+01, -.92443400E+00, -.31993900E+00, -.14217600E+01, -.19217600E+00, -.70708300E+00, -.25620200E-01, -.14115200E+00, 0.24697100E+00, -.50030100E-01, -.83436800E+00, 0.23676100E+00, -.15098800E+00, 0.27994100E+00, 0.10452700E+00, 0.58676200E+00, 0.20389000E+01, 0.11560700E+01, -.22826000E+00, 0.37700400E+00, 0.34341000E+00, -.28957600E+00, 0.51175100E+00, 0.32001700E+00, 0.81290700E-01, 0.93896200E+00, -.18641500E+00, 0.35742400E+00, -.16048700E-01, 0.11310300E+01, 0.21832800E+00, 0.36019100E+00, -.35728600E+00, -.18082800E+00, -.12758500E+00, 0.92392200E-02, 0.11210900E+01, -.30056600E-01, -.26344500E-01, 0.12170900E+00, 0.56442900E+00, 0.31522400E+00, 0.30627800E+00, -.13019100E+01, -.21141900E+00, -.52812100E-01, 0.86644400E-03, 0.34015000E-01, -.20707800E+00, -.61683700E+00, -.45223200E-01, -.10581500E+01, 0.15104200E-01, 0.19525300E+00, -.14925900E+01, -.20749400E+01, 0.40568300E+00, 0.10092300E-01, 0.80703800E-01, 0.54692100E+00, -.61465000E-01, -.35600200E-01, 0.37234400E-01, -.63372700E+00, 0.84533500E-01, -.82423200E+00, -.25817200E+00, 0.93448400E-01, 0.56255600E-01, 0.86105800E+00, -.11705400E+00, 0.30373200E+00, -.79560700E-01, 0.30729500E+00, -.28217500E+00, 0.17031100E+00, -.93646900E-01, -.12501900E+00, 0.12423600E+00, -.14974500E-02, 0.42918700E-01, -.16722300E+00, 0.39911600E-01, 0.25172500E-01, -.30793800E-01, -.23815700E+00, -.49888100E-01, 0.25548400E+00, 0.52802300E-01, -.46819700E+00, -.67343100E-01, -.10519300E-01, 0.10901900E+00, -.67962500E-01, 0.40650200E+00, -.69830000E-01, 0.23142300E+00, -.21671800E+00, 0.19656600E+00, -.80469900E+00, -.45374400E-01, -.45317400E-01, 0.62777700E-01, 0.24108600E-01, 0.22904300E-01, -.36335300E+00, 0.69712100E-01, 0.33190400E+00, 0.53155000E+00, 0.34879200E-01, 0.11414500E+00, -.47499400E+00, -.39214000E-01, 0.93703300E+00, 0.17865900E+00, 0.76571300E-01, -.68263800E-01, 0.96277100E-02, -.81159900E-01, -.25280700E+00, 0.13072500E-01, -.13069600E-01, -.14882800E+00, -.29799700E-02, -.11472700E+00, 0.20640900E+00, -.20663600E-01, 0.25912900E+00, 0.34091400E-02, -.74910500E-02, -.60607600E-01, 0.32728100E+00, -.89023500E+00, -.39293700E-01, -.95015400E-01, 0.82506200E-02, 0.30900000E+00, 0.34009200E+00, -.49381700E+00, -.12845800E+00, -.29313400E-01, 0.12410700E+00, -.10695700E+00, -.78239000E-01, -.41375000E-01, 0.56895900E+01, -.33795900E+01, 0.15530100E+02, -.12524200E+02, -.95264800E+01, -.25704700E+02, 0.15924500E+02, 0.10012800E+02, 0.21178100E+02, -.10791200E+02, -.23704000E+01, -.10631600E+02, 0.44662200E+02, 0.23911200E+02, 0.21427600E+01, 0.21021200E+02, -.88874600E-01, 0.29191500E+02, 0.13011200E+02, -.22674400E+02, 0.12159800E+02, 0.11052600E+02, 0.11003700E+02, -.18995200E+02, 0.14921100E+02, -.50428700E+01, -.11371900E+02, 0.20349500E+01, 0.16484000E+02, 0.57154900E+02, 0.98597300E+01, -.52405000E+01, -.59894500E+01, -.45953000E+01, -.21564500E+02, -.10053400E+02, -.10804300E+02, -.12796900E+02, 0.46583800E+00, -.86257900E+01, -.54220500E+02, 0.10291900E+02, -.67297800E+01, -.86961900E+01, -.53446300E+01, 0.41432600E+02, 0.28316200E+02, 0.31632500E+01, 0.20916100E+02, 0.27533600E+01, 0.28848500E+02, -.13048300E+01, -.25222200E+01, 0.46708200E+01, 0.11074600E+02, 0.93788000E+01, 0.16893900E+01, 0.19032300E+01, 0.14603500E+01, 0.90757500E+01, -.11145700E+02, -.23884500E+01, 0.64980200E+01, -.91366700E+01, -.29680200E+01, -.94026300E+01, -.14310900E+01, 0.89474800E+01, 0.62347600E+01, -.50848000E+01, -.14388300E+01, -.39449000E+01, 0.30386200E+00, 0.53398300E+01, 0.72243500E+00, 0.19380400E+01, -.11038600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.67608400E+00, 0.16698400E+00, -.11966100E+01, -.52393800E+00, -.33773600E+00, 0.98347900E-01, -.35558000E+00, -.12872800E+00, 0.11488800E+01, -.92973700E-01, 0.30457500E-01, -.47049600E-01, -.11119800E+01, -.44317000E+00, -.10506900E+01, 0.13619300E+00, 0.17173500E-01, 0.13940300E+00, -.68352900E-01, 0.62551600E-01, -.84295100E+00, -.22659500E-01, 0.24616900E+00, -.44824900E+00, -.32793800E-01, 0.11508100E-01, -.26968600E+00, 0.33408000E-01, -.29286200E+00, 0.17009400E+00, 0.18262000E+00, 0.50466500E+00, -.19905100E+00, -.46761000E+00, -.14586100E+00, 0.15640400E-01, -.13157000E-01, -.50975300E+00, 0.22185400E+00, 0.51378300E+00, -.55690400E+00, -.22743700E+00, -.55378500E+00, -.82508800E-01, -.10253000E+00, -.12238400E+00, -.24234500E+00, 0.17413900E-02, 0.12111800E+00, -.42697300E+00, -.17030100E-01, 0.44125200E+00, -.24828200E-01, -.19833500E+00, -.10218400E+00, -.18262800E+00, 0.18252400E-01, 0.10146200E+01, 0.29293600E-01, -.29453100E+00, -.64692300E-01, -.26724400E-01, 0.62410700E-01, 0.74354500E-01, 0.63331900E+00, -.21881800E+00, 0.68925100E-01, 0.53509900E+00, 0.95086000E-01, 0.19260200E+00, -.36594800E+00, 0.90233100E+00, -.73613900E-01, -.91049100E-01, -.10793900E+00, 0.18300100E+00, 0.77061100E-01, 0.22694000E+00, -.78358600E-01, 0.12894400E+00, -.16233500E+00, 0.25397000E+00, -.25461800E+00, -.95780300E+00, -.11176400E+00, 0.49435600E+00, -.27920800E+00, -.28614700E+00, 0.15117500E+00, -.34089500E+00, -.80616800E-01, -.49320500E-01, -.31875800E+00, -.14706500E+00, -.36224400E+00, 0.24545000E+00, 0.29897800E+00, -.26037500E+00, 0.66309500E-01, 0.16790600E+00, -.42553200E-01, -.86156600E-01, 0.84802500E-03, 0.49868800E+00, -.42611300E+00, 0.63686300E-01, -.50972400E-01, 0.18761200E+00, -.64511100E-01, 0.80388600E-01, 0.51465500E+00, 0.90337700E-01, 0.92380100E-01, 0.15243600E-02, -.87207200E-01, -.44454800E-01, 0.10694500E+00, 0.53170200E+00, -.36448200E+00, 0.75936900E-01, 0.13799100E+00, 0.40439400E+00, 0.68528300E+00, 0.48539500E+00, -.28477300E-02, -.17123100E+00, 0.50790400E-01, -.10160400E+00, 0.75570700E+00, -.36135700E+00, -.60950600E+00, 0.14337900E+00, 0.34800800E+00, -.20533800E+00, -.94550200E-01, 0.14834000E-01, -.18103900E+00, 0.27336100E+00, 0.71809000E-01, 0.50675700E-01, -.38834900E+00, -.60269000E-01, -.54476800E-01, 0.12303200E-01, 0.11146400E+00, -.11675100E+00, 0.38488800E-02, -.39971000E-01, 0.33796800E+00, 0.11491400E+00, 0.96192200E-01, 0.17139700E+00, 0.26343100E+00, 0.96621100E-01, -.12315000E+00, -.55287200E-02, 0.16154000E+00, 0.21805500E-01, 0.38036400E-01, -.10018800E+00, 0.46815300E-01, -.67573900E-01, -.13302400E+00, -.18895200E+00, 0.29366700E+00, -.21571300E+00, 0.46789500E+00, 0.52587500E+00, 0.56838700E-02, 0.13745900E+00, 0.34438400E+00, -.20488800E+00, -.29244300E+00, -.49007000E-01, -.81703900E-01, 0.54523700E-01, 0.14925500E-01, -.25759800E-01, -.19978800E+00, -.13469600E-01, 0.21301400E+00, -.12693700E+00, -.38734300E+00, 0.60253600E-01, -.54218600E-01, -.90801200E+00, 0.39871700E+00, -.70820900E+00, 0.11733600E-01, -.41476800E-01, 0.11793500E-02, 0.45350400E-01, 0.15872800E+00, 0.38370100E-01, -.12051100E+00, -.26555600E-01, -.44395900E-01, -.53726600E-01, 0.23882600E+00, 0.97112100E-02, -.78387500E-01, 0.16653500E-01, 0.12116400E+00, -.24464700E+00, 0.31433600E-01, 0.19345700E+00, 0.73222200E-01, 0.21700100E+00, 0.99357900E-02, 0.11899000E+00, -.10268600E+00, -.32543300E-02, -.10769800E-02, -.19365800E+02, 0.13839700E+01, -.20935000E+01, -.48323800E+01, -.84984400E+01, 0.10919300E+02, 0.25075200E+02, 0.46860900E+02, -.25002800E+02, -.29260000E+02, -.23422100E+02, 0.23473200E+02, 0.22555500E+01, -.88897800E+01, -.64580900E+01, -.16522500E+02, -.22013800E+01, -.19196200E+02, -.10605700E+03, 0.53635400E+02, 0.48014300E+02, 0.53013500E+02, 0.21470600E+02, -.22846400E+01, 0.18903800E+02, -.19380000E+02, 0.15702600E+02, 0.29301100E+01, 0.82512000E+02, 0.98339700E+00, -.51882900E+00, -.18983800E+01, -.36257500E+00, -.19079100E+02, -.63318600E+01, 0.86970900E+01, 0.49999100E+01, -.37474700E+02, -.72882000E+01, -.28094000E+02, 0.10291400E+03, -.51584800E+02, -.24576700E+02, -.51404900E+02, 0.19636600E+02, -.14623600E+02, -.24059500E+02, -.14080500E+02, -.21963800E+02, -.18591100E+02, -.80914600E+02, -.89034800E+01, -.70519500E+00, -.49060700E+01, -.55879900E+00, -.98293500E+00, 0.12999800E+01, -.22779500E+00, -.42658400E+00, 0.50289200E+01, -.70225000E+01, 0.18858500E+01, -.12228500E+01, -.10087000E+01, -.11845000E+01, -.15368600E+01, -.45627500E+00, 0.20169500E+01, 0.38865400E+01, -.15213000E+01, -.10781900E+01, 0.49594800E+00, -.25099600E+01, -.98274000E+00, -.77585800E+01, 0.14257600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28196700E+01, -.35928500E+01, -.48985200E+01, 0.37789300E+01, -.68926200E+01, -.14315300E+01, -.96939400E+00, -.30033300E+01, 0.19134400E+01, 0.25633100E+00, -.55302700E-01, -.13731000E+00, 0.34902000E+01, 0.37970500E+00, -.21616900E-01, -.27125000E+01, -.64740200E+00, 0.58904600E+00, 0.42551200E+00, -.40791700E+00, -.26727900E+01, -.17298600E+00, 0.37896500E+00, -.81480900E+00, 0.13756500E+00, 0.11923800E+00, -.29785300E+01, -.27963300E+00, -.28382500E-01, 0.15912600E+01, -.31943200E+00, 0.99256900E-02, 0.11327800E+01, -.19116200E+01, -.22772600E+01, 0.68038600E-01, -.76628200E-01, -.35312500E+01, 0.76096200E+00, 0.80787700E+00, -.20679000E+01, -.70092500E+00, 0.30012400E+00, -.47285500E+00, -.12407000E+00, 0.84767600E+00, -.98865400E-01, -.91987700E-02, 0.10735200E+00, -.33155200E+01, -.25567900E+01, 0.11435800E+01, -.40587100E+00, -.36093000E+00, -.43599000E+00, -.92897200E+00, 0.15558700E+01, 0.37985400E+01, 0.48429100E-02, -.12140500E+01, 0.48646300E+00, 0.41964900E+00, 0.66534400E+00, -.24099500E+00, 0.55699600E+00, -.38190300E+00, 0.33413700E+00, -.39863400E+00, 0.57268300E+00, 0.15987700E+00, 0.30891500E+01, -.52361200E+00, 0.16106900E+01, 0.69011400E+00, 0.93924600E-01, -.13267900E+00, -.99139800E-01, 0.19364500E+00, -.12619700E+00, 0.20697000E-01, -.12120200E+00, -.68790000E+00, 0.82927800E+00, -.15999900E+01, -.11464300E+01, 0.26752000E+00, -.14023400E+00, -.87010900E+00, 0.69584000E+00, 0.25166100E-01, -.84882100E+00, -.24866200E+00, -.75174100E+00, -.31462900E+00, 0.23277800E+01, -.25378600E+01, -.47896300E+01, -.30588700E+01, -.70516600E+00, 0.12117200E+01, 0.90095900E+00, -.68322700E-01, 0.87483600E-02, -.94111500E+00, 0.27750900E+00, -.68761400E+00, -.35462100E+00, -.10960700E+00, 0.20145000E+00, -.57231600E+00, 0.23794900E+01, -.43983600E-01, -.42070700E+00, 0.28341300E-02, 0.44858400E+00, 0.43845000E+00, -.43623100E+00, 0.17767600E+00, 0.16188000E+01, 0.65919100E+00, -.40675200E-01, -.25601000E+01, -.78977700E-01, -.49721100E+00, 0.19994900E-01, -.52147700E-01, -.46583200E+00, 0.85967700E-01, 0.28757800E+00, 0.81402300E+00, 0.30468900E+00, 0.45922100E-02, 0.43480700E+00, 0.77402200E+00, 0.12137700E+01, 0.52123400E-01, -.82134600E+00, -.78581300E+00, -.46800700E+00, -.44685200E+00, -.87061600E+00, 0.46334600E+00, -.21892200E-01, -.89961800E+00, -.36144600E+00, 0.88162600E+00, 0.32055600E-02, 0.35967300E-01, -.54111900E+00, -.16888300E+00, 0.12913900E+00, 0.97017900E-01, -.18767600E+00, 0.22641900E+00, 0.73630000E-01, -.18824400E+00, 0.10618900E+01, 0.11233500E-01, -.41544700E-01, -.23035100E+00, 0.36991500E+00, 0.63384900E+00, -.12376400E+01, -.52750300E-01, 0.18216300E+00, -.37758300E+00, -.23142900E+01, 0.71489400E+00, 0.64836100E-01, 0.18242600E+00, 0.16654700E+01, -.72072800E+00, -.22239400E+01, -.18531600E+00, -.16672500E-01, -.58143500E-02, -.17937900E-01, -.26061700E+00, 0.28389900E+00, -.19144900E-01, -.29544000E+01, -.35921400E+00, -.67167200E+00, 0.40567000E+00, -.52357100E-01, 0.23999900E+01, -.18223400E-01, -.44221000E-02, 0.16483000E+00, 0.17824000E+00, 0.16022500E-01, 0.84569100E-01, -.91837000E+00, 0.11683700E+01, -.15832600E+00, -.13265800E+00, -.72772400E+00, -.90453900E+00, 0.58240000E-01, 0.12161900E+01, -.30188100E+00, -.11297600E+00, 0.38247500E+00, 0.15602900E+01, 0.29766900E+01, 0.18331500E+01, 0.39004700E+00, -.10599500E+01, 0.65523600E-01, 0.92068500E+00, 0.13252000E+00, 0.22690700E+00, -.60836600E-02, -.71125100E+00, 0.64035600E+02, -.57934700E+02, -.40439000E+02, 0.13805000E+02, 0.92406300E+02, 0.19261500E+03, 0.40291700E+02, -.24623200E+02, -.16639400E+01, -.20087500E+02, 0.15313300E+02, -.62840600E+02, -.21982500E+02, -.54913000E+02, -.43028100E+02, -.70853700E+02, 0.38515600E+02, -.72327200E+03, 0.36160500E+03, 0.30483000E+03, 0.36162100E+03, -.57088400E+02, -.65328700E+02, 0.85833400E+02, -.12058800E+03, 0.20082600E+03, -.65688600E+02, 0.89620500E+03, 0.28590200E+02, -.12553100E+02, -.53430300E+02, -.14417300E+02, -.13672800E+03, -.72810600E+02, 0.13821600E+03, 0.66992300E+02, -.16515400E+03, -.85447600E+02, -.13028800E+03, 0.29421200E+03, -.14427200E+03, -.41603200E+02, -.14677900E+03, 0.20645700E+01, -.11431700E+02, -.13024300E+03, -.59357800E+02, -.63695000E+02, -.56919600E+02, 0.93744900E+02, -.13327000E+02, -.13826300E+02, -.78712100E+02, -.57305200E+02, -.21400200E+02, -.19914300E+02, -.22096000E+02, -.56812500E+02, 0.79593500E+02, -.14827100E+02, -.13409300E+02, 0.52221900E+02, -.24247400E+01, 0.53228400E+02, -.10437600E+02, -.56736200E+02, -.12420000E+02, 0.14868700E+02, -.10293400E+02, -.18469500E+01, -.25320800E+02, -.67748500E+00, 0.16619000E+02, -.51781800E+02, 0.17673700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25483300E+01, 0.19074900E+01, 0.15628900E+01, -.24504500E+01, 0.26728800E+01, 0.63511600E+00, 0.12817400E+01, 0.12313700E+01, -.40394300E+01, -.79573700E+00, -.10474400E+00, 0.81561000E+00, -.14799400E+01, -.16178800E+01, 0.86891700E+00, 0.66783200E+00, -.73314900E+00, -.75232400E+00, -.63123800E+00, -.80871300E+00, 0.11872000E+01, -.37945300E-01, -.38747700E+00, -.18585900E+01, 0.12408800E+00, -.18273600E+00, 0.54686000E+00, 0.34611800E+00, -.45434100E+00, -.12324400E+01, -.30461700E+00, 0.74735300E+00, -.56894500E+00, 0.17376400E+00, 0.19779500E+01, 0.11199100E+01, 0.58368900E-01, 0.18912100E+01, -.69929300E+00, 0.65781000E+00, 0.41874400E+00, 0.32180800E+00, -.84461500E+00, 0.14433300E+00, -.50176900E+00, -.25217600E+00, -.13914900E+00, 0.56903900E-02, -.33859000E+00, 0.98835700E+00, 0.68007800E+00, -.19964300E+01, 0.22686600E+00, -.41020700E+00, -.64017200E-01, -.33005300E+00, -.76341700E+00, 0.28854500E+01, 0.76319700E-01, -.49696400E+00, -.25185300E+00, -.62539900E+00, -.16833800E+00, 0.22652100E+01, -.34891000E+00, -.19744600E+00, -.21281000E+00, 0.29003600E-01, -.35048300E+00, 0.14060100E+00, -.63922200E-01, 0.18428800E+01, 0.18376400E+00, -.20248600E-01, -.10874500E+00, 0.65704600E+00, 0.11978800E+00, 0.47700400E+00, 0.10282600E+00, 0.61235900E+00, -.76660400E-01, 0.93884200E+00, -.66426400E+00, -.19646300E+01, 0.22016100E+01, 0.58571800E+00, -.63694700E+00, -.28742500E+00, 0.15190600E+00, -.10883500E+01, -.75878400E+00, 0.15887300E+00, 0.76868700E-02, 0.49400900E+00, -.19045100E+01, 0.27088400E+01, 0.30590700E+01, -.62270300E+00, 0.58500700E+00, -.31430900E+01, -.80997300E-01, 0.96374500E+00, -.20851200E-01, -.25666500E+01, -.23812500E+00, 0.94301000E+00, 0.12000600E+00, 0.28702700E+00, 0.21330400E+01, 0.16963600E+00, -.20789500E+01, 0.54710800E+00, 0.10766800E+01, -.84786700E-02, -.49811700E+00, -.50653400E+00, -.19205000E+01, -.20781400E+01, 0.37392200E+00, -.14761800E-01, -.26337300E+00, 0.40146100E+01, 0.70125400E+01, -.26355400E+01, -.25584700E-01, 0.16418400E+01, 0.53702300E-01, -.16612100E+01, -.48616800E+00, -.72226800E+00, 0.20716800E-01, -.10559300E-01, -.96889400E+00, -.63795000E+00, -.13148200E+00, 0.43894300E-01, 0.51300900E+00, -.22428000E+00, 0.85910800E+00, -.48757200E-01, -.78083800E+00, 0.44575900E-01, -.61035400E-02, 0.72216300E-02, 0.18902400E+00, -.58235200E+00, 0.15610500E-01, 0.17296100E+00, 0.30776600E+00, 0.10450700E+01, 0.40155500E+00, 0.13389200E+01, 0.94467600E-01, -.12881300E+00, 0.12794100E+00, -.41447400E-01, 0.22612800E+00, -.17334400E+00, 0.32871200E+00, -.22605400E+00, -.15813700E+00, 0.79105500E+00, 0.92131100E+00, 0.31204600E+00, -.22610000E+00, 0.17417500E+00, -.15844900E+01, 0.36075300E+00, 0.36639800E-01, -.70481700E-01, 0.58003600E+00, 0.44930100E+00, -.29941800E+00, 0.72217600E+00, 0.33243700E+00, -.52201600E+00, -.10077000E-01, 0.82362300E+00, -.14361400E+01, -.12814900E-01, 0.90800300E-01, 0.36748000E+00, -.14904900E+00, -.26892600E-01, -.46816700E+00, -.12559800E+01, 0.18815800E+00, 0.14114300E+01, -.39325000E+00, -.43611200E+00, -.81176900E-02, -.30670100E+00, 0.21423800E+00, -.86606800E+00, 0.27146100E+00, 0.13014500E+00, 0.10771500E+01, -.89475800E+00, -.67862400E-01, -.97878700E+00, -.14144000E+00, -.32368400E-01, 0.15220300E-01, 0.15494100E+01, 0.21504400E+01, -.41347300E+00, -.21140700E+00, 0.66962700E+00, 0.19023600E+00, 0.25640200E+00, 0.66828100E+00, -.27197500E+01, -.11060500E-01, -.17517300E+01, -.11456900E-02, 0.75533700E+02, -.32093700E+01, -.14711600E+03, 0.62586300E+02, 0.15592200E+03, 0.25747000E+03, -.11143200E+03, -.18428800E+03, -.12862500E+03, -.24753000E+02, -.11992900E+02, -.54353400E+02, -.15338600E+02, -.58935100E+02, -.41032600E+02, -.28000000E+03, -.53584200E+03, 0.26688100E+03, 0.27274500E+03, 0.26786900E+03, -.11120400E+03, -.55573200E+02, 0.19207200E+03, -.12973700E+03, -.52796000E+01, 0.12482100E+02, 0.52805500E+03, -.28502800E+03, 0.14557400E+03, -.18760600E+02, 0.14289300E+03, -.12728700E+03, -.15083300E+02, 0.18366200E+03, 0.18789800E+02, -.30509800E+03, 0.15617900E+02, 0.20323500E+03, 0.69939200E+03, -.34439700E+03, -.16433700E+03, -.34905700E+03, -.66284300E+02, -.24300700E+03, -.21651800E+03, -.15859200E+03, -.21489100E+03, -.31315000E+03, -.34389600E+03, -.51592000E+02, -.18295000E+02, -.79898300E+02, -.52518700E+02, 0.35661300E+00, -.77196900E+01, -.86750400E+01, -.49688500E+02, 0.80688700E+02, -.38389700E+02, -.20675400E+02, 0.40910400E+02, 0.70363100E+01, 0.41612900E+02, 0.37165400E+02, -.50208500E+02, -.25078600E+02, 0.28446900E+02, 0.37934900E+02, 0.13294900E+02, -.15087800E+02, -.51550100E+02, -.34856300E+02, -.56288400E+02, 0.41466300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14499800E+01, -.16480000E+00, -.18587100E+01, -.28482500E+00, -.17810700E+01, -.74499900E-01, 0.39120300E+00, -.79857700E+00, 0.11006000E+01, -.27882900E+00, 0.22799800E+00, -.33799500E+01, 0.55472000E-01, 0.24737500E-01, -.22417100E+01, 0.80673200E+00, 0.20885700E+01, 0.12915500E+01, -.12600500E+00, 0.27315100E+01, -.81349700E+00, -.13079900E+00, 0.98472800E-01, 0.99393300E+00, -.11690500E+00, 0.51299800E-01, 0.74451200E+00, -.15630700E+00, -.81043200E-01, -.15849600E+00, 0.83959600E+00, -.43294200E+00, -.50414600E+00, 0.23848800E+00, -.11311100E+01, -.29712200E-01, -.15934000E-01, -.34110800E+00, 0.37524000E+00, -.48004800E+00, -.39502900E+00, -.51317500E+00, 0.35730000E+00, -.66319700E-01, -.14045800E+00, -.18765000E+00, 0.79615400E-02, -.29027100E-04, -.59753500E-01, -.34634700E+00, 0.21133800E+00, 0.31828300E+00, -.20965100E-01, 0.11617000E-01, 0.20129100E+00, -.37788700E+00, -.63412100E+00, 0.41430600E+00, -.21873100E-01, -.26006200E+00, -.76298600E-02, -.32554200E+00, 0.14207400E+00, 0.10109500E+01, -.75994500E+00, 0.89826900E-02, -.38643200E-01, 0.75339300E+00, 0.55822300E+00, 0.31579700E-01, 0.16055200E+01, -.53815300E+00, 0.32625100E+00, -.55773800E+00, -.50061400E+00, 0.64632000E+00, 0.11718500E+00, 0.27341100E+00, -.10889800E+00, -.23821100E+00, -.16537100E+00, -.80316600E+00, -.51743000E+00, -.12140300E+01, -.14556000E+01, -.12755000E+00, -.10618100E+00, -.23896900E+00, 0.36178500E+00, 0.25471700E+00, 0.36095900E+00, -.10410400E+00, -.16964200E+00, -.44796700E+00, 0.32539600E+00, -.69775400E+00, -.71858400E+00, -.24829600E+00, -.15202000E+00, 0.18989300E+00, 0.78736400E-01, 0.93353100E-01, -.94436900E-02, 0.85781000E+00, 0.68476300E+00, 0.23394000E+00, 0.92128000E-01, -.11559800E+00, 0.22456700E+00, 0.13807300E+00, 0.48276800E+00, 0.12667600E+00, 0.30045200E+00, 0.14390600E-02, -.41146900E-01, 0.15361300E+00, 0.46112800E+00, -.85469600E+00, 0.42754200E+00, -.25160100E+00, -.53699500E-01, 0.10355600E+01, -.66269800E+00, -.17010400E-01, 0.19417200E-01, -.42530200E+00, -.17790000E+00, -.61582200E-01, 0.19591200E+00, -.47295200E+00, 0.75390500E+00, -.33007500E+00, -.43169900E+00, 0.26605200E+00, 0.40890400E+00, -.16631500E-01, -.11563400E+01, -.33935400E+00, 0.23682600E+00, 0.33582800E+00, 0.43740000E+00, 0.55754700E-03, 0.64846600E-01, 0.20081100E+00, -.49985800E+00, -.31583400E+00, -.45917900E-03, -.85671500E-02, 0.35658200E+00, -.12093900E+00, -.20842600E+00, 0.14846800E+00, 0.24125900E+00, -.77082400E-01, -.17568200E+00, -.48039000E-01, -.50692400E+00, 0.82111600E-01, 0.38984900E-02, 0.77382600E+00, 0.70700500E-01, 0.19541900E+00, -.70610800E+00, -.53807100E-01, -.17039400E-02, -.23440900E+00, 0.52005300E+00, 0.46546300E+00, -.23177100E-01, 0.17230600E+00, 0.15254100E+00, -.88168200E+00, 0.77957800E+00, -.17350300E+01, 0.58419200E-01, 0.98219500E+00, -.59073800E-02, -.55985500E-01, -.67656500E+00, -.93508400E-02, 0.88276800E+00, -.74563600E+00, 0.33342800E+00, 0.59108800E-01, 0.21757000E+00, 0.96102600E+00, -.39062100E+00, -.35455900E+00, 0.59715400E-01, 0.70603200E+00, 0.10536900E-01, 0.13594200E-01, -.15349000E+00, 0.11795800E+01, -.22653700E+00, -.15461800E+00, 0.69885800E-01, 0.46064800E+00, -.22793600E+00, 0.92884700E+00, 0.93532400E-01, -.15495300E-01, 0.25920300E-01, -.39037500E+00, -.55339700E+00, 0.10529200E+01, 0.20735700E+00, -.33210900E+00, -.26223100E+00, 0.16123500E+00, 0.26012100E+00, 0.63029700E+00, 0.25836500E-02, 0.95492700E-02, -.25823000E+00, 0.82395200E-01, 0.34068100E+02, 0.51373600E+02, -.95260800E+01, 0.26799100E+02, -.33428300E+02, 0.16381500E+02, 0.11586800E+02, 0.16706100E+02, -.61813000E+02, -.46914900E+02, -.12255800E+01, -.27752400E+02, 0.85235600E+01, -.46111600E+02, 0.42586600E+02, 0.80705200E+01, -.59968200E+01, -.60807800E+01, -.40281200E+01, -.29326300E+02, -.15514000E+02, -.24783700E+02, -.16945600E+02, 0.32160300E+01, -.25024300E+02, 0.93355900E+02, 0.43594300E+02, -.20791700E+02, -.12441900E+02, -.22155700E+02, 0.18503300E+02, 0.52444500E+01, 0.25504200E+02, 0.31806700E+02, -.79536900E+00, -.56584200E+01, 0.40303400E+01, -.45386000E+02, 0.25579800E+02, 0.22564800E+02, 0.22630000E+02, -.63888100E+02, -.16256500E+02, -.10895900E+02, -.35640900E+02, 0.13074400E+02, -.16603300E+02, 0.84689200E+02, 0.11309300E+02, -.81529200E+01, -.34065800E+02, -.28091700E+02, 0.21960100E+01, -.14836600E+02, -.14104500E+02, -.27793700E+02, 0.34297200E+02, 0.69005200E+01, -.13003100E+02, 0.27436200E+02, 0.64756000E+01, 0.28106800E+02, 0.16419000E+01, -.27430400E+02, -.11939100E+02, 0.88021400E+01, 0.14876100E+01, 0.76649000E+01, -.83149600E+01, -.52486600E+01, -.16128900E+00, -.90947700E+01, -.23210500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25967400E+01, 0.76068000E+00, 0.25606600E+01, -.22496800E+01, 0.37117200E+01, 0.64593200E+00, 0.10304900E+01, 0.72466200E+00, -.56998800E+01, -.16637100E+01, -.38569700E+00, 0.63988300E+01, -.47212100E+01, -.32766800E+01, 0.21601200E+01, -.48357700E+01, -.39000500E+01, 0.77917600E+00, 0.59068100E+00, -.14685900E+01, -.12625300E+01, -.21212100E+00, 0.15527600E+00, 0.16350900E+00, 0.56255600E-01, 0.17047900E+00, -.12642900E+01, -.43943900E-01, 0.51897600E+00, 0.20347700E+01, 0.10877100E+01, -.14687100E+01, 0.60386800E+00, -.18054100E+01, -.13672400E+01, -.98961600E+00, -.33579200E-01, 0.25533300E+00, -.43831300E+00, 0.16724900E+01, -.48048500E+00, 0.33137500E+00, 0.36879500E-01, 0.39099700E+00, -.53478700E+00, -.20376500E+01, 0.26625200E+00, 0.38597800E-02, 0.16624300E+01, -.11440400E+01, -.77509300E-01, 0.11041600E+01, -.24654200E+00, -.73779500E+00, 0.77850600E-01, 0.63431400E+00, 0.10274600E+01, 0.50622400E+00, 0.38205700E-01, -.10585800E+01, 0.14385200E+00, 0.64056300E+00, -.36990000E+00, 0.15490600E+01, -.18203300E+01, -.30314300E+00, 0.38352600E+00, 0.35282300E+01, 0.18807900E+01, 0.26437100E+00, 0.21646900E+01, 0.10381000E+00, 0.12074700E+01, -.38727600E-01, 0.23297200E+00, -.58960600E+00, 0.97840900E-01, 0.10983800E+01, -.46970900E+00, 0.25372000E+00, -.26342700E+00, 0.46262800E-01, -.63517000E+00, -.27983900E+01, -.13260600E+01, 0.46531100E-01, -.54266200E+00, -.47813900E+00, 0.32991900E+00, -.55061600E+00, -.10126600E+01, -.67812900E-01, -.16121700E+01, 0.55251500E+00, -.39238400E+00, 0.27502300E+00, -.16435000E+01, -.59741800E+00, -.59180000E+00, 0.49449100E+00, 0.41961100E+00, 0.54012600E+00, -.37868500E-02, -.21630600E+01, -.80522200E-01, 0.14803400E+00, -.29614900E+00, -.27480100E-01, -.17065400E+00, -.43914600E+00, 0.19459000E+01, 0.32309200E+00, 0.18410200E+00, 0.60748100E-02, -.52076000E-02, 0.33629400E+00, 0.17235600E+01, 0.31675100E+00, 0.15484400E+00, -.54362900E+00, 0.14206400E+00, 0.20981100E+01, 0.39852400E+01, -.52732800E+00, -.68712000E-02, 0.21410600E+00, -.59851300E+00, 0.94715900E-01, 0.16242500E-01, -.76611500E-02, 0.36277300E+00, 0.21711900E-01, 0.12374200E+01, 0.18498900E+00, -.34624200E+00, -.16887300E-01, -.15933200E+01, 0.80012600E-02, -.45973200E+00, 0.11477400E+00, -.14091400E+01, 0.21298300E+00, -.35883800E+00, 0.15499700E+00, 0.39635700E+00, -.83438300E-01, 0.15160600E-01, -.20692200E+00, 0.16618300E-01, -.38854800E+00, -.18140600E+00, -.26320700E+00, 0.27158800E+00, 0.18253100E+00, -.49284700E+00, -.16244400E+00, 0.14910900E+01, -.18653900E-01, -.82010600E-01, -.21318300E+00, 0.25778900E+00, -.71825800E+00, 0.24526100E+00, -.49668800E+00, 0.43274100E+00, -.35751100E+00, 0.93662800E+00, -.37629100E+00, -.56846400E-01, -.25281200E+00, -.18121800E-01, -.58708300E+00, 0.31362300E+00, -.60907400E+00, -.61326500E+00, -.10380100E+01, -.15331300E+00, -.28030100E+00, 0.20213400E+01, 0.37722900E-03, -.28894200E+01, -.12128300E+00, -.35030700E+00, 0.94229200E-01, 0.67140800E-01, 0.73020800E+00, 0.42513200E+00, -.11346100E+00, 0.64900900E-01, 0.57656800E+00, -.78802300E-02, 0.30059300E+00, -.84728200E+00, 0.55719300E+00, -.59248800E+00, -.24192100E-01, -.27494200E+00, -.39771600E+00, -.80094200E+00, 0.28389000E+01, 0.21884700E+00, -.64763400E-01, 0.66698900E-01, -.90682100E-01, -.40570000E+00, 0.39957600E+00, 0.13896300E+00, -.17989300E+00, -.22216700E+00, 0.16873200E+00, 0.53179200E+00, 0.39898200E+00, 0.42176000E+00, -.63057100E+00, -.62685300E+00, 0.12286400E+00, -.13010800E-01, 0.85676500E+02, 0.14585900E+02, 0.10663400E+03, -.31435000E+02, 0.15328400E+02, 0.11376100E+01, 0.15729300E+02, -.14052300E+03, -.11388300E+03, -.30486600E+02, -.10434400E+03, -.23925700E+02, -.13604900E+03, -.32173600E+02, -.36277900E+03, 0.17768800E+03, 0.13977500E+03, 0.18144000E+03, -.24762100E+02, -.11556300E+03, 0.61866700E+02, -.39451500E+02, 0.12397400E+03, -.12289100E+03, 0.51524700E+03, 0.85071000E+01, -.17305100E+01, -.21181000E+02, -.49771200E+01, -.14717200E+02, -.14163900E+02, 0.10799500E+03, 0.80200900E+02, -.10503200E+03, -.30532300E+02, 0.98402000E+02, 0.96038500E+02, -.40168300E+02, 0.15623100E+02, -.47992900E+02, -.14161800E+03, -.94466500E+02, -.80723900E+02, -.97391800E+02, -.23221900E+02, -.12360200E+03, 0.57651600E+02, 0.83027500E+01, -.23711300E+02, -.83903200E+02, -.65340300E+02, -.13093700E+02, -.21331600E+02, -.21692000E+02, -.64308400E+02, 0.84877500E+02, 0.30637800E+01, -.30354300E+02, 0.63168400E+02, 0.13176100E+02, 0.64790400E+02, -.53359200E+00, -.63804000E+02, -.28703600E+02, 0.24758700E+02, -.20822600E+00, 0.16321800E+02, -.20484700E+02, -.16064500E+02, 0.85263300E+01, -.41262500E+02, 0.10987800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40589900E+01, -.32801600E-01, 0.35429100E+01, 0.12768800E+01, 0.27435000E+01, -.93012300E-01, 0.22759100E+00, -.92079900E+00, -.46929200E+01, 0.25669700E+00, -.24835800E+00, 0.83707900E+01, -.55195400E+00, 0.10138200E+01, 0.57022700E+01, -.53965200E+01, -.49167400E+01, 0.52034100E-02, 0.42951300E+00, -.14215700E+01, -.93554300E+00, -.98854400E-01, 0.43659100E+00, 0.12637500E+01, 0.37610400E+00, 0.52707600E-01, -.10578400E+01, -.36750200E+00, -.17680600E+00, -.15767700E+01, -.12234000E+01, 0.10400700E-01, 0.69287400E+00, -.10237500E+01, 0.47747000E+00, -.39724000E+00, -.22373100E-01, -.44846200E+00, -.79990400E+00, 0.10331000E+00, 0.12915900E+01, 0.11036500E+01, 0.12792700E+01, 0.29084200E+00, 0.20201100E-01, -.24306200E-02, 0.55771200E+00, -.11949600E-01, -.31055900E+00, 0.20420900E+01, 0.92111900E+00, 0.42323900E+00, 0.25592200E+00, 0.15500200E+01, 0.57808100E+00, 0.98685800E+00, -.22122600E-01, -.29011900E+01, -.69949700E-01, 0.98656500E+00, 0.14683800E+00, 0.27892300E+00, -.35470100E+00, -.15546900E+01, 0.17844800E+01, 0.46509200E+00, 0.76279700E-01, -.30564300E+01, -.21605300E+01, -.23604000E+00, -.18581500E+01, -.13666200E+01, 0.54441400E+00, 0.12739000E+01, 0.11232000E+01, -.13856200E+01, -.32714200E+00, -.10382800E+01, 0.61529400E+00, 0.42590700E+00, 0.50505000E+00, 0.90126800E+00, 0.12427300E+01, 0.35145100E+01, 0.38906700E+01, -.13085100E+01, 0.88904600E+00, 0.86010000E+00, -.96077300E+00, 0.13719600E+00, -.73786200E+00, 0.16359600E+00, 0.10650900E+01, 0.92038100E+00, -.29856300E+00, 0.12645700E+01, 0.13584300E+00, 0.81667200E+00, -.12185800E+00, -.97730100E+00, -.23495300E-01, 0.15118700E+00, -.15946300E-02, -.30108100E+01, -.60551400E+00, -.26547100E+00, 0.15205100E+00, -.17454500E-01, -.14157900E-01, -.77594600E+00, -.76902300E+00, -.84680100E-01, 0.13921800E+00, -.66902600E-03, -.81748600E-01, -.51423800E-01, -.14046000E+01, -.96799600E-01, -.10102800E+01, -.25492000E+00, 0.58367200E+00, -.58615200E+00, -.17418800E+00, 0.65072600E+00, -.17667100E-01, 0.33413800E+00, 0.54139000E+00, 0.33923300E+00, -.11136900E+00, 0.41502600E+00, -.11478900E+01, 0.70722800E-01, 0.69916900E-01, -.26822900E+00, -.16676500E+01, -.23966400E-01, 0.16961900E+01, 0.78650000E+00, -.50701500E+00, -.30812600E+00, -.19389600E+00, -.56537600E+00, -.75654300E-01, -.29008300E-01, 0.55494000E-01, 0.62055900E+00, -.11421000E-01, -.21950900E+00, -.91736500E+00, -.31381100E+00, -.58413000E-01, -.63048000E+00, -.97639900E+00, 0.19473100E+00, 0.48236500E+00, 0.80105600E-02, 0.85181500E+00, -.59543200E-01, -.20987000E+00, -.69522300E+00, -.57295000E-01, -.96910600E-01, 0.13474300E+01, 0.25675400E+00, 0.57165600E+00, 0.10915900E+00, -.10179600E+01, -.17183100E+01, 0.49244200E-01, -.50076600E+00, -.14016800E+01, 0.24453900E+01, -.10575100E+00, 0.26134200E+01, 0.29423400E+00, -.11426700E+01, -.22114600E+00, -.25570700E+00, 0.29515000E+01, 0.86133100E-01, -.17942400E+01, 0.18856800E+01, -.95244200E-01, -.25527300E+00, -.15855100E+00, 0.22809800E+00, -.86431700E+00, 0.13033600E+00, -.30263400E-01, 0.23629500E+00, -.18976600E-01, 0.16686600E+00, -.13080700E+01, -.13635000E-01, -.20766900E-01, 0.14022600E+00, 0.62276100E+00, -.52584300E+00, -.17000500E+01, 0.19322400E+01, 0.33457000E+00, -.67080300E-01, 0.16333500E+00, 0.15073300E+01, 0.70918500E+00, -.29525100E+01, -.46130700E+00, -.46113700E+00, -.90525600E-02, 0.15945200E+00, 0.14061200E+00, 0.35554300E+01, 0.99789900E-02, 0.13489100E+01, 0.20025000E+00, 0.56318200E+00, 0.49020200E+00, 0.12163300E+01, -.84882900E+02, -.30203300E+03, -.25588000E+03, 0.12479200E+03, 0.22614600E+03, 0.12781400E+03, 0.70156700E+02, 0.13334100E+03, 0.37536200E+02, 0.12052900E+03, 0.11858600E+03, 0.16524100E+03, 0.20972800E+03, 0.13201400E+04, -.65323900E+03, -.60517200E+03, -.66012600E+03, -.26059100E+02, 0.10699800E+03, -.28731600E+03, 0.24882900E+03, -.22742400E+03, 0.51527300E+02, -.10920800E+04, 0.11644300E+03, -.64537600E+02, 0.69665900E+02, -.58317300E+02, 0.17727900E+03, 0.70376600E+02, -.28999500E+03, -.13939200E+03, 0.46421200E+03, 0.83974100E+02, -.41181700E+02, -.10381800E+04, 0.49866000E+03, 0.21268800E+03, 0.51839100E+03, 0.10968700E+03, 0.29355600E+03, 0.33775700E+03, 0.25789300E+03, 0.26852700E+03, 0.37891900E+03, 0.32294100E+03, 0.72886600E+02, 0.39578300E+02, 0.16849400E+03, 0.11498600E+03, 0.29108900E+02, 0.29670800E+02, 0.34360900E+02, 0.11099000E+03, -.17012300E+03, 0.57335900E+02, 0.40279300E+02, -.97552400E+02, -.93383800E+00, -.99375600E+02, -.22227300E+02, 0.11075800E+03, 0.41049900E+02, -.63751600E+02, -.22250800E+02, -.78395400E+01, 0.35374600E+02, 0.66784400E+02, 0.18680000E+02, 0.11730300E+03, -.49017500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20313200E+01, 0.15680600E+00, -.10418500E+01, -.10873400E+01, -.26556600E+00, -.74683700E-01, 0.33179700E+00, -.26664300E+01, -.40602900E+01, -.28682500E+00, 0.99524800E+00, 0.45439000E+01, 0.44317600E+00, -.14920500E+00, 0.31276000E+01, -.17813800E+01, -.23418500E+01, -.25164800E+00, -.80934500E-01, -.11689300E+01, 0.13957700E+00, -.85550900E+00, -.55110200E+00, -.48076300E+01, 0.22907600E+00, -.32454200E+00, -.83491400E+00, 0.35062000E+00, 0.38479600E+00, -.92349800E+00, -.68421700E+00, 0.11607700E+01, -.54855700E+00, 0.82555900E+00, 0.13605300E+01, 0.66047300E+00, -.47407500E-01, -.52510500E+00, 0.62946400E+00, 0.46155000E+00, -.11283600E+01, -.14342900E+00, -.18879500E+01, -.13077200E+01, -.61395800E+00, 0.96456000E+00, 0.60592800E+00, -.11450700E-01, -.10521800E+01, 0.64336200E+00, -.11360100E+01, -.48800200E+01, 0.25207900E+00, 0.16740000E+00, 0.86068300E+00, -.15846000E+01, -.78531400E+00, 0.28915000E+01, -.20379700E-01, 0.98128500E+00, 0.16671500E+00, -.42275100E+00, -.72703000E-01, 0.19745600E+01, -.20374700E+01, -.70114800E+00, -.16864700E+00, 0.56692800E+00, -.19045100E-01, 0.39883900E-01, -.83840600E+00, -.18434900E+00, 0.45565100E+00, 0.43065800E+00, 0.31086700E+00, -.35068200E+00, -.52347300E-01, 0.20031500E+00, 0.92493400E-01, 0.23432400E+00, 0.77531200E-01, 0.49805900E+00, -.14678800E+00, -.25967100E+00, 0.98955900E+00, -.86204400E-01, 0.31278900E-01, 0.30969000E+00, -.58549700E-01, -.35268600E+00, -.88387100E-01, 0.37562400E-01, 0.37131300E+00, -.82663300E-01, -.29691700E+00, 0.58651100E+00, 0.70952400E+00, -.13302600E+00, 0.22116000E-01, -.10400700E+01, 0.12828500E+00, 0.51157300E+00, -.11112500E-01, -.19512000E+01, -.39959900E+00, 0.17879400E+00, 0.24673700E+00, -.81498200E-01, -.22071800E+00, -.86628900E+00, -.11698200E+01, 0.23721200E+00, 0.92252000E+00, 0.61345100E-03, -.28567600E+00, 0.78914100E-01, -.13810700E+01, -.48001200E-01, 0.27357900E+00, 0.10171200E+00, 0.49554500E+00, 0.25838200E+01, 0.27601600E+01, 0.48121100E+00, -.35899300E-01, 0.79979400E+00, -.26466700E+00, 0.57151900E+00, -.14426800E+01, 0.41629900E-01, 0.71726700E+00, 0.59506800E+00, 0.76816000E+00, 0.87991800E-01, 0.93748700E-01, 0.24232500E-01, 0.29158400E+01, -.35185400E+00, -.79228200E+00, -.60731000E+00, 0.10933100E+01, -.16758600E+00, -.43146800E-01, -.45227700E-01, -.69340700E+00, -.31489000E+00, 0.50039000E-01, -.29994000E+00, 0.13446400E+01, 0.13325300E+01, 0.43751700E+00, 0.86280700E+00, 0.79531500E+00, -.37112500E+00, 0.13273100E+00, -.32625200E-01, -.36233300E+00, 0.31821500E-01, 0.45782200E+00, 0.42248400E+00, -.12215400E+00, 0.80480700E+00, 0.13580900E+01, 0.24313500E+00, -.15830000E+00, 0.25617200E-01, -.40341200E+00, -.28269100E+00, 0.41570800E-02, -.13963600E+00, -.54929800E-02, 0.14002400E+01, 0.57978400E+00, 0.26295000E+01, 0.26248700E-01, -.67556400E+00, 0.14838800E-01, 0.56059800E+00, -.17053800E+01, 0.44323300E-01, -.10739800E+01, -.27402700E+00, 0.45502200E+00, -.15553900E+00, -.36224400E+00, 0.63699500E-01, 0.17272100E+00, 0.12002200E+01, -.30817800E+00, -.14852400E+01, 0.79630800E-02, 0.42887000E-02, 0.20126000E+00, -.13868400E+01, 0.33568200E+00, -.44864200E-01, -.24031500E+01, -.58582300E+00, 0.11099100E+01, -.23905800E+01, -.30275800E+00, -.86711300E-01, 0.67914900E-01, 0.22374000E-01, 0.10366800E+01, 0.96926100E+00, -.12540300E+00, 0.72840900E+00, 0.26925600E+00, -.65814400E+00, -.35147000E+00, -.23112700E+01, 0.10523600E-01, -.18099800E+00, -.56377600E-01, -.39624100E+00, -.61168600E+00, -.76559400E+00, -.36503700E+00, 0.26363100E+03, 0.17967100E+02, -.98397200E+01, 0.24779900E+02, -.89835200E+01, -.62103000E+02, -.21007900E+02, -.22506900E+02, -.35212800E+02, -.28152200E+02, -.24193700E+02, -.20618600E+03, -.34172000E+03, 0.17230600E+03, 0.15870600E+03, 0.17060100E+03, -.87504300E+02, -.27613400E+02, 0.10760100E+03, -.15168000E+02, 0.96311400E+02, -.13030400E+02, 0.28342600E+03, -.17836300E+03, 0.88817000E+02, 0.48883700E+02, 0.89442100E+02, -.40730200E+02, 0.25476200E+02, 0.47679000E+02, -.19650200E+02, -.46039400E+02, 0.50486400E+02, 0.24860200E+03, 0.16109800E+03, -.84519600E+02, -.62004100E+02, -.80514300E+02, -.26589100E+02, -.34060100E+02, -.79337900E+02, -.83631500E+02, -.10653600E+03, -.45573700E+02, -.25638700E+03, -.15359500E+02, -.58178900E+01, -.23424800E+02, -.13138700E+02, -.19648000E+02, -.51393200E+01, -.54751100E+01, -.11742200E+02, 0.23787400E+02, -.97303700E+01, -.12173500E+02, 0.90528500E+01, -.41904900E+01, 0.94478900E+01, -.87286400E+01, -.12108500E+02, -.13148400E+02, 0.15844800E+02, -.83445300E+01, -.20069100E+01, -.77862800E+01, -.19578500E+02, 0.14207200E+02, -.14376400E+01, 0.11571100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22215800E+01, -.11958300E+01, 0.48434200E+01, -.64115500E+00, 0.19131500E+01, 0.83595600E-01, 0.25993000E+01, 0.29052000E+01, -.67623600E+01, -.15064000E+01, -.22645200E+00, 0.21209000E+01, 0.10206200E+01, -.87197200E+00, 0.33028300E+01, -.44508500E+00, -.81239300E+00, -.12635700E+01, 0.83155600E+00, -.16584200E+01, -.18090400E+01, 0.42397500E+00, -.18282200E+01, 0.97832100E+00, -.73237400E-01, 0.15956300E+00, 0.17140600E+01, -.62465500E+00, 0.84276500E+00, 0.42419500E-01, 0.59371500E-01, -.30684000E+00, -.20644000E+00, 0.14070600E+01, 0.48511100E-01, -.14765100E+01, -.28307900E-01, 0.14989700E+01, 0.12862800E+00, -.29420800E+01, 0.42776900E+01, 0.73360900E+00, 0.12872300E+01, 0.51006900E+00, 0.68528800E+00, -.59260300E+00, -.39119000E-01, 0.55825900E-03, 0.13742200E+01, -.28669200E+00, 0.20736400E+01, -.37570400E+01, 0.75494100E-01, -.14755000E+01, 0.10678100E+00, 0.13208500E+01, 0.12845900E+01, -.14626600E+01, 0.11695600E+00, -.25338800E+00, 0.15385500E+00, 0.13138600E+01, -.30299400E+00, -.17823200E+01, -.20258300E+01, -.42416200E+00, 0.64426500E+00, 0.46897000E+01, 0.22665100E+01, -.20490600E+00, -.43368200E+01, -.10711300E+01, -.11747300E+01, 0.36847600E+00, 0.37526200E+00, -.11714400E+01, -.10822200E+00, -.69701200E+00, -.78250700E+00, -.11004500E+01, 0.84423400E-01, 0.39232800E+00, -.51730900E+00, -.84776900E+00, -.13853500E+01, -.88146100E-01, 0.42203200E+00, -.11899100E+00, 0.88343100E-01, -.55069000E+00, -.65532000E+00, -.16620500E+00, 0.12368500E+01, -.28877900E+00, 0.96111100E+00, -.39793000E+00, -.30699000E+01, -.50778900E+00, -.10127700E+01, -.41909200E+00, 0.20318900E-02, -.18761300E+00, 0.30158200E-02, -.17626700E+01, 0.13312800E+01, 0.21528600E+00, 0.10456900E+00, -.60937000E+00, -.35956500E+00, -.38334500E+00, 0.45433700E+01, 0.10570600E+01, 0.18643000E+00, 0.59380500E-02, 0.33563200E+00, 0.92783800E+00, 0.22689200E+01, 0.79351500E+00, -.19616300E+01, -.96514600E+00, 0.19283900E+00, -.27133000E+01, 0.47079900E+01, -.18270500E+01, -.15095200E-01, 0.93668400E+00, -.21731500E+00, 0.27862400E+00, -.59953600E+00, 0.95186000E+00, -.12448000E+01, -.23464300E+00, -.12582800E+00, 0.29204900E+00, 0.65097000E-01, -.13576000E-01, -.83697300E+00, 0.13161700E+00, -.47777400E+00, -.10320300E+00, -.75209500E+00, -.37282700E-01, 0.29860300E+00, 0.62604600E+00, -.25058000E+00, 0.16780900E-01, 0.14503400E-01, 0.55922400E+00, 0.21241400E+01, -.20182500E+00, -.19095800E+00, -.11375300E+01, 0.61604800E-01, -.21330200E+00, 0.30224200E-01, 0.56865800E-01, -.17007500E+00, 0.60845700E-01, 0.27804300E+00, -.56888200E+00, -.14334300E+00, -.13592900E+01, -.17630100E+00, -.64012200E+00, 0.59453600E+00, -.91852500E+00, 0.40472800E+00, 0.15292100E+01, 0.21137700E+00, 0.25750400E+00, 0.75910900E+00, 0.21829800E+01, -.12834200E+01, 0.16077500E+01, 0.28686600E+00, -.43509400E-01, 0.10492000E+00, -.63827700E-02, -.18465200E+01, 0.26004800E-02, -.17173500E+00, -.31393900E+00, 0.47849300E+00, 0.28046400E+00, -.10481600E+00, 0.20177000E+00, -.25697500E-01, -.17587200E+01, -.19964400E-01, 0.12420400E+01, 0.12990900E-04, -.90012900E-01, 0.74954200E+00, 0.13469900E+00, -.32228200E+00, -.29564800E+00, -.72355700E+00, 0.14682500E+01, -.36097900E+00, -.43938700E+00, -.89085000E-01, 0.34242000E-01, 0.12487000E+00, -.71140200E+00, -.57254800E+00, 0.14768100E+01, 0.32230000E+00, 0.91040200E-01, 0.72811900E-01, 0.18047700E+00, -.30158000E+00, -.87098200E+00, -.12123900E-01, 0.18647800E+01, -.70018900E-01, 0.30096900E+00, 0.31236100E+00, 0.21113800E+00, 0.25762400E+00, -.65329600E-01, 0.17163800E+03, -.91908200E+02, 0.91658800E+01, -.85774300E+02, 0.10055400E+02, 0.27946900E+02, 0.14177900E+02, 0.11122300E+03, -.27895400E+02, 0.34530600E+02, -.17334500E+03, -.36101700E+02, 0.18935600E+02, 0.66291900E+02, 0.18191100E+02, -.11417700E+03, 0.55525200E+02, 0.41300200E+01, -.95592200E+02, -.83730400E+02, 0.80630900E+02, -.66300700E+02, -.15056500E+03, 0.74818900E+02, -.12953500E+02, 0.75057300E+02, -.68430300E+02, -.59650800E+01, 0.62030000E+02, -.57421700E+02, -.92221900E+02, -.33449000E+01, 0.14884100E+03, 0.32316300E+03, -.16239200E+03, -.76699200E+02, -.16134500E+03, 0.23752900E+02, -.27629200E+02, -.82804800E+02, 0.23411200E+02, -.10269200E+03, -.25818500E+02, -.19570600E+03, -.40962100E+02, 0.13487200E+01, -.21715800E+02, -.81659800E+01, -.44341700E+01, 0.23746600E+01, 0.25098400E+01, -.69847500E+01, 0.21916700E+02, -.26639500E+02, -.32631100E+01, 0.37176100E+01, -.24659100E+02, 0.31830700E+01, 0.13048300E+02, -.73420900E+01, -.38622200E+01, 0.20144700E+02, 0.13027800E+02, -.22632800E+02, -.28241900E+01, -.47387500E+02, -.13776300E+02, -.47428700E+01, 0.30588900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44978600E+01, 0.59372100E+01, 0.10200700E+02, -.42039800E+01, 0.12766600E+02, 0.23655300E+01, 0.63396400E+00, 0.37442300E+01, -.47620100E+01, -.43068500E+00, 0.11091500E-01, 0.12456600E+01, 0.39484900E+00, 0.45518100E+00, 0.12831300E+01, 0.44202500E+01, 0.11853800E+00, -.32251000E+01, 0.20480700E+00, -.37570900E+01, 0.47384500E+01, 0.40174100E+00, -.19075200E+01, -.29730800E+01, -.10280700E+00, -.36922900E+00, 0.60212000E+00, 0.59591200E+00, -.36098000E+00, -.12547800E+01, -.61067700E-01, 0.33358700E+00, -.19811600E+01, 0.60425200E+00, 0.44123600E+01, 0.10225800E+01, 0.12230400E+00, 0.65769300E+01, -.10368100E+01, -.29444200E+01, 0.26693100E+01, 0.70239500E+00, 0.98982100E+00, 0.73967300E+00, 0.43703800E-03, -.13554900E+01, -.68733400E+00, 0.20213800E-01, -.61095700E+00, 0.33314200E+01, 0.14269600E+01, -.60230100E+01, 0.32079000E+00, -.12363700E+01, -.23012000E+00, 0.87844500E+00, -.18574600E+01, -.15889500E+01, 0.27657500E-01, 0.96192200E-01, -.10619400E+01, -.12828000E+01, -.52323100E+00, 0.11490800E+01, -.31135100E+01, 0.25829200E+00, -.10804100E+01, -.37020900E+01, -.68129300E+00, -.15905800E+00, -.23235700E+00, -.39749000E+00, -.14705700E+01, -.13256100E+01, -.13830100E+01, 0.28698800E+01, 0.17102100E+00, -.22969200E-02, 0.33602400E+00, -.21568700E+00, 0.31527500E-01, -.69460400E+00, -.10180900E+01, -.14591200E+01, 0.11930300E+01, 0.39432400E+00, -.98807700E+00, 0.87720900E+00, 0.72268600E+00, -.73955600E+00, 0.25119600E+01, 0.51295700E+00, 0.21414900E+01, -.28617100E+00, -.16139700E+01, -.45734500E+00, 0.38765900E+01, 0.30645200E+01, 0.13360100E+01, 0.81316700E+00, -.29192500E+00, 0.77377000E+00, 0.50597200E-02, 0.51883400E+01, -.18619000E+01, 0.55139500E+00, -.12262800E+01, 0.57003400E+01, 0.26906300E+01, 0.91179100E-01, -.77764600E+01, -.83424000E+00, 0.11875400E+00, -.14032400E-01, 0.68010000E-01, -.11153200E+01, -.64400500E-01, -.86709000E+00, 0.25559300E+01, 0.14503800E+01, -.10946200E+01, -.18124900E+01, -.28324200E+01, -.17927300E+01, 0.36469100E-02, 0.22333200E+00, 0.14208400E+01, -.16695900E+01, -.21791500E+01, -.11159500E+01, 0.37612500E-02, -.39432800E+00, -.24320400E+01, -.13712900E+01, 0.16181900E+01, -.42762200E-01, 0.14147000E+01, -.52881000E+00, 0.12877300E+01, 0.12110300E+00, 0.14276900E+01, 0.93734100E-01, 0.22038800E+00, 0.38033800E+00, -.61805500E+00, 0.35756100E+00, -.12993900E-01, -.34343900E+00, -.21797100E+00, 0.11563600E+00, 0.64184100E-01, 0.15375400E+00, -.30791100E+00, -.61016200E+00, -.32930100E+00, -.95550300E-01, 0.50091900E-01, 0.15436600E+00, -.32879200E+00, -.18488100E+01, -.43438400E+00, 0.72243400E+00, -.68543100E+00, -.10374000E+01, 0.11654200E+01, -.50061400E+00, 0.32200400E+01, 0.69546200E+00, -.46253900E-01, -.32185400E+00, -.13866000E+01, 0.19239000E+01, 0.14276800E+01, 0.34463600E+01, 0.15751900E-01, -.45631900E+00, -.19056200E+00, -.73020900E+00, -.11283700E+01, 0.66967700E-01, 0.34295100E+01, -.46523100E-01, 0.26359300E-01, -.22465900E+00, -.11440400E+01, -.37729600E+01, -.42459700E+00, 0.13968200E+01, -.30188300E+00, -.27062100E+01, -.10025800E-01, 0.18439300E+00, -.28261400E+00, -.92415900E+00, 0.46703700E+00, 0.27031500E+00, -.14892200E+01, -.57793000E-01, -.15033600E-01, -.31616800E+01, -.41256300E+00, -.22156900E+00, 0.24360300E+00, 0.66118800E+00, 0.72666700E+00, 0.15249800E+01, 0.11484800E+00, 0.41136100E+00, 0.64070500E+00, -.49501800E+00, -.12616000E+00, -.63260000E+01, 0.72287100E-02, -.18508300E+01, 0.14419400E+00, 0.26712700E+00, -.60690300E+00, -.34803100E+00, -.37975900E+00, -.20721300E+00, -.52105000E+00, -.28045400E+02, 0.38384600E+02, -.47075600E-01, 0.11248100E+03, 0.43915700E+02, 0.77474300E+02, 0.13825700E+03, 0.28237000E+01, 0.38720300E+02, -.40861400E+01, 0.27269000E+02, -.11125300E+02, 0.13924500E+02, -.13806800E+02, -.53822100E+01, 0.16912000E+02, -.34228500E+02, -.37412900E+02, 0.47948800E+02, 0.15866600E+02, -.17481900E+03, -.42038100E+01, 0.25237200E+00, 0.38908300E+02, 0.20603500E+01, -.22535500E+02, 0.22996400E+02, -.11001600E+03, -.96507400E+02, 0.84917200E+02, 0.34029400E+02, 0.89117500E+02, -.11381200E+03, 0.46661800E+02, 0.10387600E+02, 0.56655600E+02, 0.66731100E+02, 0.14877900E+03, 0.69440100E+02, 0.11014000E+03, -.95815100E+01, 0.16797100E+03, 0.21885600E+03, 0.80022000E+01, 0.18271900E+02, 0.23017400E+02, 0.17267400E+02, 0.21912100E+02, 0.11730300E+02, 0.97422200E+01, 0.16282200E+02, -.23813800E+02, 0.67544800E+01, 0.11162800E+02, -.11948000E+02, -.11190300E+02, -.13467700E+02, 0.24485000E+02, 0.16075900E+02, 0.12561200E+02, -.11905600E+02, 0.24806900E+02, -.13879100E+02, 0.77986000E+01, 0.28627000E+01, -.79198200E+01, 0.34939600E+02, -.59304100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33275300E+01, -.54318600E+00, -.23990000E+01, -.24263500E+01, -.51863800E+01, -.57043600E+00, 0.24034100E+01, -.94309400E+00, -.57149900E+00, -.17095700E+00, 0.50057700E-01, -.19829000E+01, 0.16645000E+01, 0.13201600E+01, 0.31216200E+00, -.14384000E+01, 0.14474000E+01, 0.22617100E+01, 0.12344500E+01, 0.44537400E+01, -.99326500E+00, -.28736200E+00, -.99767700E+00, 0.49325800E+01, -.42646800E+00, 0.45850100E+00, 0.21312500E+01, -.77702500E+00, 0.93221700E+00, 0.27275900E+01, 0.12634700E+01, -.10034300E+01, 0.15855900E+01, -.20997200E+01, -.14173900E+01, 0.21681900E+01, 0.10820600E+00, 0.33280800E+00, 0.59713400E+00, 0.32190900E+01, -.48705000E+00, -.30125100E+00, -.25436300E+01, 0.12340800E+00, 0.78698700E+00, -.32640800E+00, -.12084300E+01, 0.40581200E-01, 0.15257900E+01, -.91867800E+00, 0.17065100E+00, 0.84229900E+01, -.53969000E+00, -.70674700E+00, -.48158300E+00, 0.66973400E+00, 0.69591800E+00, -.43992600E+01, 0.10467700E+00, -.20893200E+01, -.12701300E+00, 0.63102200E+00, -.59801200E+00, 0.29500700E+00, -.91199400E+00, -.42996300E+00, 0.66555900E+00, 0.10630800E+00, 0.12606000E+01, 0.11645400E+00, 0.30568200E+01, -.20683600E+01, 0.24796200E+01, 0.95543200E+00, 0.54419800E+00, -.95898800E+00, -.18255900E+00, -.50493700E+00, -.72844300E-01, 0.47468700E+00, 0.10702700E+00, 0.12800500E+01, 0.64558300E+00, 0.12494400E+01, 0.18610300E+01, -.11848600E+01, 0.53286100E+00, -.79963300E-01, -.39415800E+00, -.60714000E+00, -.24554800E+00, -.15582200E+00, -.16706600E+01, 0.44527300E+00, 0.28440400E+00, -.55377300E+00, -.28278000E+01, -.55621400E-01, -.54139600E+00, -.33390600E+00, -.10772900E+00, -.55090400E-01, -.16027600E-01, -.44360100E+01, 0.12580900E+00, -.10271300E+01, 0.29449800E+00, -.44551700E+01, -.11422000E+01, -.10919900E+01, 0.63885300E-01, -.75015100E-01, 0.24391700E+00, -.10162600E-02, -.25411800E+00, 0.16940200E+00, -.25321900E+01, -.11321800E+01, 0.20502700E+00, -.35382000E-01, 0.16889800E+00, 0.37653400E+01, 0.21754200E+01, 0.40752500E+00, 0.37807700E+00, 0.61969800E+00, -.11472600E+01, -.19044600E-01, 0.25846000E+01, -.42185100E+00, 0.33027900E+01, -.22521100E+00, 0.17354400E+01, 0.13434400E+01, -.10027800E+01, -.23493800E+00, -.17544700E+01, 0.17073000E+01, -.58998300E-01, 0.90995200E+00, 0.16984000E+01, 0.10862800E+01, -.10858600E+01, -.35519900E+00, -.22679700E+00, 0.17662400E+00, -.13437900E-01, -.78692900E+00, -.11685200E+01, -.43742700E-01, 0.36465700E+00, 0.12328100E+01, 0.44749400E+00, 0.11374100E+00, -.56872000E+00, -.26857700E-01, -.38078200E+00, 0.51898900E-01, 0.19398000E+00, 0.29512300E+01, 0.27024100E+00, 0.63168000E+00, 0.81312200E+00, 0.93931800E+00, -.14401600E+01, 0.57870200E+00, 0.41778400E+00, -.25289500E+01, -.17501900E+00, -.30414300E+00, -.13828100E+01, -.31066800E+01, 0.16012200E+01, -.21051500E+01, -.21921700E+00, 0.19035300E+00, 0.42818500E-01, -.48566200E+00, 0.27253800E+01, 0.31966600E-01, -.23182600E+01, -.11946900E-01, 0.39785800E+00, -.16692900E+00, 0.22451000E+00, 0.10391300E+01, 0.20914700E+01, -.24505200E+01, 0.53276000E+00, 0.36364600E+00, -.14220300E-01, 0.58667900E+00, -.86354800E+00, 0.10680500E+01, -.15577600E+00, 0.11393400E+00, 0.30548000E+01, 0.13115200E+01, -.25574100E+01, 0.24155000E+01, 0.14672100E+01, -.11430700E-01, 0.27725900E-01, 0.16790000E+00, -.32910000E+01, -.31349300E+01, -.70776600E-01, -.32684100E+00, -.45740800E+00, 0.94740900E+00, 0.43673000E+00, 0.92943700E+00, 0.15399200E-01, 0.40731800E+01, 0.57937200E+00, 0.41808900E+00, 0.94277000E+00, 0.31800200E-01, 0.72977200E+00, 0.94375500E-01, -.97753700E-01, -.32605300E-01, -.10036200E+03, -.59068300E-01, -.35226000E+02, -.41906000E+02, 0.61285600E+02, 0.98250400E+02, 0.78124500E+02, -.42110000E+02, 0.14612900E+03, 0.77585300E+03, -.39898200E+03, -.35629700E+03, -.38788600E+03, -.69902000E+01, -.68910800E+01, -.17190100E+03, 0.93354500E+02, -.27980800E+03, -.42831100E+02, -.21215500E+03, 0.21873800E+03, -.10620900E+03, -.11521000E+03, -.11069400E+03, 0.26686500E+02, -.56271800E+02, 0.84129600E+01, 0.49365400E+02, -.15448000E+03, -.11859500E+03, -.51115300E+02, -.76914100E+02, 0.60014600E+02, 0.74614500E+02, 0.38055800E+02, -.77166200E+02, -.72079600E+02, 0.14393000E+02, 0.70149900E+02, 0.15910200E+03, -.72512100E+02, 0.38126700E+03, 0.18649800E+02, -.11041900E+02, -.62198300E+02, -.53574500E+02, 0.41229000E+02, -.35208200E+00, 0.23693900E+00, -.53316300E+02, 0.62895700E+02, 0.11334700E+02, -.13102900E+02, 0.55717400E+02, 0.17867600E+02, 0.55003900E+02, 0.39964000E+02, -.52435700E+02, -.14317300E+02, 0.38048400E+01, 0.40399200E+02, 0.19424100E+02, -.15073300E+02, -.22488100E+02, -.29775800E+02, -.51249600E+02, 0.20746500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12130000E+01, -.11749100E+01, -.21641700E+01, -.13369000E+01, -.20426100E+01, -.14255200E+00, 0.12525000E+01, -.42290000E+00, -.20240700E+00, -.19094900E+00, -.20937500E+00, 0.10499600E+00, -.11817600E+01, -.62863800E+00, -.12007700E+00, -.86857300E+00, 0.42796600E-01, 0.90885300E+00, -.28760600E+00, 0.14619100E+01, -.75463700E+00, -.48079200E-01, 0.19485800E+00, 0.24078800E+01, 0.81737000E-01, 0.56190100E-01, 0.75360000E+00, -.10014800E+00, 0.22865800E+00, 0.62105800E+00, -.84759100E-02, 0.33470700E-01, 0.64218500E+00, -.45582300E+00, -.67018600E+00, 0.11500200E+01, 0.20220500E-01, -.80880600E+00, -.26570500E-01, 0.31732900E+00, -.23297300E+00, -.13695600E+00, 0.20917700E+00, -.30031000E-01, 0.34149200E+00, -.76662800E-01, 0.48995500E-01, 0.32452000E-02, 0.71589100E-01, 0.48691100E-01, 0.10592400E+01, 0.15911400E+01, 0.69638400E-02, 0.29824800E+00, 0.17635300E+00, -.21091300E+00, -.33737900E+00, -.12377000E+01, -.17524500E-01, -.23564800E+00, 0.54159100E-01, 0.12431800E+00, 0.11162300E+00, 0.15061800E+01, -.11292700E+01, -.11223500E+00, 0.19546400E+00, 0.12603200E+01, 0.70102000E+00, 0.49458800E-01, 0.15989200E+01, -.24944500E+00, 0.79423200E+00, 0.16641700E-01, 0.26444500E+00, -.59503000E+00, 0.37300600E-01, 0.84188600E+00, -.82084600E-01, 0.12942500E+00, -.81165500E-01, -.43522300E-01, 0.65933800E-02, -.61562000E+00, -.55651300E+00, 0.30255200E-01, -.11267000E+00, -.27753600E+00, 0.11942300E-01, 0.31832400E-01, -.35161800E+00, -.40177400E-01, -.31196200E+00, 0.40507100E+00, 0.39143100E+00, -.15127300E+00, -.99162200E+00, -.61940800E+00, -.47144600E+00, -.45629500E+00, 0.11449400E+00, 0.56834500E-01, -.54871200E-02, -.17213400E+01, 0.37542300E+00, -.12377900E+00, -.85360200E-01, -.11497800E+01, -.63461100E-01, -.19082300E+00, 0.93789900E+00, 0.10024100E+00, -.70715800E-01, 0.32051900E-03, 0.70889600E-01, 0.20957000E+00, 0.11368200E+00, 0.23957700E+00, -.14617300E+00, -.13513900E+00, 0.25539000E+00, -.10178200E+01, -.30933100E+00, 0.26503300E+00, -.18031500E-02, -.47180500E+00, -.38841200E+00, 0.82855900E-01, 0.18186600E+00, 0.47019600E-01, 0.17930200E+00, 0.49744500E-01, 0.58310200E+00, -.46369800E+00, -.58125400E+00, -.35543900E-01, -.58277000E+00, 0.36715900E+00, -.18232600E+00, 0.95627300E-01, -.87081000E+00, -.93256900E-01, -.19600700E+00, 0.89580000E-01, 0.11419300E+00, -.15629600E+00, 0.17765600E-02, -.13048300E+00, 0.19196800E+00, -.60913500E-01, 0.11375100E-01, 0.14736100E+00, 0.14971500E+00, 0.17012900E+00, -.41164800E-01, -.95476600E-01, 0.75770900E+00, 0.13160300E-01, -.50745100E-01, -.56075400E-01, 0.16958400E+00, -.27188300E+00, 0.27703200E+00, -.16021800E+00, -.21386500E-02, 0.30963600E-01, -.19863500E+00, -.21170000E+00, 0.55606700E-02, -.54931500E-01, 0.23033600E+00, -.56921600E+00, -.19179700E+00, -.79843200E+00, -.14682600E+00, -.10212100E+00, -.84166400E-01, -.74390600E-01, 0.74985400E+00, -.78499400E-02, -.11005200E+01, -.87918300E-01, -.27978900E+00, 0.41422100E-01, 0.46860400E-01, 0.73538700E-01, 0.69631900E+00, -.27399700E+00, 0.52010300E-01, 0.81214900E-01, -.84948400E-02, 0.62806500E-01, 0.15684200E+00, -.18022100E+00, -.14563400E+00, -.36189000E-02, 0.78583600E+00, 0.66702800E-01, -.40144000E+00, 0.40880100E+00, 0.46259500E-01, 0.35469900E-02, -.14763100E-01, 0.16532300E+00, 0.32746600E+00, -.37826800E+00, -.90047600E-01, 0.71502700E-01, -.18192300E-01, 0.82880700E-01, 0.25187500E-01, 0.19065500E+00, -.10299800E-02, 0.36800000E-02, -.51804100E-01, 0.48076100E-02, -.14226800E+00, 0.17638700E+00, 0.56623800E-02, 0.46931900E-01, -.22476000E+00, 0.50595900E-01, 0.37315700E-01, 0.55915000E+01, -.10138500E+02, 0.10171100E+01, 0.85373300E+01, 0.19554500E+02, 0.93439900E+01, 0.37169200E+01, -.19666800E+02, -.26765900E+02, 0.13835100E+02, 0.91452200E+01, 0.13451000E+02, -.17213900E+02, 0.12972600E+00, 0.26658400E+00, -.18647800E+02, 0.20153200E+01, 0.29548300E+00, 0.39477500E+01, 0.29126200E+01, -.16094700E+01, -.16303500E+02, -.15903700E+01, -.10475000E+02, -.13744100E+02, 0.14697000E+02, 0.79242700E+01, -.72841000E+01, -.17379800E+02, 0.22990000E+02, 0.25122300E+02, -.12851000E+02, -.74830700E+00, -.12469500E+02, -.71251000E+01, -.73503600E+01, -.10614100E+02, 0.48904900E+01, 0.19014800E+01, -.63205400E+01, -.25188400E+02, -.32387800E+01, -.40222700E+00, -.62007700E+01, -.53764300E+01, -.68711800E-01, 0.17521900E+01, 0.19876100E+01, -.51859200E+01, 0.62573200E+01, -.15132000E+01, -.11077800E+01, 0.45232500E+01, -.24451900E+01, 0.43984300E+01, 0.44184300E+00, -.53489700E+01, -.14313000E+01, 0.16215400E+01, 0.38607100E+00, -.21987500E+01, -.70209800E+00, -.74152500E+01, -.16617300E+01, -.26459400E+01, 0.44253400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24838100E+01, 0.39923300E+01, 0.51077300E+01, -.13685900E+01, 0.76129900E+01, 0.14354800E+01, -.10349000E+01, 0.45167500E+00, 0.96536500E-01, 0.83143400E-02, 0.33184100E+00, 0.16241000E+00, 0.13108100E+01, 0.56462100E+00, 0.18382300E+00, 0.30022200E+00, -.21181100E+00, -.45964200E+00, 0.75413700E+00, -.38158800E+00, 0.86997400E+00, 0.27755900E-01, -.42660900E+00, -.11327800E+01, -.19225600E+00, -.25899700E+00, 0.40669600E+00, -.18976800E+00, 0.11174200E+00, 0.18154100E+00, 0.33050800E+00, -.12897400E+00, -.34625500E+00, 0.14621400E+01, 0.16947900E+01, 0.34482000E+00, -.58748500E-02, 0.36171500E+01, -.10321900E+01, 0.70797800E+00, 0.11902100E+01, 0.23171300E+00, -.15061800E+01, 0.86390500E-01, -.30667100E+00, -.51346800E+00, -.30351600E+00, -.10630500E-02, 0.21328300E-01, 0.14766100E+01, 0.12314700E+01, -.37023600E+00, 0.30815200E+00, -.40233400E-02, 0.73433200E-01, 0.45185400E+00, -.16536900E+01, -.11847700E+01, -.89244100E-02, 0.46296500E+00, -.51082000E+00, -.40346800E-01, -.69578800E+00, 0.73648400E+00, -.12983100E+01, -.12635200E+00, -.15841900E+00, -.35507800E+00, 0.15641800E+00, 0.12121000E+00, 0.43640800E+00, 0.36638700E+00, -.51263600E+00, -.70886600E+00, -.50917700E+00, 0.99968100E+00, 0.18686100E+00, 0.54042600E+00, 0.62769300E+00, -.42150400E+00, -.33800800E+00, 0.38966500E-01, -.12254700E+01, -.26105700E+01, -.23689100E+01, 0.16882300E+01, 0.16071300E+00, 0.45636500E+00, -.29360300E+00, -.74004800E+00, -.31972600E+00, -.17225400E+00, 0.14167100E+01, -.13087800E+01, -.68803800E-01, -.36455100E+00, -.28042000E+00, 0.99596300E+00, -.33398400E+00, 0.10041100E+01, -.41990100E+00, -.15529300E+00, -.79489000E-02, 0.31505800E+01, 0.14095800E+01, 0.44145500E+00, -.18574100E+00, 0.10235300E+01, -.48079100E+00, 0.54280600E+00, 0.20603500E+01, 0.76089600E+00, 0.45952300E+00, -.40558800E-03, -.49331100E-01, 0.36418600E+00, 0.40259300E+00, -.30116600E+00, -.96495200E+00, -.90574400E-01, -.40271200E+00, 0.44354900E+00, 0.59451500E+01, -.18926900E+01, -.50393700E-01, 0.15619800E+01, 0.41609500E+00, -.77156900E+00, -.50559000E+00, -.52989800E+00, -.77635400E+00, -.40374600E+00, -.88985500E+00, 0.27711800E+00, 0.12694900E+01, -.11107000E+00, 0.49684000E+00, -.12476600E+00, 0.52863400E+00, -.20402300E+00, 0.55716300E+00, 0.65282800E+00, 0.30455800E-01, -.21320900E+00, 0.47617800E+00, -.27087100E+00, -.27087200E-01, 0.32522300E+00, -.29895600E+00, -.79891600E+00, 0.27045500E-01, -.21210600E+00, -.59445400E+00, -.25229600E-01, -.57360300E+00, -.12298400E+00, -.14661200E-01, 0.63791200E-01, -.82614100E+00, 0.86952700E+00, 0.21452500E+00, 0.98109800E+00, -.17636100E+01, -.38230800E+00, 0.18087900E+00, 0.13662500E+00, 0.95460100E-01, 0.57557800E+00, -.82853500E-02, 0.16350100E+00, -.14573100E+01, 0.16887800E+01, 0.19946000E+01, 0.32892500E+01, -.22791400E+00, -.13027500E+01, -.18632500E+00, 0.76538400E+00, 0.36786600E+00, 0.68807400E-01, 0.39078100E+01, 0.62386200E-01, 0.83530700E+00, -.56238800E+00, -.43848700E+00, -.63174700E+00, -.14628100E+01, 0.11868000E+01, 0.32699900E-01, -.16992700E+00, -.74826500E-02, 0.12472300E+00, -.11156900E+01, 0.28293000E+00, 0.11330100E+00, 0.13604800E+00, -.37289000E-01, 0.10076600E+00, -.97734600E+00, 0.45943100E+00, -.32903400E-01, -.14841900E+00, 0.14355600E+00, 0.92001500E+00, -.46864000E-01, -.23403900E+01, -.20785600E+00, -.67506700E+00, 0.17064300E+00, -.24702700E+00, -.66367300E-01, 0.22915500E+01, 0.33963200E-01, -.83826300E+00, 0.43777300E+00, -.10468000E+00, -.16786800E+00, 0.94814900E+00, 0.31358200E+00, -.21605300E+00, -.43793700E-01, -.29259700E+00, 0.92398600E-01, -.19023400E-01, 0.12951100E+03, 0.90556200E+02, 0.16560200E+02, 0.70806800E+02, -.56211600E+02, 0.77379700E+02, 0.15500100E+02, -.34682000E+02, 0.24923700E+02, 0.24681000E+02, 0.16817500E+02, 0.57617500E+02, 0.10317300E+03, -.37406300E+02, -.19296800E+02, 0.76005700E+02, 0.10207500E+03, -.28045300E+03, -.14083100E+03, 0.68538100E+02, 0.13194400E+03, 0.71463600E+02, 0.54464100E+02, 0.82511500E+02, -.13797500E+03, -.15185400E+03, 0.16653800E+03, 0.13404600E+03, 0.61604100E+02, -.25247900E+03, 0.10512500E+03, 0.54197700E+02, 0.12572600E+03, 0.10813000E+03, 0.16687200E+03, 0.11650500E+03, 0.80983300E+02, -.43080400E+02, 0.17005900E+03, 0.80478500E+02, 0.20392100E+01, 0.25308100E+02, 0.66203600E+02, 0.51653200E+02, 0.11090800E+02, 0.21976300E+02, 0.18482800E+02, 0.50273700E+02, -.67038400E+02, 0.76485600E+01, 0.23286100E+02, -.49672000E+02, -.14978700E+02, -.50873100E+02, -.15299400E+02, 0.49756000E+02, 0.24434100E+02, -.23676000E+02, -.15480300E+02, -.19126200E+02, 0.21149700E+02, 0.22049800E+02, 0.11874100E+02, 0.74507300E+02, 0.25339900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28193500E+01, 0.78693900E+00, 0.46257900E+00, 0.11902900E+01, 0.48289100E+00, 0.20501200E+00, -.55094600E+00, 0.28085000E+01, 0.26498500E+01, 0.22984400E+00, -.14777600E+01, -.36930800E+01, -.86867100E+00, -.12919000E+01, -.10409400E+02, 0.28757600E+01, 0.21320100E+01, -.94345600E+00, -.37046100E+00, -.43594000E+00, -.90246300E+00, 0.50076000E+00, 0.89988500E+00, 0.11223300E+01, 0.23836900E+00, 0.21882600E+00, 0.15276700E+01, 0.11093600E+01, 0.34855500E+00, 0.34268100E+01, 0.47446300E+00, -.84319300E+00, 0.42893200E+01, -.31661500E+01, -.81378600E-01, 0.21191700E+01, 0.20955600E+00, 0.10036000E+01, -.17065600E+00, 0.53875800E+01, -.60898900E+00, 0.90739400E+00, -.38851800E+01, 0.20584700E+00, -.58948400E-01, -.51968100E-01, -.90475100E+00, 0.48707000E-01, -.43432800E+00, -.18298100E+01, -.15188100E+01, 0.95118700E+01, -.97000700E+00, -.28874400E+00, -.98366300E-01, -.43396000E+00, -.38541700E-01, -.63817300E+00, 0.14913600E-01, -.72819600E+00, -.63584400E-01, 0.61237800E+00, -.30612700E+00, 0.91891300E+00, -.18355700E+01, -.38173600E+00, 0.40733500E-01, -.23121600E+01, 0.16578200E+01, -.54932800E-02, 0.60049700E+01, -.18970300E+01, 0.15097200E+01, -.44265600E+00, -.36537700E+00, 0.75173500E+00, 0.26653500E+00, -.32739100E+00, 0.34831600E+00, 0.35686300E+00, -.14417900E+00, -.67061200E+00, -.28658600E+00, -.17162700E+01, 0.29244600E+00, -.95705500E+00, 0.65848200E-02, -.13464100E+01, -.45931100E-01, 0.10917000E+01, -.29027100E+01, -.13072100E+00, -.30349300E+01, 0.13071500E+01, -.10295000E+01, 0.20405000E+01, -.20424200E+01, -.20929600E+01, 0.71444000E-02, 0.81504200E+00, -.22321900E-01, -.96442400E-01, 0.27042000E-01, -.41772600E+01, -.55030100E+00, -.13461300E+01, -.72416900E-01, 0.62712300E+00, 0.57538700E+00, 0.18317400E+00, 0.14943400E+00, 0.56145400E-01, 0.23633700E-01, -.25708800E-02, 0.31825000E-01, 0.10537100E+00, 0.29206500E+01, -.80185400E+00, -.38385500E+00, -.12395000E+01, 0.61966800E+00, 0.91886300E+00, -.10565200E+01, 0.10488100E+01, -.27555300E-01, 0.60468300E+00, 0.89749200E+00, -.25137500E+00, 0.40086500E+01, -.30910200E+00, -.15799400E+01, 0.67754000E-01, -.23273300E+00, 0.10841000E+01, 0.18688400E+01, -.73331200E-01, -.27591700E+01, -.80389600E-02, 0.52732700E+00, 0.41606900E+00, 0.48866000E+00, 0.33578100E+00, -.62073100E-01, -.19770600E+00, -.16495700E+00, -.23557600E+00, -.18992000E-01, 0.92763900E-01, -.37539100E-01, -.20626200E+00, 0.94448300E-03, 0.60175500E+00, -.94666700E-01, 0.42543400E+00, 0.20933900E+01, -.59724100E-01, 0.11068200E+01, -.20619800E+00, 0.10219100E+01, 0.94781300E+00, 0.30642600E-01, -.32879000E-01, 0.35251200E+00, -.78160500E-01, -.18336900E+01, 0.19702400E+00, -.47057800E+01, -.14981000E+01, 0.46991600E-01, -.50548600E+00, 0.13469100E+01, -.20763600E+01, -.23337700E+01, -.60319500E+00, 0.82952300E+00, 0.70613800E+00, 0.16758300E+00, 0.24848800E+00, -.22473800E+01, -.20628500E-01, -.17803500E+01, 0.32187700E+00, 0.30905800E+00, 0.32347300E+00, -.29032500E-01, 0.11372500E+01, 0.20951700E+01, 0.10220600E+01, -.66296600E-01, -.45611400E+00, 0.10571700E-01, 0.52317000E-01, -.10802000E+01, 0.14039800E+01, 0.19648800E+00, 0.14763400E+00, -.21085000E+01, -.17503600E+01, 0.16461000E+01, 0.25993800E+00, -.12368200E-02, -.51171000E-01, 0.49232200E+00, 0.16631300E+01, 0.30844200E+01, 0.88403800E+00, 0.13032400E+00, -.88456400E+00, 0.48344800E+00, -.64229700E+00, 0.43318400E+00, -.68623700E+00, -.19074000E-01, 0.56301100E+00, 0.25662900E+00, -.28343300E+00, -.35122700E-01, 0.43079600E+00, 0.12721400E+00, -.13828200E+00, 0.79593100E-01, -.30276500E+00, 0.54540800E+00, 0.20163400E-01, -.27528500E+00, 0.82002200E+02, -.29129100E+02, -.57357900E+02, -.10585400E+03, 0.63191000E+02, -.26569200E+03, -.59518700E+03, 0.30481500E+03, 0.29832000E+03, 0.29748900E+03, -.53441200E+02, 0.24968600E+02, 0.13440900E+03, -.40228800E+02, 0.22665500E+03, 0.52395800E+02, 0.14322500E+03, -.26714600E+03, 0.13165800E+03, 0.23266600E+03, 0.13533000E+03, 0.76684600E+02, 0.15158000E+03, -.83985100E+02, -.16065700E+03, 0.70236600E+02, 0.22682500E+03, -.95908600E+01, -.21345900E+03, 0.87135700E+02, -.17271900E+02, 0.10729300E+03, 0.20734900E+02, 0.88756100E+02, 0.11363400E+03, 0.34073400E+02, -.64714100E+02, 0.70070600E+02, -.10296800E+03, -.60514600E+01, 0.25826000E+01, 0.23423900E+02, 0.18532800E+02, -.29548000E+02, -.15208500E+02, -.17412400E+02, 0.18821200E+02, -.24520000E+02, 0.21392100E+01, -.14444300E+02, -.18289800E+02, -.97459600E+01, -.18195600E+02, -.25048800E+02, 0.18324400E+02, -.12763100E+02, 0.45718000E+01, -.24888000E+02, -.11906200E+02, -.15628800E+02, -.14140200E+01, 0.34353500E+02, 0.50467700E+02, 0.13581200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.86207400E+00, -.15851500E+00, -.24370200E+00, -.37884000E+00, -.16953800E+01, -.21864500E+00, 0.64191800E+00, -.29562200E+00, -.14425200E+00, -.14461200E+00, 0.77054500E-01, -.17430500E+01, 0.12395300E+01, 0.40879700E+00, -.52626200E-01, 0.14581700E+00, 0.11441800E+01, 0.64571300E+00, -.28238200E+00, 0.13343700E+01, 0.49111800E+00, -.12632200E+00, -.45020700E+00, 0.11022300E+01, -.85346900E-01, 0.17431100E+00, 0.11001000E+01, -.28665800E+00, 0.45220000E+00, 0.10361100E+01, 0.23491500E+00, 0.24333800E-01, 0.64315400E+00, -.67953600E-01, -.27868000E+00, 0.49489200E+00, 0.14200900E-01, -.13037400E+00, 0.36433100E+00, 0.10540800E+01, -.64644300E+00, -.36341400E+00, -.83807600E+00, -.13774500E+00, 0.26829100E+00, 0.21041500E+00, 0.51125100E+00, 0.42892000E-02, 0.91195000E+00, -.97802100E+00, -.11100900E+01, 0.15627900E+01, -.23001200E+00, 0.11752100E+00, -.31921400E+00, 0.15265000E-01, 0.50835800E+00, 0.49887200E+00, -.14903200E-01, -.84000400E+00, -.39514500E-01, -.48310600E-01, 0.22685800E-01, 0.11728500E+01, -.16956300E+01, -.13232600E-01, 0.37618200E-01, 0.73184400E+00, 0.92448200E+00, 0.78018600E-01, 0.71049800E+00, -.12781600E+01, 0.80710800E+00, 0.78174100E-01, 0.48384400E-02, 0.33090900E+00, -.39488200E-01, -.21151500E+00, 0.90217500E-02, 0.67625800E-01, -.14551500E-01, 0.16129200E+00, -.19495400E+00, -.52325800E+00, 0.11184500E+00, 0.19276400E+00, -.82815500E-01, -.15974600E+00, 0.22220400E+00, -.55497600E+00, 0.47775100E+00, -.17034200E-04, 0.29666500E-01, -.23775100E+00, -.37427000E+00, -.23101100E+00, -.26578600E+00, 0.82891600E-01, 0.14721500E+00, 0.71139100E+00, 0.61497500E-01, -.93514700E-01, 0.82462600E-02, 0.29839600E+00, -.50517900E+00, -.18417500E+00, 0.65957200E-02, 0.36758500E+00, -.43097400E+00, -.11436000E+00, 0.63186700E-01, -.12133700E+00, -.94014100E-01, 0.16643500E-02, 0.72644800E-02, -.87802000E-01, 0.17449900E+00, 0.76830100E+00, -.78241000E-02, 0.32519400E+00, -.16714200E+00, 0.14417200E+01, 0.16756900E+01, -.24771400E+00, 0.32411200E-03, 0.36519400E+00, -.31040000E+00, 0.92172500E-01, -.22228500E+00, 0.18997800E+00, 0.12246500E+01, 0.80688800E-02, 0.46528900E+00, 0.32201400E+00, 0.37662800E+00, -.28019900E-01, -.49559400E+00, 0.11087000E+00, -.24922800E+00, -.52403500E-01, 0.34295400E+00, 0.19405800E+00, 0.72898900E-01, -.16760700E+00, -.61775900E-01, 0.15524700E+00, -.10138400E-01, 0.18059300E+00, -.55853400E+00, -.20235300E+00, -.82005100E-01, -.84941600E-01, -.22587900E+00, -.24080300E-01, 0.14526200E-01, 0.82669500E-01, -.64581100E+00, -.56439900E-01, 0.14972800E+00, 0.39298500E+00, -.12881100E+00, 0.85266700E-01, -.12379200E+00, 0.37250500E+00, -.55349800E+00, 0.21641600E+00, -.47872300E+00, 0.25552800E+00, 0.15909500E-01, 0.85575400E-01, 0.36473700E+00, 0.14552000E-01, -.26106300E+00, -.58428000E+00, 0.77886300E-01, 0.15302800E+00, 0.25510100E-01, -.45595200E-01, -.10343200E+00, -.63862500E-02, -.34188700E-02, 0.23355700E-01, 0.84924200E-01, 0.30993600E-01, 0.86574900E-01, 0.56359800E+00, -.15788800E+00, 0.43738900E+00, -.38094600E-01, 0.10857400E+00, 0.73762200E-02, -.13904700E+00, 0.26776900E-01, 0.54827300E-01, 0.12076400E+00, -.13124800E-01, 0.41760600E+00, -.17001200E+00, 0.22246200E+00, -.15687700E+00, -.72040100E-01, 0.45186600E-01, -.32364800E-01, 0.15351000E-01, 0.53613700E+00, 0.25621400E+00, -.60858000E-01, 0.24043200E+00, 0.60597100E-02, -.38779700E-01, -.13535500E+00, 0.39351200E+00, -.97257700E-02, -.89709600E+00, -.62641200E-01, 0.49997500E-01, -.67182600E-01, -.15166600E+00, -.42092300E-01, 0.42250100E-01, 0.19814100E+00, 0.62868800E-01, 0.13507700E-01, 0.41436800E-02, -.11708900E+00, -.66422500E-01, -.25730700E+02, -.47914300E+02, -.21825800E+02, 0.47729400E+01, 0.86268100E+01, -.15571600E+03, 0.79616000E+02, 0.66554400E+02, 0.77900300E+02, 0.17452600E+02, 0.70613800E+01, 0.31262400E+02, 0.14465700E+01, 0.51677900E+02, 0.77400000E+01, 0.77641600E+02, -.23395200E+02, 0.11418200E+02, 0.16111800E+02, 0.12035000E+02, -.34724500E+01, -.10222800E+01, 0.13388100E+02, 0.88267900E+01, 0.19385600E+02, 0.61616800E+01, -.48736100E+02, 0.12065600E+02, -.92130800E+01, -.24290900E+01, -.59300700E+01, 0.14050100E+02, 0.16554400E+02, -.13361100E+02, -.39323400E+02, -.30669300E+02, 0.16683500E+02, -.43770900E+02, -.34729400E+01, 0.94689800E+00, 0.42339600E+01, 0.53914300E+01, -.12257300E+02, -.18706800E+01, -.26145100E+01, 0.54448700E+01, -.42462000E+01, -.20855200E+01, 0.24726700E+00, -.68984300E+01, -.23000500E+01, -.66849400E+01, -.12997000E+02, 0.54148800E+01, 0.49897400E+00, -.62965200E+00, -.13064200E+02, -.25697300E+01, 0.78445300E+00, 0.89886100E+01, 0.11178500E+02, 0.42513700E+01, -.24993400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20256700E+01, -.12842600E+01, 0.27591000E+01, 0.12823200E+00, 0.12371300E+01, -.11021700E+00, 0.16473400E+01, -.73636200E+00, -.45366100E+01, -.21363900E+00, -.33766200E+00, 0.48964700E+01, 0.32524400E-01, -.60398400E+00, 0.31926700E+01, -.28802600E+01, -.19087600E+01, 0.48268700E+00, 0.11862800E+00, -.20377800E+00, 0.13310700E+01, -.18558500E-01, -.13321400E+01, 0.10963900E+01, -.26055600E-01, 0.31130700E+00, 0.17111500E+01, 0.89138700E-02, 0.41530100E+00, -.22624000E-02, 0.15107600E+00, 0.31119100E+00, 0.36450900E+00, 0.33025500E+00, -.36630500E+00, 0.77954100E+00, 0.52757300E-01, -.11593100E+01, 0.48104500E+00, 0.56611800E+00, 0.32546800E+00, 0.68529200E+00, -.33084800E+00, 0.32605800E-01, 0.28368000E-01, -.16541900E+00, 0.20676600E+00, 0.11903100E-01, -.76603800E+00, 0.88025500E+00, 0.52688400E+00, 0.24150200E+01, -.11999700E+00, 0.63891800E+00, 0.19608900E-01, -.20595400E+00, -.27382400E+00, -.21620600E+01, -.69158300E-01, 0.19292100E+00, 0.58995400E-01, -.59807600E-01, 0.56387300E-01, 0.29397600E+01, -.31337100E+01, 0.37865800E+00, 0.51096200E-01, 0.12034700E+01, 0.72770000E+00, -.32066100E+00, 0.71753100E+00, -.16273500E+01, 0.73949500E+00, 0.79160500E-01, 0.29934700E+00, -.12709000E+01, -.31621200E-02, -.43716800E+00, -.26500000E+00, 0.25362800E+00, 0.35190600E+00, -.17331400E+00, 0.66075400E+00, 0.15193900E+01, 0.20364400E+01, -.19896500E+01, 0.24920600E+00, 0.50177900E+00, -.55103200E+00, 0.11632600E+01, -.75875600E+00, 0.18109000E+00, -.54066100E+00, 0.10351900E+01, 0.13946100E+01, -.31974600E+00, 0.13612700E+01, 0.92700700E+00, -.92661300E-01, -.28982000E+00, 0.94352300E-02, 0.10695000E+01, -.18253700E-01, -.13142100E+01, -.29294400E+00, -.21606000E+00, -.36922400E-01, 0.65370100E+00, 0.88502600E-01, -.29195200E+00, 0.80920400E+00, 0.12854400E+00, 0.27029500E+00, -.17422100E-02, -.79882300E-01, 0.20678000E+00, -.39708700E+00, -.17024200E+01, 0.71781400E+00, -.27469600E+00, -.38545400E+00, -.16519100E+01, -.34645700E+01, 0.21258600E-01, 0.77337000E-02, -.72576500E+00, 0.64563000E+00, -.38169000E+00, -.20603800E+00, -.76177600E+00, -.81784600E+00, -.33996400E+00, -.13453600E+01, 0.31328900E-01, -.28222900E+00, 0.22831100E-01, 0.56509600E+00, -.30316300E+00, 0.92717400E+00, 0.28149900E+00, 0.21026800E+00, 0.14315500E-02, -.11556800E+00, 0.23970500E+00, -.23593600E+00, 0.16033900E+00, 0.57818500E-02, -.49120100E+00, -.22027300E-01, 0.19802100E+00, -.70375400E-01, 0.80920900E-01, 0.31792800E+00, -.19738300E+00, 0.82292800E-02, -.11867600E+00, 0.95278500E+00, 0.83861400E-01, 0.87940700E-01, -.46662600E+00, 0.18090000E+00, -.23397800E+00, 0.51544800E+00, -.15263300E+00, 0.10074200E+01, -.21156100E-01, 0.88831800E+00, -.16178200E+00, -.59236900E-01, 0.14571800E+00, -.62351600E+00, -.86954100E-01, 0.45678200E+00, 0.28538600E+00, 0.18239500E+00, 0.42428100E+00, -.25408400E+00, 0.15028300E+00, 0.91777300E-01, 0.16070500E-01, 0.16888300E+01, 0.11222600E-01, -.70963800E+00, -.29108900E+00, 0.94078400E-01, -.22572400E+01, 0.59057400E+00, 0.83767200E+00, 0.15351400E+00, -.51422100E+00, -.12608300E-01, -.10950400E+00, 0.11582300E+01, -.12017900E+00, 0.25688400E-01, 0.12778700E+00, -.90425900E+00, -.20725900E-01, 0.62866900E+00, -.83481800E+00, 0.11531800E+00, 0.15356800E-01, -.14260400E+00, 0.48159100E+00, -.42014500E+00, -.16652000E+01, -.24094700E+00, -.10519900E+00, 0.45828200E+00, -.67413300E+00, 0.28469300E+00, 0.27390200E+01, -.57925700E-02, -.12144000E+01, -.32960400E+00, -.46153800E+00, -.53608600E+00, 0.24777000E+00, -.30714700E+00, -.13205600E-01, -.45029200E-01, -.28636400E+00, 0.11650900E+00, 0.18521500E-03, 0.33641700E+00, 0.10984900E+00, 0.64490100E+00, 0.46325500E+02, 0.22261100E+02, -.15979500E+02, -.47520300E+01, 0.94120600E+02, -.49998100E+02, -.63261400E+02, -.46817400E+02, -.39223800E+02, -.26871500E+02, -.18624800E+02, -.16204600E+02, -.27500600E+01, -.33822600E+02, 0.34662000E+02, 0.12662700E+03, -.62625900E+02, -.53725800E+02, -.63929600E+02, -.36400800E+00, -.91592600E+00, -.52790700E+02, 0.48774900E+01, 0.36253900E+02, -.93811400E+01, -.20694300E+02, -.19741200E+03, 0.10300400E+03, 0.77259200E+02, 0.98758900E+02, -.64786700E+02, -.10702600E+02, 0.49531100E+02, 0.69097200E+02, 0.10970400E+03, -.89586500E+01, 0.97614400E+02, 0.30280300E+02, 0.67161300E+00, 0.12301300E+02, 0.58090200E+01, 0.17766300E+02, -.26667900E+01, -.21646300E+01, 0.50951100E+01, -.12253400E+02, 0.16361900E+02, -.24028300E+01, 0.84816400E+00, 0.16929600E+02, 0.90170600E+00, 0.90439800E+01, 0.48488600E+01, -.17243700E+01, -.78658000E+01, 0.94142100E+01, 0.15996800E+02, -.18111000E+01, 0.30432300E+01, -.57073100E+01, -.26852300E+01, -.63392200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57918500E+01, -.15763700E+01, 0.37441400E+00, -.37142900E+01, -.73856300E+00, -.42472500E-01, 0.39045100E+01, 0.25830700E+01, -.45427000E+01, -.64404800E+00, -.41656300E+00, 0.28799600E+01, 0.39839900E+01, -.11959900E+01, 0.10457600E+02, -.79715200E+01, -.11607700E+01, 0.21387800E+01, -.57406800E+00, 0.26067400E+01, 0.59904800E+01, 0.53602900E-01, -.30812000E+01, 0.29973600E+01, -.37343300E+00, 0.42874800E+00, 0.46299700E+01, -.23031700E+00, 0.19189900E+01, -.17557600E+00, -.47083800E+00, 0.41816400E-01, 0.23935100E+01, 0.21920400E+01, 0.14971300E+01, 0.48958900E+00, 0.12094400E+00, 0.22194800E+01, -.46810200E+00, 0.44497300E+01, 0.56342200E+00, 0.10300300E+01, -.40190600E+01, -.15244500E+00, 0.13120900E+00, 0.25495200E+00, 0.32452000E+00, 0.20784500E-01, -.13381700E+01, 0.74026300E+00, 0.36388400E+00, 0.32818800E+01, -.49701400E+00, -.22091800E+00, 0.51371300E+00, 0.16458500E+00, -.22896500E+01, 0.24755000E+01, -.17915300E+00, 0.79867600E+00, -.22207200E+00, -.74050600E+00, -.68931300E+00, 0.31826700E+01, -.19530800E+01, 0.48614100E+00, 0.11066300E-01, 0.24557400E+01, 0.28014600E+00, 0.13771200E+00, -.89590000E+00, 0.21023700E+01, 0.73370600E+00, 0.15372200E+01, 0.14717600E+01, -.27455300E+01, -.79569200E-01, -.22015700E+00, -.77204500E-01, 0.32149500E+00, -.74741100E-01, 0.30727900E+01, -.13911800E+01, 0.24992700E+01, 0.18148700E+00, 0.77077100E+00, 0.75573500E+00, 0.29375900E+00, -.65128600E+00, 0.26937500E+00, -.80490800E+00, -.34498900E+00, -.16672600E+00, 0.22783400E-01, 0.19310900E+01, -.32275000E-01, 0.17456600E+00, -.31442600E+01, -.15955400E+00, -.68659000E+00, 0.16932700E+00, 0.22035500E+00, -.17333900E-01, -.29986300E+01, 0.15406100E+00, -.50321700E+00, 0.47766600E+00, -.21278200E+01, -.23161200E+01, 0.12394100E+01, 0.62176500E+00, 0.58697700E+00, 0.57133000E+00, -.23630800E-02, -.72491100E+00, -.86281300E-01, -.58653800E+01, -.58118600E+00, -.35706400E+01, -.19303200E-01, 0.47400200E+00, 0.51195500E+01, 0.34280400E+01, -.16269300E+00, -.73880200E-01, 0.84191100E+00, -.17047300E+00, -.65597000E+00, 0.28276500E+00, -.82485800E+00, -.11555100E+01, -.14858600E+00, -.12634000E+01, 0.62302100E+00, -.11450500E+01, 0.37754300E+00, 0.15899500E+01, 0.13571900E+00, 0.17969000E+01, 0.78864200E+00, 0.30139500E+00, 0.15833900E+01, -.53704900E+00, -.41839900E+00, 0.75358600E+00, 0.93473700E-01, 0.84421900E-02, -.90230200E+00, -.55928600E+00, 0.46221500E+00, 0.12385900E+00, 0.19771500E+00, 0.19099700E+01, -.49443200E+00, -.21124700E+01, -.18269600E+00, 0.13899900E+01, 0.12383700E-01, 0.17862800E+00, 0.84113800E+00, 0.51000600E+00, -.43501600E+01, -.18272000E+00, -.13439900E+01, 0.66297300E+00, -.68144800E+00, 0.55643200E+01, -.13991100E+00, -.11047300E+00, 0.37949700E+00, -.89513600E+00, 0.34225900E+01, -.58974400E+00, 0.16361500E+01, -.84640400E+00, -.12759200E+01, -.11213000E+01, -.64211700E+00, 0.13780200E+01, -.71742700E-01, 0.12365100E+01, -.66459100E+00, -.20556500E+01, -.15962900E+00, 0.64714800E-01, -.26828500E+01, -.21137600E+01, 0.45828100E+00, 0.27292600E+00, -.68117700E+00, -.32575400E-02, 0.35999000E+00, 0.69223000E-01, 0.17572700E+01, -.57737900E+00, 0.39107800E-01, -.62445000E+01, -.60926200E+00, 0.27122200E+01, 0.18431700E+01, 0.13297300E+00, -.17855000E+00, -.53030900E+00, 0.11126200E+01, -.18146900E+00, -.74826300E+00, -.56333000E-02, -.16434100E+01, 0.69338700E-01, -.75267100E+00, 0.79024900E+00, 0.74941200E+01, 0.50646700E-01, 0.69307100E+00, -.99803800E-01, -.16138000E+01, -.19535000E+01, 0.13941800E+01, 0.14625500E+00, -.26076000E+00, -.10893100E+01, -.10198000E+01, -.11186400E+01, -.11629700E-01, -.38655100E-01, -.12505000E+01, -.49346500E+01, 0.17297000E+00, -.17041200E+03, -.16354300E+02, -.47084000E+03, -.12843000E+04, 0.64256400E+03, 0.70233100E+03, 0.64137300E+03, -.26887800E+03, 0.14105500E+03, 0.26229000E+03, -.15351700E+03, 0.33910600E+03, 0.19829100E+03, 0.14893900E+03, -.48652800E+03, 0.24739400E+03, 0.29018400E+03, 0.24676300E+03, -.18429200E+02, 0.23823600E+03, 0.21647200E+02, -.23396200E+03, -.25256200E+02, 0.36344200E+03, -.61808600E+02, 0.23686800E+03, -.13464200E+03, -.11546700E+03, -.11759600E+03, -.16910500E+02, 0.11119700E+03, -.10235900E+03, -.17753900E+03, -.38112000E+03, 0.77962900E+02, 0.95123600E+00, -.58394600E+02, 0.30285300E+01, -.24152000E+02, 0.12705500E+02, -.81650600E+02, -.48246700E+02, -.56161100E+02, 0.15865100E+02, 0.23125700E+02, -.36420700E+02, -.61864900E+02, -.22137200E+02, -.33530900E+02, -.21426800E+02, -.23731600E+02, 0.15333100E+02, -.60021300E+02, 0.43927800E+02, -.23258200E+02, -.33063700E+02, -.62759800E+02, -.52684900E+02, 0.65170300E+02, 0.58846200E+02, 0.51964400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.41996100E+00, -.12190600E+00, -.18131700E+00, 0.27274800E+00, 0.29670300E-01, -.83539800E-02, -.37692000E+00, -.45769400E+00, 0.80682700E+00, 0.22104900E+00, -.22816500E-01, 0.75756500E+00, -.48541100E+00, -.12819900E+00, -.37962100E+00, -.35018000E+00, -.26628000E+00, -.51034000E-01, 0.25393100E+00, -.56343700E+00, -.16146800E+00, -.39830800E-01, 0.12140100E+00, 0.25732600E-01, 0.43967300E-01, 0.84712800E-02, -.44591100E+00, 0.16282500E+00, 0.91604700E-01, 0.36715200E+00, 0.14930700E+00, -.44813200E+00, 0.23960600E-03, -.22445600E+00, -.14673600E+00, 0.40051600E-01, 0.12986900E-01, 0.24074800E+00, -.55770500E-01, -.53836200E+00, -.20776300E+00, -.36678800E-01, 0.24496000E+00, 0.49683200E-01, 0.65998600E-01, -.23253100E+00, -.14282200E+00, 0.15977300E-02, 0.23597200E+00, -.21046300E+00, 0.37091600E+00, 0.26397700E+00, -.67934900E-01, -.51324800E+00, -.31935800E-02, -.17464400E+00, -.22226100E-02, 0.26989900E+00, -.21123400E-01, 0.83350700E-02, -.19269600E-01, -.61974500E-04, 0.44523000E-01, 0.67822500E+00, -.27975100E+00, -.18453700E-01, 0.22526700E-02, 0.60373800E+00, 0.13087200E+00, 0.11419800E+00, -.43515000E+00, 0.24973700E-01, 0.10143700E+00, 0.18599900E-01, 0.11090200E+00, -.79219100E-01, 0.11273400E-01, 0.17596300E+00, -.43931500E-01, 0.12184000E+00, -.57029200E-01, 0.66928700E-01, -.52206000E-01, -.52012900E+00, 0.25352200E+00, 0.22167200E+00, -.20513200E+00, -.12442700E+00, 0.94557500E-02, -.24078400E-01, -.39932000E+00, 0.31666000E-01, -.31864000E+00, 0.19364900E+00, -.10633800E+00, 0.26408500E+00, 0.29121400E+00, 0.10223800E-02, 0.16775000E-01, -.71838900E-01, -.77300900E-03, 0.14781400E+00, -.29620000E-04, -.42481600E+00, -.42580500E+00, 0.16828100E-03, -.86130200E-01, 0.58840300E+00, 0.16954000E+00, -.27618900E-01, 0.51810700E+00, 0.78490200E-01, 0.54262300E-01, -.26298900E-03, -.94861000E-01, -.26337500E-01, 0.67177500E+00, 0.11969200E+00, 0.13322700E-01, -.11573600E+00, 0.51912500E-01, 0.35376600E+00, 0.45434800E+00, 0.86854700E-01, -.31258400E-02, 0.19083500E+00, -.28535500E-01, -.35140100E-01, 0.22539100E+00, -.25990200E+00, 0.29809200E+00, 0.20205800E-01, 0.12460100E+00, 0.13542900E+00, 0.76375200E-01, -.64893100E-02, 0.12626000E+00, 0.97891700E-01, 0.11977800E-01, -.28241900E-01, 0.10459000E+00, 0.37039400E-01, 0.45022200E-01, -.47419500E-01, -.51529600E-01, 0.15634500E+00, -.44919100E-02, 0.81053100E-01, 0.76568500E-01, 0.14868100E+00, 0.13884800E+00, 0.36427500E-01, -.17484500E+00, -.62044900E-02, 0.34141700E+00, 0.25230900E-01, 0.60905500E-01, -.43750700E-04, 0.27426600E-01, 0.48932800E-01, 0.44318500E-02, -.13776000E+00, 0.22402800E+00, 0.57051600E-01, -.17292200E+00, 0.39104200E-01, -.65175400E+00, -.81410900E-01, 0.12290700E-01, -.19948100E-01, 0.10262300E+00, -.73768000E-01, -.93488500E-01, -.35109300E+00, 0.51715600E-01, 0.36708200E-01, -.64788600E-02, 0.17099600E-01, 0.83005500E-01, -.19774600E-02, -.37011000E+00, 0.65666000E-01, 0.23793800E+00, 0.22266700E-01, 0.41143000E-01, 0.60855700E+00, 0.90473700E-01, 0.21878800E+00, -.13629500E-01, 0.62792900E-01, 0.28701700E-03, -.44927200E-01, -.21354200E-01, -.16900200E+00, 0.99884400E-01, 0.40189400E-01, 0.52393500E+00, 0.92884500E-02, -.22550300E+00, -.20914600E+00, -.39657600E-01, 0.15993000E-01, -.30682300E-01, 0.11064000E+00, 0.19170500E+00, -.42261300E+00, -.92818600E-01, -.10758800E-01, -.34568500E-01, 0.32184200E-03, -.33415800E-01, -.87862100E-01, 0.13038100E-03, -.19080400E+00, 0.11941600E+00, 0.64742400E-01, 0.10278500E+00, -.89964400E-01, 0.28217800E-01, -.15769100E-01, -.46455800E-01, 0.28394300E-01, -.35158300E-01, -.69678500E-03, -.87214900E-01, 0.13558600E+00, -.25353100E+00, 0.23593200E-01, -.23570300E-01, 0.75509800E+01, 0.22772700E+02, 0.71065700E+01, -.34270700E+01, -.50306700E+01, -.35941500E+01, 0.64969600E+01, 0.83953300E+01, -.51986600E+01, 0.47422800E+01, 0.34260200E+01, 0.65458900E+01, -.31921800E+02, 0.28632400E+00, -.19399400E+00, -.64553800E+01, -.71551100E-01, 0.39793300E+01, -.77783400E+01, -.97368800E+00, 0.32601400E+01, 0.15952500E+02, -.10790500E+02, 0.12208300E+02, 0.60145800E+01, -.33716200E+01, 0.42482300E+01, -.31045600E+01, 0.55540400E+01, 0.12079000E+02, -.75348800E+01, -.16489300E+02, -.14078600E+02, 0.19947700E+02, -.84030700E+01, -.81631600E+00, 0.25828500E+01, 0.27195000E+01, 0.29338300E+01, 0.50659900E-01, 0.18633000E+01, 0.17442500E+01, 0.29005800E+01, -.26981900E+01, 0.47907300E-01, 0.23875700E+01, -.37623100E+01, -.20676600E+01, -.38730600E+01, -.13128400E+01, 0.29319000E+01, 0.23906800E+01, -.18214800E+01, -.13306500E+01, -.20527800E+01, 0.21374500E+01, 0.20899800E+01, 0.13601600E+01, 0.35840700E+01, -.24688700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11569800E+01, -.13683300E+00, 0.78964400E+00, -.17449100E+00, 0.39333900E+00, -.64409300E-01, -.22698700E+00, 0.16291700E+01, 0.16649400E+00, 0.26276400E+00, -.35533600E-01, 0.48665300E+00, 0.18515500E+01, 0.59780900E+00, 0.30438600E+01, 0.48499800E+00, -.44758100E+00, -.12272000E+01, 0.27229100E+00, -.16400700E+01, 0.15938400E+01, 0.36912000E-01, -.44021200E+00, -.44459900E+00, -.82463500E-01, 0.89098300E-01, -.80806700E+00, -.47066600E-01, -.13769100E+00, -.64024000E+00, -.45055000E+00, -.12581300E+00, -.91380300E-01, 0.30790200E+00, 0.55686500E+00, -.50408800E+00, 0.19255500E-01, 0.21613300E+00, -.20828600E-01, -.66336700E-02, -.89235100E+00, -.22531300E+00, 0.28528500E+00, 0.63858800E-01, -.28699800E+00, 0.34250200E-01, -.19357900E+00, 0.24460400E-02, -.68567300E+00, 0.47773800E+00, -.42131900E+00, -.15250600E+01, 0.52468500E-01, -.30014200E-01, 0.60080600E-01, 0.27702600E+00, 0.19559700E+00, -.41885900E+00, 0.54006900E-01, 0.43636300E+00, -.36161600E-01, -.20275900E+00, 0.78204900E-01, -.15421400E+01, 0.16663200E+01, 0.74777700E-01, -.81808500E-01, -.16623100E+01, -.10172500E+01, -.25315400E+00, -.16848500E+01, -.24040200E+00, -.41707900E+00, 0.49818200E+00, 0.41046400E+00, 0.11747400E+00, -.14828100E+00, -.88498600E+00, 0.21742500E-01, -.23666400E+00, 0.20540700E+00, -.52106900E+00, 0.11954200E+01, 0.83044100E+00, -.58105200E+00, 0.32729200E+00, 0.19026000E+00, -.30558000E-01, 0.32139600E+00, -.17526200E+00, 0.10325400E+01, -.50321800E-01, 0.64704300E+00, -.54575300E+00, 0.10570100E+01, -.10274200E+01, -.17270200E+00, -.95163000E+00, 0.95916000E-02, 0.17942200E+00, 0.62062900E-01, 0.10109500E+00, -.86320000E-03, 0.12160900E+01, 0.25277500E+00, 0.14474800E+00, 0.38404300E-01, 0.41974400E+00, -.36551600E+00, -.32451100E-01, 0.56373700E+00, 0.13880100E+00, 0.11564200E+00, 0.10292800E-02, 0.16018800E-01, 0.11435000E+00, -.13216000E+01, -.34802200E+00, -.11251600E+00, -.29821600E-02, 0.39324300E-01, 0.23965600E+00, 0.60914700E+00, -.72756500E+00, 0.10905500E-01, 0.50451600E-01, 0.14659900E+00, -.20326400E+00, -.15841200E+01, -.10258500E-01, -.31712000E+00, -.15908400E+00, -.88820200E+00, -.53834600E+00, -.22570500E+00, 0.46580100E-01, 0.80766200E+00, -.23429200E+00, 0.39077300E+00, -.19690600E+00, -.11354800E+01, -.14632900E-01, 0.92984500E-01, -.26302700E+00, -.22486800E+00, 0.15273200E+00, 0.68244100E-02, 0.11916200E-03, -.15301500E+00, 0.28224800E+00, 0.70431000E-01, 0.47609200E-01, 0.76125000E-02, -.16996100E+00, -.30255100E+00, 0.78671900E-01, -.40790400E+00, -.24937000E-01, -.89851100E-01, 0.56844400E+00, 0.38605000E-01, 0.79586700E+00, 0.49909400E+00, 0.41937500E+00, -.84603300E-03, 0.13332700E+00, -.95249800E+00, 0.36950100E+00, 0.39474900E-01, 0.59688400E-01, 0.86673700E+00, -.38559500E+00, -.55817600E+00, -.10573800E+00, 0.10671100E+00, 0.55941800E+00, 0.18345000E+00, 0.38665300E-01, -.50880700E+00, -.14011900E-01, 0.27559500E+00, 0.26445700E-01, -.19102900E+00, 0.78806100E-01, -.77050700E-01, -.76304900E+00, 0.60526300E+00, -.68911800E-01, 0.26252200E-01, 0.22873900E+00, 0.33392100E-03, -.53952400E-01, 0.30987000E+00, 0.21839700E+00, 0.48299000E-01, -.86786100E-02, 0.12309900E+01, 0.33000800E+00, -.18795200E+00, -.65255200E+00, -.19358200E-01, -.17332900E-02, 0.45205100E-01, 0.55040600E+00, 0.45955600E+00, -.11775900E+01, -.16323300E+00, -.12275000E+00, 0.20416300E+00, -.23102800E+00, -.33142400E-01, -.25786500E+00, 0.12650700E-02, 0.27833900E+00, 0.10624000E+00, -.16038500E-01, -.33311900E-01, 0.42251100E-01, 0.48184300E-01, 0.95220800E-02, 0.34919500E-01, -.45938500E-01, 0.14329200E+00, 0.10089300E-03, -.13409400E+00, 0.37747900E+00, -.30430500E+00, 0.28149700E+00, -.39401300E-01, 0.17428200E+01, 0.85718500E+02, 0.35377000E+02, -.16156800E+02, -.19350400E+02, -.17784700E+02, -.44262900E+01, 0.17430100E+02, -.20768600E+02, -.12202600E+02, -.27610700E+02, 0.20679100E+02, 0.75427800E+01, -.23919600E+02, 0.11716000E+02, 0.73880700E+01, 0.12249200E+02, -.76680600E+01, 0.38699200E+01, -.18990500E+01, -.12018800E+02, -.17940700E+02, 0.99199200E+01, -.22683100E+02, 0.42960900E+01, -.52762900E+01, -.34212700E+01, -.21776300E+01, 0.74632500E+01, -.48458500E+01, 0.63872700E+01, 0.11413000E+02, 0.19930300E+01, -.14647300E+02, 0.10714100E+03, -.48291800E+01, -.91060100E-01, 0.96144700E+01, 0.69582700E+01, 0.31502800E+01, 0.66307700E+01, 0.58226600E+01, 0.66555500E+01, -.94343200E+01, -.18101600E+01, 0.73942600E+01, -.61989900E+01, -.27065400E+01, -.58802900E+01, -.20795900E+01, 0.66094700E+01, 0.71820400E+01, -.16314100E+01, -.24915900E+01, -.35047000E+01, 0.74868200E+01, 0.19511700E+01, -.60108700E+01, -.28267000E+00, 0.55786700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.78382800E+00, 0.81074900E-01, 0.17003100E+01, 0.75940700E-01, 0.65468300E+00, -.29060900E-01, 0.73078300E+00, 0.32813600E+00, -.21026800E+01, 0.34449000E-01, -.52864300E-01, 0.63427000E-01, 0.87047400E+00, 0.48480900E+00, 0.96865300E+00, -.22653100E-01, -.63441800E-01, -.88847100E-01, 0.40947800E-01, 0.28430000E+00, 0.82221000E+00, 0.45898700E-01, -.18116500E+00, 0.40595500E+00, 0.20589500E-01, -.28313100E-01, 0.50490900E+00, -.20390600E-01, 0.26286900E+00, -.32751000E+00, -.23149100E+00, -.38919100E+00, 0.22082500E+00, 0.25241200E+00, 0.38992400E+00, 0.35933400E+00, 0.28987500E-01, 0.70275100E+00, -.24513700E+00, -.23389900E+00, 0.59584700E+00, 0.21666200E+00, 0.15688000E+00, 0.99825200E-01, 0.12494800E+00, 0.22443100E+00, 0.21742800E-02, 0.19843100E-02, -.84682800E-01, 0.33659700E+00, -.15695200E+00, -.55703900E+00, 0.59809100E-02, -.16238900E+00, -.61622600E-01, 0.19225800E+00, -.34969800E-01, -.91450100E+00, -.31231500E-02, 0.46367600E-01, -.15819500E-01, 0.19419900E-01, -.13717300E+00, -.47168800E+00, -.36802100E+00, 0.11022300E+00, -.64150900E-01, -.90545100E+00, -.16773900E+00, -.13565700E+00, 0.45281200E+00, -.55796900E+00, 0.14582800E+00, 0.16444000E+00, 0.12565800E+00, -.81608300E-01, -.44793700E-01, -.84703500E-01, 0.22353800E+00, -.22939300E-02, 0.12075500E+00, 0.12505500E+00, 0.58664100E-01, 0.75647900E+00, 0.69496900E+00, -.19979100E+00, 0.22270500E+00, 0.16830200E+00, -.11162700E+00, 0.68632200E-01, 0.48119200E-01, 0.36171600E-01, 0.85276100E+00, 0.10333200E+00, 0.18330300E+00, -.18715300E+00, -.19090300E+00, -.17780800E+00, -.35495800E-01, -.24514400E+00, 0.53537300E-01, 0.63763900E-01, -.31987300E-03, -.66536800E+00, 0.31527100E-01, -.11191600E+00, 0.97224800E-02, -.14184200E+00, 0.11637400E+00, -.11563500E-02, -.25958600E+00, -.82139800E-01, -.60730700E-01, -.72143500E-03, 0.30254700E-01, -.19955400E-01, 0.66498800E-01, -.11381100E+00, -.58017500E-01, -.64061600E-02, 0.46329600E-01, -.56902500E+00, -.38863200E+00, -.69714300E-01, -.36135600E-02, 0.10628600E+00, -.37666500E-01, 0.10218700E+00, 0.25889300E+00, 0.33188800E+00, 0.12864500E+00, 0.71096100E-02, -.39949500E-01, 0.81526900E-01, -.19452500E-01, -.21473600E-01, 0.25293000E+00, 0.15028200E+00, -.23502100E+00, -.22721100E-01, 0.62709400E+00, -.20788000E-01, 0.75954400E-01, -.45740100E-01, -.15932400E+00, 0.62383300E-01, -.55441700E-02, 0.50980200E-01, -.78048000E-01, 0.97509000E-01, 0.73875300E-01, 0.89323700E-01, -.21222000E+00, -.66978200E-01, 0.26111200E+00, 0.36283600E-01, -.27352500E+00, -.45618400E-02, 0.66540000E-01, -.91812300E-01, -.10147500E+00, 0.84803100E-01, 0.12054300E+00, 0.16954400E+00, -.21887200E+00, 0.12000400E+00, -.45921400E+00, 0.19043500E+00, 0.13709000E-02, 0.38696900E-01, 0.22372900E+00, -.12572400E+00, -.24486800E+00, -.63873900E+00, 0.17168900E+00, 0.33287500E+00, 0.45729100E-01, -.69722400E-03, -.24967500E-01, -.11785500E-01, 0.11446100E+00, 0.35976400E-01, 0.15298400E+00, -.45070400E-01, 0.67207000E-01, 0.82124100E+00, -.45056400E+00, 0.12939100E+00, -.63552500E-01, -.54861600E-02, 0.32457000E-02, -.12822800E+00, -.16396100E+00, -.15167000E+00, 0.23872000E+00, -.29870700E-01, 0.50141900E+00, -.15774000E-01, -.18987600E-02, -.53020400E+00, -.58805200E-01, -.10771700E-01, -.74151500E-01, 0.18712700E+00, 0.72266400E+00, 0.26865800E+00, -.76464700E-01, -.60335800E-01, -.56264500E-01, 0.31209900E-01, -.14073400E-01, -.52843100E+00, -.90973100E-03, -.25271200E+00, 0.14371900E+00, 0.14781800E+00, 0.28449400E+00, -.84425600E-01, 0.13423900E+00, 0.30249200E-01, 0.24628500E-01, 0.57346900E-01, 0.14921400E+00, 0.19442600E-02, 0.55450600E-01, 0.34668600E-01, 0.22776000E+00, -.28079300E+00, -.34186000E-01, -.23367300E+00, -.26744600E+00, -.10678600E+03, 0.53432500E+02, 0.37581500E+02, 0.53461400E+02, 0.47980000E+01, -.52457500E+01, 0.27673400E+02, -.20852400E+02, 0.37053700E+02, -.20094000E+01, 0.32054800E+02, 0.22056400E+02, -.11032100E+02, -.13372600E+02, -.10955800E+02, -.99681400E+01, -.40806200E+01, -.43682000E+01, 0.72898800E+01, 0.53146900E+01, -.42924600E+01, -.11293800E+02, 0.61055800E+01, -.26716100E+01, 0.18328000E+00, -.29857600E+01, -.95530100E+01, -.89582400E+01, -.13470800E+01, 0.52032300E+01, 0.79378600E+01, -.78367500E+01, -.16025200E+02, 0.10151100E+01, 0.25329900E+00, 0.98304900E+01, 0.72330200E+01, -.15583900E+01, 0.11113500E+00, 0.18782700E+00, 0.70653200E+01, -.98402600E+01, -.33156400E+00, 0.21281800E+01, -.60357700E+01, 0.80719300E+00, -.60031500E+01, -.22016800E+01, 0.68793700E+01, 0.22005900E+01, -.67716700E+00, -.22546200E+01, 0.43973500E+00, 0.19765000E+01, 0.68686700E+00, -.96443400E-02, -.16529900E+01, -.58726000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10298500E+01, 0.19481800E+00, -.62435700E+00, -.18412800E+01, -.60159800E+00, 0.22690900E+00, 0.17502500E+01, 0.16154500E+01, -.42508700E+00, -.33612200E+00, 0.86749400E-03, -.12150600E+01, 0.10038200E+01, 0.90257300E-01, 0.10588100E+01, 0.61633100E+00, 0.46530100E-01, -.51247300E+00, 0.31401800E+00, -.11588500E+00, -.10299300E+01, 0.13000000E-01, 0.29439500E-01, -.20477300E+00, -.55478700E-01, 0.13839200E+00, -.44404500E+00, -.26404800E+00, -.18548100E+00, 0.41420900E+00, -.52647800E+00, 0.19827300E+00, 0.10033300E+01, -.72248200E+00, 0.94873100E+00, 0.20168300E+01, 0.93713700E-01, 0.19375200E+01, -.12804900E+01, 0.69654900E+00, -.71638000E+00, -.62137700E+00, -.50448000E+00, 0.17937400E-01, 0.49824100E+00, -.15426700E+00, -.80529100E-01, 0.89397400E-02, -.13920000E+00, -.14094600E+00, 0.55081200E+00, 0.20963600E+01, -.14030200E+00, 0.19177100E+00, 0.43265600E+00, 0.24526500E-01, -.63452800E+00, -.38711500E+00, -.81359200E-02, 0.24374100E+00, -.70860200E-01, 0.38747000E+00, -.29518500E+00, 0.12761600E+01, -.22403100E+01, 0.10184800E+00, 0.13499500E-01, 0.29217000E+01, 0.16475900E+01, -.15487000E-01, -.91034600E+00, -.85139700E+00, -.94172400E-01, 0.13716100E-01, 0.10806100E+00, -.28896100E+00, -.18492400E-01, -.21525200E+00, -.71456800E-01, -.94073200E-01, 0.55312700E-01, -.34999900E-01, -.58089600E+00, -.17101100E+01, -.91980500E+00, 0.42299000E+00, -.14727600E+00, -.46031000E+00, 0.11247000E+00, -.10872800E+00, -.76962000E+00, 0.77616600E-01, 0.45385000E+00, 0.12663700E+00, 0.15371800E+01, -.14393700E+01, -.16142100E+01, -.61746400E-01, -.23247800E+00, 0.16345400E+01, 0.23078500E+00, 0.39962400E+00, 0.20672800E-01, -.96604400E+00, -.91293300E+00, -.16122800E+00, 0.22788300E+00, 0.12884200E+01, -.78322800E+00, -.73121400E-01, 0.34385700E+00, 0.29749400E+00, 0.37498000E+00, 0.56931400E-02, 0.51104800E-02, 0.23278800E+00, -.59554800E+00, 0.12670500E+01, -.11467500E+01, 0.38540300E+00, -.21045100E+00, 0.18468900E+01, 0.45352200E+01, -.72695000E+00, -.13667300E-01, 0.73250600E+00, -.57978100E+00, 0.27493300E+00, -.31090900E+00, 0.45976400E+00, 0.11668600E-01, 0.30400000E+00, -.20358700E+00, -.10613300E+00, -.50582500E+00, 0.68602000E-01, 0.15912800E+01, 0.39026500E-01, -.55435800E+00, -.19636000E+00, 0.84108600E+00, 0.12865200E+00, 0.25417000E+00, 0.20246600E-01, -.19033000E+00, 0.39465000E+00, 0.23220600E-01, -.13668500E-01, 0.44591300E+00, 0.30669900E+00, -.33264500E-01, -.29233600E+00, 0.21139800E+00, -.13169900E+00, 0.32628700E+00, -.63141900E-01, 0.23972200E+00, 0.12480000E-01, -.11152300E+00, -.10905600E+01, -.53612900E-01, 0.39767400E+00, 0.96775900E-01, -.88521400E-01, 0.36882900E+00, 0.10949900E+00, 0.38564500E+00, 0.36003700E+00, 0.18277900E-01, 0.10018300E+00, 0.65269100E-01, 0.86403800E+00, 0.22490900E+00, 0.12658700E+01, -.23948300E+00, -.57143800E+00, 0.42804800E-02, -.10869000E-01, -.58668800E+00, -.40304200E-02, -.15458200E+00, -.10840400E+00, -.13469000E+00, 0.26909900E-01, -.13801400E+00, -.10021200E+01, 0.11887900E+00, 0.52081800E+00, -.63750800E-01, -.21650900E+00, -.23682600E-02, 0.30703000E-02, 0.30229500E+00, -.23556200E+00, -.88962100E-01, 0.53553000E-01, 0.17803500E+00, 0.22204000E+00, -.44848800E+00, -.84264800E-01, 0.86528200E-01, -.30857600E-01, 0.68307100E-02, -.62102100E+00, -.11258100E+01, 0.68605200E+00, 0.61359100E-01, 0.36293400E+00, 0.50750800E-01, 0.16851500E+00, -.14193900E+00, -.18676900E+00, 0.32055600E-02, -.86286500E+00, -.63626100E-01, 0.15966600E-01, 0.47086400E-01, -.26570600E+00, -.21812700E+00, -.11874800E-01, -.20827400E+00, 0.18506800E+00, -.27835000E-01, -.12184600E-02, -.14367300E+00, 0.38167000E-01, -.26050900E-01, 0.14640400E+00, -.44294200E-01, -.67974000E+00, 0.68743800E-01, 0.21317800E+00, 0.24819000E+01, 0.70816200E+01, -.17261700E+00, 0.15575400E+02, 0.34247400E+02, -.88485300E+01, -.35711400E+01, -.19058700E+02, 0.35147600E+02, -.10424900E+03, -.11339900E+02, 0.50569900E+01, -.40889800E+00, 0.57489200E+01, -.13159900E+02, -.17043300E+02, 0.31812900E+02, 0.12992200E+02, 0.10255200E+02, -.16413400E+02, -.35570100E+02, 0.53794400E+02, -.30807700E+02, -.16147500E+02, -.27092200E+02, 0.24619100E+02, 0.18778200E+02, -.10760900E+02, -.14636000E+02, -.34953500E+02, 0.28443600E+02, -.63737200E+02, -.10371700E+02, 0.11448700E+01, -.62712400E+01, -.17442000E+01, 0.66885500E-01, 0.28504300E+01, 0.31731000E+01, -.13279100E+01, 0.61943200E+01, -.49072000E+01, 0.27315300E+01, -.12776200E+01, -.84901500E+01, -.13287900E+01, 0.49891400E+01, -.14434600E+01, 0.25570700E+01, 0.12355800E+01, 0.49033200E+01, -.82218500E+01, 0.33887000E+01, -.22917800E+01, -.47221000E+01, 0.51795600E+01, 0.17175500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26185200E+01, -.70802300E+00, 0.48890200E+01, -.59889300E+00, 0.31729800E+01, 0.29328600E+00, 0.16370800E+01, 0.19196800E+01, -.65546400E+01, -.13793500E+01, -.17760400E+00, 0.23524100E+01, 0.13079900E+01, -.96352200E+00, 0.30776100E+01, -.95415300E+00, -.10381700E+01, -.87543500E+00, -.26329600E+00, -.16496600E+01, -.13562100E+00, 0.12290300E+00, -.11965200E+01, 0.19184900E+00, -.35861200E-01, 0.22659900E+00, 0.79606900E+00, -.39651600E+00, 0.79670000E+00, 0.13108800E+01, -.18310700E+00, -.23068000E+00, 0.19912900E+00, 0.13243800E+01, -.35038500E+00, -.11117000E+01, -.39960900E-01, 0.72082300E+00, -.25452100E+00, -.75176400E+00, 0.12330800E+01, -.15124300E-01, 0.17970600E+00, -.23283900E+00, 0.68090600E+00, 0.77546400E+00, 0.74974400E+00, -.13141700E-01, 0.16223600E+01, -.15497900E+01, -.10678500E+01, 0.70638500E+00, -.21824400E+00, 0.48002900E+00, 0.79698300E-01, 0.18694200E+00, 0.17311700E+01, 0.35965100E+01, -.26140900E-01, -.75736100E+00, 0.46758300E+00, 0.45691100E+00, -.10510200E+00, -.92557700E+00, -.40013600E+00, 0.26852200E+00, 0.12480600E+00, 0.91721900E+00, 0.73726500E+00, -.47192700E-01, -.50780400E+00, -.13616600E+01, -.36812700E+00, 0.90993200E-01, -.49173300E+00, 0.12179900E+01, -.19863900E+00, -.19715900E+01, -.17594000E+00, 0.16515100E-01, 0.25683500E+00, 0.17468900E+00, -.35969500E+00, -.31463900E+00, 0.12299700E+01, -.18944700E+01, 0.33476300E+00, 0.68655000E+00, 0.35425900E+00, -.13851900E+01, 0.20348600E+01, 0.20458900E-01, 0.43660500E+00, -.41434500E+00, -.10792100E+01, -.66954300E-02, -.45972900E+00, 0.11233200E+01, 0.26543700E+00, -.49853200E+00, 0.13514000E-01, 0.48677400E+00, -.10577600E-01, -.25208900E+00, 0.11510000E+00, 0.22066500E+00, 0.11268700E+00, 0.51652400E+00, 0.64237400E+00, -.35631000E+00, 0.18495600E+01, 0.21957800E+00, -.16457700E+00, -.22867800E-02, 0.10830400E+00, 0.89088900E-01, 0.40588400E+01, 0.42799800E+00, 0.46093600E+00, -.62354700E+00, -.66409300E+00, -.13316700E+01, -.61177300E+00, -.16011800E+00, 0.24731000E-02, -.39856700E+00, -.35500500E+00, 0.42586000E+00, -.15136900E+01, -.63609600E+00, 0.17898400E+01, -.30432500E+00, 0.24950100E-01, 0.50582400E+00, 0.55454800E+00, -.66154800E-01, -.73602100E+00, -.26474700E+00, -.25631200E+00, -.11879000E+00, 0.93937500E-01, 0.34999900E+00, 0.26530900E+00, 0.25496700E+00, 0.61907900E+00, -.71593900E-01, -.24077100E-01, 0.27936600E+00, -.87803800E+00, -.44182100E+00, -.38613600E+00, -.36312000E+00, -.14977400E+00, -.29976800E+00, -.26696400E+00, -.17547300E-01, 0.67499900E-01, -.24188300E-02, 0.12381000E+00, 0.38372700E+00, 0.68292200E-01, -.26401500E+00, 0.34785400E+00, -.57333300E-01, 0.17059600E+00, -.35038100E+00, -.96444800E+00, -.59706000E+00, 0.25000300E-01, -.29853000E+00, 0.26949400E+00, 0.48318900E+00, -.77266900E+00, 0.87914100E+00, 0.19597900E+00, -.16119700E+00, -.58090100E-01, 0.51626200E-01, 0.94508300E+00, 0.60044100E-01, -.15751500E+01, 0.28465700E+00, 0.17317100E+00, 0.37372600E-01, 0.23155900E-03, 0.18748600E+01, -.58743000E+00, 0.10096400E+00, -.17527300E+00, -.60442800E+00, 0.13468200E-01, 0.18187600E+00, -.14913700E+01, 0.10354100E+01, -.50421800E+00, -.24301000E+00, -.13768600E+01, 0.71858500E-01, 0.35998900E+00, 0.16993100E+01, -.42118700E-02, -.18217900E-01, -.30906100E-01, 0.36332900E+00, 0.10254500E+01, 0.61365900E+00, -.11592100E+00, -.36527300E+00, -.42740000E-01, 0.33247800E-02, 0.19504500E+00, 0.22058800E+01, -.55697500E-03, -.12214300E+01, -.12466000E+00, -.31643800E+00, -.65264600E+00, 0.40954900E+00, -.11471000E+00, -.78838000E-01, -.34879300E-01, -.20671100E+00, -.81291000E-01, 0.34656300E-02, -.10131500E+00, -.31111900E-01, -.38705100E-01, 0.23881700E+00, 0.19366500E+00, 0.12268800E+01, 0.33245200E+00, 0.31520000E+00, 0.12612300E+00, 0.43837000E+02, 0.16985200E-01, -.27650200E+01, -.19743700E+02, -.20480600E+02, -.11386200E+02, 0.17904100E+02, -.12878200E+02, 0.65097100E+02, -.38901500E+02, 0.19174200E+02, 0.18591900E+02, 0.19159600E+02, 0.15070000E+02, 0.96345200E+01, -.66079000E+01, 0.26017300E-01, 0.32877300E+02, 0.14333000E+02, 0.81748500E+02, 0.19777200E+02, -.90799500E+01, -.14856400E+02, -.98306400E+01, 0.76824300E+01, -.57510000E+01, -.29438000E+01, 0.80274500E+00, -.28059500E+02, -.11977800E+02, -.40224600E+02, 0.47887500E+01, 0.19104000E+00, -.12519300E+02, -.12710200E+02, 0.84671800E+01, -.23744200E+01, -.24150500E+01, -.12421600E+02, 0.12284100E+02, 0.23383600E+01, -.30739000E+01, 0.11322600E+02, 0.84952000E+01, 0.11539100E+02, 0.14570400E+02, -.12365600E+02, -.28045700E+01, 0.10758300E+01, 0.14611200E+02, 0.93358500E+01, -.27999100E+01, 0.25869200E+00, -.44564000E+01, 0.66746000E+01, -.32057300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.29329500E+01, -.55469800E+00, 0.11274500E+01, -.43868700E+01, -.94383600E+00, 0.27563400E+00, 0.38676400E+01, 0.57454500E+01, -.42633700E+01, -.15799000E+01, -.19165000E+00, -.38606800E+01, 0.49060700E+01, 0.12267600E+00, 0.52802000E+01, 0.27402400E+01, 0.12951900E+01, -.21793700E+01, -.44075700E-01, -.12601300E+01, 0.63887700E+00, 0.31993800E+00, -.13622800E+01, 0.16379300E+01, -.21997400E+00, -.54378400E+00, -.41379100E+00, -.43403300E+00, 0.47943400E+00, 0.13354300E+01, -.36340500E+00, -.65931500E-01, -.13183800E+00, 0.29697300E-02, -.38642200E-01, -.14778000E+01, -.89503300E-01, 0.11311900E+01, 0.41020500E+00, -.18299500E+01, 0.16930800E+01, -.33578000E+00, 0.42792400E+00, -.10166300E+00, 0.12825400E+01, 0.74918000E+00, 0.89683800E+00, -.18017800E-01, 0.22585600E+01, -.23185700E+01, -.14501600E+01, -.35017600E+01, -.37020500E+00, -.20745000E+01, -.33701400E+00, 0.45664100E+00, 0.22833200E+01, 0.41462800E+01, -.72337600E-01, -.11478600E+01, 0.33617200E+00, 0.41953200E+00, 0.33793100E+00, -.18763100E+01, -.45775100E+00, -.90291600E-01, 0.25565200E-01, 0.35992000E+00, 0.71853400E+00, 0.36089300E+00, -.22548600E+01, -.91828400E+00, 0.74852500E-01, 0.11701800E+01, 0.44925800E+00, -.47958300E-01, -.28094600E+00, -.15194900E+01, -.66031300E-01, 0.23665700E-01, -.62143200E-02, 0.65399700E+00, -.80047200E+00, -.10230400E+01, -.57813100E-01, -.92202400E+00, 0.49274900E+00, -.23343500E+00, 0.42846200E+00, -.13982900E+01, 0.10467400E+01, -.25454900E+00, 0.45760000E+00, -.38648400E+00, -.12658500E+01, 0.98990100E+00, -.26749500E+01, -.42378300E+00, -.45831500E+00, -.91641100E+00, 0.15121000E-01, -.45607600E+00, -.14260400E-01, -.34169700E+01, 0.68970300E+00, -.27358700E-01, 0.16329600E+00, -.14098200E+01, -.24674900E+00, -.42231400E+00, 0.28409900E+01, 0.65876300E+00, 0.69526100E-02, -.59221400E-02, 0.95005000E-01, 0.41810700E+00, 0.22566800E+01, 0.99823500E+00, -.13534500E+00, -.37563800E+00, -.35746600E+00, -.27477700E+01, 0.11536500E+01, -.22663700E+00, -.27625600E-01, -.58700300E+00, -.12133500E+01, 0.99560300E+00, -.71840900E+00, -.19614100E-01, 0.14733700E+01, -.29934900E+00, 0.59360000E+00, 0.44590000E+00, -.19991800E+00, -.16266200E+00, -.37538600E+00, 0.33580800E+00, -.11052500E+01, -.12541300E+00, 0.80304700E+00, 0.18064300E+00, 0.35102800E+00, 0.48348900E+00, 0.34048200E+00, -.41180100E+00, -.29044000E-01, 0.48408600E+00, 0.11332200E+01, 0.26545500E+00, 0.95930900E-01, -.75373500E-01, 0.95659500E-01, -.13051000E+00, 0.48792400E+00, 0.22529000E-01, 0.49670200E-01, 0.27937400E+00, 0.40965900E-01, -.18363000E+00, -.25763800E-02, -.63356200E+00, 0.41752400E+00, -.30121100E+00, 0.98325200E-01, -.45481200E+00, -.16825000E+00, -.44961400E+00, 0.18883300E+00, -.22685400E+00, -.48373700E-01, 0.12835000E+01, -.35544400E+00, 0.15460700E+01, -.15675300E+00, -.77381700E+00, -.11555500E-01, -.21878200E-01, 0.93169900E+00, 0.14392900E+00, -.15518300E+01, -.13169800E-01, 0.56543400E+00, 0.21577500E-01, 0.33974100E-01, 0.18025600E+01, -.91496300E+00, -.69594100E+00, -.27661200E+00, -.25728000E+00, 0.19652800E-01, 0.19941400E+00, -.11363600E+01, 0.60916900E-01, -.51952000E+00, -.22532400E+00, -.35615400E+00, 0.13744400E+01, -.74947400E+00, 0.76044100E+00, -.12008000E+00, 0.24171900E+00, -.93441500E-01, -.59578100E+00, -.64765700E+00, 0.10364500E+01, 0.10554300E+00, -.10172000E+00, -.26450000E+00, 0.98271300E-01, -.59607000E-01, -.11982300E+00, -.51342300E-01, -.48260300E+00, -.65677100E-01, -.22243600E-01, -.49074000E+00, 0.64550500E+00, 0.15663400E+00, -.11606400E+00, 0.13023100E+00, -.26428200E-01, -.28808300E+00, 0.18223300E-01, -.83706500E-01, 0.63404800E-01, -.80903500E+00, -.45778600E+00, 0.13610500E+00, 0.11312200E+01, 0.73224700E+00, 0.20901300E+00, -.11930600E+01, 0.45068000E+00, 0.63949800E+01, 0.57557300E+02, 0.21677000E+02, -.34146800E+02, -.37415100E+01, 0.77197400E+01, 0.13764600E+02, -.20137000E+03, 0.11922200E+03, -.59980400E+02, -.66875100E+02, -.60526000E+02, -.10905600E+02, -.67343700E+02, 0.25868300E+02, 0.72846000E+02, 0.66197200E+02, -.86095700E+02, -.66742400E+02, -.27148000E+02, 0.15424800E+02, 0.41565300E+02, 0.13853900E+02, 0.12153600E+02, 0.32163900E+02, -.24567300E+00, -.70311000E+01, 0.55672800E+01, 0.53943900E+02, -.11419600E+03, 0.60738600E+01, 0.53227800E+01, -.13098900E+02, -.78406500E+01, 0.42665300E+01, 0.39446700E+01, 0.40542800E+01, -.74711700E+01, 0.12995800E+02, 0.52797300E+01, 0.40147100E+01, 0.47488900E+01, 0.85922600E-01, 0.41418100E+01, 0.12514100E+02, -.76741100E+01, 0.40903100E+01, -.72063400E+01, 0.12545600E+02, 0.14778600E-01, 0.50585300E+01, 0.63483600E+01, -.45229000E+01, 0.38660100E+01, -.75939800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.39592000E+01, -.23576200E+01, 0.42628700E-01, -.16159700E+01, 0.47873500E+00, -.21504400E+00, 0.93496500E+00, -.71282300E+00, -.36467400E+01, -.59545800E-01, -.59817900E+00, 0.13160500E+02, -.23129900E+01, -.29256500E+01, 0.84928800E+01, -.76679700E+01, -.60791700E+01, -.30626900E+00, 0.22710800E+01, -.23825800E+01, 0.88301400E+00, -.12248700E+00, -.26466400E+01, -.56134300E+00, 0.19038700E+00, 0.88933200E+00, -.27268200E+01, 0.22362100E-01, -.43641700E+00, -.19234200E+01, -.13298800E+01, 0.79003600E+00, 0.23693300E+01, -.24580900E+01, 0.24178700E+00, -.56692400E+00, 0.90267200E-01, -.28653500E+01, 0.11945600E+01, 0.39851100E+01, -.21910200E+01, 0.45925600E+00, -.23426800E+01, -.47148400E-01, -.25841200E+00, 0.11029900E+01, -.76433500E+00, 0.21535400E-01, -.17170300E+01, -.64211300E+00, -.27280500E+01, 0.25222700E+01, -.79112000E+00, -.76419400E+00, 0.33071900E+00, -.11260500E+00, 0.49162900E+00, 0.26192400E+01, -.72284000E-01, 0.29890800E+00, 0.17011400E+00, -.19929600E+00, 0.34812800E+00, -.68631600E+00, 0.24777100E+01, -.35034200E-01, 0.13658000E+00, -.21851100E+01, -.87440000E+00, 0.70571000E-01, -.51280000E+00, 0.14607600E+01, 0.91841500E+00, 0.24805300E+01, 0.13456200E+01, -.19632000E+01, -.19650900E+00, -.28772000E+01, 0.64823600E+00, 0.59964500E+00, 0.40036600E+00, 0.19553300E+01, 0.26604200E+01, 0.47554100E+01, 0.19619500E+01, 0.98823400E+00, 0.95273300E-01, -.56145300E+00, 0.31561900E+00, 0.45513900E+00, 0.95596700E-01, -.44519300E+00, -.75305400E+00, 0.78432300E+00, 0.18089300E+01, -.81399900E+00, -.25235300E+01, -.52004400E+01, -.24513300E+00, -.13263700E+01, 0.79410100E-01, -.54311200E+00, -.95564700E-02, -.64165600E+01, -.81550900E+00, -.16050800E+01, 0.39289700E+00, -.21099900E+01, -.12891800E+01, 0.47628500E+00, 0.70461300E+01, 0.43455300E-01, -.82037600E+00, -.27495200E-03, 0.72126600E-01, 0.49150200E+00, -.32470600E+00, 0.26545500E+01, -.55471300E+01, -.96337800E+00, 0.24226900E+01, -.78310000E+01, 0.20234900E+01, -.58012400E+00, -.45978600E-01, 0.48613600E+00, -.96835100E+00, -.23126500E+00, 0.22578500E+01, 0.35139200E+00, -.11169500E+01, -.37048400E+00, -.10594800E+01, -.61065000E+00, 0.34876000E+00, -.16491500E+00, -.21214400E+01, 0.22118300E+00, 0.75207300E+00, 0.47829900E+00, -.23877100E+01, -.37833700E+00, -.12383800E+00, -.51386800E+00, -.10092100E-01, 0.72296400E+00, -.80071500E-01, -.17166700E+00, 0.11432500E+00, -.37796200E+00, -.38696600E-01, -.58224700E+00, -.31749100E+00, 0.75410400E+00, 0.22541300E+01, -.21481900E+00, 0.41438300E+01, 0.27750300E+00, -.17070000E+00, 0.14207800E+01, 0.11393700E+01, -.11799200E+01, 0.10358900E+01, -.89539200E-01, -.67872900E+00, 0.94127200E-01, -.24089500E+01, 0.15355400E+01, 0.20709200E+00, 0.19646500E+00, 0.11757700E+01, 0.16799500E+00, -.22818800E+01, 0.10396700E+01, 0.22238700E+00, -.66488300E+00, -.55116900E-01, 0.21470200E+00, 0.20655100E+01, 0.77545900E-01, -.40390900E+01, 0.13101800E+01, -.13607300E+01, -.56280800E-01, -.34059600E+00, 0.33774200E+00, 0.28307900E+00, -.54029600E+00, -.24622800E-02, 0.13576100E+01, 0.14971900E-02, -.70012900E-02, -.10601500E+01, 0.61396200E+00, -.49442300E+00, -.26316400E+00, -.44094300E-01, -.12911600E+01, -.36074600E+00, 0.24346700E+01, 0.85436200E-01, -.11997200E-01, 0.71704400E+00, 0.63752300E+00, 0.43559400E+00, -.10537200E+01, -.58285000E-01, 0.13114100E+00, 0.17281400E+00, -.54797100E+00, -.31557300E+00, 0.30629200E+00, -.36917000E-02, -.24203100E+00, -.33500600E+00, 0.27956000E+00, 0.33845500E+00, 0.19946300E+00, 0.10135800E+00, -.31937000E-01, 0.59836900E+00, 0.10535300E+00, 0.41680800E-01, 0.44042800E-02, -.33238800E+00, 0.47188400E+00, 0.25681100E+01, 0.63322800E+00, -.33713200E+00, -.48858300E+00, -.17570500E+01, -.98159800E+00, 0.10268400E+01, -.27708900E+00, -.10980900E+00, -.21257100E+03, -.35706600E+02, 0.38855400E+02, 0.19177700E+02, -.20841800E+02, -.20133700E+02, 0.27803300E+03, -.17367300E+03, 0.87843800E+02, 0.62522000E+02, 0.87927600E+02, -.94502200E+02, 0.50487200E+02, -.14560800E+02, -.85675800E+02, -.11778300E+03, 0.84556000E+02, 0.30857600E+03, 0.16283600E+03, -.84978000E+02, -.78375700E+02, -.81488500E+02, 0.54037500E+02, -.26720700E+02, -.41417600E+02, -.68976200E+01, -.44770900E+02, -.48831200E+02, -.13574900E+03, -.25762900E+02, -.26301200E+01, 0.47534300E+02, 0.45217900E+02, -.17959600E+02, 0.75807900E+01, 0.41940200E+01, 0.44332100E+02, -.46881200E+02, -.17670100E+02, -.70428100E-01, -.41900000E+02, -.70231000E+01, -.41230400E+02, -.17866800E+02, 0.43933000E+02, -.10316800E+01, 0.11550600E+02, -.17949700E+02, -.89729400E+01, 0.30489900E+00, -.13673300E+02, 0.13378500E+02, -.72755200E+01, 0.14945700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19725900E+01, -.28776600E+00, 0.54569600E+00, -.35957600E+01, 0.10372900E+00, 0.41317300E+00, 0.30235500E+01, 0.16956500E+01, -.66806900E+01, -.16720400E+01, -.15996900E+00, 0.15407700E+01, -.53594500E+00, -.16386900E+01, 0.20350000E+01, -.10787900E+01, -.66729400E+00, 0.13912900E+00, 0.28742900E+00, 0.80846100E+00, 0.12253400E+01, 0.14019600E+00, -.98769100E+00, 0.13430800E+01, -.24578600E-01, 0.10338600E+00, 0.26346700E+01, -.24641200E+00, 0.79205200E+00, -.93582500E+00, 0.82519400E+00, -.67302600E+00, -.48100900E+00, 0.26697600E+01, -.11266800E+01, -.28935700E+01, -.94809500E-01, -.74260000E+00, 0.88258800E+00, -.91756300E+00, 0.15867000E+01, 0.57884800E+00, 0.69893500E+00, 0.29346000E+00, -.28740600E+00, -.24693400E+00, 0.30047500E+00, -.85104000E-02, 0.14627000E+01, -.51648700E+00, 0.55919400E-01, -.16557200E+01, 0.13683500E+00, -.65008100E-01, -.20191600E+00, 0.28096000E+00, 0.95958000E+00, 0.21119400E+00, 0.55944600E-01, -.42341500E+00, 0.11128500E+00, 0.16566700E+00, 0.34830300E-01, -.12787800E+01, 0.23268600E+00, 0.12294100E+00, -.72152800E-01, -.81406100E+00, 0.15537300E+00, -.21586100E+00, 0.35980500E+00, -.10298800E+01, -.34145900E+00, -.36220200E+00, -.59921500E+00, 0.93010400E+00, -.19181500E-01, -.48323800E+00, 0.62856600E-01, -.19014000E+00, 0.18659700E+00, 0.11511400E+00, -.31559800E+00, 0.19129000E+00, -.10031100E+00, -.57407900E+00, 0.96889400E-01, 0.78224400E+00, 0.21990700E+00, -.75702600E+00, 0.34052000E+01, 0.10488500E+00, 0.20356000E+01, -.62802400E+00, -.55934700E+00, -.12218200E+01, 0.13379600E+01, 0.24099900E+00, 0.57917000E+00, -.38024200E+00, -.11114800E+00, -.33338000E+00, 0.44526400E-03, 0.35309500E+01, -.55725400E+00, 0.25446800E+00, -.52209500E+00, 0.24774700E+00, 0.63713100E+00, -.42558700E-01, -.14120600E+01, -.51483000E+00, -.65355800E+00, -.35699800E-02, 0.24008400E+00, -.15239300E+00, 0.40006000E+01, 0.11419000E+01, -.53076400E+00, -.23443800E-01, -.82672100E-01, -.68988000E+01, -.38784800E+01, 0.16128900E+00, 0.12087500E-02, -.56848200E+00, -.45080700E+00, 0.57955300E+00, -.14792400E+01, -.22190800E+00, 0.16521800E+01, 0.59893200E-03, 0.75603700E-01, -.56890500E-01, 0.16563000E+01, -.65176000E-01, 0.37121600E-01, -.17919300E+00, -.89343200E-01, 0.34824100E-01, 0.46952600E+00, 0.11147200E+00, 0.14613600E+00, 0.43906000E+00, 0.71451700E+00, -.63709200E+00, -.16053900E-01, 0.34119700E+00, 0.97424200E+00, 0.12910700E+00, 0.25209500E+00, 0.65589900E-01, 0.34963500E+00, -.35522600E+00, 0.80831200E+00, -.22869100E-02, 0.44173000E+00, 0.10890800E+00, 0.10202800E+00, 0.89758900E-01, 0.45200900E-01, -.58837800E+00, -.68770700E+00, -.56790700E+00, -.69097100E+00, 0.77881800E-01, 0.82253000E-02, -.17270000E+00, -.33056400E-01, -.21145200E+00, -.96013800E-02, -.12476800E+01, -.53968800E+00, -.69349600E+00, -.11010800E+00, -.13992200E+00, -.78374400E-02, 0.24406100E-01, 0.55766800E-01, 0.43352300E-02, 0.27422900E+00, -.45578500E+00, 0.28118900E+00, 0.39210100E-01, -.28469000E+00, 0.72041500E+00, -.12422700E+01, 0.83694400E+00, -.13239600E+00, -.11776200E+01, 0.23944400E-02, 0.17212100E-02, -.47216100E+00, -.20865100E+00, 0.98922000E-01, 0.16801000E+00, -.18511700E+01, -.10406400E+01, 0.69965500E+00, -.33849800E-01, -.34814200E-01, -.36455000E-02, 0.16754700E+00, 0.64624000E+00, -.12951400E+00, 0.12468900E+00, 0.85382000E-01, -.60900100E+00, 0.38350600E+00, -.43472200E+00, 0.29117400E+00, -.85058700E+00, -.16854400E-01, -.80764000E+00, 0.95887800E-01, -.28565200E+00, -.71249500E+00, 0.10375700E+00, -.17281800E+00, -.33332600E-01, -.23340900E+00, -.19863800E+00, -.45699700E-02, 0.78204400E-02, 0.16498500E+00, -.50954300E-03, -.11168100E+01, -.32841600E-01, 0.14059900E+00, 0.12690900E+01, -.16512500E+00, 0.51229600E+00, 0.61313100E+00, -.16217200E+00, 0.85397200E-01, 0.29005000E+00, -.77012200E+02, 0.85113900E+01, -.12464500E+02, 0.30003500E+02, -.73382400E+02, 0.20815300E+03, 0.11136700E+03, -.56225600E+02, -.42006100E+02, -.56304900E+02, 0.16451400E+02, -.13999600E+02, -.39060300E+02, 0.36759100E+02, 0.48785000E+02, -.25682900E+02, -.53699300E+02, -.12177100E+03, 0.62205500E+02, 0.25648900E+02, 0.61418800E+02, -.53960200E+02, -.14691000E+02, 0.48352600E+02, 0.45548600E+02, 0.62259100E+02, -.20001500E+02, 0.16274400E+03, 0.27198500E+02, 0.10602500E+01, -.11525900E+02, -.17071700E+02, 0.20012500E+02, -.56787900E+01, -.50402300E+01, -.17328900E+02, 0.11379100E+02, 0.14256000E+02, -.15286700E+01, 0.22337800E+02, 0.18125000E+02, 0.22560000E+02, 0.26657000E+02, -.17231200E+02, -.69901200E+00, -.58690100E+01, 0.26808300E+02, 0.17805000E+02, -.15453700E+01, 0.10354500E+02, -.16636100E+02, -.47577000E+01, -.10607500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.51595800E+01, -.94561600E+00, -.57414100E-01, 0.36563000E+01, -.59123100E+00, -.30804100E+00, -.32180800E+01, -.13084800E+01, 0.83486400E+01, 0.15882400E+01, 0.41165900E+00, -.24971900E+01, 0.38472400E+00, 0.34193700E+01, -.41988600E+01, 0.23319800E+01, 0.22036900E+01, 0.46093000E+00, 0.13430200E+01, 0.10191500E+01, -.20695500E+01, 0.23850400E+00, 0.11523900E+01, 0.20677700E+01, -.28210500E+00, 0.13563100E+00, -.96243400E+00, -.45352900E+00, 0.15686700E+00, 0.12182000E+01, 0.11569400E+01, -.14649600E+01, -.35992700E+00, 0.85484400E+00, -.99521300E+00, -.10535000E+01, -.12062500E-01, 0.21565200E+01, -.58116900E+00, -.20631100E+01, 0.11726800E+01, -.35596300E+00, 0.12156700E+01, 0.34860200E+00, 0.11154100E+01, -.15414900E+00, -.93007900E+00, 0.12738400E-02, 0.11797800E+01, 0.50816500E+00, 0.11574500E+01, 0.31950600E+01, -.93607200E-01, 0.34645300E+00, 0.67339900E+00, 0.17998800E+01, -.36208600E+00, -.30620500E+01, 0.36417100E+00, 0.76318100E+00, -.18594500E+00, 0.19507300E+00, -.69488400E+00, -.60538900E+01, 0.37165200E+01, 0.86504500E+00, -.17004600E+00, -.44857800E+01, -.19497900E+01, -.27060800E+00, -.29602400E+00, -.17214800E+01, -.19557900E+01, -.72413800E+00, -.12016500E+01, 0.20557200E+01, -.23503500E+00, -.26209700E+01, 0.45079400E+00, -.80373600E+00, 0.25791300E+00, -.15403600E+01, 0.12116000E+01, 0.42141700E+01, -.75920800E+00, -.14067800E+01, 0.96665000E+00, 0.20892200E+01, -.55675900E+00, 0.80584100E+00, 0.31859900E+01, 0.61496000E-01, 0.10773500E+01, -.14072400E+01, 0.83995400E+00, -.24113700E+01, -.89819500E+00, 0.46563600E+01, 0.64903000E+00, 0.31777700E+01, -.59997200E+00, -.11743600E+01, 0.25389200E-01, 0.76552700E+01, 0.78117500E+00, 0.31277100E+00, 0.26572300E+00, 0.19090000E+01, -.35726300E+00, -.10674100E+01, -.48769200E+01, -.61028500E+00, -.49223000E+00, -.64609500E-03, 0.82654500E+00, 0.42687100E-01, -.13095900E+01, 0.68963100E+00, 0.28809200E+00, 0.13051400E+01, 0.24182500E+00, -.85488000E+01, -.37118900E+01, -.13865200E+01, -.27380700E-01, 0.77985700E+00, 0.83173400E+00, -.29184700E+00, -.73357800E+00, 0.19432400E+01, -.19902500E+01, -.37718900E-01, -.82023700E+00, -.10784300E+01, -.53147300E+00, -.82614500E-01, 0.27608900E+01, 0.97193100E+00, -.78790600E+00, -.13988100E+00, 0.26465300E+01, -.12599800E+01, 0.73264700E+00, 0.54092700E+00, -.47718400E+00, 0.60491500E+00, -.58531300E-01, 0.45843800E+00, 0.91362300E+00, -.10592700E+01, -.25474300E+00, -.23965400E+01, -.80464400E+00, -.90780900E-01, 0.12467700E+01, 0.15029200E+00, -.20429800E+01, 0.46802000E+00, -.94420600E+00, 0.29386900E+00, -.48885400E-01, 0.62564600E+00, -.18955300E+01, 0.67642200E-01, -.12704200E+00, 0.81122800E+00, 0.28335800E+01, 0.16030800E+01, -.41083300E-01, 0.74146800E+00, -.19622400E+01, 0.37751500E+00, 0.20588400E+01, 0.10412500E+00, 0.42542400E+00, 0.19901800E+01, 0.72974100E-01, 0.40033600E+00, -.10072600E+01, 0.44506100E-01, 0.67409500E+01, -.12516000E+00, 0.40414100E+00, -.47009400E-01, -.64644700E-02, -.32260800E+01, 0.86786400E+00, -.17370300E+01, 0.34977000E+00, 0.12484000E+01, 0.54138800E-02, -.23251400E+00, 0.27885600E+01, -.46647100E+00, 0.14134900E+00, 0.12106600E+00, 0.52138300E+00, 0.18236000E+01, -.58337800E+00, -.17314000E+01, 0.27228100E+00, 0.27156500E+00, 0.99980900E-01, -.29200900E+01, -.42952000E+01, -.20225800E+01, -.10847400E+00, 0.40860000E-01, 0.14096200E+00, -.11926600E+01, 0.56070000E+00, 0.45830400E+01, -.18127500E-01, -.37007900E-01, -.95498000E+00, -.42258500E+00, 0.21266800E+00, -.40067400E+00, 0.16034900E+00, 0.54022000E+00, -.15729700E+00, -.63861500E+00, 0.32771600E+00, 0.98868800E-02, -.48989800E+00, 0.44052900E-01, -.13362100E+01, 0.74854000E+00, -.53611600E-01, -.65311000E+00, -.15628000E+01, 0.34307400E+01, 0.24830100E+01, -.69577400E+00, 0.32299400E-01, 0.97229300E+00, 0.45545500E+00, -.15470800E+03, -.10071100E+03, 0.56449800E+02, -.13721900E+02, 0.24088000E+03, 0.61653200E+02, -.28325900E+02, 0.24307100E+02, -.30437000E+02, 0.12258000E+03, 0.44970300E+02, -.13079700E+03, -.38963800E+02, 0.13683300E+03, 0.40722400E+02, -.95970200E+02, -.45958700E+03, 0.21934600E+03, 0.14902700E+03, 0.22990300E+03, -.10566400E+03, 0.11958500E+03, 0.13035500E+03, -.33150000E+02, 0.55682100E+02, 0.12439600E+03, 0.42272300E+03, 0.54125300E+02, 0.11817600E+02, -.42037600E+02, -.41273000E+02, 0.44639900E+02, -.35478700E+01, -.56360100E+01, -.41487400E+02, 0.42319500E+02, 0.39875300E+02, 0.30595600E+01, 0.43710100E+02, 0.19657100E+02, 0.44957500E+02, 0.13022500E+01, -.40830700E+02, 0.55052800E+01, -.16416300E+02, 0.87020100E+00, 0.18899500E+02, 0.11330300E+01, 0.22986700E+02, -.11242500E+02, 0.31257400E+02, -.17698500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14954000E+01, 0.88850000E-01, 0.38931900E+00, -.24905000E+01, 0.31022800E+00, 0.32640900E+00, 0.16016200E+01, 0.13334900E+01, -.43409300E+01, -.11672800E+01, -.34996500E-01, 0.28450200E+00, -.18697200E+00, -.10301800E+01, 0.18190100E+01, -.59710200E+00, -.45278400E+00, -.14212300E+00, 0.60565200E+00, 0.32096200E+00, -.85342400E+00, 0.10093400E+00, -.27386900E+00, 0.15498500E+01, 0.72489300E-02, 0.31228200E-01, 0.14715600E+01, -.41061700E+00, 0.65396300E+00, -.76227900E+00, 0.88980000E+00, -.11497300E+01, -.40136500E+00, 0.29522500E+01, -.13516100E+01, -.45249300E+01, -.14831800E+00, 0.23174400E-01, 0.74238700E+00, -.11606400E+01, 0.21222200E+01, 0.74180200E+00, 0.61401500E+00, 0.28428600E+00, -.33221900E+00, 0.15055400E+00, 0.40802900E+00, -.19983200E-01, 0.17986500E+01, -.11318900E+01, -.58650400E+00, -.23632900E+01, 0.58041900E-01, -.35167800E+00, 0.12132500E+00, 0.75737700E+00, 0.17513600E+01, 0.99211200E+00, 0.47422700E-01, 0.58817900E+00, 0.40580000E+00, 0.41929200E+00, 0.20977800E+00, -.38219200E+01, 0.30272800E+01, 0.29055700E-01, 0.12618700E+00, -.18359700E+01, -.10477300E+01, -.32091200E+00, -.13628400E+01, -.45262000E+00, -.71663200E+00, 0.21046400E+00, -.44458300E+00, 0.19786100E+00, -.22541000E+00, -.17682700E+01, -.11191900E+00, -.61934800E+00, 0.30910500E+00, -.62375500E-01, 0.91724700E+00, 0.30079100E+01, 0.84814100E+00, -.77950700E+00, 0.53716500E+00, 0.84162500E+00, -.22115300E+00, -.12220500E+00, 0.20613900E+01, 0.75409300E-01, 0.32518900E+00, -.36210800E+00, -.17827000E+01, 0.94068900E+00, 0.15767800E+01, 0.12093700E+01, 0.51376700E+00, 0.37505400E+00, -.70985900E+00, -.24260700E+00, 0.11359600E-01, 0.22535300E+01, 0.62527000E+00, -.11997000E+00, -.18454900E+00, 0.10927400E+01, 0.42398900E+00, 0.11935500E+00, 0.48773800E+00, 0.53691200E+00, 0.19213900E+00, -.16173200E-02, 0.81077400E-01, 0.41925500E-01, 0.45909100E+00, -.21139800E+00, -.52876500E+00, -.30501500E+00, 0.40789500E-01, -.30104800E+01, -.15125600E+01, 0.86926100E+00, -.23621100E-01, -.11863800E+00, 0.43206000E+00, 0.61747000E+00, -.23709600E+00, -.74042200E-02, -.73987400E+00, 0.40347900E+00, 0.29643100E+00, -.94474800E-01, 0.41197500E+00, -.13245700E-01, 0.80982200E+00, -.38605400E-01, -.89927000E+00, -.35662200E+00, 0.77628300E+00, -.18353400E+00, 0.24583200E+00, 0.41008800E+00, 0.31130000E+00, -.38084000E+00, 0.11955100E-01, 0.17530700E+00, 0.15647400E+01, 0.51535800E+00, 0.33204300E+00, 0.41822900E-01, 0.33050900E+00, -.31493500E+00, 0.48378900E+00, -.11104400E-01, 0.25505700E+00, 0.63287900E-01, 0.25042700E+00, 0.36534500E+00, 0.40338200E-01, 0.18477500E+00, 0.80771900E+00, -.36955700E-02, -.44221900E+00, -.10270200E+00, -.10720700E+01, -.75337800E+00, 0.46658800E-01, -.16804900E+00, -.11446600E+00, 0.10991000E+01, -.71197800E-01, 0.20739600E+01, 0.35685500E-01, -.81829900E+00, -.49358800E-01, 0.16596500E+00, 0.12283200E+00, 0.40450200E-01, -.60850300E+00, 0.30597300E+00, 0.19860400E+00, -.11873000E+00, -.35519500E+00, -.18883600E+00, -.33808600E+00, 0.81938600E-01, -.24141700E+00, -.11798500E+00, -.73937100E-02, 0.79658100E-01, -.78129200E+00, -.15855600E+00, -.20421700E+00, -.18853400E+00, 0.43223900E+00, 0.75547700E+00, -.57070600E+00, -.39231900E-01, -.58722200E-01, -.10158400E+00, 0.41214600E-01, 0.52594200E+00, -.11745900E+00, 0.14227400E+00, 0.30677300E-01, 0.37403300E-01, 0.20557100E+00, -.17246500E+00, -.27707900E+00, -.18852100E+01, 0.59786300E-02, -.64859500E+00, 0.18930400E+00, 0.23160500E+00, -.60560100E-01, 0.59382100E-01, -.38957000E-01, -.19089100E+00, -.56727800E-01, 0.26595600E+00, -.44065200E+00, -.98047600E-02, -.36399300E-02, 0.13010300E+00, -.12384500E+01, -.12210000E+00, -.57998700E-01, 0.47901500E+00, 0.23403500E+00, -.89154700E+00, -.26179900E+00, -.48562900E+00, 0.60352300E-02, -.19001400E+00, 0.21162100E+00, 0.55879900E-01, 0.40771500E+02, 0.31917600E+02, -.45005300E+01, -.11677100E+03, 0.88027300E+00, -.10302600E+01, -.61802200E+01, -.50016500E+00, -.22296300E+02, -.21195500E+02, 0.96462200E+01, 0.17080000E+02, -.12977500E+02, -.19506800E+02, 0.67645300E+02, 0.10191600E+03, -.49530900E+02, -.33812400E+02, -.51221900E+02, 0.46754900E+02, -.39885200E+00, -.40987600E+02, -.15418100E+02, -.30409800E+02, 0.27110500E+01, -.15344900E+03, -.12134700E+02, 0.12543200E+01, 0.19060500E+02, 0.18768500E+02, -.82141500E+01, 0.97102100E+01, 0.84067400E+01, 0.18791900E+02, -.19021400E+02, -.67919200E+01, 0.56228000E+01, -.20298500E+02, -.61529200E+01, -.20569400E+02, -.84410600E+01, 0.18668700E+02, 0.48647400E+01, 0.95981700E+00, -.82556100E+01, -.65154000E+01, 0.51123300E+01, -.31238500E+01, 0.10744500E+02, -.54934300E+00, 0.18262900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.41743200E+01, -.42427100E+00, -.53280100E+01, 0.24300800E+01, -.52994500E+01, -.80070400E+00, -.17815800E+01, -.18512700E+01, 0.10421900E+02, 0.23680300E+01, 0.31830100E+00, -.35112700E+01, 0.76601000E+00, 0.26415100E+01, -.34162700E+01, 0.27330100E+01, 0.18537400E+01, -.45562900E+00, 0.64104300E-01, -.52384400E+00, -.38789700E+01, 0.54573800E-01, 0.65715100E+00, -.20098500E+01, -.16838600E+00, -.38003300E+00, -.14562600E+01, 0.13909300E+00, -.94192200E+00, -.26869700E+00, -.78203600E+00, 0.15084200E+01, -.14688400E+00, 0.27417700E+00, 0.10652500E+01, 0.28721600E+01, 0.39632100E+00, 0.33498400E+00, -.11122200E+01, -.19669100E+00, -.23869300E+01, -.10699000E+01, -.51875600E-02, -.35436100E+00, -.80849100E+00, -.73351800E-01, -.17499100E+01, -.38086500E-01, -.29779600E+01, 0.16283000E+00, 0.16082200E+01, -.21147900E+01, 0.99949200E-01, -.63490200E+00, 0.95448000E+00, -.17589800E+01, -.23486800E+01, 0.68887900E+01, 0.15295000E+00, 0.40182900E+00, 0.62980400E+00, -.70767100E+00, -.35327500E+00, 0.97652900E-01, 0.47719800E+01, 0.50669300E+00, -.45509000E-02, 0.70310400E+00, -.10888000E+01, 0.57838200E-02, 0.61040800E+01, 0.38411800E+01, 0.38402500E+00, -.32591900E+00, -.64939600E+00, 0.20824100E+01, 0.31983400E+00, 0.18607300E+01, 0.78214000E+00, 0.90199800E+00, 0.70442700E-01, 0.11570900E+01, -.75003100E-01, 0.83458600E+00, 0.30631600E+01, 0.25333700E+00, -.46408600E-02, 0.96734900E+00, 0.70049000E+00, -.21100500E+01, 0.13376500E+01, -.98653500E-01, 0.15862200E+00, -.17574400E+01, -.94185700E+00, 0.19782500E+01, 0.22998000E+01, -.16415700E+01, 0.37103700E+00, -.54972200E+01, -.78134900E-01, -.64912700E+00, -.73149600E-02, 0.76438300E+00, -.16060500E-01, 0.13210500E+01, 0.94915300E+00, 0.25868700E-01, 0.13907700E+01, -.15050300E+01, -.29255200E+00, 0.67297500E+00, 0.10587000E+01, 0.34951000E-02, 0.20092800E+00, 0.37837600E+00, 0.28157800E+01, 0.29836500E+01, -.51947500E+01, -.23044000E+01, 0.31876000E+01, -.32559000E+01, 0.82233300E+00, 0.10953100E+01, 0.45070200E-02, 0.30764000E+00, 0.28627600E+00, 0.13682000E+01, -.32459900E+01, 0.13145100E+01, -.15216100E+01, 0.12375200E+01, 0.25647000E+00, -.12054600E+01, -.34112300E+00, 0.25275700E+00, 0.39755700E+01, -.63130200E+00, -.13395100E+01, -.12475300E+01, -.27442400E+01, 0.92546100E-01, 0.66425700E+00, -.44688800E+00, 0.72301200E+00, 0.61231400E+00, 0.64964900E-01, 0.46508600E+00, 0.99940100E+00, 0.74338100E+00, 0.68509300E-02, -.11175500E+01, 0.62518500E+00, -.12240700E+00, -.75547200E+00, 0.24231300E-02, 0.71815100E+00, -.24772600E+00, -.14494600E+00, -.67776500E+00, 0.15857300E+00, -.22082800E+01, -.38298000E+00, -.91139600E+00, -.81594300E+00, -.22294500E+00, 0.10154300E+00, 0.18904000E+01, 0.20609100E+00, 0.19614900E+00, 0.22203700E+01, -.45959600E-01, -.42372900E+01, -.76316000E+00, -.52810100E+00, -.15788400E+01, 0.25275700E-01, -.82582600E+00, -.11267600E+01, -.21053900E+00, -.19792100E+01, -.73041200E+00, -.10668700E+01, 0.81709900E+00, -.67445300E+00, -.14805600E+01, -.80858500E+00, -.16191700E+01, 0.10380000E+00, -.13705000E+01, -.58982700E-01, 0.51442000E-01, 0.35085900E+00, -.21829000E+01, -.27587900E+00, 0.27530900E+00, -.10482100E+01, -.58251500E+00, 0.15340800E+01, -.26425900E+00, -.20741000E+00, 0.24474200E-01, 0.88731900E-01, -.21076900E+01, -.14280900E+01, -.15145600E+01, -.47355900E-01, 0.76986900E+00, 0.50390200E+00, -.89063400E+00, -.40478400E+00, -.32464500E+01, 0.29033400E-01, 0.11553900E+01, -.22104800E-01, -.19706600E+00, 0.54630300E-01, -.39859400E+00, -.24347400E+00, -.40756000E+00, -.35525500E+00, 0.28783600E+00, -.95368300E+00, -.16630700E-01, 0.31335200E+00, -.14888600E+00, -.21654200E+01, 0.14032200E+00, -.18334900E+00, 0.30552800E+01, -.23074700E+01, -.12859800E+01, -.45122900E+00, 0.27322200E+00, -.77526000E-01, 0.34381800E+00, -.15372400E+01, -.12116100E+00, 0.67874700E-01, -.10901400E+03, 0.22209700E+02, 0.36708400E+03, 0.11362200E+03, -.56641400E+02, -.42831800E+02, -.56757600E+02, -.39241500E+02, -.26425900E+02, 0.77406500E+01, 0.35553400E+02, -.16268200E+03, -.39384100E+02, -.39188300E+03, -.17664900E+02, 0.12550200E+02, -.19462400E+02, 0.10039500E+02, -.51700300E+02, -.53706400E+02, 0.18068700E+02, 0.10752500E+03, 0.11600100E+03, -.10820600E+03, 0.53653500E+03, -.28274000E+00, -.13323900E+02, -.31789000E+02, -.31075000E+02, 0.29711100E+00, -.10421700E+01, -.29643700E+01, -.30413300E+02, 0.32247700E+02, -.37138600E+01, -.79682900E+00, 0.38065200E+02, 0.38111100E+01, 0.38804400E+02, 0.12318200E+02, -.30194300E+02, -.13869400E+01, 0.72380800E+01, 0.11728600E+02, 0.19911400E+01, -.54652400E-02, -.29120600E+01, -.22273300E+02, -.53479000E+02, 0.21861000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34406600E+01, 0.21282600E+01, 0.51341300E+01, 0.20698300E+01, 0.37454500E+01, 0.18684300E+00, -.13768000E+01, 0.16434500E+01, 0.11385600E+00, 0.33096500E+00, 0.44837500E+00, 0.19399100E+01, 0.82025900E+00, 0.35644000E+01, -.90043200E+00, 0.25416800E+01, -.65746800E+00, -.10197000E+01, 0.56976600E+00, -.17906200E+01, -.35751400E+01, 0.14734300E+00, 0.68754300E+00, -.35889500E+01, -.46188500E+00, -.28448800E+00, -.10856600E+01, -.53371900E+00, -.65644700E+00, -.54863000E+00, 0.81487100E+00, 0.43576800E+00, -.10229300E+01, 0.19882900E+01, -.76453400E+00, -.24919400E+01, -.14013900E+00, -.10077600E+01, 0.27128400E+00, -.10546500E+01, 0.86040900E+00, -.75339200E-01, -.28877700E+00, 0.21938600E+00, -.12258500E+01, -.24045600E+00, 0.41588000E+00, -.24378200E-01, 0.17361900E+01, -.25433900E+01, -.35163500E+01, -.42479500E+01, -.28278100E+00, -.12595100E+01, 0.82942600E-01, 0.41588600E+00, 0.16736300E+01, 0.66204100E+01, -.52861700E-02, -.23685200E+00, 0.29027300E+00, -.46556000E+00, 0.17802600E+00, -.45375100E+01, 0.35578100E+01, 0.27279900E+00, -.48494500E+00, -.35551200E+01, -.10540500E+01, -.13734000E-01, 0.94042200E-01, 0.15801400E+00, -.12550700E+01, -.52795700E+00, -.12829800E+01, 0.28115900E+01, -.13387700E-01, -.20577200E+01, 0.44807200E+00, -.37409300E+00, -.29849500E-01, -.21365300E+00, -.35438100E+00, 0.44118300E+00, -.32949700E-01, 0.38571900E+00, 0.70071500E-01, 0.62625400E+00, 0.65285500E+00, -.13136800E+01, 0.32418900E+01, -.23381900E-01, 0.18619000E+01, -.17202800E+01, -.10571200E+01, -.95610000E+00, 0.20863800E+01, 0.55247200E+00, 0.12111900E+01, 0.18287900E+01, -.64659700E-01, 0.64896000E-01, -.34306900E-02, 0.57237400E+01, -.12126200E+01, 0.67372700E+00, 0.29670200E+00, 0.22936900E+01, -.17826200E+00, -.10524800E+00, -.20835800E+01, -.23722100E+00, 0.54458500E+00, -.68405600E-03, -.15937700E+00, -.34166500E+00, -.21712900E+01, 0.52934900E+00, 0.17697400E+00, 0.93730400E+00, 0.20212600E+00, 0.31063500E+01, 0.12232400E+01, 0.75417500E+00, 0.78594000E-02, 0.92791000E-01, 0.50537900E+00, -.28787000E-01, -.19030200E+01, -.62497800E+00, 0.86957000E+00, -.63757100E-01, -.55852500E+00, -.78191700E-02, 0.12869700E+01, -.50990800E-04, 0.48455200E+00, -.43173700E+00, 0.56176000E-01, -.44356100E+00, -.10366100E+01, 0.37940000E+00, 0.78853100E+00, -.32136600E+00, -.42149900E+00, -.20400100E+00, -.56306100E-02, 0.52079600E+00, -.83383200E+00, 0.52837200E+00, -.61901300E+00, -.30130000E+00, 0.50740800E-01, -.27872500E+00, -.13008900E+00, 0.27143600E+00, -.28674300E+01, 0.33603300E-03, -.29644600E+00, 0.61451300E+00, -.28728300E+00, 0.13327200E+01, -.24413800E+01, 0.23121200E+00, -.34025100E+00, -.60875900E-02, -.29977800E+00, -.12882200E+01, 0.33291600E-01, 0.60026600E-01, -.85320000E+00, -.54345800E+00, 0.11465700E+01, -.91700900E-01, 0.29961400E+00, 0.98673900E+00, 0.21429300E+00, 0.34390100E+00, -.13692700E+01, 0.47821100E+00, 0.46961000E+01, -.28888500E+00, 0.15324000E+01, -.63873000E-02, 0.44351500E+00, 0.47885000E+00, -.11524600E+01, -.66882600E+00, 0.30138200E+00, 0.15182700E+01, 0.27364600E-01, -.12076800E+00, 0.74639100E+00, 0.52575300E+00, -.48115500E-01, 0.85243000E-01, -.75487500E+00, 0.11453300E+01, 0.31738200E-01, 0.77370500E+00, 0.41421300E+00, 0.41463200E+00, -.13277800E+00, -.19360300E+01, -.44605500E+01, -.22299400E+01, 0.12200000E+00, -.39825700E+00, -.17297800E+00, -.79052900E+00, 0.27356900E+00, 0.64765700E+01, -.39051900E-01, -.29708600E+00, -.42035000E+00, -.35285200E+00, 0.50477200E+00, 0.87280200E-01, 0.30335000E+00, -.66589800E-01, 0.85109000E+00, -.66482000E+00, 0.57511200E+00, 0.19184500E-01, -.22577800E+00, 0.50125000E+00, 0.34278500E+01, 0.89341200E+00, -.74807900E-01, -.21848500E+01, 0.13895300E+00, -.29969900E+01, -.17388900E+01, -.42726400E+00, -.35220800E-01, 0.87350200E-01, -.84563500E+00, 0.82346200E-02, -.18134900E+01, -.69890100E+00, 0.38473500E+02, -.74048400E+02, 0.20079100E+03, -.10064400E+03, -.10355000E+03, -.10051500E+03, -.64187400E+02, -.75092100E+02, -.55744100E+02, 0.91749600E+02, -.67317100E+01, -.83048000E+02, 0.20293000E+02, 0.96546600E+02, -.43607100E+02, -.85312700E+02, -.47873900E+02, 0.29916700E+01, -.44046700E+02, -.40423400E+01, 0.47541000E+02, 0.82683400E+01, -.42478600E+02, 0.67757400E+02, -.66401300E+00, 0.41627200E+01, 0.31636800E+02, 0.26753900E+02, 0.30563000E+02, 0.20584200E+02, 0.19782700E+02, 0.27132100E+02, -.31293300E+02, -.29093500E+01, 0.33327200E+02, -.20635600E+02, 0.17883400E+01, -.19887800E+02, 0.41675000E+02, 0.26907400E+02, 0.32631800E+02, -.29107900E+01, 0.40985800E+02, -.35496900E+00, 0.32809000E+02, 0.67329000E+01, -.47034900E+02, -.14943300E+02, -.53036300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20125600E+01, 0.18143500E+00, 0.32227500E+01, -.10385100E+01, 0.29881600E+01, 0.41305700E+00, 0.97900800E+00, 0.12080500E+01, -.55210100E+01, -.12174900E+01, -.17422800E+00, 0.15543300E+01, -.54287300E-01, -.13748500E+01, 0.19067700E+01, -.11139400E+01, -.79303800E+00, 0.15033500E+00, -.18895700E+00, 0.16949700E+00, 0.21325300E+01, -.19843700E-01, -.31779000E+00, 0.89286800E+00, 0.75204100E-01, 0.18010200E+00, 0.86592200E+00, -.73088300E-01, 0.66811300E+00, 0.16727400E+00, 0.33035200E+00, -.10267800E+01, 0.29216500E+00, 0.71072700E+00, -.61350700E+00, -.89362700E+00, -.12811900E-01, 0.44666100E-01, -.83034300E-02, 0.99851600E+00, 0.49087300E+00, 0.50860700E+00, -.42868700E+00, 0.33416300E-01, 0.25618600E+00, 0.19622600E+00, 0.67724400E+00, -.27939500E-02, 0.10566400E+01, 0.13566800E+00, -.30995000E+00, 0.24439000E+01, 0.40306100E-01, 0.89731100E+00, -.35923800E+00, 0.63510400E+00, 0.68507000E+00, -.28284400E+01, -.62849200E-02, 0.32808100E-01, -.27560000E+00, 0.29178800E+00, 0.17433200E+00, 0.58086800E+00, -.14121300E+01, -.28505800E+00, 0.13473000E+00, 0.90372800E+00, 0.55835600E+00, 0.12239600E+00, -.29409200E+01, -.10633000E+01, -.32871100E+00, 0.72975000E-01, 0.36370400E+00, -.12070700E+01, -.10827500E+00, -.48331900E+00, -.52329200E+00, -.27335400E+00, 0.16873100E-01, -.21469200E+00, 0.35557300E+00, -.21968000E+00, -.12729500E+01, 0.40114700E+00, -.29963600E+00, -.48816900E+00, -.28918100E+00, 0.63906200E+00, -.81072100E+00, 0.15319200E+00, -.22922700E+00, 0.11460000E+01, 0.68641200E+00, -.12280300E+01, -.63385600E+00, 0.48231600E+00, -.18974900E+00, 0.27082100E+01, -.19760100E-01, 0.49376200E+00, 0.15937600E-01, -.44817200E+00, 0.17110600E+00, -.71374900E+00, -.50748000E+00, -.27642900E+00, -.80781700E+00, 0.79367900E+00, 0.85122200E-01, -.13109100E+00, -.42775600E+00, 0.46927800E-03, -.39525100E-01, -.10586000E+00, -.24351500E+01, -.15992600E+01, 0.20434300E+01, 0.11857300E+01, -.15742500E+01, 0.18358600E+01, -.84132200E+00, 0.16890500E+00, 0.68765000E-02, -.35070600E+00, -.31689600E+00, -.78893800E-01, 0.44623300E+00, -.28898400E+00, 0.11116000E+01, -.15312900E+00, 0.33482700E+00, 0.18165400E+00, -.56310800E+00, -.39729100E-01, -.63645800E+00, 0.32094100E+00, -.59310800E-01, 0.23279100E+00, 0.72584200E+00, -.19093600E-01, -.62008400E-01, 0.23026700E+00, -.20089900E+00, -.11006000E+00, -.34989700E-02, -.12567200E+00, -.22262600E+00, -.10564300E-01, -.13890400E-01, 0.34891100E+00, 0.24757300E-01, -.16293300E+00, 0.12106800E+00, -.27787900E-01, -.37753300E+00, 0.26303300E-01, 0.26179000E+00, 0.45056300E+00, -.38001100E-01, 0.51634200E+00, 0.43103500E+00, 0.50416100E+00, -.46005100E+00, 0.31562600E+00, -.10247700E+01, -.15999200E+00, -.27509100E-01, -.22273400E-03, 0.91280100E-01, -.21735500E+00, 0.52517800E+00, -.36940900E+00, 0.32316300E+00, 0.73309600E+00, 0.67431900E-01, 0.28835400E+00, -.97977100E+00, 0.21419300E-01, 0.10944300E+00, 0.11322800E-01, 0.87132300E-01, -.41554500E-02, -.51241800E-01, 0.42801000E-01, 0.81723200E+00, 0.13762700E+01, -.67380500E-01, -.33653000E+00, 0.97513800E-02, -.18020900E+00, 0.37858900E+00, 0.17323900E+00, 0.24899100E+00, -.42780100E-01, 0.21600100E+00, -.43626700E+00, 0.40371200E+00, -.94471900E+00, -.93706400E-01, -.46106400E-01, -.30038800E-01, 0.61135800E+00, 0.17549200E+01, 0.91128700E+00, -.51820600E-01, 0.96002800E-01, 0.85714400E-01, -.10000200E-01, 0.12873300E+00, 0.55822000E+00, -.50795000E-02, -.44610100E+00, -.24661300E+00, -.18252200E+00, 0.25563600E-02, -.30222200E+00, -.26451100E+00, 0.21842200E+00, 0.54364300E-01, -.11518000E+00, 0.37114400E+00, 0.59891700E-02, -.19494900E+00, 0.16794800E+00, 0.39848900E+00, 0.55829700E+00, 0.23394700E-02, -.11805100E+00, 0.13988600E+00, 0.15226700E+01, 0.19343200E+01, -.71058400E+00, 0.15088300E-01, 0.13518300E+00, 0.63450300E+00, 0.16174900E+00, 0.65002400E+00, -.22906200E+00, -.93607500E-02, 0.21567200E+03, -.12684400E+03, 0.63700100E+02, 0.69917000E+02, 0.63418700E+02, 0.35479000E+02, 0.63368300E+02, 0.24292000E+01, -.47376500E+02, -.10565200E+02, 0.76798800E+02, 0.53186200E+02, 0.11249600E+02, -.65197400E+01, -.34353100E+02, -.52912400E+01, -.24851700E+02, -.29519500E+02, -.50733100E+01, -.53328700E+01, -.13596200E+02, -.56123000E+02, 0.16083400E+03, -.60821900E+00, -.84128500E+01, -.22111700E+02, -.23425900E+02, -.55621700E+00, -.90355600E+01, -.79534000E+01, -.23329400E+02, 0.22109300E+02, -.63183900E+00, -.99287500E+01, 0.23377800E+02, 0.32523900E+01, 0.23881100E+02, -.11990100E+02, -.22898600E+02, -.99084700E+01, 0.69096700E+01, -.12127500E+02, 0.43404600E+01, -.10330900E+02, -.57037600E+01, 0.65229700E+01, 0.84976600E+00, 0.63611500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.78220200E+00, 0.51626500E+00, 0.15858100E+01, -.67832700E+00, 0.84381000E-01, -.25543100E-02, 0.12517600E+01, 0.18826300E+01, -.13044700E+00, 0.67663100E-01, -.88402200E-01, -.38524900E+01, -.21482600E+01, 0.91657900E+00, -.28626100E+01, 0.40286000E+01, 0.22185400E+01, -.35988400E+00, -.32022300E+00, 0.47520700E+00, 0.59466600E+00, -.38319500E-01, 0.47329700E+00, 0.12260600E+01, -.98756800E-01, -.11074200E+00, 0.37719300E+01, -.20925900E+00, 0.65153100E+00, 0.21275400E+01, 0.11517800E+00, -.17015000E+01, 0.87939200E+00, 0.13155800E+00, -.50295500E+00, 0.53040100E+00, -.39599600E-01, 0.16422100E+01, -.99967500E+00, -.68315400E+00, -.10740600E+01, -.62677500E+00, 0.14155900E+01, 0.23450900E+00, -.21503000E+00, -.40701100E+00, 0.22050500E+00, -.15496800E-01, 0.10374700E+01, -.16824700E+01, 0.12937400E-01, 0.38232800E+00, 0.59349100E-01, 0.14719400E+00, -.16620700E-01, -.46415100E-01, 0.27979500E+00, 0.21659000E+00, 0.14840000E-01, -.16967300E-01, 0.11483800E+00, 0.28592000E+00, -.68913300E-01, -.12349400E+00, -.11770200E-01, -.70385900E-01, 0.21636800E+00, 0.35719800E+00, 0.45936500E-01, -.72898200E-01, 0.11147400E+01, 0.84103600E+00, -.14701400E+00, -.56892900E+00, -.54948200E+00, 0.60833000E+00, 0.19583400E+00, -.92016900E-01, 0.18588200E+00, 0.78193600E-01, -.60807700E-01, 0.33059300E+00, -.20893800E+00, -.12370900E+00, 0.39705000E+00, 0.18639300E+00, -.11244900E+00, 0.56680400E-01, -.71898400E-01, -.20925000E+00, -.50553100E-01, 0.12456900E-01, 0.36991100E+00, 0.12753800E+00, 0.18628200E+00, -.23462100E+00, 0.46668300E+00, 0.22117300E+00, 0.14682600E+00, 0.21889100E+00, -.69917600E-01, 0.83743100E-01, -.50964700E-02, -.15719900E-01, -.59171300E+00, 0.66068200E-01, -.62859700E-01, 0.12556100E+00, 0.18592400E+00, 0.67216100E-03, -.98393200E-01, 0.68893800E-01, 0.46169500E-01, -.90599100E-03, -.21900500E-01, -.68054100E-01, -.77849000E+00, -.62712400E-01, -.33395400E+00, 0.10303400E+00, 0.15243200E+00, 0.11255200E+00, 0.10407500E+01, -.23742400E+00, -.13470500E-01, 0.55890600E+00, 0.73099200E-01, -.13337500E+00, 0.53920800E+00, 0.10896200E+00, -.15335600E+00, -.13644300E-01, -.12729700E+00, 0.25137900E+00, 0.22045900E+00, -.22595200E-01, 0.15462700E+00, -.91155000E-01, 0.23702500E-01, -.47550600E-01, 0.30493900E+00, -.19392400E-01, 0.60214300E-01, -.14018600E+00, -.85415500E-01, 0.14840000E+00, -.11986900E-01, 0.58767600E-01, -.23882200E+00, -.31124800E+00, -.21818300E-01, -.63982200E-01, -.37060600E+00, 0.15179400E+00, 0.61370500E+00, -.84422000E-01, 0.54091500E+00, -.32055100E-01, -.33391300E-01, 0.96800200E+00, 0.57613900E-01, 0.10152100E+00, -.15411700E+00, -.22876300E+00, 0.29960600E+00, -.60349800E-01, 0.35889300E+00, 0.53802700E-01, 0.13297600E-01, -.11583600E+00, 0.40951700E-02, 0.33845500E-01, 0.37868300E+00, 0.93575000E+00, 0.25314800E-01, 0.21858400E+00, 0.68323000E-01, 0.21730800E+00, 0.18892400E+00, 0.37617300E-01, 0.28662700E+00, 0.17197400E+00, -.14279600E+00, -.10711300E+00, -.69098100E-01, -.37610000E+00, 0.76705500E+00, -.73790800E+00, -.11496600E-01, 0.24299200E-02, 0.26074300E-02, 0.17182700E+00, -.27726300E+00, 0.40805200E+00, -.20580100E+00, -.53698000E-01, -.10445800E+01, 0.85829100E-02, 0.14378200E+00, 0.39936100E+00, -.19879700E-01, -.31221100E-01, 0.13673000E+00, -.20759200E+00, -.11726800E+00, 0.58188900E+00, 0.82196500E-01, -.85263400E-01, 0.12550300E-01, -.15432000E+00, 0.61972700E-01, -.33165100E+00, 0.26848200E-02, -.45997400E+00, -.65271300E-01, -.12619400E+00, -.23528000E+00, 0.12355500E+00, -.40472700E-01, -.42669300E-01, 0.21830600E+00, -.85974500E-01, 0.21038500E+00, 0.70287000E-05, -.45483400E-02, 0.81128300E-01, 0.72129800E+00, 0.13616500E-01, 0.31247700E-01, -.75858500E+00, 0.22832200E+00, -.19305300E+00, 0.27457500E+00, -.12685500E+00, -.99802900E-02, -.67759400E-01, 0.35735100E+00, 0.55556300E-02, 0.27089800E+00, -.65111500E-01, 0.16424800E+00, 0.13368900E+00, -.52241600E+02, 0.26189700E+02, 0.22780200E+02, 0.26392000E+02, -.12354800E+02, 0.21806200E+02, -.12281700E+02, -.31126300E+02, -.11142900E+02, 0.28544300E+02, 0.89864400E+02, 0.19834100E+02, -.12393100E+02, 0.54628100E+01, -.10181100E+02, -.40450500E+00, 0.11418000E+02, -.25678700E+02, -.26171100E+02, -.15494600E+02, 0.13673200E+02, -.65856400E+02, -.82866500E+00, 0.87884600E+00, 0.95466500E+01, 0.98908000E+01, -.63818100E+01, 0.88372800E-01, -.68652000E+00, 0.94487800E+01, -.93734500E+01, -.26670100E-01, -.15671400E+01, -.99136000E+01, -.74082800E+00, -.98626300E+01, -.10979900E+02, 0.93336100E+01, -.15112200E+01, -.62612900E+00, -.10764300E+02, -.95122800E+00, -.17382900E+01, -.28676900E+00, 0.99752600E+01, 0.25256300E+01, 0.65916000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.26543900E+01, -.32668400E+01, -.47315600E+01, 0.13255500E+01, -.63734700E+01, -.11141700E+01, 0.25216700E+00, -.32538600E+00, 0.73842400E+00, -.36184000E+00, -.18905200E-01, -.92880300E+00, 0.14311900E+01, -.40666700E+00, 0.61650600E+00, -.22954400E+01, -.21150900E-01, 0.11487000E+01, -.20682200E+00, 0.16027600E+01, -.14178900E+01, -.10333900E+00, 0.60135100E+00, 0.11116400E+01, -.85051300E-01, 0.21350900E+00, -.13359000E-01, -.32445300E+00, 0.36736400E+00, 0.99130700E+00, 0.54863800E+00, -.23308900E+00, 0.81187100E+00, 0.64740000E+00, -.34689200E+01, -.34690500E+01, -.16234500E+00, -.49825600E+01, 0.15038400E+01, 0.88193400E+00, -.58545400E+00, 0.16521500E+00, 0.24762400E+00, -.38575700E+00, -.33257800E+00, 0.93795700E+00, 0.76655500E+00, -.21680700E-01, 0.94946100E+00, -.30060500E+01, -.28296600E+01, 0.93016200E+00, -.36479800E+00, 0.16809200E+00, -.11580500E+00, -.40842000E+00, 0.28986900E+01, 0.43274900E+01, -.63871300E-02, -.65207500E+00, 0.88932500E+00, 0.62062300E+00, 0.67008400E+00, -.30753100E+01, 0.31937900E+01, -.40277800E-01, 0.39346200E+00, -.11488400E+01, -.48571300E+00, -.49012700E-01, -.43383600E+00, -.29999800E+00, 0.17815400E+00, 0.66621600E+00, -.35550600E-01, -.27136700E+00, -.27503600E+00, -.18881200E+01, -.25015800E+00, 0.27855800E+00, 0.34344100E+00, 0.56907300E+00, 0.99419100E+00, 0.27341700E+01, 0.19665300E+01, -.21212900E+01, 0.64324800E+00, 0.55515100E+00, -.33165900E+00, 0.21386600E+00, 0.15002000E+01, -.45145700E-01, -.14039900E+01, -.14528600E+00, -.10495000E+01, 0.52336300E+00, 0.19611200E+00, 0.65613400E-01, 0.53926800E+00, 0.37418500E+00, 0.13853800E+00, -.22380900E+00, 0.13377400E-01, 0.43592000E+00, -.11278900E+01, -.47187300E+00, 0.61894800E-01, -.21581700E-02, -.58748000E+00, -.19686800E+00, 0.59275600E+00, -.53753400E+00, -.66570700E+00, 0.70795800E-02, 0.77054600E-01, -.17798400E+00, 0.32339600E+01, 0.17692300E+01, -.13666900E+00, -.19617100E+00, 0.12737500E-01, -.43534700E+00, -.29676400E+01, 0.18782200E+01, 0.14421300E-01, -.61852200E+00, -.44773400E+00, 0.11838500E+01, 0.12236700E+01, 0.27423800E+00, 0.79163300E+00, 0.45069400E+00, 0.12273100E+01, 0.93166700E+00, 0.19769400E+00, 0.55734100E-01, 0.25074800E+00, 0.39729000E-01, -.90819200E+00, 0.61310200E-01, 0.15602600E+01, -.18405100E+00, 0.58916700E-02, -.51429300E-01, 0.30922900E+00, 0.29680400E-01, 0.46489700E-03, 0.10415900E+00, 0.46415900E+00, -.15559900E-02, 0.19251800E-01, -.33729800E+00, 0.44398400E+00, 0.15991300E+00, 0.48108300E+00, 0.82963200E-01, -.48018300E+00, 0.86432900E-01, 0.20956400E+00, 0.11739300E+01, 0.17711400E+00, -.60007400E+00, 0.21135600E-01, 0.33496000E+00, -.52892000E+00, 0.18486100E+00, 0.64881900E+00, -.51743700E-02, -.29016500E-01, 0.38235000E+00, 0.38741100E+00, -.17901300E+01, -.80059300E+00, -.31151500E+01, -.34971800E+00, 0.15918800E+00, -.73849900E-02, -.46501900E+00, 0.23278400E+01, -.48505400E-01, -.19048500E+01, -.20264300E+00, -.57371000E-01, 0.19631000E+00, 0.59469700E+00, 0.24832500E+01, -.53951500E+00, -.10204800E+01, 0.12800900E+00, 0.11678700E+01, 0.10675100E-02, 0.13938400E-01, -.25949900E+00, 0.43369500E+00, -.16447200E+00, 0.22385800E-01, -.94514000E+00, -.52840900E+00, 0.22932900E+00, 0.16463600E+01, 0.19660500E+00, 0.84865100E-01, -.28485900E-01, -.63297100E+00, -.12029300E+01, -.29775200E+00, 0.33518300E-01, -.41536100E+00, -.34362800E+00, 0.12566900E+00, 0.13997600E+00, 0.21805200E+01, -.22707300E-02, 0.14216800E+01, -.95663800E-01, -.73787200E-01, 0.46699500E-01, 0.37483400E-01, 0.32160900E+00, 0.19598500E+00, 0.32886500E+00, -.27787500E+00, -.52939900E-01, 0.12928800E-02, -.25053900E+00, -.31110200E+00, 0.99930800E-02, -.32821900E+00, 0.96206100E-01, -.66674700E+00, 0.15188000E-01, -.36776200E+00, -.88978000E+00, 0.21057200E+00, -.14706200E-01, -.11787800E+00, 0.12239600E-01, 0.45208200E-01, -.15158300E+00, 0.54176500E-01, 0.86026300E-01, -.18929500E+00, 0.13897700E+01, 0.51208500E+01, -.76672400E+01, -.20534900E+00, 0.29542000E+02, -.20069800E+02, 0.19824400E+02, 0.19313800E+02, 0.38827100E+02, -.26351400E+02, -.11494400E+03, -.17703400E+02, 0.98639600E+01, 0.29477600E+01, 0.88981800E+01, 0.17369200E+02, -.23879500E+01, 0.34119800E+02, 0.16498400E+02, -.12805700E+02, -.86434900E+00, -.10567500E+02, -.47663500E+00, 0.18094300E+01, -.52426600E+01, -.50787600E+01, 0.86506200E+01, -.68638400E+00, -.18538100E-01, -.46318800E+01, 0.50079800E+01, -.43436100E+00, 0.18297200E+01, 0.40528800E+01, 0.39625100E+00, 0.38824000E+01, 0.15883800E+02, -.45470400E+01, 0.19048300E+01, -.91625000E+00, 0.15774600E+02, 0.82536500E+00, 0.22377900E+01, 0.10257200E+01, -.11288600E+02, 0.60629100E+01, -.23719500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24336200E+01, 0.23454300E+01, 0.43133300E+01, 0.16238400E+01, 0.36125600E+01, 0.34897200E+00, -.15919600E+01, 0.27717500E+01, 0.60563300E+00, 0.19554200E+00, 0.37905000E+00, -.20437900E+01, 0.38119900E+01, 0.16837600E+01, 0.45198000E+00, 0.32374900E+01, 0.87914400E+00, -.24518000E+01, 0.52491700E+00, -.30232400E+01, 0.20307100E+01, 0.21770000E+00, -.60771200E+00, -.47944100E+01, -.31215100E+00, -.45995300E+00, -.12573200E+01, 0.29454000E+00, -.40416700E+00, -.11371000E+01, 0.20513000E+00, -.29664900E-01, -.15675400E+01, 0.11613000E+01, 0.11966100E+01, -.25245600E+01, -.75192400E-01, 0.14880000E+01, 0.23839400E+00, -.85944000E+00, 0.44436900E+00, 0.19654300E+00, -.46094500E+00, 0.10493400E-01, -.69914900E+00, 0.20466700E+00, -.10122800E+00, -.10928500E-01, 0.11266800E-01, -.37694500E+00, -.23086800E+01, -.34989100E+01, -.40649700E-01, -.82532400E+00, -.44605000E+00, 0.32725100E+00, 0.62687800E+00, 0.31230500E+01, -.23867900E-02, 0.34680700E+00, -.11889300E+00, -.42104300E+00, -.12602800E+00, -.27409100E+01, 0.23049100E+01, 0.20885000E+00, -.43832200E+00, -.23010400E+01, -.13519900E+01, 0.75743600E-01, -.25827000E+01, 0.82756100E+00, -.15606200E+01, -.18542400E+00, -.64026600E+00, 0.13994700E+01, -.20158400E-01, -.13387500E+01, 0.14926200E+00, -.22969600E+00, -.15258000E-01, -.48752200E-01, -.29431900E+00, 0.60198000E+00, 0.70975000E+00, 0.80359800E-01, 0.12814900E+00, 0.48747500E+00, 0.73352600E-01, -.23897800E+00, 0.81168500E+00, 0.70650400E-02, 0.47409500E+00, -.94566400E+00, -.90355600E+00, 0.24287900E+00, 0.19140600E+01, 0.12694000E+01, 0.91518000E+00, 0.91828700E+00, -.24156500E+00, -.20428400E+00, 0.84284500E-04, 0.37080600E+01, -.63468300E+00, 0.29633300E+00, 0.17639400E+00, 0.19420800E+01, 0.58081800E-01, 0.34825300E+00, -.17722700E+01, -.16744000E+00, 0.13381300E+00, -.50354400E-02, -.15699000E+00, -.40042500E+00, -.15795900E+00, -.55762200E+00, 0.92687700E+00, 0.38711900E+00, -.69892300E+00, 0.24516100E+01, 0.61332600E+00, -.58598800E+00, -.63661800E-02, 0.80774000E+00, 0.62373300E+00, -.13514400E+00, -.35188300E+00, -.12429200E+00, -.14511600E-01, -.13082300E+00, -.97414400E+00, 0.10747200E+01, 0.12937800E+01, 0.26641200E-01, 0.10287200E+01, -.69783600E+00, 0.30400500E+00, -.17990400E+00, 0.19733800E+01, 0.32440000E+00, 0.40751500E+00, -.15587900E+00, -.26597300E+00, 0.22232900E+00, -.85152900E-02, 0.33337900E+00, -.20232000E+00, 0.25174100E+00, 0.36469300E-01, -.14892700E+00, -.18037700E+00, -.38473200E+00, 0.25568700E-01, 0.21812500E+00, -.18019400E+01, 0.69685400E-02, 0.16713800E+00, 0.12092500E+00, -.39961300E+00, 0.54674300E+00, -.65719200E+00, 0.33070200E+00, -.20629900E-01, -.75607900E-01, 0.58317600E+00, 0.65022200E+00, 0.64703700E-01, 0.17336400E+00, -.45072500E+00, 0.12967700E+01, 0.52032400E+00, 0.17084500E+01, 0.29557600E+00, 0.20560500E+00, 0.21336400E+00, 0.16329600E+00, -.19783400E+01, 0.46628400E-01, 0.26086200E+01, 0.83349100E-01, 0.70059800E+00, -.48725300E-01, -.12890200E+00, -.27241700E+00, -.13859200E+01, 0.56943200E+00, -.11902900E+00, -.20857600E+00, 0.21672400E-01, -.16013200E+00, -.17692100E+00, 0.17524900E+00, 0.33262700E+00, 0.20236500E-01, -.14259800E+01, 0.49859400E-01, 0.80234500E+00, -.11996500E+01, -.14082000E+00, 0.10246500E+00, 0.28255600E-01, -.53020300E+00, -.77360400E+00, 0.98547200E+00, 0.23460800E+00, -.75968700E-01, 0.30866800E-01, -.15942600E+00, -.87481400E-01, -.71610600E+00, -.20583000E-01, -.64353000E-01, 0.10982100E+00, 0.97721400E-02, 0.32199700E+00, -.43212900E+00, -.31340900E-01, -.89107100E-01, 0.50046300E+00, -.15952900E+00, -.10523800E+00, 0.42188200E+00, 0.26077100E+00, -.29060700E+00, 0.10044200E+01, -.54575900E+00, 0.79027200E-02, -.29035200E+01, 0.49925200E+00, -.14385500E+01, -.18659200E+01, -.10266700E-01, 0.58468700E-02, -.19887500E+00, -.34223400E+00, -.14015900E+00, 0.60072100E-02, -.31247300E+00, 0.26111700E+00, 0.33090500E+00, -.22733800E+01, 0.28029800E-01, 0.26589600E+02, 0.73251500E+00, -.15231800E+02, 0.43883800E+02, -.72102700E+02, -.62609300E+02, 0.22271000E+02, 0.47133000E+02, 0.10669700E+02, -.13607500E+03, 0.60521300E+02, 0.71731500E+02, 0.67507300E+02, -.37406800E+02, 0.84007600E+02, 0.70280300E+01, -.36806300E+02, 0.15991100E+02, 0.11565300E+03, -.40401100E+02, 0.20444900E+02, 0.67130900E+01, 0.23513700E+02, 0.25239400E+02, -.15751600E+01, -.78343800E+01, -.96522300E+01, 0.24004000E+02, -.23367100E+02, 0.13383800E+02, -.48048400E+01, -.21457400E+02, 0.51788500E+01, -.21276600E+02, -.33811600E+01, 0.23717500E+02, -.32299600E+01, -.82687600E+01, -.24650800E+01, 0.35384600E+01, -.60193800E+01, 0.11240900E+02, 0.13919100E+02, 0.84123600E+01, -.13030700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.26778100E+01, 0.51660100E+00, -.60620400E+00, 0.52254100E+01, 0.23680100E+01, -.20026700E+00, -.54222600E+01, -.90512900E+01, -.41310600E-01, 0.65966600E+00, 0.42609400E+00, 0.77319600E+01, -.77108700E+01, -.22026700E+01, -.54070000E+01, -.72595200E+01, -.36442500E+01, 0.33767100E+01, 0.12902400E+00, 0.13675700E+01, -.32282600E+01, -.54016400E+00, 0.17752300E+01, -.14270700E+01, 0.56687300E+00, 0.10533800E+01, 0.33591600E+00, -.93576000E-01, -.17766200E+00, -.76674500E+00, 0.57470400E+00, -.29204400E+00, -.39993800E+00, 0.11630600E+01, -.93288200E+00, -.34167400E+01, -.13395100E+00, -.68132900E+00, -.26668800E+00, -.21769800E+00, 0.23490600E+01, 0.14381100E+01, 0.60673700E+00, 0.28945200E+00, -.52153400E+00, -.38582700E-01, 0.31201900E+00, -.23191300E-01, 0.10341900E+01, 0.63852200E+00, 0.22301200E+00, 0.15611900E+00, 0.28143000E+00, 0.10857600E+01, 0.53953900E+00, 0.97874700E+00, 0.49208400E+00, 0.73751400E+00, 0.10281300E-02, 0.78049500E+00, 0.28061100E+00, 0.48087600E+00, -.48536800E+00, -.36780200E+01, 0.37645400E+01, 0.30479700E+00, 0.10718700E+00, -.29831300E+01, -.20258700E+01, -.18429300E+00, -.14684100E+01, 0.39053800E+00, -.10278000E+01, 0.21668100E-01, -.34766100E+00, 0.55954600E+00, -.15692500E+00, -.16678500E+01, 0.51713300E+00, 0.52291700E-01, 0.29984200E+00, 0.46682900E+00, 0.65366900E+00, 0.24989800E+01, 0.21106800E+01, -.13499200E+01, 0.95310200E+00, 0.13755600E+01, -.87375400E+00, 0.72448700E-02, 0.11820800E+01, -.17234800E-01, 0.82745300E+00, -.68665600E+00, -.12020200E+01, 0.98913600E+00, 0.17147800E+01, 0.13403700E+01, 0.69057000E+00, 0.57872200E+00, -.17863800E+00, 0.66488500E-01, 0.59958000E-02, 0.28934300E+01, -.88549000E+00, 0.30226100E+00, -.66601300E-02, 0.27279100E+01, -.99940400E-01, 0.51261300E-01, -.24807800E+00, -.50518600E-01, -.32668600E-01, 0.38319300E-02, 0.62940800E-01, -.14824100E+00, 0.23485300E+01, 0.16328000E+01, -.15214200E+01, -.91377400E-01, 0.26459100E-01, -.59926200E+00, 0.17234000E+01, 0.10460200E+00, -.35248800E-01, 0.81062000E+00, 0.55623600E+00, 0.29841500E+00, -.97287000E-01, 0.32188200E+00, -.14284500E+01, 0.51158200E+00, 0.18694600E-01, 0.42361500E-01, 0.16580700E+00, 0.44317300E-01, 0.20989200E+01, -.13726200E-01, -.63056200E+00, -.45715100E+00, 0.12289900E+01, -.50327600E+00, 0.25661700E+00, -.38211600E-02, 0.80616300E-01, 0.25498000E+00, 0.15481800E-02, 0.22238700E+00, 0.55352800E+00, -.32023000E+00, -.12358400E-01, -.11106000E+01, -.48011300E+00, 0.37967000E-01, 0.28391400E+00, 0.12436500E+00, -.71923400E+00, -.23270800E-01, -.33089700E+00, -.89529100E-01, -.11934800E+00, 0.32657900E+00, -.76318500E+00, -.88981900E-01, 0.78880600E+00, -.39047500E-01, 0.21792600E+01, 0.75679000E+00, -.29624400E+00, 0.36815600E+00, -.64118500E+00, 0.24799700E+00, 0.48283100E+00, 0.13685500E+00, -.44004500E+00, -.89465800E+00, -.20900900E+00, -.20921000E+00, 0.21409000E+01, -.49126500E-01, 0.25838400E+00, 0.56825400E-01, -.21131200E-01, -.54344500E-01, -.80118600E-01, 0.26180000E+00, -.81075600E+00, 0.60530900E-01, 0.21199500E-01, 0.19976900E+00, 0.24797300E-01, 0.14252800E+00, -.70279100E+00, 0.19416000E+00, -.64291200E-01, 0.15511500E+00, -.14396900E+01, -.72844300E+00, -.36542900E+00, 0.13523600E+01, 0.13749400E+00, -.10160800E+00, 0.18325700E+00, 0.17916700E+00, -.64815700E+00, -.51271500E+00, -.20943600E-01, -.33726300E+00, -.52629000E-01, 0.66003100E-01, -.66001800E-01, 0.13594100E+01, 0.33882300E-01, 0.36643100E+00, 0.88433400E-01, 0.40743800E-01, -.36066200E+00, 0.36839700E+00, 0.27682500E+00, 0.44999400E-01, 0.16692100E+00, -.12057100E+00, -.96026800E-01, -.17932600E-01, 0.14099500E+00, -.45136900E+00, -.26613300E-01, -.22175700E+00, 0.14691600E+00, -.69003200E+00, -.20919600E+00, -.39089300E+00, -.14198200E+00, 0.18689300E+00, -.66560700E-01, -.15058900E+00, 0.26951100E+00, 0.59765300E-01, 0.24316100E-01, 0.85436400E-01, 0.70364500E-01, -.51648600E-01, 0.18742600E+01, -.19280400E-01, -.24167600E+00, 0.69073100E+01, 0.32678200E+02, -.60071100E+01, -.54192100E+00, 0.13485100E+01, 0.32983400E+02, -.10837500E+02, -.13493700E+03, -.55108500E+02, 0.28950200E+02, 0.21259800E+02, 0.27320700E+02, 0.15808000E+02, 0.24654400E+01, 0.50944400E+02, 0.30444400E+02, 0.48126100E+01, 0.59657700E+01, -.15235900E+02, 0.24402000E+01, 0.31774700E+01, 0.67569500E+01, 0.49333400E+01, 0.69918800E+01, -.14377000E+01, -.14444900E+01, 0.50105100E+01, -.69961200E+01, 0.10262600E+01, 0.22796000E+01, -.44914500E+01, 0.22768600E+01, -.47077600E+01, 0.13587500E+02, 0.50180800E+01, 0.26919900E+01, -.20546900E+01, 0.13529700E+02, 0.21270600E+01, 0.22403100E+01, 0.23281000E+01, -.79136000E+01, 0.64360100E+01, -.35389500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36880900E+01, 0.11744700E+01, 0.30335800E+01, -.32190400E+01, 0.27631400E+01, 0.55519500E+00, 0.33086100E+01, 0.25812500E+01, -.78486100E+01, -.14348500E+01, -.34909100E+00, 0.19657300E+01, -.11767700E+01, -.16350200E+01, 0.20689600E+01, 0.15656100E+00, -.10857900E+01, -.38676800E+00, -.13710000E+01, 0.26341200E+00, 0.62252800E+00, 0.15054100E+00, -.11709900E+01, -.15631800E+01, -.67902900E-01, -.49451600E-01, 0.23079500E+01, 0.16414800E+00, -.31488000E+00, -.18821600E+01, -.48424600E+00, 0.19658700E+01, -.57302100E+00, 0.25570900E+00, 0.13401800E+01, 0.77049900E+00, 0.37480900E-01, -.11174300E+01, 0.98389000E+00, 0.19506600E+01, 0.95498200E+00, 0.62071300E+00, -.23612300E+01, -.22371200E+00, -.10908400E+01, 0.36170400E+00, -.52535900E+00, 0.44222800E+00, -.17263600E+01, 0.58098200E+00, 0.69383600E+00, -.21913500E+01, 0.28484600E+00, -.81260100E+00, -.91380200E+00, -.70054600E+00, -.69459500E+00, -.32497400E+01, 0.18849900E+00, -.10249100E+00, -.48202100E+00, 0.20992600E+00, -.24918200E-01, -.10005500E+01, 0.15998000E+00, -.98918600E+00, 0.21251500E+00, 0.11447500E+01, 0.26905000E+00, 0.13541300E+00, -.15045500E+01, 0.27191200E+01, -.61384200E+00, 0.14998800E+00, 0.48192400E+00, -.11334200E+01, 0.18679100E+00, 0.18790400E+01, -.52711700E+00, -.77649400E-01, -.28526200E+00, 0.26921300E+00, -.89769500E+00, -.19935500E+01, -.12680600E+01, 0.13353000E+01, -.47872300E+00, -.17998500E+01, 0.51094300E+00, -.15755100E+00, -.14433200E+01, -.14929100E+00, 0.50905300E+00, 0.59446100E+00, -.27433900E+00, 0.84112100E+00, -.37348200E+00, -.26453100E+01, -.87708700E+00, -.26071400E+01, 0.42702700E-01, -.63518200E+00, -.16583700E-01, -.30044700E+01, 0.14848100E+01, 0.29707400E-01, 0.15844300E+00, -.48046400E+01, -.17663900E+00, 0.44724100E+00, 0.11979300E+01, 0.38794200E+00, 0.17285600E+00, -.12786600E-02, -.20761800E+00, 0.38746300E-01, -.27139700E+01, -.25878000E+00, -.18476500E+01, -.25224500E+00, -.11444300E+00, -.23614300E+01, 0.35786500E+00, 0.64844100E+00, 0.21776500E-02, -.11753100E+01, -.23933800E+00, -.49054100E-01, 0.15038400E+01, -.87314300E+00, -.89180300E+00, -.54480800E+00, 0.44883700E+00, -.18725900E+00, -.41342800E+00, -.12191200E+00, -.34528400E+01, 0.68185400E+00, 0.90865700E+00, 0.24057900E+00, -.24732900E+01, 0.17714200E-01, -.37672300E+00, 0.21740200E+00, 0.15130400E+01, -.10363300E+01, -.43825300E-01, 0.32608800E+00, -.27933700E+00, -.63666000E+00, 0.42688600E+00, 0.19934100E+01, 0.30805200E+00, 0.16053400E+00, -.58551800E+00, 0.11397600E+00, 0.10160200E+01, -.32053500E+00, 0.70124400E+00, -.29746700E+00, 0.76898200E-02, -.31223000E+00, 0.57117200E+00, 0.21862200E+00, -.32477500E+00, -.25258000E+00, -.35184400E+01, -.10364300E+01, 0.11036300E-01, -.23421800E+00, 0.74417800E+00, -.11362800E+01, -.37790600E+00, -.89483800E+00, -.17250100E-01, -.73773300E+00, 0.92283300E-01, -.13641400E+00, -.10125800E+01, -.14136700E-01, -.65674700E+00, 0.16765800E+00, -.35644700E+00, -.92032500E-01, -.36811700E-01, -.17928300E+01, -.11095600E+00, 0.10365500E+01, -.16493600E+00, -.94138500E+00, -.36272000E-02, -.14491900E+00, 0.21751500E+00, -.29533100E+00, 0.11648400E+00, 0.20697000E+00, 0.93727300E+00, -.11560000E+01, 0.24943100E+00, 0.74556500E-01, -.91736000E-01, 0.66931900E-01, -.69212100E-01, 0.18614700E+01, 0.86254800E+00, -.12827800E+01, 0.10502400E-01, 0.51603600E+00, 0.71881700E-01, 0.12315600E+01, -.42084200E+00, 0.72571800E+00, -.21142000E-01, 0.80681100E+00, 0.50511800E+00, 0.54010700E+00, 0.36446600E+00, 0.40930600E+00, -.17397600E+00, -.45658300E+00, 0.10173200E+00, 0.25412800E+00, 0.30905200E+00, 0.65425000E-02, 0.12792800E+01, -.38320700E+00, 0.30275000E+01, 0.54094300E+00, -.17343900E+00, -.16200100E+01, -.17273800E+01, -.93134500E+00, 0.86234200E+00, 0.78236100E+00, 0.30711800E-01, -.15936500E+00, -.21801900E+00, -.47064300E+00, -.51927100E+00, 0.67723700E-01, 0.23490100E+00, -.39362600E+00, 0.43062600E+01, -.15890300E+00, 0.15112300E+01, -.17714900E+00, 0.13273400E+03, -.37713500E+02, 0.16274700E+03, 0.13762900E+03, -.25328400E+02, -.33370500E+02, -.53111300E+03, 0.22488700E+03, -.91474200E+02, -.21781000E+03, -.10966600E+03, 0.78488400E+02, -.25072400E+03, 0.99683900E+02, 0.19466900E+03, 0.16254200E+02, -.35973400E+03, 0.54545200E+03, -.50706300E+02, -.23566700E+02, -.48612200E+02, -.61746000E+02, 0.13487700E+02, 0.68587000E+01, 0.11518300E+02, -.58272300E+02, 0.47411700E+02, -.35175700E+02, 0.49205600E+01, 0.58670400E+02, -.80581700E+01, 0.58712000E+02, 0.25119300E+02, -.57090600E+02, 0.18509600E+01, 0.28183700E+02, 0.22277500E+02, -.46314400E+01, 0.43341500E+01, -.32940700E+02, -.47779400E+02, -.15366300E+02, 0.38813100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.50590800E+00, 0.98771900E-01, 0.51137900E+00, -.47284600E-01, -.38049700E+00, -.12505100E+00, 0.35335700E+00, -.12821700E+00, -.89294600E+00, -.10131800E+00, -.26283500E-01, 0.22211500E+00, -.37017200E+00, 0.14373800E+00, 0.17223900E-01, -.66749100E+00, 0.96812300E-01, 0.75981400E+00, -.22309200E+00, 0.12508000E+01, 0.38591000E+00, -.92781600E-01, -.10834900E+00, 0.12229300E+01, 0.43887900E-01, 0.73273300E-01, 0.55649300E+00, -.66800100E-01, 0.41630600E+00, 0.78880600E+00, 0.16290900E-01, -.54770200E+00, 0.44457200E+00, -.31317500E+00, -.35956000E+00, 0.40643300E+00, 0.17644800E-01, -.25140600E-01, 0.91123700E-01, -.19383800E+00, 0.15131100E+00, 0.14558700E+00, 0.23323400E+00, 0.35737100E-02, 0.10105800E+00, 0.78510200E-01, 0.33762000E+00, 0.73128000E-03, 0.66732500E+00, -.66726400E-01, -.76380400E-01, 0.64950100E+00, -.21206300E-01, 0.38349900E+00, -.98187100E-02, -.97824900E-02, 0.25667700E+00, -.83281100E+00, -.14631000E-01, -.12903800E+00, 0.25160600E-01, -.12437900E-01, 0.12857400E+00, 0.42198100E+00, -.75275200E+00, 0.51301000E-01, -.29888800E-01, -.66019500E+00, 0.93517600E-01, -.10491700E+00, 0.92186200E+00, -.83689400E+00, 0.37730300E+00, 0.19324200E-01, -.11656200E-01, 0.10892100E+00, -.33181800E-01, -.40756900E+00, 0.85193400E-01, 0.18513500E-01, 0.96497900E-01, -.18498200E+00, 0.40679600E+00, 0.73558600E+00, 0.63343400E-01, -.43448700E+00, 0.12592800E+00, 0.14818500E+00, -.73509100E-01, 0.27404800E+00, 0.50367500E+00, 0.13358600E-01, 0.85642100E-01, 0.21678700E+00, 0.26758200E+00, 0.17512900E+00, 0.27463200E+00, 0.72057100E-01, -.59108000E-01, -.41924400E+00, -.89179800E-01, 0.10885100E+00, -.57430800E-02, -.49932500E+00, 0.24040700E+00, 0.26792100E-02, -.63207900E-01, 0.88773900E-01, 0.39440500E+00, 0.48910100E-02, 0.39969800E+00, 0.11641200E+00, 0.47469400E-01, -.16929700E-02, -.79233100E-02, 0.38373400E-01, -.21996600E+00, -.60485200E+00, 0.12165700E+00, -.14445100E+00, 0.13096600E+00, -.12151900E+01, -.14204200E+01, 0.58930600E-01, 0.21425900E-02, -.26301400E+00, 0.30607000E+00, -.19871100E+00, 0.25966200E-01, -.17225200E+00, -.54987500E+00, -.62950000E-01, -.41776100E+00, -.35747900E+00, 0.51091900E-01, -.56163600E-02, 0.70732700E-01, -.70499400E-02, 0.20584800E+00, 0.45781400E-01, -.11420700E+00, -.25539200E-01, -.10557500E-01, 0.76863400E-01, -.81865300E-01, -.99059900E-01, 0.21501500E-02, -.80969500E-01, 0.35091300E+00, 0.21615600E+00, 0.13317700E+00, 0.19566200E+00, 0.90685700E-01, -.85400900E-01, 0.13816500E+00, 0.46641500E-02, 0.10471500E+00, 0.32629400E-01, 0.88679000E-02, -.29215800E+00, -.66299600E-02, 0.71915400E-01, 0.12702200E+00, -.10558100E+00, 0.43738700E-01, -.30024900E-01, -.48895700E+00, -.37372800E+00, -.65532100E-02, -.40750200E-01, -.69437700E-01, 0.73563400E-01, -.40197900E-01, 0.26056200E+00, 0.39060800E-01, 0.10777600E+00, 0.37576100E-02, 0.47856000E-01, -.50161500E-01, -.21823600E-02, 0.43005000E+00, -.33882200E-01, 0.15541900E+00, -.10880200E+00, 0.59339500E-01, -.13126600E+00, -.58603900E-01, 0.24856700E+00, 0.26023300E-01, -.14693300E+00, -.45321200E-02, -.33872500E-01, 0.20495500E+00, -.66147100E-01, 0.63628300E-01, -.23666200E-01, 0.37906000E+00, 0.23981600E+00, 0.16127000E-01, -.34027300E+00, 0.73314000E-02, -.23646000E-01, -.63085200E-01, 0.30018400E+00, -.27394800E-01, -.52409300E+00, -.39508700E-01, -.82748900E-01, 0.10701400E+00, -.13992200E+00, 0.56020300E-01, -.81964100E-02, 0.31091000E-02, -.26462700E+00, 0.71217400E-02, -.11721200E-01, 0.20875500E-01, 0.12726300E+00, -.27987800E-01, -.49902500E-01, -.10198200E+00, 0.60045500E-02, -.24581000E-02, -.22939200E-02, 0.19560700E+00, 0.91423200E-01, -.12586900E+00, 0.84352400E-01, -.38959600E-01, 0.43756200E+00, -.50493100E-01, 0.72439100E-01, -.36387100E+00, 0.38248600E-01, -.26939300E-02, -.65979100E-04, -.17454300E+00, 0.58057000E-02, -.52493900E-01, 0.69664000E-01, -.11386600E-01, -.20936900E+00, -.10580100E+00, -.54651000E-01, 0.95236700E-01, -.33806000E-01, -.18764100E-01, -.93154900E+01, 0.21391200E+02, 0.16506300E+02, 0.35827800E+01, -.97862100E+01, -.14857700E+02, 0.29262900E+02, -.12771800E+02, -.23593700E+02, -.14505800E+02, 0.82475600E+01, -.12642800E+02, -.35447300E+01, 0.61047100E+01, -.41181500E+01, -.21577000E+02, 0.50446900E+01, -.21829200E+01, -.28105000E+01, -.86769500E+01, -.90041800E+01, 0.54804200E+00, -.44645700E+00, 0.47752000E+00, -.87033800E+01, 0.85923000E+01, -.15928500E+01, -.92455400E+00, 0.82009000E+01, -.12719500E+00, 0.81904200E+01, 0.70797000E+00, -.86460100E+01, -.12516600E+01, 0.18584900E+01, 0.60757700E+00, 0.34086400E+00, -.76046000E+00, -.20375900E+01, -.26799500E+01, -.18270300E+01, 0.15745900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.72538500E+01, -.64329900E+00, 0.22451000E+01, -.45596900E+01, 0.26337900E+00, 0.16133000E+00, 0.42234500E+01, 0.39979300E+01, -.37007000E+01, -.85351000E+00, -.45293700E+00, -.10330200E+01, -.74901700E-01, -.57997400E+00, 0.14748400E+02, -.20687200E+01, 0.99260600E+00, 0.75196500E+00, 0.17839300E+00, 0.15700700E+01, 0.10598400E+02, 0.34207600E+00, -.17714100E+01, 0.87255500E+01, -.64764300E+00, 0.62303200E-01, -.21778300E+01, -.21603200E+00, 0.57298100E+00, -.33100300E+01, -.11551100E+01, -.61937000E+00, -.41999400E+00, 0.10217400E+01, -.18005700E+00, -.13486400E+01, -.22762000E+00, -.57944200E+00, -.15515800E+00, 0.79080800E+00, -.29268300E+01, -.15689800E+01, 0.13590700E+01, 0.15257600E+00, 0.17393500E+00, -.23841700E+00, -.37449000E+00, -.22432100E-01, 0.11724100E-01, 0.11548800E+01, 0.15029000E+01, -.10289100E+01, 0.20330100E+00, -.36362600E+00, 0.19392300E+00, 0.21382300E+01, 0.19812900E+01, 0.80957800E+00, 0.82916200E-01, -.68513800E+00, 0.27286600E+00, -.74789300E-01, -.44485900E+00, -.38891100E+01, 0.69174200E+01, 0.20912200E+00, 0.10429600E+01, 0.11088500E+01, -.32595700E+01, -.43895800E-01, -.72371100E+01, 0.41654800E+01, -.91859500E+00, 0.20570800E+01, 0.21250400E+01, -.25670300E+01, -.60108400E-01, -.64482200E+00, 0.69995500E-01, 0.62443700E+00, 0.50128400E-01, 0.34385400E+01, 0.13165500E+01, 0.34445900E+01, 0.66936200E+00, 0.31067600E+01, 0.13881300E+00, -.11015400E+01, -.33902200E+00, -.11234400E+01, 0.13367600E+01, -.37245400E+00, 0.16302100E+01, 0.68846200E-01, 0.40950300E+01, -.34899000E+01, -.99684800E-01, -.16833100E+01, -.17086100E+00, -.90213800E+00, -.47747700E+00, -.13836400E+00, 0.67382900E-01, -.43899000E+01, -.14433800E+01, -.16304500E+01, 0.69723800E+00, -.81848000E+01, -.43832300E+01, 0.10650300E+01, 0.87188300E+01, -.28417000E+00, -.15582700E+01, 0.28265500E-01, -.12871600E+01, -.16435500E-01, -.72919500E+01, -.25598600E+01, 0.35431100E+01, 0.12931700E+01, -.15917000E+01, 0.13091500E+02, 0.17886900E+01, -.61544200E+00, 0.12473100E-01, -.72648500E+00, -.17655200E+01, -.15546200E+01, 0.26175600E+01, -.16537700E+01, 0.38319300E+01, -.87117600E+00, -.19427100E+00, 0.71937400E-01, -.42758300E+01, -.18267100E+00, 0.12389800E+01, 0.25246800E+01, 0.15213600E+01, 0.12700900E+01, 0.15068400E+01, 0.18889000E+01, -.63950600E+00, -.89775700E+00, -.12799600E+01, 0.56110400E+00, 0.41325900E-01, -.10301000E+01, -.21485000E+01, 0.17464700E+01, 0.23245000E+00, 0.12746000E+01, 0.40900300E+00, 0.28231400E+00, -.22487100E+01, 0.25327800E+00, -.32203600E+00, 0.25569500E+00, -.76461600E+00, 0.97314400E+00, 0.16916400E+00, -.54974400E+00, 0.15347400E+01, 0.13405100E+01, 0.10829100E+01, 0.17817800E+00, 0.55269800E+01, 0.12153800E+00, -.16245500E+00, 0.13848500E+00, -.14243100E+01, 0.25274000E+01, 0.49976600E+01, 0.27267500E+01, -.50323500E+00, 0.17574400E+01, 0.10732300E+00, 0.11682500E+01, -.20512200E+01, 0.34912500E-01, 0.47868800E+01, -.92685500E+00, -.15960900E+01, -.88921300E+00, 0.27784700E+00, -.43495100E+01, 0.27300700E+01, 0.13583000E+01, -.20706600E+00, -.24964600E+01, -.29932900E-03, -.45006300E+00, 0.36197800E+01, -.22442900E+01, 0.49287800E-01, -.48183600E+00, 0.25412000E+01, 0.37994800E+01, 0.25909100E+01, -.74538000E+01, -.12750200E+01, 0.76112900E-01, -.25045800E+01, -.35678600E+01, 0.18086300E+01, 0.54581800E+01, -.19457800E+00, 0.27394000E+01, -.12217300E+01, 0.16084500E+01, 0.25365400E+00, 0.19230000E+01, 0.31833400E-01, -.26752100E+00, -.15487200E+01, -.19447900E+01, -.27124000E+01, -.64653400E+00, -.15469300E+01, 0.18152000E+00, -.16238400E+01, -.56418000E+00, -.15172300E+01, -.10303000E-01, -.81512300E+00, -.13524700E+01, -.47239100E+01, 0.48628100E+00, 0.52116400E+00, -.85488500E+00, 0.69321600E+00, 0.34274800E+01, 0.30491300E+01, 0.35124000E+00, -.33671000E-02, 0.42987200E+00, -.91307900E+00, 0.83526000E-01, 0.53184200E+00, 0.24445000E+00, -.12787200E+01, -.92979200E+00, -.70053100E+01, 0.40300000E+00, -.62454600E-01, -.75106400E-01, -.14033700E+01, -.38538400E+01, 0.19340500E+03, 0.17951900E+03, -.14522500E+03, 0.35167000E+02, -.27929500E+03, 0.30109800E+03, -.13204800E+03, -.27340000E+03, -.14675800E+03, -.14912700E+03, -.39927700E+03, 0.39043200E+02, 0.18302000E+03, 0.91165700E+02, -.58678500E+03, 0.12606200E+04, -.41040300E+02, -.49100100E+02, -.16442800E+03, -.16497200E+03, -.20585200E+02, -.27476900E+02, -.18660400E+02, -.16054000E+03, 0.16373600E+03, -.31480500E+02, -.38673800E+02, 0.16321800E+03, 0.12404900E+02, 0.16557800E+03, -.92702800E+01, -.15936400E+03, -.42301200E+02, 0.44342500E+02, -.13668200E+02, 0.18543800E+02, -.38806700E+02, -.51191200E+02, -.26992300E+02, -.60077300E+02, 0.70798400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.50165600E+00, 0.41184700E+00, 0.83126400E+00, -.15744200E+00, -.67996100E+00, -.13249900E+00, 0.92021900E+00, 0.11374000E+00, -.15362400E+01, -.22493500E+00, 0.12114000E-01, 0.10732700E+01, 0.10885500E+01, 0.50539500E+00, 0.11634100E+01, -.10210300E+01, -.52574300E+00, 0.27421600E-01, 0.12730500E-01, 0.53517500E-02, -.15865200E+00, -.15015100E+00, -.41603400E-01, 0.11950200E+00, 0.15312900E+00, 0.11163100E+00, -.17165900E+00, -.95300200E-01, 0.24186700E+00, -.13525800E+00, -.68381100E+00, -.66444000E-01, 0.72051900E+00, -.48223000E+00, 0.33103200E+00, 0.48488500E+00, 0.18064900E-01, 0.33502700E+00, -.57319800E+00, 0.30383600E+00, 0.40489200E+00, -.28359700E-02, -.30152900E-01, 0.68486600E-01, 0.48762900E+00, 0.10996100E-01, 0.86281500E-01, -.62976600E-04, 0.82562500E+00, -.31401600E+00, 0.64836600E+00, 0.10192800E+01, -.10009300E+00, -.14104700E+00, 0.21364400E+00, 0.15207500E+00, 0.41326700E+00, 0.12599300E+01, -.11405200E-01, -.46442900E+00, 0.68444800E-01, 0.28587600E+00, -.10183100E+00, 0.53974500E+00, -.39461800E+00, 0.24185500E-01, 0.15739700E+00, 0.18427400E+01, 0.64977000E+00, 0.19989900E+00, -.20631000E+01, -.25658000E+00, -.71015400E-01, 0.35696000E+00, 0.24822000E+00, -.29662100E+00, -.40733300E-01, -.59282300E+00, -.17010600E+00, 0.18055700E+00, -.66184800E-02, 0.70596400E+00, -.27634600E+00, -.77527000E+00, -.42566900E+00, -.59745000E-01, 0.20793000E-01, -.31468000E+00, 0.80583700E-01, -.70021900E+00, -.61452700E+00, -.75218100E-01, -.17792700E+00, 0.30094800E+00, 0.14229600E+00, 0.58934400E-01, -.97650600E+00, 0.66769600E-02, -.19941000E+00, 0.96615500E+00, 0.13290300E+00, 0.14495700E-01, 0.12202300E-03, -.10225900E+01, -.15737600E+00, -.70286100E-01, -.84945900E-01, 0.24117000E+00, -.11162200E+00, -.15480000E+00, -.33153200E+00, -.42181000E-01, 0.30408000E-01, 0.29596400E-03, 0.68120800E-01, 0.42765400E-01, -.23118700E+00, 0.48785000E+00, 0.95016900E-01, 0.15219100E+00, -.69417900E-01, 0.91869900E+00, 0.81807600E+00, 0.20641300E-01, -.38969600E-02, -.18103900E+00, 0.10857900E+00, -.21929400E+00, 0.46790700E+00, -.20159400E-01, -.84169500E+00, -.90391500E-01, -.70472300E-01, -.35450200E+00, -.57252200E+00, -.19391900E-01, -.11010800E+00, 0.29400300E+00, 0.44624600E-01, 0.49306100E-01, -.61707200E+00, -.16673900E+00, -.89490400E-01, 0.46155300E-03, 0.23819600E-01, -.29788000E+00, -.14327800E-02, 0.98224000E-02, 0.63804600E-01, -.76525600E-01, -.53016800E-01, 0.49914100E-01, -.19852400E-01, 0.17399200E+00, 0.75313900E-02, -.45361800E-01, 0.22997700E+00, 0.83437400E-02, -.77561600E-01, 0.22663600E+00, 0.83655500E-01, -.16824200E+00, -.53954000E-01, -.70896100E-01, -.12632900E+00, 0.58630600E-01, 0.16665800E+00, 0.43083900E+00, 0.32052900E-01, 0.33296600E-01, 0.17944800E+00, -.45554700E+00, -.26949800E-01, -.65007400E+00, 0.19518500E-01, 0.77934500E-01, 0.23493000E-01, -.26716100E-01, -.30938300E+00, -.74215800E-02, 0.23398600E+00, -.74295100E-01, -.18786700E+00, 0.88113400E-01, -.11531200E+00, -.56359400E+00, 0.26080200E+00, -.59142900E+00, 0.14000800E-01, -.15219600E-01, -.54982800E-02, 0.16913000E-01, 0.20489200E+00, -.52337500E+00, 0.11050200E+00, 0.45795200E-01, 0.99089500E-01, 0.10391500E+00, -.48876100E-01, -.67778400E+00, -.12415500E+00, 0.26463100E-01, -.22822400E-01, 0.41287100E-02, 0.70035800E+00, -.15837800E+00, -.81581200E-02, 0.11034900E+00, 0.17917000E-01, 0.29274600E-01, -.75741500E-01, -.49671500E+00, -.35278800E-02, 0.21575600E+00, 0.19336000E-01, 0.10676600E+00, 0.11666600E+00, -.14957800E-01, 0.39910900E-01, 0.41220000E-01, 0.54329200E-01, 0.62199000E-01, 0.82930500E-01, 0.59159200E-03, 0.17327500E-01, 0.49295900E-01, 0.12567700E+00, -.95684900E-02, -.39048300E-01, -.11149900E+00, 0.46206400E-01, 0.31902300E+00, 0.16585600E+00, -.11301800E+00, 0.10680600E-01, -.37452100E-01, 0.76464200E-01, 0.17891500E-01, 0.16479900E+00, -.25886000E-01, -.15602400E+00, 0.83907700E-01, -.38459700E+00, -.44383900E-02, -.12106300E+00, 0.30857900E-01, -.86713700E-01, -.48890000E+00, 0.42533200E-02, 0.59398500E+01, -.75100400E+01, 0.25729900E+01, -.92171700E+01, 0.30240400E+02, -.13922300E+02, -.26778600E+02, -.14907600E+02, 0.68931300E+01, -.17127700E+02, -.87794800E+00, 0.12417400E+02, -.47196800E+01, -.25093700E+02, 0.30566300E+02, -.36620700E+01, -.80632300E+00, 0.35324500E+01, 0.19383700E+01, 0.36255500E+01, 0.28963500E+01, 0.28749900E+01, 0.20966900E+01, -.35427400E+01, -.27752600E+01, 0.36599200E+01, -.13714100E+01, -.14183100E+00, -.12528900E+01, 0.24356700E+01, 0.20979600E+01, 0.33839800E+01, 0.15866700E+01, 0.22635200E+01, -.23052600E+00, 0.34929500E+01, -.16898400E+01, -.54223800E+01, -.13461900E+01, 0.22869500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10721400E+01, 0.84140100E-01, 0.37485400E+00, -.19220400E+01, 0.45565700E+00, 0.24771300E+00, 0.16605700E+01, -.46404900E+00, -.39582200E+01, -.70958700E+00, -.16948000E+00, 0.19132100E+01, -.21356900E+01, -.11690500E+01, 0.23245800E+00, -.13431900E+01, -.70993000E+00, 0.80213000E+00, 0.19136900E+00, 0.66520800E+00, 0.21547200E+00, 0.47092700E-01, -.43726900E+00, 0.99943600E+00, 0.13484900E+00, -.10123200E-01, 0.15950400E+01, -.10905200E-01, 0.51609000E+00, -.16307100E+01, 0.70762700E-01, -.67754600E+00, -.36393300E+00, 0.15485500E+01, -.32248500E+00, -.46486900E+00, -.17543300E-01, -.21513600E+00, 0.17132700E+00, 0.94940400E-01, 0.27124800E+00, 0.14778300E+00, 0.19907600E-01, 0.85977100E-01, -.37009700E+00, -.13607000E+00, -.22841300E+00, 0.19389300E-03, -.18825800E+00, 0.58854200E+00, 0.12101500E+01, 0.50359800E+00, 0.24971200E+00, 0.70817600E+00, 0.46161200E-01, -.31216700E+00, -.65651700E+00, -.22117800E+01, 0.18940600E-01, 0.54945700E+00, -.89613200E-01, -.13596500E-01, 0.17154100E-01, 0.82626500E+00, -.92056900E-01, -.46520600E-01, 0.87939700E-01, 0.12018400E+01, 0.33351900E-01, -.68269700E-01, 0.18999200E+00, 0.28992900E+00, -.86061100E-01, -.38945600E+00, 0.10096200E+00, -.50884400E+00, 0.16512600E+00, 0.10961000E+01, -.10430300E+00, -.28476900E+00, -.15530600E+00, -.36862100E+00, -.41687600E-01, -.65389700E-01, -.16071400E+01, 0.10611100E+01, -.20723200E+00, -.37557500E+00, 0.55950500E-01, 0.45229400E+00, -.33467000E+00, -.35451700E-01, 0.86978000E+00, 0.24007600E+00, 0.12498800E+01, -.68592400E+00, 0.10892500E+01, -.11741600E+01, -.21914900E+00, -.34095900E+00, -.38184000E-01, -.92114800E-01, -.16045700E-01, 0.72514900E+00, 0.68955300E+00, 0.12649900E+00, -.42327700E-01, -.13724200E+01, -.20830500E-01, 0.55495500E+00, -.13856200E+00, -.21449300E-01, 0.66938600E-01, -.45936800E-02, -.14499700E+00, 0.42137300E-01, -.16525000E+01, -.91880200E+00, -.31400000E+00, -.20550000E-01, 0.35572900E+00, -.33932900E+00, -.18398300E+01, 0.32075200E+00, 0.81931400E-02, -.72476500E+00, -.18797400E-01, -.27326000E+00, -.94240700E+00, -.41989100E+00, 0.20618900E+00, -.22685000E+00, -.31461500E+00, -.58737700E+00, -.14994600E+00, -.28433300E-01, -.10260400E+01, -.23957200E+00, 0.64943900E+00, 0.17020000E+00, -.13032600E+01, -.10337200E+00, -.16623500E+00, 0.18802900E+00, 0.40330800E-01, -.38682700E+00, -.44382200E-03, -.16863200E+00, -.22564900E+00, -.29924400E-01, -.10114200E+00, 0.40658000E+00, 0.14617200E+00, 0.55379600E-01, -.17456700E+00, -.53322300E-01, 0.71033900E+00, -.79284700E-01, 0.12263900E+00, -.29957000E+00, -.85140900E-02, -.22549300E+00, -.63514800E-01, -.19146800E+00, 0.34488600E-01, 0.63341500E-01, -.21911200E+00, -.31191700E+00, 0.14431100E-02, -.26624500E+00, 0.10533600E+00, -.43759500E+00, -.34055000E+00, 0.44312700E+00, 0.22436500E+00, 0.56302400E+00, 0.65425700E-02, 0.16545900E+00, -.35305300E+00, 0.19476200E-01, 0.51725400E+00, 0.10443400E+00, -.62725200E+00, -.94981800E-01, 0.46980300E-01, -.74894700E+00, 0.19022000E+00, -.47119200E+00, 0.22494100E-01, -.58303400E+00, 0.23994100E-02, 0.87808000E-01, 0.24303800E+00, -.47882000E-01, 0.42409300E-01, 0.37995500E-02, -.11685600E+01, 0.23282800E+00, 0.81091500E+00, -.88701000E+00, -.94914100E-01, 0.41674700E-01, -.22722300E+00, -.15687300E+00, 0.26775000E+00, 0.55574100E+00, 0.40815900E-01, 0.99716300E-01, -.83078400E-01, -.38564700E-01, 0.13246900E+00, 0.52045700E+00, -.50597400E-02, -.26273400E+00, -.12584800E+00, -.20761000E+00, -.14330000E+00, -.43084000E-01, -.12329400E+00, 0.28851400E-01, -.10720500E+00, -.88730400E-01, 0.12315500E+00, 0.67598100E-02, -.40618800E-01, 0.34051100E-01, 0.39266900E+00, 0.90093500E-01, 0.18117100E-01, -.66897200E+00, 0.93235900E-01, 0.42491600E+00, 0.10105900E+00, -.90739500E-02, -.30455300E-02, 0.68388100E-01, -.15673800E-01, -.90127400E-01, -.35091300E+00, -.10320100E+00, 0.24143600E-01, -.18623700E+00, -.15822600E+00, 0.25307600E-01, 0.41103000E+00, -.62002900E-01, 0.40732300E-01, 0.64623500E+00, 0.17584300E-01, -.41970600E+00, -.32925900E+02, 0.28413300E+01, 0.45321600E+02, -.52769800E+01, 0.30135800E+01, -.34588000E+01, 0.27774300E+01, -.10063100E+02, -.14185400E+02, -.71633600E+01, -.22016500E+00, 0.18122300E+02, -.23569900E+02, 0.78868600E+02, -.20684200E+01, -.25987800E+01, -.12851000E+02, -.11259900E+02, -.94198200E-01, 0.19465800E+01, 0.21477200E+01, -.10878900E+02, 0.12864300E+02, -.65159300E+00, 0.57078800E-01, 0.10422900E+02, -.20674000E+01, 0.10631900E+02, -.19632300E+00, -.10765500E+02, -.19522100E+00, 0.12803600E+01, -.41588900E+00, -.16223200E+01, 0.96526900E-01, -.16331500E+01, -.22293000E+01, -.59692100E+01, 0.49594600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.83104800E+00, 0.48121200E+00, 0.15166500E+01, 0.16917700E+00, -.35855300E+00, -.16064200E+00, 0.91684100E+00, 0.10408700E+01, -.88566600E+00, -.52344100E+00, -.19131300E-02, -.20121400E+01, 0.98863100E+00, 0.51549200E+00, 0.44399400E+00, 0.91876500E+00, 0.92516800E+00, 0.17988800E+00, -.28329000E+00, 0.95696000E+00, -.25561400E+00, 0.27230900E-01, -.33108900E+00, 0.82909500E+00, -.18424800E-01, 0.54978500E-01, -.11006300E+00, -.24666100E+00, 0.30100100E+00, 0.48070300E-01, -.38534200E+00, -.19786000E+00, 0.44689400E+00, -.22123000E+00, 0.56838200E-01, 0.11152800E+00, 0.47701900E-02, 0.43581000E+00, -.58382800E-01, 0.80726900E+00, -.55613800E+00, -.44247800E+00, -.35165800E+00, -.54575900E-01, 0.13571200E+00, -.55816400E-01, -.30615100E+00, 0.59351000E-02, 0.67907000E-01, -.46208300E+00, 0.21186400E+00, 0.12327000E+01, -.14529700E+00, 0.27956500E+00, 0.21998200E+00, -.15348600E+00, 0.13823300E+00, 0.93031000E+00, 0.72236400E-02, -.13876900E+00, -.20219500E-01, -.73136800E-03, 0.12529600E+00, 0.27549900E+00, 0.46538200E+00, -.36411700E-01, 0.48251600E-01, 0.10255000E+01, 0.26335500E+00, 0.14673000E+00, -.16455700E+01, -.20192200E+00, -.26841700E+00, 0.48124000E-01, 0.43412500E-01, 0.19891200E+00, -.24612300E-01, -.21758300E+00, -.19015100E+00, -.53774400E-01, -.64269500E-01, 0.18432700E-01, -.15811900E-01, -.85028600E+00, -.37798400E+00, 0.34908200E+00, -.38915700E+00, -.44809000E-01, 0.37560900E+00, -.47521500E+00, 0.73932700E+00, 0.49345800E-01, -.52451000E+00, -.12151000E-02, -.18203300E+00, -.55322000E+00, -.29268800E+00, 0.41225100E+00, 0.17352800E+00, 0.13251000E+01, 0.13943000E+00, -.24742000E+00, 0.12820500E-01, 0.92696000E+00, -.58311800E+00, 0.80129500E-01, -.20450400E+00, 0.76191400E+00, -.47786800E-01, -.11879300E+00, -.29622300E+01, -.45810800E+00, -.17590300E+00, -.12928500E-02, 0.12833600E+00, -.12748100E+00, 0.43255300E+00, 0.39821800E+00, 0.14558000E+01, 0.27716200E+00, 0.50531000E-02, -.32961700E+00, -.26073700E+01, 0.20938500E+00, 0.10585200E-01, -.57602900E+00, -.37706400E+00, 0.13181700E+00, -.71588400E+00, -.60146300E-01, 0.66757500E+00, 0.11568000E+00, -.22495500E+00, -.58130300E+00, -.26097300E+00, 0.26862400E-01, 0.73380300E+00, -.14484500E+00, -.31148200E-01, 0.35274200E-01, 0.35470600E+00, -.80536000E-01, 0.77256900E-02, -.20990500E-01, -.86622900E-01, 0.40726600E-02, 0.66864900E-02, -.24454500E+00, -.72031400E-01, 0.11679300E-01, -.13562200E+00, 0.88186600E-01, 0.40690100E+00, -.57345700E-02, -.19546600E+00, -.84600300E-01, -.73306200E-01, 0.95821100E-01, -.27435700E+00, -.98023900E+00, -.66905000E-01, 0.63091300E+00, -.11984600E+00, -.18377800E+00, 0.15267900E+00, -.16659800E+00, 0.81014300E+00, -.21793000E-01, -.16556900E-01, -.59378300E-01, 0.10073400E+00, -.21675900E+00, -.20918600E+00, -.13222900E+00, -.28870200E+00, -.25181900E+00, 0.24228500E-01, -.19827600E+00, 0.46194600E+00, -.11328500E-01, -.62008100E+00, -.19466500E+00, -.60360600E-01, 0.11737100E+00, 0.73386700E-01, 0.48293800E+00, -.52376200E+00, -.70724900E+00, 0.35198400E-01, -.14876800E-01, 0.58227200E-02, 0.17616100E+00, -.23341600E+00, -.22873300E-01, -.11365500E+00, 0.38680600E-02, -.11368000E+01, 0.94218900E-01, 0.26551000E+00, 0.45048700E+00, 0.23939300E-01, 0.40651200E-01, -.86109700E-01, -.58148600E+00, -.82616300E+00, 0.29310600E+00, 0.14711700E+00, -.99287000E-01, -.24410700E+00, 0.24777000E-01, 0.75712200E-01, 0.30572300E+00, 0.50881000E-02, 0.53908900E+00, -.56932100E-01, -.13581200E+00, -.16812300E+00, 0.10489900E-01, 0.72433900E-01, 0.51294600E-02, -.11460800E+00, -.65231500E-01, -.17814800E+00, 0.38242500E-03, -.17203200E+00, -.21300000E+00, -.70287700E+00, -.30577900E+00, 0.93773900E-01, -.49505800E+00, -.28683400E+00, 0.26935800E-01, -.12313200E+00, 0.16442300E+00, -.12374900E-01, 0.14594200E-01, -.16238600E+00, 0.15405500E-01, -.16044600E+00, 0.32108500E-01, 0.19300800E-01, -.81013000E-01, 0.34222600E+00, 0.47662900E-01, -.19765500E+00, 0.30443400E-01, -.40658900E-01, -.16803600E+00, -.13074100E-01, -.93416200E-02, -.72726000E-01, 0.45657300E+01, -.22075400E+02, -.21793900E+02, 0.10884000E+02, 0.93545200E+01, 0.11068000E+02, -.38642400E+01, -.39971000E+01, 0.84454200E+01, 0.21568100E+01, 0.72554700E+01, -.11783900E+02, 0.78486300E+02, 0.54868000E+00, -.60832200E+00, -.56987300E+01, -.44150100E+01, 0.10891300E+01, -.47711400E+00, -.53604100E+00, -.42591700E+01, 0.56842600E+01, 0.85572400E+00, -.23114700E+00, 0.42908300E+01, 0.28318900E+00, 0.43212900E+01, 0.48020400E+01, -.41946100E+01, -.18106500E+00, -.59847200E+00, 0.46909800E+01, 0.27392500E+00, -.25106100E+00, 0.49163600E+00, -.28742000E+01, 0.13603800E+00, 0.26357600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19423800E+01, 0.14496900E+00, -.19921400E+01, -.10110700E+01, -.13090200E+01, 0.13097300E+00, 0.10816300E+01, -.53911400E+00, 0.61913100E+00, -.37026100E+00, 0.22497700E+00, -.99442800E+00, -.10099200E+01, -.44681100E+00, -.98067200E+00, -.73269300E+00, 0.13436200E+00, 0.10185100E+01, 0.72688600E+00, 0.24344600E+01, -.17436700E+01, -.11541000E+00, 0.55316100E+00, 0.50795700E+00, -.20370800E-02, 0.48771300E-01, 0.19208300E+01, -.28783400E+00, -.26375800E+00, -.19786000E+01, 0.44541500E+00, -.20739900E-01, -.80473000E-01, 0.65203500E+00, -.59635100E+00, 0.39871800E+00, 0.23306500E-03, -.10167100E+01, 0.34875200E-01, 0.50632900E+00, 0.55832300E+00, 0.13709000E+00, -.80667700E+00, 0.46710500E-01, -.10483400E+00, 0.16160100E+00, -.13838000E+00, 0.79238500E-04, 0.72691600E+00, 0.18587400E+00, 0.99293100E+00, 0.17191400E+01, 0.20147000E+00, 0.75815600E-01, -.15379300E+00, 0.14555600E+00, -.69044900E+00, -.14957100E+01, 0.41132800E-01, -.63157000E-01, -.92325900E-01, 0.24873800E+00, -.58151500E+00, -.61966500E+00, 0.12235800E+01, -.26572700E-01, 0.29076200E+00, 0.11233800E+01, -.22732000E+00, 0.12402100E+00, 0.21628500E+00, 0.82875900E+00, 0.27892500E+00, 0.10801700E+00, 0.21387000E+00, -.32460500E+00, 0.13202500E+00, 0.69945600E+00, 0.38467300E+00, 0.43416600E-01, -.21060800E+00, 0.43797500E+00, -.64346700E+00, -.72995300E+00, -.93969900E+00, 0.80876500E+00, 0.51535100E+00, -.47933400E+00, -.18143300E+00, -.33429700E+00, -.52665100E+00, -.34964000E+00, 0.16362500E+01, -.88434800E+00, 0.46328500E+00, 0.28892100E+00, -.78577900E+00, -.17902500E+01, -.49815400E+00, -.22126200E+01, -.89999400E-01, -.88253000E+00, -.22322000E-01, -.87997000E+00, 0.14734200E+01, 0.68148200E+00, 0.99659500E+00, -.27757000E+01, -.48717000E+00, 0.24589100E+00, 0.38753200E+01, 0.75057400E+00, 0.32725000E+00, 0.14545200E-02, -.85036300E-01, 0.54881800E+00, 0.12010800E+01, 0.12310000E+01, -.38529600E+01, -.97864300E+00, 0.91749300E+00, -.34767400E+01, 0.32126700E+01, -.15107900E-01, -.24978200E-01, 0.21917100E+00, -.65760000E+00, 0.60801700E+00, -.10067600E+00, 0.12331700E+00, -.60218300E+00, 0.36891100E-01, 0.20979200E+00, 0.23548900E+00, 0.10226300E+00, -.14935200E-01, -.71282100E-01, 0.82304200E-01, -.63986800E-01, -.18451200E+00, -.13969100E+01, -.97880000E-01, 0.10598000E+00, 0.20360600E+00, 0.21990500E+00, -.53579500E+00, 0.91502600E-02, 0.26789800E+00, 0.98724800E+00, 0.24602000E+00, 0.12388000E+00, 0.35533800E-01, 0.13425800E-01, -.77260300E-01, 0.67296300E+00, 0.35791100E-01, 0.47658600E+00, -.87306200E-01, 0.20619400E+00, 0.55103700E+00, 0.10465900E+00, -.22821200E+00, -.25582200E+00, -.36547300E-01, -.13278000E-01, 0.19600400E+00, -.31810400E+00, 0.31255100E+00, 0.30000900E-01, 0.39493700E-01, -.18860900E+00, 0.26801800E+00, 0.67235700E-01, 0.95514400E+00, 0.26126600E+00, -.23492600E+00, -.47280300E-01, 0.26768700E+00, -.13590600E+01, 0.75954900E-02, 0.12560900E+01, 0.18946700E+00, -.35246100E+00, -.11339900E+00, -.23730900E+00, -.18995900E+01, -.11625700E+00, -.11496500E-01, -.50385600E-01, 0.39347500E+00, -.53876000E-02, -.88189900E-01, 0.13697900E+00, 0.68139500E+00, -.12836800E+00, -.22439900E-01, 0.42913400E+00, 0.19591600E+00, -.27726000E+00, -.26212900E+00, 0.10258900E+00, -.77219000E-01, 0.33580700E+00, 0.17158200E+00, -.95848400E+00, -.46086000E-01, -.41440500E-01, -.48142200E-01, 0.35268200E+00, 0.20608600E-01, -.18202800E+00, -.10388400E+01, -.17823500E-02, -.86487000E+00, 0.37927700E+00, 0.19391300E+00, 0.30404000E-01, -.21325700E+00, -.10878400E+00, 0.23009800E-01, 0.24567700E+00, 0.10326900E+00, 0.29061700E+00, -.37326600E-02, 0.35024700E+00, 0.12097900E+00, 0.42405300E+00, -.15850700E+00, -.25787300E-01, -.56385300E+00, 0.94448200E+00, 0.82899900E-01, -.57989000E-01, -.62436600E-01, 0.35167200E-01, -.18474900E+00, 0.73058200E+00, -.15368500E+00, 0.75719900E-01, -.30341000E-02, -.72485100E-01, -.32338100E+00, 0.21165400E+00, -.71809200E-02, 0.49944100E+00, -.43404300E-01, 0.28427500E+00, -.11486000E+01, -.40581300E-02, 0.12527000E+01, -.31622200E+00, -.17573600E+01, 0.94828700E+02, -.32611500E+02, 0.14486700E+02, 0.22886900E+02, 0.15787900E+02, -.12892400E+02, 0.17046100E+02, -.63601800E+01, -.71099100E+02, -.80710500E+01, 0.25006200E+02, -.10834100E+03, 0.10822900E+02, -.19732400E+01, -.17130600E+02, -.11828000E+02, 0.35507300E+01, -.24030700E+01, -.43335200E+00, -.11772300E+02, 0.17174800E+02, 0.87900500E+01, -.21719000E+01, 0.79716100E+01, 0.51609100E+01, 0.82953000E+01, 0.69833300E+01, -.11709000E+02, -.21929600E+01, -.63646600E+01, 0.73169700E+01, 0.59978200E+01, -.17727800E+01, 0.68285400E+01, 0.30532800E+00, -.48626100E+00, -.10135500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.66642700E+01, 0.45569800E+00, -.25837800E+01, 0.56521300E+01, -.49508100E+00, -.31264400E+00, -.50368600E+01, -.66925500E+01, 0.28155200E+01, 0.97003700E+00, 0.62424400E+00, 0.32545700E+01, -.54334800E+01, -.43211900E+00, -.11131400E+02, 0.76144200E+01, -.37285300E+01, -.17022500E+01, 0.23191000E+00, -.32927700E+01, -.12902200E+02, -.42028800E+00, 0.21100100E+01, -.97540500E+01, 0.11984700E+01, -.17410600E+00, 0.18842900E+00, 0.50244600E-01, -.20560500E+01, 0.12835800E+01, 0.74860200E+00, 0.20407500E+01, -.14281800E+01, -.96885800E+00, 0.13468800E+01, 0.15491600E+01, 0.17793800E+00, -.95206400E-01, 0.10506800E+01, -.23159700E+01, 0.25880100E+01, 0.93631500E+00, -.52344500E+00, -.15401200E+00, 0.69587700E+00, 0.11092900E+01, 0.86503800E+00, 0.28834400E-01, 0.39777700E+00, 0.13730200E+01, -.21396500E+01, -.11509600E+01, -.75637400E-02, 0.14142700E+01, -.16939900E+00, -.12387900E+01, -.24194500E+01, -.50660500E+01, -.94205600E-01, 0.17363600E+01, -.46211900E+00, -.72514100E+00, 0.10130700E+01, 0.32476000E+01, -.54698500E+01, 0.17601900E+00, -.56729400E+00, 0.60059400E+01, 0.12687700E+01, -.90562100E-01, -.58394600E+01, -.13632600E+01, -.17960300E+01, -.12143400E+01, -.13491700E+01, 0.64710700E+00, -.96872500E+00, 0.15167600E-01, -.13389600E+01, -.16278600E+01, 0.44048300E+00, -.29888600E+01, -.11480900E+01, -.97617200E+00, -.65746500E+00, -.16892800E+01, -.10636800E+01, 0.89494500E+00, 0.17127800E+01, 0.44358800E+00, 0.37648600E+01, 0.86087200E+00, 0.12771400E+01, -.75399400E+00, -.21818100E+01, -.57953700E+00, 0.14346900E+01, 0.26558400E+01, 0.32931500E+00, 0.12337800E+01, 0.37885200E+00, 0.12900300E+01, 0.56360800E-01, 0.72659100E+01, 0.24300200E+01, 0.22010000E+01, -.11571900E+01, 0.93009000E+01, 0.51433300E+01, -.34778400E+00, -.14538400E+02, 0.28257600E+00, 0.25772800E+01, -.52957200E-02, 0.11233000E+01, -.65936800E+00, 0.15071300E+01, 0.22489000E+01, -.35595800E+01, 0.34094700E+00, -.38537500E+00, -.83030000E+01, 0.40847800E+00, -.11981100E+01, 0.68305000E-01, 0.81052100E-01, 0.11627800E+01, 0.61325700E+00, -.69528700E+01, 0.10469800E+01, 0.16251000E+00, 0.47040500E+00, -.21936800E+00, -.10124000E+01, 0.22962400E+01, 0.23773300E+00, 0.10656800E+00, -.33807100E+01, -.13391600E+01, -.12231100E+01, -.15636500E+01, -.25598500E+01, 0.26255000E+00, 0.16474900E+01, 0.17642100E+01, -.86953900E+00, 0.24885300E-01, 0.39562400E+00, 0.13270500E+00, -.29636800E+01, -.13248000E+01, -.29260700E+01, -.73398700E+00, -.10961200E+01, -.55673400E+00, -.84223200E+00, -.10283200E+01, 0.29830800E+00, -.67993800E+00, -.82218300E+00, 0.12827000E+00, -.65127800E+00, -.14367900E+01, -.96670100E+00, -.19845900E+01, 0.86729000E+00, -.10006600E+01, -.11269300E+01, 0.12522300E-01, -.68464500E+00, 0.74423300E+00, -.24600000E+01, -.30877600E+01, -.16631200E+01, -.11822200E+00, 0.53191600E+00, 0.59261500E+00, -.88332400E+00, -.27661000E+00, -.88168200E-01, 0.96045600E+00, 0.39074100E-01, 0.24190700E+00, 0.65609700E+00, -.46092900E+00, -.71976600E+00, -.13906200E+01, -.18792500E-01, 0.18229100E+00, 0.13164900E+00, -.17918600E-01, -.12209400E+00, 0.60460900E+00, 0.23746900E+00, 0.89535000E-02, -.15694300E+00, -.11899500E+00, -.16690300E+01, 0.90907600E+00, 0.25128400E+01, 0.61875500E+00, -.12076400E+00, 0.13117200E+01, 0.92462300E+00, -.38695600E+01, -.12362500E+01, 0.11032200E+01, -.74139300E+00, 0.17345700E+01, -.13558600E+01, -.16190100E+00, -.62780400E+01, -.25276300E-01, 0.25316900E+01, 0.63379300E-01, 0.58928500E+00, 0.98158100E+00, -.61969200E+00, -.20111500E+00, 0.88604500E-01, 0.10537800E+01, 0.29604400E+00, 0.35537900E+00, -.99684500E-02, 0.95848900E+00, 0.83651000E+00, 0.16323900E+01, 0.17884300E+00, -.63201500E+00, 0.20231300E+01, -.16705800E+01, -.24812200E+01, -.30576200E+01, -.10051800E+00, -.18737500E-01, -.72512700E+00, 0.65574600E+00, 0.10467800E+00, 0.13424000E+01, 0.88151300E+00, -.43566200E+00, 0.38291600E+00, -.82150700E+00, 0.29867200E+00, -.17382500E+01, 0.39527700E+00, -.12460300E+01, 0.30229600E+01, 0.34792700E+00, -.37892400E+01, -.16899200E+01, 0.20362400E+01, 0.36108300E+00, 0.31269700E+03, -.15314300E+03, -.19039300E+03, -.15607500E+03, 0.22260800E+03, -.35639700E+02, -.65012900E+01, 0.15752600E+03, -.59544600E+02, -.10904500E+02, -.22434300E+03, -.68099000E+02, 0.18017800E+02, 0.23989300E+03, 0.20615300E+03, 0.21628400E+02, 0.56177200E+02, 0.49151500E+02, 0.20360800E+03, -.23924500E+03, -.47520700E+02, 0.70053200E+02, -.18548000E+03, -.38106400E+02, -.18591400E+03, 0.17499600E+02, 0.20402300E+03, 0.67888900E+02, 0.79373800E+01, 0.16836400E+02, -.45068200E+02, 0.67006100E+02, -.10399400E+02, -.33183800E+02, 0.24696500E+02, 0.10718900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.28828600E+01, 0.34394700E+01, 0.54487000E+01, -.33688100E+01, 0.69051700E+01, 0.14279000E+01, 0.56633500E+00, 0.22185200E+01, -.44685000E+01, -.10293000E+01, 0.15014100E+00, -.15168700E+00, 0.12328200E+01, -.32258400E+00, 0.12303400E+01, 0.11064700E+01, 0.52700100E-01, -.17244800E+01, 0.24077000E+00, -.20996800E+01, 0.54019300E+00, 0.19955000E+00, -.10214300E+01, -.16442100E+01, -.75375000E-02, -.25615000E-01, -.52907900E-01, -.39694300E-01, -.16900300E-01, 0.31396500E+00, -.35378300E-01, -.50507100E-01, -.10878800E+01, 0.17795300E+00, 0.21946300E+01, -.11727000E+01, 0.12919500E-01, 0.49926800E+01, -.89345000E+00, -.23977500E+01, 0.39895200E+01, 0.78071200E+00, -.33463600E-01, 0.40726700E+00, 0.98545900E+00, -.19133700E-02, 0.17020600E+00, -.34533800E-02, 0.21151600E+01, -.15769500E-01, 0.15885900E+00, -.42130800E+01, 0.15382600E-01, -.18194700E+01, -.27192800E-01, 0.12903400E+01, 0.10616000E+01, 0.34861600E+01, 0.83434200E-01, -.65686200E+00, -.13787400E+00, 0.31987500E+00, -.58774100E+00, -.30113500E+01, 0.20189800E+00, 0.42128500E-01, -.18793200E+00, -.11939900E+01, -.31384200E+00, -.22775000E-01, -.44792500E+01, 0.34373700E+00, -.16599100E+01, 0.35359700E+00, -.41780600E+00, 0.15518700E+01, -.18233600E+00, -.25446200E+01, 0.17592900E+00, -.11994500E+00, 0.23485900E+00, 0.87523900E+00, -.81793200E+00, -.48911200E+00, 0.15796700E+01, -.88195800E+00, 0.59106500E+00, 0.42267400E+00, 0.17942900E+00, -.13772500E+01, 0.10700900E+01, -.87586200E-01, 0.17152400E+01, -.92846300E+00, -.18428400E+01, 0.22824800E+01, 0.67812300E+00, 0.42382300E+00, 0.46200300E+00, -.15941800E+01, -.29997900E-01, 0.88687300E-01, -.43810800E-02, -.31568200E+00, 0.39942600E+00, 0.10575500E+01, 0.14804700E+00, 0.24521600E+01, 0.15371100E+01, 0.13804500E+00, -.20075800E+00, 0.55439100E+00, 0.45199200E+00, -.17314900E-02, 0.10629400E+00, -.14662300E+00, 0.33469200E+01, 0.13169100E+01, -.30040500E+01, -.82840800E+00, 0.96175100E-01, -.36078900E+01, 0.42616300E+01, -.15557500E+01, -.33307400E-01, 0.11486300E+01, 0.13177400E+00, 0.18730300E+00, -.13614800E+01, 0.65263800E-01, -.79262900E+00, -.12256500E+00, -.10282400E+01, -.11096100E+00, 0.58398500E+00, -.35045900E-01, 0.48824400E+00, -.33355100E+00, -.53462600E+00, -.42756600E+00, 0.12458600E+00, -.34536600E+00, 0.66632300E+00, 0.47378700E+00, 0.61678000E+00, -.33364600E+00, -.24877600E-01, 0.76876900E+00, 0.10291000E+01, -.27941500E+00, -.46945600E-01, -.85860500E+00, -.53776300E+00, -.14809200E+00, 0.55545800E+00, 0.16377800E-01, -.16261300E+00, 0.74084400E-01, -.40494200E+00, -.44983200E+00, -.59137000E-01, 0.45409500E+00, -.47378300E+00, -.38763600E+00, 0.48417900E+00, -.45848000E+00, 0.76678700E+00, 0.38537400E+00, -.10411300E-01, -.10433200E+00, -.70004000E+00, 0.14276200E+01, 0.37437500E+00, 0.21760900E+01, -.17885900E-01, -.11908200E+01, -.20237700E+00, -.67556900E-01, 0.12789200E+01, 0.58752100E-01, -.41362100E+00, 0.44201100E+00, 0.52826000E+00, -.14213000E-01, -.50334700E+00, 0.76233400E+00, -.92835000E+00, 0.83580200E+00, -.42430300E+00, 0.31805700E+00, 0.19838000E-03, 0.91033300E-01, -.17979900E+01, 0.15065600E+00, -.37548500E+00, -.96424200E-01, -.69251700E+00, 0.37097400E+00, -.15550500E+01, 0.16761100E+01, -.69421300E-01, -.14033700E+00, 0.20154900E+00, 0.21569100E+00, 0.34063700E+00, 0.13852700E+01, 0.94538900E-01, -.22319000E+00, -.98209100E-01, 0.11056300E+00, -.23714900E+00, -.15036800E+01, 0.13932700E-01, -.10372000E+01, 0.10817200E+00, 0.25721100E+00, -.35658800E+00, 0.58172200E+00, 0.18067900E+00, -.10868400E+00, 0.14636600E+00, 0.18136300E+00, -.12574100E+00, -.66665200E-02, -.13194600E+00, 0.11688800E+00, -.32528800E+00, -.46623500E+00, 0.12285300E+00, 0.82569100E+00, 0.85662000E+00, 0.79179000E-01, 0.15845500E+01, -.14547700E+00, 0.45776000E-01, -.29558900E-01, 0.12536800E+01, 0.16695200E+00, 0.78153900E+00, -.77826400E-01, -.38984200E-01, -.17315100E+00, 0.97715400E+00, 0.19581400E+00, -.25619000E+00, -.64007400E-02, 0.20328700E+00, -.37444300E+01, 0.93048600E-01, -.64168100E+00, -.44865700E+00, -.15246100E+01, 0.12197800E+01, 0.19033800E-01, 0.13258900E+02, -.76129700E+01, 0.48369300E+00, 0.14850300E+02, -.30103000E+02, -.22024100E+02, 0.65998300E+02, 0.38224700E+02, -.61637700E+02, 0.57401700E+02, 0.20974100E+01, -.41046900E+01, 0.56254400E+01, -.14825000E+00, -.84431900E+01, -.28864200E+01, -.35558400E+01, -.66278700E-01, -.56656700E+01, -.19413600E+01, -.36067200E+01, 0.28764600E+01, 0.48556100E+01, 0.21631800E+01, -.15933400E+02, 0.82607400E-02, -.39060400E+01, 0.39986800E+01, -.16012300E+02, 0.46577200E+01, -.40496800E+01, -.39131100E+01, 0.70445400E+01, -.77099700E+01, 0.80816700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.59050500E+01, 0.10868300E+01, -.23320000E+01, 0.32440900E+01, -.59979400E+00, -.21470200E+00, -.29267000E+01, -.13445900E+01, 0.95891500E+01, 0.21799900E+01, 0.17503300E+00, -.19392300E+01, -.21777800E+01, 0.20051600E+01, -.43851000E+01, 0.35449400E+01, 0.12023200E+01, 0.72018900E+00, 0.70183800E-01, 0.14989200E+01, 0.73013000E+00, -.63349700E-01, 0.18716600E+01, -.22787700E+01, -.25962000E+00, -.50765600E+00, -.84981400E+00, 0.56323800E+00, -.11133900E+01, -.29400500E+01, 0.82435000E+00, 0.21560600E+00, -.55805300E+00, 0.17528200E+01, -.29498400E+00, 0.18589400E+01, 0.39362300E-01, -.25093500E+01, -.16677000E+00, 0.35511300E+01, -.54232400E+01, -.10534100E+01, -.96870500E+00, -.11499700E+00, -.23878100E+01, -.99200400E+00, -.17531300E+01, 0.16540900E-01, -.40868700E+01, 0.32255500E+01, 0.19240200E+01, 0.56878700E+01, 0.48487800E+00, 0.28742500E+01, 0.41779700E+00, -.10426000E+01, -.47564500E+01, -.52827000E+01, -.52851400E-01, 0.20004700E+01, -.71420600E+00, -.16238400E+01, -.18069700E+00, 0.43432200E+01, 0.18316000E+01, 0.26075100E+00, -.40906000E+00, 0.25316700E+00, -.14271200E+01, 0.17761900E+00, 0.55621400E+01, 0.21031000E+01, 0.44396700E+00, -.18171700E+01, -.59181600E+00, 0.10976800E+00, 0.47350300E+00, 0.43163400E+01, 0.63483800E-01, -.27172200E-01, -.64439200E+00, -.20302700E+01, 0.22137000E+00, -.13841900E+01, -.29003100E+01, 0.31063700E+01, -.16233100E+01, -.21047100E+00, -.59612700E-01, 0.15228300E+01, -.86648900E+00, 0.35400900E+00, -.15960300E+01, 0.36132400E+00, 0.16766800E+01, -.28790400E+01, 0.32487900E+01, 0.12932000E+01, 0.53620500E+00, 0.27712900E+01, -.20110000E+00, 0.10894800E+00, 0.60014000E-02, 0.62720000E+01, -.10698100E+01, -.37108000E+00, -.18293900E+00, -.12519600E+00, -.94119200E+00, 0.38534000E+00, -.36494400E+01, -.10245900E+01, -.26203700E+00, -.43577400E-02, -.35331400E+00, -.60285300E+00, -.63301500E+01, -.25696900E+01, 0.58404500E+01, 0.23652200E+01, -.81149200E+00, 0.75616700E+01, -.16515000E+01, -.54453100E+00, 0.36845300E-01, 0.12117900E+00, 0.96672000E+00, -.20048000E+01, 0.15155600E+01, -.15948100E+00, -.40769500E+00, -.24893100E-01, -.21381400E+00, -.56273400E-01, 0.86565900E+00, 0.10123300E+00, 0.44543900E+00, -.84221700E-01, 0.18755600E+01, 0.40342500E+00, 0.69070000E+00, 0.58719800E+00, -.66480500E+00, -.88432100E+00, -.10985000E+01, 0.37496500E+00, 0.28553400E-01, -.68900300E+00, -.14831800E+01, 0.24281300E+00, 0.11460400E+00, 0.97995500E+00, 0.34298500E+00, 0.38539500E-01, -.94965300E+00, 0.75087600E-01, -.14713600E+01, -.78906100E-01, 0.13590800E+00, 0.39477700E+00, -.27117100E+00, 0.92104700E+00, -.11199200E+01, 0.65607500E+00, -.21524800E+00, 0.80955700E+00, 0.23309100E+01, 0.21793300E+01, 0.25245200E-01, 0.79258700E+00, -.61551200E-02, -.94709700E+00, 0.18305800E+01, -.15673800E+01, 0.14776800E+00, 0.14784200E+01, 0.24955800E+00, 0.18817400E+00, -.48636500E+01, -.78699600E-01, 0.59890100E+01, -.62814600E+00, -.66070800E+00, 0.65965000E-01, -.33195900E+00, -.53708000E+01, 0.20588500E+01, 0.16931100E+01, 0.45302600E+00, -.29839500E+00, -.71780700E-02, -.59296500E+00, 0.35397400E+01, -.14982800E+01, 0.12278900E+01, 0.47819900E+00, 0.14066000E+01, -.12788900E+01, 0.19982000E+01, -.44601600E+01, -.14446800E+00, 0.15918100E+00, -.64178600E-01, -.31515900E+00, 0.43071600E+00, -.37438200E+00, 0.13405800E+00, 0.89527900E+00, 0.48114500E+00, -.13908900E+00, -.91644800E-01, -.13120000E+01, -.30785300E-01, 0.65224900E+00, -.48193200E-01, -.14360600E+00, 0.73513000E+00, -.17459800E+01, -.63151100E+00, 0.23125900E+00, -.39028700E+00, 0.16112400E+00, 0.29781100E+00, 0.14469700E-01, 0.14483900E+00, -.36623300E+00, 0.10526400E+01, 0.80016700E+00, -.24284500E+00, -.26068900E+01, -.14333600E+01, -.20645400E+00, 0.36273300E+01, -.93218300E+00, 0.45997800E+00, 0.71591800E+00, 0.33542700E+00, -.31663400E+00, -.78794400E+00, -.21904500E+00, 0.32735200E-01, 0.17062700E+01, -.14508000E+01, 0.20194400E+00, 0.13823000E+01, 0.21779100E-01, 0.31897300E+00, -.23716400E+01, -.78572000E-01, -.52417800E+00, 0.51913500E+01, -.17183300E+01, -.26689200E+01, -.12896800E-01, 0.71032100E-01, 0.36443500E+02, -.12305400E+01, -.10602800E+02, 0.24403600E+02, -.95791600E+01, -.18251200E+03, -.70902800E+02, 0.25404900E+02, -.35606100E+03, 0.28067600E+02, -.29250300E+01, 0.46203900E+01, 0.61009200E+01, -.27335300E+01, -.76950400E+01, -.31151200E+01, 0.51539100E+01, -.41800600E+01, 0.19878600E+02, -.14194500E+01, -.12479000E+02, 0.22699100E+02, -.11908300E+02, -.15189100E+02, 0.51489800E+01, -.21308800E+01, -.17525900E+02, -.14069100E+02, 0.23818100E+02, -.20966300E+01, 0.17324600E+02, 0.14816900E+02, -.16211400E+01, -.27628200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22371700E+01, -.11931900E+01, 0.19532300E+00, -.31137600E+01, -.18402800E+01, -.89711500E-01, 0.37234500E+01, 0.29600200E+01, -.29471600E+01, -.45858600E+00, -.40636200E+00, -.46005900E+00, 0.30204300E+01, 0.34980000E+00, 0.25881600E+01, -.55651100E-02, 0.74282700E+00, -.54362600E+00, 0.87183500E-01, 0.18843600E+00, 0.18100000E+01, 0.18088200E+00, -.12752500E+01, 0.21799600E+01, -.17460600E+00, -.52217600E+00, 0.23189300E+01, 0.21135300E+00, 0.88242600E+00, 0.78346600E+00, 0.25852900E+00, -.36992100E+00, 0.43454200E+00, 0.90826500E-01, -.69351900E+00, 0.89120400E+00, -.84750200E-02, -.70179900E+00, 0.48909500E+00, 0.12050400E+00, 0.12668600E+00, 0.29738000E+00, -.16145100E+00, -.97641700E-01, 0.10526900E+00, 0.46875400E-01, 0.34408500E+00, 0.49119500E-03, 0.20342300E+00, -.29338700E+00, 0.11912700E+00, 0.14649800E+01, -.15424900E+00, -.46897900E-01, -.28515300E+00, -.62034000E+00, -.22740600E+00, -.95040300E+00, -.13322500E+00, -.50683400E+00, -.75866500E-02, -.29639200E+00, 0.40253600E+00, 0.33675800E+01, -.27956400E+01, 0.37581300E-02, 0.21459900E-01, 0.16354300E+01, 0.10118200E+01, 0.29575100E+00, 0.27386200E+01, -.29542900E+00, 0.12306800E+01, -.10601100E+00, 0.28741800E+00, -.89283900E+00, 0.16947800E+00, 0.10123800E+01, -.14280600E+00, 0.38712300E+00, -.29136700E+00, -.17062700E+00, 0.83302000E-01, -.18740700E+00, 0.47613100E+00, -.42797100E+00, -.16397200E+00, -.16821200E+00, -.25651200E+00, 0.76683000E+00, -.13199200E+01, -.12620000E+00, -.75254300E+00, 0.92810900E+00, 0.13787800E+01, -.19456400E+00, -.87267600E-01, -.37767700E+00, -.54326900E+00, -.11431300E+01, 0.11924900E+00, 0.35444500E+00, -.43163800E-01, -.28061300E+01, 0.46568200E+00, -.16436300E+00, 0.87406900E-01, -.15892400E+01, 0.16042700E+00, -.23814000E+00, 0.16561300E+01, 0.25904700E+00, 0.60555800E-01, -.12135500E-01, -.11979000E+00, 0.29695900E+00, 0.14660800E+00, -.12813700E+01, 0.11187400E+01, -.36215000E+00, -.35777000E-01, -.17115900E+01, -.31127000E+01, 0.21044600E+00, -.29836900E-01, -.98910400E+00, -.19772600E+00, -.41486600E-01, 0.46515800E+00, -.33386900E+00, -.12306300E+00, -.24632400E+00, -.32357200E+00, -.13305500E+00, -.33542200E+00, -.13460500E+00, -.43194300E+00, 0.15238200E+00, 0.28090800E+00, 0.33941100E+00, 0.45807900E+00, 0.91148100E-01, -.11252200E+00, 0.32826700E+00, -.20327800E+00, -.14842800E+00, -.16966800E-01, -.19199000E+00, 0.99412700E+00, 0.53182800E+00, 0.27980400E+00, 0.73121500E+00, 0.58341800E+00, -.25929900E-01, 0.51687900E+00, -.43221900E-01, 0.86151400E+00, 0.14108500E+00, 0.34499300E+00, -.69995000E+00, 0.59111800E-01, -.55631000E+00, 0.56449800E+00, -.26439400E+00, 0.39831400E+00, -.14636700E+00, -.32004600E+00, -.10275100E+00, 0.14378200E+00, 0.11604800E+00, 0.65192800E-01, -.23665200E+00, -.12607900E+00, -.13617400E+00, 0.13047100E+00, 0.40038300E+00, -.38534500E-01, 0.39618700E-01, -.23793600E+00, 0.72560000E-01, 0.62986300E+00, -.15531900E+00, -.73674800E-01, -.15720400E+00, 0.24697800E+00, -.44953200E+00, 0.43423800E+00, -.42952100E+00, 0.57897500E-01, -.37621900E+00, 0.48981500E-02, -.45784600E-01, 0.82452100E+00, -.64820700E+00, 0.11506100E+00, 0.63565500E-03, -.93532900E-01, 0.76369700E+00, 0.28397200E+00, -.12400000E+01, -.33814100E-01, 0.26841400E+00, -.24152700E+00, 0.15109000E+00, -.88070100E-01, -.38203300E+00, 0.24292800E-01, -.21135000E-01, 0.95076900E-01, -.91964400E-01, 0.89135400E-01, 0.86765200E+00, -.55398100E-01, -.31118500E+00, -.82893400E-01, -.20434100E-01, 0.74342600E-01, 0.20956300E+00, -.23452300E-01, -.35128200E-01, -.88198200E-01, 0.54769500E-02, 0.87577900E-01, 0.27601200E-01, 0.24987700E+00, 0.10927100E+00, 0.47564800E+00, 0.31872300E+00, -.59129300E-01, 0.27718600E+00, -.40996100E-01, 0.18138200E+00, -.57221000E+00, 0.19437400E+00, 0.10439200E+00, -.42561100E-01, -.35093500E+00, -.67428600E-01, -.39845300E+00, 0.55304700E-01, 0.31074500E-01, -.36887800E+00, 0.26995000E+00, -.40587100E-01, 0.28710100E+00, -.96096600E-01, 0.59674000E-01, 0.20684000E+01, -.70801500E-01, 0.71105800E-01, 0.74143300E+00, 0.14145400E+00, -.33444800E+00, -.45112800E-01, -.48546500E-01, -.61981400E-01, 0.61110400E+01, 0.19425300E+01, -.13570900E+01, 0.17381400E+00, -.15569200E+02, -.89294000E+01, 0.15487200E+01, -.52749700E+02, 0.17959900E+01, -.33615400E+00, 0.32336000E+01, 0.29751600E+01, 0.64387600E+00, -.82451600E+00, -.35279000E+00, 0.28415900E+01, -.32143600E+01, 0.10587400E+01, 0.78123300E-01, -.36254400E+01, 0.18952100E+01, -.35018300E+01, 0.30796900E+00, 0.28366800E+01, 0.24189800E-01, -.10171300E+01, 0.41881300E+00, 0.20536400E+01, 0.23637700E-02, 0.10616400E+01, 0.59988800E+00, 0.32058400E+00, -.32219200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.64938700E+00, -.21478400E+00, -.85781900E+00, -.43660200E+00, 0.33320100E+00, 0.17211300E+00, -.29048800E+00, -.58151500E-01, 0.25169200E+00, -.94857600E-01, 0.21176600E-01, 0.89287300E+00, -.54490300E+00, -.52713500E+00, 0.28917200E+00, -.80743300E+00, -.91018700E+00, -.18715700E-01, 0.25089800E+00, -.48828600E-01, -.91756100E+00, -.26903900E-01, 0.46372400E+00, -.66338500E+00, 0.51934600E-02, 0.27571800E-01, -.82002500E-01, -.11718100E+00, -.11444300E+00, -.29792000E+00, -.15234000E-01, 0.63661000E-01, 0.13531800E+00, 0.49653300E+00, -.26103800E+00, -.86308600E+00, -.38238300E-01, -.27486600E+00, -.35495300E+00, 0.62590600E+00, 0.85509700E-01, 0.61499300E-01, -.20848300E+00, -.37989500E-01, -.16966800E+00, 0.22488200E+00, -.13602700E+00, -.72674300E-02, 0.30397100E+00, -.53568300E+00, -.34097700E+00, 0.96890700E-01, -.32377000E-03, -.11062200E+00, 0.61710100E-01, 0.12371300E+00, 0.43970000E+00, 0.14599600E+01, 0.24481800E-01, -.84387900E-01, 0.19248300E+00, 0.23101700E+00, -.48898200E-01, -.14523000E+01, 0.20334500E+01, -.66741000E-01, 0.15869800E+00, -.59390500E-01, -.32819000E+00, 0.95334800E-01, -.64826300E+00, 0.41809100E+00, -.21060700E+00, 0.19508200E+00, -.56635500E-01, -.61181100E-01, -.62789300E-01, -.11755700E+00, -.25394000E-01, -.10751300E+00, -.37678900E-01, 0.34440900E+00, -.21899600E+00, 0.12339600E+00, -.17916900E+00, -.47460500E-01, 0.17806000E+00, 0.22468200E+00, 0.42974500E-01, -.62754400E+00, 0.47786200E+00, -.79389800E-01, 0.16542400E+00, -.49853600E+00, -.83332200E+00, -.17487000E-02, -.31196300E+00, -.99996100E-01, 0.21463900E+00, 0.72370700E+00, 0.74650200E-01, -.30609300E-01, 0.13999000E-02, 0.72569300E+00, -.27922600E+00, -.45902600E-01, 0.15007500E-01, 0.28309100E+00, -.30869500E+00, 0.42424600E-01, -.56756900E+00, -.15289100E+00, 0.80417500E-01, 0.18623300E-02, -.40358200E-01, -.95070900E-01, 0.15592300E+00, 0.45062400E+00, 0.11101900E+00, 0.18107800E+00, -.12220700E+00, 0.13622400E+01, 0.75419800E+00, 0.33152600E+00, -.55929700E-02, 0.21707300E-01, 0.11468100E-01, 0.12821600E+00, -.63530100E-01, -.71837500E-01, 0.24477200E+00, 0.78419800E-01, 0.27221900E+00, 0.18516800E+00, -.90659700E-01, -.46836300E-02, 0.20038700E+00, 0.71436400E-01, -.26588000E+00, -.94715700E-01, -.36764600E-01, 0.99155700E-01, 0.19437000E-01, -.12523100E+00, 0.18912600E+00, 0.54361400E-01, -.26181500E-02, -.13396000E-01, -.58325400E+00, -.21486400E+00, -.18767900E+00, -.33911500E+00, -.10968200E+00, 0.49627800E-01, 0.17139300E+00, -.15392700E-01, -.14567700E+00, 0.17859400E-02, -.13085000E+00, 0.25240200E+00, 0.38166100E-01, 0.13113900E+00, -.44795400E+00, 0.26847900E-01, -.25329100E-01, 0.16380800E+00, 0.60948900E+00, 0.15353300E+00, -.36125500E-01, 0.63044000E-01, -.81698200E-01, -.27858300E+00, -.26041400E+00, -.18944800E+00, -.18289500E+00, -.37174600E+00, -.21345400E-01, -.10622400E+00, 0.10126400E+01, -.12501300E-02, -.27241500E+00, 0.20620300E-01, -.16896900E+00, 0.30085500E-01, 0.77055500E-02, 0.98726500E-01, -.22521800E+00, -.13660700E+00, -.33170900E-02, 0.81794800E-01, 0.92048600E-03, 0.32555500E-01, -.18061500E+00, 0.11861700E+00, -.46605800E-01, 0.16577900E-01, -.29903900E+00, -.16469000E+00, 0.34913200E-01, 0.28311200E+00, 0.12274900E-01, 0.43236600E-02, 0.31036900E-01, -.28574000E+00, -.92310700E-01, 0.32382400E+00, -.56700000E-02, 0.42440600E-01, -.87569100E-01, 0.41192800E-01, -.12456900E-01, 0.18229800E+00, 0.60969700E-03, -.33745000E-02, -.39018800E-02, -.16039500E-01, -.34611400E-01, -.64338100E-01, 0.42771700E-01, 0.65377000E-01, 0.64405600E-01, -.12846700E-01, 0.52185200E-01, 0.92437200E-03, -.11562700E+00, -.54873000E-01, 0.13250700E+00, -.15609200E+00, 0.24029400E-01, -.50579300E+00, 0.53817900E-01, 0.25427400E+00, 0.11212900E+00, -.71969800E-02, -.37908900E-02, -.11590100E-01, 0.88691700E-01, 0.78283800E-02, -.12814900E-01, -.29526800E-01, -.13552500E-02, 0.50396800E-01, 0.17201800E+00, 0.33508800E-01, -.74331600E-01, 0.74084600E-02, 0.27017000E-01, -.72550900E+00, 0.43348900E-02, 0.94022100E-01, -.23066200E+00, -.46198500E+00, 0.12173700E+00, -.62121600E-01, 0.15227900E-01, -.11189800E+00, -.11351600E-01, 0.86669400E+01, 0.23556600E+01, 0.43169300E+01, -.94645300E+01, -.57683200E+01, 0.75992600E+00, -.96924000E+01, 0.27345400E-01, 0.64417500E+00, 0.96959800E+01, 0.91442900E+01, 0.22625300E+01, 0.24163900E+01, 0.24960500E+01, 0.89824700E+01, -.96134100E+01, 0.24778400E+00, 0.37887900E+01, -.86402800E+01, 0.24420100E+00, -.85776500E+01, 0.33407900E+01, 0.90701300E+01, 0.35886400E+01, -.19682300E+01, 0.33594700E+01, -.32615100E-01, 0.36656100E+01, 0.19648200E+01, -.26744900E+01, 0.97428300E+00, -.13729800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.66237000E+01, -.10724900E+01, -.61697300E+01, 0.35120900E+01, -.59238000E+01, -.79558100E+00, -.30902500E+01, -.25659600E+01, 0.10891500E+02, 0.16822900E+01, 0.72748800E+00, -.11485400E+02, 0.52001200E+01, 0.22384300E+01, -.64633700E+01, 0.73609800E+01, 0.68314200E+01, -.29831700E+00, -.32046800E+00, 0.14021500E+01, 0.12719400E+01, 0.10335900E+00, -.41698300E+00, -.17748500E+01, -.39684800E+00, -.61575700E-01, 0.53831700E+00, -.10693200E+00, -.66132500E+00, 0.14397000E+00, 0.48874200E+00, 0.10874700E+01, -.11722500E+01, 0.31252600E+01, -.10203100E+01, -.76625800E+00, -.85952400E-01, -.18367600E+01, 0.10224300E+01, -.22434700E+01, -.13684800E+01, -.14279700E+01, 0.11957200E+01, -.60957700E+00, -.17965900E+00, 0.96075900E+00, 0.75145400E+00, -.20485100E-01, -.85683500E+00, -.10650200E+01, -.14197600E+01, -.64539200E+00, -.68164400E-01, 0.15772800E+01, 0.39605100E+00, -.13381300E+01, -.10301200E+00, 0.56420100E+01, -.12327900E+00, 0.37625900E+00, 0.39485300E+00, -.92250800E+00, 0.95834700E+00, 0.28846400E+01, -.23909900E+01, 0.54997400E+00, -.61380400E+00, -.10425100E+00, 0.96806500E+00, -.37462800E+00, 0.23824800E+01, -.14784800E+01, -.76629700E+00, -.15355500E+01, -.18353500E+01, 0.25236000E+01, 0.39136000E-01, -.15109600E+01, -.56067800E+00, -.90461500E+00, 0.89502300E-01, -.21684800E+01, -.16802600E+00, -.38699100E+00, -.22795600E+01, -.11176600E+01, -.29739700E+00, 0.89203500E+00, 0.58812000E+00, 0.82561800E+00, 0.23150200E+01, 0.18855500E+00, -.22042700E+01, -.10258400E+01, -.73101700E+00, -.60058900E+00, 0.37544000E+01, 0.28477800E+01, 0.11766100E+01, 0.23966700E+01, -.82357600E-01, 0.13107500E+01, 0.40800100E+00, 0.62490300E+01, -.29472700E+00, 0.56435800E+00, 0.77768100E+00, 0.40607800E+01, -.11255200E+01, 0.83390700E+00, 0.19336300E+01, -.61981400E-01, 0.10254800E+00, -.39662300E-02, -.33895900E+00, -.29200700E+00, 0.48590500E+00, -.31884200E+00, 0.14564600E+01, 0.30977300E+00, -.67683300E+00, 0.66713100E+01, 0.54767400E+01, -.37773800E+01, 0.17103500E-01, 0.19244900E+01, -.54661600E-01, -.23636200E+01, -.15111500E+01, -.14085500E+01, 0.38554000E+01, -.14247400E+01, -.25022700E+01, 0.24607800E+01, 0.56197200E+01, -.73734400E-01, -.33579900E+01, -.34599900E+01, 0.32749300E+01, 0.22497700E-01, 0.65256300E+00, 0.12535900E+01, 0.20272900E+00, -.14730400E+01, -.44069100E+00, -.33429200E-01, -.88319100E-01, 0.50339000E+00, -.42643500E+01, -.17729900E+01, -.11594500E+01, -.10198900E+00, -.15853600E+01, 0.17524200E+00, -.23610700E+00, 0.27692100E+00, -.34600000E+01, -.92313500E-01, -.68126900E+00, 0.25559900E-01, -.39685700E+00, 0.12835600E+01, -.40461000E+01, 0.31575400E+00, 0.23453000E+00, -.65969700E+00, -.88813000E+00, -.80430100E+00, -.15907800E+00, -.32462500E-01, -.81783200E-01, -.22669300E+01, -.35086100E+00, -.32645500E+01, 0.94217300E+00, 0.26791000E+01, 0.31946600E+00, -.23230000E+00, -.14431200E+01, -.60893100E-02, 0.39652400E+01, -.34934500E+00, 0.20691600E+01, 0.14165200E+00, 0.10449800E+01, 0.58056300E+01, -.18266400E+01, 0.36505900E+00, 0.29310800E+00, 0.19865300E+01, 0.83988200E-01, -.52232700E+00, -.96595100E-01, 0.22186600E+01, 0.71407900E+00, -.29209200E+00, 0.73006300E+00, 0.15952900E+01, 0.94543700E+00, -.12894700E+01, -.36865700E+00, 0.26884900E+00, -.85057900E+00, -.53101700E+00, 0.14132900E+01, 0.40115500E+01, 0.64482900E+00, -.15427500E+01, -.81238400E+00, 0.10786700E+01, 0.12024900E+01, 0.22872300E+00, -.44322300E-01, 0.11014900E+01, 0.48042600E+00, -.76939700E-01, 0.91075000E+00, 0.24033900E-01, 0.47398100E+00, 0.16977800E+00, 0.38663200E+00, -.62235400E+00, 0.11712100E+01, 0.29496600E-01, -.10251800E+00, 0.60931700E+00, 0.12744100E+01, -.12578100E+01, 0.32607500E-01, -.52859700E+00, 0.27760100E+01, 0.36857900E+01, -.35489700E+01, 0.18780300E+01, 0.19728400E-01, 0.20139800E+00, -.14643100E+01, -.26027600E+00, -.26001700E+01, -.67281500E+00, 0.19455900E+00, -.17535200E+01, -.35853200E+01, 0.11614100E+00, -.41054700E+00, -.45315600E-01, -.39234600E+00, -.94145300E+00, 0.50676200E+00, -.19952400E+01, -.31268200E+01, 0.10665000E+00, 0.11809400E+01, 0.87989100E-01, -.20738900E+00, -.37423900E+00, 0.16575200E-01, -.58442200E+01, 0.69863400E+02, -.11375900E+03, -.20727300E+03, -.77240500E+02, 0.56004000E+02, 0.11305700E+03, 0.19080500E+02, 0.24589600E+00, 0.13906700E+02, 0.27259500E+02, 0.17150700E+02, 0.94850400E+01, 0.10008200E+02, 0.27355400E+02, -.13269500E+02, 0.16833000E+02, 0.76712800E+01, -.27823400E+02, 0.45329900E+01, -.27214300E+02, 0.22190800E+02, 0.28370100E+02, 0.55892100E+01, -.19539800E+02, 0.23427800E+02, 0.44742900E+01, 0.69497900E+01, 0.23029300E+02, -.11600800E+02, -.61272600E+00, -.13461200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21787200E+01, 0.32696100E+01, 0.50202600E+01, -.25124300E+01, 0.66861000E+01, 0.12364700E+01, 0.51021800E+00, 0.38211500E-01, -.30858800E+01, 0.39019500E-01, -.25854900E-01, 0.27633400E+01, -.53341300E+01, -.42191000E+00, -.22821300E+01, 0.25393000E+01, -.52412000E+00, -.64570300E+00, 0.24229200E+00, -.53377400E+00, 0.41891900E+00, 0.70247200E-01, 0.15653900E+00, -.15087000E+00, 0.18147700E+00, -.33698100E-02, 0.16766000E+01, 0.44451300E+00, -.50571600E+00, -.15051800E+01, 0.45828000E+00, -.20714600E+00, -.14048900E+01, 0.37872300E+00, 0.17449200E+01, 0.11205200E+01, 0.11988600E+00, 0.30772100E+01, -.82311600E+00, -.16454700E+01, 0.21523400E+01, 0.81592200E+00, 0.81084700E+00, 0.66630300E+00, 0.11802000E+00, -.87507500E+00, -.38624800E+00, 0.16592800E-01, 0.44174800E+00, 0.31181600E+01, 0.27071800E+01, -.21529200E+00, 0.44172800E+00, 0.41533600E+00, 0.21518600E+00, 0.72985800E+00, -.21116700E+01, -.44412600E+01, 0.29185700E-01, 0.76575600E+00, -.61170600E+00, -.38056300E+00, -.56760700E+00, 0.22840900E+01, -.22721200E+01, 0.32873200E+00, -.39817400E+00, 0.84623300E-01, 0.44609900E-01, -.24428300E+00, 0.10105000E+00, -.42748900E+00, -.35121800E+00, -.54202800E+00, -.78968600E-01, -.37695400E+00, 0.14518400E+00, 0.64114700E+00, 0.23656500E+00, -.20650300E+00, 0.60575200E-01, -.54529700E+00, 0.41455200E+00, 0.86611600E+00, -.17999900E+00, 0.83121300E+00, -.37080100E+00, 0.48910500E+00, -.33736700E+00, 0.98404900E+00, -.71068100E+00, 0.27597500E+00, 0.14658600E+01, 0.82715500E+00, 0.12723900E+01, -.71229600E+00, 0.15061200E+01, 0.93400400E+00, 0.73844300E-01, -.68262700E-01, -.10639900E+00, 0.79708000E+00, -.13875700E-02, -.50164100E+00, -.28130600E+00, 0.19172100E+00, -.14496200E+00, 0.23184700E+01, 0.12099000E+01, 0.33109800E+00, -.76058000E+00, 0.34531600E+00, 0.38387900E+00, -.42251300E-02, -.69442100E-01, -.25171800E-01, -.13017900E+01, -.96668900E+00, 0.96651000E+00, 0.52436300E+00, -.40755900E+00, -.17795000E+01, 0.12357500E+01, -.22015100E+01, -.25509700E-01, 0.54475600E+00, 0.65022200E+00, -.12258800E+01, -.15378200E+01, -.21758100E+00, -.17826000E+01, -.13199200E+00, -.19970900E+01, -.12205500E+01, 0.33423200E+00, 0.26484200E-01, 0.18173600E+01, -.86666500E+00, 0.69419000E+00, -.10042100E+00, 0.12863900E+01, -.42291200E+00, 0.25766400E+00, 0.46858200E+00, -.48607900E+00, -.58708600E-01, 0.59917600E-02, -.59666800E-01, 0.13083100E+01, 0.35184700E+00, 0.81055200E-01, -.22200000E+00, -.21812700E+00, -.25729200E+00, 0.72867000E+00, -.49412400E-02, 0.83875400E+00, 0.62840100E-01, -.25961100E+00, -.25728100E+01, -.17322500E+00, -.15547600E+00, 0.43309700E-01, -.85685800E+00, 0.10176400E+01, -.25274100E+00, 0.63482500E+00, 0.31804200E+00, 0.25977700E-01, -.29585600E-01, -.24465900E+00, 0.21958900E+01, 0.33402000E+00, 0.30922600E+01, -.58656500E-01, -.19325200E+00, -.80527300E-01, -.80415200E-01, -.19948000E+01, -.10823500E-01, 0.30353600E+01, -.30964700E+00, 0.84718000E-01, -.31753300E+00, -.21551900E+00, -.26824100E+01, -.64813000E+00, 0.15190000E+01, -.54866300E-01, -.17966500E+01, -.13223000E-01, -.66655200E-01, 0.84570000E+00, -.12897300E+01, 0.49195600E+00, 0.23313400E-01, -.80621900E+00, 0.90252700E+00, 0.55052600E+00, -.20891400E+01, -.28127400E-02, -.11121500E+00, -.26507000E+00, 0.36038400E+00, -.36269200E+00, -.30131000E+00, 0.15019300E+00, 0.18366700E+00, 0.53025000E+00, -.54129400E+00, 0.29780900E-01, -.12187600E+01, 0.13902300E-01, -.14000500E+01, -.12655700E+00, -.90912300E-01, -.43235000E+00, 0.31426600E+00, -.25362900E+00, -.15327500E+00, -.40782700E+00, 0.21911300E+00, -.20066700E+00, -.10437700E-01, 0.64887100E+00, 0.34474900E-01, -.39607100E+00, 0.25381700E+00, -.70527000E-01, 0.12102600E+00, -.15781400E+00, 0.37398400E+00, -.14404900E+01, 0.29404300E+00, -.25645100E-01, -.18879600E+00, -.94746900E+00, 0.33249400E-01, -.20310100E+00, 0.27463200E+00, -.22040800E+00, -.63704300E+00, -.14098900E+01, -.21980900E+00, -.25551300E+00, -.66432700E-03, -.49985400E+00, 0.36916900E+01, 0.96202200E-01, -.13565000E+00, -.53301700E+00, 0.13534900E+01, -.14368200E+00, 0.12775900E+00, 0.43431000E+00, -.26565500E-01, -.40307000E-01, -.15109700E+00, 0.23641400E+00, 0.35844200E+02, 0.51164300E+01, -.59802200E+01, 0.28294100E+02, -.95624500E+02, -.71853700E+01, 0.27602200E+01, -.82930400E+01, -.77317500E+01, 0.34943100E+01, 0.76210800E+00, 0.10145700E+01, -.76584400E+01, 0.80898500E+01, -.37166100E+01, 0.99408300E+00, 0.52974700E+01, -.55164300E+01, 0.55496000E+01, 0.74923900E+01, -.80791600E+01, 0.16971100E+01, 0.30243700E+01, 0.73434100E+01, -.52566900E+01, 0.13894700E+01, -.35847300E+01, -.33255800E+01, 0.54956000E+01, -.35150100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11623900E+01, -.20194400E+00, 0.83580200E+00, 0.15970900E+01, 0.48750300E+00, -.24639200E+00, -.14438600E+01, -.86780900E+00, 0.60833200E+00, 0.62059300E+00, -.70465300E-01, 0.12078700E+01, -.18821300E+00, 0.47370900E+00, 0.10776900E+00, 0.78588500E-01, -.29893200E+00, -.35362100E+00, 0.44058000E-01, -.14753100E+01, 0.52149800E+00, -.75178900E-02, -.28718700E+00, -.25180300E+00, 0.46959300E-01, -.80015400E-01, -.11061500E+01, 0.18323800E+00, -.13671800E+00, 0.67493500E+00, -.40582400E+00, 0.41666300E+00, -.99039800E-01, -.83525900E+00, 0.67927600E+00, 0.81945600E+00, 0.19398400E-01, 0.46192900E+00, 0.82487700E-01, -.36284800E+00, -.86662900E+00, -.35708000E+00, 0.46850800E+00, -.27441500E-01, -.44255200E-01, -.20742100E+00, -.79794800E-01, 0.33153300E-02, -.96603100E+00, 0.46707700E+00, -.15908400E+00, -.83018700E+00, -.79835300E-01, -.12260100E-01, 0.11270200E+00, -.28189500E+00, -.45759900E+00, -.12446800E+00, -.66927400E-01, 0.14721500E+00, -.46944300E-01, -.58122000E+00, 0.32827300E+00, 0.19072400E+01, -.12856100E+01, 0.12717700E+00, -.22395200E+00, -.26328200E+00, -.13954900E-01, -.20799400E-01, 0.15999700E+01, -.30878900E+00, 0.51248300E+00, -.14393900E+00, -.17038800E-01, 0.97318900E-01, 0.20079300E-01, 0.46358200E+00, -.15851500E+00, 0.43338400E-01, -.34638700E-01, -.51249900E+00, 0.23734900E+00, 0.76294500E-01, 0.59745000E+00, -.82554100E-01, -.43969000E+00, -.55339200E-01, 0.19852200E+00, 0.25806400E+00, -.37327800E+00, 0.16015700E+00, -.11472100E+01, 0.67744500E+00, -.26248400E+00, 0.54196700E+00, 0.75037900E+00, 0.62927300E+00, 0.40892300E-01, 0.11002300E+00, -.79591700E-01, 0.37475000E+00, -.86947000E-03, -.51497000E+00, 0.87518800E-02, -.11842700E+00, -.28332800E+00, 0.60304400E+00, 0.65877100E+00, -.35059700E+00, -.17584400E+01, -.57323000E-01, 0.20741000E+00, -.45316900E-02, -.12114700E-01, -.17617000E+00, -.22122200E+01, -.14493200E+01, 0.15640500E+01, 0.15324500E+00, 0.16000300E+00, 0.16222400E+01, -.15672600E+01, 0.66036400E-01, 0.11758900E-01, -.10126400E+00, 0.57697400E+00, -.48857500E+00, 0.25660100E+00, 0.33629000E-01, -.61182100E-01, -.13339600E+00, 0.48180700E-01, 0.31224200E-01, 0.12061900E-02, -.17074700E-01, -.86316600E+00, -.42042300E-01, 0.18043300E+00, 0.12286100E+00, -.32578400E+00, 0.10816800E+00, -.23363600E+00, -.17081500E+00, -.81240200E-01, 0.77843200E-01, -.27567700E-02, -.23413700E+00, -.10203800E+01, -.19849300E+00, -.11577500E+00, 0.15907200E+00, -.17141200E+00, 0.10761700E+00, -.38717900E+00, -.60718600E-01, 0.13567700E+00, -.36226700E-01, -.56644400E-01, 0.95667100E-03, -.95572200E-02, 0.15444800E+00, 0.57517500E+00, 0.17594500E+00, -.26876800E+00, -.11038500E+00, -.97444800E+00, -.10421900E+01, -.27171800E-01, -.43496600E+00, 0.10141000E+00, -.22093200E+00, 0.32020400E-01, -.26995000E+00, 0.16512800E+00, 0.43722100E+00, -.97005600E-01, 0.10093600E+00, 0.36681200E+00, 0.24492500E-01, -.11325700E+01, 0.20813500E+00, -.24562900E+00, -.26837600E-01, 0.15656000E+00, 0.78562600E+00, 0.77350500E+00, 0.31689700E+00, 0.19749300E-01, 0.35778600E+00, 0.85238500E-02, 0.15498700E-01, -.19869500E+00, -.88439900E-01, -.77842600E-01, -.38932700E-01, -.45487800E+00, -.19938100E+00, 0.12697300E+00, 0.44054400E+00, -.15175800E+00, 0.51108900E-01, -.19438600E+00, 0.63076500E-01, 0.14067900E+01, 0.88298200E+00, 0.24936800E-02, -.17516300E+00, -.22318500E+00, 0.91227100E-01, 0.26427200E+00, 0.39248300E+00, -.84344000E-02, -.23686200E+00, -.12268200E+00, -.16609900E+00, 0.25052400E-01, 0.10821800E+00, -.40787300E-01, -.14898700E-01, -.18351200E+00, -.11025100E+00, -.69305200E-01, 0.70634300E-02, -.40358700E+00, 0.29042200E+00, -.36815600E+00, 0.12318900E+00, 0.18634300E-01, 0.72423300E+00, 0.41671900E+00, -.58661200E-01, -.99720000E-01, -.14194100E+00, -.19154600E-02, 0.63757800E-01, -.99383500E-01, 0.86998200E-02, 0.75824200E-01, -.19959700E+00, 0.42349000E-01, 0.68572700E-01, -.88484500E+00, 0.65512100E-01, -.10294800E+00, 0.88724400E-02, -.18674000E+00, 0.30238300E-01, 0.81272500E-01, 0.76754700E+00, -.82331400E-01, -.35691200E+00, 0.26563700E+00, -.73692700E-01, -.33968000E-01, 0.13893300E+00, 0.63191300E-01, 0.82512500E+00, 0.55997200E-01, -.14040600E+00, 0.71762600E+02, 0.27770200E+02, 0.64711800E+01, 0.13619800E+03, -.13695900E+02, 0.16424500E+01, -.13847600E+01, -.25845000E+01, -.61085700E+01, 0.27362400E+01, 0.47154700E+00, -.23976800E+01, 0.12253700E+01, -.88984600E+01, -.13252300E+01, 0.51519600E+01, -.12215700E+02, 0.46273400E+01, -.48820700E+01, -.24499200E+01, -.73356400E+00, 0.79092300E+01, -.52820600E+01, -.12860900E+02, -.11898600E+01, -.84243200E+01, 0.25924000E+01, 0.15336200E+01, 0.12686000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.47366800E+00, 0.58428700E-01, 0.36307100E+00, 0.35353500E+00, 0.15302600E+00, -.20804300E-01, -.82587500E-01, 0.28789900E+00, 0.10967800E+01, 0.33595300E+00, -.18804900E-01, -.35831400E+00, 0.57106800E+00, 0.47260200E+00, 0.11730000E+00, 0.51452800E+00, 0.21150000E+00, -.26599000E+00, 0.13247700E+00, -.13878100E+00, 0.23608600E+00, 0.25310000E-01, 0.59344000E-01, 0.37163000E-01, -.62342700E-01, -.79767600E-01, -.61774800E-01, 0.64631200E-01, -.12376500E+00, 0.13375100E+00, 0.20654500E+00, -.41767700E-01, -.66828300E-02, -.36624800E+00, -.66723200E-02, 0.31138100E+00, 0.20587400E-01, 0.49796900E-02, 0.11171000E-01, -.10656300E+00, 0.77920200E-01, 0.12414300E+00, -.43210700E-03, 0.43053600E-01, 0.42418300E-01, -.83110400E-01, 0.21775400E-01, 0.30048000E-02, 0.94429100E-01, 0.15856700E+00, 0.11167400E+00, 0.48698600E+00, -.13046200E-01, -.12881800E+00, -.85220800E-01, 0.20218800E+00, -.10503200E-01, -.80495100E+00, 0.53240500E-02, -.10817800E+00, -.58420700E-01, 0.21009400E-01, -.87556100E-01, 0.13907200E-01, -.70036400E-01, -.51814700E-01, 0.56486800E-01, -.15443400E+00, -.45105800E-01, 0.20394500E-01, 0.32892800E+00, 0.42991400E-01, 0.22492100E+00, 0.82909400E-01, 0.26424700E-01, -.20157300E+00, -.97578400E-02, 0.96522900E-02, -.35433600E-02, 0.33063700E-01, -.61493800E-02, 0.56950900E-01, 0.79426800E-01, 0.17258300E+00, 0.41346900E+00, -.11654000E+00, 0.38159400E-01, -.74371200E-02, -.84622900E-01, 0.81302900E-01, -.32984600E+00, -.92957000E-02, -.23856100E+00, 0.74140100E-01, -.57022900E-01, 0.13714500E+00, -.37450000E+00, 0.15735600E+00, -.90317700E-01, -.24549400E+00, -.45529000E-01, -.17416800E-01, -.14185800E-02, -.65872800E+00, 0.12260700E+00, -.10370800E+00, 0.74114400E-01, -.14656500E+00, 0.44176700E-01, -.10467000E+00, 0.38936600E+00, 0.84451600E-01, 0.50936200E-01, 0.34224400E-03, -.15467600E-01, 0.44926100E-01, -.67394400E-01, -.18055400E+00, 0.23900600E+00, -.36059600E-01, -.11428300E+00, -.12843400E+00, 0.92976200E-01, -.43424600E-01, -.45312100E-02, -.39464900E-02, 0.79944300E-01, -.50241100E-01, 0.45612600E+00, -.28104600E-01, -.25701400E+00, -.41972000E-01, 0.40771300E-01, 0.20409000E+00, 0.38153500E-01, -.12463100E-01, -.10349900E+00, 0.95946200E-01, 0.16579100E-01, 0.45829000E-01, 0.36106000E+00, 0.60849100E-01, -.85331500E-01, -.45074400E-02, 0.61576200E-01, -.47443900E-01, -.22216400E-02, -.34821600E-01, 0.45122600E-01, -.44367300E-01, 0.78461700E-01, 0.10534200E+00, 0.53370300E-02, -.79180600E-02, 0.49966100E-01, -.20953000E-01, 0.27209800E+00, 0.55248800E-02, 0.99891900E-01, 0.27211300E+00, 0.71055100E-01, -.41365300E-01, 0.20456700E+00, 0.53345000E-01, 0.67329000E-01, 0.74942500E-02, -.67364800E-01, 0.35597600E-01, 0.13719400E-01, 0.41015500E-01, -.59576600E-01, 0.92313500E-01, 0.25963300E+00, 0.20125500E+00, 0.17895500E-01, -.29820900E-01, -.20754100E-01, 0.85406800E-01, 0.76943100E-01, 0.12339700E-01, 0.63750000E-01, 0.10920300E+00, -.87401100E-01, -.70180800E-01, -.24181900E-01, -.31486400E+00, 0.40371400E+00, -.12761500E+00, 0.76556400E-02, 0.17539200E+00, -.25631500E-02, -.52992200E-05, 0.30249200E-01, 0.68289000E-01, -.17241800E-01, -.16568500E-01, 0.39342800E+00, 0.70495600E-01, -.17878800E+00, -.28141400E-01, 0.30136700E-01, -.11640600E-01, 0.35080000E-01, 0.15155000E+00, -.49946200E-02, -.13415800E+00, -.23859500E-01, 0.26653800E-01, 0.51031800E-01, 0.71464600E-01, -.38900100E-01, -.13176400E+00, -.18637700E-02, 0.49432100E-01, 0.59583100E-01, 0.74511500E-01, 0.67570400E-01, -.17751500E-02, 0.12927400E-02, -.24943300E-01, 0.48266700E-02, 0.40124500E-01, 0.23825200E-01, -.29632600E-03, 0.77333200E-01, 0.33552100E-02, 0.79985400E-01, 0.65172900E-01, -.22492000E-01, 0.29449000E-01, -.83158700E-02, -.83535200E-01, 0.79994600E-01, 0.32822300E-01, 0.91299800E-02, -.20225000E-01, 0.40476000E-01, -.34332600E-01, 0.20534400E-01, 0.14126100E-01, -.17739700E-01, -.11524900E-01, 0.13544200E+00, -.40379400E-02, 0.11764900E+00, -.19587700E-01, 0.64698700E-01, 0.52339500E-01, -.24545000E-01, -.27113500E-01, 0.27566600E+00, -.13692300E-01, -.80528900E-01, 0.17159700E-01, -.13075700E-01, 0.21621800E-01, -.22262100E-02, -.65660100E+00, -.20979800E-02, 0.12075700E+00, -.12488900E+00, -.23378100E+01, -.33268600E+01, 0.18377800E+02, 0.26476800E+00, 0.27059700E+00, 0.37035900E+01, 0.34603900E+01, -.11918300E+00, 0.26015200E+00, 0.16895300E+00, 0.33778600E+01, -.36556000E+01, 0.63750400E-01, 0.62171000E+00, -.27965000E+01, 0.55655100E+00, -.27982800E+01, -.10053600E+00, 0.34562100E+01, 0.52505500E+00, -.42913400E+00, -.12640200E+00, 0.44479100E+00, 0.55928800E+00, 0.42631100E+00, -.23077100E+00, 0.36068100E+00, 0.58386600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.51413100E+01, 0.26335200E+01, 0.12180900E+01, -.19326700E+01, 0.23958000E+01, 0.64487600E+00, -.31953700E+00, 0.31702600E+01, 0.61839800E+00, 0.16324200E+00, -.47905500E-01, -.32868800E+01, -.27156300E+01, 0.65227900E+00, -.33545600E+01, 0.73500600E+01, 0.21177400E+01, -.27133900E+01, -.83437400E+00, -.28065200E+01, 0.12504300E+00, 0.33237600E+00, 0.81095200E+00, -.12242900E+00, 0.89033000E-01, -.15503400E+00, 0.36505800E+00, 0.28166900E+00, -.21499000E+00, -.93901800E+00, 0.27702100E-02, -.12595300E+01, -.10098700E+01, 0.85265400E+00, 0.19639400E+01, -.13134500E+00, 0.91946500E-01, 0.45797000E+01, -.15400400E+01, -.23472900E+01, 0.28826200E+00, -.38590900E+00, 0.15826800E+01, 0.67564100E+00, -.40501500E-01, -.76982400E+00, -.34241000E+00, 0.57652400E-02, 0.38881700E+00, 0.10116800E+01, 0.16462700E+01, -.12735300E+01, 0.28983700E+00, 0.30152800E+00, 0.55708600E+00, 0.55346600E+00, -.15247400E+01, -.32073900E+01, 0.55596900E-01, 0.17635000E+01, -.40823000E+00, -.14374300E+00, -.56056800E+00, -.14558900E+01, 0.94090800E+00, 0.34294400E+00, -.41921900E+00, -.52740100E+00, -.48999000E+00, -.34457400E+00, 0.32580100E+00, 0.11980800E+00, -.15513200E+01, -.13087100E+01, -.89909700E+00, 0.14953900E+01, 0.20353400E+00, 0.77649300E+00, 0.27327600E+00, -.84078800E+00, -.90784500E-01, -.15701000E+01, -.25979100E+00, -.84666300E+00, -.30725700E+01, 0.16391500E+01, -.63757500E+00, 0.80745200E-01, 0.52859400E+00, -.17442400E+00, 0.17648900E+01, 0.63994800E+00, 0.22747200E+01, -.31731900E+00, 0.20945300E+00, -.18202900E+01, 0.12868600E+01, 0.22292400E+01, 0.71063900E+00, 0.24834900E+01, -.12390600E+00, 0.46157100E+00, 0.91113900E-02, 0.30806000E+01, -.22194600E+01, 0.37931900E+00, -.17386100E-01, 0.43657600E+01, 0.44050300E+00, 0.18008100E+00, -.39065000E+01, -.58471200E-01, 0.46188300E+00, -.76654000E-02, 0.23909700E-02, -.32819200E+00, -.16336400E+01, 0.13463100E+01, 0.16360500E+01, 0.15525500E+01, -.58895600E+00, 0.33078300E+01, 0.40617300E+01, -.17199400E+01, -.57475500E-01, 0.50390000E+00, 0.68790900E+00, -.10701500E+01, -.27102500E+01, -.51380900E-01, -.11077600E+01, 0.62984500E+00, -.81378400E+00, -.13950100E+01, 0.12639000E+01, 0.30063900E-01, 0.20689600E+01, -.98590800E+00, -.85141500E-01, -.57548200E+00, 0.22229300E+01, -.84240100E-01, 0.25012400E+00, 0.67236900E-01, 0.77707200E-01, -.85907700E+00, 0.24197000E-01, 0.39265900E+00, 0.84771000E+00, 0.28651500E+00, 0.70639300E-01, 0.75164700E-01, 0.14156700E+00, -.31941000E+00, -.10265300E+01, 0.19848200E+00, -.16223700E+01, -.24004700E+00, -.44022400E+00, -.26191500E+01, -.67729200E+00, 0.13847200E+01, -.86115500E+00, -.60039500E+00, 0.25892300E+00, -.69894600E+00, -.87325000E+00, -.68865200E+00, -.24678200E-01, -.53848200E+00, 0.37103300E+00, 0.17865000E+01, -.57746700E+00, 0.37485900E+01, -.22995500E+00, -.68709700E+00, 0.29986100E+00, 0.22894600E-01, -.34437900E+01, -.44438600E-01, 0.19041500E+01, -.61694600E+00, 0.14015500E+01, 0.22193900E+00, -.24962100E+00, -.28947900E+00, -.63741500E+00, 0.15803300E+01, -.12868200E+00, -.15527800E+01, 0.28392600E-01, 0.50914700E-01, 0.26172000E+00, -.44116400E+00, 0.44577300E+00, 0.23877500E-01, -.59829500E+00, 0.12727300E+01, 0.63093300E+00, -.17692600E+01, -.17759200E+00, 0.15956700E-01, -.41991200E-01, -.16911700E+00, -.87034200E+00, 0.16170400E+01, 0.68364900E+00, 0.14629900E+00, 0.42334300E+00, -.17594700E+00, -.23165400E+00, -.25951600E+01, -.38718300E-02, -.13139300E+01, 0.15742200E+00, 0.21463800E-01, -.33411000E+00, 0.66850700E-01, -.19277100E+00, -.24106300E+00, -.46431700E+00, 0.25250000E+00, -.35475100E-01, 0.91605700E-02, 0.35931900E+00, -.10618400E+00, -.46661400E+00, -.57209500E+00, 0.31741100E-01, -.42066000E+00, -.43617700E+00, 0.97596200E+00, 0.10353400E+01, 0.42995000E+00, 0.42993200E-01, 0.31305200E+00, -.53131500E+00, 0.40967300E-01, -.93657800E+00, -.22678000E-01, -.40970300E-03, -.30232600E+00, -.21352300E+01, -.29463800E+00, 0.11111600E+00, 0.67846200E-01, -.44790400E+00, 0.21839400E+01, 0.17996000E+00, -.12292700E+01, 0.13028500E+01, -.23393300E+00, -.15300200E+01, 0.71412600E-01, 0.78250900E-01, 0.32269100E+00, 0.56526300E-01, 0.63866800E+01, -.25074400E+00, -.22049000E+01, -.10622100E+00, -.28185100E+01, 0.62161800E+02, -.13087600E+03, -.73154600E+01, 0.11705800E+01, -.67679300E+02, -.58912000E+02, 0.43457200E+01, -.52256500E+01, -.54196100E+01, -.57548900E+02, 0.66714500E+02, -.27447500E+01, -.14598800E+02, 0.47793700E+02, -.82396000E+01, 0.47666600E+02, 0.10627500E+02, -.58613100E+02, -.12847200E+02, 0.98727200E+01, 0.10866300E+02, -.62658700E+01, -.13129900E+02, -.80914500E+01, 0.12945400E+01, 0.43827700E+01, -.10348500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21847700E+01, -.15043900E+01, 0.38665300E+01, 0.21509900E+01, 0.21143400E+01, -.13695300E+00, 0.59402600E+00, -.23674800E+00, -.29499100E+01, -.43829200E+00, -.16515400E+00, 0.12153700E+01, 0.14956200E+01, -.91711300E+00, 0.20211700E+01, -.27420700E+01, -.87707100E+00, 0.19555600E+00, 0.19452200E+00, -.78521000E+00, 0.48920400E+00, -.35286300E-01, -.18277900E+00, 0.31652700E+00, 0.13471400E+00, -.40806400E-01, -.35173300E+00, -.86105800E-02, 0.13688700E+01, 0.95743600E+00, -.84765000E-01, -.16429900E+01, 0.67163500E+00, 0.14371700E+01, -.11861100E+01, -.20431200E+01, -.82492700E-01, -.22022800E+00, 0.16961400E+00, 0.35902800E+00, -.69145800E+00, -.31334100E+00, 0.51562100E+00, -.24032800E+00, -.54795700E+00, 0.49551600E+00, 0.29395700E+00, -.14505400E-01, 0.48846200E-01, -.17370600E+01, -.19559000E+01, -.52956000E+00, -.13975400E+00, 0.33793600E+00, -.10508300E+00, -.53703300E+00, 0.11060700E+01, 0.19271600E+01, -.19273200E-01, -.20236400E+00, 0.41390200E+00, 0.28778700E+00, 0.37140100E+00, -.11968400E+01, 0.94823300E+00, -.21921500E-01, 0.87771300E-01, -.56470100E-01, -.53437700E-03, 0.26990000E-01, 0.89956300E+00, 0.11580800E+00, 0.13114300E+00, 0.14446800E+00, -.47530200E-01, 0.26110700E-01, -.13687800E+00, 0.90744600E-01, -.22966100E+00, -.19367600E+00, -.13298600E-01, -.31399300E-01, 0.25501300E+00, 0.65708600E+00, 0.68519700E+00, 0.13503700E+00, -.66318500E-01, 0.28076500E+00, 0.75429200E-02, 0.22657000E+00, -.41550100E+00, 0.21369500E-01, -.88411900E+00, 0.11494000E+00, -.52425900E-01, -.55422200E-01, -.23422700E+00, -.49333200E+00, -.15318900E+00, -.15497200E+01, 0.10389000E+00, -.13505100E-01, -.88510800E-02, -.19259900E+00, 0.10724400E+01, -.27484400E-03, 0.32664700E-01, -.23136900E+01, 0.44061700E+00, -.79005300E-01, 0.43271300E+00, -.20712200E+00, -.48929600E+00, -.18304300E-02, -.95567500E-02, 0.27172700E-01, 0.21136200E+01, -.10106200E+01, -.76012600E-01, -.96806100E+00, 0.43214800E+00, -.48832000E+00, -.13750100E+01, -.25616600E-01, 0.60884000E-02, 0.45821400E+00, -.53924000E+00, 0.52003200E+00, 0.95828500E+00, 0.74433700E+00, 0.10453200E+01, -.27960600E+00, 0.22394500E+00, 0.65754200E+00, -.42823700E+00, -.73961800E-01, -.74689500E+00, 0.28118700E+00, -.44332800E+00, 0.99290600E-01, 0.33537100E+00, 0.43672500E-01, 0.12209500E+00, -.83468800E-01, -.16423100E+00, 0.46380700E+00, -.28178300E-01, 0.33873500E+00, 0.72222500E-01, -.17340700E+00, 0.14428300E+00, -.11837800E+00, -.47913700E+00, 0.12914900E+00, 0.48650400E+00, 0.97559100E-01, -.26769200E+00, 0.36024500E-01, 0.88143100E-01, 0.18094300E+00, -.69941100E-01, -.70712300E+00, -.34025200E+00, 0.19284600E+00, -.40348500E+00, 0.88390100E-01, -.80321900E-01, 0.73812100E+00, 0.37060400E-01, 0.10256700E+00, 0.15211600E+00, -.98111400E+00, -.25395500E+00, -.17948000E+01, 0.15113100E+00, 0.41575200E+00, 0.18481000E+00, -.83811300E-01, 0.96589600E+00, 0.28345800E-01, -.15135600E+01, 0.12044300E+00, 0.35617500E+00, 0.72545600E-01, 0.16527400E+00, 0.27992700E+01, -.74342300E+00, -.47253900E+00, -.10857300E+00, 0.15439300E+00, 0.13925300E-01, -.60633200E-01, -.10931400E+01, -.35446700E+00, 0.99361000E-01, -.38822200E-01, -.10249800E+00, -.68171700E+00, -.21450800E+00, 0.68671300E+00, -.14638600E+00, 0.10829900E+00, -.19077000E+00, -.25622300E+00, 0.18688300E+01, 0.86805500E+00, -.14893100E+00, -.17079700E-01, -.73876300E+00, 0.69884900E+00, 0.96924800E-01, 0.52507600E+00, -.86044400E-02, 0.92993300E+00, -.38056500E-01, 0.12285000E+00, 0.42570500E+00, 0.78061800E-01, 0.32506300E+00, 0.19451400E+00, 0.13197400E+00, -.72474100E-01, 0.29103500E+00, 0.12395100E-01, -.19531700E+00, -.15560500E+00, 0.10804000E+01, -.39338400E+00, 0.77292700E-01, 0.10372700E+01, -.37118600E+00, 0.92266000E+00, 0.21371900E+00, 0.11528500E+00, 0.16637300E-01, 0.18153800E+00, 0.11377900E+00, 0.62561500E-01, -.48508700E+00, -.42526500E-01, 0.15720100E+00, 0.17401000E+00, 0.89200800E+00, -.22439200E-01, -.18078800E+00, -.52503300E-01, 0.99950300E-01, 0.14022200E+00, -.93519900E-03, -.16156600E+01, -.10499500E+00, 0.30888200E+00, -.47637600E+00, -.15596900E-01, 0.27659300E-01, -.62038000E-01, -.25369800E-01, 0.36200700E+00, 0.14559700E+00, 0.43425100E+00, 0.36167800E+00, -.21527300E+01, -.29167600E+00, -.16180100E+03, 0.83766500E+01, -.43870500E+01, -.81796600E+01, -.10268800E+02, 0.39406400E+01, -.51046300E+01, -.33957400E+01, -.10265500E+02, 0.80444000E+01, 0.45801200E+01, -.32882900E+01, 0.85569500E+01, 0.66393300E+01, 0.85328200E+01, 0.10629800E+01, -.10561900E+02, -.33039400E+01, -.83425500E+00, 0.13253800E+01, 0.73526400E+01, -.26804200E+01, 0.13219200E+01, -.48730100E+00, -.33932000E+01, -.58745400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.92472000E+01, 0.27747400E+01, -.46432000E+01, 0.19778200E+01, -.12453800E+01, 0.12408800E+00, -.45561600E+01, -.17879500E+01, 0.10706200E+02, 0.10914700E+01, 0.84964800E+00, -.66096100E+01, -.28507400E+01, 0.13615900E+01, -.80193400E+01, 0.33028000E+01, 0.23559200E+01, 0.13606800E+01, 0.41222200E+00, 0.27921200E+01, -.69250900E+01, -.21900000E+00, 0.40861700E+01, -.22544000E+01, -.20086100E+00, -.28620900E+00, -.19041100E+01, -.40790700E+00, -.11807800E+01, -.12550500E+01, 0.14934700E+01, -.86130000E+00, -.97114800E+00, 0.26595300E+01, -.19149900E+01, -.30159700E+01, -.26501800E+00, -.25327600E+00, -.13439400E+01, 0.26864900E+01, -.83000700E+00, -.74931700E+00, -.27397600E+01, -.16604100E+00, -.68832700E+00, 0.82339800E+00, -.67698500E+00, 0.79959100E-01, 0.19324100E+01, -.90549100E+00, 0.13694600E+01, 0.64629500E+01, 0.46092400E+00, 0.16204000E+01, 0.10487700E+01, 0.84692000E+00, -.12124100E+01, 0.26512000E+01, -.11499300E+00, 0.16548600E+01, 0.37617600E+00, 0.11606900E+01, -.11737400E+01, -.40305900E+01, 0.82282000E+01, -.81596200E-01, 0.79400400E+00, 0.45408900E+01, -.10800100E+01, 0.32704900E+00, -.36765800E+01, 0.43853900E+01, -.15521200E+01, 0.37253800E+00, 0.43308800E+00, -.96343400E+00, 0.20540500E-03, 0.47787000E-01, 0.26745200E+00, -.63229400E+00, -.59049300E+00, 0.31516300E+00, -.59268900E+00, -.20058200E+01, -.55298300E+01, 0.31634000E+01, 0.10074200E+01, -.77754100E+00, -.94669300E+00, -.12614300E+00, -.32390700E+01, -.11966600E+01, -.90965100E+00, -.19579300E+01, 0.11444200E+01, 0.84323700E+00, -.36783200E+01, -.32249100E+01, -.11416400E+01, 0.82850200E-01, -.18449800E+00, -.12190100E+01, -.21653600E+00, -.16122400E+01, 0.43756900E+01, 0.87783400E+00, 0.22489800E+01, -.54498700E+01, -.33557800E+01, 0.14706800E+01, 0.11423800E+02, 0.24726900E+01, 0.94270000E+00, 0.16847100E-01, -.37779000E+00, 0.14427700E+01, -.28646600E+01, 0.29411500E+00, -.23816600E+01, -.31286500E+00, -.26075700E+00, 0.66120900E+01, 0.16587900E+02, -.23839800E+01, 0.58744900E-01, 0.20749600E+01, -.21435800E+01, 0.71891300E+00, 0.10923500E+01, 0.17616600E+01, -.17178500E+01, 0.54831000E+00, 0.16724600E+01, 0.88767200E+00, -.21062200E+01, 0.25609600E+00, 0.13914000E+01, 0.18547300E+00, -.14642600E+01, -.76087900E+00, -.95934100E+00, -.31083400E+00, 0.57375200E+00, -.63499800E-01, -.16383800E+01, -.25685200E+00, 0.12670200E-01, 0.73013700E+00, 0.33649200E+01, 0.10938000E+01, -.81547100E-01, -.18784700E+01, -.15621300E+00, 0.10135500E-01, 0.60114900E+00, 0.29767500E+00, -.29497300E+01, 0.10663600E+00, 0.92302000E-01, 0.17473500E+01, -.15508400E+00, 0.42761800E+00, -.14489500E+01, 0.70320900E+00, 0.96291200E+00, 0.36779400E+00, 0.46632100E+01, 0.52801700E+01, 0.62009000E+00, 0.16715500E+01, -.12511500E+01, 0.64353800E+01, 0.31179000E+01, 0.71911900E+01, 0.30842200E+00, -.14465400E+01, 0.58298700E+00, 0.15906500E+00, -.66355100E+01, -.10499200E-02, 0.26021900E+01, 0.65551500E+00, 0.11065600E+01, 0.41561200E+00, -.16780000E+01, -.45974900E+01, 0.92007100E+00, 0.52117100E+00, -.23104000E+00, 0.14448100E+01, -.16228700E-03, -.22196400E+00, 0.23538000E+00, 0.18103400E+00, -.66956700E-01, -.14423800E+00, 0.20163300E+01, 0.15355800E+01, -.30705300E+01, -.24120900E+01, -.95589900E-01, -.49730900E+00, 0.10914200E+01, -.26474700E+01, -.29835000E+01, 0.39230900E+01, 0.45451800E+00, 0.17527300E+01, 0.14809500E+00, 0.44400600E+00, -.16119600E+01, -.93431500E+01, 0.80915900E-01, 0.56832600E-01, -.22488800E-01, 0.96081700E+00, 0.90683300E+00, -.12685500E+01, -.23373900E+00, 0.29052300E+00, 0.12206400E+01, 0.12726000E+01, -.15573200E+00, -.50773200E-01, -.76529700E-02, -.52812400E+00, 0.19677400E+01, -.76426400E+00, -.14536800E+00, -.35634700E+01, 0.86438700E+00, -.13717200E+01, 0.84787300E+00, -.37848200E+00, -.15339200E+00, -.90181900E+00, -.64446000E+00, 0.25372300E+00, 0.13157900E+01, 0.50999300E+00, -.19337300E+00, 0.13210800E+01, -.19034700E+01, -.17206000E+00, -.21124700E+01, 0.40327400E+00, -.61089300E+00, -.97170400E+01, 0.58710700E+00, -.25416000E+01, -.54110100E+01, 0.18482700E+01, 0.24060000E+01, 0.73722800E+00, 0.39685800E+00, 0.34038500E+00, -.39318200E-01, 0.25128700E+01, -.57964700E-01, -.19628100E+01, 0.37951800E+00, -.18439200E+02, -.31521300E+00, 0.24349300E+01, -.13596000E+02, 0.19746400E+02, -.76555800E+01, -.32909200E+01, -.10978300E+02, 0.13241700E+02, 0.94796000E+01, -.28164800E+01, 0.76094600E+01, -.87179700E+01, 0.33097100E+01, -.15117700E+00, -.10328500E+02, 0.10437000E+00, -.18677300E+02, -.33564300E+01, 0.31497200E+01, 0.26837000E+01, -.18842000E+02, -.99010000E+01, 0.22894800E+01, -.57293700E+01, 0.10446300E+02, 0.18943200E+02, 0.78559500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.45115200E+01, 0.23649500E+01, -.46386100E+00, 0.11179800E+01, 0.13802400E+01, 0.49022600E+00, -.30036400E+01, 0.34524100E+01, 0.68713500E+01, 0.10204900E-01, 0.61951100E+00, -.80039200E+01, 0.10082100E+01, 0.13758100E+01, -.46619400E+01, 0.71979300E+01, 0.33409100E+01, -.19682900E+01, -.44414100E+00, -.81048700E+00, -.10065900E+01, 0.23615600E+00, 0.14593300E+01, -.43467000E+01, -.38287300E+00, -.70979100E+00, -.31230600E+01, 0.12217000E+00, -.14578900E+01, -.10096500E+01, 0.49297100E+00, 0.94400600E+00, -.23753200E+01, 0.10436200E+01, 0.62330200E+00, -.29748400E+01, -.16841600E+00, 0.67443600E+00, -.15521900E-01, -.14989700E+01, -.15507600E+00, -.84519400E+00, 0.13927500E+00, -.47319800E-01, -.31624800E+00, 0.15393100E+00, -.68897900E+00, -.25225000E-01, 0.41878600E+00, -.79879000E+00, -.11974700E+01, -.45935300E+01, 0.18840200E+00, -.10347300E+01, 0.85832100E-01, 0.75387300E+00, 0.19918600E+00, 0.52019600E+01, 0.66548100E-01, 0.37048500E+00, -.35434600E-01, -.30608800E+00, -.30946800E+00, -.53017200E+01, 0.58394700E+01, -.86056600E-01, -.27784300E+00, -.22205300E+01, -.18199500E+01, 0.31645600E+00, -.21399800E+01, 0.23922200E+01, -.23328000E+01, -.64623000E+00, -.11899000E+01, 0.29175000E+01, -.34375200E-01, -.21359400E+00, 0.23214500E+00, -.59088900E+00, -.35004200E+00, -.32599700E+00, -.15934300E+01, -.27633500E+01, -.28247900E+01, 0.14978100E+01, -.13297100E+00, 0.43428600E-01, 0.95606800E+00, -.24120900E+01, 0.31106200E+01, -.15066000E+00, 0.74450800E+00, -.25551500E+01, -.33748800E+01, 0.17878100E+00, -.33869000E-01, 0.90505700E+00, 0.95634800E+00, 0.21920400E+01, -.29556700E+00, -.11500300E+01, 0.27172100E-01, 0.70410500E+01, -.32074300E+00, 0.62910200E+00, -.14753600E+00, 0.13857400E+01, -.59489500E+00, 0.30065400E+00, -.28947200E+01, -.35902300E+00, -.14220000E+00, 0.15053300E-02, 0.16267100E+00, -.50822500E+00, 0.21355800E+00, 0.21600300E+01, 0.83840500E+00, 0.12317900E+01, -.83886800E+00, 0.55896000E+01, 0.61302300E+01, -.62544100E+00, 0.33698000E-02, 0.13115400E+01, -.32939700E+00, 0.26960100E+00, -.86031900E+00, 0.52572900E+00, 0.19378200E+01, 0.36911000E+00, 0.16530000E+01, 0.10242500E+01, 0.13144300E+01, 0.34148500E-01, 0.16708700E+00, -.11717300E+00, -.89076800E+00, -.63618000E+00, 0.18651100E+00, 0.50147800E+00, 0.30634000E+00, -.53666400E+00, 0.22920500E+00, -.15107200E+00, 0.77676500E-02, 0.76184800E+00, -.10634300E+01, -.40267900E+00, -.25158300E+00, -.72598400E+00, -.57369000E+00, -.17084500E+00, -.13369100E+01, 0.23123100E+00, -.31919900E+01, -.13607300E+00, -.34368200E+00, 0.14292600E+01, -.43684900E+00, 0.11541400E+01, -.16396000E+01, 0.59376900E+00, -.91520800E+00, 0.22819100E+00, 0.15064700E+01, 0.13277300E+01, 0.88200500E-01, 0.84716900E-01, -.71578400E-01, 0.12032400E+01, 0.92776500E+00, 0.73320600E+00, -.24238500E+00, -.79289900E+00, 0.30196600E+00, -.92166900E-02, -.18647700E+01, 0.10144800E-01, 0.71844800E+00, -.14322000E+00, 0.86721400E+00, 0.48620000E+00, -.65875700E+00, 0.35203700E+00, -.83984300E+00, 0.94134400E+00, -.19216400E+00, 0.54094900E+00, 0.15798200E-01, -.80219200E-01, -.99727700E+00, 0.36284800E+00, -.20820400E-01, 0.69654400E-01, 0.94805800E+00, -.64042200E+00, -.60257800E+00, 0.60520200E+00, -.17142100E+00, 0.27518400E-01, 0.48631500E+00, -.12669000E+01, -.37399900E+00, 0.18637800E+01, 0.21476600E+00, 0.36089700E+00, -.22384500E+00, 0.22357700E+00, -.36285400E+00, -.33896400E+01, -.48599200E-02, 0.34565700E+00, 0.21311300E+00, 0.15782000E+00, 0.67427400E-01, -.81067200E+00, -.37447200E-01, 0.94864700E-01, 0.31049300E+00, 0.14694900E+00, -.15353200E+00, -.49689700E-05, -.46982900E+00, -.20768100E+00, -.69182100E+00, -.85551100E+00, 0.60075100E-01, -.75666500E+00, 0.35519900E+00, -.36035200E+00, 0.89926600E+00, -.31917300E+00, 0.34868200E-01, 0.29049500E-01, 0.44401200E+00, 0.11071900E+00, 0.58065900E+00, -.10939700E+00, 0.28906600E-01, 0.95440100E+00, -.83056700E+00, 0.41039800E-01, -.55719300E+00, 0.12409100E+00, -.35408700E-01, -.52466400E+01, 0.13589000E+00, -.22828400E+00, -.16025200E+01, -.36481100E+00, 0.62977000E+00, 0.95917400E-01, 0.28922700E+00, 0.31236900E+00, 0.45077800E+00, -.10646700E+01, 0.17236300E+00, 0.55383200E+00, 0.82440400E+00, -.57739700E+01, -.68565300E+00, -.32251100E+00, -.45737700E+00, 0.93889900E+01, -.31705700E+02, -.25896200E+02, 0.12598500E+01, 0.34182600E+01, 0.20233000E+01, -.25098800E+02, 0.31334100E+02, 0.17512900E+00, -.33369800E+01, 0.20714500E+02, 0.70837600E+00, 0.20786200E+02, 0.88751900E-01, -.25599000E+02, -.33105100E+01, 0.99975500E+00, 0.94781300E-01, 0.17863600E+01, -.29597700E+01, -.97100800E+00, 0.20617600E-01, 0.94367100E+01, -.14068100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54366200E+01, -.98653800E+00, 0.13718700E+01, 0.65102900E+00, 0.26036400E+00, -.27472800E+00, 0.11922200E+01, -.22552800E+01, -.20380800E+01, 0.65163000E+00, -.43133100E+00, 0.39189000E+01, 0.12402200E+00, -.97171700E-01, 0.27453800E+01, -.26314800E+01, -.14194500E+01, 0.28634200E+00, -.52774300E-02, -.11280800E+01, 0.18109100E+01, -.13271700E+00, -.15915500E+01, 0.15970400E+01, 0.34081500E+00, 0.11357500E+00, -.72712300E-01, 0.25041100E+00, 0.41552400E+00, 0.21672100E+00, -.20155800E+01, 0.66446400E+00, 0.11905600E+01, -.37738200E+01, 0.21815700E+01, 0.63229400E+01, 0.21196600E+00, 0.58102200E+00, -.19310100E+00, -.10365400E+00, -.20441800E+01, -.80944200E+00, 0.19831500E+00, -.20904400E+00, 0.90854600E+00, -.69412600E-01, -.15413100E-01, 0.28302100E-01, -.21892800E+01, 0.10401800E+01, 0.60330500E+00, -.40574800E-01, -.19730200E+00, -.34045500E+00, -.55500900E+00, -.10426700E+01, -.10458800E+01, -.45787000E+01, -.95984400E-01, -.65012400E+00, -.39925100E+00, -.71503200E+00, 0.57702200E+00, 0.61131100E+01, -.59124400E+01, -.17738000E+00, -.60636500E-01, 0.25975800E+01, 0.17377700E+01, 0.14606100E+00, 0.22505700E+01, -.13435700E+01, 0.24124900E+01, 0.60794100E+00, 0.14345600E+01, -.20495800E+01, 0.17555800E+00, 0.25133400E+01, -.31578400E+00, 0.49828600E+00, -.21258400E+00, 0.14995200E+00, 0.63708400E-01, -.88242000E+00, 0.85191500E+00, 0.87852100E+00, -.78985200E+00, -.15640700E+01, 0.43435700E+00, 0.36470700E+00, -.37013400E+01, 0.41367800E-01, -.54574800E+00, 0.22368200E+01, 0.22328300E+01, -.13166800E+00, -.21672800E+01, -.19981000E+01, -.13765900E+01, -.29089600E+01, 0.39584000E+00, 0.23210100E+00, -.34897000E-01, -.80672800E+01, 0.12575800E+01, -.49330400E+00, 0.12985600E+00, -.49345100E+01, 0.81236500E+00, -.79836700E+00, -.11184000E+01, -.74638500E-01, 0.32408700E+00, -.10625800E-01, -.18110500E+00, 0.16100600E+00, -.48773000E+01, -.33058000E+01, 0.46966900E+00, -.77819500E+00, 0.97313600E+00, 0.71228700E+00, -.41010400E+01, 0.10111200E+01, 0.25060700E-01, -.10210400E+01, -.88816100E-01, -.99786400E-01, 0.15898700E+00, -.16081000E+00, 0.10810800E+01, -.65615900E+00, 0.68826300E-01, -.40384500E+00, -.21126700E+01, -.13039800E+00, -.25561100E+01, 0.71079900E+00, 0.71409200E+00, 0.51993800E+00, -.33794500E+01, 0.25300400E+00, -.57494100E+00, -.25525000E-01, 0.21800700E-01, 0.19730600E+00, -.14803400E-01, -.63369400E+00, -.20554400E+01, 0.25898000E+00, -.23430800E-01, 0.15006200E+01, -.90437400E-01, 0.15787800E+00, -.21222000E+00, -.21414400E+00, 0.23467300E+01, -.21345400E+00, 0.51083200E+00, -.57236800E+00, 0.15267900E+00, -.53656800E+00, 0.29111100E+01, 0.48582400E+00, -.98431800E+00, 0.22964200E+00, -.54496900E+01, -.33791400E+01, -.44621900E-01, -.12283700E+01, 0.11445700E+01, -.18295700E+01, -.13251800E+01, -.19832200E+01, 0.74809300E+00, 0.16059900E+01, 0.89231200E-01, 0.35169000E+00, -.50427300E+00, 0.28544400E-02, -.34867000E+01, 0.38778400E+00, -.96430000E+00, -.21727000E+00, 0.55972700E+00, 0.36249900E+00, 0.18024900E+01, -.62352200E+00, -.25261500E-01, -.81461000E+00, 0.12409800E-02, -.29295300E-01, 0.65871200E+00, -.24396200E+00, -.12189800E+00, -.28311600E+00, 0.26708700E+01, 0.36842900E+00, 0.81598300E+00, -.96147500E+00, -.11607700E+00, 0.10026900E+00, -.54938000E+00, 0.11023100E+01, 0.27670300E+01, -.98954100E+00, -.46724100E+00, 0.40131000E+00, -.27172800E-01, 0.77276700E-01, 0.37667800E+00, 0.46207400E+00, -.18162300E-01, -.10230300E+00, -.14418600E+00, -.19272800E+00, 0.41855700E+00, -.10929600E+00, -.38162000E+00, -.16646200E+00, -.55905300E+00, -.17480900E-02, 0.85028700E-01, 0.11441000E-01, -.23324300E+00, 0.85681300E+00, -.35185400E+00, 0.84027400E+00, -.21785900E+00, 0.24104800E+01, 0.19628400E+00, 0.30868500E+00, 0.74989200E-01, -.40692400E+00, -.46014800E-02, 0.17116500E+00, -.91439000E-01, -.25930200E+00, 0.31749700E+00, -.17247300E+00, -.19233500E+00, -.20353800E-01, -.23118700E+01, 0.67402600E+00, 0.11509900E+01, 0.28184000E+00, -.44431400E+00, 0.28945800E+01, 0.30799600E+00, -.13152500E+01, 0.31541000E+01, 0.51555300E-02, 0.41003600E+00, 0.63439100E+00, -.15218400E-01, 0.59616400E+00, 0.16504200E+00, -.63339400E+01, 0.26026400E+00, 0.99919200E+00, 0.83161100E+00, 0.10926700E+02, -.14498900E+00, 0.23258500E+00, -.91390500E-01, -.50433800E+00, -.94785900E+02, -.84000000E+02, 0.45290400E-01, -.10382500E+01, -.14820500E+01, -.82243900E+02, 0.94127700E+02, 0.16422100E+01, -.12344400E+02, 0.71643700E+02, -.59143700E+00, 0.71243200E+02, -.29087600E+01, -.82981000E+02, -.11739900E+02, 0.66195500E+01, -.29818700E+01, 0.14968600E+01, -.10612900E+02, -.61697300E+01, 0.14002700E+01, -.69679900E+00, 0.88875200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.85095700E+00, -.47138600E+00, -.51612900E+00, -.62853700E-01, -.80985000E-01, -.56370100E-01, -.51139800E+00, -.26661800E+00, 0.30767300E+00, 0.50345500E-01, -.24439600E-01, 0.69766500E-01, 0.11896800E+01, -.48776200E-01, 0.84393000E+00, 0.48663200E+00, -.21119800E+00, -.33027500E+00, -.40818400E+00, -.59123000E+00, 0.26466900E+00, -.93381900E-02, 0.10618700E+00, -.56479700E+00, -.13360300E-01, 0.85005800E-01, -.99930500E+00, 0.69377200E-02, -.11966300E+00, 0.58580200E-01, -.11267900E+00, 0.91620500E-01, 0.17167100E+00, -.42795400E-01, 0.23384600E+00, -.23613000E+00, 0.34677700E-02, 0.48065500E-01, 0.31444300E-01, 0.62622200E-01, -.36560100E+00, -.12555500E+00, 0.13304200E+00, -.54921300E-02, 0.10596100E+00, 0.27394000E-02, 0.11604000E+00, 0.19163300E-04, -.40404100E+00, 0.74527300E-01, -.27140600E+00, -.58683500E+00, -.63112800E-01, -.17515300E+00, 0.24468000E-01, 0.12647100E+00, -.51971500E-01, -.26290100E+00, -.27123200E-01, 0.36364900E+00, 0.59291300E-02, -.21975400E-01, 0.19370800E-01, -.85028100E-01, -.43112700E+00, 0.77328600E-01, -.71670300E-01, 0.26806800E+00, 0.20196200E+00, -.60271200E-01, -.35533000E+00, -.47346600E+00, -.68713000E-01, 0.60232100E-01, -.29053600E-01, -.12583100E+00, -.90717700E-01, -.26430700E-01, -.14238900E+00, -.21584400E+00, 0.75486500E-01, -.31059600E+00, -.10564700E+00, 0.83710500E-01, -.52281800E-01, -.27071900E+00, 0.25001400E-01, 0.74832000E-01, 0.80712200E-01, 0.52654500E-03, -.55247800E-01, 0.72528700E-01, -.20971200E+00, -.18727200E-01, -.21402900E+00, 0.19712300E-01, -.42372800E-01, 0.38733800E+00, 0.45697300E-01, 0.54642900E+00, -.52966100E-02, 0.15133100E+00, 0.87877500E-02, 0.57322100E+00, 0.81002600E-01, -.13611800E-01, -.12186300E+00, 0.51302900E+00, 0.11009500E+00, -.21717800E+00, -.18576400E+01, -.11119700E+00, 0.21196600E+00, 0.17621000E-02, 0.54351100E-01, -.77337400E-01, -.95961200E+00, -.37945300E+00, 0.67797800E+00, 0.24617800E+00, -.20319200E+00, 0.13669100E+01, 0.11319800E+00, 0.56681600E-02, 0.61676500E-02, 0.24430100E+00, 0.17599800E+00, -.11313800E-01, 0.31514100E+00, 0.16842300E+00, 0.69269600E-01, 0.23201800E-01, 0.10226200E+00, 0.33526300E+00, -.20481700E+00, 0.23790900E-01, 0.45705300E+00, -.68721900E-02, -.19965100E+00, -.10377700E+00, 0.52334600E+00, 0.55924000E-02, 0.55598500E-01, -.12290900E+00, -.20041700E+00, 0.85770200E-01, 0.59059400E-02, -.29594700E-01, -.36835900E+00, -.16180300E+00, -.76882300E-01, -.57428400E-01, -.18368400E+00, 0.27563900E-01, -.12061400E+00, -.52939500E-01, -.14933000E+00, -.15207400E-01, -.13823100E+00, 0.16706200E+00, 0.21136600E-02, 0.31147900E+00, -.26510800E+00, 0.84230800E-01, 0.12259000E+00, 0.65443700E-01, 0.55254500E+00, 0.10735400E+00, -.24554200E-01, -.23694200E-01, -.17634800E+00, -.33409500E+00, 0.49602800E+00, 0.43651200E-01, 0.25179800E-02, 0.13262300E+00, 0.10113900E+00, 0.67117400E-01, -.32000300E+00, 0.21312900E-02, -.71804600E-02, -.81006100E-01, 0.81768200E-01, 0.72155100E-01, -.80945200E-01, 0.12692000E+00, 0.19099400E+00, -.33241000E+00, -.36938000E-01, -.23957200E+00, 0.27536000E-03, 0.77759700E-01, -.15773400E+00, -.75119900E-01, -.14144400E-01, 0.11686200E-01, -.29382800E+00, 0.19960900E+00, -.32476200E-02, -.33904500E+00, -.73003700E-01, -.20181200E-01, -.10512900E+00, -.34405400E+00, 0.12685800E+00, 0.44319400E+00, -.32370600E-01, 0.11175800E+00, -.18786100E+00, 0.16503100E+00, 0.26338900E-01, -.19397500E+00, 0.92152200E-02, -.95223500E-01, 0.10971300E-01, -.82232600E-01, -.15386400E+00, -.31093600E-01, -.20246600E-01, 0.46097100E-02, -.47558100E-01, -.31090000E-01, 0.27227600E-01, -.28252600E-02, -.34003000E-01, -.10564900E+00, -.14305500E+00, -.12952900E+00, 0.70159300E-01, -.37859000E+00, 0.15741100E+00, 0.22348900E+00, 0.28571900E+00, 0.29407900E-02, -.54034800E-02, -.30860600E-01, 0.40627400E-01, 0.43225200E-02, 0.18551500E-01, -.34024400E-01, 0.21841500E-01, 0.75703100E-01, 0.31464800E-01, -.13760700E-01, -.54495900E-01, 0.16922600E-02, 0.16563400E-03, -.66496400E+00, 0.82787100E-02, 0.15683400E+00, -.10828200E+00, 0.68716100E-01, 0.66448700E-01, -.32250500E-01, 0.24388100E-01, -.26341700E-01, -.12076900E-01, 0.24951200E+00, -.14617700E-01, -.82623800E-01, -.25865500E-01, -.47970900E+00, 0.87570500E-03, 0.83738400E-01, 0.19835500E-01, 0.23955600E-01, 0.16360500E-01, 0.23214700E+01, -.64354500E+00, -.25680100E+00, -.37642300E+00, 0.23828500E+01, 0.15373000E-01, -.61630200E-01, -.33409800E+00, -.20078900E+01, 0.21857200E+00, -.19868600E+01, -.76607700E+00, 0.24790600E+01, -.34047300E+00, 0.14303100E+00, -.77280100E+00, 0.12479900E+00, -.37834200E+00, -.15981400E+00, 0.60844200E+00, -.69506500E-01, 0.33327000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23569100E+01, 0.67595500E+00, -.48101100E+01, -.14287200E+01, -.33083200E+01, -.66461000E-01, -.82576100E+00, -.13967800E+00, 0.31133700E+01, 0.10926800E-01, 0.33282800E+00, -.31166200E+01, -.14133500E+00, 0.19818000E+00, -.21822500E+01, 0.94216400E+00, 0.11876200E+01, 0.54974300E+00, -.14388000E-01, 0.19819000E+01, -.13036900E+01, -.76462600E-01, 0.10083500E+01, -.32054700E+00, -.12536500E+00, 0.48570000E-02, 0.13490400E+00, -.20058400E+00, -.38830600E+00, 0.19936100E+00, 0.90001000E+00, -.14568400E+00, -.70981900E-01, 0.27157700E+00, -.90597700E+00, -.16837200E+01, -.64353800E-01, -.42525600E+00, 0.12504100E-02, 0.41762500E+00, 0.79745700E+00, 0.36147000E+00, -.12296900E+00, 0.74047300E-01, -.70239200E-01, -.75398300E-01, 0.19423000E+00, -.82086700E-02, 0.15143700E+01, -.30139000E+00, 0.22660400E+00, 0.63840100E+00, 0.12860300E+00, 0.98035800E-01, 0.78587100E-01, 0.85545500E+00, 0.53652100E+00, 0.10150100E+01, 0.81437400E-01, -.40381900E+00, 0.24303800E-01, 0.51246500E+00, -.43676600E+00, -.25818000E+01, 0.21853200E+01, -.24263500E+00, 0.19316900E+00, -.78800500E+00, -.39208900E+00, 0.13930600E+00, -.81812700E+00, 0.72746900E+00, -.45500400E+00, 0.23283200E-01, -.30228500E+00, 0.55161900E+00, -.74260900E-01, -.52352200E+00, 0.15524300E+00, -.11599100E+00, -.69084400E-01, 0.45227900E+00, -.25176900E+00, -.31100800E+00, -.71163000E+00, 0.28002600E+00, 0.25035300E+00, 0.38624400E+00, 0.11209200E-01, -.89250800E+00, 0.15885200E+01, -.14284000E+00, 0.42996400E+00, -.10939500E+01, -.88554600E+00, -.30482800E+00, -.62063100E+00, -.14415300E+00, 0.41799500E+00, 0.85237000E+00, 0.24968500E-01, -.75001500E+00, 0.17774400E-01, 0.26220000E+01, -.61505500E+00, 0.68086700E-01, -.10372600E+00, 0.58895400E+00, -.41575700E+00, 0.21860900E+00, -.11148500E+01, -.41264500E+00, -.42776100E+00, 0.47114600E-02, 0.14496900E+00, -.13457000E+00, 0.23884400E+01, 0.16925500E+01, 0.18798100E+00, 0.31914200E+00, -.30906600E+00, -.78702200E+00, 0.11144800E+01, 0.56058800E-01, -.17581600E-01, 0.38856700E+00, -.22571300E+00, 0.15529700E+00, 0.26227000E+00, 0.34285600E-01, 0.57811100E-01, 0.36770000E+00, 0.88791700E+00, 0.37644400E+00, 0.73734100E+00, 0.24430000E-01, 0.31398400E+00, 0.54632400E-01, -.38368500E+00, -.10337600E+00, 0.94222000E+00, 0.22118700E+00, -.98852900E-01, -.17566600E+00, 0.49117100E+00, 0.78569200E-01, 0.94181300E-03, -.13869200E+00, -.55931900E+00, -.45656900E+00, -.14471100E+00, -.17277700E+00, 0.27872600E+00, 0.67561200E-01, -.47820600E+00, -.49026400E-01, 0.23378800E+00, 0.19221700E-02, -.51326900E-01, 0.50699300E+00, 0.13270900E+00, 0.17458500E+00, -.62149900E+00, -.27696000E+00, 0.53701400E+00, -.19029800E+00, 0.17783900E+01, 0.64522700E+00, -.50112200E-01, 0.23902800E+00, -.14136000E+00, -.30152000E+00, 0.22501800E+00, 0.18259700E+00, -.47592800E+00, -.77450500E+00, -.62624900E-01, -.23247600E+00, 0.17388700E+01, -.10673100E-01, -.44103800E+00, -.69605500E-01, -.13456100E+00, 0.85524600E-02, -.52413600E-01, 0.77448700E+00, -.61561400E+00, -.14438700E+01, 0.76126600E-01, 0.10543300E+00, 0.16040200E-02, 0.35499100E+00, -.11395900E+01, 0.61524800E+00, -.15895200E+00, 0.32213500E-01, -.13449600E+01, -.12080200E+00, -.29151300E+00, 0.14693600E+01, 0.27900300E+00, -.89882100E-01, 0.14213200E+00, -.30422000E+00, -.12501900E+01, 0.49656300E-01, 0.79291200E-01, -.22269200E+00, -.28424000E+00, 0.40151800E+00, -.86442900E-01, 0.34360600E+00, 0.25933600E-01, 0.94026500E+00, 0.28189000E+00, 0.20016100E+00, 0.10401600E+00, 0.76888700E-01, 0.34604600E+00, -.24139200E-01, -.55058100E-01, 0.70738800E-01, -.80652000E-01, -.81326500E-02, 0.10458700E+00, -.56520600E+00, -.21189500E+00, -.60887900E+00, 0.10411600E+00, -.11477900E+01, -.79949700E+00, 0.42964100E-01, -.51647200E-01, 0.64336500E+00, -.42567000E-01, -.13128900E-01, -.26896200E+00, -.54318300E-01, -.46385300E+00, 0.18626200E+00, 0.11467800E+00, -.25262100E+00, 0.25684500E+01, -.53112900E-01, 0.34447700E+00, -.64601500E-01, 0.51078600E+00, 0.12861300E+01, -.31530100E+00, 0.75680600E+00, 0.75813600E+00, 0.25639200E+00, -.53262800E+00, -.29763900E+00, -.89189500E-01, 0.10995100E+00, -.15079700E-01, 0.60949100E+00, -.30016600E+00, -.28529300E+00, -.28494300E+00, 0.33055600E+01, 0.34965800E+00, -.66535600E+00, 0.55109100E-01, 0.63088600E-01, -.40171300E+00, 0.24782600E+00, 0.75886900E+01, 0.24853700E+01, 0.24911400E+01, 0.84801400E-01, 0.19161500E-01, 0.22862500E+00, 0.39326500E+01, 0.34518600E+00, -.48372500E+00, 0.40504700E+00, 0.13983100E+02, 0.47541200E-01, 0.37954200E+01, -.13474100E+01, 0.13939200E+02, -.37692300E+00, 0.44318800E+01, 0.15603100E+01, -.95998500E+01, -.12160000E+01, 0.42066000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30078300E+01, 0.37809800E+00, 0.63475200E+01, -.84792800E+00, 0.50595100E+01, 0.50213400E+00, 0.20973000E+01, 0.28243700E+01, -.74101300E+01, -.11530600E+01, -.44254900E+00, 0.40123400E+01, -.90506000E+00, -.16827500E+01, 0.41829700E+01, -.93206400E+00, -.23965700E+01, -.80227600E+00, -.43377100E+00, -.12637300E+01, 0.29494300E+01, 0.96123300E-01, -.76274300E+00, -.54709400E+00, -.43793300E-01, -.10105400E+00, 0.92899900E+00, 0.11888800E+00, 0.74096500E+00, 0.30441200E+00, -.16943200E+00, -.63677100E+00, 0.41879500E+00, 0.80672800E+00, 0.63453700E+00, -.38098900E+00, 0.98218300E-02, 0.90820600E+00, 0.13225700E-02, 0.50918500E+00, 0.14254500E-01, 0.25225200E+00, -.10541000E+00, 0.10399000E+00, -.36335400E+00, 0.17726300E+00, 0.38060400E+00, 0.65431700E-03, 0.18531300E+00, -.39318500E+00, -.18805000E+01, -.24223900E+01, -.12064800E+00, -.52516800E+00, -.45157200E+00, 0.69265800E-01, 0.50127800E+00, -.12647500E+01, -.24897300E-01, 0.17440500E+00, -.75322800E-01, 0.27677200E+00, -.25141700E+00, -.11116400E+01, -.17858300E+01, 0.25830900E+00, -.35303300E+00, -.12030100E+01, 0.26104700E+00, -.17200900E+00, 0.79397200E+00, -.91750400E+00, -.66530700E-01, 0.44006400E-01, -.32464100E-01, 0.26074500E-01, -.33987500E-01, 0.38836500E-01, 0.25397600E+00, -.13132200E+00, 0.13369700E+00, -.17302400E+00, -.54979000E+00, 0.14428200E+00, 0.41935000E+00, -.38012500E+00, 0.19606300E+00, 0.34843200E+00, -.13191900E+00, 0.33721200E+00, 0.18302200E+00, 0.11628000E+00, 0.11981400E+01, -.10130600E-01, -.20265800E+00, 0.34531200E+00, 0.72225400E+00, 0.44757400E+00, 0.17697500E+00, -.28374600E+00, -.17077900E+00, 0.15278500E+00, 0.30122700E-02, 0.39696900E+00, -.73499700E+00, -.32870800E+00, -.40436200E+00, 0.16432000E+01, 0.68913300E+00, 0.15136800E+00, 0.87973300E+00, -.88633000E-01, -.36350500E+00, -.25452700E-02, -.33221300E-01, -.13686200E+00, 0.19836300E+01, -.19416400E+00, 0.12019100E+01, -.40786200E-01, -.14655900E+00, -.10817300E+01, -.23726200E+01, 0.28719800E-01, -.11186200E-02, 0.71513100E-01, 0.62582100E+00, -.18492600E+00, 0.10837300E+01, -.14241300E+00, -.89196800E+00, -.41490300E-01, -.60317400E+00, 0.23958900E+00, 0.63331500E+00, -.18273100E-02, 0.49635500E+00, -.56922100E-02, 0.20920500E+00, 0.13277500E+00, 0.17823100E+01, -.16184100E-01, 0.57535700E-01, 0.95328400E-03, -.29342600E+00, 0.42809500E+00, -.12987700E-01, 0.89678900E-01, 0.73048800E+00, 0.59257800E+00, 0.66271500E+00, 0.34035600E+00, -.27299300E+00, -.17214900E+00, 0.52822900E+00, 0.11388500E+00, -.28084100E+00, 0.99241100E-01, 0.66770300E-01, 0.98841000E-01, -.10382900E+00, 0.10332800E-01, 0.55410500E+00, 0.98938700E-01, -.22322500E+00, 0.60626900E-01, -.75073900E+00, 0.87229900E+00, 0.41808200E-01, 0.90930000E-01, 0.30134900E+00, -.30363400E+00, -.42265900E+00, -.13292500E+00, 0.31532400E+00, 0.75993500E+00, 0.23811900E+00, 0.15287200E+00, -.15365800E+01, -.12560400E-01, 0.14194100E+01, -.30224600E-01, 0.33749700E+00, -.43583800E-01, -.72726100E-01, -.60772300E+00, 0.18725000E+00, 0.39138600E+00, -.24124700E-01, -.33093900E-01, 0.21212800E-02, -.28027500E+00, 0.78934100E+00, -.52507500E+00, 0.49972800E+00, 0.51967300E-01, 0.16594800E+01, 0.26685500E+00, 0.80548200E-01, -.20655500E+01, -.16591700E+00, 0.50158300E-01, 0.51900300E-01, 0.24361300E+00, 0.17920400E+00, -.20605900E+00, 0.43984500E-01, 0.92858600E-01, 0.92318900E-01, 0.50548100E+00, -.37502400E+00, -.34490800E+01, -.11587600E-01, 0.86688300E+00, 0.69276300E+00, 0.34534700E+00, 0.43855500E+00, -.82203200E+00, -.11556000E+00, 0.32012200E-01, -.27744800E+00, 0.34849800E+00, 0.30709600E+00, 0.53983500E-02, 0.61897400E+00, -.11769100E+00, 0.72551500E-01, -.53937800E+00, -.16087200E+00, 0.49567100E+00, -.92718000E+00, 0.25845900E+01, 0.54414500E+00, 0.78965600E+00, 0.50688800E-01, 0.36631500E+00, -.83041300E-01, 0.23638300E-01, -.45403700E+00, 0.29871200E+00, -.27751400E+00, -.70030100E+00, 0.85596100E+00, -.20659500E+00, 0.37929300E+00, -.11668400E+00, 0.38202200E+00, 0.29240300E+00, -.47445200E-02, -.13623300E+01, 0.17841600E+00, -.75888200E+00, -.55555900E+00, 0.21607800E-01, 0.21249400E-02, -.27081300E+00, -.59697800E-01, -.79494100E+00, 0.39565800E+00, 0.52043700E+00, -.47122400E+00, 0.78544100E+00, -.46693500E-01, 0.64338600E+00, -.22441700E+00, 0.32104600E+00, -.25412000E-01, -.14915000E+01, -.63152400E+00, -.54163500E+01, -.44748100E+01, -.16153300E+00, -.67231800E-01, -.17188400E+00, 0.53012600E+01, 0.38691300E+00, -.29438400E+01, 0.31627000E+00, 0.59106500E+00, -.18543500E-01, 0.61508000E+01, -.71262700E+00, 0.69825400E+00, -.31083000E+01, 0.40028100E+01, -.22728500E+00, -.15994600E+00, -.23171400E+01, 0.60355200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.28506300E+00, 0.21263600E+00, 0.12941400E+01, 0.98888200E+00, 0.47624600E+00, -.12030900E+00, -.23035500E+00, -.25347800E+00, -.23981200E+00, 0.31337000E+00, 0.51355200E-02, 0.31408800E+00, 0.49537600E+00, 0.77612400E+00, -.99260000E-01, 0.20217600E-01, 0.56355800E-01, 0.55640400E-01, 0.16172100E+00, 0.14179600E+00, 0.13846800E+00, 0.33798700E-01, -.10529600E+00, 0.91846700E-01, -.19738400E-01, 0.54512100E-02, 0.35433900E+00, -.15492100E-01, 0.20808000E-01, 0.90854800E-02, 0.64133600E-01, 0.40125900E-01, 0.32295600E-01, 0.15809800E+00, 0.72291100E-02, 0.50975900E-01, 0.40729900E-02, 0.30155100E-01, 0.17841800E-01, 0.31753600E+00, 0.86063400E-01, 0.65784800E-01, -.23022100E+00, 0.14411600E-01, -.13909900E+00, 0.12740800E-01, 0.71857600E-01, 0.88629900E-03, 0.10547400E+00, -.70681900E-01, -.15751200E+00, 0.27448400E-01, -.14299800E-01, 0.66280300E-01, -.42165200E-01, -.96466700E-02, 0.46171500E-01, 0.32774300E+00, 0.57162200E-02, -.13615800E+00, -.24882000E-01, -.76060400E-01, 0.39952000E-01, 0.14934200E+00, 0.25303800E-01, 0.10881200E-01, -.34080100E-01, -.83300200E-01, 0.25041400E-01, 0.14898500E-01, 0.16449000E+00, 0.12269000E+00, 0.26187900E-01, -.57490400E-01, -.41065400E-01, 0.11707700E+00, 0.26835800E-01, -.21696100E-01, 0.68146100E-02, 0.72109000E-01, -.15735200E-01, 0.43880900E-01, 0.59606500E-02, -.95228500E-01, 0.24930400E+00, 0.92936700E-01, -.10432200E+00, -.81190600E-01, 0.26940600E-01, -.43523500E-01, -.10801100E+00, 0.21904400E-01, -.31370800E-02, 0.11957400E+00, -.14068200E+00, 0.22020700E+00, 0.40104400E+00, -.53971000E-01, 0.70293100E-01, -.12859600E+00, 0.13290600E-01, 0.83335500E-01, -.86314700E-03, -.18342900E+00, -.12182100E-01, 0.88470400E-01, 0.47283400E-01, 0.11451500E+00, 0.18841900E+00, 0.76128700E-01, -.56208900E-01, 0.23250000E-01, 0.50336300E-01, -.34679100E-03, -.41905000E-01, -.68619100E-01, -.10743900E+00, -.51513500E-01, -.23590900E-01, -.14967100E-01, 0.26519500E-01, 0.31007400E+00, 0.40990400E+00, -.82594800E-01, -.25212200E-03, 0.74501900E-01, 0.93981400E-02, -.73676000E-01, -.96966400E-02, -.82190700E-01, 0.21398000E-01, -.33437300E-01, -.88588800E-01, -.48530300E-01, 0.29708500E-01, -.40098300E-02, -.13537900E+00, -.11594600E-01, 0.72678000E-01, 0.66302400E-02, -.13342700E+00, 0.12468600E-01, 0.45039600E-02, -.18686800E-01, 0.49833800E-01, -.29474000E-01, -.28057800E-02, 0.32136000E-01, -.75171700E-01, -.27106200E-01, -.31984700E-02, 0.63297200E-01, -.23477900E-01, 0.13798100E-01, -.82236100E-02, 0.97299600E-02, -.15274000E-01, -.18093500E-01, -.92711100E-03, 0.31321100E-02, -.57318200E-03, 0.12416100E-01, -.74915000E-01, 0.15505700E-01, -.98448900E-01, 0.12937700E-01, -.22024000E+00, -.32302800E-01, -.19539700E-02, -.87040400E-02, 0.47609700E-01, -.50906400E-01, -.24631500E-01, -.69902700E-01, -.39716000E-02, -.31406300E-01, 0.18034600E-02, -.15085500E-01, -.87703000E-01, -.36807900E-02, 0.55610500E-01, -.80211500E-02, 0.68369200E-02, -.27146800E-02, -.13185500E-01, -.53095200E-01, -.63774900E-01, 0.14036700E+00, -.11780600E-01, -.44635000E-01, 0.23487700E-03, -.17403000E-01, -.25023000E-01, -.26715800E-01, 0.31364300E-01, 0.64965700E-02, 0.63866500E-01, -.70298800E-01, 0.19475000E-01, -.20723800E-01, -.13541300E-01, -.47950500E-02, -.19087800E-02, 0.14841000E+00, 0.14920600E+00, 0.49550900E-02, 0.16554000E-01, -.76948900E-02, 0.15351600E-01, 0.42730500E-01, 0.83194200E-02, -.43741700E-01, -.60267000E-03, 0.12896900E-01, 0.13786200E-01, 0.37257600E-01, 0.17356500E-01, 0.37224200E-01, -.12458700E-03, -.30660400E-01, -.19174300E-01, 0.11678000E-01, 0.63432200E-02, 0.18373800E-03, 0.37190400E-01, -.65191500E-02, 0.38657300E-01, 0.16318500E-01, -.43770800E-02, -.22217300E-01, -.54127500E-01, 0.12695900E-02, 0.54920500E-01, -.29559100E-04, 0.16324600E-02, 0.83264700E-03, -.30592500E-02, -.16875100E-01, -.26791100E-02, -.19842800E-02, 0.10732600E-02, 0.14579000E-01, 0.39290200E-01, -.54938600E-02, 0.42667000E-01, -.24838600E-02, 0.10856800E-01, 0.74481800E-01, 0.41415300E-02, 0.26606200E-03, 0.56446500E-01, -.12596200E-01, -.42914000E-01, 0.10099600E-02, -.24395300E-02, 0.16000400E-01, 0.88790500E-03, 0.84335200E-01, -.21442100E-02, -.31886700E-01, 0.13900400E-01, -.17164600E+00, 0.70053600E-02, -.64292200E-02, 0.32138800E-02, -.14911200E-01, 0.21867400E-02, -.13627500E-01, 0.43697200E-02, -.84183900E-02, 0.20511300E+00, 0.74939000E-02, -.26465400E-02, 0.19657200E-01, -.26247500E-02, -.14179300E-01, -.77538900E-01, -.10622000E-01, 0.86023700E-01, 0.75656100E-02, -.12670300E-01, -.38469900E-01, 0.91069800E-01, -.58481100E-01, 0.20426200E-01, 0.19393200E-01, 0.89626200E-03, 0.82332400E-01, -.99004600E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.69486100E+00, 0.57687500E+00, 0.12661200E+01, -.39153200E+00, 0.36763100E+00, 0.10979900E+00, 0.73430200E+00, 0.20027600E+01, 0.60793500E+00, 0.74844600E-03, -.94355600E-01, -.33151200E+01, -.37228400E+00, 0.73452800E+00, 0.11017000E+01, 0.31701100E+01, 0.14109900E+01, -.46446000E+00, -.21514200E+00, 0.94985400E-01, 0.10130000E+01, 0.54838700E-01, 0.33081500E+00, 0.20132100E+01, -.11426100E+00, 0.12765300E-01, 0.14136600E+01, -.25628500E+00, 0.25742000E+00, 0.63235100E+00, -.22188700E+00, -.72343200E+00, 0.74459400E+00, 0.79562200E+00, 0.36067300E+00, 0.19927200E+00, -.42621800E-01, 0.15863300E+01, -.59922500E+00, 0.56450700E+00, -.95968700E+00, -.82630000E+00, 0.15441200E+00, 0.59205500E-01, -.12369100E+00, -.14949700E+00, -.88511200E-01, -.94780400E-02, 0.16604400E+00, -.44266700E+00, 0.64605200E-01, -.45490100E+00, 0.26735900E-01, -.15737800E+00, -.50278300E-01, -.10158100E+00, 0.62031500E-02, 0.54164100E+00, -.37532300E-01, -.10041800E+00, 0.11395500E-01, 0.87649000E-01, -.56696200E-01, 0.17338100E+00, -.53985500E+00, -.40848700E-01, -.90599300E-01, 0.12343100E+00, 0.54219600E+00, 0.15381700E+00, 0.44652500E+00, -.44172200E+00, -.11239700E+00, -.31192400E+00, -.39102500E+00, 0.48018400E+00, 0.11043100E+00, -.20853300E+00, 0.17011000E+00, 0.61797100E-01, -.10592800E+00, 0.36828000E+00, -.12049500E+00, -.83913600E-01, 0.15618900E+00, 0.22020700E+00, -.19832400E-01, 0.75333500E-01, -.48472900E-01, -.10548400E+00, -.11142600E+00, -.78329200E-01, 0.14636600E+00, -.18666500E+00, 0.39067400E+00, -.22683200E+00, 0.60946300E-01, -.25407100E+00, 0.41492500E-01, -.18054200E+00, 0.46174600E-01, 0.10656100E+00, -.10969200E-01, 0.15519800E+00, -.64450400E-01, 0.76652400E-01, -.28891900E-01, 0.99059700E-01, 0.20755400E+00, 0.17518500E+00, 0.64950100E+00, -.82892900E-02, -.11509200E+00, -.16335900E-02, -.24564400E-01, -.39910000E-01, 0.48152400E+00, 0.10126400E+00, -.39958200E+00, -.12705700E+00, 0.13264800E+00, 0.67191900E+00, 0.52951300E+00, 0.97904600E-01, -.96005900E-02, 0.32342400E+00, 0.37424700E-01, 0.12313400E-01, 0.41095000E+00, 0.55856600E-01, -.14433300E+00, 0.12450300E+00, -.90182100E-01, -.43296100E-01, 0.10780100E+00, -.44587500E-02, 0.79035500E-01, 0.34212700E-02, 0.77992000E-01, 0.57016200E-01, -.81534300E-01, -.20903300E-02, 0.21216800E-01, 0.22045900E-02, -.92774200E-02, -.17268800E-01, 0.39648600E-03, 0.14263200E-01, 0.15756000E+00, -.11859100E-01, -.85237500E-02, 0.19032500E-01, 0.23415300E-01, 0.44273300E-01, 0.54028100E+00, -.43354900E-01, 0.39614600E+00, -.58082300E-01, 0.23701200E+00, -.13643900E+00, -.11638100E+00, -.85976100E-01, 0.22487800E+00, -.24547100E+00, 0.13385900E+00, -.21223300E+00, -.36727000E+00, -.49320900E+00, -.87098800E-02, -.14008300E+00, 0.13086300E+00, 0.49036900E-01, -.48679300E+00, -.21808200E-01, -.47991700E-01, -.14156200E+00, -.38001800E-02, -.82008700E-01, 0.33742000E+00, -.14013200E-01, -.28206300E+00, 0.18713900E-01, 0.15290100E+00, -.65886700E-01, 0.15446600E+00, 0.17872900E+00, -.16395000E+00, -.25080000E-01, 0.28225300E-01, 0.13831300E+00, 0.10909300E-03, 0.26527900E-01, -.24848900E+00, 0.21719900E+00, 0.11867500E-01, 0.46174500E-01, -.31036600E+00, -.45479900E+00, -.45173700E-01, 0.66885000E+00, 0.13093400E+00, -.29838700E-02, 0.26533400E+00, 0.39433000E+00, -.19981800E+00, -.47806900E+00, 0.71658700E-01, -.30111100E+00, 0.21492700E+00, -.22520200E+00, 0.11155500E-01, -.38949600E+00, -.64510200E-02, 0.27722400E+00, 0.12876000E+00, 0.14330800E+00, 0.23698700E+00, 0.59695100E-01, 0.11881200E+00, -.16950300E-01, 0.15434600E+00, 0.28036400E-01, 0.13986700E+00, 0.19993400E-02, 0.10681800E+00, 0.18888300E+00, 0.29908700E+00, -.15569600E-01, -.60190500E-01, 0.30317400E+00, -.15912100E+00, -.37492000E+00, -.45847100E+00, -.70788800E-02, 0.46851600E-02, -.79954200E-01, 0.88302800E-01, 0.27068500E-03, 0.15166600E-02, 0.48006600E-01, 0.62486600E-01, 0.64088000E-01, 0.48970100E+00, -.15820400E-01, -.11554900E+00, 0.28809000E-01, 0.42888000E-01, 0.39791000E+00, -.51408800E-01, -.30352900E+00, -.11881600E+00, 0.86428300E-01, 0.26993800E-01, 0.61707700E-01, 0.54745500E-02, -.25000300E-02, 0.94050300E-03, -.35487000E-01, 0.12510900E-01, 0.46049100E-01, 0.34002300E-02, 0.27412700E-01, -.14226400E-01, 0.21533500E-01, -.87162500E-02, 0.22484300E-01, -.70485900E-02, 0.10664000E-01, -.11619600E-01, -.59622700E-02, -.38950500E-01, -.50372400E+00, 0.42209000E-02, -.35266100E-03, 0.75171400E-01, 0.14599300E+00, -.10616700E+00, 0.10032800E+00, 0.89753400E-01, -.55443300E+00, 0.85680600E-01, -.56680700E-01, 0.91911700E-01, -.11259600E+00, 0.58953500E-01, 0.16860400E-01, -.63450800E-02, -.74081400E-01, 0.56979900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.89599800E+00, 0.24506700E+00, 0.23380100E+00, 0.13037200E+00, -.29111000E+00, -.25851000E-01, 0.57157500E+00, -.32011900E-01, -.42559400E+00, -.10454600E+00, 0.57943000E-01, 0.11321800E+00, -.10413800E+01, 0.42050400E-02, -.46764000E+00, -.10109900E+01, -.14789700E-01, 0.46118000E+00, 0.58532200E+00, 0.67742300E+00, -.41713000E+00, 0.33042100E-01, -.26481800E+00, 0.61154900E+00, 0.11942400E-01, -.51505000E-01, 0.11470200E+01, -.11753600E+00, 0.96044900E-01, -.11313200E+00, 0.76642200E-01, 0.48534200E-02, -.17505900E+00, -.33598700E-01, -.31037500E+00, 0.35025100E+00, -.32651300E-02, -.18813800E+00, -.17975400E-01, 0.87784400E-01, 0.31942500E+00, 0.10425300E+00, -.26633500E+00, -.34066100E-01, -.12140100E+00, 0.71654100E-01, -.18358000E+00, 0.32960100E-03, 0.46775700E+00, -.20860500E+00, 0.22660300E+00, 0.77412400E+00, 0.54774200E-01, 0.19118600E+00, -.66892100E-01, -.21389000E+00, 0.98750800E-01, 0.65132400E+00, 0.33776500E-01, -.52775200E+00, 0.15154200E-01, 0.52404800E-01, -.14244900E-02, 0.14458900E+00, 0.47363900E+00, -.96093200E-01, 0.96850900E-01, -.30007800E+00, -.20459100E+00, 0.78508800E-01, 0.42920300E+00, 0.54759400E+00, 0.16876600E+00, 0.38735000E-01, 0.66470600E-01, 0.85282900E-01, 0.78161600E-01, -.29317800E-01, 0.15285600E+00, 0.24877800E+00, -.77985700E-01, 0.39209700E+00, 0.14562400E+00, -.68886100E-01, 0.17247200E+00, 0.25803900E+00, -.14685500E-02, -.63170400E-01, -.70615700E-01, -.11868600E-01, 0.57326100E-02, -.98494600E-01, 0.15973300E+00, -.36136500E-01, 0.33777300E+00, -.85213200E-01, -.11199000E+00, -.56309400E+00, -.83968500E-01, -.61986400E+00, 0.73313700E-01, -.14040500E+00, -.10418600E-01, -.70564200E+00, -.18997100E-01, 0.10431000E-02, 0.13769300E+00, -.54344400E+00, -.13886000E+00, 0.22818200E+00, 0.22050100E+01, 0.12363500E+00, -.23127500E+00, -.14647300E-02, -.41705600E-01, 0.91172300E-01, 0.98661800E+00, 0.47041200E+00, -.90097400E+00, -.27825700E+00, 0.27179600E+00, -.17785300E+01, -.55561400E-01, -.25906100E-01, -.70569100E-02, -.21975700E+00, -.20092600E+00, 0.18770100E-01, -.33143700E+00, -.15641700E+00, -.12747400E+00, -.31813400E-01, -.13689000E+00, -.35212600E+00, 0.23513300E+00, -.24354600E-01, -.50771400E+00, -.25973400E-01, 0.22601900E+00, 0.10334400E+00, -.66689500E+00, -.26991900E-01, -.68755400E-01, 0.93852100E-01, 0.22142900E+00, -.51655200E-01, -.78802300E-02, 0.14313800E-01, 0.31379900E+00, 0.13876100E+00, 0.65916800E-01, 0.39580700E-01, 0.16034200E+00, 0.61163500E-02, 0.15564400E+00, 0.40742200E-01, 0.28573100E+00, 0.22787600E-01, 0.11435100E+00, -.11033900E+00, 0.41324000E-01, -.33858900E+00, 0.27308900E+00, -.89033500E-01, -.12457900E+00, -.72854100E-01, -.58746700E+00, -.95434600E-01, 0.24439400E-01, 0.27697300E-01, 0.20083100E+00, 0.33800100E+00, -.55331800E+00, -.37525100E-01, -.67413900E-02, -.15034700E+00, -.10943700E+00, -.76263200E-01, 0.39039100E+00, -.35815600E-02, -.89447100E-01, 0.95457400E-01, -.11303400E+00, -.73562300E-01, 0.83536600E-01, -.76941100E-01, -.21923100E+00, 0.33418800E+00, 0.41704900E-01, 0.26457500E+00, -.61946500E-03, -.73332300E-01, 0.11625900E+00, 0.11674700E+00, 0.37014600E-02, -.16326900E-01, 0.24877900E+00, -.23205000E+00, 0.59493600E-02, 0.41836600E+00, 0.76316200E-01, 0.10791900E-01, 0.11407400E+00, 0.37972900E+00, -.10009000E+00, -.46893700E+00, 0.30137600E-01, -.13868500E+00, 0.18726400E+00, -.16837100E+00, -.23684400E-01, 0.27173900E+00, -.74600700E-02, 0.10104000E+00, -.38430300E-02, 0.74447000E-01, 0.14694800E+00, 0.49107100E-01, 0.28201500E-01, -.66672000E-02, 0.49007800E-01, 0.23950200E-01, -.30492000E-01, 0.20814300E-02, 0.30200100E-01, 0.10415900E+00, 0.14453200E+00, 0.13581000E+00, -.67081500E-01, 0.37396800E+00, -.17908700E+00, -.23230700E+00, -.27832700E+00, -.68817700E-02, 0.11286200E-02, 0.43909000E-01, -.44020100E-01, -.38793100E-02, -.25152000E-01, 0.31545700E-01, -.18778500E-01, -.74879100E-01, -.29475400E-01, 0.12874700E-01, 0.48421200E-01, -.18579900E-02, -.13497400E-02, 0.67268500E+00, -.87003900E-02, -.16183500E+00, 0.97047700E-01, -.53657500E-01, -.67518700E-01, 0.32198300E-01, -.25068900E-01, 0.25882500E-01, 0.88558500E-02, -.23087600E+00, 0.13613100E-01, 0.76013700E-01, 0.24616900E-01, 0.45144100E+00, 0.10100500E-02, -.80555300E-01, -.17607400E-01, -.26753600E-01, -.16779200E-01, -.10412800E+01, -.80701100E-03, -.27510600E-02, -.40884000E-01, -.42393100E-02, 0.12192200E+00, 0.39046400E-02, -.19658100E-01, -.25819700E-03, 0.83973600E-02, -.26407300E-02, 0.43283900E-01, 0.30218900E-02, -.20201300E-01, 0.30728100E-02, 0.42361800E-01, 0.91376900E-02, -.18086500E-01, -.66759400E-02, -.57812400E-02, -.38959700E-02, 0.40357100E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.93880300E+00, 0.33250200E+00, 0.54735500E+00, -.51455500E+00, 0.63828900E+00, 0.11238500E+00, 0.30354600E+00, -.96909000E-02, -.82695500E+00, 0.26121700E-01, -.90229100E-01, 0.55112800E+00, 0.40627000E+00, 0.70152600E-02, 0.79835100E+00, -.21649600E+00, -.14680600E+00, -.18062700E+00, -.27817000E-01, -.42445100E+00, 0.62044300E+00, 0.17279700E-01, -.25434100E+00, 0.54214300E+00, 0.24778100E-01, 0.66897900E-01, 0.33051300E+00, -.82376400E-02, 0.23643800E+00, 0.22353600E+00, -.56851800E-01, -.31158900E+00, 0.26423900E+00, 0.50094500E-01, 0.20958600E+00, 0.36206100E+00, 0.33289400E-01, 0.69724200E+00, -.25427800E+00, 0.25985200E+00, -.13601700E+00, 0.92095000E-02, 0.25724700E-02, 0.31829700E-01, -.34933100E-02, -.12575000E+00, 0.10054500E-01, 0.49982900E-02, -.16761100E+00, 0.31933600E+00, 0.42854800E+00, 0.67458200E+00, 0.19043000E-01, 0.27742200E+00, 0.84563800E-01, -.64992400E-01, -.28917200E+00, -.10690400E+01, 0.25639400E-02, 0.17579700E+00, -.63039600E-01, 0.48283700E-01, -.45995000E-01, 0.60775400E+00, -.67463400E+00, 0.29037000E-01, 0.35864300E-02, 0.32642600E+00, 0.20207900E+00, -.74380700E-01, 0.55499000E-01, -.30098900E+00, 0.73455800E-01, -.60606100E-01, 0.50452600E-01, -.20641800E+00, 0.85933600E-02, 0.13651100E+00, -.44966600E-01, -.46460300E-01, 0.40817800E-01, -.14824800E+00, 0.82539700E-01, 0.61492500E-01, -.57707400E-01, -.13012900E+00, -.28779200E-01, 0.14036100E+00, -.96818900E-01, 0.25097800E+00, -.13815100E+00, 0.59062400E-01, -.19331600E+00, 0.15641000E+00, 0.18720100E+00, -.13929000E-01, 0.13618300E+00, 0.38444400E+00, -.57394900E-01, -.51606900E-01, -.41427700E-01, 0.13416600E+00, 0.35122900E-03, -.24339900E+00, 0.43138800E-01, -.37548800E-01, -.44169200E-01, 0.17448800E+00, 0.60378600E-02, -.25770900E-03, -.10507500E+00, 0.21306600E-01, 0.98809300E-03, -.88671200E-03, -.27514300E-03, 0.29424000E-01, 0.23676600E+00, -.26396900E+00, 0.10626700E+00, -.96010000E-01, 0.17081700E-02, -.70759200E+00, -.70701600E+00, -.36862300E-01, -.36189000E-02, 0.14235900E-02, 0.13210300E+00, -.66828700E-01, 0.28282100E-01, -.72111800E-01, -.28312500E+00, 0.63355100E-02, -.22189800E+00, -.52935300E-01, 0.79374900E-01, 0.26054800E-02, 0.33406200E+00, -.57726400E-01, 0.84901100E-01, 0.19350100E-02, 0.30577900E+00, -.22784000E-03, 0.50324000E-02, 0.61459300E-01, -.59104300E-01, 0.33232500E-01, 0.26354400E-02, -.56041300E-01, 0.23691600E+00, 0.99549300E-01, 0.78905000E-01, 0.54982400E-01, 0.45831000E-01, -.65858900E-01, 0.38454100E-01, -.11328400E-01, 0.12277100E+00, 0.18468300E-01, -.18290600E-01, -.14979000E+00, 0.65550000E-02, 0.81173100E-01, 0.29250800E-01, -.71757900E-01, 0.10553600E+00, -.33268900E-02, 0.15655200E-01, -.22597900E-01, -.11855900E-01, 0.62916400E-02, -.13341900E+00, 0.10447900E+00, 0.15135400E+00, 0.32305600E+00, 0.16679200E-01, -.15881900E-01, -.15984500E-01, 0.64244500E-01, -.11711100E+00, 0.14964000E-02, 0.47044900E+00, -.52424500E-02, 0.14868500E-01, -.62249500E-01, -.55577700E-01, -.47571200E+00, 0.85288000E-01, 0.23441300E+00, 0.35644200E-02, -.10905600E+00, -.32673600E-02, -.22491400E-01, 0.14800100E+00, -.59956800E-01, 0.27393000E-01, 0.17732300E-01, 0.20262400E+00, 0.63678900E-01, -.86966500E-01, -.24982800E+00, -.26799200E-02, -.24908700E-01, 0.43993300E-02, 0.21885800E+00, 0.78658400E-03, -.37091800E+00, -.49242500E-01, -.47820500E-02, 0.94281200E-01, -.67415800E-01, -.99754100E-02, 0.15593200E-01, 0.31383200E-02, -.20197300E+00, 0.92055400E-02, -.18029200E-02, -.10783200E-01, 0.53998000E-01, -.40127500E-01, -.23767700E-01, -.36811200E-01, 0.12418200E-01, 0.21972100E-01, -.20903300E-02, 0.13173800E+00, 0.39529900E-01, 0.40019200E-01, 0.12709200E+00, -.24268600E-01, 0.19624600E+00, -.48050600E-01, 0.48747800E-01, 0.75093100E-01, -.46200800E-01, -.15722300E-02, 0.14076700E-01, 0.41730700E-02, 0.13460000E-01, 0.44093600E-01, 0.30468900E-01, -.77205500E-02, -.44995000E-01, 0.11634700E+00, -.39939200E-01, 0.49663800E-01, -.11138200E-01, 0.30870400E-01, 0.20905600E+00, 0.92154000E-03, -.39317200E-01, -.21330500E-01, -.44644700E-01, 0.15391300E-01, 0.36413000E-04, 0.86150000E-02, -.30548700E-03, -.27946700E-02, -.75045300E-01, -.21541600E-02, -.24365500E-01, -.26166600E-01, -.23823500E+00, -.43087000E-02, -.90248800E-02, -.12187500E-01, 0.24325200E-01, -.17870000E-01, 0.19618900E-02, -.43031000E-02, -.19495900E-01, 0.14610000E+00, 0.25498100E-01, 0.20163700E-01, 0.18865200E+00, 0.38251000E+00, -.18537300E-01, -.17718600E+00, -.18194700E-01, -.54973500E-02, 0.24003300E-02, 0.40685000E+00, -.18299800E+00, -.24780400E-02, -.18917200E+00, 0.32540700E+00, 0.26698200E-01, 0.22260800E-01, -.25279300E-02, 0.17952200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18786600E+01, 0.88603800E-01, -.33390800E+01, -.10558100E+01, -.22999700E+01, 0.70433800E-02, -.47496200E+00, -.35518500E+00, 0.34183900E+01, 0.29530900E-01, 0.17260100E+00, -.27008400E+01, -.76591700E+00, -.78307000E-01, -.32581000E+01, 0.12783200E+01, 0.16935400E+01, 0.51079300E+00, 0.14664400E+00, 0.10543000E+01, -.15080300E+01, -.18298400E-01, 0.21076600E+00, -.65621600E-01, -.12175200E+00, 0.58170400E-01, 0.86690400E-01, 0.73853600E-01, -.30241500E+00, 0.55518100E+00, 0.64964300E+00, 0.39945700E+00, -.35071900E+00, -.79534900E+00, -.40376100E+00, 0.52849100E+00, 0.15397500E-01, -.23839200E+00, 0.40582000E+00, 0.44879700E+00, -.39972200E+00, -.34333700E+00, -.11263100E+01, -.89610300E-01, 0.84817500E-01, -.28386600E+00, -.54171000E+00, 0.10030400E-01, 0.36788200E+00, -.73039300E+00, 0.38869300E+00, 0.14274400E+01, -.10334000E+00, -.72153500E+00, -.19530200E+00, -.22358800E+00, -.10196600E+00, 0.10132100E+01, 0.62166600E-01, -.74048000E+00, -.16685600E+00, -.36735500E-01, 0.58697400E-01, 0.55836600E+00, 0.22946400E+00, -.45363700E+00, 0.20199500E+00, 0.16367500E+01, 0.71208900E+00, 0.30776800E+00, -.16812900E+00, 0.13080800E+01, -.10571600E+00, -.30724100E+00, -.21270500E+00, 0.29455900E+00, 0.16405500E+00, 0.43286800E+00, -.23036900E+00, 0.13429400E+00, -.30957500E+00, 0.10957800E+00, -.41666500E+00, -.19651500E+01, -.98110000E+00, 0.81649000E+00, -.47214800E+00, -.70201600E+00, 0.32296300E+00, -.27380600E+00, -.36901700E+00, -.14214500E+00, -.74528400E+00, -.22251500E+00, 0.19433900E-01, -.11387500E+00, -.49545700E+00, -.66121700E+00, -.17805100E+00, 0.12166100E+00, 0.57610900E-01, -.23443800E+00, -.75191300E-03, 0.28939800E+00, 0.10151100E+00, 0.19865000E+00, 0.16310300E-01, -.44827700E+00, -.17289200E+00, 0.19657700E+00, 0.97472700E+00, 0.21300600E+00, 0.14549400E+00, 0.33081300E-02, -.36501200E-01, 0.93984100E-01, 0.36385300E+00, 0.50270100E+00, -.55524600E+00, -.72553400E-02, -.70124000E-01, 0.18966500E+00, 0.13197800E+01, 0.17810800E+00, 0.22337700E-02, -.32552100E+00, -.41266700E+00, 0.53706100E-01, 0.41963400E+00, -.37157000E+00, -.50101100E-01, 0.71509600E-01, 0.27760600E+00, -.23371900E+00, -.15381900E+00, 0.16868800E-01, -.39925200E+00, 0.18631000E+00, 0.20012500E-01, 0.13811000E+00, -.59293100E+00, 0.48328000E-01, -.25999500E-01, 0.14608000E+00, 0.10404900E+00, -.34589300E+00, 0.12566600E-01, -.88119200E-02, 0.76061600E+00, 0.79115100E-01, -.19679400E-01, 0.22552700E+00, 0.60277000E+00, 0.50661800E-01, -.17285500E+00, -.67360500E-01, 0.32280600E+00, 0.35523000E-01, 0.60091100E-01, 0.10101300E+00, 0.14445800E+00, -.10698900E+00, -.40057100E+00, -.29120900E+00, 0.13928100E+00, -.13930000E+00, 0.72427300E+00, 0.79348400E+00, 0.19459000E-01, 0.27091100E+00, 0.46887400E+00, -.59727800E+00, 0.75521100E-01, -.90519300E+00, -.27135400E+00, -.85092300E-01, -.61142400E-01, -.15683500E+00, -.35991200E+00, -.32402200E-01, 0.21546700E+00, -.66117000E+00, -.31431900E+00, 0.50830900E-01, 0.21975000E-01, -.54128000E+00, 0.70174200E-01, -.55392800E+00, 0.14408500E-01, -.16454700E+00, -.71614200E-02, 0.74354300E-01, -.64043900E-01, 0.16886500E+00, -.21495800E+00, -.56078500E-01, 0.14220900E+00, 0.93274600E-02, 0.10728500E+00, 0.55670800E+00, 0.60739000E-01, -.20765800E-01, 0.12444000E+00, -.30910800E+00, -.33338000E+00, 0.13738900E+00, 0.17483300E-01, 0.32232300E+00, 0.30712600E-01, 0.70977200E-01, -.71132800E-01, 0.23118300E+00, 0.28118600E-02, 0.11974300E+00, -.11919200E+00, 0.39044500E-01, -.47152300E-01, 0.18633600E-01, -.91485900E-01, 0.15002400E-01, -.24458600E-01, 0.87858200E-01, -.69579500E-01, -.28438500E-02, -.22698300E-01, -.40556700E-01, 0.48954600E-02, 0.16346200E+00, 0.18738800E-01, 0.37233100E+00, 0.17151000E+00, -.73445600E+00, 0.66425200E-01, -.53876800E-01, 0.65396100E-02, -.11793400E+00, 0.50438200E-01, -.29802800E-01, 0.12742000E+00, 0.12969400E+00, -.33759900E-01, 0.26018500E-01, -.20334600E+00, 0.63388100E-02, 0.12268500E-01, -.87110100E-05, -.69555500E-01, 0.18973400E+00, 0.17649500E-01, 0.31765800E+00, -.10157800E+00, -.26553400E+00, 0.36751700E+00, 0.75184000E-01, 0.46685300E-01, 0.15568600E+00, 0.36669500E-01, 0.58875900E+00, -.16976900E+00, -.32785900E+00, 0.13581000E+00, -.38260500E+00, 0.78586400E-01, -.87897100E-01, 0.72924100E-01, -.14262100E+00, 0.11517400E+00, 0.76979600E+00, 0.10055300E+00, 0.44612100E+00, -.28680200E+01, -.18757100E+00, 0.20748200E+00, -.11189800E+01, -.64428200E+01, -.15348100E+00, 0.15144900E+01, -.90475100E-01, 0.13695300E+01, -.92539900E-01, -.70591000E+01, 0.11886300E+01, 0.12583400E+01, 0.18774200E+01, -.54794900E+01, -.75894900E+00, -.91497400E+00, 0.19366000E+01, 0.15339900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30630000E+00, -.15341900E+00, -.77526000E+00, -.89927600E+00, -.29891600E-01, 0.37482300E-01, -.86216700E-01, -.57734800E+00, -.12661800E+00, -.85593700E-01, -.31398000E-02, 0.22419600E+00, -.43683100E+00, -.34153900E+00, 0.12110700E-01, -.49382100E+00, -.14717100E+00, 0.26604700E+00, -.15588800E+00, 0.23387200E+00, -.22285300E+00, -.15365100E-01, 0.39352900E-01, 0.44793600E+00, 0.76231000E-01, 0.36900600E-01, 0.69001200E-01, -.12944800E-01, 0.20563100E+00, 0.14668100E+00, -.79647500E-01, 0.57956700E-01, 0.21361500E+00, 0.14792600E-01, 0.21393000E+00, 0.25142800E+00, 0.12431300E-01, 0.37149000E+00, -.94187100E-01, 0.23154000E+00, 0.19556700E+00, 0.58439500E-01, -.30867400E+00, 0.13317200E-01, 0.10567300E+00, -.15089300E-01, 0.57170800E-01, 0.14212200E-02, 0.79640700E-01, 0.12381400E+00, 0.15690400E+00, 0.40856600E+00, -.18027000E-01, 0.67639800E-01, 0.51059900E-01, -.14081900E-01, -.26410300E+00, -.23933900E+00, -.22983700E-01, 0.50366000E-01, -.49853000E-01, -.20474800E-01, -.50325200E-01, 0.44532600E+00, -.50774500E+00, 0.17550200E-01, -.11317000E-01, 0.37141000E+00, 0.12833100E+00, 0.52617400E-01, -.14808400E+00, -.52340900E-01, 0.46707400E-01, -.18053000E-01, 0.14548100E-02, -.31750900E-01, -.14773200E-01, 0.76653000E-01, 0.13621000E-01, 0.21341900E-01, -.18006900E-01, 0.19894300E+00, -.26881900E+00, -.82319500E-01, 0.16402600E+00, -.11500000E-01, -.10404800E-01, 0.63121300E-01, -.43668000E-01, -.70201000E-01, -.68104900E-01, 0.15968100E-01, -.77042400E-02, 0.29613500E-01, -.22063500E+00, 0.27505900E+00, 0.79092000E-01, 0.17665500E+00, -.16059900E-01, -.93597000E-01, -.26046200E-01, -.29894200E-01, 0.15690200E-02, -.16643800E+00, 0.77234700E-01, 0.22183900E-01, -.22173900E-01, 0.10406500E+00, 0.14083500E+00, 0.22084800E-01, -.54731400E+00, 0.51946400E-02, 0.69744700E-01, -.13551500E-03, 0.11967900E-01, -.10033700E-01, 0.61178000E+00, -.28881600E-01, -.19334900E+00, -.17838400E+00, 0.62061100E-01, 0.15107300E+00, 0.57503000E-01, 0.13833200E+00, -.63671800E-02, 0.11746800E+00, 0.51038900E-01, 0.34482200E-01, 0.29524900E+00, 0.57439300E-02, -.45526200E-01, 0.38708900E-01, 0.95211200E-01, 0.13825700E+00, 0.68865900E-01, -.11788500E-01, 0.53163200E-01, -.18054700E-01, -.95217800E-01, -.92999900E-02, 0.31054000E+00, -.16107300E-01, 0.32981500E-01, 0.26590700E-01, 0.20044900E-02, -.27240200E-01, -.25973400E-02, 0.15773700E-01, -.39655200E-01, -.86596300E-01, -.48475700E-01, -.51059600E-01, -.94360200E-01, 0.17647800E-01, 0.91284800E-01, -.15270800E-01, 0.15476700E-01, -.10310600E-02, -.54301000E-01, -.74416900E-01, -.28583300E-02, -.20122200E+00, -.18510200E+00, -.13763600E+00, -.31684100E-01, 0.17294100E-01, 0.17191500E+00, -.16430000E+00, -.16617800E-01, -.53089400E-01, -.18451100E+00, 0.28586900E-01, 0.19954200E+00, 0.19224900E-01, -.21269700E-01, -.26678500E-01, -.10289800E-01, 0.44109900E-02, -.10738200E+00, 0.13774400E-04, 0.68137700E-01, -.64391300E-01, 0.73180500E-01, -.41842800E-02, 0.15464000E-01, 0.97731300E-01, -.72331500E-01, 0.25897900E-02, -.91732100E-02, -.17073400E+00, 0.28174300E-03, 0.18555400E-01, 0.31671900E-01, -.11619300E+00, 0.18443200E-01, 0.29093800E-02, -.11138500E+00, 0.11248100E+00, 0.66542900E-01, -.16529200E+00, -.13484800E-01, 0.93363000E-03, -.83875800E-01, -.15361400E+00, -.99733100E-01, 0.84452100E-01, -.71912600E-02, 0.58871700E-01, -.53348900E-01, 0.40489600E-01, 0.23063500E-01, 0.84442500E-01, 0.26825900E-02, -.19538700E-01, -.28179700E-01, -.48611600E-01, -.57336700E-01, 0.56574800E-02, -.21166800E-01, -.71882000E-02, -.61374000E-01, -.87044900E-02, -.42227300E-01, -.12680200E-02, 0.26251000E-01, -.65075400E-01, -.15859200E+00, -.49207700E-01, 0.24293800E-01, -.14541600E+00, -.54173700E-01, 0.84207800E-01, -.72140500E-01, 0.19836300E-01, -.17234400E-02, -.21293700E-01, -.28100700E-01, 0.14871200E-02, 0.92839900E-02, 0.14406700E-01, -.99746100E-02, -.50316700E-01, -.20800100E-01, -.28515400E-03, 0.30985600E-01, -.35347600E-02, -.17153700E-01, 0.30719900E+00, 0.43237000E-02, 0.27840300E-01, -.10495100E-01, -.20206100E-01, -.74640600E-02, -.41126900E-02, -.64636400E-02, -.17313300E-03, -.12564300E-02, -.26264100E-01, 0.64524600E-02, 0.44458100E-01, 0.21032400E-01, 0.14909000E+00, 0.45239400E-03, -.36739600E-01, -.12093400E-01, 0.16694300E-03, 0.18152200E-02, 0.85000400E-02, 0.41234900E-01, 0.21130500E-01, -.37214100E-01, -.67780000E-02, -.32070600E-01, -.95681300E-01, 0.14441400E-01, 0.27616900E+00, -.19750700E-02, 0.33297900E+00, -.15436100E+00, 0.16572100E-01, -.46262300E-02, 0.20085700E-01, -.14438900E+00, -.18225200E-02, -.21513100E-01, -.17046200E-01, 0.93846700E-01, 0.79882200E-01, -.84038900E-04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10581000E+01, -.35499900E+00, 0.15338900E+01, 0.51511600E+00, 0.14979200E+01, 0.66794100E-01, 0.16400600E+00, 0.88995500E-01, -.13993500E+01, -.90736500E-01, -.11434800E+00, 0.20756400E+01, -.33824800E+00, -.15039900E+00, 0.80932100E+00, -.71673300E+00, -.88776200E+00, -.12456900E+00, 0.10883100E+00, -.70215100E+00, -.10207700E+00, 0.49363900E-01, -.18385800E+00, 0.18017300E-01, 0.16570200E-01, 0.51544700E-01, 0.24374200E+00, 0.38042800E-03, 0.11538100E+00, -.32252400E+00, 0.12658500E-01, -.25824700E-01, -.47718500E-01, 0.70252000E+00, -.21963300E+00, -.43712000E+00, -.10330400E-01, -.49352600E+00, 0.13854500E+00, -.13401600E-01, 0.11023600E+00, 0.17371200E+00, 0.14261700E+00, 0.13635200E-01, -.27254600E+00, -.65913400E-01, -.80898700E-01, -.26065800E-03, -.32461300E+00, 0.15927100E+00, 0.26272600E+00, -.26004800E+00, 0.41029800E-01, 0.16818300E+00, 0.83901300E-01, -.19675500E+00, -.24365800E-01, -.13624000E+00, 0.25645800E-03, 0.30664200E+00, 0.74701200E-01, 0.28866500E-02, 0.11682200E+00, 0.42728500E-01, 0.24662600E+00, 0.62111500E-01, -.14023600E-01, -.66864300E-02, -.11943100E+00, -.99100000E-01, -.23980500E+00, -.19798200E-01, -.14504700E+00, -.17220800E-01, -.25145700E-01, -.27101900E+00, -.95120500E-02, -.74366000E-01, -.11020000E+00, -.81167800E-01, 0.79099500E-01, -.90242500E-01, 0.26876700E+00, 0.65347100E+00, 0.11386600E+00, -.27337600E+00, 0.22101100E-01, 0.26154000E+00, -.12231000E+00, 0.30412400E+00, 0.46079400E-01, 0.59528900E-01, -.13166000E+00, 0.13873000E+00, 0.18262500E+00, 0.25107000E-01, 0.79673500E+00, 0.23938500E+00, 0.89465300E-01, -.13638900E+00, -.38368600E-01, 0.14418300E+00, -.32267500E-02, 0.64835400E+00, 0.10327900E+00, 0.66232800E-01, -.11737400E+00, 0.13501400E+00, 0.12411300E+00, 0.76615600E-01, -.69828500E+00, -.10845100E+00, -.63655800E-01, -.19567000E-02, 0.30664400E-01, -.35309700E-01, -.40324500E+00, -.43240500E+00, 0.63503500E-01, -.12272900E-01, -.62587200E-03, -.98798500E+00, -.17218700E+01, 0.11021200E+00, 0.69024700E-02, -.26423900E+00, 0.83916800E-01, -.23953800E-01, -.52784000E+00, -.76853000E-02, -.98703400E-02, 0.88913800E-02, -.37848000E+00, -.28539100E+00, -.16763300E+00, 0.23670600E-01, 0.65370900E+00, -.22127600E+00, 0.15220900E+00, -.36145000E-01, -.20947900E+00, -.70747200E-01, 0.33325400E-01, 0.22593500E-01, -.42687200E-01, -.76729300E-03, 0.61572400E-02, -.13120700E+00, -.87016800E-01, 0.75888800E-01, -.82746100E-01, -.19360000E-02, 0.18889300E-01, -.48705100E-01, 0.36460700E-01, -.52016800E-01, 0.14791500E+00, 0.11571200E-01, -.12795200E+00, -.19473500E+00, 0.56859400E-01, 0.13704900E+00, 0.37776100E-01, -.78924500E-01, 0.14529000E+00, 0.15652000E+00, -.27321700E-01, -.25841900E+00, -.11192000E-01, -.69205900E-01, -.40398400E-01, -.81239500E-01, -.13037200E-01, 0.10505800E+00, -.28223100E-02, 0.11350800E+00, 0.35105800E-01, 0.97363900E-02, -.21750300E+00, -.47385200E-02, 0.32183500E+00, -.96493000E-01, 0.40633800E-01, -.24373000E-01, 0.17401500E-01, -.13947900E+00, -.14974300E+00, 0.25298100E+00, -.80502800E-02, -.16331800E+00, -.17308800E-02, -.32990200E-01, 0.14685300E+00, -.16380000E+00, 0.26290100E-01, -.17813600E-01, 0.57156000E-01, 0.78635900E-01, 0.10809700E+00, -.23792700E+00, -.49452900E-01, -.77540400E-02, -.50490000E-01, 0.12473200E+00, 0.15852100E+00, -.18099300E-02, 0.34015600E-02, -.25516700E-01, 0.50016500E-01, -.25958200E-01, 0.32029800E-01, -.22993700E+00, -.21796700E-03, -.26334000E+00, 0.70562900E-02, -.33494600E-01, -.99981600E-01, 0.33336500E-01, -.56095600E-01, 0.12044900E-01, -.58604400E-01, 0.97271600E-03, 0.78907200E-02, -.38231400E-03, 0.12185100E+00, -.53379100E-02, -.50900900E-01, -.26176600E-01, 0.10451300E-02, 0.14361900E+00, 0.63136300E-02, 0.26578900E+00, -.14292100E+00, 0.14218700E+00, 0.69822400E-02, -.58782300E-02, -.54623000E-01, 0.10555400E-01, -.41472300E-01, 0.64794100E-01, -.58682000E-01, -.16785100E+00, -.11263000E+00, -.30197800E-01, -.31902100E-04, -.12835400E-01, -.21755400E-01, 0.22777500E+00, 0.19978600E-01, 0.75060800E-01, -.20802100E+00, -.95708900E-01, 0.10440100E+00, 0.20410500E-01, 0.13283400E-01, 0.23695300E-01, 0.10080700E-01, 0.89840900E-03, -.16659800E-01, -.12112900E+00, 0.75587200E-02, -.11133200E+00, 0.37620700E-01, -.46531700E-01, -.10087500E-01, 0.15378900E-01, 0.40837500E-02, 0.86808100E-01, 0.58632100E-01, 0.86876800E-01, -.77533800E+00, -.40213200E-01, 0.49096800E-01, -.34421900E-01, 0.13140400E+00, 0.76070700E-02, 0.66368900E+00, 0.67561600E-02, -.30364000E+00, -.14516600E-01, -.80166900E-02, -.31792800E-01, -.30796100E+00, 0.55905700E+00, -.40248400E-01, 0.52158200E-01, 0.56363400E-01, 0.89536500E-01, 0.11402900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.59801900E+00, -.60293700E+00, -.14772900E+01, -.57182900E+00, -.87012600E+00, -.11165100E+00, -.91996100E-01, -.97887000E+00, 0.13191400E+00, -.12658300E+00, -.32230700E-01, 0.25835100E-01, -.11640200E+00, -.45599800E+00, -.15574800E+00, -.97747900E+00, -.94120800E-01, 0.49725200E+00, -.26349600E+00, 0.42053700E+00, -.42044400E+00, -.30984700E-01, 0.10621600E+00, 0.70540300E+00, 0.10844600E+00, 0.49217300E-01, -.20793300E+00, -.13506900E-01, 0.28220900E+00, 0.36755900E+00, -.34959800E-01, 0.85385400E-01, 0.40155600E+00, -.15730700E+00, -.92922100E-01, 0.25224800E+00, 0.39310800E-02, -.70146400E-01, 0.46465400E-02, 0.43126100E+00, 0.29526600E-02, 0.14128900E-01, -.36538700E+00, -.74013400E-01, 0.15103400E+00, 0.86934800E-01, 0.94457400E-01, 0.66330300E-03, 0.10698000E+00, -.28460100E+00, -.36572200E-01, 0.70357700E+00, -.76702800E-01, 0.33456200E-01, -.10657400E-01, -.16104100E+00, -.19165100E+00, 0.27715900E+00, -.33564800E-01, -.11854900E+00, 0.97967300E-02, 0.21039700E-01, -.57944600E-02, 0.68507600E+00, -.71696900E+00, -.19271900E-01, 0.31925100E-01, 0.55053400E+00, 0.35222500E+00, 0.92777400E-01, 0.56164500E+00, -.98277700E-01, 0.31620400E+00, -.93511300E-03, -.44439700E-01, -.10501900E+00, -.18294000E-02, 0.21764300E+00, -.27932900E-01, 0.32579000E-01, -.61537000E-01, 0.25361900E+00, -.39895400E+00, -.31499700E+00, 0.37374000E-01, -.55103800E-01, -.30656600E-01, 0.14076100E-01, -.13025000E-02, -.10900900E+00, -.20297800E+00, -.12335800E-01, -.19714000E+00, 0.50159600E-01, -.17446200E+00, 0.14135800E+00, -.56079100E+00, -.30202500E-01, -.12549800E+00, 0.38125900E-01, 0.68959800E-01, -.45631600E-01, 0.32444900E-02, -.48050500E+00, 0.12987600E+00, -.69394900E-01, -.88417200E-01, 0.39970000E-01, 0.20952000E+00, -.10458000E+00, -.42455500E+00, 0.21520900E-01, 0.42261800E-01, 0.38999000E-03, 0.77509500E-01, 0.54163900E-01, 0.48661100E+00, 0.50742500E-01, 0.96884100E-01, -.11268500E+00, 0.87575100E-01, -.23672600E+00, 0.28982100E-01, 0.15417200E+00, -.83860900E-02, 0.13160000E+00, -.14126800E-01, 0.49419100E-01, 0.51862600E+00, 0.79485100E-01, -.45516700E-01, 0.76395800E-01, 0.27387100E+00, 0.20635200E+00, 0.14603300E+00, -.15629700E-01, -.89137300E-01, -.60347100E-01, -.18620100E+00, -.37847500E-01, 0.33523000E+00, -.72537700E-01, 0.34044300E-01, -.32556500E-01, -.52278100E-01, 0.26767200E-01, -.55948200E-02, 0.34571100E-01, -.30579000E-01, -.11955400E+00, -.35816200E-01, -.54080300E-01, -.17613500E+00, 0.89043000E-01, 0.16459700E+00, -.44824500E-01, 0.20795900E+00, 0.49714800E-02, -.60113300E-01, -.69290100E-01, 0.51889400E-01, -.25981600E+00, -.25792000E+00, -.17151600E+00, -.43994000E-01, -.11928100E-01, 0.29595900E-01, -.11338900E+00, -.10478700E-01, -.21880900E-01, -.14667700E+00, 0.86980900E-01, 0.15404000E+00, 0.33882500E-01, -.18743600E-01, -.97430000E-01, -.59238700E-01, 0.70851100E-02, -.56457900E-01, 0.90775700E-03, -.10855000E+00, -.77522400E-01, 0.25414700E-01, 0.11075300E-01, 0.64021000E-02, 0.27562200E+00, -.13358800E+00, -.34094100E-01, -.25096200E-02, -.18491100E+00, 0.53569000E-03, 0.36610800E-01, -.56081900E-01, -.54362500E-01, -.14338900E-01, -.27563300E-02, -.30241900E+00, 0.43147400E-02, 0.83416200E-01, 0.14151700E-01, -.21735900E-01, -.87610700E-02, -.55480900E-01, -.84773400E-01, 0.18238100E-01, 0.17651200E+00, 0.12920300E-01, 0.53852200E-02, -.59081900E-01, 0.83602100E-01, 0.34891900E-01, 0.21376000E+00, 0.33380900E-02, -.85061400E-01, 0.87273300E-02, -.48424900E-01, -.62634400E-01, 0.31323200E-01, -.15806700E-01, -.12155000E-01, -.64066500E-01, -.10695400E-01, -.62361100E-01, -.16827200E-02, 0.43304000E-01, -.92929100E-01, -.13599100E+00, -.49603600E-01, 0.28628900E-01, -.24688900E+00, -.16516000E+00, 0.53929200E-01, -.74409200E-01, 0.98054900E-02, -.45215700E-02, -.81568000E-02, -.33253400E-01, 0.29552500E-02, 0.79564500E-02, 0.17473200E-01, -.86146600E-02, -.44772400E-01, -.78779600E-02, -.81010800E-02, 0.20066600E-01, -.20359600E-02, -.18208200E-01, 0.36417400E+00, 0.32970300E-03, 0.38090900E-01, -.22226600E-01, 0.40307500E-02, -.17262400E-01, -.36547300E-02, -.40216100E-02, 0.63379400E-02, -.15088900E-02, 0.21196300E-01, 0.55153100E-02, 0.50943400E-01, 0.40488400E-01, 0.10041000E+00, -.11234200E-02, -.37648700E-01, -.15586700E-01, 0.70455400E-02, 0.10836100E-02, 0.17200000E-01, 0.46175000E-01, 0.22069200E-01, -.63641000E-01, 0.34863900E-02, -.11150200E-01, -.94720900E-01, 0.18823400E-01, 0.14360500E+01, 0.10021500E-02, -.19869600E+00, 0.14883500E+00, -.87065400E-02, 0.26536800E-02, -.30397300E-01, 0.14158700E+00, 0.36512300E-03, 0.11555900E-01, 0.17106000E-01, -.54355100E-01, -.41022000E-01, 0.19356500E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.53826400E+01, 0.19125400E+01, 0.13117100E+01, 0.42808900E+01, 0.45991300E+01, 0.35084700E+00, -.44684000E+01, -.26271100E+01, 0.78798700E+01, 0.22548500E+01, 0.90535800E-01, -.25121300E+01, -.17549000E+01, 0.10934500E+01, -.50854500E+01, 0.31122600E+01, 0.18105800E+01, 0.13304300E+01, -.35469000E+01, 0.99117300E+00, 0.64192100E+01, -.59728800E+00, 0.31734600E+01, -.31326800E+01, 0.20151200E+00, -.54184600E+00, -.46612900E+01, 0.15719200E+01, 0.35867000E+00, 0.66713400E+00, 0.92581200E+00, -.20059900E+01, -.60958700E-02, 0.93647500E+00, -.78861000E+00, -.18503000E+01, -.90086100E-01, -.30515500E+01, 0.49903100E+00, -.13313900E+01, -.46666300E+01, -.15854600E-01, 0.37170700E+01, 0.25965500E+00, -.67743900E+00, -.91453400E+00, 0.15817500E+01, -.26639700E-01, -.13627800E+01, 0.54095200E+00, -.10597600E+01, -.53488200E+01, 0.37268100E+00, 0.57353100E+00, 0.14766800E+00, 0.79486300E-01, -.24709000E+00, -.87118700E+00, -.35108000E-01, 0.27711800E+01, 0.14444300E+00, -.12684700E+01, 0.10800400E+01, -.21345800E+01, 0.41439000E+01, 0.81379600E+00, -.11147600E+01, -.67698400E+01, -.32662400E+01, -.78234900E+00, 0.29848200E+01, 0.19505600E+00, 0.44625000E+00, -.35304000E+00, -.38718000E+00, 0.53783000E-01, -.93385800E-01, 0.61891700E+00, 0.18505500E+00, 0.79738400E-01, 0.56888000E+00, -.14500900E+01, 0.32962400E+01, 0.70232200E+01, 0.27597400E+01, 0.85620700E+00, -.64704700E+00, -.46464700E-02, -.13819700E+00, 0.29206200E+01, 0.12087200E+00, 0.70969100E+00, -.32733200E+01, 0.15040200E+01, 0.41936700E+00, -.18894600E+01, 0.74074800E+01, 0.33955000E-01, 0.22656000E+01, 0.23578200E+01, 0.26592000E+00, 0.46507500E+00, 0.26860400E-01, 0.53206700E+01, -.33402800E+01, -.91746900E+00, -.10079900E+01, 0.12640400E+01, 0.16469700E+01, -.62625400E+00, -.19099900E+02, -.28912000E+01, 0.68294000E+00, -.10909300E-01, -.43162300E+00, -.16424700E+01, -.66335900E+01, -.41279000E+01, 0.67783500E+01, 0.15660100E+01, -.38665400E+00, 0.79009500E+01, -.84064600E+01, 0.32661700E+01, 0.13096700E-01, -.63089300E+00, 0.29788800E+01, -.48896700E+00, 0.14311500E+01, -.49246700E+00, -.11713400E+01, 0.72414900E+00, 0.23720600E-01, -.31958100E+00, 0.92264000E+00, 0.26036400E-01, 0.24721000E+01, -.47381100E+00, -.50611000E+00, -.25095400E+00, 0.25273500E+01, 0.14467100E+00, -.35670500E+00, -.47742600E+00, 0.48121500E-01, -.35700800E+00, 0.45294700E+00, -.51183300E+00, 0.27475900E+00, 0.58328300E+00, 0.69884700E+00, 0.68125900E+00, 0.14347400E+00, -.21542900E+00, 0.10774600E+01, -.52066400E-01, -.10937500E+01, 0.62208600E-01, -.65698100E+00, 0.16110000E+01, 0.18100400E+00, 0.18168100E+01, 0.22558600E+00, 0.11780300E+01, -.33815900E+01, 0.13675600E+01, -.21759500E+01, -.39306000E+00, -.11380200E+00, 0.58000900E-01, 0.58521600E+00, -.33272100E+01, 0.46287300E+00, -.47979900E+01, -.33064700E+00, -.26712000E+00, -.25815700E+00, -.55073500E+00, -.60476300E-01, -.13987000E+00, 0.13932300E+01, -.28353000E+00, -.72011900E+00, -.28775900E-01, -.55350100E+00, -.15333700E+01, -.81523300E+00, 0.58866400E+01, 0.29394100E+00, 0.97292700E+00, -.41413800E-01, -.69855700E+00, -.11527800E+00, -.33824500E+01, 0.99502000E+00, 0.61423300E+00, 0.24308400E+01, -.25956100E+01, -.29343500E+00, -.45129400E+00, -.48085500E+00, -.44174500E-01, -.59875400E+00, 0.21430400E+01, 0.38181000E+01, -.13304300E+01, -.42175200E-01, -.61146000E-01, 0.88748000E-01, 0.27864600E+00, -.61696500E-01, -.23542200E+01, 0.51533300E-02, 0.34021000E+00, 0.56806800E+00, 0.42187400E+00, 0.72842800E+00, -.58934200E+00, -.40002500E-01, -.44641900E-02, -.11154700E+01, 0.44797800E+00, -.40316200E+00, -.60893300E-02, -.56213200E-01, -.20119200E-02, -.17870800E+01, -.21717900E+00, -.18361100E+00, -.27429800E+00, 0.53604700E+00, -.10913100E+01, -.46118400E+00, -.11414400E+01, 0.37475400E-01, 0.81219600E-01, -.22534700E+00, -.17017300E+00, 0.64649400E+00, 0.15181500E+00, -.40724500E+00, -.82496800E+00, -.55570100E+00, -.25594600E-01, 0.63323300E+00, -.14301500E+00, 0.40871800E+00, -.12656100E+01, -.19975800E-01, 0.25098100E+01, -.12881100E+01, -.16417900E+01, 0.22065200E+01, -.13735100E+00, -.43035700E-01, -.62106300E+00, 0.43703800E-01, -.56430200E+01, 0.41991600E+00, 0.56182400E+00, -.29893600E+00, 0.57532700E+01, -.21723100E+00, -.42373200E+00, -.22737300E-01, -.39707800E+00, 0.86820500E-01, -.30498800E+01, -.73376000E+00, 0.17034800E+00, 0.41710900E+01, -.43372800E+00, 0.27546400E+00, -.19755100E+01, -.67714700E+00, 0.34141300E+00, -.16634500E+01, -.12255100E+01, -.20998400E+02, 0.18644800E-01, -.33266400E+00, 0.32808000E+01, -.21143700E+02, 0.44485200E+00, -.67691500E+00, -.21258500E+01, -.66007100E+00, 0.10837400E+01, -.19408400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24205800E+00, 0.33563200E-01, -.25800900E-01, 0.11206800E+01, -.78096700E+00, -.11423800E+00, 0.14940700E+00, 0.17071000E+00, 0.63471400E+00, 0.18214100E+00, 0.48798300E-01, -.51250800E+00, 0.75391500E+00, 0.51318900E+00, 0.10489800E+01, 0.62684800E-01, 0.21466300E+00, 0.54390900E-02, 0.32256000E-01, 0.16255200E+00, 0.71623600E-01, 0.10099400E-01, 0.25299600E-01, 0.18837200E+00, -.19826300E-01, -.38811100E-02, 0.38757500E+00, 0.40221100E-02, 0.62230800E-01, 0.15290000E+00, 0.14025200E+00, -.15001400E+00, 0.71193200E-02, 0.55298300E-01, -.85749500E-01, 0.66987700E-02, -.26615100E-02, 0.15783500E+00, -.10362900E+00, -.89707200E-01, 0.14665300E+00, 0.79444300E-01, 0.63228800E-01, 0.39613000E-01, -.31579300E-01, -.10253900E+00, -.96556800E-02, -.83422200E-03, 0.12222600E+00, -.69715100E-01, 0.20195700E+00, 0.11655200E+00, 0.24551500E-01, -.13685200E-01, 0.23514300E-01, 0.42421100E-01, 0.28753700E-01, 0.31947100E-01, 0.12368800E-01, -.63245200E-01, -.26148800E-02, 0.42610400E-01, -.57845400E-01, -.52426800E-01, 0.11027900E+00, -.16214400E-01, 0.93154300E-02, -.23778600E+00, 0.99551700E-02, -.14021200E-01, 0.25511300E+00, -.10275300E+00, 0.59409000E-01, -.51670400E-01, 0.33373000E-01, 0.92923100E-01, 0.42694200E-01, 0.60476300E-01, 0.47724900E-01, 0.52439500E-01, -.14332600E-01, 0.50082200E-01, 0.25824500E-01, -.66700800E-01, -.94194100E-01, 0.94890900E-01, 0.28449700E-01, -.50016500E-01, -.43519100E-01, -.13196300E-01, -.15000500E+00, -.24773600E-01, -.53735900E-01, 0.55463900E-01, 0.39139000E-01, 0.94536600E-02, -.20951900E+00, -.13669500E+00, -.34439100E-01, 0.11611000E-01, 0.24802300E-02, -.83176900E-01, 0.73488300E-03, -.37794400E+00, -.71936200E-01, -.10297900E+00, 0.44571000E-01, -.32103000E+00, -.19155000E+00, -.13567700E-01, 0.46211400E+00, -.47904300E-02, -.84097800E-01, 0.34012600E-03, -.20728700E-01, 0.36154000E-01, -.36441400E-01, -.36416100E-01, 0.16257000E+00, 0.13965700E-01, 0.25110900E-01, 0.10777600E-01, -.95870300E-01, 0.25706900E-01, -.14229600E-02, -.74491200E-01, -.90056400E-01, 0.21137300E-01, 0.59603200E-01, -.29558700E-02, -.26231300E-01, -.18808100E-01, 0.14735600E-01, -.35046100E-01, -.11143400E+00, -.60336700E-02, 0.72475900E-01, 0.11611500E+00, 0.30946300E-01, 0.22667500E-01, -.37549700E-01, 0.63291000E-01, -.62371000E-03, -.51315600E-01, -.43916600E-01, 0.97493700E-02, -.54128500E-03, 0.44586900E-02, 0.86202200E-01, 0.15277900E+00, 0.74350600E-01, 0.10545900E+00, 0.59112600E-01, 0.29744000E-01, -.73356500E-02, 0.51926800E-01, 0.33712900E-01, -.82645500E-02, 0.39401800E-01, 0.32899400E-01, -.58832900E-02, -.30618200E-01, 0.84287000E-01, -.89106400E-02, 0.65782200E-01, -.35571000E-01, 0.12778800E-01, 0.60491800E-03, 0.56874900E-02, 0.66257700E-02, 0.22871400E-01, 0.10189700E+00, 0.45342400E-01, 0.42863400E-01, -.11036400E-01, -.22638700E-01, -.15440000E-01, 0.85257400E-02, 0.42890400E-01, 0.22919700E-02, -.57912800E-01, 0.11505900E-01, 0.98858300E-02, -.12681500E-01, 0.15032700E-01, 0.46362700E-01, 0.26272700E-01, -.26053500E-01, -.39366100E-04, 0.23471400E-01, 0.53802200E-03, 0.13829300E-01, -.64588700E-01, 0.38663500E-01, -.77552800E-02, 0.99993300E-02, -.97401300E-01, -.25219800E-01, -.28641800E-01, 0.67801700E-01, 0.66665800E-02, 0.12955200E-02, 0.70197400E-02, 0.25932100E-01, 0.53365600E-01, -.22228700E-01, -.17346000E-01, -.31166900E-01, -.15376900E-01, -.30163000E-02, 0.81556300E-02, 0.12512900E+00, -.17572500E-03, -.51270400E-01, 0.13566800E-01, 0.18318600E-02, -.38436300E-02, 0.33922900E-01, 0.23892800E-01, -.54484500E-02, 0.27558500E-02, -.64244300E-02, 0.17752200E-01, 0.44507100E-03, -.10486400E-01, 0.36469100E-02, 0.29764000E-01, -.81894600E-02, 0.98850800E-02, -.57177500E-01, 0.36744600E-01, 0.11073800E-01, 0.16847900E-01, 0.22729800E-03, 0.10992300E-02, 0.44265200E-02, 0.47989300E-02, -.37040400E-02, -.31046200E-01, -.22491400E-01, 0.28210400E-01, 0.96372800E-03, 0.13344800E+00, -.96547000E-02, 0.34408900E-01, -.68506400E-02, 0.42597000E-01, -.13644700E-01, -.18766900E-01, 0.90081500E-01, 0.22613600E-01, -.35049300E-01, -.18550600E-02, -.20305500E-01, -.61923900E-03, 0.23647100E-03, -.38777600E-03, -.17396200E-01, 0.25539600E-02, 0.10439300E-01, 0.42218900E-02, -.10695200E-01, -.32815300E-02, -.20682200E-02, -.22831100E-02, 0.55921600E-02, -.16867600E-02, -.14466700E-01, -.24244100E-02, -.36467800E-04, -.23046300E-01, -.14400900E+00, 0.63452000E-02, -.12779200E-01, 0.75845000E-03, 0.61541400E-01, -.14785400E-01, 0.74146500E-01, -.12632000E-02, -.12080900E+00, 0.24966500E-03, -.11330600E-01, -.16311800E-03, -.32323900E-02, -.52286700E-03, 0.12650600E-02, 0.34301900E-02, -.15815900E-01, 0.21849600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26882800E+00, 0.22243100E+00, -.21911000E+00, 0.72167100E+00, -.71024200E+00, -.20157900E+00, -.33206200E+00, -.36028800E+00, 0.59078400E+00, 0.32083200E+00, 0.91056700E-01, -.81813900E+00, 0.12491600E+01, 0.76645900E+00, -.19104200E+00, 0.87982400E-01, 0.45137500E+00, -.16947400E+00, -.61646400E-01, -.34704400E+00, 0.19767600E+00, -.19298500E-01, -.20633500E-02, -.14704500E+00, 0.32632500E-01, -.24675800E-01, -.86619600E-01, 0.23220800E-01, 0.33478600E-01, -.95888700E-01, -.10500900E+00, -.35277800E-01, 0.35520900E-01, -.12778500E-01, 0.11570900E+00, -.99673900E-01, -.25754300E-02, 0.36695600E-01, -.72391300E-01, -.15194600E-01, -.24774300E-01, 0.66619800E-01, 0.11206100E+00, 0.20607600E-02, -.26327500E-01, 0.27894400E-01, 0.93602900E-01, -.17258600E-02, 0.44445000E-02, 0.61594600E-01, -.75396700E-01, -.28119200E+00, 0.17810600E-01, 0.29974200E-01, 0.23463900E-02, 0.15898700E-01, 0.22090700E-01, -.15632800E+00, -.83689600E-02, 0.11880100E+00, 0.98808300E-02, 0.34938200E-01, -.44592700E-01, -.96327800E-01, -.29547900E-01, 0.40778700E-01, -.19311700E-01, -.13438600E+00, -.12640500E+00, -.14889400E-01, -.11777800E+00, -.78106500E-01, 0.38767900E-01, 0.69286100E-01, 0.54452700E-01, -.57125100E-01, -.16416500E-01, 0.33397700E-02, 0.58867400E-01, 0.17398500E-01, 0.27129500E-01, 0.93850700E-01, 0.21380800E-01, 0.18346700E+00, 0.23723800E+00, -.11326000E-01, 0.52356600E-01, 0.54614300E-01, -.58632900E-01, 0.37082200E-02, -.67749500E-01, 0.10876900E-01, 0.13141700E+00, 0.24120500E-01, 0.94029200E-02, 0.25020600E-01, 0.32944100E-01, -.32408200E-01, 0.41599300E-02, -.64442000E-01, -.31168800E-02, -.88045900E-03, 0.43668300E-03, -.11473200E+00, -.10066700E+00, -.59540300E-01, -.28571500E-01, 0.41735200E-01, 0.30128500E-01, 0.91951900E-02, 0.48847100E-01, -.38341200E-01, -.60196400E-01, -.27446600E-03, -.26545100E-02, -.17890500E-01, 0.15455900E+00, 0.35302500E-01, 0.29750000E-01, -.21695400E-01, 0.40142600E-01, -.16217800E-01, -.12670400E+00, 0.29871000E-01, -.10524600E-02, 0.70269600E-01, 0.51706700E-01, 0.43152900E-02, 0.14959700E+00, 0.54848400E-01, -.10387400E+00, 0.15371900E-01, -.28839000E-01, 0.35322000E-02, -.39723900E-01, -.50566800E-03, 0.14421800E+00, 0.69786000E-01, -.85396000E-02, 0.25368600E-02, 0.14240000E+00, 0.17709500E-02, -.49912900E-02, -.42368100E-01, -.17423100E-01, 0.72648300E-01, -.16272900E-02, -.49720600E-02, -.38549400E-01, 0.45757100E-01, 0.56305600E-01, 0.35077300E-01, -.61752000E-01, 0.30268300E-02, 0.41213300E-01, 0.10457100E-01, 0.78176400E-02, -.12055700E-02, -.11569400E-03, -.26190700E-01, -.12359400E-01, 0.10840600E-01, 0.73533600E-01, 0.26828800E-01, -.75504900E-02, 0.22951300E-01, -.10357500E+00, 0.47444700E-01, 0.31815500E-02, -.67292600E-02, 0.45825200E-02, 0.59643100E-01, -.40332300E-01, 0.14622100E+00, 0.43336100E-01, 0.27458000E-01, 0.11598100E-01, 0.42946700E-01, -.32718700E-01, 0.36054400E-02, 0.70455100E-01, 0.79353600E-01, -.15946400E-01, -.23842800E-01, -.14420500E-01, -.48302700E-01, 0.57425700E-01, 0.65327300E-01, -.13813100E-01, -.21602200E-01, 0.64344300E-03, -.23984200E-01, 0.18032900E-01, -.64456100E-01, 0.53190200E-01, 0.41258900E-02, 0.13140600E-01, -.41320600E-01, 0.36122600E-01, -.19409300E+00, -.28802300E-01, -.12950500E-02, 0.24243600E-02, 0.70644000E-01, 0.18433300E+00, 0.22196900E-01, -.16230100E-01, -.13604000E-01, 0.88211400E-02, 0.19061100E-01, -.29942500E-01, -.15823400E+00, -.54253800E-03, 0.71458200E-01, 0.61147800E-01, 0.17549100E-01, 0.44667700E-02, -.28586500E-01, 0.20994500E-01, 0.46938900E-02, -.11002300E-01, 0.78939400E-02, 0.28435600E-01, 0.53625400E-03, 0.32190200E-01, -.61718100E-03, 0.13734500E-01, -.52540800E-01, -.97096300E-02, -.48077100E-01, -.75720800E-01, 0.25197600E+00, 0.36208300E-01, 0.29513800E-01, 0.12264700E-02, 0.29175400E-01, -.33407500E-02, 0.57012900E-02, -.25602100E-01, -.23975600E-02, -.10038500E-01, -.28167100E-01, 0.50200700E-01, -.10011500E-01, 0.12987300E-01, -.50123500E-02, 0.21016100E-01, -.15177500E-01, -.23796700E-04, -.99754600E-01, 0.21556200E-01, -.50901400E-02, -.69390000E-01, -.52604100E-02, -.61009300E-02, -.26904000E-01, -.70811000E-02, -.71608500E-01, 0.35424800E-01, 0.53570000E-01, -.32741500E-01, 0.36513900E-01, -.11703800E-01, 0.48852100E-01, -.16088600E-01, 0.28137600E-01, -.10095100E-01, -.15125700E+00, -.40928900E-01, -.10992700E-02, 0.32955400E+00, 0.18948700E-01, -.18541800E-01, 0.14396700E+00, -.11068700E+00, 0.17785700E-01, 0.40828600E-01, 0.46610400E-02, -.23461000E-03, 0.86448100E-02, -.94780700E-01, 0.12423200E-01, 0.10902300E-02, 0.33307100E-02, -.29379500E-01, -.22475800E-02, 0.48874300E-02, 0.98119600E-02, -.43299100E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10768200E+01, -.19625500E+00, -.14270000E+01, -.14445200E+00, -.91445400E+00, -.34222800E-01, -.41027800E+00, -.15050200E+00, 0.14034500E+01, 0.96028400E-01, 0.69244800E-01, -.56357700E+00, -.37145000E+00, 0.17389500E+00, -.73640300E+00, 0.16290700E+00, 0.86316400E-01, 0.20334000E+00, 0.29156400E-01, 0.42769100E+00, -.86654200E+00, -.18647700E-01, 0.38013200E+00, -.38998500E+00, -.12686900E-01, 0.18856300E-03, -.39168300E+00, -.72343500E-01, -.30470400E+00, -.21715900E+00, -.69211900E-01, 0.29117400E+00, -.33013400E-01, -.45983400E+00, 0.55344900E-01, 0.29882200E+00, 0.21202200E-04, -.23556800E+00, -.10502700E+00, -.67638300E-01, 0.24860100E-01, -.78406100E-01, -.74701000E-01, 0.24026300E-02, 0.12803600E+00, 0.22523400E-02, -.12679400E+00, -.40374600E-03, 0.11650700E+00, -.10858700E+00, 0.46421200E-02, -.65492500E-01, -.50983200E-02, -.27580200E+00, -.59580900E-01, 0.14680300E+00, 0.86029400E-01, 0.24339600E+00, 0.13853700E-01, -.14220400E+00, -.19732600E-01, 0.88919000E-01, -.77187900E-01, -.62852700E+00, 0.55474700E+00, -.10865500E+00, 0.70681900E-01, -.36737900E-01, -.89742600E-01, 0.93004300E-01, -.49046400E+00, 0.30957600E+00, -.94004000E-01, 0.12287500E+00, 0.50366500E-01, 0.54824900E-01, -.12710600E-01, -.37117500E-01, 0.39016500E-01, 0.17036500E-02, -.61336500E-01, 0.18365800E+00, -.18361400E+00, -.30667400E+00, -.16556400E+00, 0.20861300E+00, 0.46139200E-01, -.10071500E+00, 0.70288000E-01, -.27779600E+00, -.14093400E-01, -.71149900E-01, 0.10971800E+00, -.22993400E+00, -.12500300E+00, 0.19521200E-01, -.57824100E+00, -.22696100E+00, -.74821000E-01, 0.10316600E+00, 0.58238100E-01, -.23997700E+00, 0.15992900E-02, 0.49608300E-01, -.63019000E-01, 0.45094800E-02, 0.32680400E-01, -.17522600E+00, -.22939000E+00, -.65731500E-01, 0.12343200E-01, -.25154800E-01, -.64659600E-02, 0.13640200E-02, 0.28444000E-01, 0.25391200E-01, -.32824800E-01, 0.44094800E+00, -.30099600E+00, 0.47306900E-01, 0.70556100E-01, 0.47698900E+00, 0.10253300E+01, -.37765400E-01, -.26506400E-02, 0.16753700E+00, -.22442900E+00, 0.13734500E+00, 0.22376300E-01, 0.21224400E+00, 0.25499700E+00, 0.46706200E-01, 0.28361900E+00, 0.91579100E-01, -.15834200E+00, -.40826500E-02, 0.23500400E-01, 0.11564900E+00, -.18865600E+00, -.36481200E-01, -.92620300E-01, -.59108800E-02, 0.21552900E-01, -.87713700E-01, -.13916700E-01, 0.23143700E-01, -.15687400E-02, 0.28703800E-01, -.24500900E+00, -.79276200E-01, -.79721500E-01, -.64411700E-01, -.86482400E-01, 0.51952400E-01, 0.32385300E-02, -.14233300E-02, -.75330900E-01, -.18067600E-01, -.24904100E-01, 0.10151500E+00, 0.11306900E-02, 0.23264900E-01, -.58351500E-01, 0.38695600E-01, -.18355000E-01, -.72470700E-02, -.36052500E-01, -.58914000E-01, -.57603800E-02, -.32116700E-01, 0.25562000E-01, -.69503900E-01, -.44640500E-01, -.14604000E+00, 0.45210900E-03, -.11343500E-01, 0.71838300E-02, -.21403100E-01, 0.13446900E+00, 0.55159200E-03, -.36460700E+00, 0.33166900E-01, 0.25330900E-01, 0.36428900E-01, 0.38953400E-01, 0.38598600E+00, -.57446700E-01, -.24335700E+00, -.49285800E-02, 0.13549500E+00, 0.35949200E-02, 0.32878500E-01, -.15514400E+00, 0.12764800E+00, -.59012600E-01, -.27297300E-01, -.67512900E-01, 0.28289200E-01, -.27056600E-01, 0.25843100E+00, 0.13888400E-02, 0.94669900E-02, -.35117200E-02, -.14540900E+00, -.29302600E-01, 0.21606800E+00, 0.20742800E-01, -.33468400E-02, -.72746400E-01, 0.70543000E-01, -.15438600E-02, 0.64131800E-01, 0.11311100E-03, 0.19200800E+00, 0.14569400E-01, 0.77991200E-02, 0.47074400E-02, 0.18874100E-02, 0.53601200E-01, 0.38886000E-02, 0.47889900E-01, -.16797800E-01, -.30715600E-01, 0.57705500E-04, -.10406400E+00, -.28390500E-02, -.83747400E-01, -.11648800E+00, 0.19652600E-01, -.70489200E-01, 0.21387000E+00, -.14073500E+00, -.25140100E+00, 0.59154400E-01, -.54168500E-02, -.43963900E-01, -.32584400E-01, -.23470500E-01, -.13354600E-01, -.34339900E-01, 0.36014200E-02, 0.30751800E-02, -.28920200E+00, 0.40106100E-01, -.15210700E-01, 0.16539500E-01, -.51876500E-01, -.62603700E-01, 0.67497000E-02, 0.22797300E-01, -.49925400E-02, 0.52268500E-01, 0.48902000E-01, 0.12810100E-01, -.85716900E-02, 0.45794400E-02, 0.33653000E-02, -.21304000E+00, 0.45525200E-02, 0.28713600E-01, -.29067300E-02, 0.54902000E+00, 0.14825000E-01, -.24604900E-01, 0.25017200E-01, -.55815000E-01, 0.34006300E-01, 0.92351400E-01, 0.47923700E-01, 0.13099400E-01, -.21610000E+00, -.50765900E-01, -.26605900E-01, -.46473400E+00, 0.26158300E-01, -.48881200E-01, -.39674300E-01, -.86673400E-01, 0.37657200E-02, -.15770300E-01, -.74058000E-01, 0.38216900E+00, 0.97574500E-03, 0.12552300E-01, -.17406300E-01, -.17498300E+00, 0.88288300E-02, 0.68555500E-01, -.81463400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.41637300E+00, -.58015200E-01, 0.11109000E+01, 0.11287800E+01, 0.11814900E+01, -.33478100E-01, -.11431700E+01, -.22673600E+00, 0.74660500E+00, 0.41247100E+00, -.10009800E+00, 0.84409400E+00, -.13853800E+00, 0.24041900E+00, -.43947000E+00, 0.33896500E+00, -.12626500E+00, -.24277300E+00, -.44662800E+00, -.10787300E+01, 0.58188800E+00, 0.62766900E-01, 0.85555800E-01, -.42668400E+00, -.11826100E-01, -.20268100E-01, -.59555500E+00, 0.12375200E+00, 0.24303500E+00, 0.89111700E+00, 0.21624600E-01, -.25969500E+00, -.14282400E-01, 0.31188300E+00, -.54085500E-01, -.24231600E+00, -.51148000E-02, 0.12036900E+00, -.62238600E-01, 0.15216000E+00, 0.61477500E-01, 0.83156000E-02, -.19057500E+00, -.41502200E-01, -.54701800E-01, 0.10044500E+00, -.13801000E-01, -.11505400E-02, 0.10928400E+00, -.14895100E+00, -.13343100E-01, 0.26233200E+00, -.12189600E-01, 0.54828700E-01, 0.36097400E-01, -.78915300E-02, 0.96098000E-01, 0.31145800E+00, 0.10189900E-02, 0.27090300E-01, 0.38978000E-01, 0.70620300E-01, -.34423000E-01, -.80392900E-01, 0.29074700E+00, -.35881500E-01, 0.66683500E-01, 0.39157700E+00, 0.25750600E-01, 0.44966200E-01, -.20252300E+00, 0.14696300E+00, -.12438000E+00, -.51966100E-01, -.36472900E-01, -.96116500E-02, 0.66438400E-02, 0.20402900E-01, -.63621500E-01, -.34226000E-01, -.39845300E-01, 0.34476000E-02, -.38189800E-01, -.17866800E+00, -.15133600E+00, 0.48445200E-01, -.56222600E-01, 0.45947800E-01, -.52436400E-01, 0.22305400E-01, -.56356600E-01, 0.35696300E-02, -.13506500E+00, 0.48093100E-01, -.50871200E-01, 0.74019800E-01, 0.52145700E-01, 0.24253900E+00, -.15869900E-01, 0.21797400E+00, -.33578700E-01, 0.49915500E-01, 0.13678100E-03, 0.49693300E-01, 0.73404500E-01, 0.14736900E-01, -.69142800E-02, 0.21752100E+00, -.28123300E-01, 0.79699400E-01, 0.40620700E+00, 0.81650100E-01, -.26801900E-01, -.19021900E-03, -.43378700E-02, 0.42915600E-04, 0.12207700E-01, 0.19563600E-02, 0.12898700E+00, 0.64611600E-01, -.83983500E-01, 0.29716100E+00, 0.33849100E+00, -.80323700E-01, -.34347000E-02, 0.70304600E-01, 0.14630300E-01, -.78613700E-01, 0.17710400E+00, -.18766300E-01, -.24034300E+00, 0.38064500E-03, -.45202200E-01, -.83762800E-02, -.10143600E-01, 0.12871400E-02, 0.79619100E-01, 0.51141900E-02, 0.14612200E-01, 0.23115500E-02, 0.24391900E-01, 0.12577700E-01, -.54616000E-02, -.26946500E-01, 0.88073600E-02, -.50172200E-02, -.10595100E-03, 0.93631400E-03, -.18121000E-01, 0.17638600E-02, 0.30189900E-02, 0.53058500E-03, 0.63025500E-03, 0.72263300E-02, 0.93274100E-02, -.28443600E-02, -.97421600E-02, 0.27312900E-02, -.28721800E-01, 0.56855300E-01, 0.14012700E-01, 0.11529300E-01, -.22763600E-01, 0.99173700E-02, -.62260000E-01, 0.19081300E-01, 0.59682600E-02, 0.21607400E-01, -.33354700E-03, 0.10932900E-02, 0.95207200E-02, -.70319300E-01, 0.16531400E-01, -.81979800E-01, -.98150400E-02, 0.39438600E-04, -.40541000E-02, -.11130200E-01, -.33542900E-01, -.24526300E-02, 0.61206300E-01, -.21535500E-01, -.14876800E-01, 0.43346700E-02, -.11299600E-01, -.42713100E-01, -.16284900E-01, 0.50229800E-01, -.24259600E-02, 0.24385700E-01, -.75326500E-03, -.11172600E-01, 0.99319300E-02, -.66179900E-01, 0.11569200E-01, 0.38039100E-02, -.84989400E-02, -.64769300E-01, 0.21712700E-01, 0.86900000E-02, -.17326500E-01, -.16135300E-03, 0.10196000E-02, 0.79075000E-02, 0.11407300E+00, 0.10359700E-01, 0.27514600E-02, 0.47755000E-02, 0.25132200E-02, -.11385300E-02, -.19543000E-02, -.38585600E-01, 0.80597700E-04, 0.43921300E-02, 0.13218100E-02, 0.23384400E-02, 0.42815200E-02, -.60101900E-02, -.12354300E-02, 0.63001100E-03, -.97183500E-03, 0.46468900E-02, 0.87905800E-03, -.92697400E-04, 0.32026700E-04, 0.25229500E-02, -.54059000E-02, -.18303300E-02, -.24276800E-02, -.12761100E-01, 0.87192600E-02, 0.27327100E-03, -.44741900E-03, -.82622300E-02, 0.61456100E-04, 0.79087800E-03, -.22920700E-02, -.20018100E-02, 0.35546100E-02, 0.42800700E-03, -.23100300E-02, -.29587700E-02, -.26357000E-01, 0.38575900E-02, 0.65005400E-02, -.58041500E-03, -.14853900E-02, -.14025400E-01, 0.18830200E-02, 0.11893400E-01, 0.13823000E-02, -.14450600E-01, 0.11713700E-01, 0.91890300E-03, 0.16362900E-02, -.15602100E-03, 0.10925400E-03, -.41511600E-01, 0.32776000E-02, -.20581400E-03, -.38284200E-02, 0.15019200E-01, -.41022100E-03, -.23357200E-02, 0.14908200E-02, -.44530200E-02, 0.17233900E-02, -.17367800E-01, -.19796500E-02, 0.30456500E-02, 0.35942100E-01, -.50253500E-02, -.37716700E-02, -.18076600E-01, -.98631600E-03, 0.15787100E-01, -.16282200E-01, -.19060600E-01, 0.75309200E-02, 0.32213800E-02, 0.11774500E-01, -.16566500E-01, 0.94872900E-01, -.37515000E-02, -.29734300E-02, 0.22643800E-02, 0.29014600E-01, 0.83727900E-02, 0.14521200E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10804200E+01, -.26576800E+00, 0.56221200E+00, 0.17026800E+00, 0.68247200E+00, 0.31436900E-01, 0.18919800E+00, 0.13215500E+00, -.60427900E+00, 0.12368200E-01, -.94904400E-01, 0.11400900E+01, 0.61640800E-03, -.97431500E-01, 0.56642600E+00, -.31271600E+00, -.48054300E+00, -.19704700E+00, 0.13333300E+00, -.55512400E+00, 0.67856800E-01, 0.58458900E-01, -.17144500E+00, 0.81478900E-01, -.17808900E-01, 0.15473300E-01, 0.76461700E-01, 0.40555500E-01, -.16307400E-01, -.51823100E-01, 0.45817100E-01, 0.69475800E-01, -.22344300E-01, 0.13233800E+00, -.79653100E-01, 0.80461700E-01, 0.73012800E-02, -.25755100E+00, 0.46666100E-01, 0.39772400E-02, 0.78962700E-01, 0.14770600E+00, 0.78068000E-01, 0.19317900E-01, -.74844000E-01, -.11128600E+00, -.16259500E+00, 0.26635800E-02, -.40360000E+00, 0.38548800E+00, 0.44019200E+00, 0.28221700E+00, 0.27327400E-01, 0.18780200E-01, 0.33404900E-01, -.90507000E-01, -.19289200E+00, -.56317100E+00, -.37356500E-02, 0.12683900E+00, 0.19714600E-01, 0.18460800E-01, 0.11256700E-01, 0.33318000E+00, -.10829900E+00, 0.20295800E-01, 0.27212500E-01, 0.68762500E-01, -.38793100E-01, -.39849500E-01, 0.57489300E-01, 0.19930500E-01, 0.82482300E-01, 0.10819200E+00, 0.11161600E+00, -.44651100E+00, -.13553000E-01, 0.66517000E-01, -.73508100E-01, 0.44651700E-01, 0.54606300E-01, 0.29134300E-01, 0.21058600E+00, 0.49333800E+00, 0.27719800E+00, -.38415300E+00, 0.63027400E-01, 0.24349800E+00, -.18720100E+00, 0.28380000E+00, -.21304500E+00, 0.29255100E-01, -.26375000E+00, 0.20653700E+00, 0.12696800E+00, 0.12386100E+00, 0.23444700E+00, 0.23192600E+00, -.46115300E-01, -.27735100E+00, -.15703700E-01, 0.14227700E+00, -.45729100E-02, -.19316300E+00, 0.14032600E+00, 0.23359100E-01, -.71298300E-01, -.17149800E+00, 0.26125400E-01, -.80814700E-01, -.15880300E+00, -.10188200E-01, -.36812300E-01, -.12467700E-02, 0.30820100E-01, 0.47299400E-01, -.14645900E+00, -.45845100E+00, 0.23137900E+00, -.58795100E-01, -.64488100E-01, -.81908800E+00, -.11936700E+01, 0.38985300E-01, 0.18185700E-02, -.21866700E+00, 0.35314500E-01, -.17720300E-01, -.16641800E+00, -.48810600E-02, -.12350800E+00, -.19701500E-03, -.11208300E+00, -.11411000E+00, -.24317900E+00, 0.10339800E-01, 0.38508600E+00, -.46921200E-01, 0.60390300E-01, 0.11771600E-01, -.10592700E+00, -.60624100E-01, -.18124600E-01, 0.58088100E-01, -.52033300E-01, 0.73911000E-02, 0.50878600E-02, -.14576100E+00, -.79524800E-03, 0.67662600E-01, -.34377400E-01, -.20795400E-01, 0.38475500E-01, -.45138200E-01, 0.25208200E-01, -.38134500E-01, 0.17663800E+00, 0.26546900E-01, -.43244700E-01, -.80087200E-01, 0.50410900E-01, 0.87722000E-01, 0.22154000E+00, -.15885600E-01, 0.19753300E+00, 0.92131800E-01, 0.31312400E-01, -.28225400E+00, -.12659800E-01, -.45311100E-01, -.13193800E+00, -.47319900E-01, 0.97772000E-01, 0.59740300E-01, 0.12866200E-01, 0.10430200E+00, 0.17634700E-01, 0.13870500E-01, 0.96147400E-01, 0.39830300E-02, 0.10016400E+00, -.12068500E-02, 0.71025200E-02, -.54892700E-01, 0.44123300E-01, -.98790600E-01, 0.82778200E-01, 0.91602700E-01, 0.19362400E-01, -.10546000E+00, -.25157300E-02, -.17453700E-01, 0.10458400E+00, -.34176600E-01, 0.12100800E-01, -.21326600E-01, 0.35144500E+00, 0.13246000E+00, -.18690500E-01, -.13465400E+00, 0.29186700E-01, -.17713000E-02, -.42689800E-01, 0.18386300E+00, 0.81580700E-01, -.27584000E+00, -.53402300E-01, -.27485100E-01, 0.26512700E-01, 0.15206800E-01, 0.42778000E-01, -.15698800E+00, -.10983700E-02, -.92760700E-01, 0.34513200E-01, -.31637800E-02, -.46985100E-01, 0.37997600E-01, -.22660500E-01, 0.13620700E-01, -.72583000E-01, 0.52654100E-02, 0.36648700E-01, 0.99964300E-04, 0.12841100E+00, -.10522800E-01, -.61884300E-01, -.16389600E-01, -.26354000E-02, 0.17890800E+00, -.15834200E-01, 0.25007800E+00, -.12041000E+00, 0.15209300E+00, 0.11160700E-01, -.29982800E-02, -.65437300E-01, 0.55493200E-02, -.39211700E-01, 0.71754600E-01, -.64671500E-01, -.15516000E+00, -.14349600E+00, -.29244000E-01, 0.29466300E-01, -.14986800E-01, -.15867700E-01, 0.26172700E+00, 0.14791900E-01, 0.91377100E-01, -.12642500E+00, -.11183700E+00, 0.66939000E-01, 0.19656900E-01, 0.51565600E-02, 0.47021400E-01, 0.15455600E-01, -.18773500E-01, -.33244300E-01, -.15386900E+00, 0.11997800E-02, -.67078100E-01, 0.48783000E-01, -.71988700E-01, -.50992300E-03, -.30476800E-02, 0.50061600E-02, 0.12228400E+00, 0.10410700E+00, 0.97375100E-01, -.78454400E+00, -.47707000E-01, 0.59864800E-01, -.17402400E-01, 0.16921100E+00, -.23079800E-01, 0.83368700E+00, -.14016300E-01, 0.16123100E-02, 0.18134400E-01, -.57693600E-01, 0.15298600E-01, -.11359200E-01, 0.12681900E+00, -.37258400E-02, 0.66271100E-02, 0.27178700E-01, 0.81398800E-01, -.33699500E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.61314700E+00, 0.30540100E+00, 0.25916600E+00, 0.52362300E+00, -.33006400E+00, -.16094000E+00, -.15909100E+00, -.24004400E+00, -.12169300E+00, 0.29694100E+00, 0.39831900E-01, -.11899300E+00, 0.89821700E+00, 0.70060200E+00, 0.61582100E-01, -.23846700E+00, 0.65488100E-01, -.11853800E+00, 0.91921700E-01, -.28505500E+00, 0.18963800E+00, -.18507900E-01, 0.35055300E-01, -.50982200E-01, 0.38594800E-01, -.33601600E-01, -.13598500E+00, 0.51099100E-01, 0.67654300E-01, 0.11884700E+00, -.86676100E-01, -.74561500E-01, 0.16539400E+00, -.26767800E+00, 0.16912200E+00, 0.16954800E+00, 0.95391600E-02, 0.19561400E+00, -.20135800E+00, 0.29647500E+00, -.36745600E-02, 0.11579500E+00, -.10872700E+00, 0.32866800E-01, 0.60100900E-01, -.35444000E-01, 0.40780600E-02, 0.70715100E-03, 0.16708300E+00, 0.58361600E-01, 0.62470400E-01, 0.35532900E+00, -.56527000E-02, -.50249600E-01, -.38863200E-01, 0.12214500E+00, 0.75076200E-01, -.19734300E+00, 0.27272900E-02, -.10580500E+00, -.18630200E-01, 0.41847900E-01, -.80976300E-01, 0.20466100E+00, -.24926000E-01, -.27035800E-01, 0.44662300E-01, 0.13333900E+00, -.11689300E-01, 0.50776300E-01, 0.93025100E-01, 0.10583500E+00, 0.21377300E+00, 0.14413800E+00, 0.14006500E+00, -.17213700E+00, -.10503600E-01, 0.17015800E+00, 0.32642300E-01, 0.13828300E+00, -.78111900E-02, 0.26153400E+00, -.40330700E-01, -.11206900E+00, 0.45854700E+00, 0.21836800E-01, -.37957100E-01, -.12656000E-01, -.50670000E-01, -.13774200E+00, -.25854100E+00, 0.12101200E-01, -.39771800E-02, 0.17364300E+00, -.12496200E+00, 0.17666300E+00, -.16730800E+00, -.16113500E+00, -.53361200E-01, -.22146700E+00, 0.40626300E-01, 0.55208000E-01, 0.92741500E-04, -.73839000E+00, -.19470000E+00, -.47673900E-01, -.82726100E-01, -.86285800E-01, 0.14674200E+00, -.11821300E+00, -.92518400E-01, -.11279500E-02, 0.47424600E-02, 0.10306800E-04, -.16493600E-01, -.19199000E-01, 0.17012400E+00, 0.26858300E-01, 0.10207000E+00, -.16780200E-01, 0.48869600E-01, -.70105500E-01, 0.32936600E+00, 0.41543100E-01, -.66104600E-02, 0.92310500E-01, 0.13806900E-01, -.67503200E-02, 0.43989400E+00, 0.55324000E-01, -.24939300E+00, 0.72639600E-01, 0.26236800E+00, -.39035400E-01, -.22957300E+00, -.99769300E-02, 0.44736200E-01, 0.28320100E+00, -.18221600E+00, 0.23850900E-01, 0.13877200E+00, -.35873200E-01, -.55388300E-01, 0.35960800E-01, 0.31231800E-01, 0.40004300E-01, 0.41192400E-03, -.37466600E-01, 0.13455800E+00, 0.63914100E-01, 0.10246000E+00, 0.52083700E-01, 0.61078100E-02, 0.17351900E-01, 0.34239800E-01, -.36897400E-02, 0.19980200E+00, 0.88449200E-02, 0.47026700E-01, -.54962400E-01, 0.50855500E-02, -.67220500E-01, 0.26491000E+00, 0.12665300E-02, 0.32614900E-01, 0.86099800E-02, 0.17339200E-01, 0.51178700E-01, 0.22324900E-02, -.27646600E-02, -.25890700E-02, 0.21756800E-01, 0.33668800E-01, 0.11401900E+00, -.35750700E-01, -.96699100E-01, 0.15377200E-01, 0.10930200E-01, 0.18193400E+00, 0.36963600E-02, -.22967000E+00, 0.84702500E-01, -.44966400E-01, -.34554100E-01, -.27362500E-01, -.12566800E+00, 0.15311600E+00, -.37321700E-01, -.13453700E-01, -.78590200E-01, -.16761100E-02, 0.16571400E-01, -.36957800E-01, -.14230700E+00, 0.23079700E-01, 0.13370100E-01, 0.50997700E-01, -.71919500E-01, -.64609900E-01, -.41123700E-01, 0.48278800E-02, -.84713300E-02, 0.24845400E-01, 0.47955000E-01, 0.24263700E-01, -.75500500E-01, -.15558000E-01, 0.34741900E-01, 0.62128300E-02, 0.55644300E-02, -.24282100E-01, -.20246400E+00, 0.77531800E-03, 0.26871400E-01, -.12960900E-03, 0.30999500E-01, 0.17343900E-01, -.52817300E-03, -.20045300E-02, 0.81478600E-04, -.45467200E-01, 0.37403900E-01, -.14385100E-02, -.20788800E-03, 0.30959900E-01, -.29802800E-01, -.36821500E-01, 0.88559800E-03, -.10335200E-01, -.69180900E-01, -.24101700E+00, 0.16581400E+00, 0.26948300E+00, -.66306800E-01, 0.29683800E-02, 0.23057200E-01, 0.79292400E-01, 0.22333300E-01, 0.79982800E-01, 0.20321300E-01, -.19557600E-01, 0.61905800E-01, 0.28400500E+00, -.17254500E-01, 0.15920000E-03, -.34387700E-03, 0.39563500E-01, -.51420800E-01, -.24455100E-01, -.26022500E-02, 0.18961400E+00, 0.17504300E-01, -.15683000E+00, -.14166900E-01, 0.27855400E-02, -.14443300E-01, -.84809400E-02, 0.25421700E+00, -.84069500E-02, 0.71968300E-01, -.32357900E-01, 0.80946100E-01, -.15913100E-01, 0.70290900E-01, -.26978900E-01, 0.48405000E-01, -.17607200E-01, -.16495700E+00, -.61742500E-01, -.36818500E-01, 0.52375400E+00, 0.19088100E-01, -.29593500E-01, 0.68889200E-01, -.15250400E+00, 0.18111600E-01, -.49464900E-01, 0.12532400E-01, -.68965500E-03, 0.17674600E-01, 0.54559700E+00, -.65724200E-01, -.39194400E-01, -.51052000E-01, 0.18884700E+00, -.12882700E-01, -.34410700E-01, -.91787500E-01, 0.58589500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42484700E+01, -.15531900E+01, 0.62748800E+01, 0.93332200E-01, 0.37063400E+01, 0.12585400E+00, 0.24359400E+01, 0.19140900E+01, -.74269100E+01, -.83564200E+00, -.57489900E+00, 0.44845300E+01, 0.10254000E+01, -.88405600E+00, 0.44472500E+01, -.15743700E+01, -.17672600E+01, -.12905400E+01, -.19791800E+00, -.29979600E+01, 0.27121700E+01, 0.19374000E+00, -.14569300E+01, 0.15034100E+01, 0.22592000E+00, 0.12503400E+00, 0.85765300E+00, 0.16080000E+00, 0.13827800E+01, 0.83665300E+00, -.10479300E+01, -.12212600E+01, 0.93653400E+00, 0.70642100E+00, 0.52315000E+00, 0.55858000E+00, 0.67940500E-01, 0.16053700E+01, -.57919600E+00, -.71277400E+00, -.52851500E+00, -.15011600E+00, 0.16182600E+01, 0.21642100E-01, -.32725500E+00, -.10969400E+00, -.93594700E-03, 0.61590300E-02, -.13688400E+01, -.16011400E+00, -.55327600E+00, -.26595200E+01, -.88869200E-01, -.48529400E-01, -.44969700E-01, -.12946300E+01, 0.20468900E+00, 0.76878200E-01, -.29913800E-01, 0.39758900E+00, 0.13154300E+00, -.46381600E+00, 0.89918900E+00, 0.12107900E+01, -.97570100E+00, 0.11877800E+00, -.30486300E+00, -.10769600E+01, -.54148500E-01, -.30935900E+00, 0.63697600E+00, -.90030300E+00, -.16018600E+00, -.32330600E+00, -.27962000E+00, 0.30303200E+00, 0.12328800E-01, 0.19283600E+00, -.29976700E+00, -.57490300E-02, 0.25824400E+00, -.61743700E+00, 0.81895900E+00, 0.14095800E+01, 0.17302500E+01, -.57698300E+00, -.86600900E+00, 0.35276600E+00, 0.37352600E+00, 0.10287200E+01, 0.88948300E+00, 0.48471400E+00, -.65536700E+00, 0.13287300E+01, -.13594700E+00, -.81258600E+00, 0.21584500E+01, 0.10109600E+01, 0.25990300E+00, 0.22140700E+00, 0.76660500E-01, 0.96726400E+00, 0.63232500E-02, 0.22260100E+00, -.75203400E+00, -.38139700E+00, -.89419100E+00, 0.12821400E+01, 0.11190600E+01, 0.17281500E-01, -.35280700E+01, -.65508600E+00, -.41955400E+00, -.69365000E-02, 0.93934400E-01, -.41312200E+00, 0.35219800E+00, -.11633300E+01, 0.12373400E+01, 0.93234500E-01, 0.27399100E-01, -.21179900E+01, -.66386400E+01, 0.31029800E+00, 0.28874600E-01, -.56926300E+00, 0.19368000E+00, 0.10259300E+00, -.11111400E+01, -.91492600E-01, 0.12851700E+01, -.31201300E+00, -.16185900E+01, -.50977700E+00, 0.55558200E+00, -.30685000E-01, 0.69429800E+00, -.62260900E+00, 0.34812400E+00, 0.21807200E+00, 0.59567400E+00, 0.57244500E-01, 0.22567600E+00, 0.37172300E+00, -.15753000E+00, 0.16015200E+00, -.92801100E-02, 0.21023700E-01, 0.59528400E+00, 0.58020300E+00, 0.12745000E+00, 0.25980600E+00, 0.22030700E+00, -.37822800E+00, 0.65149400E+00, 0.43891200E-03, -.33127400E+00, 0.14156800E+00, -.97213800E-01, -.13729100E+01, -.15768400E+00, -.71097400E-01, 0.63567700E-01, -.19810600E+00, -.90384900E+00, -.12448400E+00, -.19474800E+01, -.13705300E+01, -.31644300E-01, -.44742500E+00, 0.41445100E+00, -.12785800E+01, -.17401200E+01, -.17885200E+01, 0.17796100E+00, 0.66593900E+00, 0.77526800E-01, -.20481500E+00, -.29724500E+00, -.31901800E-01, -.70718000E+00, -.55197400E+00, 0.68913800E+00, 0.23876600E+00, 0.12200000E+00, 0.18071100E+01, -.39908500E+00, 0.20443500E+01, -.13098500E+00, -.14183600E+01, 0.13133800E-02, -.34455200E+00, 0.60269700E+00, -.96613700E+00, 0.53482400E+00, 0.34342100E-01, 0.31671900E+00, -.30934700E+00, 0.11465200E+01, -.19224600E+01, -.28002500E+00, 0.96729800E-01, -.33850900E+00, 0.78735400E+00, 0.23000900E+01, -.26292100E+00, -.95084700E-01, -.23106500E+00, 0.24303000E+00, -.70877900E+00, 0.47705300E+00, -.44067400E+00, -.22816700E-01, 0.21434400E+00, -.33245600E+00, -.43253300E+00, -.12313900E+00, 0.13477200E+00, -.17060900E+00, -.45464500E-02, -.31484500E+00, -.29701100E+00, -.52366900E-01, 0.14384800E-01, -.17914600E+00, 0.60860400E+00, -.14810000E+01, 0.39855400E+00, -.49383900E-01, 0.32810000E+01, -.61985300E-01, 0.86341600E+00, -.30823900E+00, -.72899600E+00, 0.37616500E-01, 0.48284200E+00, -.13786700E+00, 0.18425800E+00, 0.19716900E+00, -.10907200E+00, 0.68492100E-01, 0.33424500E+00, -.27191900E+01, -.22885200E-02, 0.42954200E-01, -.47168100E-01, -.54967000E+00, 0.41737800E+01, 0.11805000E+00, 0.49485200E-01, -.14050600E+00, -.48289200E+00, -.58954400E+00, -.19756600E-01, -.14520200E+00, 0.33827700E+00, 0.10924700E+00, 0.78260300E+00, -.12843800E+00, -.11776000E+01, 0.55490300E+00, -.51309800E+01, 0.18188000E+00, -.10924800E+01, 0.98484900E-01, -.75850700E+00, 0.22314000E+00, 0.86926100E+00, 0.13909500E+01, 0.13642200E+00, -.35949100E+00, -.27249600E-02, -.78290600E+00, 0.38219000E+01, 0.81638200E+00, -.22441000E+01, 0.82634600E+00, -.11345700E+01, 0.83278200E-01, 0.39621100E-01, -.23098700E+01, 0.35862600E+00, 0.15159400E+01, 0.17345900E+01, -.19946700E+01, 0.49162700E+00, 0.31975800E+01, 0.46154900E+01, -.19000800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.49251300E+00, 0.31834600E+00, -.52562800E+00, 0.41843100E+00, -.47793800E+00, -.12839800E+00, -.75748300E+00, -.51633700E+00, 0.12833000E+01, 0.53489800E+00, 0.33012100E-01, 0.38199700E+00, 0.50449800E+00, 0.74778300E+00, -.26254100E+00, 0.59913600E-02, -.39324500E-01, -.14093400E+00, -.15190700E-01, -.46633400E+00, 0.26635400E+00, -.17948300E-01, 0.96642100E-01, -.25344300E+00, 0.24342400E-01, -.40316200E-01, -.47749400E+00, 0.11072800E+00, 0.39479900E-04, 0.36188900E+00, -.90736600E-01, 0.33027000E-01, 0.51916500E-01, -.58027300E+00, 0.24006200E+00, 0.23907300E+00, 0.10785400E-01, 0.85816200E-01, 0.31587500E-01, 0.18499600E+00, 0.10622300E+00, 0.94752700E-01, -.43363200E+00, -.11649300E-01, 0.15135500E+00, 0.51280700E-01, -.70950400E-01, 0.22625300E-02, 0.33676300E+00, -.13391800E+00, -.48514400E-01, 0.35243600E+00, -.64916600E-01, -.34546400E+00, -.12749900E+00, 0.11083600E+00, 0.27097000E+00, 0.35685900E+00, 0.55071800E-02, -.38982700E+00, -.35969900E-01, 0.57356200E-01, -.43945800E-01, 0.21091600E+00, -.50500400E-02, -.11694200E+00, 0.72808500E-01, 0.10219400E+00, 0.70397900E-01, 0.14456500E+00, -.45370600E+00, 0.24037400E+00, 0.18837000E+00, 0.26927900E+00, 0.22471000E+00, -.26807600E+00, -.25951500E-01, -.40018200E-02, 0.41892200E-01, 0.15946200E+00, -.54241700E-01, 0.43665100E+00, -.14228000E+00, -.44687800E+00, 0.84224700E-01, 0.14755500E+00, 0.47412900E-01, -.73705500E-01, -.10906900E+00, -.21541100E+00, -.42516300E+00, -.62892800E-01, -.14221100E+00, 0.23385100E-01, -.39518500E-01, 0.50757400E+00, -.47702400E+00, -.14122500E+00, -.75833700E-01, -.10415400E+00, -.70698000E-02, -.11858300E+00, 0.72154000E-03, -.89147100E+00, -.69039200E-03, -.81753200E-01, -.64282700E-01, 0.19042400E+00, -.19832800E-01, -.10898800E-02, -.32078100E-02, 0.34668200E-01, 0.91909400E-02, -.46214300E-03, 0.57489800E-02, -.44502200E-02, -.28264000E+00, -.37654200E-01, 0.15951400E-01, 0.88907700E-01, -.60717500E-01, -.22904300E+00, -.16754400E+00, 0.13804800E+00, -.40756000E-02, -.75927300E-01, 0.10154500E+00, -.30624300E-01, 0.26421400E+00, -.49646000E-01, -.31649800E+00, 0.10491900E-01, 0.26033700E-01, -.49334500E-01, -.55033700E-01, -.10236000E-01, 0.48802400E-01, 0.57720800E-01, -.46484800E-01, 0.58532800E-03, 0.66163400E-01, -.60006900E-01, -.14184900E-01, 0.19680100E-01, 0.15205900E-01, -.72969000E-01, -.17655700E-02, -.98038800E-02, 0.15135400E+00, -.49608300E-02, 0.34205400E-01, 0.32776400E-01, 0.14756200E-01, 0.71063000E-01, 0.90668000E-01, -.21288600E-01, 0.22804600E+00, 0.21849400E-01, -.53224400E-01, 0.86094800E-01, 0.59927200E-01, -.10576600E+00, -.74487200E-02, -.72762700E-01, -.29568600E-01, -.45422300E-02, 0.15073000E+00, 0.81786600E-02, 0.91908500E-02, -.42209100E-02, -.53990400E-01, -.11138100E+00, 0.13769500E+00, -.27009100E-01, -.38659000E-01, -.43804600E-01, -.18952100E-01, -.33602400E-02, 0.84257200E-01, 0.46263200E-02, 0.19376900E+00, -.13022700E-01, -.59889600E-01, -.25769400E-01, -.13644000E-01, -.22489900E+00, 0.71589300E-01, -.38590900E+00, -.21766200E-02, 0.35305800E-01, -.24830700E-02, 0.40960900E-01, 0.74578300E-02, -.20637800E+00, -.16164600E-01, 0.71378400E-02, -.59881200E-02, 0.14133600E+00, -.91409400E-01, -.81005400E-01, -.37062200E-01, 0.15824700E-01, -.13802000E-01, -.52451100E-01, -.66046700E-01, -.95689700E-01, 0.53715300E-02, -.25237400E-02, 0.10977600E-01, 0.26714200E-01, -.30596800E-01, -.14169700E+00, -.28578600E-02, 0.20766700E-01, 0.51639400E-01, 0.61350400E-01, 0.18734600E-01, 0.58445600E-01, 0.41581900E-01, -.26059200E-01, 0.83924900E-02, 0.29776200E-01, -.16777300E-01, -.32082400E-03, 0.57792900E-01, 0.45601000E-02, -.51467300E-01, -.54270500E-01, -.12521200E-01, -.15669500E+00, 0.57434500E-01, -.96593000E-01, -.20579700E+00, 0.17068400E-01, 0.93454500E-02, -.63935100E-01, 0.15812100E-01, -.23003000E-01, 0.19889000E-01, -.71017700E-02, -.25548200E-01, -.10387300E+00, 0.27904600E-01, 0.22156700E-02, 0.27420300E-01, 0.12004500E-02, 0.81179900E-02, -.20102200E-01, -.13312800E-01, 0.23900800E+00, 0.11233900E+00, -.12640300E-01, -.45718400E-01, -.71995200E-02, -.18971200E-01, -.35642300E-01, -.67063700E-02, -.15687700E+00, 0.18911700E-01, 0.13832500E+00, -.69354700E-01, 0.51519300E+00, -.18347500E-01, 0.34272100E-01, -.24460900E-01, 0.38850500E-01, -.68707700E-02, -.46650800E-01, -.58883600E-01, -.59838300E-02, -.16424100E+00, -.70906500E-02, 0.28388100E-01, -.12376000E+00, -.20430100E-01, 0.14899600E+00, 0.54912100E-01, 0.44546000E-01, 0.33599700E-01, 0.74145800E-01, -.32469900E-01, -.42717100E+00, 0.27629500E+00, -.40467300E+00, 0.41835200E-01, -.17964600E-01, 0.56051700E+00, -.63446100E-01, -.37161000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11666200E+01, 0.17387100E+00, 0.84787600E+00, 0.25852900E-01, 0.59645800E+00, 0.31340900E-01, 0.10275700E+00, 0.64677300E-01, -.89862500E+00, -.31916000E-01, -.19284200E-01, 0.46937500E+00, 0.22310200E+00, -.54147300E-01, 0.45201000E+00, -.25380500E+00, -.88903000E-01, -.34346100E-01, -.77881900E-02, -.15293700E+00, 0.56918900E+00, -.14277800E-01, -.25107700E+00, 0.26197600E+00, 0.85975100E-02, -.59887700E-03, 0.24126700E+00, 0.54593800E-01, 0.22328100E+00, 0.25865700E+00, 0.54320100E-01, -.20153300E+00, 0.80865200E-01, 0.23966200E+00, -.31185400E-01, -.51400800E-01, 0.31891700E-02, 0.19035900E+00, 0.25762600E-01, 0.14571600E+00, -.14639300E-01, 0.79020000E-01, -.21778100E-01, 0.53669000E-02, -.91245200E-01, -.25325400E-01, 0.74937300E-01, 0.68577600E-03, -.43741800E-01, 0.12529600E+00, 0.31530900E-01, 0.22407100E+00, 0.58951600E-02, 0.20741900E+00, 0.59630300E-01, -.91147200E-01, -.90202200E-01, -.22938200E+00, -.90976300E-02, 0.66614300E-01, 0.42764800E-02, -.62903600E-01, 0.38303900E-01, 0.54861300E+00, -.46125000E+00, 0.63980200E-01, -.42290300E-01, 0.16804800E-01, 0.59565600E-01, -.57084200E-01, 0.39426000E+00, -.19261200E+00, 0.12178400E+00, -.61003400E-01, -.10705800E-01, -.78255500E-01, 0.76146900E-02, 0.38069500E-01, -.19509200E-01, 0.33046600E-01, 0.43572100E-01, -.82734600E-01, 0.14418200E+00, 0.21160100E+00, 0.20775000E+00, -.15433500E+00, -.35380400E-01, 0.81529000E-01, -.71219200E-01, 0.18637900E+00, -.15368600E-01, 0.51139000E-01, -.66755800E-01, 0.19388400E+00, 0.77874100E-01, 0.39599600E-01, 0.47533700E+00, 0.14016700E+00, 0.44220700E-01, -.11566900E+00, -.46834000E-01, 0.19879100E+00, -.20438400E-02, -.91134300E-01, 0.40682000E-01, 0.12697800E-01, -.45003800E-01, 0.14083700E+00, 0.18921400E+00, 0.24052500E-01, 0.26952400E-01, 0.40744900E-01, 0.23785100E-01, -.10245700E-02, -.18870300E-01, -.74181600E-02, -.52515000E-01, -.36520700E+00, 0.16170000E+00, -.52380100E-01, -.12728000E-01, -.54086000E+00, -.77328400E+00, 0.26406100E-01, 0.98035600E-03, -.13140000E+00, 0.18843200E+00, -.12329900E+00, 0.46840500E-01, -.14653800E+00, -.31826100E+00, -.25763600E-01, -.20508900E+00, -.11979800E+00, 0.57297200E-01, 0.29446900E-02, 0.13442700E-01, -.33118900E-01, 0.13680300E+00, 0.39071300E-01, 0.22612600E-01, -.17201700E-01, -.23005800E-01, 0.87314900E-01, 0.25486900E-02, -.21867500E-01, 0.20314300E-02, -.45578300E-01, 0.24709900E+00, 0.88048600E-01, 0.81187500E-01, 0.65008500E-01, 0.87610100E-01, -.49251200E-01, 0.44160100E-01, -.27613200E-03, 0.10652300E+00, 0.18548400E-01, 0.21163400E-01, -.11375900E+00, 0.44931000E-02, -.12331900E-01, 0.84388600E-01, -.47133000E-01, 0.47068500E-01, -.42262300E-02, 0.12380900E-01, 0.23699100E-01, 0.18774600E-02, 0.21996200E-01, -.40311800E-01, 0.78605900E-01, 0.37384800E-01, 0.19224600E+00, 0.13468300E-01, 0.20261900E-01, -.16249000E-01, 0.34518000E-01, -.12421900E+00, -.35614700E-03, 0.35147700E+00, -.15335700E-01, -.30288700E-01, -.37637300E-01, -.35107100E-01, -.40349400E+00, 0.10406800E+00, 0.23283800E+00, 0.53895300E-02, -.11533500E+00, -.36059200E-02, -.30136500E-01, 0.17092700E+00, -.11390500E+00, 0.56615600E-01, 0.19626800E-01, 0.83278400E-01, 0.24768200E-02, 0.22360600E-01, -.29309000E+00, -.74076300E-02, -.14547600E-01, 0.63389000E-03, 0.19083200E+00, 0.82942500E-01, -.23820100E+00, -.23944500E-01, -.67923900E-02, 0.90942200E-01, -.81370700E-01, 0.47955300E-02, -.92970100E-01, 0.41180100E-03, -.13468900E+00, -.82342100E-02, -.74631700E-02, -.23543800E-01, 0.25105200E-01, -.42322600E-01, -.49249400E-02, -.60018500E-01, 0.18210700E-01, 0.12522800E-01, -.37473300E-03, 0.84817300E-01, 0.24440800E-01, -.24684000E-01, 0.10220000E+00, -.18162800E-01, 0.15365600E+00, -.11191800E+00, 0.11370000E+00, 0.14749900E+00, -.37104100E-01, 0.43502200E-02, 0.35471300E-01, 0.12761500E-01, 0.15130500E-01, 0.12785800E-01, 0.31677900E-01, -.15393800E-01, -.32183300E-01, 0.87686400E-01, -.30251000E-01, 0.30682400E-01, -.14002300E-01, 0.25654200E-01, 0.13974300E+00, -.26973300E-03, 0.25520200E-01, 0.13853900E-01, -.10205800E+00, -.23035200E-01, -.69719300E-02, 0.19161100E-02, 0.16588600E-01, 0.15661000E-02, 0.17673600E+00, -.14461300E-01, -.10257700E+00, 0.56388800E-03, -.49526900E+00, 0.13261900E-01, -.27824600E-01, -.29464300E-02, 0.66114500E-02, -.16313000E-01, -.49112800E-01, 0.14330700E-01, 0.38618500E-02, 0.49788100E-01, 0.25589400E-01, -.14563500E-01, 0.24023700E+00, 0.12113100E-01, -.42949400E-01, 0.13581800E+00, -.88652100E-02, 0.42270800E-02, 0.86535300E-02, 0.67198500E-01, -.52868600E+00, 0.75512500E-01, 0.70108500E-01, -.35616700E-01, 0.26841500E+00, -.13595300E+01, -.12028100E+01, 0.47844500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14731700E+01, -.30944000E+00, 0.17203000E-01, -.12629400E+00, -.19781900E+00, -.65701600E-01, 0.38118600E+00, -.48680900E+00, -.82657800E+00, -.12524600E-01, -.78435500E-01, 0.97473200E+00, -.13590500E+00, -.20608900E+00, 0.55269900E+00, -.92937500E+00, -.38994300E+00, 0.28832000E+00, 0.67930700E-01, 0.19169900E+00, 0.19542200E+00, -.35694700E-01, -.19175800E+00, 0.75504000E+00, 0.44793300E-01, 0.84280600E-01, 0.46088600E+00, -.31204100E-01, 0.21204000E+00, 0.32723400E+00, -.51371000E-01, -.11132800E+00, 0.36900400E+00, -.13243400E+00, -.12267900E+00, 0.46976400E+00, 0.19816300E-01, -.82213300E-01, -.41412900E-01, 0.38190800E+00, -.11116400E+00, 0.68466800E-01, -.62802500E-01, -.22992000E-01, 0.31862800E-01, -.16365900E-01, 0.70790100E-01, 0.30682800E-02, -.14189500E-01, 0.16020400E+00, 0.21032600E+00, 0.75526900E+00, -.18191900E-02, 0.23671500E+00, -.52408300E-02, -.11725400E+00, -.41024300E-01, -.61297600E+00, -.37985300E-02, -.12527500E+00, 0.13794700E-01, 0.31442400E-01, 0.55393500E-01, 0.84516100E+00, -.72642000E+00, -.81591900E-02, 0.50003600E-01, 0.23374900E+00, 0.23649100E+00, -.36593200E-01, 0.45836200E+00, -.32001200E+00, 0.40255700E+00, 0.11564200E+00, 0.16581800E+00, -.38474700E+00, -.14128200E-02, 0.82610500E-01, -.14168100E-01, 0.10908800E+00, 0.48882100E-01, 0.11181600E+00, 0.23675200E+00, 0.37721100E+00, 0.34857900E+00, -.17276700E+00, 0.79105500E-02, 0.90199200E-01, -.16333500E+00, 0.24924700E+00, -.30043900E+00, 0.30457400E-01, -.15410800E+00, 0.32392800E+00, 0.21946200E+00, 0.14279900E+00, 0.15080900E+00, 0.28216900E-01, -.92011900E-01, -.31214000E+00, -.23332100E-01, 0.15018000E+00, -.28057700E-02, -.86247800E+00, 0.97020200E-01, -.69835200E-01, -.30283400E-01, -.15399600E+00, 0.11670600E+00, -.50515400E-01, 0.37535400E+00, 0.68208800E-01, 0.11402100E-01, -.28983300E-03, -.19123500E-01, 0.52588700E-01, 0.62814000E-01, -.35541400E+00, -.36892300E-01, -.19302200E+00, 0.13006500E+00, -.87854300E+00, -.11456500E+01, 0.23498600E+00, 0.16401800E-03, -.21260000E+00, 0.10823100E+00, -.11617500E-01, 0.10237600E+00, -.12447100E+00, -.28787000E+00, 0.10323900E-01, -.12325000E+00, -.19413500E+00, -.11876900E+00, 0.13614700E-03, 0.13372000E+00, 0.30263300E-01, 0.70478900E-01, 0.41566900E-01, -.13254900E+00, -.38346100E-01, -.31922500E-01, 0.84147800E-01, -.20404200E-01, -.86097000E-03, 0.35197400E-02, -.11033300E+00, 0.26634800E+00, 0.16149700E+00, 0.87158100E-01, 0.95768200E-01, 0.11574300E+00, -.51632200E-01, 0.18033300E+00, -.16920600E-01, 0.29797100E+00, 0.22752700E-01, 0.34554000E-01, -.17013300E+00, 0.49012600E-01, -.57448300E-01, 0.25141900E+00, -.55740000E-01, -.11832600E-01, 0.41462100E-01, -.43295000E+00, -.36812300E+00, -.21581600E-01, -.37511600E-01, -.19550100E-02, -.19751900E+00, -.11050200E+00, -.12567800E+00, 0.21115300E-01, 0.11646900E+00, -.11435800E-01, 0.21434700E-01, 0.13991400E+00, -.90857800E-02, 0.31433500E-01, -.20488800E-01, -.13119600E-01, -.73672800E-01, 0.74883700E-01, -.15191700E+00, 0.12202000E+00, 0.19363400E+00, 0.31583000E-01, -.86828900E-01, -.51718300E-02, -.36779700E-01, 0.25306000E+00, -.77145800E-01, 0.20908500E-01, -.38773500E-02, 0.35575700E+00, 0.80704700E-01, 0.17308300E-01, -.19334800E+00, 0.32206100E-01, -.20382800E-01, -.58311200E-01, 0.28843700E+00, -.15504500E-01, -.61067300E+00, -.87472100E-01, -.41087100E-01, 0.10378900E+00, -.99164900E-01, 0.48368800E-01, 0.30606500E+00, 0.32206200E-02, -.15207600E+00, -.20450500E-01, -.30556000E-01, -.43223200E-02, 0.80001000E-01, -.44571100E-01, -.18064700E-01, -.57392300E-01, -.21502000E-01, 0.13524200E-01, -.23666900E-02, 0.12883600E+00, 0.86367200E-01, -.35319200E-01, 0.17735100E+00, -.37528300E-01, 0.41847200E+00, -.39517800E-01, 0.71788500E-01, -.14411900E+00, -.90508400E-02, -.73278000E-02, 0.52386700E-02, -.56006700E-01, 0.24771500E-02, 0.24810400E-01, 0.57408400E-01, -.23732600E-01, -.14715600E+00, 0.60016500E-01, -.11585200E-01, 0.68651700E-01, -.18425600E-01, 0.23304300E-02, 0.68227000E+00, 0.16970100E-02, -.15752300E-01, -.20237200E-01, -.84414000E-02, 0.46996300E-01, 0.10095300E-01, -.15345300E-01, -.24211500E-01, -.55586700E-02, -.31221200E+00, 0.10834800E-01, 0.46711200E-01, -.46236700E-01, 0.28537200E+00, -.78559100E-02, -.31749800E-01, -.28862100E-01, 0.16796400E-01, 0.36439400E-02, -.53574300E-02, -.48921700E-01, -.35248900E-02, -.42017600E-02, 0.17491500E-01, 0.41456900E-01, 0.43657000E-01, -.34505200E-01, 0.59978300E-01, -.24775900E+00, -.69078400E-02, -.35772000E-02, 0.80699000E-01, 0.13466200E+00, -.96850500E-01, -.76826800E-01, -.10105700E+00, 0.49498400E-01, -.18139300E+00, 0.81547700E+00, -.78926300E+00, 0.37506600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
    },
    {
        { 0.19357400E+06, -.95564400E+05, -.68008500E+05, -.95882500E+05, -.33729900E+04, 0.52558000E+04, -.76521200E+04, 0.86947800E+05, -.34251600E+05, -.64206700E+03, -.82441000E+05, 0.85771800E+05, -.41666400E+05, -.16904900E+05, -.42649800E+05, 0.13423900E+05, -.11361900E+04, 0.20167200E+05, 0.94051100E+05, -.27450500E+04, -.88346800E+04, -.61419400E+05, 0.40797000E+04, -.17840500E+04, 0.43843600E+05, -.16686500E+04, 0.25537600E+05, 0.16228900E+05, 0.76058400E+05, 0.19080100E+06, 0.44982800E+05, -.11337700E+04, -.38377800E+05, 0.17579100E+06, -.85333100E+05, -.69227300E+05, -.84857100E+05, -.12085400E+05, -.43939800E+05, 0.17408000E+05, 0.10981500E+06, -.10626400E+05, -.47552500E+05, -.77624300E+05, 0.10334300E+06, -.49660400E+05, -.33047700E+05, -.48706800E+05, -.14113000E+05, -.23777900E+05, 0.45993300E+05, 0.14352000E+06, 0.19316900E+05, -.26053900E+05, -.59788200E+05, 0.56873100E+05, -.28849600E+05, 0.92365300E+04, -.27742300E+05, 0.76196900E+04, 0.27383200E+05, 0.30798000E+05, 0.11220200E+06, 0.41869900E+04, 0.19736600E+05, -.35029200E+05, 0.25101500E+06, -.12319700E+06, -.82200300E+05, -.12267000E+06, 0.48623900E+04, -.81683700E+04, 0.13384600E+05, 0.16207900E+06, -.24991900E+05, -.20569100E+05, -.12723200E+06, 0.13033600E+06, -.63427400E+05, -.29639700E+05, -.62571400E+05, 0.13670900E+04, -.11836500E+05, 0.46165500E+05, 0.16645000E+06, 0.13904200E+05, -.20514200E+05, -.81397500E+05, 0.16134900E+06, -.76932100E+05, -.48578600E+05, -.76571800E+05, -.49182300E+04, -.12137800E+05, 0.76704400E+05, 0.25989600E+06, 0.38991200E+05, -.23453200E+05, -.99253700E+05, -.22915900E+06, 0.11281000E+06, 0.88031800E+05, 0.11287500E+06, 0.92355800E+04, 0.23219400E+05, -.18119900E+05, -.14595100E+06, 0.24387400E+05, 0.27202400E+05, 0.10691600E+06, 0.11344600E+06, -.55738400E+05, -.36973700E+05, -.56544600E+05, -.68248800E+04, -.23762300E+04, 0.14852100E+05, 0.90095600E+05, -.63954300E+04, -.51458000E+04, -.55073200E+05, 0.18115600E+06, -.88219400E+05, -.64072400E+05, -.87287900E+05, -.11051500E+05, -.26185000E+05, 0.44764400E+05, 0.17780600E+06, 0.56333700E+04, -.32427700E+05, -.84970100E+05, -.23282800E+05, 0.11252900E+05, 0.43937500E+04, 0.11174500E+05, 0.16764700E+03, 0.39467200E+04, -.10324300E+05, -.33293200E+05, -.34945900E+04, 0.54602600E+04, 0.14389800E+05, 0.17006600E+06, -.83555900E+05, -.55101000E+05, -.83534800E+05, -.14136500E+05, -.16075000E+05, 0.46920800E+05, 0.18376100E+06, 0.79247100E+04, -.23083500E+05, -.86442100E+05, 0.13771400E+06, -.66502800E+05, -.30438100E+05, -.68226800E+05, -.48815400E+04, 0.14971200E+04, 0.29576000E+05, 0.13642300E+06, -.32944600E+04, -.70418900E+04, -.73207800E+05, 0.60310200E+05, -.28454800E+05, 0.68730800E+04, -.29958500E+05, 0.58364900E+04, 0.12818100E+05, 0.25019300E+05, 0.95713900E+05, 0.61483100E+04, 0.56632000E+04, -.41123300E+05, -.12664100E+06, 0.62788900E+05, 0.23692900E+05, 0.62265300E+05, -.29196400E+05, -.19792400E+05, -.23150700E+05, -.15030600E+06, 0.27014400E+04, 0.18216900E+04, 0.67304800E+05, -.12066100E+06, 0.58947200E+05, 0.45568000E+05, 0.59501600E+05, 0.30092700E+04, 0.15712400E+05, -.37096600E+05, -.14059900E+06, -.84182600E+04, 0.21828700E+05, 0.72547000E+05, -.14655400E+06, 0.71763900E+05, 0.12158700E+05, 0.71111100E+05, -.28300600E+04, -.19555000E+05, -.52821200E+05, -.20152000E+06, -.47851700E+04, -.11087100E+05, 0.85211400E+05, -.25860000E+06, 0.12869200E+06, 0.88634200E+05, 0.12732800E+06, 0.38650500E+04, -.11016200E+05, 0.22182900E+05, -.91324500E+05, 0.59218300E+05, -.20362700E+04, 0.10500100E+06, 0.61410300E+05, -.29294500E+05, -.29183800E+05, -.28580400E+05, -.61588600E+04, -.13683300E+05, 0.17687700E+05, 0.64200900E+05, 0.66787800E+04, -.12622300E+05, -.36187000E+05, 0.21093500E+06, -.10362800E+06, -.69964100E+05, -.10462400E+06, -.14383800E+05, -.67347400E+04, 0.32660500E+05, 0.17713800E+06, -.76615400E+04, -.12661800E+05, -.10300200E+06, 0.16106600E+06, -.75053600E+05, -.64646700E+05, -.75133200E+05, -.16674700E+05, -.45600200E+05, 0.87621700E+05, 0.25676000E+06, 0.45482300E+05, -.46259900E+05, -.10708400E+06, 0.20139200E+06, -.97494800E+05, -.69738000E+05, -.98327300E+05, -.14120500E+05, -.20609900E+05, 0.10735000E+05, 0.10977400E+06, -.24156200E+05, -.21339200E+05, -.92345800E+05, 0.14183200E+06, -.69341100E+05, -.58632800E+05, -.68693700E+05, -.14465800E+05, -.31664600E+05, 0.68646800E+04, 0.67765600E+05, -.18484300E+05, -.32389100E+05, -.57626800E+05, 0.33778400E+05, -.21541500E+05, 0.43936300E+05, -.31439000E+05, 0.62597800E+05, -.13684600E+05, 0.65552900E+05, -.20463900E+05, 0.37570900E+04, -.10362700E+05, 0.21918400E+05, -.26104400E+05, 0.63944300E+05, 0.17875000E+05, -.31623300E+05, 0.73260300E+04, -.24070600E+05, -.11870000E+05, -.14643400E+05, 0.46216200E+05, -.53425300E+05, -.15839600E+05, 0.28315700E+05, 0.10804000E+05, -.16878500E+04, -.85691100E+05 },
        { -.27441600E-01, -.20808400E+04, -.64167300E+05, 0.27195100E+04, -.51840100E+05, -.48240800E+05, 0.35973700E+05, 0.32982700E+05, 0.55235500E+05, -.47338500E+05, 0.46638100E+05, -.88031900E+05, 0.42073000E+05, -.25860000E+05, 0.44723800E+05, -.20644800E+05, -.98200600E+04, 0.16728900E+05, -.11293100E+05, 0.42819300E+05, -.10523900E+05, 0.65663500E+05, -.13820400E+06, 0.67853500E+05, -.12633300E+05, 0.70228400E+05, -.35986500E+05, -.30937500E+05, 0.36778700E+05, -.94074800E+04, 0.57428400E+05, -.25034500E+05, 0.96937300E+05, 0.69580200E+05, -.38275200E+05, -.11384400E+06, -.25493800E+05, -.65586800E+05, -.36214200E+05, 0.19224000E+05, 0.51518200E+05, 0.56645700E+05, -.40653900E+05, 0.35509400E+05, 0.11363400E+04, -.33908600E+04, -.74025500E+05, 0.84959200E+04, -.49726900E+05, -.22072400E+05, 0.20612200E+05, 0.36443300E+05, 0.57376900E+05, -.24963000E+05, 0.55595700E+05, -.78212800E+05, 0.37611500E+05, -.33612100E+05, 0.41245200E+05, -.39092400E+05, -.34303000E+05, 0.30877900E+05, 0.54715500E+04, 0.43057500E+05, -.29938400E+05, 0.67275000E+05, 0.96044900E+05, -.51850900E+05, -.12158200E+06, -.39349100E+05, -.10076400E+06, -.84664900E+05, 0.43208100E+05, 0.58082700E+05, 0.53748400E+05, -.81779700E+05, 0.34410800E+05, 0.81444200E+05, -.43222500E+05, -.11430700E+06, -.32788100E+05, -.91394300E+05, -.79574600E+05, 0.45314800E+05, 0.59895900E+05, 0.52168800E+05, -.75992400E+05, 0.30828700E+05, -.39351600E+04, -.30616100E+04, -.99976600E+05, 0.14512900E+05, -.86580300E+05, -.60209600E+05, 0.44645300E+05, 0.55242900E+05, 0.88652800E+05, -.59048500E+05, 0.93420700E+05, -.14860900E+05, 0.97010200E+04, 0.10666300E+06, 0.22498000E+04, 0.67377300E+05, 0.37424500E+05, -.27346900E+05, -.37599900E+05, -.62330800E+05, 0.42843700E+05, -.66759300E+05, -.21379800E+05, 0.86808100E+04, -.60741800E+05, 0.11208800E+05, -.25464400E+05, -.23320800E+05, 0.20472900E+05, 0.24432300E+05, 0.49170700E+05, -.25952300E+05, 0.49154800E+05, 0.13769100E+06, -.72466800E+05, -.14808800E+06, -.58776700E+05, -.11314700E+06, -.89229600E+05, 0.51882500E+05, 0.84871400E+05, 0.58220500E+05, -.88986500E+05, 0.24718200E+05, -.94032500E+04, 0.52599700E+04, 0.23035500E+05, 0.32743700E+04, 0.16065300E+05, 0.12302000E+05, -.80276000E+04, -.10046800E+05, -.11630100E+05, 0.12171400E+05, -.88960000E+04, 0.10654300E+06, -.55411700E+05, -.14394100E+06, -.48805400E+05, -.79315700E+05, -.69737400E+05, 0.39042900E+05, 0.80444100E+05, 0.68968800E+05, -.72095800E+05, 0.37722400E+05, -.95564100E+04, 0.17906000E+03, -.68641000E+05, 0.66828000E+04, -.67715100E+05, -.61227800E+05, 0.51111800E+05, 0.39853900E+05, 0.60463400E+05, -.60327200E+05, 0.54071700E+05, -.12817700E+06, 0.60585300E+05, -.31394800E+05, 0.64677200E+05, -.23835100E+05, -.21693500E+05, 0.32447700E+05, -.26416300E+04, 0.61775000E+05, -.19814400E+05, 0.82831300E+05, 0.11799100E+06, -.56541400E+05, 0.19999500E+05, -.62211600E+05, 0.36827000E+05, 0.34901400E+05, -.31983000E+05, 0.14257000E+05, -.49670400E+05, 0.27024300E+05, -.88152400E+05, -.38825900E+05, 0.21068800E+05, 0.47224900E+05, 0.16936000E+05, 0.44904700E+05, 0.31224100E+05, -.16356200E+05, -.30544600E+05, -.32697700E+05, 0.31947300E+05, -.28318800E+05, 0.92755500E+05, -.42849500E+05, 0.96570900E+05, -.53039500E+05, 0.77858300E+05, 0.54437200E+05, -.47499300E+05, -.24108600E+05, -.83511800E+05, 0.51195400E+05, -.11269300E+06, -.26268800E+05, 0.15093100E+05, 0.93737600E+05, 0.70763300E+04, 0.70070100E+05, 0.62425400E+05, -.41260900E+05, -.39198500E+05, -.51648300E+05, 0.61021200E+05, -.43305400E+05, 0.29108300E+05, -.15649600E+05, -.29936100E+05, -.80549100E+04, -.27295400E+05, -.15961100E+05, 0.70841900E+04, 0.20159400E+05, 0.17891500E+05, -.17504400E+05, 0.14024900E+05, 0.41052700E+05, -.24023100E+05, -.14250300E+06, -.18051900E+05, -.68282500E+05, -.66084200E+05, 0.44634000E+05, 0.71879800E+05, 0.90086300E+05, -.70007700E+05, 0.67375100E+05, 0.65139300E+05, -.37229800E+05, -.11696400E+06, -.16076200E+05, -.93139200E+05, -.53818600E+05, 0.32196600E+05, 0.70508500E+05, 0.79788300E+05, -.59724900E+05, 0.74683900E+05, 0.80480400E+05, -.43139500E+05, -.12928200E+06, -.33029400E+05, -.84357800E+05, -.67098600E+05, 0.44908400E+05, 0.64636200E+05, 0.61020500E+05, -.69251800E+05, 0.29538500E+05, 0.11063200E+06, -.57460600E+05, -.10497600E+06, -.48499200E+05, -.66596700E+05, -.46995400E+05, 0.24545500E+05, 0.57434500E+05, 0.34131200E+05, -.50327600E+05, 0.32536800E+04, 0.98502200E+04, 0.19593200E+05, 0.55598400E+05, -.33522200E+05, -.38926700E+05, 0.44187300E+05, 0.24349900E+05, -.11434900E+05, 0.51423000E+04, -.29791900E+05, 0.43200200E+05, 0.78942800E+05, -.14110200E+05, -.17547300E+05, 0.68010500E+05, 0.44968100E+05, -.35709700E+05, -.30961300E+05, 0.82897400E+05, 0.27811500E+05, -.15398000E+05, -.38462800E+05, -.72753800E+05, 0.37282100E+05, 0.42569200E+03, 0.25906700E+05 },
        { -.17331600E+01, 0.50446400E+01, 0.51995700E+06, -.12785000E+05, 0.27921200E+06, 0.28264600E+06, -.15732100E+06, -.96546300E+05, -.30182800E+06, 0.27211500E+06, -.26842100E+06, 0.38594100E+06, -.19379000E+06, 0.37067900E+06, -.19630000E+06, 0.13169200E+06, 0.49269400E+05, -.92123600E+04, 0.18822500E+06, -.18817300E+06, 0.47172100E+05, -.37304500E+06, 0.37709200E+06, -.19242200E+06, 0.49143100E+06, -.19381700E+06, 0.22803200E+06, 0.18069500E+06, 0.32890100E+05, 0.38502000E+06, -.11062300E+06, 0.13208900E+06, -.45169900E+06, -.44294200E+06, 0.21937600E+06, 0.87275900E+06, 0.17790900E+06, 0.33810100E+06, 0.13268800E+06, -.19327200E+05, -.17977300E+06, -.28496600E+06, 0.16258700E+06, -.19335100E+06, -.24617700E+06, 0.12279500E+06, 0.72970700E+06, 0.80603000E+05, 0.24325000E+06, 0.83691800E+05, 0.52244600E+05, -.54668000E+04, -.21270100E+06, 0.10925000E+06, -.25989000E+06, 0.28633800E+06, -.14704800E+06, 0.47796300E+06, -.15317500E+06, 0.21109400E+06, 0.21591300E+06, -.46408400E+05, 0.17128000E+06, -.15403800E+06, 0.18764500E+06, -.35042700E+06, -.62276300E+06, 0.30942000E+06, 0.94855000E+06, 0.27072400E+06, 0.55653600E+06, 0.46117400E+06, -.12789700E+06, -.14307100E+06, -.23954200E+06, 0.43331500E+06, -.20618700E+06, -.64944500E+06, 0.32477900E+06, 0.95826100E+06, 0.28753500E+06, 0.49786500E+06, 0.42511100E+06, -.84934100E+05, -.98753400E+05, -.18048700E+06, 0.39935700E+06, -.15578600E+06, -.45995500E+06, 0.22981300E+06, 0.10574700E+07, 0.17114100E+06, 0.46638000E+06, 0.32708000E+06, 0.34609800E+05, 0.49512400E+05, -.27872700E+06, 0.31686800E+06, -.40535300E+06, 0.16803300E+06, -.84381100E+05, -.88206500E+06, -.59669700E+05, -.35953800E+06, -.19380600E+06, 0.46371100E+05, 0.54859100E+05, 0.30981100E+06, -.22211300E+06, 0.37283400E+06, 0.26447800E+05, -.12202200E+05, 0.54617300E+06, -.15683000E+05, 0.14431300E+06, 0.14276800E+06, -.40853500E+05, -.24864200E+05, -.23737600E+06, 0.15660800E+06, -.26930700E+06, -.99954600E+06, 0.49661900E+06, 0.11682300E+07, 0.45258900E+06, 0.59181400E+06, 0.44840200E+06, -.10260100E+06, -.24348300E+06, -.20121500E+06, 0.44879100E+06, -.72605300E+05, 0.90926900E+05, -.45122100E+05, -.19830100E+06, -.38774000E+05, -.86964700E+05, -.62746100E+05, 0.10420200E+05, 0.80458100E+04, 0.43547300E+05, -.61103500E+05, 0.45361300E+05, -.83627400E+06, 0.41069600E+06, 0.11599000E+07, 0.39707800E+06, 0.42676500E+06, 0.37440600E+06, -.34547300E+05, -.19724500E+06, -.26287300E+06, 0.38666500E+06, -.17319300E+06, -.10313900E+06, 0.55457400E+05, 0.70854200E+06, 0.42621700E+05, 0.34313500E+06, 0.33958200E+06, -.14587300E+06, -.25320900E+05, -.25312800E+06, 0.33543000E+06, -.27442500E+06, 0.62502300E+06, -.31107500E+06, 0.45754600E+06, -.31527900E+06, 0.12705400E+06, 0.13271400E+06, -.83892500E+05, 0.17190400E+06, -.29631600E+06, 0.12001300E+06, -.46528000E+06, -.53821000E+06, 0.27508100E+06, -.37873400E+06, 0.28416200E+06, -.23942800E+06, -.20919100E+06, 0.65795500E+05, -.29265800E+06, 0.19582500E+06, -.14006900E+06, 0.47066800E+06, 0.49850400E+06, -.24318900E+06, -.51587000E+06, -.23758200E+06, -.24550000E+06, -.15519500E+06, -.58704500E+05, -.37273400E+04, 0.60029100E+05, -.15763900E+06, 0.91221600E+05, -.33954200E+06, 0.17360100E+06, -.10423800E+07, 0.20099000E+06, -.39927800E+06, -.29619200E+06, 0.52071300E+05, -.19696500E+06, 0.35695900E+06, -.27947700E+06, 0.63140300E+06, 0.35922800E+05, -.15246700E+05, -.69116400E+06, 0.10408900E+05, -.37408800E+06, -.36376200E+06, 0.20723200E+06, 0.12357200E+06, 0.31525000E+06, -.34888700E+06, 0.29079400E+06, -.31352200E+06, 0.15914700E+06, 0.27429900E+06, 0.12630000E+06, 0.14868800E+06, 0.93920400E+05, 0.24042000E+05, -.48047000E+05, -.42685400E+05, 0.10049300E+06, -.37503400E+05, -.41352900E+06, 0.20658100E+06, 0.11694500E+07, 0.19507300E+06, 0.37698800E+06, 0.38212100E+06, -.96513400E+05, -.17320600E+06, -.41674300E+06, 0.40238500E+06, -.36466600E+06, -.93859100E+06, 0.47882100E+06, 0.11318100E+07, 0.39196700E+06, 0.50547300E+06, 0.28840200E+06, 0.10853000E+06, -.76489100E+05, -.20720300E+06, 0.32003000E+06, -.27266100E+06, -.41469000E+06, 0.21232900E+06, 0.95355000E+06, 0.17356100E+06, 0.43273000E+06, 0.35409900E+06, -.17810900E+06, -.23869600E+06, -.34329900E+06, 0.36699800E+06, -.20964000E+06, -.62843200E+06, 0.31031900E+06, 0.73990700E+06, 0.28230500E+06, 0.33678700E+06, 0.20951800E+06, -.80284000E+05, -.25480700E+06, -.17342600E+06, 0.23481500E+06, -.16504000E+05, -.95376300E+05, -.14707300E+06, -.24421400E+06, 0.18215700E+06, 0.32470700E+06, -.26948600E+06, -.71174400E+05, 0.27875700E+05, -.18145700E+05, 0.15779200E+06, -.16333500E+06, -.42968200E+06, 0.17973000E+06, 0.10306300E+06, -.38449600E+06, -.35801800E+06, 0.23515300E+06, 0.22231700E+06, -.47515000E+06, -.13736200E+06, 0.23156800E+05, 0.13106500E+06, 0.39840500E+06, -.14500800E+06, 0.57750500E+05, -.27572100E+06 },
        { 0.37625700E+00, -.14552400E-01, 0.43817000E-01, -.26471500E+04, 0.31774800E+05, 0.14720700E+05, -.23207400E+05, -.27789100E+05, -.17865000E+05, 0.15247600E+05, -.21453000E+05, 0.37185100E+05, -.18651800E+05, -.28478300E+05, -.19281900E+05, 0.12670400E+05, -.18939900E+04, -.14691600E+05, -.14255100E+05, -.14864600E+05, 0.93183500E+02, -.20329100E+05, 0.92808200E+05, -.46954200E+05, -.52978200E+05, -.47495800E+05, 0.20340500E+05, 0.14759700E+04, -.49444000E+05, -.60482000E+05, -.46917300E+05, 0.22485500E+04, -.45345300E+05, -.75824800E+05, 0.37459300E+05, -.10294200E+05, 0.28904900E+05, 0.58125400E+05, 0.29482100E+05, -.15751800E+05, -.40916800E+05, -.40448800E+03, 0.29094300E+05, 0.73207000E+04, 0.52564000E+04, -.26833500E+04, -.45278200E+05, -.11413200E+05, 0.50539100E+05, 0.19843900E+05, -.34939000E+05, -.52632100E+05, -.20788900E+05, 0.18006900E+05, -.16284900E+05, 0.63342800E+03, -.67357800E+03, -.29078000E+05, -.23845200E+04, 0.36835300E+05, 0.11222000E+05, -.28081800E+05, -.47438300E+05, -.10743800E+05, 0.90287400E+04, -.10635400E+05, -.90194600E+05, 0.44807400E+05, 0.12499500E+05, 0.36690400E+05, 0.69131800E+05, 0.36192000E+05, -.29749300E+05, -.59723100E+05, -.16814100E+04, 0.36462800E+05, 0.12312600E+05, -.65981600E+05, 0.32958500E+05, -.79461600E+04, 0.25300100E+05, 0.69629200E+05, 0.43619100E+05, -.44204300E+05, -.73849000E+05, -.11610700E+05, 0.40498700E+05, 0.10193300E+05, 0.43648000E+05, -.21974600E+05, -.50882500E+05, -.33987300E+05, 0.64462800E+05, 0.21311600E+05, -.60583800E+05, -.88422100E+05, -.44852400E+05, 0.20708700E+05, -.46715700E+05, 0.34169300E+05, -.17235400E+05, 0.14785900E+05, -.12050300E+05, -.54774300E+05, -.17223900E+05, 0.22294900E+05, 0.40434600E+05, 0.44802300E+04, -.18779400E+05, 0.14636200E+05, 0.26421800E+05, -.12917900E+05, -.17984500E+05, -.13719200E+05, 0.11777300E+05, -.23246900E+04, -.16742900E+05, -.24533000E+05, -.15885500E+05, -.28020800E+03, -.22349900E+05, -.10803000E+06, 0.53429800E+05, 0.32431000E+04, 0.44259000E+05, 0.90800300E+05, 0.51059000E+05, -.46925300E+05, -.84847800E+05, -.60473700E+04, 0.48903100E+05, 0.13100200E+05, 0.89544600E+04, -.44104200E+04, 0.28594200E+04, -.30939500E+04, -.12551700E+05, -.66222500E+04, 0.82596900E+04, 0.13725800E+05, 0.31012300E+04, -.64564400E+04, 0.11565300E+02, -.80319000E+05, 0.38294200E+05, -.12921400E+05, 0.35799500E+05, 0.59756200E+05, 0.26768300E+05, -.35932200E+05, -.83094700E+05, -.10294600E+05, 0.27210000E+05, 0.99840800E+04, -.23191700E+05, 0.12685600E+05, -.55492500E+05, 0.97440800E+04, 0.61873000E+05, 0.33285200E+05, -.45198600E+05, -.59884100E+05, -.15358800E+05, 0.31013400E+05, -.27058900E+04, 0.72592000E+05, -.35798500E+05, -.40778300E+05, -.36869200E+05, 0.17576100E+05, 0.45056300E+04, -.31183200E+05, -.27043800E+05, -.32042000E+05, 0.40293200E+04, -.35708300E+05, -.24332000E+05, 0.13023900E+05, 0.13284700E+05, 0.15282200E+05, -.17004300E+05, 0.26614400E+04, 0.20030300E+05, 0.34632800E+05, 0.14675100E+05, 0.66943400E+03, 0.25856100E+05, 0.26019200E+05, -.11586400E+05, 0.43046300E+05, -.10593800E+05, -.40308500E+05, -.13365000E+05, 0.22579400E+05, 0.44415600E+05, 0.16904400E+04, -.12911900E+05, -.21521800E+04, 0.44440900E+05, -.21647900E+05, 0.50715300E+05, -.15770400E+05, -.81564400E+05, -.32713200E+05, 0.46118400E+05, 0.85415900E+05, 0.86583100E+04, -.28251200E+05, -.11459000E+04, 0.76625400E+05, -.37963200E+05, -.20639100E+05, -.32448800E+05, -.51899000E+05, -.24716000E+05, 0.17924400E+05, 0.39798300E+05, -.88817100E+03, -.24848400E+05, -.65992800E+04, 0.13758300E+05, -.65906500E+04, -.96194700E+04, -.13177400E+05, 0.18504500E+05, 0.53117300E+04, -.12976100E+05, -.17113500E+05, -.11480700E+05, 0.59278600E+04, -.14585000E+05, -.16115000E+05, 0.79855700E+04, -.15998800E+05, 0.56363700E+04, 0.39458400E+05, 0.12084700E+05, -.35276700E+05, -.67155000E+05, -.24606000E+05, 0.14787600E+05, -.17903600E+05, 0.58115200E+05, -.27768800E+05, -.49650300E+05, -.45048100E+05, 0.65801700E+05, 0.21790500E+05, -.59002500E+05, -.79745900E+05, -.50757900E+05, 0.22976200E+05, -.56567000E+05, -.92465900E+05, 0.46915600E+05, -.37312400E+04, 0.39242000E+05, 0.72520600E+05, 0.43385600E+05, -.31916300E+05, -.54116300E+05, 0.12311900E+03, 0.41460800E+05, 0.16888800E+05, -.11456200E+06, 0.56458400E+05, 0.76080000E+04, 0.50683000E+05, 0.61237800E+05, 0.37254700E+05, -.15098700E+05, -.42214000E+05, 0.99535400E+04, 0.35784200E+05, 0.26997500E+05, -.13720000E+05, -.21997400E+05, -.51914600E+05, 0.26508300E+05, 0.31773800E+04, -.17600200E+05, -.25081300E+05, 0.54949100E+04, -.56526100E+04, 0.21300700E+05, -.38989000E+05, -.68505000E+05, -.17202300E+05, 0.11931900E+05, -.50678900E+05, -.68091200E+04, 0.27993900E+05, 0.14796000E+05, -.45995100E+05, -.11487500E+05, 0.31368100E+04, 0.36929700E+05, 0.63635100E+05, -.33646300E+05, -.87158900E+03, 0.97519000E+04 },
        { 0.51229300E+00, 0.18599600E+00, -.32475400E-01, 0.40633200E+00, -.46205700E+05, -.76292000E+05, 0.37662200E+05, -.43813800E+04, 0.11144700E+05, -.66836100E+05, 0.19189500E+04, -.23556900E+05, 0.11467300E+05, 0.22084800E+05, 0.11776300E+05, -.27434200E+05, -.50204900E+05, 0.14979300E+05, -.26734400E+05, 0.58606900E+03, -.41116100E+05, 0.15226900E+05, -.13310400E+06, 0.65380100E+05, 0.21331700E+05, 0.66572100E+05, -.34026400E+05, -.79459800E+05, 0.24771800E+05, -.72601600E+05, 0.34886500E+05, -.63097100E+05, 0.63578900E+05, 0.13931900E+06, -.69637700E+05, 0.12212600E+05, -.69517600E+05, -.59332400E+05, -.76227200E+05, 0.20897800E+05, 0.27791500E+05, -.31394200E+05, -.67748200E+05, -.62605200E+05, 0.10553000E+06, -.52725900E+05, 0.20921400E+05, -.52636800E+05, -.42921900E+05, -.49033000E+05, -.75709400E+04, -.25675900E+05, -.49732400E+05, -.40766400E+05, -.44716900E+05, -.37879100E+05, 0.16944100E+05, 0.13976100E+05, 0.18987200E+05, -.43652700E+05, -.73742400E+05, 0.16893000E+05, -.44785100E+05, 0.65668500E+04, -.59931600E+05, 0.15276100E+05, 0.34308300E+05, -.17634600E+05, -.10266200E+05, -.17034300E+05, -.89243800E+05, -.12914000E+06, 0.54767400E+05, -.24426900E+04, 0.88517600E+04, -.11333400E+06, -.31925500E+04, 0.99571300E+05, -.49580100E+05, -.28912200E+05, -.49674500E+05, -.85276700E+05, -.10977700E+06, 0.29995800E+05, -.80295500E+04, -.16761400E+05, -.97697600E+05, -.27911300E+05, -.31586900E+05, 0.16178200E+05, 0.36775800E+05, 0.15947900E+05, -.62097300E+05, -.91233500E+05, 0.14878400E+05, -.78965200E+05, -.60202900E+04, -.77821500E+05, 0.22446100E+05, -.11923800E+06, 0.59463300E+05, 0.61887200E+03, 0.59598800E+05, 0.64776300E+05, 0.83783100E+05, -.14259200E+05, 0.11764700E+05, 0.44357700E+05, 0.75594700E+05, 0.50220700E+05, 0.35712200E+05, -.17869800E+05, -.37566200E+04, -.17874100E+05, -.26151500E+05, -.52032600E+05, 0.94406200E+04, -.14538600E+05, -.12374900E+05, -.46231300E+05, -.15256700E+05, 0.17233300E+06, -.86471800E+05, -.32179700E+05, -.86013400E+05, -.10247400E+06, -.13776900E+06, 0.40734200E+05, 0.12940600E+05, -.32764600E+05, -.12353200E+06, -.70509600E+05, -.23046300E+05, 0.11533600E+05, 0.47950400E+04, 0.11502700E+05, 0.15135600E+05, 0.21159000E+05, -.50126600E+04, 0.11691100E+04, 0.51399000E+04, 0.18590900E+05, 0.84447800E+04, 0.16599900E+06, -.83017000E+05, -.28431100E+05, -.83053900E+05, -.77293000E+05, -.12010100E+06, 0.20820100E+05, -.20720700E+04, -.34383200E+05, -.10745000E+06, -.69354100E+05, 0.13325400E+06, -.67218900E+05, -.21967200E+05, -.66620500E+05, -.78667600E+05, -.10418900E+06, 0.24272500E+05, -.90425900E+03, -.30242500E+05, -.90175000E+05, -.47063300E+05, -.22323400E+05, 0.10499000E+05, 0.10887800E+05, 0.11160500E+05, -.29609100E+05, -.53052400E+05, 0.11980600E+05, -.31068000E+05, 0.22213300E+04, -.42490300E+05, 0.16268800E+05, 0.26992200E+06, -.13301100E+06, -.76660000E+05, -.13501500E+06, 0.28409900E+05, 0.83671400E+05, -.60595600E+05, 0.64529700E+05, -.83701300E+05, 0.65739500E+05, -.10918700E+06, -.74660800E+05, 0.37267800E+05, -.13758700E+05, 0.37352100E+05, 0.50074500E+05, 0.72433300E+05, -.89718800E+04, 0.20799500E+05, 0.29910300E+05, 0.62565400E+05, 0.32408300E+05, -.39939600E+05, 0.21161700E+05, -.45677300E+05, 0.19860600E+05, 0.89137300E+05, 0.12916000E+06, -.20563300E+05, 0.57133100E+05, 0.27319600E+05, 0.10682400E+06, 0.15140900E+05, -.35251800E+05, 0.18593100E+05, 0.99413500E+04, 0.17514900E+05, 0.68608400E+05, 0.10838400E+06, -.51921100E+05, -.10333400E+05, -.93236500E+04, 0.94353900E+05, 0.15706500E+05, 0.32064300E+05, -.15051100E+05, -.11713300E+05, -.15937900E+05, -.17174300E+05, -.14855100E+05, -.66226900E+04, -.18321900E+05, -.21020100E+05, -.15404600E+05, -.61956200E+04, 0.11752800E+06, -.58700900E+05, -.26180100E+05, -.58821000E+05, -.66039100E+05, -.11573700E+06, 0.23966300E+05, -.11550600E+05, -.22836300E+05, -.10431100E+06, -.45876300E+05, 0.13213700E+06, -.62579800E+05, -.29050700E+05, -.65852700E+05, -.65104300E+05, -.68693600E+05, -.20025100E+05, -.61229000E+05, -.66286300E+05, -.67046100E+05, -.33783600E+05, 0.20523000E+06, -.10063100E+06, -.33016900E+05, -.10251100E+06, -.86647500E+05, -.10428400E+06, 0.28136900E+05, 0.29150900E+05, -.46037400E+05, -.94798100E+05, -.83366700E+05, 0.19873200E+06, -.99498200E+05, -.28877100E+05, -.99234500E+05, -.67315900E+05, -.82303100E+05, 0.23490100E+05, 0.49066100E+05, -.37097500E+05, -.75177500E+05, -.85946000E+05, 0.25024800E+05, 0.39388300E+05, 0.37640500E+05, -.56225700E+05, -.84427000E+05, 0.87447500E+05, 0.37594500E+05, 0.35721700E+05, -.38595500E+05, -.75938600E+05, 0.58685900E+05, 0.55725300E+05, -.15086400E+05, -.34925100E+05, 0.45196300E+05, 0.46218600E+04, -.34220800E+05, -.68055600E+05, 0.39904600E+05, 0.31615100E+05, 0.32346100E+05, -.86136300E+05, -.49092900E+05, 0.82192500E+05, 0.14702000E+05, 0.62899800E+05 },
        { -.13124200E+00, 0.68921400E+00, 0.35451000E-01, -.28001400E+00, -.11451700E+00, -.15983700E+05, -.40890600E+04, -.10034600E+05, -.87973900E+04, -.95021800E+04, -.96822900E+04, 0.55537100E+05, -.27349500E+05, -.15509000E+05, -.27770900E+05, -.10538500E+05, -.16812600E+05, -.85376900E+04, -.57741100E+04, -.20074100E+05, -.12055200E+05, -.23234000E+05, 0.11922200E+05, -.62870200E+04, -.37709900E+05, -.59352700E+04, -.26392800E+05, -.27012200E+05, -.99602000E+04, -.36570700E+05, -.10455900E+05, -.19872100E+05, 0.85305800E+04, 0.86028700E+05, -.42185200E+05, -.10145900E+05, -.42842200E+05, 0.93306200E+04, 0.45397000E+04, -.24395300E+05, -.73096600E+04, -.43348200E+05, 0.77779500E+04, -.51731600E+05, 0.10505900E+06, -.51895600E+05, -.20833300E+05, -.52374500E+05, 0.61543000E+04, -.64226000E+04, -.23033200E+05, -.24155300E+04, -.40530700E+05, -.37981100E+04, -.57012700E+05, -.18094500E+05, 0.77368800E+04, -.12888700E+05, 0.91060400E+04, -.11105900E+05, -.25961100E+05, 0.15696900E+04, -.20500100E+05, 0.33331300E+04, -.20935500E+05, 0.11972700E+05, -.16279000E+05, 0.84613300E+04, -.42326200E+04, 0.82843000E+04, 0.46566100E+04, -.67351000E+04, -.16043200E+05, -.30879300E+05, -.11068100E+05, 0.64168600E+03, -.84606200E+03, -.17255600E+05, 0.89837900E+04, -.51858500E+04, 0.87623900E+04, 0.78282800E+04, -.38599300E+04, -.18326200E+05, -.33763100E+05, -.11236800E+05, 0.20868600E+04, -.86632100E+03, 0.87575300E+05, -.42589300E+05, -.40690900E+05, -.43604700E+05, -.43551100E+04, -.18626500E+05, -.26538300E+05, -.21701800E+05, -.35009000E+05, -.11954200E+05, -.46932000E+05, -.10468900E+06, 0.51502600E+05, 0.15808600E+05, 0.52324000E+05, -.83703100E+04, 0.88028500E+04, 0.23591700E+05, 0.15895500E+04, 0.42997200E+05, 0.35102700E+04, 0.62380800E+05, 0.66847800E+05, -.33420200E+05, -.11271100E+05, -.33443400E+05, -.27062000E+04, -.14436000E+05, -.10391100E+05, -.34065500E+03, -.24286600E+05, -.11227400E+05, -.37611500E+05, 0.13452500E+05, -.62583400E+04, 0.86956700E+03, -.65402200E+04, 0.18401400E+05, 0.64093900E+04, -.30901800E+05, -.34221900E+05, -.27358300E+05, 0.11052800E+05, -.20392000E+05, -.63868000E+04, 0.30901800E+04, 0.21633400E+04, 0.31686000E+04, -.11499500E+04, 0.73366400E+03, 0.47701500E+04, 0.54535400E+04, 0.54426000E+04, -.47556500E+03, 0.42655500E+04, 0.64203600E+05, -.32155800E+05, -.78820000E+04, -.32169500E+05, 0.10809200E+05, -.12238800E+04, -.29330100E+05, -.23477400E+05, -.41793800E+05, 0.23754500E+04, -.44233300E+05, 0.11460100E+05, -.56304100E+04, -.97458400E+04, -.57221600E+04, 0.74745000E+04, -.85058000E+04, -.17879300E+05, -.22248800E+05, -.18118300E+05, -.33500800E+04, -.12986500E+05, 0.21854500E+05, -.10908500E+05, -.68992400E+04, -.10928200E+05, -.12240200E+05, -.26994600E+05, -.81313100E+03, -.94241000E+04, -.96785600E+04, -.20325400E+05, -.98203200E+04, 0.37779000E+05, -.18114000E+05, 0.26181300E+05, -.18958300E+05, 0.32633900E+05, 0.29671300E+05, -.47040800E+04, 0.30888300E+05, -.13448200E+05, 0.21045600E+05, -.32271900E+05, -.67402600E+05, 0.33301800E+05, 0.30188600E+05, 0.33727700E+05, -.19701600E+04, 0.67012200E+04, 0.18445700E+05, 0.84359000E+04, 0.25405600E+05, 0.40373800E+04, 0.35401300E+05, -.16042300E+05, 0.85427100E+04, 0.83331700E+04, 0.78912300E+04, 0.82010700E+04, 0.36854100E+05, 0.60913700E+04, 0.26408200E+05, 0.12382200E+05, 0.27941500E+05, 0.10393700E+05, 0.19290700E+05, -.90934900E+04, -.59733900E+04, -.97801700E+04, -.39576300E+04, 0.13477300E+05, 0.55501600E+04, 0.15824500E+05, 0.65444100E+04, 0.71444400E+04, 0.13855600E+04, 0.46696900E+05, -.22409200E+05, -.17769200E+05, -.23234300E+05, 0.47520700E+04, -.25772000E+04, -.94430700E+04, 0.22673800E+04, -.14224100E+05, -.99886800E+03, -.28181400E+05, 0.87058700E+05, -.43633700E+05, -.77268600E+04, -.43593200E+05, 0.37452100E+04, -.14716700E+05, -.24134700E+05, -.14244200E+05, -.44136100E+05, -.95536400E+04, -.56520000E+05, 0.16818000E+06, -.80627500E+05, -.54182700E+05, -.83829800E+05, 0.11607700E+05, -.78339200E+04, -.40172800E+05, -.57469100E+04, -.61480100E+05, -.27967300E+04, -.96729600E+05, 0.19468300E+05, -.78937400E+04, 0.10168900E+05, -.96035400E+04, 0.19733500E+05, 0.82881700E+03, -.20150400E+05, -.15471100E+05, -.25426800E+05, 0.64784500E+04, -.27132100E+05, 0.30713100E+05, -.14935600E+05, 0.38449900E+04, -.15195000E+05, 0.18392100E+05, 0.12816800E+05, -.21926800E+05, -.13267100E+05, -.28929500E+05, 0.14167600E+05, -.27186100E+05, 0.26312700E+04, 0.42642400E+04, -.30320200E+04, -.11600100E+05, -.96052500E+04, 0.35574800E+04, 0.29708300E+03, 0.89402800E+04, -.11859600E+05, -.85663400E+04, -.26234900E+04, -.12818700E+05, -.85232800E+04, -.27414700E+04, -.11310500E+05, 0.77125200E+03, -.61207200E+04, -.18978900E+05, -.12892700E+05, 0.98046800E+01, 0.13065400E+05, -.21107700E+04, 0.12915400E+05, 0.31090400E+04, 0.29545800E+04, 0.10462900E+05 },
        { -.45480100E+00, 0.42300800E+00, 0.14443700E+00, 0.16517700E+00, 0.17187300E+00, -.13030500E+01, -.17286100E+05, -.38799000E+05, -.56091100E+05, 0.48727300E+04, -.21238900E+04, 0.13898200E+06, -.68486200E+05, -.45304200E+05, -.69497800E+05, -.22864900E+05, -.63715400E+04, -.32950100E+05, -.20237700E+05, -.69513400E+05, -.45495700E+04, -.46822100E+05, 0.15780500E+06, -.77383100E+05, -.11391500E+06, -.78831700E+05, -.50923300E+05, -.12006900E+05, -.48159500E+05, -.43465000E+05, -.71261700E+05, -.10275000E+05, -.27275600E+05, 0.17109600E+06, -.84344200E+05, -.15990700E+04, -.85049000E+05, -.44139400E+04, 0.33942600E+05, -.61602500E+05, -.47909700E+05, -.14589000E+06, 0.33223100E+05, -.80940200E+05, 0.18767100E+06, -.93078100E+05, -.15110600E+05, -.93384700E+05, -.10872500E+05, 0.10391300E+05, -.52741100E+05, -.35346400E+05, -.12921500E+06, 0.86681700E+04, -.82791000E+05, 0.12312200E+06, -.60463800E+05, -.63628200E+05, -.61392500E+05, -.43155400E+05, -.30551300E+05, -.23617400E+05, -.18859200E+05, -.56038600E+05, -.26663700E+05, -.29380500E+05, 0.65044500E+05, -.31530800E+05, -.24097700E+05, -.32100700E+05, -.16395700E+05, 0.22028400E+05, -.55111700E+05, -.77582400E+05, -.11627700E+06, 0.25549100E+05, -.18000600E+05, 0.70172700E+05, -.34926600E+05, -.17944000E+05, -.34696000E+05, -.16716100E+05, 0.10508300E+05, -.51339600E+05, -.72139000E+05, -.10590700E+06, 0.15669000E+05, -.25961300E+05, 0.17586900E+06, -.87375300E+05, -.53349900E+05, -.87392400E+05, -.21022800E+05, 0.25038100E+05, -.78621400E+05, -.85487100E+05, -.16073100E+06, 0.22022900E+05, -.53900100E+05, -.21957200E+06, 0.10849000E+06, 0.33415300E+05, 0.10971600E+06, 0.12717200E+05, -.73084800E+04, 0.60284900E+05, 0.37946300E+05, 0.15276800E+06, -.10371100E+05, 0.95088500E+05, 0.10078200E+06, -.50369200E+05, -.17037300E+05, -.50450100E+05, 0.43425500E+03, 0.57161200E+04, -.31754200E+05, -.26929800E+05, -.79383700E+05, 0.46561300E+04, -.42796100E+05, 0.14815800E+06, -.72704500E+05, -.19472500E+05, -.73539600E+05, -.10420200E+05, 0.33329600E+05, -.78046600E+05, -.79094200E+05, -.15904500E+06, 0.34312500E+05, -.62766300E+05, -.26573000E+05, 0.13098800E+05, 0.57456700E+04, 0.13214600E+05, 0.34015100E+04, -.32919100E+04, 0.12098000E+05, 0.12891300E+05, 0.24940700E+05, -.40231300E+04, 0.99368800E+04, 0.17674800E+06, -.86811100E+05, -.18508800E+05, -.88564200E+05, 0.38276800E+04, 0.37001200E+05, -.78994200E+05, -.72183400E+05, -.16636300E+06, 0.34007200E+05, -.75624300E+05, 0.11574100E+06, -.58130500E+05, -.89415600E+04, -.57847500E+05, -.18427800E+05, -.53666100E+04, -.42919300E+05, -.39730700E+05, -.96174200E+05, -.26364500E+04, -.49611400E+05, 0.51516900E+05, -.25756000E+05, -.15731700E+05, -.25762000E+05, -.21642400E+05, -.23994300E+05, -.11572600E+05, -.21544600E+05, -.37206200E+05, -.19188600E+05, -.13799000E+05, -.67973900E+05, 0.32430300E+05, 0.87656700E+05, 0.33794400E+05, 0.51877800E+05, 0.11872400E+04, 0.31609000E+05, 0.43788900E+05, 0.40474200E+05, -.78693100E+03, -.15133000E+05, -.17683000E+06, 0.86729300E+05, 0.40036100E+05, 0.88489900E+05, 0.14750800E+05, -.13522400E+05, 0.54397200E+05, 0.38580500E+05, 0.11861000E+06, -.12337500E+05, 0.69160500E+05, -.22416200E+06, 0.11103700E+06, 0.49903200E+05, 0.11169700E+06, 0.61882400E+05, 0.39766500E+05, 0.47175600E+05, 0.40344400E+05, 0.12983400E+06, 0.31884700E+05, 0.78634500E+05, -.68830800E+05, 0.33498800E+05, 0.26503800E+05, 0.34024500E+05, 0.13219800E+05, 0.44736900E+04, 0.28539100E+05, 0.29516200E+05, 0.75183000E+05, 0.60771900E+03, 0.27991900E+05, 0.55138100E+05, -.27676700E+05, -.16171300E+05, -.27237300E+05, 0.15705600E+04, 0.49448400E+04, -.20027600E+05, -.21780100E+05, -.51457200E+05, 0.57834300E+04, -.25848700E+05, 0.15514100E+06, -.77448500E+05, -.13529500E+05, -.77762400E+05, 0.98723200E+04, 0.27496000E+05, -.68788300E+05, -.69416600E+05, -.15755200E+06, 0.24788900E+05, -.69642400E+05, 0.23624800E+06, -.11890200E+06, -.55876100E+05, -.11736600E+06, -.10989800E+04, 0.26160900E+05, -.87809200E+05, -.83247100E+05, -.19903400E+06, 0.26044900E+05, -.10025100E+06, 0.65536300E+05, -.33285500E+05, 0.34502300E+05, -.32400100E+05, 0.28299600E+04, 0.10151900E+05, -.40111200E+05, -.53406200E+05, -.11285900E+06, 0.17343300E+05, -.44736900E+05, 0.13975700E+06, -.68485600E+05, -.26290100E+04, -.69415700E+05, -.38859900E+03, 0.25940800E+05, -.51986800E+05, -.33685800E+05, -.11686300E+06, 0.25677000E+05, -.70507200E+05, 0.28670100E+05, 0.38794200E+05, 0.55417000E+04, -.23660200E+05, -.28086100E+05, 0.91564300E+04, -.57123600E+04, 0.26337200E+05, -.70324300E+04, -.21592000E+05, -.16115600E+05, 0.13028400E+05, -.73204300E+04, -.92980100E+04, 0.11757000E+05, 0.10763900E+05, -.32050900E+05, -.37840100E+05, -.30898100E+04, -.99852700E+04, 0.57875100E+05, 0.10286800E+05, -.14861000E+05, -.30207600E+04, -.18865300E+05, 0.31291300E+05 },
        { 0.10112700E+00, -.33116500E+00, 0.21773200E-02, -.46115700E-01, -.27448700E+00, 0.18849000E+00, -.32502200E+00, -.14236100E+05, -.86122900E+04, -.18414000E+04, -.57265000E+03, -.16216200E+05, 0.79787500E+04, 0.18041800E+04, 0.81064400E+04, 0.23706700E+04, 0.96288800E+03, -.77771400E+03, -.13721900E+05, -.24031300E+04, 0.54101400E+03, 0.64322600E+04, 0.33742900E+05, -.16634400E+05, -.11779000E+05, -.16857200E+05, 0.13986700E+05, 0.35887700E+04, -.20135100E+05, -.27662500E+05, -.20656400E+05, 0.27821500E+04, -.22312800E+05, -.23531400E+05, 0.11468200E+05, 0.92389900E+04, 0.11885200E+05, -.64646100E+04, -.62890400E+04, 0.61987400E+04, -.14190700E+05, -.35244700E+04, -.63514500E+04, 0.88218700E+04, -.15892000E+05, 0.77078500E+04, 0.46041600E+04, 0.80549800E+04, -.65257700E+03, 0.12695400E+04, -.92214100E+04, -.37054000E+05, -.16018700E+05, 0.77741300E+03, 0.63876300E+04, 0.38631100E+05, -.18741900E+05, -.10499400E+05, -.19275900E+05, 0.48658900E+04, 0.16123300E+04, -.15479400E+05, -.19034100E+05, -.19997600E+05, 0.12759700E+04, -.23822300E+05, 0.43021600E+04, -.23021400E+04, 0.42142800E+04, -.20487800E+04, -.64348800E+04, -.83401300E+04, 0.50502500E+04, -.14801900E+05, -.13248500E+05, -.94341300E+04, -.28697200E+04, 0.35698200E+05, -.18005400E+05, -.78890100E+04, -.17755600E+05, -.76943400E+04, -.75020800E+04, -.46282500E+04, -.18107400E+05, -.22147500E+05, -.90178400E+04, -.14315500E+05, -.30481400E+05, 0.14651400E+05, 0.13589800E+05, 0.15377900E+05, 0.71666400E+04, 0.43189100E+04, -.15608500E+05, -.62461200E+05, -.23969500E+05, 0.23437600E+04, 0.10073500E+05, 0.36020500E+05, -.17802100E+05, -.84586800E+04, -.18033800E+05, 0.68754600E+04, 0.60991400E+04, -.45268600E+04, 0.28551600E+05, 0.65830100E+04, 0.69035400E+04, -.15689900E+05, -.27301400E+05, 0.13672600E+05, 0.20573500E+04, 0.13636600E+05, 0.84304900E+03, -.14143400E+03, -.72116700E+03, -.21601400E+05, -.29207900E+04, -.58446300E+03, 0.13131700E+05, 0.32935200E+05, -.16592200E+05, -.12033500E+05, -.16337900E+05, -.13250200E+05, -.16005800E+05, 0.76305000E+03, -.20013700E+05, -.23341900E+05, -.16246300E+05, -.16847500E+05, -.39542000E+04, 0.20113300E+04, 0.16935500E+04, 0.19598500E+04, 0.11915400E+04, 0.16578600E+04, 0.70400100E+03, 0.43057400E+04, 0.35171600E+04, 0.18329000E+04, 0.18625200E+04, -.47789800E+04, 0.27015800E+04, -.53678400E+04, 0.23484400E+04, -.77089800E+04, -.13217600E+05, 0.47012700E+03, -.29086700E+05, -.11486300E+05, -.12629200E+05, 0.28543600E+04, 0.50746200E+05, -.25629900E+05, -.17428300E+05, -.25367300E+05, -.80480900E+04, -.90419400E+04, -.75708800E+04, -.17153800E+05, -.23927200E+05, -.94662300E+04, -.21230800E+05, 0.17573500E+05, -.89551100E+04, -.12560800E+05, -.87880000E+04, 0.65818300E+04, 0.72620700E+04, -.13791600E+05, -.20092900E+05, -.14295100E+05, 0.52682100E+04, -.78273100E+04, 0.15565400E+05, -.80755600E+04, -.14180000E+05, -.78246600E+04, -.14868000E+05, -.34749400E+04, 0.46378600E+04, 0.19082100E+05, 0.46845800E+04, -.27755400E+04, 0.51434700E+04, 0.11458700E+05, -.58062700E+04, -.11568300E+05, -.57131400E+04, 0.40376500E+04, 0.47989000E+04, 0.22591800E+04, 0.25827400E+05, 0.13076700E+05, 0.44781300E+04, -.47486400E+04, -.39677800E+05, 0.19608900E+05, 0.90803200E+04, 0.19741600E+05, -.14566300E+04, -.19245300E+04, 0.21172300E+05, 0.37750400E+05, 0.32133700E+05, -.71239100E+03, 0.23674300E+05, -.12953500E+05, 0.61758200E+04, 0.42296400E+04, 0.63826500E+04, 0.57959400E+04, 0.84685300E+04, -.58197900E+04, 0.54598100E+04, 0.69872700E+04, 0.89618600E+04, 0.84439700E+04, -.18233300E+05, 0.87611700E+04, 0.67253200E+04, 0.91968800E+04, -.13854700E+04, 0.15212000E+04, -.24285200E+04, -.19195300E+05, -.75470200E+04, 0.41662400E+03, 0.10948900E+05, -.29964300E+05, 0.15102400E+05, -.34952200E+04, 0.14935400E+05, -.33036200E+04, -.73453800E+04, 0.10040000E+04, -.34260500E+05, -.67215300E+04, -.76633400E+04, 0.15904400E+05, -.46006900E+05, 0.21539700E+05, 0.12856900E+05, 0.23187800E+05, -.19298500E+04, 0.24692200E+04, -.11926400E+05, -.65581600E+05, -.24598300E+05, -.53132700E+03, 0.26337800E+05, 0.19758600E+05, -.10670500E+05, -.74289500E+04, -.97974800E+04, -.14814300E+05, -.11199100E+05, 0.42221800E+04, -.12232800E+05, -.14815600E+05, -.12542000E+05, -.52018200E+04, 0.19597000E+05, -.98371600E+04, -.68183900E+04, -.96907100E+04, -.13987000E+05, -.14731300E+05, 0.80479300E+04, 0.13297400E+04, -.68969600E+04, -.13883100E+05, -.88670000E+04, 0.69419500E+04, 0.90292100E+04, -.68618100E+04, 0.12355700E+04, -.21088800E+05, 0.15323500E+05, -.21043900E+04, 0.10759700E+05, -.40209200E+04, -.87609200E+04, -.54136200E+03, 0.45804800E+04, -.56656700E+04, -.47361000E+04, 0.63992100E+04, 0.43448700E+03, -.63721500E+03, -.38789600E+04, 0.35388600E+04, 0.65499500E+03, 0.12702600E+05, -.47046500E+04, -.51652200E+04, 0.56601700E+04, -.43565700E+04, 0.20276100E+05 },
        { 0.79265400E+00, -.14833200E+01, -.15475900E+00, -.58586300E+00, -.41224400E+00, -.42859700E+00, 0.23372100E+01, -.26495600E+01, 0.89126700E+05, -.14720400E+05, 0.25907200E+05, -.26088600E+06, 0.12770300E+06, 0.63040500E+05, 0.13045200E+06, 0.35107400E+05, 0.16855100E+05, 0.21362500E+05, -.54902100E+05, 0.10115300E+06, 0.13344700E+05, 0.11727100E+06, -.48613600E+05, 0.22546500E+05, 0.10821900E+06, 0.24207300E+05, 0.12005700E+06, 0.42896400E+05, -.68320100E+05, -.13617000E+06, -.96901200E+04, 0.39982000E+05, -.34527200E+05, -.29846600E+06, 0.14521300E+06, -.34930300E+05, 0.14859900E+06, -.23804200E+05, -.71777900E+05, 0.88311600E+05, 0.29920000E+05, 0.26039100E+06, -.74317200E+05, 0.17985700E+06, -.26404300E+06, 0.12921600E+06, -.44599500E+05, 0.13145200E+06, 0.85684700E+04, -.17783400E+05, 0.64687800E+04, -.10058500E+06, 0.16284600E+06, -.19284500E+05, 0.16632800E+06, -.43812700E+05, 0.22944400E+05, 0.43713500E+05, 0.21689800E+05, 0.93253200E+05, 0.59559000E+05, -.58435500E+05, -.97561900E+05, 0.83653000E+04, 0.49421400E+05, -.18952500E+05, -.64242400E+05, 0.29448100E+05, 0.21151300E+05, 0.31590500E+05, -.50446400E+03, -.55434700E+05, 0.48244900E+05, 0.35083600E+05, 0.17339600E+06, -.65244200E+05, 0.63118100E+05, 0.76234100E+05, -.39255900E+05, -.53534900E+05, -.38613200E+05, 0.47624700E+04, -.24235400E+05, -.10862600E+05, -.29568600E+04, 0.98949700E+05, -.40731100E+05, 0.19773300E+05, -.17874500E+06, 0.85282900E+05, 0.17148600E+05, 0.88711200E+05, 0.32405100E+05, -.44786900E+05, -.13955800E+05, -.14245400E+06, 0.15864100E+06, -.46498100E+05, 0.10882000E+06, 0.44100700E+06, -.21658200E+06, -.36017600E+05, -.22043900E+06, 0.11217000E+05, 0.32293700E+05, -.68013400E+05, 0.62070200E+05, -.25809400E+06, 0.43364800E+05, -.24355500E+06, -.17146100E+06, 0.85713300E+05, -.98778900E+04, 0.85806600E+05, -.11815200E+05, -.23453100E+05, 0.19481100E+05, -.38435500E+05, 0.12306400E+06, -.25079700E+05, 0.10883300E+06, -.79222500E+05, 0.36196700E+05, -.64487200E+05, 0.38927900E+05, -.16031000E+05, -.82007500E+05, 0.41636900E+05, 0.61394600E+04, 0.20067700E+06, -.89747800E+05, 0.78187700E+05, 0.15712000E+05, -.72942000E+04, 0.78336700E+04, -.77647400E+04, -.19160500E+04, 0.72455800E+04, -.20436600E+04, 0.53776300E+04, -.28862000E+05, 0.96347800E+04, -.14036600E+05, -.18386000E+06, 0.89814000E+05, -.82868600E+05, 0.92188900E+05, -.43583700E+05, -.11049800E+06, 0.55802200E+05, -.20358400E+05, 0.24608700E+06, -.10737800E+06, 0.14898600E+06, -.36690900E+05, 0.17834700E+05, -.77274900E+05, 0.18317200E+05, 0.24142600E+05, 0.20718500E+04, -.21033000E+05, -.58813800E+05, 0.91982200E+05, -.83417300E+04, 0.55040200E+05, 0.23002800E+05, -.12151500E+05, -.39439600E+05, -.11498100E+05, 0.54739600E+05, 0.62882200E+05, -.63266100E+05, -.75430000E+05, -.31896900E+04, 0.47710600E+05, -.25322600E+04, 0.11998900E+06, -.58772700E+05, -.19380500E+06, -.59734900E+05, -.12171700E+06, -.19511900E+05, 0.71860700E+04, 0.69078000E+05, -.22854300E+05, -.20542600E+05, 0.43997000E+05, 0.26738100E+06, -.13033100E+06, -.35556000E+05, -.13379200E+06, -.28038600E+04, 0.40675800E+05, -.35177100E+05, 0.64547900E+05, -.16108500E+06, 0.38989900E+05, -.14947000E+06, 0.18087100E+06, -.89723700E+05, 0.22770300E+05, -.89966900E+05, -.11510200E+06, -.76775400E+05, 0.68045100E+05, 0.15201100E+06, -.99718700E+05, -.54645100E+05, -.86808000E+05, 0.13125600E+06, -.65384500E+05, -.49730300E+05, -.65133200E+05, -.14631900E+05, 0.70690600E+04, -.33039600E+05, -.11980500E+04, -.13787100E+06, 0.17458500E+05, -.69042800E+05, -.82743500E+05, 0.39534400E+05, 0.14054800E+05, 0.40953000E+05, -.19067300E+05, -.11988400E+05, 0.42434200E+04, -.31980900E+05, 0.59203700E+05, -.18333200E+05, 0.75775000E+05, -.20294100E+06, 0.10159200E+06, -.78779700E+05, 0.10171400E+06, -.49214500E+05, -.88994900E+05, 0.48826800E+05, -.25357500E+05, 0.24651600E+06, -.89480300E+05, 0.16890900E+06, -.28027500E+06, 0.13354500E+06, -.89118500E+04, 0.13918400E+06, -.43176900E+05, -.57457800E+05, 0.99005400E+04, -.12827800E+06, 0.22587500E+06, -.71982100E+05, 0.23884000E+06, -.58315500E+05, 0.25806600E+05, -.11103200E+06, 0.28666900E+05, -.37453100E+05, -.32732200E+05, 0.26726500E+05, 0.22517200E+05, 0.17939300E+06, -.54509800E+05, 0.10661700E+06, -.17646300E+06, 0.85104900E+05, -.47980600E+05, 0.87632600E+05, -.33985200E+05, -.68735800E+05, 0.75616500E+05, 0.50903400E+05, 0.20429900E+06, -.71762400E+05, 0.12151300E+06, -.11675400E+05, -.16235400E+05, -.52261900E+05, 0.43663300E+05, -.42364100E+05, 0.33470800E+05, -.20540700E+05, 0.91081400E+03, -.66374600E+02, 0.19057500E+05, 0.24671300E+03, -.57503600E+04, -.37016800E+05, 0.14038300E+03, -.10072900E+04, 0.15044600E+04, 0.48193200E+05, 0.37124000E+05, 0.19742400E+05, 0.39545600E+04, -.40013200E+05, -.51716900E+04, 0.10873500E+05, -.15700400E+03, -.44601300E+04, 0.38441900E+05 },
        { -.78115000E+00, -.39404900E+00, -.59276300E-01, -.47901300E+00, -.71650900E+00, -.61003600E+00, -.19634900E+00, -.37976700E+00, -.23197400E+00, -.88801300E+04, 0.52360300E+04, -.36505700E+05, 0.17979700E+05, 0.71482400E+04, 0.18247200E+05, 0.59711500E+04, -.39388100E+04, 0.11661200E+05, 0.81820300E+04, 0.13832000E+05, -.11693300E+05, 0.13115800E+05, -.25667000E+05, 0.12421700E+05, 0.18417700E+05, 0.12888600E+05, 0.17232200E+05, -.50089100E+04, 0.12693800E+05, 0.17988700E+05, 0.17869600E+05, -.17333900E+05, -.20294000E+04, -.40565500E+05, 0.19958000E+05, -.16718400E+05, 0.20683900E+05, 0.84859500E+02, -.16437800E+05, 0.16058800E+05, 0.12972600E+05, 0.23849100E+05, -.28510800E+05, 0.27068200E+05, -.57351200E+05, 0.28477200E+05, -.62815700E+04, 0.29038800E+05, 0.74649400E+04, 0.44086100E+04, 0.41787700E+04, -.12901900E+05, 0.11046500E+05, -.68045100E+04, 0.30135000E+05, -.21995100E+05, 0.10606800E+05, 0.21313200E+04, 0.11132700E+05, 0.12877200E+05, 0.74145800E+04, 0.12426800E+04, -.75307600E+03, 0.98197500E+04, -.66844300E+03, 0.42052500E+04, -.26996000E+05, 0.13158300E+05, 0.65641800E+04, 0.13837700E+05, 0.24919300E+04, -.11760000E+05, 0.15013500E+05, 0.16106900E+05, 0.17557700E+05, -.27363100E+05, 0.18142800E+05, -.25152400E+05, 0.12529800E+05, -.32284900E+04, 0.12890000E+05, 0.41825900E+04, -.81232000E+04, 0.12203900E+05, 0.14317600E+05, 0.18217500E+05, -.22884500E+05, 0.15695700E+05, -.10689800E+06, 0.53192300E+05, 0.24682000E+05, 0.53889300E+05, 0.10984400E+05, 0.84234500E+03, 0.16778300E+05, -.15680500E+05, 0.24250300E+05, -.19137400E+05, 0.47596900E+05, 0.70530400E+05, -.35054200E+05, 0.15852700E+04, -.35325800E+05, 0.64474200E+03, 0.92629300E+04, -.16037000E+05, 0.23133400E+04, -.20945100E+05, 0.23479200E+05, -.40371700E+05, -.17822500E+05, 0.89233800E+04, -.57716700E+04, 0.88640500E+04, -.42710000E+04, -.52189400E+04, 0.51582400E+04, -.10533500E+03, 0.60005800E+04, -.12824400E+05, 0.14840300E+05, -.33785200E+05, 0.16527200E+05, -.13093700E+05, 0.17326500E+05, 0.47104700E+02, -.17065200E+05, 0.15044800E+05, 0.11802700E+05, 0.21495300E+05, -.32485100E+05, 0.23321100E+05, 0.67004000E+04, -.33011900E+04, 0.82017900E+03, -.34080200E+04, -.88257500E+03, 0.22855700E+04, -.28281400E+04, -.25910000E+04, -.39368100E+04, 0.49439900E+04, -.36235100E+04, -.31443600E+05, 0.15376400E+05, -.19030900E+05, 0.15571800E+05, -.43489000E+04, -.18489600E+05, 0.15476800E+05, 0.12449700E+05, 0.23113800E+05, -.33169000E+05, 0.23778200E+05, 0.33291800E+05, -.16767000E+05, -.44790200E+05, -.16627100E+05, 0.21048700E+04, -.48960800E+03, -.62343500E+04, 0.10570600E+05, -.10884100E+03, -.13395300E+05, -.26731700E+04, 0.11576400E+05, -.59835700E+04, -.11545800E+05, -.57913100E+04, 0.57769200E+04, 0.71978200E+04, -.49777300E+04, 0.18863800E+04, -.30919400E+04, -.85038700E+03, -.31172900E+04, 0.71974300E+05, -.35380400E+05, -.42455300E+05, -.36139300E+05, -.17513500E+05, 0.10541800E+05, -.24140500E+05, -.14161500E+05, -.29065700E+05, 0.22599200E+05, -.17094800E+05, 0.51730800E+05, -.25521200E+05, -.18242300E+04, -.25806400E+05, -.52402800E+04, 0.80718700E+04, -.13408800E+05, -.26597600E+04, -.16689200E+05, 0.19142100E+05, -.24358500E+05, 0.76957900E+05, -.38107900E+05, -.44599700E+04, -.38791200E+05, -.20483200E+05, -.11760200E+05, -.68041500E+04, 0.11192100E+05, -.22063200E+05, 0.30351600E+04, -.33369000E+05, -.16070300E+05, 0.82845600E+04, 0.11720700E+05, 0.77205800E+04, 0.83324800E+03, 0.39423600E+04, 0.46741100E+03, -.87209300E+04, -.24380800E+04, 0.14959800E+05, -.81130700E+03, -.39303100E+05, 0.19768800E+05, 0.10470900E+05, 0.19918800E+05, -.13385700E+04, 0.35398200E+02, 0.53195800E+04, -.96736700E+04, 0.24571100E+04, -.53302300E+04, 0.22358700E+05, -.24693100E+05, 0.12330500E+05, -.18547000E+05, 0.12192200E+05, -.96811300E+04, -.15104700E+05, 0.12023700E+05, 0.71735800E+04, 0.16378000E+05, -.29889700E+05, 0.25012400E+05, -.11229400E+06, 0.56541200E+05, 0.16653700E+05, 0.56758100E+05, -.20043300E+04, -.68224900E+04, 0.20018300E+05, -.16724800E+05, 0.19778700E+05, -.27383900E+05, 0.62645400E+05, -.22178300E+05, 0.11333300E+05, -.20379300E+05, 0.11381100E+05, -.24307900E+04, -.54641900E+04, 0.58033000E+04, 0.13664100E+04, 0.12615300E+05, -.16347700E+05, 0.22176500E+05, 0.51399300E+04, -.28785300E+04, -.32282600E+05, -.21998200E+04, -.54944900E+04, -.17065600E+05, 0.79391500E+04, 0.17154000E+05, 0.14679200E+05, -.25587200E+05, 0.84565800E+04, -.77364900E+04, -.54785300E+04, -.67101800E+04, 0.79353400E+04, -.11740800E+05, 0.25104200E+05, 0.87415100E+04, -.68569600E+03, 0.46648600E+04, -.12088600E+05, 0.61291600E+03, -.14757600E+05, 0.32268500E+04, 0.63027900E+03, -.51630200E+04, -.97323500E+04, 0.13425600E+05, 0.67985800E+04, 0.21127400E+04, 0.15883100E+05, -.81735900E+04, -.31509800E+04, 0.12785600E+05, 0.36439700E+04, 0.44579100E+04, 0.55332200E+04 },
        { -.68672800E+01, 0.42343500E+01, 0.60378900E+00, 0.10396500E+01, -.26837200E+01, -.32503900E+01, -.35396200E+01, -.22628700E+01, -.31141300E+01, 0.49382000E+01, 0.17951900E+06, -.38422600E+06, 0.19138600E+06, 0.11811500E+06, 0.19209500E+06, 0.47456800E+05, -.54348400E+05, 0.99477200E+05, 0.16359900E+05, 0.12040800E+06, -.37660200E+05, 0.22170400E+06, -.43019300E+06, 0.21024300E+06, 0.19163800E+06, 0.21524300E+06, 0.14805900E+06, -.96306600E+05, 0.13452300E+06, 0.51047600E+05, 0.15657400E+06, -.64358800E+05, 0.19518000E+06, -.29079800E+06, 0.14543100E+06, 0.13628200E+06, 0.14651700E+06, -.60006100E+05, -.15181200E+06, 0.14079800E+06, 0.84785400E+05, 0.13460300E+06, -.12486900E+06, 0.35298500E+06, -.21812300E+06, 0.10975600E+06, 0.97973700E+05, 0.11007400E+06, -.41435300E+05, -.57346800E+05, 0.50184900E+05, -.35251500E+05, 0.41671900E+05, -.29965700E+05, 0.31475500E+06, -.27001900E+05, 0.64997500E+04, 0.49417500E+05, 0.13870400E+05, 0.34708100E+05, -.26926500E+05, 0.15291100E+05, 0.58845200E+04, 0.35807900E+04, -.10530800E+04, 0.76785500E+05, -.13036800E+06, 0.64307800E+05, 0.99945200E+05, 0.66132800E+05, -.24025900E+05, -.14499000E+06, 0.12260600E+06, 0.10746200E+06, 0.79327000E+05, -.12188900E+06, 0.29798300E+06, 0.37436300E+05, -.17655600E+05, 0.48025200E+05, -.17841300E+05, -.45643900E+05, -.10305500E+06, 0.70884500E+05, 0.95006200E+05, 0.18963400E+05, -.87863000E+05, 0.21971300E+06, -.45631200E+06, 0.23172100E+06, 0.17466600E+06, 0.22940100E+06, 0.24138100E+05, -.96616500E+05, 0.11055400E+06, -.41610500E+05, 0.99640800E+05, -.53316400E+05, 0.52088700E+06, 0.29794100E+06, -.14901200E+06, -.75996200E+05, -.14915900E+06, 0.54129100E+05, 0.71380300E+05, -.83622700E+05, 0.26909700E+04, -.79579700E+05, 0.57229200E+05, -.40407400E+06, -.42867400E+06, 0.21358800E+06, 0.83077700E+05, 0.21418500E+06, -.95539500E+02, -.23533800E+05, 0.70303100E+05, -.56153600E+05, 0.11276100E+06, -.46603200E+04, 0.37928500E+06, -.83149300E+05, 0.39993800E+05, 0.64132300E+05, 0.42781000E+05, -.84332300E+05, -.18502200E+06, 0.12695700E+06, 0.10542800E+06, 0.71934400E+05, -.14880300E+06, 0.32608000E+06, 0.35000700E+05, -.17427200E+05, -.16092200E+05, -.17661400E+05, 0.53468600E+04, 0.26876200E+05, -.21906300E+05, -.15198800E+05, -.17688100E+05, 0.22429100E+05, -.56073800E+05, -.44253200E+06, 0.21623200E+06, 0.11305900E+06, 0.22084700E+06, -.68078900E+05, -.15969900E+06, 0.14922100E+06, 0.20978900E+05, 0.17605600E+06, -.11415200E+06, 0.56309800E+06, 0.24437100E+05, -.97576000E+04, 0.36779700E+05, -.12166400E+05, -.38641300E+05, -.73936600E+05, 0.33522800E+05, 0.17233900E+05, -.17111400E+04, -.47345900E+05, 0.14794400E+06, -.64454700E+05, 0.33143200E+05, -.29926800E+05, 0.32215800E+05, 0.50390500E+05, 0.12558500E+05, -.33859900E+04, -.16857600E+05, 0.13374400E+05, 0.19747700E+05, 0.97411300E+05, 0.54676700E+06, -.26714600E+06, -.23906900E+06, -.27379600E+06, -.16233600E+06, 0.12986300E+06, -.18046100E+06, -.76366300E+05, -.18921900E+06, 0.96350500E+05, -.23250000E+06, 0.40193900E+06, -.19719800E+06, -.24523600E+06, -.20080100E+06, 0.27040200E+05, 0.93168700E+05, -.10980400E+06, 0.17372100E+05, -.89901500E+05, 0.62929700E+05, -.37090700E+06, -.32333300E+05, 0.20235300E+05, -.57244400E+05, 0.15288800E+05, 0.21011800E+05, 0.82812200E+05, -.28152400E+05, -.31410400E+05, 0.39124400E+04, 0.46426700E+05, -.19919000E+06, 0.18371600E+05, -.50890400E+04, -.19564000E+05, -.10059100E+05, 0.26880300E+05, 0.64623000E+05, -.46657600E+05, -.42728400E+05, -.37628400E+05, 0.45654600E+05, -.19293000E+06, -.72776700E+05, 0.40083500E+05, 0.14284400E+05, 0.37132500E+05, -.25332800E+05, -.27181500E+04, 0.14938000E+04, -.31124800E+05, -.16501300E+05, -.41403400E+04, 0.16869400E+06, -.63002300E+06, 0.31320000E+06, 0.95542400E+05, 0.31453200E+06, -.36532300E+05, -.97473100E+05, 0.13932900E+06, -.42228400E+05, 0.20671500E+06, -.56873000E+05, 0.67539300E+06, -.33652100E+06, 0.18321500E+06, 0.82392200E+05, 0.16997000E+06, -.59545300E+05, -.57382400E+05, 0.63312400E+05, -.52319500E+05, 0.40486100E+05, -.45633300E+05, 0.59357500E+06, 0.20462500E+06, -.94284100E+05, -.63164700E+05, -.10151700E+06, -.11018700E+06, -.67184800E+05, 0.63487200E+04, 0.60140400E+05, -.32376600E+05, -.64716900E+05, 0.17930600E+06, -.40091400E+05, 0.17759100E+05, 0.52957300E+05, 0.21065000E+05, -.97040100E+05, -.14165400E+06, 0.96421300E+05, 0.96783400E+05, 0.73092700E+05, -.11507800E+06, 0.19905400E+06, -.27231600E+05, -.54351400E+05, 0.11404900E+05, -.18588700E+05, -.46079100E+05, 0.96585900E+05, 0.51733500E+05, -.22641300E+05, -.40699500E+05, -.69094700E+05, 0.94495700E+05, 0.91605900E+04, 0.48689400E+04, -.23767000E+05, 0.32562200E+05, -.31779100E+05, 0.47123100E+05, -.10720100E+05, 0.36531700E+05, 0.29879500E+05, -.38298700E+05, -.12656600E+06, -.18209900E+05, 0.11053000E+06, 0.62396200E+05, 0.27627800E+05 },
        { 0.66198200E+01, -.83888500E+01, -.81464600E+00, -.29066200E+01, 0.27443900E+01, -.24315900E+00, 0.61044500E+01, -.20608100E+01, 0.42379600E+01, -.36315600E+01, 0.25750800E+00, 0.48239300E+06, -.23525700E+06, -.14836100E+06, -.24120700E+06, -.55540100E+05, 0.70368100E+05, -.13694900E+06, -.39506500E+05, -.14727600E+06, 0.50715600E+05, -.13079200E+06, 0.52347300E+06, -.25559300E+06, -.31471400E+06, -.26160900E+06, -.22611300E+06, 0.95096000E+05, -.18226500E+06, -.11588000E+06, -.18577700E+06, 0.59181600E+05, 0.77876500E+04, 0.28257800E+06, -.13364000E+06, -.16724700E+06, -.14046600E+06, 0.13662300E+06, 0.28171900E+06, -.21362700E+06, -.14929100E+06, -.17374200E+06, 0.23848600E+06, -.10244100E+06, 0.34975700E+06, -.16985900E+06, -.17871000E+06, -.17413700E+06, 0.10431600E+06, 0.13452200E+06, -.11819000E+06, 0.37167800E+05, -.76465100E+05, 0.88260400E+05, -.11499400E+06, -.66166700E+05, 0.36383600E+05, -.11000100E+06, 0.33367900E+05, -.45214600E+05, 0.21070500E+05, -.10609600E+05, -.27487400E+05, 0.46089800E+05, -.13355400E+05, 0.16030900E+06, 0.45811600E+05, -.16209600E+05, -.14862100E+06, -.22215500E+05, 0.56249200E+05, 0.22763300E+06, -.16880400E+06, -.18932200E+06, -.74134300E+05, 0.19397900E+06, 0.58113300E+05, -.19095500E+06, 0.97080200E+05, -.95478600E+05, 0.96119700E+05, 0.89383000E+05, 0.16798400E+06, -.96689600E+05, -.17762100E+06, 0.12401600E+05, 0.14631500E+06, 0.12455500E+06, 0.71002100E+06, -.34760800E+06, -.34815300E+06, -.35414900E+06, -.51546600E+04, 0.17373000E+06, -.21517000E+06, 0.31322800E+05, -.17013400E+06, 0.11231500E+06, -.18398100E+06, -.36859300E+06, 0.17837600E+06, 0.85369800E+05, 0.18421200E+06, -.12222400E+06, -.15910200E+06, 0.14090000E+06, 0.18626800E+04, 0.93084500E+05, -.13195100E+06, 0.15025100E+06, 0.42502000E+06, -.21202700E+06, -.34835700E+05, -.21259300E+06, 0.13734500E+05, 0.55861400E+05, -.93928700E+05, 0.38110700E+05, -.11672000E+06, 0.27890900E+05, -.17890800E+06, -.72340700E+05, 0.43424700E+05, -.84115200E+05, 0.37060400E+05, 0.15862400E+06, 0.30543500E+06, -.16541600E+06, -.18159900E+06, -.41127500E+05, 0.24933300E+06, 0.92357100E+05, -.25669800E+05, 0.11744800E+05, 0.24471600E+05, 0.12716300E+05, -.13700400E+05, -.43890700E+05, 0.31811900E+05, 0.30158000E+05, 0.19468800E+05, -.37587900E+05, -.37383200E+04, 0.26222600E+06, -.12806300E+06, -.97946400E+05, -.13143800E+06, 0.14971800E+06, 0.29596400E+06, -.20414600E+06, -.11508400E+06, -.16453500E+06, 0.22404400E+06, -.82559800E+05, -.14740700E+06, 0.77043100E+05, -.11649700E+06, 0.73741200E+05, 0.99904800E+05, 0.12738100E+06, -.42027100E+05, -.53759400E+05, 0.40940000E+05, 0.84629900E+05, 0.10703900E+06, 0.16195800E+06, -.76884400E+05, -.92557500E+04, -.80978600E+05, -.64205900E+05, -.40170200E+05, -.71055900E+04, 0.25628400E+05, -.33429500E+05, -.45115000E+05, -.24290800E+05, -.65501400E+06, 0.31909100E+06, 0.39866400E+06, 0.32717100E+06, 0.26439700E+06, -.12137000E+06, 0.21788500E+06, 0.11790900E+06, 0.20700700E+06, -.87382900E+05, 0.34001500E+05, -.25989200E+06, 0.12427000E+06, 0.29521700E+06, 0.13007100E+06, -.97415200E+05, -.19958900E+06, 0.15763200E+06, 0.52798900E+05, 0.52436400E+05, -.14884800E+06, 0.47982800E+05, 0.16897600E+06, -.89162400E+05, 0.15375400E+06, -.85102400E+05, -.64785600E+05, -.11233700E+06, 0.38256000E+05, 0.63257600E+05, -.85563600E+05, -.60452000E+05, -.21372400E+06, 0.10263300E+06, -.53999300E+05, 0.47140800E+04, -.51962000E+05, -.46671100E+05, -.88129800E+05, 0.34663900E+05, 0.65467800E+05, 0.28640500E+04, -.61056200E+05, -.73464200E+05, 0.10854500E+06, -.53985800E+05, -.20371300E+05, -.53726800E+05, 0.55930800E+05, 0.33998900E+05, -.26757500E+05, 0.32234700E+05, 0.14749000E+05, 0.33533800E+05, -.81605200E+05, 0.51777700E+06, -.25900800E+06, -.10855800E+05, -.25917000E+06, 0.84461000E+05, 0.18792000E+06, -.18225900E+06, -.25822400E+05, -.20753300E+06, 0.12698200E+06, -.22847600E+06, 0.56183800E+06, -.27871300E+06, -.15350700E+06, -.27968000E+06, 0.13926500E+06, 0.16945000E+06, -.17716000E+06, 0.41676500E+05, -.10098400E+06, 0.14552500E+06, -.27422900E+06, -.34937400E+06, 0.17553000E+06, 0.65309000E+05, 0.17532300E+06, 0.20212300E+06, 0.14286100E+06, -.16452500E+05, -.98256800E+05, 0.64125700E+05, 0.13287100E+06, 0.10607600E+06, -.15710600E+06, 0.84502000E+05, -.29117500E+05, 0.79332400E+05, 0.18417800E+06, 0.25693300E+06, -.12007900E+06, -.16992100E+06, -.49383400E+05, 0.21330500E+06, 0.61674400E+05, 0.59120900E+04, 0.13162300E+05, -.35070000E+05, 0.30137900E+05, 0.87250000E+05, -.15448300E+06, -.97065000E+05, -.11839200E+05, 0.76126200E+05, 0.11222500E+06, -.16022900E+06, -.57994100E+05, -.41497500E+05, 0.34467700E+05, -.49432600E+05, 0.36137300E+05, -.26067900E+05, 0.12730000E+05, -.30147600E+05, -.60860700E+05, 0.29339600E+05, 0.20927900E+06, 0.59276000E+05, -.18702600E+06, -.48035300E+05, -.38148100E+05 },
        { -.16059300E+00, -.82219200E+00, -.69980800E-01, -.61098700E-01, -.26692200E+00, 0.11346500E-01, -.72394400E+00, 0.74241700E+00, -.20826000E+00, 0.31210400E+00, 0.12655600E-01, 0.14688500E-01, -.61135700E+03, -.39894100E+04, 0.29125700E+01, -.55061500E+03, 0.43598300E+04, -.33214600E+04, -.59980800E+04, -.31710200E+04, 0.48523000E+04, 0.16923300E+04, 0.61005500E+04, -.30136100E+04, -.24446200E+04, -.30778000E+04, -.19876100E+04, 0.89359400E+04, -.67334700E+04, -.90352300E+04, -.64718900E+04, 0.10526300E+05, 0.14050700E+04, -.11684400E+05, 0.49651500E+04, -.20497500E+05, 0.56142000E+04, 0.65348800E+04, 0.82743600E+04, -.44625900E+04, -.78878200E+04, 0.50658900E+04, 0.71409600E+04, 0.85947300E+04, -.40495000E+05, 0.19573100E+05, -.50241300E+04, 0.20039500E+05, 0.10364100E+05, 0.54335900E+04, 0.35434500E+04, -.51932300E+04, 0.13472400E+05, 0.47222700E+04, 0.17379600E+05, -.25497200E+05, 0.13413500E+05, -.17231700E+04, 0.12672200E+05, 0.13093400E+05, 0.89942100E+04, 0.58147800E+03, -.13467700E+04, 0.87042800E+04, 0.75324000E+04, 0.11008900E+05, -.10311500E+05, 0.45113200E+04, -.82684000E+04, 0.49605800E+04, 0.69722500E+04, 0.10399500E+05, -.53619200E+04, -.83134900E+04, 0.32432500E+04, 0.92192400E+04, 0.85822000E+04, -.23754700E+05, 0.11541200E+05, -.85123400E+04, 0.11699300E+05, 0.11174600E+05, 0.97391900E+04, -.22034400E+04, -.57635900E+04, 0.91853600E+04, 0.83850900E+04, 0.13362000E+05, -.36526900E+05, 0.16897500E+05, 0.14943200E+04, 0.18002500E+05, 0.56029500E+04, 0.67790300E+04, 0.22558300E+04, -.78123400E+04, 0.95933700E+04, 0.69886000E+04, 0.16549100E+05, 0.21781400E+05, -.10186500E+05, 0.66599300E+04, -.10847000E+05, -.72773100E+04, -.52481400E+04, 0.22049300E+03, 0.50982900E+04, -.65745500E+04, -.41219800E+04, -.10802400E+05, 0.83967300E+04, -.42633400E+04, -.55573900E+04, -.41742400E+04, -.21390700E+04, -.29735200E+04, 0.63413000E+03, 0.33219400E+04, -.19261000E+04, -.29130600E+04, -.51612800E+04, -.27586700E+05, 0.13190000E+05, -.13648900E+05, 0.13545500E+05, 0.13056100E+05, 0.11324600E+05, -.26528200E+04, -.66127500E+04, 0.11052000E+05, 0.93151200E+04, 0.15816300E+05, 0.30086500E+04, -.13887000E+04, 0.21344900E+04, -.14713900E+04, -.14860900E+04, -.18688200E+04, 0.70863900E+03, 0.12899400E+04, -.10550400E+04, -.16659600E+04, -.20179500E+04, 0.69900800E+03, -.22606400E+03, -.18843600E+05, -.27220800E+03, 0.14018300E+04, -.23827700E+02, 0.29823500E+03, 0.35548300E+04, 0.42431100E+04, -.66241800E+03, -.77812700E+03, -.36573400E+05, 0.17498900E+05, -.14222900E+05, 0.18275400E+05, 0.12467500E+05, 0.66660400E+04, 0.26982400E+04, -.29328700E+04, 0.13393500E+05, 0.52344300E+04, 0.17483100E+05, -.89266400E+04, 0.37881800E+04, 0.23253500E+04, 0.44653100E+04, 0.15933000E+04, 0.23158100E+04, 0.10831700E+04, -.11632200E+04, 0.12559100E+04, 0.24530800E+04, 0.38678000E+04, -.11548800E+05, 0.57939200E+04, 0.40601300E+04, 0.58551600E+04, 0.50108200E+04, -.10977800E+05, 0.10340200E+05, 0.14697300E+05, 0.10750800E+05, -.12890000E+05, -.20203800E+04, 0.16802700E+05, -.82052500E+04, 0.17081400E+05, -.84313100E+04, -.61942500E+04, -.52925400E+04, 0.66315600E+03, 0.40382400E+04, -.58820500E+04, -.46369300E+04, -.84913900E+04, 0.57345400E+05, -.28748900E+05, 0.88518300E+04, -.28487000E+05, -.24911400E+05, -.16921500E+05, -.16470100E+04, 0.59784400E+04, -.19480700E+05, -.13657100E+05, -.25841900E+05, 0.50112200E+04, -.27981700E+04, 0.41448700E+04, -.23255700E+04, -.49514400E+04, -.32631800E+04, 0.13796600E+04, 0.85042400E+03, -.25492700E+04, -.24249700E+04, -.31009800E+04, -.91234000E+04, 0.39869000E+04, 0.28700900E+04, 0.44084400E+04, 0.20052600E+04, 0.91305800E+03, 0.13278800E+04, -.49182000E+03, 0.24773500E+04, 0.20753200E+03, 0.33052300E+04, 0.14775100E+05, -.73517900E+04, -.13779100E+05, -.73046500E+04, -.36371400E+04, -.54385600E+04, 0.13692600E+04, 0.73696900E+04, -.92120800E+03, -.55468700E+04, -.88785900E+04, -.26922000E+05, 0.10976300E+05, 0.14258200E+04, 0.13109700E+05, 0.50214900E+04, 0.37655100E+04, 0.28711800E+04, -.32286100E+04, 0.75507800E+04, 0.24723300E+04, 0.10690300E+05, -.30556100E+05, 0.13974700E+05, -.10493400E+05, 0.15121000E+05, 0.11587700E+05, 0.55937100E+04, 0.15197900E+04, -.27333100E+04, 0.12696300E+05, 0.35376000E+04, 0.14994100E+05, -.14557500E+05, 0.69419800E+04, -.19361500E+05, 0.70721900E+04, 0.94579700E+04, 0.62659900E+04, -.22378000E+04, -.31782800E+04, 0.81490600E+04, 0.45211400E+04, 0.88135600E+04, -.49097700E+04, -.40195600E+04, -.56255600E+04, 0.85311400E+04, 0.25399300E+04, -.59736800E+04, -.76343200E+04, -.37413400E+04, 0.40878000E+04, 0.85360400E+04, -.70716400E+04, -.31922700E+04, -.35325800E+04, 0.31820100E+04, -.30558400E+04, 0.18776100E+04, 0.46643700E+04, 0.91705900E+04, -.19098500E+03, -.32325700E+04, -.38170300E+04, 0.80889400E+04, 0.34786700E+04, -.79132700E+04, 0.56088800E+03, -.15536900E+03 },
        { -.17601700E+00, -.80113200E+00, -.76609500E-01, -.36063400E+00, -.41304600E+00, 0.36326900E+00, -.60092300E+00, 0.11760800E+01, -.22141000E+00, 0.26798300E+00, 0.11595000E-01, 0.25648700E-02, 0.86169300E-01, -.44785100E+04, -.40182100E+00, -.10602500E+04, 0.43355400E+03, -.17669200E+04, -.37845300E+04, -.41169000E+03, 0.71943100E+03, 0.31677500E+04, 0.50629000E+04, -.26268700E+04, 0.41002100E+04, -.25276700E+04, -.26630600E+04, 0.20420000E+04, -.33414700E+04, -.52062100E+04, -.31457900E+04, 0.21169100E+04, 0.28403700E+04, -.22959600E+04, 0.85403900E+03, -.17790300E+05, 0.11752200E+04, -.18577600E+04, 0.13673800E+04, -.64600800E+03, -.18017900E+04, 0.15951900E+04, 0.14769000E+04, 0.44518600E+04, -.17452600E+04, 0.82115300E+03, -.15413600E+05, 0.89726700E+03, -.25918900E+04, -.20474100E+02, 0.21227100E+03, -.75341700E+03, 0.12270800E+04, 0.21104500E+03, 0.44536900E+04, 0.88141500E+04, -.41190300E+04, -.49589300E+04, -.43979400E+04, -.16872700E+04, 0.11934500E+04, -.20058100E+04, -.54625400E+03, -.36184800E+04, 0.45635900E+03, -.93628100E+03, 0.19456900E+05, -.97244100E+04, -.14187400E+05, -.97054000E+04, -.47860000E+04, -.74837600E+03, -.41171800E+04, -.14115200E+04, -.70413100E+04, -.11365100E+03, -.56063500E+04, 0.16217300E+05, -.81431900E+04, -.13931100E+05, -.80873200E+04, -.39608000E+04, 0.87297900E+03, -.43486000E+04, -.19382200E+04, -.64673100E+04, 0.11353200E+04, -.40675800E+04, 0.10599900E+05, -.54244700E+04, -.99935500E+04, -.52701500E+04, -.45999900E+04, 0.62730400E+02, -.28133700E+04, -.22349300E+04, -.34298700E+04, 0.32982300E+03, 0.13224600E+04, -.10016500E+05, 0.49953300E+04, 0.19283500E+05, 0.50042300E+04, 0.49925800E+04, 0.18282900E+04, 0.22202400E+04, 0.17623700E+04, 0.34145400E+04, 0.91153900E+03, 0.10123800E+04, -.69058800E+04, 0.34943500E+04, -.32814900E+04, 0.34495400E+04, -.63397100E+03, -.16150400E+04, 0.13752800E+04, -.13587900E+04, 0.26481500E+04, -.14771200E+04, 0.36911800E+04, 0.15058100E+05, -.77706000E+04, -.20344800E+05, -.74996300E+04, -.61497200E+04, -.15441200E+04, -.27504700E+04, -.49584500E+03, -.52602200E+04, -.92871700E+03, -.35820100E+04, -.23127800E+04, 0.11899200E+04, 0.29659400E+04, 0.11524700E+04, 0.73906500E+03, -.14587800E+03, 0.69050300E+03, 0.41918400E+03, 0.86912800E+03, -.20278200E+03, 0.32378000E+03, -.10340400E+05, 0.40251200E+04, -.16041600E+05, 0.51598000E+04, -.17221500E+04, -.24198300E+04, 0.12301400E+04, -.33612700E+04, 0.39996500E+04, -.19778000E+04, 0.77147700E+04, -.53641000E+04, 0.36063400E+04, -.10499200E+05, 0.26833100E+04, 0.26533000E+04, 0.30946600E+04, -.64783200E+03, -.87480600E+03, 0.22926600E+04, 0.27084400E+04, 0.39933500E+04, -.19793400E+04, 0.14731200E+04, -.41832200E+02, 0.98944200E+03, 0.29964200E+04, 0.37700800E+04, -.78309900E+03, -.98262600E+02, 0.74474000E+03, 0.29835500E+04, 0.18418000E+04, -.55593300E+04, 0.27762600E+04, -.90345100E+04, 0.27692800E+04, 0.48574700E+03, -.35111900E+04, 0.41420900E+04, 0.61637500E+04, 0.38721300E+04, -.33386800E+04, -.49968400E+03, 0.57380700E+04, -.18878400E+04, 0.11915200E+05, -.28649200E+04, 0.18032300E+04, 0.22225700E+04, -.47364100E+03, 0.35942700E+04, -.17966400E+04, 0.14134400E+04, -.55147500E+04, -.46798200E+04, 0.23410700E+04, 0.19492200E+05, 0.23188400E+04, 0.16516200E+04, -.25504300E+04, 0.20933300E+04, 0.19111100E+04, 0.21508400E+04, -.14423600E+04, -.30249800E+04, -.48140800E+04, 0.23634600E+04, 0.59307100E+04, 0.23857300E+04, 0.14510300E+04, 0.45880700E+03, 0.80566700E+03, 0.13070200E+02, 0.16989800E+04, 0.44783100E+03, 0.17289700E+04, 0.10403100E+05, -.53142800E+04, -.59733600E+04, -.51834500E+04, -.32652500E+04, -.19797600E+04, -.11519400E+04, 0.79422400E+03, -.34171000E+04, -.14272900E+04, -.34715600E+04, -.13340800E+05, 0.64594800E+04, -.95921400E+04, 0.66594800E+04, -.12443100E+04, -.29767100E+04, 0.21943300E+04, -.29867600E+04, 0.52533900E+04, -.27540900E+04, 0.78328800E+04, 0.23874100E+05, -.12060900E+05, -.19896700E+05, -.11895600E+05, -.88515300E+04, -.37129200E+04, -.38750400E+04, -.38107000E+03, -.76892200E+04, -.23364800E+04, -.43836700E+04, 0.27801600E+04, -.14462800E+04, -.18007300E+05, -.13701700E+04, -.82720300E+03, 0.63754000E+03, -.10454900E+04, 0.42713000E+03, -.60223700E+02, 0.69565400E+03, -.40980200E+03, 0.58121100E+03, -.78085800E+03, -.16819400E+05, -.26545900E+03, -.22057500E+04, 0.20224500E+03, -.40939300E+03, -.15349900E+03, 0.38660400E+03, 0.20780000E+03, 0.18664800E+04, 0.28761300E+04, 0.17086000E+04, 0.94623100E+03, -.97233600E+03, -.29475100E+04, 0.74442300E+03, -.11279200E+04, 0.30635000E+03, 0.12748200E+04, 0.13863000E+03, -.55026100E+03, 0.30194700E+04, -.18142800E+04, -.98789600E+02, 0.38664500E+04, 0.54541900E+04, -.13338500E+04, -.11580500E+04, 0.54730000E+04, 0.70283000E+02, 0.13835300E+04, 0.83356900E+03, -.32290900E+04, -.50491500E+03, -.33730200E+04, 0.38055600E+04 },
        { -.26264000E+00, -.14258800E+00, 0.14253400E-01, -.21976700E+00, -.57044700E+00, -.60552600E+00, 0.14742500E+00, 0.58387100E+00, -.35245200E-01, 0.13881000E-01, -.12815600E-01, 0.11312700E-02, 0.55046900E+00, -.10178800E+01, -.35551800E+01, -.45048200E+03, 0.84800800E+03, -.27667600E+04, -.45263000E+04, -.96891600E+03, 0.41532300E+03, 0.49323200E+04, 0.56194700E+04, -.25476500E+04, 0.23726000E+05, -.27742400E+04, -.21791400E+04, 0.23677100E+04, -.59674400E+04, -.99360500E+04, -.47092300E+04, 0.85486800E+03, 0.50639500E+04, -.11855900E+05, 0.54148500E+04, -.19421700E+05, 0.61852400E+04, -.41583700E+04, -.55501100E+04, 0.52128100E+04, 0.14396200E+04, 0.62131200E+04, -.46170200E+04, 0.82676400E+04, 0.56935000E+04, -.30658800E+04, -.25201800E+05, -.26138100E+04, -.68972500E+04, -.30570700E+04, -.30339300E+04, -.58091500E+04, -.33590100E+04, -.21035100E+04, 0.61765800E+04, 0.24228100E+05, -.11069100E+05, 0.68847200E+03, -.12027300E+05, -.44235100E+04, 0.36812500E+04, -.80599900E+04, -.49348600E+04, -.11173900E+05, 0.16970600E+04, -.54937000E+04, 0.28726800E+05, -.14370300E+05, -.83962700E+04, -.14145500E+05, -.66128900E+04, -.37665100E+04, -.38521600E+04, 0.78083800E+03, -.99374700E+04, -.32819700E+04, -.97316000E+04, 0.27505300E+05, -.13940200E+05, -.10924900E+05, -.13551400E+05, -.76935900E+04, -.12926600E+04, -.74175800E+04, -.46646400E+04, -.11929500E+05, -.10598100E+04, -.66631500E+04, 0.16007600E+05, -.86372000E+04, -.54623000E+04, -.77217300E+04, -.89422400E+04, -.34153900E+04, -.81299700E+04, -.11876900E+05, -.90046300E+04, -.31305000E+04, 0.57336100E+04, -.14085100E+05, 0.71464100E+04, 0.24560900E+05, 0.70040800E+04, 0.80713800E+04, 0.59195200E+04, 0.33082700E+04, 0.44994300E+04, 0.61826300E+04, 0.41568500E+04, 0.19807900E+04, 0.25579800E+02, 0.14668800E+03, -.26050200E+04, -.42608700E+02, -.10913600E+03, 0.60336700E+03, -.28137200E+04, -.48152200E+04, -.10879500E+04, 0.47044300E+02, 0.27231600E+04, 0.24256700E+05, -.12414400E+05, -.20096000E+05, -.11849900E+05, -.10583100E+05, -.76372200E+04, -.30251800E+04, -.13046000E+04, -.89928600E+04, -.64437300E+04, -.73123400E+04, -.41921000E+04, 0.21513300E+04, 0.28107300E+04, 0.20589600E+04, 0.11836000E+04, 0.29012900E+03, 0.11743900E+04, 0.67150200E+03, 0.17213500E+04, 0.28246600E+03, 0.83976800E+03, -.23858900E+04, 0.29950200E+03, -.13573600E+05, 0.10967100E+04, -.21799600E+04, -.32885100E+04, -.38209600E+04, -.98687100E+04, -.17331000E+04, -.32668800E+04, 0.79134200E+04, 0.19383100E+05, -.87369900E+04, -.80655100E+04, -.96794600E+04, 0.11401100E+04, 0.76955400E+04, -.86168400E+04, -.32449900E+04, -.87766100E+04, 0.71597900E+04, -.47738200E+04, 0.96146700E+04, -.42531100E+04, 0.84771500E+03, -.48092300E+04, 0.46121100E+04, 0.11305100E+05, -.73872700E+04, -.30135100E+04, -.50919500E+04, 0.89470800E+04, -.95226000E+03, 0.17379000E+05, -.92076800E+04, -.43214100E+05, -.87873700E+04, -.11645600E+04, -.44220600E+03, -.18040500E+04, 0.63648900E+04, -.42379800E+04, 0.10227100E+04, -.78735100E+04, -.18765200E+03, 0.10595900E+04, 0.10510000E+05, 0.13157200E+03, 0.38101300E+04, 0.77164800E+04, 0.51736800E+03, 0.63919300E+04, 0.19882000E+04, 0.61944400E+04, -.57542600E+04, -.20269500E+05, 0.97935500E+04, 0.22222800E+05, 0.99346600E+04, 0.68714700E+04, -.34859200E+04, 0.93353900E+04, 0.99236900E+04, 0.10715200E+05, -.10851300E+04, -.13247500E+04, -.48694300E+04, 0.19973100E+04, 0.16935800E+04, 0.22328600E+04, 0.21274900E+04, 0.26363700E+03, 0.19226500E+03, -.69333100E+03, 0.15727800E+04, 0.25754400E+03, 0.30423800E+04, 0.19770800E+05, -.10421900E+05, -.99788000E+04, -.97139800E+04, -.46907600E+04, -.33859000E+04, -.40672500E+04, -.92606600E+03, -.84034200E+04, -.22120300E+04, -.62134300E+04, -.16730800E+04, 0.83892000E+03, -.67522200E+04, 0.73855000E+03, -.47809700E+03, 0.51626800E+03, -.55589600E+04, -.10235800E+05, -.19201300E+04, -.47540500E+03, 0.69324700E+04, 0.45065500E+05, -.24258200E+05, -.30788400E+05, -.22140900E+05, -.13505300E+05, -.86019500E+04, -.12662700E+05, -.95669500E+04, -.19902000E+05, -.60042100E+04, -.70948100E+04, 0.13281800E+05, -.75626400E+04, -.27021400E+05, -.64532800E+04, -.45771800E+04, -.18208400E+04, -.28841700E+04, 0.21575000E+02, -.37251600E+04, -.94131600E+03, -.41818200E+04, -.76060600E+03, -.14397000E+03, -.18945000E+05, 0.61799200E+03, -.52929300E+04, -.53525500E+04, 0.33332400E+04, 0.25546700E+04, 0.18101200E+04, -.43737100E+04, 0.16045100E+04, 0.56026700E+04, 0.38038700E+04, 0.56090800E+03, -.24572700E+04, -.67337700E+04, 0.51761800E+04, -.14149100E+04, 0.26107700E+04, 0.32840500E+03, -.27161700E+04, 0.35624000E+03, 0.30111600E+04, -.17497500E+04, -.97852400E+03, 0.39141100E+04, 0.58965700E+04, -.25526100E+04, -.26285000E+04, 0.48593700E+04, -.15867500E+03, 0.32709600E+04, -.17124100E+04, -.31975800E+04, 0.19421600E+04, -.51909500E+04, 0.67657900E+04 },
        { -.33076100E+00, -.47336200E+00, -.43324200E-01, -.20604900E+00, -.37508100E+00, 0.25631400E+00, -.71072700E+00, 0.87000900E+00, -.31950600E+00, 0.34671300E+00, 0.16376200E-01, -.18883900E-01, -.13840600E+00, 0.42708000E+00, -.10083300E-01, 0.22124700E+04, 0.13310600E+04, -.59902800E+03, -.26826300E+03, -.89076500E+03, 0.12386800E+04, -.13099200E+04, 0.27419100E+04, -.13405800E+04, -.37394700E+03, -.13708000E+04, 0.89668900E+03, 0.50056800E+03, -.11342700E+04, -.27979400E+03, -.22082100E+04, 0.90499600E+03, -.31174800E+04, -.96687800E+04, 0.47961000E+04, -.33397600E+04, 0.48306400E+04, 0.44387100E+04, 0.12775000E+04, 0.10917800E+04, -.25818600E+03, 0.43837400E+04, 0.61862800E+03, 0.40206700E+04, -.13009000E+05, 0.64921400E+04, -.97152300E+03, 0.65008200E+04, 0.46259600E+04, 0.23568800E+04, 0.81124100E+03, -.24322800E+04, 0.35323100E+04, 0.18782300E+04, 0.55313500E+04, -.68276800E+04, 0.34989100E+04, -.11832800E+04, 0.34126400E+04, 0.28458800E+04, 0.18622700E+04, -.22716700E+03, -.15380000E+04, 0.16829900E+04, 0.18143200E+04, 0.13304300E+04, -.89138900E+04, 0.44475400E+04, -.38430900E+03, 0.44534100E+04, 0.24898600E+04, 0.15930500E+03, 0.12540700E+04, -.36877100E+03, 0.39742200E+04, -.95392800E+02, 0.35087700E+04, -.94325100E+04, 0.47005400E+04, -.23023000E+04, 0.47133800E+04, 0.31689700E+04, 0.12206800E+04, 0.75554600E+03, -.88206500E+03, 0.41438300E+04, 0.72484600E+03, 0.43115100E+04, -.80507300E+04, 0.39769600E+04, 0.10473700E+04, 0.40193900E+04, 0.38460600E+04, 0.18928100E+04, 0.23859500E+03, -.23133900E+04, 0.13758100E+04, 0.16722800E+04, 0.18891900E+04, 0.10673400E+05, -.53260900E+04, -.12256800E+04, -.53345100E+04, -.54258100E+04, -.26849200E+04, -.65554300E+03, 0.13878900E+04, -.29846200E+04, -.20628100E+04, -.32288000E+04, 0.34407900E+04, -.17338200E+04, -.18811400E+03, -.17204600E+04, 0.11495700E+04, 0.22724100E+04, -.23804900E+04, -.21057100E+04, -.22280600E+04, 0.17130500E+04, -.16325500E+04, -.12185800E+05, 0.60666800E+04, -.22658700E+04, 0.60886500E+04, 0.49643000E+04, 0.21781400E+04, 0.87262200E+03, -.59108000E+03, 0.55206300E+04, 0.14014400E+04, 0.51320900E+04, 0.17218200E+04, -.85582800E+03, 0.20997600E+03, -.86036000E+03, -.71490300E+03, -.25638000E+03, -.16616900E+03, 0.73102500E+02, -.75163000E+03, -.15091800E+03, -.68750700E+03, -.51154400E+04, 0.25725800E+04, -.48037000E+04, 0.25577100E+04, 0.39494300E+04, 0.33535600E+04, -.14431200E+04, -.24811000E+04, 0.27568000E+04, 0.21643600E+04, 0.23119800E+04, -.11618900E+05, 0.58510100E+04, -.42281300E+04, 0.58091700E+04, 0.30664600E+04, 0.14037100E+04, 0.83305800E+03, -.13855100E+04, 0.48195400E+04, 0.10650700E+04, 0.59814700E+04, 0.34642000E+03, -.14307100E+03, 0.77780300E+03, -.17307500E+03, -.18964400E+03, -.10806600E+03, -.31228300E+03, -.61197900E+03, -.83879200E+03, 0.14855000E+03, -.14355200E+03, -.20746200E+04, 0.10008500E+04, -.14963100E+04, 0.10377200E+04, -.96167500E+03, -.63218700E+03, 0.88540300E+03, 0.46509300E+02, 0.24286700E+04, -.11858200E+04, 0.34354900E+04, 0.12250700E+05, -.60848800E+04, 0.36703300E+04, -.61252800E+04, -.50256400E+04, -.37619000E+04, 0.28119700E+03, 0.31615100E+04, -.34548200E+04, -.28224700E+04, -.52533500E+04, 0.19117100E+05, -.95927400E+04, 0.36431000E+04, -.95541900E+04, -.70335900E+04, -.42968800E+04, -.40542400E+03, 0.35680200E+04, -.53080000E+04, -.37481400E+04, -.71726700E+04, 0.34379900E+04, -.17597700E+04, 0.82270000E+03, -.17158300E+04, -.17433400E+04, -.93550000E+03, 0.14819700E+03, 0.68560200E+03, -.12538100E+04, -.79367300E+03, -.11043900E+04, -.33933100E+04, 0.16682800E+04, 0.20688500E+04, 0.16939200E+04, 0.15709500E+04, 0.86314300E+03, 0.31026400E+03, -.81010700E+03, 0.22527600E+03, 0.61844500E+03, 0.86375400E+03, 0.49524200E+04, -.24836100E+04, -.29128600E+04, -.24756900E+04, 0.22102000E+04, 0.36142900E+04, -.35701600E+04, -.27443300E+04, -.18587600E+04, 0.24781000E+04, -.21144200E+04, -.77272300E+04, 0.37439100E+04, 0.30946400E+04, 0.38572200E+04, 0.50519700E+04, 0.23857300E+04, 0.34027600E+03, -.22030800E+04, 0.84131400E+03, 0.16713400E+04, 0.16179000E+04, -.11172500E+05, 0.54984500E+04, -.33355500E+04, 0.55850900E+04, 0.38542800E+04, 0.16346000E+04, 0.10215600E+04, -.66630200E+03, 0.53172600E+04, 0.92326500E+03, 0.59248800E+04, -.87098500E+04, 0.43236000E+04, -.46776900E+04, 0.43521300E+04, 0.41750800E+04, 0.16352800E+04, 0.64734100E+03, -.30029300E+02, 0.47840700E+04, 0.88331000E+03, 0.41027400E+04, -.26659400E+04, -.19921000E+04, -.29140500E+04, 0.22534500E+04, 0.13601600E+04, -.97399700E+03, -.17084000E+04, -.13473000E+04, 0.55508100E+03, 0.16013100E+04, -.18136100E+04, -.37677200E+04, -.70067900E+03, 0.89010100E+03, -.27939200E+04, -.20763900E+03, 0.20428800E+04, 0.21499500E+04, -.15888100E+04, -.22451700E+03, -.18722200E+04, 0.19802900E+04, 0.35860000E+04, -.19210500E+04, 0.12545700E+04, -.95687400E+03 },
        { -.73581700E+00, -.29574100E+00, -.20765900E-03, 0.10181500E+01, 0.42645200E+00, -.24383900E+01, -.27061100E+00, -.14662000E+01, -.51136100E+00, 0.40676900E+00, 0.79886300E-02, -.49046200E-01, -.13857600E+01, 0.49107500E+00, -.13600400E+01, -.45271200E-01, 0.12168900E+05, -.60688400E+04, -.75344100E+04, -.57538800E+04, 0.11333700E+05, 0.21344400E+04, 0.33252900E+05, -.15636900E+05, 0.11002200E+05, -.16620500E+05, -.62909400E+04, 0.22756000E+05, -.21974000E+05, -.23950600E+05, -.21176400E+05, 0.21957500E+05, -.25883900E+04, -.51145400E+04, 0.24431700E+04, -.47525700E+05, 0.25168300E+04, 0.37082200E+04, 0.10435600E+05, -.72827100E+04, -.11527900E+05, 0.43861200E+04, 0.86963800E+04, 0.73118100E+04, -.44570900E+05, 0.22087300E+05, -.24760100E+05, 0.22244400E+05, 0.13560200E+05, 0.78862200E+04, -.76994400E+03, -.12256500E+05, 0.10328700E+05, 0.63726900E+04, 0.16716200E+05, -.21044900E+05, 0.11993200E+05, 0.65967400E+04, 0.10510800E+05, 0.17042800E+05, 0.20316500E+05, -.57671100E+04, -.35594700E+04, 0.47234200E+04, 0.15230400E+05, 0.10238800E+05, 0.54769200E+04, -.26499600E+04, -.50266900E+04, -.27787500E+04, 0.62023200E+04, 0.20011200E+05, -.10582000E+05, -.92413400E+04, -.86708700E+03, 0.16946600E+05, 0.27136000E+04, -.31659000E+05, 0.15604500E+05, -.28678300E+04, 0.15798500E+05, 0.12967600E+05, 0.15332000E+05, -.39311300E+04, -.93708800E+04, 0.11755700E+05, 0.13244900E+05, 0.13556200E+05, -.44255500E+05, 0.21266700E+05, 0.88901000E+02, 0.22051100E+05, 0.38313500E+04, 0.10284700E+05, -.35467700E+04, -.19148300E+05, 0.54028800E+04, 0.93400200E+04, 0.20340000E+05, 0.39162200E+05, -.19506400E+05, 0.12168700E+05, -.19546500E+05, -.12756100E+05, -.10301800E+05, -.98022300E+03, 0.67332200E+04, -.83251800E+04, -.90644800E+04, -.12245700E+05, 0.17821600E+04, -.10953800E+04, -.98971000E+03, -.89179300E+03, -.50271700E+02, 0.14669000E+04, -.14470600E+03, 0.28708800E+04, -.95714200E+03, -.36034300E+03, -.54714600E+04, -.22308200E+05, 0.11411600E+05, -.25494200E+05, 0.11107300E+05, 0.13251900E+05, 0.16773900E+05, -.78522400E+04, -.12307500E+05, 0.10103300E+05, 0.13148900E+05, 0.13989400E+05, 0.92557100E+03, -.46425400E+03, 0.37716800E+04, -.45679200E+03, -.17028700E+04, -.37526200E+04, 0.21899000E+04, 0.21469800E+04, -.13534800E+03, -.32530200E+04, -.11122500E+04, -.46969500E+04, 0.34461900E+04, -.23775200E+05, 0.23408800E+04, 0.40458800E+04, 0.65845600E+04, -.14851900E+04, 0.47033500E+04, 0.68856000E+04, 0.28898700E+04, -.18593000E+04, -.15459600E+05, 0.70364300E+04, -.16064900E+05, 0.77262500E+04, 0.18940900E+05, 0.18541100E+05, -.74112900E+04, -.50712300E+04, 0.38380100E+04, 0.15925700E+05, 0.35559800E+04, 0.33224700E+04, -.21031300E+04, 0.36575400E+04, -.16596800E+04, 0.67959200E+04, 0.14217300E+05, -.76010500E+04, -.51733500E+04, -.62727400E+04, 0.12484600E+05, -.26670600E+04, -.62744500E+04, 0.19364400E+04, -.20755700E+05, 0.31347900E+04, 0.19398500E+05, -.18713300E+05, 0.16717100E+05, 0.32322200E+05, 0.13604100E+05, -.19756200E+05, -.21888100E+05, 0.23827900E+05, -.12596300E+05, 0.20454600E+05, -.11910200E+05, -.70112800E+04, -.65504700E+04, 0.26404600E+03, 0.53488000E+04, -.56588700E+04, -.52528600E+04, -.98439300E+04, 0.76859400E+05, -.39290900E+05, 0.12685700E+05, -.38374100E+05, -.33102200E+05, -.32187300E+05, 0.38002100E+04, 0.14189700E+05, -.21975500E+05, -.23881900E+05, -.33917900E+05, 0.46363800E+04, -.32211500E+04, 0.92730800E+03, -.22833600E+04, -.62324700E+04, -.89746900E+04, 0.26222100E+04, -.48119400E+03, -.27136300E+04, -.71403800E+04, -.35455200E+04, -.17082700E+05, 0.77865500E+04, 0.69174900E+04, 0.85106000E+04, 0.72032500E+04, 0.24772200E+04, 0.22773900E+04, -.60468800E+03, 0.35727500E+03, 0.24026900E+04, -.11061500E+04, 0.28602400E+04, -.14687600E+04, -.76360900E+04, -.14231900E+04, -.45867700E+03, 0.16185800E+04, 0.87849800E+03, 0.87894700E+04, 0.33499000E+04, -.21647300E+04, -.96836200E+04, -.39652800E+05, 0.16629000E+05, 0.51925300E+03, 0.19753100E+05, 0.16024000E+05, 0.75535800E+04, 0.15747400E+04, -.73078200E+04, 0.86653800E+03, 0.71237500E+04, -.27101200E+04, -.38962100E+05, 0.17712000E+05, -.24022000E+05, 0.19478900E+05, 0.15331700E+05, 0.62281100E+04, 0.27924200E+04, -.12507900E+04, 0.18002400E+05, 0.42838400E+04, 0.14030800E+05, -.92239100E+04, 0.50721300E+04, -.39983400E+05, 0.45869800E+04, 0.85922800E+04, 0.67772600E+04, -.29592300E+04, -.27060200E+04, 0.99304700E+04, 0.46729900E+04, 0.61150200E+04, -.29418400E+04, -.27372700E+04, -.77818400E+04, 0.13554300E+05, 0.13738500E+04, -.86186600E+04, -.14426900E+05, -.41065000E+04, 0.80151200E+04, 0.13322000E+05, -.12419700E+05, -.45769400E+04, -.45463300E+04, 0.51553200E+04, -.31597700E+04, 0.45689600E+04, 0.46869600E+04, 0.14121100E+05, 0.29403700E+03, -.73012200E+04, -.34860200E+04, 0.14161900E+05, 0.41771100E+04, -.14010600E+05, -.29543200E+04, 0.15736900E+04 },
        { -.45998300E+00, -.14667200E+00, -.57220800E-02, -.19168300E+00, -.13824800E-01, 0.77455500E-02, -.97346100E+00, 0.48032800E+00, -.38242000E+00, 0.33819900E+00, -.12558000E-01, -.25274400E-01, -.38142000E+00, 0.67270200E+00, -.29874400E-01, -.43836100E+00, 0.28625300E+00, 0.62661900E+04, 0.60299300E+04, 0.12973300E+04, -.44824200E+03, -.59473200E+04, -.85163700E+04, 0.46005600E+04, -.16604500E+05, 0.42575400E+04, -.12805100E+04, 0.19114800E+04, 0.88844400E+04, 0.10984900E+05, 0.60614000E+04, 0.10221700E+04, -.15871900E+04, 0.23916000E+05, -.11908700E+05, 0.33058600E+04, -.11953100E+05, -.24562900E+03, 0.12477300E+04, -.28361500E+04, 0.10436300E+04, -.74638000E+04, 0.29496900E+03, -.11638700E+05, -.52060700E+04, 0.25213900E+04, 0.17032600E+05, 0.26079900E+04, 0.11960900E+04, -.12356100E+04, 0.11721600E+05, 0.11212400E+05, 0.76200000E+04, -.29309600E+04, -.44843300E+04, -.25739900E+05, 0.13231500E+05, -.56981200E+03, 0.12871400E+05, 0.67290400E+03, -.23967200E+04, 0.14536800E+05, 0.11029200E+05, 0.13874600E+05, -.25758300E+04, 0.39625400E+04, -.20081100E+05, 0.10039200E+05, 0.35210300E+04, 0.10045400E+05, 0.26341600E+04, 0.43688300E+04, 0.25302900E+04, -.85537300E+03, 0.63657200E+04, 0.34695400E+04, 0.55355000E+04, -.31161400E+05, 0.15500700E+05, 0.92137300E+04, 0.15584500E+05, 0.47355600E+04, 0.27161300E+04, 0.91481000E+04, 0.54783900E+04, 0.13567500E+05, 0.20105600E+04, 0.62615700E+04, -.32785300E+05, 0.16094500E+05, 0.10013100E+05, 0.16401700E+05, 0.20077300E+04, 0.14799600E+04, 0.22252200E+05, 0.16920600E+05, 0.21747600E+05, -.16905000E+04, 0.39699600E+04, 0.22735200E+05, -.11316000E+05, -.21255600E+05, -.11371600E+05, -.45068100E+04, -.47985200E+03, -.15108000E+05, -.99603400E+04, -.11349100E+05, 0.67953800E+03, -.15150500E+04, 0.11560300E+05, -.57629400E+04, -.28139600E+04, -.57800500E+04, -.83227300E+03, -.26483400E+04, 0.62832500E+04, 0.96180900E+04, 0.12683200E+04, -.29766600E+04, -.78656700E+04, -.16155300E+05, 0.82349100E+04, 0.10093600E+05, 0.80833400E+04, 0.69497400E+04, 0.89010700E+04, 0.22155700E+04, 0.47485800E+04, 0.61850400E+04, 0.69935800E+04, 0.27205000E+04, 0.35790000E+04, -.17996200E+04, -.18930500E+04, -.17902300E+04, -.66122700E+03, -.50875000E+03, -.16488700E+04, -.13877200E+04, -.17473100E+04, -.34960700E+03, -.38951800E+03, 0.52099900E+04, -.18568700E+04, 0.36140900E+04, -.26042100E+04, 0.33389100E+04, 0.29310400E+04, 0.91857500E+04, 0.15828200E+05, 0.66650200E+04, 0.12296200E+04, -.97396900E+04, -.23741800E+05, 0.11260900E+05, 0.68415600E+04, 0.11871300E+05, 0.47222600E+03, -.20300400E+04, 0.82627900E+04, 0.46851900E+04, 0.97672500E+04, -.25483100E+04, 0.62296800E+04, -.11803800E+05, 0.55734900E+04, 0.18518800E+04, 0.59017800E+04, -.46377600E+04, -.75819500E+04, 0.10101600E+05, 0.55697000E+04, 0.64173100E+04, -.67785700E+04, 0.26223800E+04, -.17284000E+05, 0.82671700E+04, 0.32503700E+05, 0.86422000E+04, 0.30821100E+04, -.59168000E+04, 0.44441500E+04, -.40349300E+03, 0.67396100E+04, -.48371300E+04, 0.46002100E+04, -.34440200E+04, 0.10892900E+04, -.24473400E+04, 0.17216100E+04, -.24938400E+04, -.42133000E+04, -.70742700E+04, -.10426300E+05, -.40179700E+04, -.23053800E+04, 0.86925200E+04, 0.28520400E+05, -.14509200E+05, -.17423500E+05, -.14266800E+05, -.97618100E+03, 0.33477900E+04, -.20971800E+05, -.17388200E+05, -.15692100E+05, 0.35298900E+04, -.80575300E+03, 0.14723600E+04, -.99642900E+03, 0.53112300E+03, -.74039600E+03, -.23984300E+04, -.25324600E+04, 0.34315600E+04, 0.37694200E+04, 0.25913300E+04, -.22923400E+04, -.54137800E+03, -.36633200E+05, 0.18081000E+05, 0.14871800E+05, 0.18320300E+05, 0.27486200E+04, 0.43259500E+03, 0.14821700E+05, 0.55615200E+04, 0.16696900E+05, -.62583800E+03, 0.10172800E+05, 0.13899600E+05, -.67850500E+04, -.23666600E+04, -.69506300E+04, 0.84884400E+03, -.16582200E+04, 0.10721000E+05, 0.17645100E+05, 0.50974700E+04, -.26702400E+04, -.12268900E+05, -.85826200E+05, 0.41818300E+05, 0.40711800E+05, 0.42922000E+05, 0.68224200E+04, 0.39759700E+02, 0.41630300E+05, 0.22332900E+05, 0.42867600E+05, -.28475800E+04, 0.19180800E+05, -.18745600E+05, 0.88064400E+04, 0.20154300E+05, 0.93732700E+04, 0.41525700E+04, 0.11820200E+04, 0.46892900E+04, 0.23067300E+04, 0.58449500E+04, 0.10151300E+04, 0.44835600E+04, 0.12309800E+05, -.58288700E+04, 0.42272300E+04, -.61518000E+04, 0.37975700E+04, 0.45482200E+04, -.60975100E+04, -.17703900E+04, -.63481800E+04, 0.36954900E+04, -.71659000E+04, -.56145100E+04, -.32405500E+04, 0.18099400E+04, 0.38901700E+04, 0.55567800E+04, -.32583300E+04, 0.11752200E+04, -.34435900E+04, 0.22873200E+04, 0.25533000E+04, 0.94878300E+03, -.29828800E+04, 0.25189900E+04, 0.12962000E+04, -.30505600E+04, -.40142500E+04, 0.17435700E+04, 0.43943300E+04, -.14274800E+04, 0.13324600E+04, -.24840200E+04, -.24151000E+04, 0.35797500E+04, 0.11059000E+03, 0.43867500E+04, -.63087600E+04 },
        { -.75281200E+00, 0.83960500E+00, 0.98618500E-01, 0.13856300E+00, -.12235700E+00, 0.10344300E+01, -.19887200E+01, 0.16611900E+01, -.79795500E+00, 0.47467600E+00, -.68992300E-02, -.75011700E-01, -.11301400E+01, 0.24103700E+01, -.13341200E+01, -.15846700E+01, 0.63748100E+00, 0.25318100E+00, -.42185300E+04, -.29380700E+04, 0.89838000E+03, 0.16603900E+04, -.15431200E+05, 0.89442800E+04, 0.89396700E+04, 0.77137000E+04, 0.19210700E+04, -.11249800E+04, 0.59066900E+04, 0.84711600E+03, 0.30214700E+04, 0.11144800E+04, 0.46501500E+04, -.17070700E+03, -.62677600E+02, 0.25771400E+04, 0.88882900E+02, -.41987800E+04, -.63891000E+04, 0.52584200E+04, 0.29298200E+04, 0.19967100E+04, -.50454100E+04, 0.40728400E+04, -.14171400E+05, 0.67804300E+04, 0.86575400E+04, 0.70897300E+04, -.47628200E+04, -.51976700E+04, 0.81634800E+04, -.52968100E+03, 0.44491900E+04, -.32426500E+04, 0.12284900E+05, -.28039400E+04, 0.32923300E+04, 0.28708700E+04, 0.14026100E+04, -.13621800E+04, -.23210400E+04, 0.30088600E+04, -.73027500E+03, 0.10540300E+03, -.89783700E+03, 0.24977400E+03, 0.13551400E+04, -.55298900E+03, -.61593700E+03, -.67338600E+03, -.33303200E+04, -.36893600E+04, -.48681800E+03, -.17828500E+04, -.15476400E+04, -.27460200E+04, 0.31681000E+04, 0.55205000E+04, -.30499200E+04, -.93247800E+03, -.27575400E+04, -.44740500E+04, -.33017700E+04, -.91486000E+03, -.10010900E+04, -.14920800E+04, -.24153800E+04, 0.44151400E+04, -.21928300E+05, 0.98840100E+04, 0.15848000E+05, 0.10974600E+05, -.44102500E+04, -.56198500E+04, 0.10337200E+05, -.41845900E+04, 0.67582900E+04, -.35287900E+04, 0.16143000E+05, -.16045200E+04, 0.10610200E+04, 0.31056900E+03, 0.79583500E+03, 0.56027600E+04, 0.63835700E+04, -.24741100E+04, 0.43320400E+04, 0.19862500E+04, 0.52684900E+04, -.61977200E+04, -.10681400E+05, 0.50295700E+04, 0.51937200E+04, 0.53407500E+04, -.17217900E+04, -.56489300E+04, 0.75285700E+04, 0.50750200E+03, 0.55956300E+04, -.43579700E+04, 0.59068600E+04, -.25978700E+04, 0.16213200E+04, 0.39847800E+04, 0.13032700E+04, -.31220100E+04, -.34720400E+04, 0.12403300E+04, 0.18031000E+04, 0.10818500E+04, -.23147200E+04, 0.52998500E+04, 0.52978400E+01, -.22728100E+01, -.49090300E+03, -.31859700E+01, 0.72212600E+03, 0.73107900E+03, -.31837200E+03, 0.35964700E+02, -.83810200E+02, 0.56157300E+03, -.88260500E+03, -.79811200E+03, 0.17711700E+04, 0.62389900E+04, 0.40201000E+03, -.52128800E+04, -.96390400E+04, 0.66900400E+04, 0.82787600E+03, 0.54672600E+04, -.75518300E+04, 0.49697800E+04, -.61023600E+04, 0.21531700E+04, 0.43163900E+04, 0.30516500E+04, -.38683300E+04, -.26963700E+04, 0.24508000E+04, 0.14032400E+04, 0.22640300E+04, -.15959900E+04, 0.70612000E+04, -.46596300E+04, 0.18290900E+04, 0.21943900E+04, 0.23297400E+04, -.19684500E+04, 0.54826200E+03, 0.27705100E+04, 0.53505200E+03, 0.49051200E+03, 0.75144700E+03, 0.31400200E+04, 0.12113300E+05, -.76882800E+04, -.12904900E+05, -.60543400E+04, -.72456800E+04, -.30426800E+04, -.22702500E+04, 0.24740600E+04, 0.84192300E+03, -.40677900E+04, 0.43958800E+04, 0.25756300E+04, -.22859300E+04, -.53658400E+04, -.12890000E+04, 0.28001900E+04, 0.48778700E+04, -.39705800E+04, 0.34403200E+04, -.37339500E+03, 0.32325500E+04, -.38516400E+04, 0.99034600E+03, -.16224600E+04, -.51429300E+04, -.50269300E+03, 0.47406300E+04, 0.37784000E+04, -.41154900E+04, 0.14908400E+04, 0.23168800E+04, 0.20053700E+04, -.36392700E+04, 0.17791200E+04, -.20021600E+04, -.16456300E+04, -.89283300E+03, -.47606800E+03, 0.67913300E+03, 0.12858800E+04, 0.20912200E+04, 0.10997400E+04, 0.88217800E+02, -.11224200E+03, 0.38502700E+04, -.29768700E+04, -.22760600E+04, -.19220700E+04, -.41334100E+04, -.28187300E+04, 0.76103500E+03, -.26486700E+04, -.20424900E+04, -.28984500E+04, 0.43557200E+04, -.91214700E+04, 0.44066600E+04, 0.67692400E+04, 0.45597200E+04, -.42694300E+04, -.10760300E+05, 0.10802400E+05, 0.21485900E+04, 0.89826700E+04, -.85628400E+04, 0.83787800E+04, -.16379600E+04, -.34934500E+04, 0.43645100E+03, 0.82674500E+03, -.12196300E+05, -.10073400E+05, 0.71576300E+04, -.59086500E+04, 0.43117700E+03, -.89998600E+04, 0.19490700E+05, 0.66737000E+04, -.56536900E+04, -.18344600E+04, -.33399000E+04, -.46780300E+04, -.30475800E+04, -.16608100E+04, 0.39634500E+03, -.14423300E+04, -.29863800E+04, 0.24255300E+04, 0.47527500E+04, -.18018400E+04, -.18362700E+03, -.23757600E+04, -.26908600E+04, -.39077200E+04, 0.63348900E+03, 0.32913500E+04, 0.33568600E+02, -.31446200E+04, 0.13840800E+04, 0.77833000E+02, 0.12312700E+04, 0.93835200E+03, -.44839300E+03, -.24744500E+04, 0.37740600E+04, -.35113600E+03, 0.69854200E+03, -.84325000E+03, -.24367600E+04, 0.28442700E+04, 0.35807500E+04, -.68612800E+03, -.14203400E+04, 0.26424500E+04, 0.35149900E+03, -.16901300E+04, 0.30285100E+03, 0.23407400E+04, -.66683800E+03, 0.15637600E+04, -.68746300E+04, -.27996500E+04, 0.56838900E+04, 0.43836300E+03, 0.13908400E+04 },
        { 0.13361000E+00, -.10687500E+01, -.90027600E-01, -.35580200E+00, -.29586300E+00, -.12342600E+01, 0.54929400E+00, -.35421900E+00, 0.23906800E+00, -.23887700E+00, 0.12812900E-01, 0.61509700E-01, -.23308900E+00, 0.25501200E+00, 0.60198400E+00, 0.46381300E+00, 0.38419500E+00, 0.14784800E+00, -.36991900E+00, -.19509900E+04, 0.82710900E+03, 0.52865000E+03, -.88485700E+04, 0.41634300E+04, -.15709000E+05, 0.44235000E+04, 0.23806200E+04, 0.26903300E+04, 0.99645000E+03, 0.13392500E+04, 0.62182000E+03, 0.55852200E+04, 0.49361800E+04, -.16339100E+05, 0.87907500E+04, 0.17393600E+05, 0.81775200E+04, 0.72650500E+04, -.19748100E+04, 0.34684700E+04, 0.12264200E+03, 0.77753500E+04, -.24028900E+04, 0.39733900E+04, -.43050900E+05, 0.21776700E+05, 0.27257200E+05, 0.21533400E+05, 0.96781600E+04, 0.98538300E+03, 0.51025000E+04, -.79223900E+04, 0.12003100E+05, 0.12997100E+04, 0.15615300E+05, -.27013800E+05, 0.12342300E+05, -.42476800E+04, 0.13509300E+05, 0.95045700E+04, 0.59992600E+04, 0.13789500E+03, -.37007000E+04, 0.73374100E+04, 0.73249500E+04, 0.15305200E+05, -.36987800E+05, 0.18532200E+05, 0.87311200E+04, 0.18501600E+05, 0.99832500E+04, 0.55169900E+04, 0.24548700E+04, -.44610000E+04, 0.13072200E+05, 0.41504200E+04, 0.17571200E+05, -.38930400E+05, 0.19684500E+05, 0.68954500E+04, 0.19471300E+05, 0.11189000E+05, 0.36366700E+04, 0.29811200E+04, -.42128800E+04, 0.14692300E+05, 0.25259300E+04, 0.20308100E+05, -.58500200E+05, 0.29946600E+05, 0.16702900E+05, 0.29264100E+05, 0.79322700E+04, 0.32057600E+04, 0.64450100E+04, -.11259600E+05, 0.14507700E+05, 0.44490700E+04, 0.25704700E+05, 0.28050600E+05, -.14166300E+05, -.19104500E+05, -.14031100E+05, -.76199800E+04, -.33172300E+04, -.95794500E+03, 0.62805500E+04, -.79111500E+04, -.10430100E+04, -.16699900E+05, 0.14601700E+05, -.75635000E+04, -.25839600E+04, -.73007100E+04, -.21881500E+04, -.35872700E+04, 0.82170900E+03, 0.56882100E+04, -.25685100E+04, -.28656000E+04, -.75097000E+04, -.40516200E+05, 0.20627400E+05, 0.14636300E+05, 0.20267200E+05, 0.15955000E+05, 0.84147600E+04, 0.18395100E+04, -.35125700E+04, 0.15387300E+05, 0.63772800E+04, 0.20293100E+05, 0.55750700E+04, -.28566400E+04, -.19201100E+04, -.27887100E+04, -.17162700E+04, -.34566000E+03, -.56811200E+03, 0.43674800E+03, -.20885600E+04, -.20837000E+03, -.27562800E+04, 0.13721600E+05, -.59296600E+04, 0.38604100E+04, -.68599500E+04, 0.19246900E+04, 0.73868900E+03, -.13907000E+04, 0.58916500E+04, -.15391200E+04, 0.42821800E+03, -.63050300E+04, -.29425600E+05, 0.13579700E+05, 0.98704600E+01, 0.14713400E+05, 0.25444500E+04, -.61597800E+04, 0.63155300E+04, -.15269100E+04, 0.12715900E+05, -.55942700E+04, 0.14486800E+05, -.91431400E+04, 0.38651900E+04, -.43448900E+02, 0.45711100E+04, -.48581800E+04, -.86037400E+04, 0.46946800E+04, -.64098700E+03, 0.26898000E+04, -.61140000E+04, 0.40922900E+04, 0.23607000E+04, -.63629800E+03, 0.24705100E+05, -.11804900E+04, -.26206400E+03, -.42902300E+04, 0.65228800E+02, -.21288500E+04, 0.26044200E+04, -.75877600E+04, -.36495900E+04, 0.41296900E+04, -.32031500E+04, -.98419500E+03, -.20653300E+04, -.63689500E+04, -.64433400E+04, 0.20920700E+04, -.48014400E+03, -.21066600E+04, -.51694700E+04, -.28707900E+04, 0.43409300E+05, -.21336200E+05, -.13353300E+05, -.21714800E+05, -.18002900E+05, -.10964400E+05, 0.74242100E+03, 0.85567200E+04, -.10177800E+05, -.11310000E+05, -.21246600E+05, 0.11156900E+05, -.51135600E+04, -.34426600E+04, -.55852400E+04, -.52795500E+04, -.30834500E+04, 0.21661700E+03, 0.96513100E+03, -.32169500E+04, -.27906300E+04, -.67886100E+04, -.22197800E+05, 0.11674200E+05, 0.85857100E+04, 0.11104800E+05, 0.29161000E+04, 0.24289500E+04, 0.62806700E+03, -.62847000E+04, 0.59146800E+04, 0.35401600E+03, 0.12499700E+05, 0.27330600E+05, -.13824000E+05, -.28358200E+04, -.13666600E+05, -.31210600E+04, -.48987300E+04, 0.44250600E+03, 0.10147700E+05, -.48318800E+04, -.40395800E+04, -.13901600E+05, -.58677800E+05, 0.31184300E+05, 0.24308800E+05, 0.29352900E+05, 0.79936200E+04, 0.40800400E+04, 0.36342100E+04, -.14645700E+05, 0.16196800E+05, -.30430400E+02, 0.30965500E+05, -.26441300E+05, 0.14254700E+05, 0.16946300E+05, 0.13222000E+05, 0.79853300E+04, 0.78653200E+03, 0.20594100E+04, -.45640000E+04, 0.10136400E+05, -.13380100E+04, 0.13444000E+05, -.15105700E+05, 0.82081000E+04, 0.11763700E+05, 0.75582400E+04, 0.92456000E+04, 0.64610200E+03, 0.16534600E+04, 0.98149400E+03, 0.88072500E+04, -.52620700E+03, 0.65082000E+04, -.74044300E+04, -.49450000E+04, -.40471100E+04, 0.61167200E+04, 0.34626200E+04, -.14199400E+04, -.55063900E+04, -.31540800E+04, 0.40614700E+03, 0.41684900E+04, -.26622000E+04, -.48781500E+04, -.10867800E+04, 0.14647200E+04, -.60373400E+04, -.49420100E+04, 0.43278600E+04, 0.75104200E+04, -.57179100E+04, -.29651500E+04, -.42018600E+04, 0.21218000E+04, 0.56003400E+04, -.21910200E+04, 0.56743200E+04, -.39155600E+04 },
        { -.60941100E+00, 0.43714400E+00, -.11967700E-01, -.11202500E+00, 0.32593100E-01, 0.27058000E+01, -.19525000E+01, 0.85159500E+00, -.66720800E+00, 0.11909600E+01, 0.14748700E-01, -.14196200E+00, 0.35372000E+00, -.47670600E+00, -.16244100E+01, -.97673000E+00, -.13046500E+01, -.73048800E+00, 0.44603000E+00, -.10665800E+01, -.28351500E+04, 0.72357200E+04, -.19373500E+03, 0.16798500E+04, 0.31656600E+05, 0.10450500E+03, -.13606900E+05, -.57916900E+04, -.25539200E+03, -.72984500E+04, -.10589000E+04, -.11263500E+05, 0.22735900E+05, -.11908300E+05, 0.50780900E+04, -.57632100E+05, 0.59255600E+04, 0.97729800E+04, 0.14201900E+04, 0.21913800E+04, 0.50337200E+04, 0.96060500E+04, -.21189800E+04, 0.76416500E+04, 0.24922700E+05, -.13033200E+05, -.66420600E+05, -.12491500E+05, 0.33707900E+04, 0.10544600E+05, -.12008900E+05, -.52163300E+04, -.80306400E+04, 0.69881600E+04, 0.40204000E+04, 0.16738900E+05, -.50960900E+04, -.10900200E+05, -.83767500E+04, 0.18635100E+04, 0.14157000E+05, -.89140300E+04, -.23925500E+04, -.79025800E+04, 0.62381700E+04, 0.98998800E+04, 0.46325100E+04, -.22516400E+04, -.11705900E+05, -.23463900E+04, 0.44270900E+04, 0.37839900E+04, -.26104700E+04, 0.13847400E+04, 0.97483600E+03, -.65364900E+01, 0.18103800E+04, -.19961800E+05, 0.94251800E+04, -.15710200E+05, 0.99589700E+04, 0.70879100E+04, 0.79827300E+04, -.36829600E+04, -.80505800E+04, 0.53166900E+04, 0.50538500E+04, 0.13825300E+05, 0.41800100E+05, -.22862900E+05, -.36770400E+05, -.20963600E+05, -.11515200E+05, 0.30956800E+04, -.13942000E+05, -.76830700E+04, -.12904400E+05, -.16491700E+04, 0.77449200E+04, -.12605000E+05, 0.65918400E+04, 0.39931800E+05, 0.63355200E+04, -.57842000E+04, -.59075300E+04, 0.42832500E+04, 0.86500500E+03, 0.51805100E+04, -.53271600E+04, 0.48645300E+04, 0.33577800E+05, -.16711400E+05, -.16030100E+05, -.16789400E+05, -.87527900E+03, 0.22067700E+04, -.74661400E+04, 0.53566500E+03, -.90001300E+04, -.11927400E+04, -.12557800E+05, -.13533500E+05, 0.66516500E+04, -.40251900E+05, 0.67330500E+04, 0.87034400E+04, 0.58449200E+04, -.33997500E+04, -.26166600E+04, 0.63463500E+04, 0.76357100E+03, 0.11076000E+05, 0.13491400E+04, -.59366900E+03, 0.50273500E+04, -.67030000E+03, -.14193900E+04, -.14046500E+04, 0.69417900E+03, 0.92790800E+02, -.57059000E+03, -.62208900E+03, -.17979200E+04, 0.58229100E+03, -.25148300E+03, -.48423400E+05, -.30225000E+03, 0.87312800E+04, 0.78436500E+04, -.67649900E+04, -.31903900E+04, 0.26271600E+04, 0.95957400E+03, 0.75796100E+04, -.13132000E+05, 0.70043900E+04, -.28750100E+05, 0.65630700E+04, 0.19957900E+05, 0.28263400E+05, -.12905600E+05, -.10047500E+05, -.12092300E+04, 0.23399800E+05, 0.10781400E+05, 0.93550100E+04, -.44228700E+04, 0.31728100E+04, -.46755600E+04, 0.60866300E+04, 0.16672200E+05, -.79431900E+04, -.29439200E+04, -.68323500E+04, 0.12866400E+05, 0.25577900E+04, 0.73151000E+05, -.38787000E+05, -.65712800E+05, -.36582600E+05, 0.18531000E+05, 0.23856300E+05, -.21702100E+05, 0.58307700E+04, -.29461300E+05, 0.27182800E+05, -.49418700E+05, 0.15101900E+05, -.70697900E+04, 0.42556200E+05, -.75461400E+04, -.66725300E+04, 0.26952000E+04, -.23723200E+04, 0.75834800E+03, -.96348700E+04, 0.58569700E+04, -.15878200E+05, 0.27492000E+05, -.15270200E+05, 0.52433000E+05, -.13700000E+05, -.15488400E+05, -.25170200E+05, 0.75273400E+04, 0.11637500E+05, -.66256600E+04, -.13722800E+05, -.35517300E+05, 0.53864200E+04, -.43784400E+04, 0.63980700E+04, -.26680200E+04, -.48477100E+04, -.87415100E+04, 0.38379000E+04, 0.36872200E+04, 0.18034700E+04, -.61201900E+04, -.34820100E+04, 0.22337500E+05, -.12855600E+05, -.79554800E+04, -.11191400E+05, 0.14336400E+04, 0.10083200E+03, -.15478200E+04, 0.53222900E+04, -.79786800E+04, 0.17244300E+04, -.14783700E+05, 0.38587400E+05, -.19232700E+05, -.33155100E+05, -.19287700E+05, 0.19459800E+04, 0.68427700E+04, -.12645600E+05, -.23816400E+04, -.98593400E+04, -.23106200E+03, -.12897900E+05, 0.75950900E+05, -.44373100E+05, -.45302300E+05, -.38030700E+05, -.30002000E+02, 0.42848100E+04, -.13936800E+05, 0.44272900E+04, -.28099000E+05, 0.55114100E+04, -.32545900E+05, -.32936100E+05, 0.12968200E+05, -.41097100E+05, 0.16474600E+05, 0.16651800E+05, 0.12640700E+05, -.20861800E+04, -.60290900E+04, 0.10060400E+05, 0.12048400E+05, 0.10637400E+05, -.17123100E+05, 0.83757600E+04, -.50662300E+05, 0.85478600E+04, 0.12988500E+05, 0.75063200E+04, -.17946300E+04, -.59396300E+03, 0.60206400E+04, 0.41088500E+04, 0.71212400E+04, -.42294900E+04, -.44755800E+04, -.51922100E+04, 0.41556200E+04, -.99349000E+03, -.17991800E+04, -.61017100E+04, -.40406900E+04, 0.57557500E+04, 0.34750100E+04, -.87660100E+04, -.95946900E+04, -.24796700E+04, 0.39250800E+04, -.56670200E+04, 0.59920300E+04, 0.61020100E+04, 0.21258300E+04, 0.25651300E+04, 0.12998000E+04, -.41303000E+04, 0.11324900E+05, 0.93533800E+04, -.96795400E+04, -.30744300E+04, 0.21478300E+04 },
        { -.31676900E+01, 0.15795500E+01, 0.13269300E+00, 0.30737400E+00, 0.26572600E-01, -.29592500E+00, -.31370500E+01, -.26461000E+01, -.17288500E+01, 0.18999100E+01, 0.42066000E+00, -.17553900E+00, 0.16057300E+01, -.16256200E+01, -.40057800E+00, -.46116500E+01, -.93007000E+00, 0.80289400E+00, 0.65065500E+00, -.24265700E+01, -.16133800E+00, 0.35060900E+05, -.59495600E+05, 0.30763300E+05, 0.22262800E+05, 0.29758700E+05, -.20104200E+05, -.12683700E+03, 0.10381000E+05, -.10268800E+05, 0.13729600E+05, 0.50017700E+04, 0.13041100E+06, -.88099400E+05, 0.43747600E+05, -.28319800E+05, 0.44124600E+05, 0.36949000E+05, 0.68098000E+04, 0.11364000E+05, -.34797200E+04, 0.40160900E+05, 0.18416300E+04, 0.22979500E+05, -.11531000E+06, 0.57279000E+05, -.81191900E+04, 0.57723100E+05, 0.36574800E+05, 0.13542500E+05, 0.32743000E+04, -.29371000E+05, 0.33110700E+05, 0.11840600E+05, 0.56518300E+05, -.74380200E+05, 0.38864900E+05, -.13613500E+05, 0.37217900E+05, 0.20981600E+05, 0.29973700E+05, -.49331800E+04, -.14191900E+05, 0.17876600E+05, 0.26213800E+05, 0.10125600E+06, -.92034600E+05, 0.45961200E+05, 0.40535500E+04, 0.46081000E+05, 0.28165300E+05, 0.22362300E+05, 0.19065600E+04, -.15908100E+05, 0.35131000E+05, 0.15680900E+05, 0.57958200E+05, -.15655000E+06, 0.77908600E+05, 0.52806800E+04, 0.78332300E+05, 0.37172800E+05, 0.17169200E+05, 0.10764200E+05, -.24212300E+05, 0.54569600E+05, 0.11974500E+05, 0.86175800E+05, -.13449600E+06, 0.66032500E+05, 0.12518300E+05, 0.67328500E+05, 0.97229400E+04, 0.78305700E+04, 0.67564900E+04, -.37650900E+05, 0.37300900E+05, 0.88583600E+04, 0.11611600E+06, 0.51824000E+05, -.25631800E+05, 0.13407400E+05, -.25920400E+05, -.33661600E+05, -.14377900E+05, 0.40630100E+04, 0.10830900E+05, -.18061600E+05, -.75266700E+04, -.29959600E+05, 0.93382200E+05, -.46438900E+05, -.33327800E+05, -.46689800E+05, -.38509900E+04, -.48345700E+04, -.13559000E+05, 0.14602700E+05, -.18083200E+05, -.83926500E+04, -.32532800E+05, -.14217800E+06, 0.71162100E+05, -.13568700E+05, 0.71171700E+05, 0.51320100E+05, 0.31358000E+05, 0.51220300E+04, -.15806800E+05, 0.53044000E+05, 0.22467600E+05, 0.80800200E+05, 0.16517100E+05, -.82296800E+04, 0.27416500E+04, -.82694100E+04, -.61891800E+04, -.35073000E+04, -.31796300E+03, 0.22128000E+04, -.62331400E+04, -.24295700E+04, -.12229500E+05, 0.83706800E+04, -.28251600E+04, -.65917700E+05, -.42085400E+04, 0.29105100E+05, 0.20820600E+05, -.15224100E+05, 0.46987200E+03, 0.79820200E+04, 0.10370700E+05, 0.18514900E+05, -.10895100E+06, 0.53735900E+05, -.39210100E+05, 0.54479600E+05, 0.31297600E+05, 0.12924500E+05, 0.58174400E+04, -.16402300E+05, 0.42208200E+05, 0.10870200E+05, 0.68536200E+05, -.82503200E+04, 0.38534800E+04, 0.78259400E+04, 0.41260100E+04, -.50550700E+04, -.18234900E+04, -.16952300E+03, -.73581400E+04, -.16389600E+04, 0.73542800E+03, 0.30760100E+05, 0.11388500E+06, -.58223700E+05, -.34461600E+05, -.56972300E+05, 0.36447800E+05, 0.10292700E+05, -.30165300E+05, 0.50266300E+04, -.36586500E+05, 0.22460500E+04, -.16038400E+06, 0.35215100E+05, -.18416200E+05, 0.68857400E+05, -.17600400E+05, -.28834800E+05, -.13573500E+05, 0.27836100E+04, -.12538800E+04, -.27634300E+05, -.70828500E+04, -.51590000E+05, 0.20446200E+06, -.10307400E+06, 0.22172200E+05, -.10229100E+06, -.66836500E+05, -.60595000E+05, 0.38574700E+04, 0.46194000E+05, -.49169400E+05, -.49422100E+05, -.15600200E+06, 0.46066900E+05, -.23984700E+05, -.14574100E+04, -.23094200E+05, -.18250000E+05, -.16970800E+05, 0.37440600E+03, 0.46036900E+04, -.10312000E+05, -.14314300E+05, -.35086000E+05, -.11106900E+04, -.40150300E+03, -.51162500E+03, 0.60613700E+03, 0.10717300E+05, 0.36110900E+04, -.76717800E+04, -.88668800E+04, -.10191800E+04, 0.33525500E+03, -.12353700E+05, 0.11221400E+06, -.55502400E+05, -.57940200E+05, -.56113000E+05, 0.47449400E+04, 0.20173400E+04, -.21898400E+05, 0.15043000E+05, -.20044700E+05, -.66151300E+04, -.41965000E+05, -.30617200E+05, 0.11376700E+05, -.87906100E+04, 0.15422200E+05, 0.30871100E+05, 0.10085700E+05, -.17744600E+05, -.31026600E+05, 0.40929000E+04, 0.98217700E+03, 0.25874000E+04, -.11374900E+06, 0.54735100E+05, -.22585700E+05, 0.56931400E+05, 0.47099700E+05, 0.19005600E+05, 0.13914200E+04, -.23181400E+05, 0.38909800E+05, 0.12251800E+05, 0.29544400E+05, -.91456400E+05, 0.46060900E+05, -.33066500E+05, 0.45800000E+05, 0.43609300E+05, 0.15300400E+05, 0.63669200E+04, -.46251300E+04, 0.38929300E+05, 0.94820800E+04, 0.28220500E+05, -.25569200E+05, -.19093300E+05, -.15475200E+05, 0.19048100E+05, 0.90323700E+04, -.65681100E+04, -.27495600E+05, -.15462300E+05, 0.98536100E+04, 0.17760600E+05, -.18522800E+05, -.30789200E+05, -.95276500E+04, 0.86189400E+04, -.23417800E+05, -.22778800E+04, 0.19794400E+05, 0.24537300E+05, -.76369100E+04, -.10916000E+05, -.16970000E+05, 0.21126100E+05, 0.30964900E+05, -.18264600E+05, 0.10147600E+05, -.52269800E+04 },
        { 0.36756700E+01, 0.78916200E+01, 0.98897800E+00, 0.34196900E+01, -.10348000E+01, -.20794300E+01, 0.73372500E+01, 0.26620400E+00, 0.30051000E+01, -.36104400E+01, -.35027800E+00, 0.31083800E+00, 0.45186100E+01, -.91839900E+01, 0.52337700E+01, 0.27341000E+01, -.13766900E+01, -.14592100E+01, -.23941000E+01, 0.20145100E+01, -.16734500E+01, 0.27100200E-01, 0.12111200E+06, -.66035500E+05, -.27264300E+05, -.60552100E+05, -.14752300E+04, 0.10244600E+05, -.38187800E+05, -.18850600E+05, -.44246200E+05, 0.24633600E+03, -.45553000E+05, 0.13038400E+06, -.65090900E+05, -.11603500E+05, -.65336200E+05, -.64323700E+05, -.36175800E+05, 0.51248900E+04, 0.24979900E+05, -.35074500E+05, -.29284800E+05, -.50028400E+05, 0.17448300E+06, -.85929200E+05, -.35559100E+05, -.87381700E+05, -.56096800E+05, -.13906900E+05, -.14936900E+05, 0.17923500E+05, -.63363700E+05, -.14849300E+05, -.69049600E+05, 0.15167300E+06, -.83232300E+05, -.10572500E+05, -.75883000E+05, -.38910100E+05, -.73870100E+04, -.15665400E+05, 0.14705400E+05, -.56885200E+05, -.12928300E+05, -.67637800E+05, 0.20127600E+06, -.10098000E+06, -.43649200E+05, -.10077300E+06, -.52910300E+05, -.34681300E+05, -.11488800E+05, 0.32135200E+05, -.57954500E+05, -.27129300E+05, -.86135600E+05, 0.22088900E+06, -.10910100E+06, -.27764900E+05, -.11055500E+06, -.61934700E+05, -.20180600E+05, -.23483000E+05, 0.19315700E+05, -.77009600E+05, -.13402000E+05, -.99097400E+05, 0.24962200E+06, -.12040600E+06, -.62942700E+05, -.12503500E+06, -.40284000E+05, -.37649800E+03, -.35137100E+05, 0.23812000E+05, -.80328900E+05, -.76563800E+04, -.94698600E+05, -.46985600E+05, 0.22163600E+05, 0.22199200E+03, 0.23572000E+05, 0.42874300E+05, 0.11034100E+05, -.12471400E+05, -.12350100E+05, 0.27323900E+05, -.20365900E+04, 0.32761000E+05, -.18883400E+06, 0.94117700E+05, 0.64239900E+05, 0.94414600E+05, 0.67497100E+04, 0.77082600E+04, 0.29272200E+05, -.35545300E+05, 0.43258600E+05, 0.93059500E+04, 0.77206200E+05, 0.24232900E+06, -.12290600E+06, -.38941100E+05, -.12132800E+06, -.84352000E+05, -.42609500E+05, -.14912400E+05, 0.33124200E+05, -.75180300E+05, -.34000600E+05, -.10252100E+06, -.32882700E+05, 0.16485800E+05, 0.48090400E+04, 0.16462500E+05, 0.10715700E+05, 0.46853700E+04, 0.24653100E+04, -.42156600E+04, 0.10579800E+05, 0.35204500E+04, 0.14077000E+05, -.50494300E+05, 0.17270200E+05, 0.58593400E+05, 0.25249800E+05, -.46837900E+05, -.26337600E+05, 0.26871300E+05, -.89999100E+04, 0.10507700E+05, -.18532800E+05, 0.24741500E+05, 0.19306300E+06, -.90580000E+05, 0.20276700E+05, -.96542100E+05, -.28725200E+05, 0.17561800E+04, -.25925700E+05, 0.26341300E+05, -.64061800E+05, 0.37722300E+04, -.10088400E+06, 0.55984700E+05, -.25181500E+05, -.23892300E+05, -.27988800E+05, 0.22865800E+05, 0.25650400E+05, -.17034800E+05, 0.81035300E+04, -.15789100E+05, 0.18799600E+05, -.32447600E+05, -.12695100E+06, 0.70562600E+05, 0.57620100E+04, 0.63494400E+05, -.13336000E+05, -.86260100E+04, 0.37701100E+05, 0.88327600E+04, 0.43651800E+05, 0.21678000E+04, 0.55426300E+05, -.25801000E+05, 0.19083500E+05, -.73655500E+05, 0.12902600E+05, 0.47526900E+05, 0.30546900E+05, -.13289700E+05, 0.65543300E+04, 0.28827900E+05, 0.20940900E+05, 0.17910400E+05, -.28834300E+06, 0.14881200E+06, 0.23874900E+05, 0.14433500E+06, 0.91744300E+05, 0.37590900E+05, 0.17436200E+05, -.36901300E+05, 0.10240600E+06, 0.37301800E+05, 0.12902000E+06, -.60468000E+05, 0.34628100E+05, 0.38328400E+04, 0.30355100E+05, 0.26906100E+05, 0.11666600E+05, 0.35354500E+04, -.61842400E+04, 0.21529100E+05, 0.78201600E+04, 0.30403500E+05, -.35668100E+05, 0.22144700E+05, 0.18858200E+05, 0.17729300E+05, -.37908500E+04, -.20343200E+03, 0.18580300E+05, 0.76116700E+04, 0.25775000E+04, 0.66302400E+04, 0.71491800E+03, -.25118800E+06, 0.12363500E+06, 0.92155500E+05, 0.12561300E+06, -.77656800E+04, -.18163300E+04, 0.46401100E+05, -.42260000E+05, 0.65951000E+05, 0.18832000E+04, 0.10958400E+06, 0.18707200E+05, 0.90255800E+04, 0.99231600E+04, -.95975000E+04, -.30705600E+05, -.45830400E+03, 0.23965500E+05, 0.16043700E+05, -.22350100E+05, 0.15544500E+05, -.27016400E+05, 0.16896300E+06, -.74491900E+05, -.18751200E+05, -.84530800E+05, -.60420200E+05, -.30717800E+05, -.18247000E+04, 0.43168200E+05, -.44758500E+05, -.19712200E+05, -.82754100E+05, 0.13797900E+06, -.72352900E+05, -.51762000E+04, -.69098900E+05, -.70251400E+05, -.36844600E+05, 0.20115200E+04, 0.27457200E+05, -.37114600E+05, -.28687900E+05, -.55874300E+05, 0.46740500E+05, 0.28736400E+05, 0.27426000E+05, -.33924500E+05, -.21080000E+05, 0.13666500E+05, 0.22736500E+05, 0.19211000E+05, -.70282900E+04, -.24670600E+05, 0.21780400E+05, 0.46459000E+05, 0.11985400E+05, -.10474800E+05, 0.40325300E+05, 0.19368300E+05, -.31475500E+05, -.44339900E+05, 0.25229500E+05, 0.11111100E+05, 0.22941000E+05, -.22898600E+05, -.47525500E+05, 0.19716800E+05, -.23815700E+05, 0.95958300E+04 },
        { 0.26294300E+01, -.43949100E+01, -.88982100E+00, -.47158800E+00, -.59740800E+00, -.11552400E+00, 0.19943200E+01, 0.16719400E+00, 0.74633900E+00, -.12034600E+01, -.61500700E-01, 0.12602900E+00, 0.60600000E+00, 0.21264200E+01, 0.77725400E+00, 0.27290700E+01, -.46772500E+00, 0.14421300E+00, -.11923900E+01, 0.38420400E+01, -.29976200E+00, -.16982600E+00, 0.33831700E+00, 0.43451900E+04, -.88481300E+05, 0.59077500E+01, -.10785000E+04, -.12899000E+05, -.22602400E+04, -.99870500E+04, 0.69587700E+04, -.11885900E+05, 0.83058700E+04, 0.53918400E+05, -.28408100E+05, 0.37295800E+05, -.26959900E+05, -.11907800E+05, 0.13421100E+05, -.17338300E+05, -.13020100E+05, -.28999600E+05, 0.11475700E+05, -.28459500E+05, 0.93361500E+05, -.48080400E+05, 0.24828900E+05, -.46683500E+05, -.72881700E+04, 0.37041700E+04, -.19772100E+05, 0.53135200E+04, -.36386300E+05, -.96606100E+03, -.50650100E+05, 0.45662900E+03, 0.78561800E+04, -.35204400E+05, -.22689400E+03, -.10451000E+05, -.23639800E+05, 0.82320900E+04, 0.39414400E+04, 0.52763500E+04, -.20084600E+05, -.62097400E+04, 0.85726600E+04, -.37448800E+04, -.20833800E+05, -.42899000E+04, -.94457100E+04, 0.67997400E+03, -.33180100E+03, -.45758300E+04, -.40404600E+04, 0.16313100E+04, -.65239700E+04, 0.61350500E+04, -.43771200E+04, -.16786100E+05, -.30680800E+04, -.12565200E+05, -.11456500E+05, 0.65494800E+04, 0.99859500E+03, -.27499000E+04, -.75297300E+04, -.13696300E+05, 0.45147300E+05, -.26716500E+05, -.44894400E+05, -.22591100E+05, -.31497700E+04, -.79781500E+04, -.87203900E+04, 0.67008600E+04, -.15869100E+05, -.10294300E+05, -.30235700E+05, 0.16405400E+04, 0.68813300E+03, -.56934200E+05, -.80499700E+03, 0.17339900E+04, -.13107900E+04, -.33547500E+04, -.40348200E+04, 0.29129300E+04, -.24020900E+04, 0.17952900E+05, -.29494800E+05, 0.14782600E+05, 0.14233000E+05, 0.14747400E+05, 0.43854200E+04, -.13614400E+04, 0.21906500E+04, -.56659900E+04, 0.54389200E+04, -.44483400E+03, 0.13970600E+05, 0.31559500E+05, -.15326600E+05, 0.93078900E+03, -.15781600E+05, -.16751700E+05, -.39150600E+04, -.31389300E+04, -.89641400E+04, -.14787000E+05, -.25048000E+04, -.22572100E+05, -.26739200E+04, 0.14508000E+04, 0.12121100E+04, 0.13371200E+04, 0.23076700E+04, 0.15598200E+04, 0.15212000E+02, 0.14492300E+04, 0.16520800E+04, 0.81101200E+03, 0.20470000E+04, -.40909500E+05, 0.23480800E+05, 0.13159400E+05, 0.20444800E+05, 0.25500100E+04, -.30849400E+04, 0.41189400E+04, -.11508100E+05, 0.91515100E+04, -.17642800E+04, 0.13648800E+05, 0.16572900E+05, -.88524800E+04, -.20746400E+04, -.82871900E+04, -.56675500E+04, -.25688300E+04, -.21215900E+04, -.48534300E+04, -.96280400E+04, -.33831200E+04, -.10446600E+05, 0.17374700E+05, -.84380300E+04, -.22517200E+05, -.86859700E+04, 0.14362200E+04, -.87094700E+04, -.23861100E+04, -.23982100E+04, -.90725000E+04, -.66232600E+04, -.65291700E+04, 0.14706900E+05, -.14049700E+05, 0.14040800E+06, -.73625600E+04, 0.89820500E+04, 0.21465800E+05, -.59258300E+04, 0.53960800E+04, -.15380800E+05, 0.17780400E+05, -.26700000E+05, 0.18812000E+04, -.19783600E+04, -.17132800E+05, -.93682700E+03, 0.18760600E+04, -.10619400E+05, 0.74482000E+04, 0.61953900E+04, 0.30619700E+04, -.78500300E+04, 0.25701800E+04, -.68128400E+05, 0.29644200E+05, 0.94836600E+04, 0.34076600E+05, 0.22868500E+05, 0.34193600E+05, -.16188900E+04, -.10387400E+05, 0.21652300E+05, 0.26605400E+05, 0.43751400E+05, 0.79979900E+04, -.82270300E+04, 0.42883300E+04, -.39974000E+04, 0.67461400E+04, 0.95402300E+04, -.78398000E+04, -.30507000E+04, -.75930600E+04, 0.72849200E+04, -.14415900E+04, -.31482000E+05, 0.11213400E+05, 0.20946300E+05, 0.15738800E+05, 0.33139200E+04, 0.45386100E+04, 0.37030600E+04, -.16730400E+04, 0.80107500E+04, 0.55747900E+04, 0.28959500E+04, -.64132000E+05, 0.32806500E+05, 0.18524000E+05, 0.32068000E+05, 0.77642600E+04, -.46602200E+04, 0.79369800E+04, -.10813400E+05, 0.15071700E+05, -.26138500E+04, 0.27106300E+05, -.55681400E+05, 0.10647500E+05, 0.66228700E+05, 0.27833600E+05, 0.92879000E+04, 0.11234800E+05, 0.42217800E+04, -.53775600E+04, 0.73905800E+04, 0.12501900E+05, -.90625800E+04, 0.21104100E+05, -.19951500E+05, 0.44579600E+05, -.10538200E+05, -.13867100E+05, -.76070400E+04, 0.39778800E+04, 0.20283500E+04, -.12734900E+05, -.38381600E+04, -.18741800E+05, 0.22592800E+05, -.10692700E+05, 0.40219600E+05, -.11290100E+05, -.13413400E+05, 0.67096700E+04, -.58089600E+04, -.10828400E+05, -.13645000E+05, 0.64244900E+04, -.18140000E+05, 0.54612400E+04, 0.55253100E+04, 0.50608600E+04, -.60895300E+04, -.67263000E+04, 0.22416600E+04, 0.93851100E+04, 0.25122500E+04, -.32535200E+04, -.83551600E+04, 0.59120500E+04, 0.25316800E+04, -.27509500E+04, -.42857700E+04, 0.74296000E+04, 0.47351100E+04, -.82927200E+04, -.11174000E+05, 0.45409400E+04, 0.46116600E+04, 0.44859500E+04, -.70156600E+04, -.48416800E+04, 0.59699900E+04, -.18730700E+03, 0.72978000E+04 },
        { 0.11494200E+00, -.34716400E+00, 0.78891000E-02, -.47624300E+00, -.62380500E+00, 0.36905800E+00, 0.93329200E-01, -.60743500E+00, 0.21360800E+00, -.54765800E-01, 0.41801400E-01, 0.29734900E-01, -.14844300E+00, 0.12834700E+00, -.47469300E+00, -.14932800E+00, 0.25761800E+00, -.20087000E+00, 0.22133700E+00, -.34914800E+00, 0.15909000E+00, -.12971400E-01, 0.96279400E-02, -.55047200E-01, -.19489900E+05, -.54050500E+00, 0.20155000E+04, 0.74054500E+03, -.27094900E+04, -.37108300E+04, -.95263600E+03, 0.10231700E+04, -.11049100E+04, -.73670900E+03, 0.36460400E+03, 0.22187900E+05, 0.39037700E+03, 0.13138100E+04, 0.80496900E+03, 0.13092200E+04, 0.13124400E+04, -.48835500E+03, 0.87781500E+03, -.28190700E+04, -.90893200E+02, 0.41769100E+01, 0.19029600E+05, 0.66844100E+02, 0.82226400E+03, -.19422600E+04, 0.74859700E+03, 0.14491800E+03, 0.10147700E+04, -.20382000E+04, -.14130700E+04, -.83890800E+04, 0.42299200E+04, -.50615800E+04, 0.42016700E+04, 0.11977800E+03, -.19127400E+04, -.40856800E+02, -.43523700E+04, 0.19938300E+04, -.67862900E+03, 0.27572300E+04, -.15003900E+05, 0.75114400E+04, 0.39422300E+04, 0.75225200E+04, 0.24253500E+04, 0.15748000E+04, 0.14938800E+04, -.28136100E+04, 0.36738600E+04, 0.15390600E+04, 0.50955900E+04, -.83351100E+04, 0.41390000E+04, 0.37558200E+04, 0.41844400E+04, 0.19919500E+04, -.25734000E+02, 0.43770600E+03, -.29223300E+04, 0.17175400E+04, -.24302600E+03, 0.31228000E+04, -.98016800E+04, 0.48864100E+04, 0.48322600E+04, 0.49350000E+04, 0.39565800E+04, 0.11345100E+04, -.39522500E+03, -.33684400E+04, 0.34415300E+04, 0.40123800E+03, 0.23878500E+04, 0.14659000E+05, -.72154100E+04, -.19167800E+05, -.73414500E+04, -.20822000E+04, -.12837000E+03, -.30160700E+04, -.43199900E+03, -.61987100E+04, 0.85959100E+03, -.65834200E+04, 0.12196200E+05, -.59666000E+04, -.34529800E+04, -.60977100E+04, -.15274000E+03, 0.44311100E+00, -.24907300E+04, 0.14436300E+04, -.29480600E+04, 0.20034000E+03, -.39252700E+04, -.99352500E+04, 0.49468400E+04, 0.13631300E+05, 0.49926500E+04, 0.46061900E+04, 0.50045500E+04, -.50387200E+03, -.32606000E+04, 0.14526900E+04, 0.44320700E+04, 0.24198700E+04, 0.93959800E+03, -.46655300E+03, -.15324300E+04, -.47303500E+03, -.34008300E+03, 0.50056500E+01, -.38101400E+02, 0.53845300E+03, -.61731500E+02, 0.10649000E+02, -.21994700E+03, 0.12395700E+05, -.61591000E+04, 0.55442100E+04, -.61983400E+04, 0.21268100E+04, 0.35541500E+04, -.46382300E+04, -.16350400E+04, -.56625100E+04, 0.34536700E+04, -.53784600E+04, -.41424000E+04, 0.20831200E+04, 0.37762000E+04, 0.20728200E+04, -.35119500E+04, -.60193400E+04, 0.19660600E+04, -.28267300E+04, 0.11927300E+04, -.54338500E+04, 0.26953100E+04, 0.97227000E+03, -.39316500E+03, -.39950000E+04, -.48681900E+03, -.33926600E+04, -.62886100E+04, 0.73481000E+03, -.23837100E+04, -.75854100E+03, -.52570400E+04, 0.53731900E+03, -.15760000E+05, 0.77771800E+04, 0.27198000E+05, 0.78770300E+04, -.33916200E+04, -.55309300E+04, 0.50907100E+04, -.12714700E+04, 0.64862400E+04, -.55034800E+04, 0.89301400E+04, -.11385600E+05, 0.56502400E+04, -.42707900E+04, 0.56924800E+04, -.11959800E+04, -.45126500E+04, 0.41684800E+04, -.25642900E+03, 0.32342800E+04, -.35841200E+04, 0.46398400E+04, -.53410700E+04, 0.26575600E+04, -.88480000E+04, 0.26456000E+04, 0.80884000E+03, 0.23572900E+04, 0.24519200E+04, 0.42521400E+04, 0.41393300E+04, 0.82456400E+03, 0.38367600E+04, 0.71404700E+04, -.35606300E+04, -.39234600E+04, -.35887400E+04, -.78973300E+03, 0.37431300E+03, -.16210300E+04, 0.53581300E+03, -.19206900E+04, -.16919200E+02, -.23306900E+04, -.13722900E+05, 0.67749400E+04, 0.49742200E+04, 0.68774200E+04, 0.59624300E+03, 0.10758100E+04, 0.95589200E+03, -.24055300E+04, 0.57709500E+04, 0.45819700E+02, 0.80667200E+04, 0.18138500E+05, -.88893300E+04, -.27144800E+04, -.90721500E+04, 0.10712600E+04, 0.18373300E+04, -.48264900E+04, 0.42758100E+03, -.62904100E+04, 0.21792200E+04, -.63357500E+04, -.33050200E+05, 0.16287400E+05, 0.17765000E+05, 0.16562300E+05, 0.30930700E+04, 0.17123800E+04, 0.23836700E+04, -.62006800E+04, 0.13308400E+05, -.79027400E+03, 0.17693600E+05, -.47478200E+04, 0.22777100E+04, 0.18219600E+05, 0.23816000E+04, -.54341800E+03, -.16685200E+04, 0.20167100E+04, -.77293200E+03, 0.69689000E+03, -.17366200E+04, 0.21950800E+04, -.93775400E+04, 0.46712100E+04, 0.20605200E+05, 0.47055400E+04, 0.21013000E+04, 0.21233500E+04, 0.17288700E+04, -.10488800E+04, 0.16310600E+04, 0.21489700E+04, 0.13720000E+04, -.92764900E+03, 0.41122400E+02, -.94205000E+03, 0.12803800E+04, 0.24019600E+04, 0.33417700E+02, -.98077200E+03, 0.43787200E+03, -.83401400E+03, -.24620700E+02, 0.23454300E+03, -.15111800E+04, -.10843400E+03, -.45019900E+03, -.19546200E+04, -.24780800E+04, -.25050400E+03, 0.77917800E+03, -.30203700E+04, -.90690800E+03, 0.59050300E+03, -.53133900E+03, 0.16808100E+04, 0.32951600E+03, 0.20351500E+04, -.26447600E+04 },
        { -.36850000E+01, 0.18452900E+01, 0.21245800E+00, -.52174900E+00, -.15585600E+01, 0.15184700E+01, -.40719400E+01, 0.17568000E+01, -.20192300E+01, 0.27274800E+01, 0.16560300E-01, -.36600500E+00, 0.13342700E+01, -.14954500E+01, -.26928600E+01, -.16867800E+01, -.46093800E+00, -.76896700E+00, 0.72014200E+00, -.30821500E+01, 0.47474900E+00, 0.25680800E+00, 0.15659500E+00, -.12727100E+00, 0.80074700E+00, 0.92324300E+02, -.19430100E+04, 0.70674700E+04, -.31256300E+04, -.11577500E+03, -.33329600E+04, 0.83912200E+04, -.21300900E+04, -.51642700E+05, 0.25845000E+05, -.13758900E+04, 0.26471100E+05, 0.11124300E+05, -.37270800E+04, 0.11036100E+05, -.57795600E+03, 0.21054700E+05, -.51194200E+04, 0.21730200E+05, -.64025000E+05, 0.31988400E+05, 0.70085100E+04, 0.32600000E+05, 0.69856200E+04, -.94435800E+03, 0.88725500E+04, -.14501200E+05, 0.20161500E+05, -.68430500E+03, 0.27928300E+05, -.35595200E+04, 0.18001700E+04, -.14720400E+05, 0.20003100E+04, 0.41532600E+03, 0.88736400E+04, -.60886000E+04, -.75640400E+04, -.25252100E+04, 0.92085100E+04, 0.53051100E+04, -.24343700E+05, 0.12229100E+05, -.51677500E+04, 0.12720900E+05, 0.24553400E+04, 0.25349100E+04, 0.12733400E+04, -.45640500E+04, 0.55586100E+04, 0.12127400E+04, 0.10242600E+05, -.28573000E+05, 0.14272800E+05, -.11567300E+05, 0.14794400E+05, 0.44004800E+04, 0.38979700E+04, -.90081700E+03, -.91468500E+04, 0.70397900E+04, 0.24578500E+04, 0.14288500E+05, -.66068800E+05, 0.33042500E+05, 0.14770500E+05, 0.33739300E+05, 0.22272200E+04, 0.47326400E+04, 0.51378100E+04, -.21818200E+05, 0.15462600E+05, 0.45974600E+04, 0.31016500E+05, 0.14457100E+05, -.71835200E+04, 0.97580900E+04, -.73185700E+04, 0.15470000E+03, 0.15983400E+04, 0.66543000E+03, 0.95689600E+04, -.47905600E+04, 0.39602600E+04, -.14504600E+05, 0.43037100E+05, -.21367100E+05, -.14093400E+05, -.21591500E+05, -.15403800E+04, -.39655600E+04, -.42389900E+04, 0.89170100E+04, -.60119300E+04, -.45323000E+04, -.18962500E+05, -.23666000E+05, 0.11832500E+05, -.14287400E+05, 0.12536100E+05, 0.73687500E+04, 0.55360900E+04, -.14614400E+04, -.54459200E+04, 0.57136800E+04, 0.35283400E+04, 0.11987900E+05, 0.37538600E+04, -.18786900E+04, 0.17926900E+04, -.19705900E+04, -.98694100E+03, -.30992400E+03, -.43482900E+02, 0.88576700E+03, -.10859100E+04, -.40170500E+01, -.17133600E+04, -.23804700E+04, 0.37694500E+03, -.22601400E+05, 0.94425800E+03, 0.12485600E+05, 0.62813300E+04, -.45725500E+04, -.24727100E+04, 0.33513000E+04, 0.31115200E+04, 0.26302100E+04, -.37781200E+05, 0.19069100E+05, -.15738500E+05, 0.18920900E+05, 0.55066900E+04, 0.36116800E+03, 0.28564100E+04, -.71201700E+04, 0.16065100E+05, -.67404700E+03, 0.19090600E+05, -.51999400E+04, 0.26981400E+04, 0.48072500E+04, 0.25962700E+04, -.33211100E+04, -.31668600E+04, 0.15206100E+04, -.20927000E+04, 0.19467400E+04, -.23109400E+04, 0.22228200E+04, -.11768000E+05, 0.57575700E+04, 0.19866500E+03, 0.56324900E+04, -.14726300E+04, -.14280200E+05, 0.58013200E+04, -.39112300E+04, 0.10298500E+05, -.15379400E+05, 0.63286400E+04, 0.17316700E+05, -.83869100E+04, 0.24327900E+05, -.85623500E+04, -.10412100E+05, -.37136300E+04, -.62000900E+03, 0.15941500E+04, -.10629600E+05, -.16434300E+04, -.10260300E+05, 0.44688600E+05, -.22310100E+05, 0.23628300E+05, -.22845100E+05, -.10649100E+05, -.16525800E+05, 0.49694600E+04, 0.19730200E+05, -.65452200E+04, -.14875100E+05, -.25091800E+05, 0.68973400E+04, -.33960700E+04, 0.49582300E+04, -.39584800E+04, -.32592000E+04, -.51631600E+04, 0.24300300E+04, 0.31584100E+04, 0.98527700E+03, -.42911900E+04, -.51555600E+04, -.10564500E+05, 0.51729700E+04, 0.14210700E+04, 0.57146500E+04, -.41094800E+04, -.24494300E+04, -.37184400E+03, -.80903900E+04, 0.27610100E+04, -.45166100E+04, 0.97637500E+04, 0.48713900E+05, -.24443300E+05, -.22662000E+05, -.24597900E+05, 0.37960900E+04, -.50327600E+02, -.80566700E+04, 0.76526700E+04, -.77858600E+04, -.22083200E+04, -.21448500E+05, -.43524700E+05, 0.21550900E+05, 0.30039400E+04, 0.22749200E+05, -.66842500E+04, -.62871700E+04, 0.15974100E+04, -.23440500E+05, 0.13624400E+05, -.10974300E+05, 0.30705900E+05, -.37288600E+05, 0.18661400E+05, -.13465800E+05, 0.19124500E+05, 0.85556800E+04, 0.21269500E+04, 0.14952900E+04, -.96475600E+04, 0.12809100E+05, -.23572100E+03, 0.19153600E+05, -.33683600E+05, 0.16789200E+05, -.10905400E+05, 0.17445700E+05, 0.10513700E+05, 0.14310900E+03, 0.47978200E+04, -.20803100E+03, 0.13781200E+05, -.17574300E+04, 0.15720400E+05, -.56429500E+04, -.25835500E+04, -.31183100E+04, 0.50170600E+04, -.16397900E+04, 0.35843200E+04, -.84510000E+04, -.29458300E+04, 0.25223600E+04, 0.32490200E+04, -.33835300E+04, -.88457900E+04, -.34934900E+04, 0.10578700E+04, -.57950100E+04, 0.20249700E+04, 0.30431900E+04, 0.76001200E+04, -.28674900E+03, -.27427800E+04, -.14164000E+04, 0.13630500E+04, 0.90976700E+04, -.15262000E+04, 0.16143800E+04, 0.25544500E+04 },
        { 0.17775300E+01, 0.12218600E+01, 0.90130300E-01, 0.11977400E+00, 0.90104000E+00, -.60004800E-01, 0.22635300E+01, -.14001200E+01, 0.13068200E+01, -.14850100E+01, -.36031700E-01, 0.10097200E+00, -.43424200E-01, -.14514600E+01, -.23115300E+00, -.19618700E+01, 0.16467200E-01, -.40035200E+00, 0.71394800E+00, -.61681800E+00, -.13673200E+00, -.20399000E-01, -.13511800E-02, -.18559600E+00, 0.13069300E+01, -.10557300E-01, -.80114100E+04, -.76910000E+03, -.25728200E+04, -.88228800E+04, -.87191500E+03, -.60291300E+03, 0.94693600E+04, 0.24298200E+03, -.70224100E+03, -.32276200E+05, -.13468800E+03, 0.28578000E+04, 0.11654500E+04, -.43098400E+04, -.59770400E+04, 0.16177700E+04, 0.23576500E+03, 0.32168600E+04, 0.25415000E+04, -.14206500E+04, -.25974500E+05, -.12835400E+04, 0.43425800E+04, 0.52136100E+04, -.62302000E+04, -.61419400E+04, -.31709100E+04, 0.41150600E+04, -.25538700E+04, 0.40969600E+03, 0.54173300E+03, -.12877600E+05, -.20944200E+03, 0.46800600E+04, 0.74020400E+04, -.13543700E+04, 0.36914200E+04, 0.14951100E+02, 0.41205300E+04, 0.23487700E+04, 0.11548100E+05, -.58218700E+04, -.18773500E+05, -.57863100E+04, 0.92262600E+03, 0.43696900E+04, -.39751400E+04, -.89133500E+03, -.98245800E+03, 0.31335700E+04, -.20231700E+04, -.95297100E+04, 0.46302500E+04, -.19853300E+05, 0.47548600E+04, 0.23540200E+04, 0.42799700E+04, -.14428200E+04, -.32979600E+04, 0.41731100E+04, 0.37477400E+04, 0.39125100E+04, -.17639600E+04, 0.45802900E+03, -.20001200E+05, 0.86236800E+03, -.50102600E+04, -.43604300E+03, -.34424500E+04, -.58465500E+04, -.14103100E+04, -.80649900E+02, 0.30093700E+04, -.10384600E+05, 0.52022700E+04, 0.17573800E+05, 0.51984900E+04, 0.63932400E+02, -.31460900E+03, 0.22560400E+04, -.30359200E+03, 0.35957600E+04, -.93154400E+03, 0.91396100E+04, 0.56763100E+04, -.26012900E+04, -.17226000E+04, -.28392600E+04, 0.53091700E+02, -.79517800E+03, -.23737900E+04, -.95077600E+03, -.31355800E+04, -.20073500E+04, -.54987800E+04, 0.57043100E+04, -.32836300E+04, -.33823600E+05, -.28672800E+04, 0.69988000E+03, 0.15009200E+03, -.35099600E+04, -.26034900E+04, 0.89569600E+03, -.11443400E+04, 0.17512100E+03, 0.17640200E+02, 0.58187800E+02, 0.43969800E+04, -.68766800E+01, -.31676600E+03, -.55202200E+03, 0.58993400E+03, 0.38855800E+03, -.14243000E+03, -.49251700E+03, -.36869300E+03, -.17878100E+05, 0.72743600E+04, -.22632100E+05, 0.89393000E+04, 0.46797700E+04, 0.95809500E+03, -.38629400E+03, -.20938000E+04, 0.60961900E+04, -.12471400E+04, 0.65067400E+04, -.13850800E+05, 0.83535500E+04, -.23198100E+05, 0.69244400E+04, 0.15632100E+05, 0.14225100E+05, -.48063800E+04, -.29211900E+04, 0.43366400E+04, 0.11434300E+05, 0.51439600E+04, 0.60952400E+04, -.22489900E+04, -.13095100E+04, -.30474800E+04, 0.63714000E+04, 0.70307500E+04, -.29167300E+04, 0.12708100E+04, -.29501600E+04, 0.60131200E+04, -.34335400E+04, 0.40905000E+05, -.20617100E+05, -.52091800E+04, -.20450200E+05, 0.15204900E+05, 0.12975300E+05, -.87010100E+04, 0.12344500E+05, -.16080900E+05, 0.10319700E+05, -.34125900E+05, 0.24748600E+05, -.10813200E+05, 0.20739900E+05, -.12374000E+05, -.62929200E+04, -.17879600E+04, -.10752800E+04, 0.36559200E+04, -.82023200E+04, -.70929200E+03, -.10370800E+05, 0.20356900E+05, -.10288100E+05, 0.34381400E+05, -.10163900E+05, -.14004600E+05, -.12574000E+05, 0.58304500E+03, -.18000600E+03, -.78203500E+04, -.79372200E+04, -.98466700E+04, -.17463200E+04, 0.66402600E+03, 0.97474300E+04, 0.88440300E+03, -.82584700E+03, -.18511500E+04, 0.12720100E+04, -.58603600E+03, -.17471800E+03, -.87175300E+03, -.17232600E+04, 0.35602900E+04, -.20877000E+04, -.23587700E+03, -.17897400E+04, 0.69272000E+03, -.48566200E+03, 0.14598100E+04, 0.47958100E+04, -.15078500E+04, 0.13426400E+03, -.89014300E+04, -.22153100E+04, 0.10407500E+04, -.83999500E+04, 0.11072100E+04, 0.12441500E+04, -.94993700E+03, -.23165000E+04, -.13425200E+04, -.94222600E+02, -.35798200E+04, -.38375800E+04, 0.21354500E+05, -.11440000E+05, -.13161400E+05, -.10699200E+05, -.39610400E+03, 0.69354800E+03, -.27229300E+04, 0.57163700E+04, -.94355700E+04, 0.19479100E+04, -.25014300E+05, -.16301000E+05, 0.77026300E+04, -.21745500E+05, 0.81450700E+04, 0.81608500E+04, 0.38858400E+04, -.79839400E+02, -.23194000E+04, 0.65965600E+04, 0.34926700E+04, 0.43550900E+04, 0.17212000E+04, -.16663500E+04, -.31253100E+05, -.87121800E+03, 0.34701900E+04, 0.75347300E+03, -.30824100E+04, -.21683200E+04, 0.20499100E+04, -.72634900E+03, 0.22516100E+04, -.80603700E+03, -.23777100E+04, -.19423200E+04, 0.23404200E+04, -.42963300E+04, -.16199400E+04, -.26570300E+04, -.29439000E+04, 0.32985600E+04, 0.30418100E+04, -.35480600E+04, -.47324600E+04, -.26377500E+04, 0.22051200E+04, -.16202800E+04, 0.60698400E+04, 0.22878500E+04, 0.16372700E+04, 0.22998100E+04, 0.12852700E+04, -.29257800E+04, 0.46014300E+04, 0.39754400E+04, -.42611000E+04, -.20018500E+04, 0.55296100E+04 },
        { 0.10206900E+01, 0.53304300E+00, 0.65829900E-01, -.44619600E-01, -.13153800E-02, 0.26101000E+00, 0.46751200E+00, 0.11888100E+00, 0.24479400E+00, -.55750000E+00, 0.27955200E-01, 0.28054000E-01, 0.58486600E+00, 0.24155000E+00, 0.10280100E+01, -.28963700E+00, 0.32641300E+00, 0.35856700E+00, -.25514200E+00, 0.39585800E+00, -.42047100E+00, -.20786800E-01, 0.18640300E-02, 0.32341800E-01, 0.42227900E+00, -.54461400E-02, 0.31883200E+00, -.51984700E+04, -.26370500E+03, -.56356100E+04, -.10639300E+04, -.52791100E+04, -.23573900E+04, 0.30716200E+05, -.15217200E+05, 0.40288700E+04, -.15337300E+05, -.66906700E+04, -.27921300E+03, -.48698400E+04, 0.39260800E+03, -.12951800E+05, 0.11842800E+04, -.10890600E+05, 0.39786100E+05, -.19863700E+05, -.25490000E+04, -.19873000E+05, -.78156000E+04, -.48880800E+03, -.48402300E+04, 0.69624500E+04, -.13230500E+05, 0.12180200E+03, -.10927300E+05, 0.76211600E+04, -.40415400E+04, 0.75695700E+04, -.38037400E+04, -.57623400E+04, -.65482000E+04, 0.32054500E+04, 0.43006400E+04, -.32580200E+04, -.64483700E+04, -.59353400E+04, 0.12288900E+05, -.61942500E+04, 0.31741900E+04, -.61252900E+04, -.53855500E+04, -.52096700E+04, 0.16555400E+03, -.61634900E+03, -.53654900E+04, -.33853400E+04, -.53710400E+04, 0.24643600E+05, -.12300100E+05, 0.42773300E+04, -.12305800E+05, -.74817400E+04, -.32091600E+04, -.21891500E+04, 0.10639000E+04, -.10893200E+05, -.19829900E+04, -.10079900E+05, 0.39236600E+05, -.19562300E+05, -.34554300E+04, -.19587400E+05, -.35594400E+04, -.16232900E+04, -.49143800E+04, 0.79906800E+04, -.12243100E+05, -.13274600E+04, -.13973700E+05, -.12407900E+05, 0.61976000E+04, -.36319500E+04, 0.61939200E+04, 0.35205400E+04, 0.90948500E+03, -.16759400E+04, -.77499000E+04, 0.26639400E+04, -.11129400E+03, 0.55538000E+04, -.76142400E+04, 0.37725300E+04, 0.15500300E+04, 0.38073000E+04, 0.12503800E+04, 0.17972300E+04, 0.56954800E+03, -.49697000E+03, 0.19471000E+04, 0.13959700E+04, 0.65778900E+04, 0.19670400E+05, -.97476700E+04, 0.87001100E+04, -.98117000E+04, -.75080800E+04, -.48217100E+04, 0.31131000E+03, 0.15919200E+04, -.82215100E+04, -.34350100E+04, -.10512900E+05, -.26428900E+04, 0.13078300E+04, -.12825800E+04, 0.13184000E+04, 0.10040300E+04, 0.41430800E+03, 0.10975100E+03, -.15166700E+03, 0.13118500E+04, 0.23242400E+03, 0.12243800E+04, 0.10968200E+04, 0.15341000E+03, 0.11762700E+05, -.54979400E+03, -.18050900E+04, 0.20312600E+03, 0.77770900E+02, -.10281800E+04, -.38983900E+04, 0.77678700E+03, 0.14626300E+04, 0.18106300E+05, -.95829600E+04, 0.11858200E+05, -.90517100E+04, -.96318900E+04, -.40078400E+04, 0.90631100E+02, 0.25403200E+04, -.92183800E+04, -.30558500E+04, -.59398800E+04, 0.19294700E+04, -.12437300E+04, -.17024700E+04, -.96473600E+03, -.13785400E+04, 0.18174400E+03, -.72582000E+03, -.22264200E+03, -.10548400E+04, -.34672500E+03, 0.96579100E+03, 0.80153000E+04, -.38839700E+04, -.76694900E+04, -.40112200E+04, -.20628600E+04, 0.90875300E+04, -.23782400E+04, 0.62315700E+04, -.40796200E+04, 0.88775300E+04, 0.68226800E+04, -.16719000E+05, 0.77871700E+04, -.10856800E+05, 0.83595900E+04, 0.52235700E+04, 0.15465200E+04, 0.16980500E+04, -.14104000E+04, 0.67270300E+04, 0.61428400E+03, 0.70915100E+04, -.36613900E+05, 0.18364900E+05, -.12272300E+05, 0.18284500E+05, 0.14016000E+05, 0.10527000E+05, -.16558600E+04, -.10002600E+05, 0.11915500E+05, 0.91533600E+04, 0.16768800E+05, 0.73904400E+03, -.30801800E+03, -.51688200E+04, -.38687500E+03, 0.27199900E+04, 0.33402600E+04, -.16692500E+04, 0.60287600E+03, 0.13492000E+04, 0.28158500E+04, 0.12298800E+04, 0.10318300E+05, -.50344600E+04, -.32484300E+04, -.51442300E+04, -.13625000E+03, 0.10764400E+04, 0.60657100E+03, 0.78902200E+04, -.14356900E+04, 0.15541800E+04, -.26663600E+04, -.11880200E+05, 0.60609100E+04, 0.61259800E+04, 0.59371600E+04, 0.18335900E+04, 0.28114600E+04, 0.10711900E+04, -.11307500E+04, 0.12871500E+04, 0.24644500E+04, 0.10346500E+05, 0.35823300E+05, -.17659300E+05, -.82497200E+04, -.17877000E+05, -.19778600E+04, 0.38525500E+04, -.21620200E+04, 0.16838200E+05, -.91243800E+04, 0.48813100E+04, -.82968700E+04, 0.20024800E+05, -.99039500E+04, 0.91213100E+04, -.10003900E+05, -.76785100E+04, -.17435100E+04, 0.74061900E+02, 0.47177400E+04, -.85253400E+04, -.45041700E+03, -.82212300E+04, 0.19684800E+05, -.96002200E+04, 0.89154100E+04, -.98260000E+04, -.65461500E+04, -.90919700E+03, -.21422900E+04, -.41126400E+03, -.10490000E+05, 0.16987600E+03, -.81081700E+04, 0.35323100E+04, 0.33861300E+04, 0.29240200E+04, -.39504100E+04, -.13849400E+04, -.48808000E+03, 0.40873600E+04, 0.30169300E+04, -.16614500E+04, -.34804500E+04, 0.33470400E+04, 0.29761800E+04, 0.15888600E+04, -.18440700E+04, 0.32448100E+04, -.87352000E+03, -.35007800E+04, -.63781500E+04, 0.86591100E+03, 0.74612800E+03, 0.37316100E+04, -.14548600E+04, -.34790300E+04, 0.20135500E+04, -.12542900E+04, 0.63687000E+03 },
        { 0.14633600E+01, -.50620400E+00, -.85606400E-01, 0.14796100E+00, 0.48276400E+00, 0.40822800E+00, 0.56121700E+00, -.71442300E+00, 0.49866000E+00, -.65552900E+00, -.10251200E-01, 0.18079300E-01, -.10996200E+01, 0.44785200E+00, -.68740600E+00, -.34763900E+00, 0.75707300E+00, -.72914500E-02, -.61312800E+00, -.31611500E+00, -.24276700E+00, 0.10525000E+00, -.42561500E-01, 0.15364800E+00, -.52956800E+00, -.55366900E-01, -.19157600E+00, -.25681800E+00, -.49387000E+04, -.11534500E+05, -.52274100E+04, -.10262400E+03, -.70959000E+04, -.76867900E+04, 0.37729200E+04, 0.60034400E+04, 0.38996100E+04, 0.18066200E+04, -.42642700E+04, 0.53763500E+04, 0.42012300E+04, 0.43916900E+04, -.31808700E+04, 0.93442600E+04, -.83281900E+03, 0.36679900E+03, 0.29444300E+03, 0.47017900E+03, -.17007500E+04, -.76297900E+03, 0.11683500E+04, -.91749700E+03, 0.25805600E+04, 0.40492600E+03, 0.10760100E+05, -.11965200E+04, 0.74112100E+03, -.41986400E+04, 0.61567400E+03, -.80092800E+03, 0.24472100E+04, -.19478500E+04, -.44676800E+04, -.33400700E+04, 0.12438900E+04, -.16665700E+04, 0.15326100E+04, -.74901900E+03, -.61632700E+04, -.71471900E+03, -.16625700E+04, -.41631900E+04, -.40524700E+03, -.18041900E+04, -.15599200E+04, -.35203000E+04, 0.23830300E+04, 0.13172500E+05, -.66084700E+04, -.10096500E+05, -.65425800E+04, -.20734800E+04, 0.92942800E+03, -.64883100E+04, -.60236300E+04, -.77498100E+04, 0.35352700E+03, 0.24000000E+04, 0.86907500E+04, -.44418600E+04, 0.37251300E+04, -.42621300E+04, 0.60942800E+03, 0.41397900E+04, -.51534700E+04, -.61792500E+04, -.25501300E+04, 0.38389400E+04, 0.33599700E+04, -.26292600E+04, 0.13777500E+04, 0.37410100E+04, 0.12869600E+04, 0.46245300E+04, 0.41305300E+04, -.35943600E+04, -.54177100E+04, -.49590700E+04, 0.41235900E+04, -.80581900E+04, 0.96611200E+04, -.48883100E+04, -.13679000E+04, -.48344500E+04, -.86152800E+03, -.41658900E+03, -.79660800E+02, 0.22122600E+04, -.15918600E+04, -.74435100E+03, -.11151700E+04, 0.27302100E+04, -.14340100E+04, -.31542400E+04, -.13024000E+04, 0.18500200E+04, 0.14622300E+04, -.17932400E+04, -.48239700E+02, -.18580600E+04, 0.52481400E+03, 0.28139000E+04, -.88406100E+03, 0.45185200E+03, 0.77688800E+02, 0.43382500E+03, 0.50592200E+01, 0.11244700E+03, 0.35943400E+03, 0.30140900E+03, 0.68498300E+03, 0.25880300E+03, -.29250100E+03, 0.82688900E+04, -.46634400E+04, 0.53813200E+04, -.41408500E+04, 0.10276300E+04, 0.32062800E+04, -.34656700E+04, -.32750300E+04, -.66277100E+04, 0.23593200E+04, 0.20271400E+04, -.95455300E+04, 0.50119200E+04, -.41638700E+04, 0.47764600E+04, -.17934300E+04, -.59667800E+03, 0.39764200E+03, -.28402100E+04, 0.13900800E+04, -.12319700E+04, 0.11361800E+05, 0.23750600E+04, -.10660600E+04, -.12665500E+04, -.11889200E+04, -.24643400E+04, -.72923000E+02, -.84498900E+03, -.17582400E+04, -.17768800E+04, -.72827900E+03, 0.26581600E+03, -.90444000E+04, 0.44298800E+04, -.14023900E+05, 0.45128100E+04, -.86033500E+04, -.27059600E+04, 0.50721300E+04, 0.55242800E+04, 0.66498500E+04, -.19732900E+04, 0.26326400E+05, -.32462000E+04, 0.18583800E+04, 0.11354700E+04, 0.16252900E+04, -.19665500E+04, -.16114000E+04, 0.15430700E+04, 0.16656900E+04, 0.51167500E+03, -.16004200E+04, -.11280200E+04, -.14514300E+05, 0.72364000E+04, 0.88804100E+04, 0.71975000E+04, 0.10515400E+04, -.39690800E+04, 0.49919400E+04, 0.39408200E+04, 0.78277400E+04, -.22572400E+04, 0.28892800E+04, 0.49129800E+04, -.24851400E+04, -.23837000E+04, -.25024600E+04, 0.85730700E+03, 0.84917400E+03, -.20814300E+03, 0.23057000E+04, 0.15794700E+04, 0.12279300E+04, -.18752400E+04, 0.45082900E+04, -.23775200E+04, -.47807100E+04, -.22142500E+04, -.38802400E+04, -.15578400E+04, 0.19277900E+04, 0.65561800E+04, 0.39415300E+04, -.23660500E+04, 0.66383800E+04, 0.16002300E+05, -.82570500E+04, 0.10093400E+04, -.80191400E+04, -.26894000E+03, 0.24204000E+04, -.26621600E+04, 0.73656100E+03, -.66764000E+04, 0.14212900E+04, 0.54775800E+03, 0.14711900E+05, -.76768500E+04, -.13189800E+05, -.72624700E+04, -.98069500E+04, -.23607500E+04, 0.45259600E+03, 0.77643900E+04, 0.59399100E+04, -.38383600E+04, 0.20921700E+05, -.23771100E+04, 0.10973600E+04, -.26512800E+04, 0.12111800E+04, -.10000200E+04, -.67542000E+03, 0.12022800E+04, 0.18174800E+04, 0.11851200E+04, -.98843500E+03, 0.86658000E+04, -.11115600E+05, 0.54373600E+04, 0.27446900E+04, 0.56012400E+04, 0.19982400E+04, -.61258800E+03, 0.29561400E+04, 0.17265600E+04, 0.22622100E+04, -.10270700E+04, 0.11279500E+05, 0.66442400E+03, 0.93384000E+03, -.25985700E+03, 0.51815900E+03, 0.93399000E+02, 0.14599200E+02, -.16746300E+04, 0.94922500E+03, 0.34214300E+02, -.13573400E+03, 0.56054100E+03, -.61830400E+03, -.15353400E+03, -.33073900E+03, -.10656400E+04, 0.51626700E+03, -.95029800E+03, -.12856200E+04, -.12604300E+04, 0.25212900E+03, 0.19280300E+04, 0.27453700E+02, 0.98135700E+03, 0.22999800E+02, -.29217900E+02, -.47342500E+03 },
        { -.38175900E+00, 0.15831100E+01, 0.18793000E+00, 0.67815000E+00, 0.28252800E+00, -.50549100E-01, -.16632200E+01, 0.23770700E+01, -.66339700E+00, -.26369000E+00, -.13668000E-01, 0.18600900E-01, 0.81012400E+00, -.95755200E+00, 0.12859300E+01, -.72811100E-02, -.44967400E+00, 0.24885900E+00, -.45496000E+00, 0.72272000E+00, -.85646200E-01, 0.64188400E-01, 0.15245900E+00, 0.10355300E+00, -.58276100E+00, -.23909900E-02, 0.19702300E+00, 0.23596600E+00, 0.34170000E+00, 0.24585200E+04, 0.65085100E+03, 0.72878600E+03, -.47734700E+01, -.32707000E+05, 0.16619000E+05, 0.14430500E+05, 0.16344700E+05, 0.67814000E+04, 0.13934600E+04, 0.76840700E+04, 0.27102700E+04, 0.10346900E+05, 0.13988400E+04, 0.78975700E+04, -.15776300E+05, 0.79686200E+04, 0.56398600E+04, 0.78798600E+04, 0.70150900E+04, -.12641400E+04, 0.15283700E+04, -.37560100E+04, 0.39788000E+04, -.44360800E+03, 0.64668400E+03, -.13047200E+05, 0.61226600E+04, 0.34107800E+04, 0.65210900E+04, 0.15497200E+04, -.24071600E+04, -.21619900E+03, -.75168300E+04, 0.50689300E+04, -.22617400E+03, 0.51769700E+04, -.27218300E+05, 0.13589600E+05, 0.15454100E+05, 0.13601200E+05, 0.52376700E+04, 0.42282800E+04, 0.33958200E+04, -.56469700E+03, 0.78814100E+04, 0.36954700E+04, 0.85889900E+04, -.26533300E+05, 0.13319300E+05, 0.11342400E+05, 0.13259700E+05, 0.60167200E+04, -.15666800E+03, 0.37076700E+04, -.32677200E+04, 0.94885600E+04, 0.12761000E+02, 0.87340700E+04, -.18399900E+05, 0.93754100E+04, 0.18444600E+04, 0.91869700E+04, 0.55860800E+04, -.21935500E+04, 0.16039700E+04, -.60793300E+04, 0.53888000E+04, -.92255600E+03, 0.23902300E+04, 0.65845200E+04, -.33567600E+04, -.45444600E+03, -.32878300E+04, -.77976800E+04, -.37776900E+04, 0.33785700E+04, 0.58064300E+04, 0.32577500E+03, -.28808600E+04, -.78527300E+03, 0.10574900E+05, -.52812900E+04, -.46956000E+04, -.52859000E+04, 0.12172300E+04, 0.24965800E+04, -.32866600E+04, -.31703900E+03, -.34107300E+04, 0.24383600E+04, -.47199500E+04, -.38572900E+05, 0.19473700E+05, 0.15665700E+05, 0.19276900E+05, 0.97183400E+04, 0.47125400E+04, 0.38414200E+04, -.54078800E+04, 0.11215100E+05, 0.49702100E+04, 0.13298100E+05, 0.28173600E+04, -.14384900E+04, -.12009300E+04, -.14074100E+04, -.11296000E+04, -.49674800E+03, -.28636000E+01, 0.85669600E+03, -.81429200E+03, -.49251900E+03, -.78019000E+03, 0.90483300E+04, -.37297200E+04, -.31705700E+04, -.45226300E+04, 0.50923300E+04, 0.56697600E+04, -.42097600E+04, -.12414400E+04, -.23495000E+04, 0.51634400E+04, -.59179800E+04, -.65820100E+04, 0.25617300E+04, 0.40166700E+04, 0.32904800E+04, 0.95608800E+03, -.25429200E+04, -.21148600E+03, -.56402600E+04, 0.19747000E+04, -.12956700E+04, 0.11011300E+04, -.29632500E+04, 0.10688900E+04, 0.18152900E+03, 0.14817900E+04, -.30456400E+04, -.52137600E+04, 0.18436400E+03, -.41816200E+04, 0.70634600E+03, -.39276500E+04, 0.18188800E+04, 0.80173500E+03, -.24057800E+03, 0.19783000E+04, -.39945600E+03, 0.41551900E+04, -.33601600E+04, -.27108100E+04, -.96566200E+04, -.13635200E+04, -.31149200E+04, -.72110800E+04, -.48600600E+04, 0.17101300E+04, 0.22917000E+04, 0.24293000E+04, -.33187700E+04, -.33154400E+04, 0.25882400E+04, 0.33422300E+03, 0.17348600E+04, -.26473100E+04, 0.19818200E+04, 0.22672000E+05, -.11233300E+05, -.77878800E+04, -.11327000E+05, -.47359700E+04, 0.94670100E+03, 0.97260300E+03, 0.11219300E+05, -.62223200E+04, -.11513400E+04, -.74107100E+04, 0.90794200E+04, -.44208200E+04, -.59173300E+04, -.45327400E+04, -.34668300E+04, -.36329500E+04, -.13179000E+04, -.11845200E+04, -.36799200E+04, -.36504100E+04, -.27381000E+04, 0.42428500E+04, -.19193000E+04, -.46009800E+04, -.21275500E+04, 0.27516300E+04, 0.38381500E+03, -.52810100E+04, -.87536900E+04, -.38400500E+04, 0.21268900E+03, -.26442900E+04, 0.16495400E+05, -.80559400E+04, -.66644200E+04, -.82428300E+04, 0.32168700E+04, 0.49460000E+04, -.53126600E+04, -.10800200E+04, -.47967300E+04, 0.49038000E+04, -.90729900E+04, 0.49462400E+03, 0.25228100E+03, -.77238800E+04, -.26187000E+03, 0.98797300E+04, -.56935500E+03, -.97896900E+04, -.19162900E+05, -.54024900E+04, -.80532600E+03, -.74042100E+04, -.13146100E+05, 0.68277000E+04, 0.55803400E+04, 0.65696000E+04, 0.58681300E+04, 0.26442300E+04, -.72638500E+03, -.60251800E+04, 0.25266000E+04, 0.21799900E+04, 0.39796900E+04, -.37505900E+05, 0.19136100E+05, 0.16092700E+05, 0.18746300E+05, 0.80297000E+04, 0.21330400E+04, 0.77550200E+04, -.19950500E+03, 0.12526800E+05, 0.27571200E+04, 0.10131600E+05, -.38869900E+04, -.18338700E+04, -.29534000E+04, 0.20156200E+04, 0.36975500E+04, -.28155200E+03, -.30921700E+04, -.11357400E+04, -.66345800E+03, 0.16976000E+04, -.29694700E+04, -.40094100E+04, -.16381400E+04, 0.51903200E+03, -.38871600E+04, -.27976900E+04, 0.24474700E+04, 0.36349600E+04, -.35201600E+04, -.24594900E+04, -.17410300E+04, 0.22836400E+04, 0.40459400E+04, -.15964200E+04, 0.21121000E+04, -.28656100E+04 },
        { 0.20485600E+01, -.63342400E+00, -.87823100E-01, 0.85607100E+00, 0.71902000E+00, -.21290800E+01, 0.34903400E+01, 0.44806600E+00, 0.62314900E+00, -.16283100E+01, 0.73472200E-01, 0.58657600E-01, 0.36224400E+00, 0.10543600E+01, -.33606900E-01, 0.11606800E+01, 0.90021700E+00, -.12146800E+01, 0.10407300E+01, 0.37232200E+00, 0.38084900E+00, -.29423700E+00, 0.66315400E-01, -.24687800E+00, 0.33212300E+01, -.50455100E-01, 0.53722900E-02, -.21275800E+00, 0.94527500E+00, -.45997200E+00, 0.66646800E+04, -.89564600E+03, 0.18031600E+05, -.48763000E+04, 0.25658000E+04, -.48901800E+04, 0.24270700E+04, 0.57868200E+04, 0.56809200E+04, -.69512700E+04, -.14961000E+05, -.27829800E+04, 0.60004400E+04, -.15177000E+05, 0.11332900E+04, -.59947500E+03, -.24283900E+04, -.57724800E+03, 0.12813200E+05, 0.72589000E+04, -.10097700E+05, -.93220400E+04, -.83705000E+04, 0.52161200E+04, -.17006800E+05, -.39706600E+05, 0.19491700E+05, 0.28197200E+05, 0.19849900E+05, 0.10192600E+05, -.16146800E+04, 0.75533200E+04, 0.25532200E+04, 0.19588100E+05, -.18185600E+04, 0.21336100E+05, -.45806200E+05, 0.22725800E+05, 0.33194200E+05, 0.22892900E+05, 0.17486200E+05, 0.10812700E+05, 0.43817700E+04, -.67263800E+04, 0.18782700E+05, 0.10088700E+05, 0.12099800E+05, -.56096500E+05, 0.28017900E+05, 0.31018200E+05, 0.28039600E+05, 0.18094500E+05, 0.72371300E+04, 0.75247200E+04, -.49330000E+04, 0.22852000E+05, 0.70557300E+04, 0.12656600E+05, -.27320000E+05, 0.13531800E+05, -.68155600E+04, 0.13643600E+05, 0.95928500E+04, -.65603200E+03, 0.66988400E+03, -.23374700E+04, 0.36323700E+04, -.82259700E+03, 0.20762400E+04, 0.33715300E+05, -.16931700E+05, -.14762000E+05, -.16852200E+05, -.20743800E+05, -.92891600E+04, -.13746500E+04, 0.47739700E+04, -.47372000E+04, -.98401300E+04, 0.10604000E+05, 0.36550600E+05, -.17794900E+05, -.23185200E+05, -.18274400E+05, 0.11631600E+04, 0.44367400E+04, -.12099800E+05, -.26489000E+04, -.22506800E+05, 0.41649000E+04, -.18309500E+05, -.55532700E+05, 0.27921500E+05, 0.27585400E+05, 0.27754000E+05, 0.18011300E+05, 0.22425200E+04, 0.54916300E+04, -.14834500E+05, 0.19983300E+05, 0.37757100E+04, 0.12526100E+05, 0.64090400E+04, -.32236100E+04, -.22910600E+04, -.32029000E+04, -.28361800E+04, -.15183600E+04, -.80113000E+02, 0.16349400E+04, -.23639800E+04, -.16570800E+04, -.13721500E+04, 0.37789400E+05, -.16730200E+05, -.25956400E+05, -.18893400E+05, 0.54300500E+04, 0.34903200E+04, -.11308500E+05, -.13060700E+04, -.18088400E+05, 0.45086900E+04, -.25986000E+05, -.36006300E+04, 0.70853900E+03, 0.12610600E+05, 0.17996000E+04, 0.64443500E+04, 0.16888300E+04, -.18566400E+04, -.49625000E+04, 0.14622500E+04, 0.24111500E+04, -.68727300E+04, -.83305500E+04, 0.36665200E+04, 0.39078800E+04, 0.41662300E+04, -.85553000E+03, -.13810000E+04, -.10111300E+04, -.47386000E+04, 0.26756600E+04, -.11527300E+04, 0.78825100E+04, 0.39681400E+05, -.19534300E+05, 0.15558900E+05, -.19838900E+05, 0.17415000E+05, 0.14050000E+05, -.13051000E+05, 0.12268700E+04, -.21896400E+05, 0.12289400E+05, -.54192800E+05, -.32705200E+05, 0.15100200E+05, 0.12714200E+05, 0.16352100E+05, -.30009400E+04, -.38241600E+04, 0.10077000E+05, 0.15975000E+04, 0.19257200E+05, -.44130000E+04, 0.17759700E+05, 0.75298600E+05, -.37532200E+05, -.44250400E+05, -.37637500E+05, -.19813900E+05, 0.86255700E+03, -.10107300E+05, 0.43856000E+04, -.31447000E+05, 0.32009300E+03, -.26875300E+05, 0.20063300E+05, -.10007700E+05, -.11967500E+05, -.10022600E+05, -.98242900E+04, -.34892100E+04, -.39329000E+04, -.31409700E+04, -.14909200E+05, -.36732500E+04, -.54421100E+04, -.27568800E+05, 0.13959300E+05, 0.12401700E+05, 0.13776600E+05, 0.14093800E+05, 0.65351100E+04, 0.16695100E+04, -.42269200E+04, 0.26895900E+04, 0.75535800E+04, -.58494600E+04, 0.56052100E+05, -.26790200E+05, -.38010300E+05, -.28022200E+05, 0.16727400E+04, 0.36818700E+04, -.16020100E+05, -.11682500E+04, -.30038400E+05, 0.39629000E+04, -.33812900E+05, -.59237800E+05, 0.29845300E+05, 0.22670700E+05, 0.29600400E+05, 0.34368000E+05, 0.14928000E+05, 0.15601400E+04, -.10763000E+05, 0.18184300E+04, 0.16865900E+05, -.26561600E+05, -.23571300E+05, 0.11837100E+05, 0.15957200E+05, 0.11781300E+05, 0.13948000E+05, 0.62994500E+04, 0.12443500E+03, -.70615500E+04, 0.76316500E+04, 0.65127600E+04, -.36304500E+04, -.78543200E+04, 0.43754200E+04, 0.82382400E+04, 0.39186100E+04, 0.83148600E+04, 0.29481800E+03, -.35804200E+03, -.86177700E+04, 0.55923100E+04, 0.20919800E+04, -.13957400E+05, -.91189600E+04, -.66130200E+04, -.76930800E+04, 0.65334300E+04, 0.11468800E+02, -.51491000E+04, -.29106100E+04, -.21787200E+04, -.20760200E+03, 0.57647400E+04, -.58746700E+04, -.96360500E+04, -.30245000E+04, 0.26969300E+04, -.87259400E+04, -.82761400E+04, 0.86958300E+04, 0.73166800E+04, -.90493200E+04, -.41100100E+04, -.72002500E+04, 0.72721400E+04, 0.87817400E+04, -.69007700E+04, 0.46782500E+04, 0.20983100E+04 },
        { -.85287400E+00, -.57209100E+00, -.75284900E-01, -.22720500E+00, -.13725200E+01, -.96007900E+00, 0.49511000E+00, -.36345200E+00, -.96816600E-01, 0.11675000E+01, -.57867200E-01, -.12718000E-01, 0.16808500E+00, -.31641600E-01, -.82195400E+00, 0.58233000E+00, -.28773100E+00, -.96079500E+00, -.27152400E+00, -.11705900E+00, 0.11862000E+00, 0.62802400E-01, 0.13966900E+00, 0.16205300E+00, -.96439300E+00, -.36742300E-01, -.52113400E+00, -.72510500E+00, 0.80627000E+00, 0.38608500E+00, 0.44080100E-01, 0.13432300E+04, 0.36348800E+04, 0.14758600E+05, -.72908900E+04, -.90208700E+04, -.73638000E+04, 0.57119200E+03, 0.15392900E+04, -.62072500E+04, -.37142500E+04, -.55441100E+04, 0.68696700E+03, -.68829300E+04, -.33945300E+04, 0.17092400E+04, -.20684000E+04, 0.17121800E+04, 0.32584100E+03, 0.13956600E+04, -.49183400E+01, 0.60740700E+03, 0.16323000E+04, -.12638200E+03, 0.15635500E+04, -.93287200E+04, 0.44962200E+04, 0.34454500E+04, 0.46693800E+04, 0.31279300E+04, 0.14996500E+04, 0.32803400E+04, 0.52706600E+04, 0.45309500E+04, 0.13171400E+04, 0.50225800E+04, -.69876800E+04, 0.34504700E+04, 0.49052900E+04, 0.35081300E+04, 0.36818400E+04, 0.27418500E+04, -.69467900E+03, -.37931400E+04, 0.14671700E+04, 0.24918500E+04, 0.27910600E+04, -.57544100E+04, 0.28758800E+04, 0.21875700E+04, 0.28891600E+04, 0.39675400E+04, 0.44755800E+04, -.30341400E+03, -.15748700E+03, 0.18282800E+04, 0.35864600E+04, 0.16184700E+03, -.17001900E+05, 0.85302800E+04, -.76251300E+03, 0.85239400E+04, -.11459700E+03, 0.11356200E+04, 0.30492200E+04, 0.75559100E+03, 0.48539500E+04, 0.30830800E+03, 0.79313800E+04, 0.77155900E+04, -.38642800E+04, -.66058200E+03, -.38653200E+04, -.27282800E+04, -.35622600E+04, -.15495300E+04, -.29348300E+04, -.35969000E+04, -.13146700E+04, -.49616100E+03, 0.16289700E+05, -.80110200E+04, -.65133700E+04, -.81450300E+04, -.69488900E+03, -.34613300E+03, -.32793500E+04, 0.31750100E+04, -.34623100E+04, -.11952300E+04, -.62778200E+04, -.57928700E+04, 0.29486000E+04, 0.19870500E+04, 0.29139200E+04, 0.34041500E+04, 0.14722500E+04, 0.12187300E+03, -.18632900E+04, 0.18240700E+04, 0.83010000E+03, 0.12773400E+04, 0.16952500E+04, -.85582600E+03, -.49180000E+03, -.84989700E+03, -.50113600E+03, -.42415500E+03, -.21874700E+03, 0.49208600E+02, -.59610000E+03, -.33958500E+03, -.58099300E+03, 0.79771200E+04, -.35333100E+04, -.35840600E+04, -.39898300E+04, 0.19725300E+04, 0.58364300E+02, -.19694800E+04, 0.25759900E+04, -.14395600E+04, -.79801900E+03, -.45350500E+04, -.25138600E+04, 0.90098500E+03, 0.19998000E+04, 0.12580000E+04, 0.85162400E+03, 0.11287200E+04, 0.78866000E+03, 0.17316200E+04, 0.12287300E+04, 0.29010500E+03, 0.16215000E+04, -.34522700E+04, 0.15647100E+04, 0.15026400E+04, 0.17258400E+04, -.10668500E+04, -.12816100E+02, 0.11887500E+04, 0.13729500E+04, 0.16683900E+04, -.47674000E+02, 0.30092900E+04, 0.89418700E+04, -.43903200E+04, 0.58928600E+02, -.44735800E+04, 0.26825600E+04, 0.44258600E+04, -.42366500E+03, 0.62534600E+04, -.19021600E+04, 0.67905100E+03, -.89968600E+04, -.48993500E+04, 0.20919700E+04, 0.29377200E+04, 0.24499000E+04, -.10681000E+04, 0.21730900E+03, 0.10739400E+04, -.16100900E+04, 0.14231800E+03, 0.77069600E+03, 0.26228400E+04, 0.23679300E+05, -.11778000E+05, -.82205500E+04, -.11856300E+05, -.50513000E+04, -.12078800E+04, -.60720900E+04, -.42455300E+04, -.94342600E+04, -.86171600E+03, -.10609500E+05, -.16797000E+03, 0.14228100E+03, -.44042300E+03, 0.71107800E+02, -.18613900E+04, 0.35500600E+03, 0.55033700E+03, 0.44636700E+03, -.40534900E+02, 0.30739100E+03, -.75306600E+03, -.12865200E+05, 0.65111800E+04, 0.41211000E+04, 0.64437200E+04, 0.20228100E+04, 0.27513500E+04, 0.37151400E+04, 0.31690500E+04, 0.49024600E+04, 0.13902200E+04, 0.30371600E+04, 0.21595200E+05, -.10507800E+05, -.82891800E+04, -.10800600E+05, 0.19447300E+03, 0.24384500E+02, -.46634000E+04, 0.45131400E+04, -.50033700E+04, -.13204900E+04, -.95763200E+04, -.19744700E+05, 0.10034800E+05, 0.15090300E+04, 0.98982000E+04, 0.40192500E+04, 0.83532400E+04, 0.54282700E+04, 0.83987300E+04, 0.78576800E+04, 0.36978700E+04, 0.27709000E+04, -.11129300E+05, 0.56325300E+04, 0.47312300E+04, 0.55709800E+04, 0.30756300E+04, 0.30442500E+04, 0.16314800E+04, -.78380100E+03, 0.30781700E+04, 0.18361700E+04, 0.22866600E+04, 0.13272300E+05, -.64828500E+04, -.59243800E+04, -.66239900E+04, 0.18999900E+04, 0.11932000E+04, -.46874500E+04, -.21251500E+04, -.48813700E+04, 0.44502100E+03, -.69692600E+04, -.25623700E+04, -.16797700E+04, -.12083600E+04, 0.16749900E+04, -.60274100E+03, -.56244200E+03, -.47652700E+03, -.70373100E+03, 0.10781900E+04, 0.16779700E+04, -.14476700E+04, -.29355400E+04, -.26719400E+02, 0.72208800E+03, -.22048900E+04, -.20155100E+04, 0.17752600E+04, 0.17527000E+04, -.15338800E+04, -.56592300E+03, -.12280800E+04, 0.48285800E+04, 0.28428700E+04, -.34802500E+04, 0.89191000E+03, 0.64453600E+03 },
        { -.16182700E+01, -.11299100E+01, -.93658600E-01, 0.35598400E+00, -.66513500E+00, -.81411300E+00, -.13708800E+01, -.64133500E+00, -.99189200E+00, 0.12254900E+01, 0.40168500E-01, -.14520900E+00, -.29411500E+00, 0.10093100E+01, -.30450900E+01, -.14763400E+00, 0.27745600E+00, -.69437600E+00, 0.11911900E+01, -.15891100E+01, 0.86361400E+00, 0.23439100E-01, 0.30879900E-02, -.45669400E+00, 0.23374800E+01, 0.12845000E-01, -.73758600E-01, -.71072100E+00, -.39269300E+00, -.36266800E+00, 0.36404000E+00, 0.52632800E+00, -.93090000E+04, -.35508100E+05, 0.17871600E+05, -.92625500E+04, 0.17759000E+05, 0.42586200E+04, -.22656200E+04, 0.76099500E+04, -.18015600E+04, 0.13133600E+05, -.16338800E+04, 0.20911600E+05, -.94422900E+04, 0.47686700E+04, -.17021900E+05, 0.47258600E+04, -.11419800E+04, -.25998400E+04, 0.24866300E+04, -.27386900E+04, 0.49347100E+04, -.15787300E+04, 0.99403900E+04, 0.88054900E+04, -.45087800E+04, -.19737900E+05, -.44012400E+04, -.73317300E+04, -.43444600E+04, -.15116900E+03, -.10889300E+04, -.37039400E+04, -.34604700E+04, -.80737300E+04, 0.17116600E+05, -.84941900E+04, -.23225100E+05, -.85537900E+04, -.10866800E+05, -.65674300E+04, -.85341100E+03, 0.79270200E+03, -.77398100E+04, -.53074800E+04, -.63336400E+04, 0.14323900E+05, -.71065900E+04, -.31591700E+05, -.71581200E+04, -.10228100E+05, -.58058500E+04, -.22834800E+04, -.29333800E+04, -.74907300E+04, -.41256400E+04, -.20885700E+04, -.73282400E+04, 0.38236000E+04, -.11934600E+05, 0.36714400E+04, -.42579600E+04, -.43382200E+04, 0.15278400E+04, -.50282000E+04, 0.37593300E+04, -.32107600E+04, 0.59543900E+04, -.18109300E+05, 0.90565200E+04, 0.22261800E+05, 0.90522200E+04, 0.11679700E+05, 0.86237100E+04, 0.14320800E+04, 0.31736300E+04, 0.61807200E+04, 0.69484000E+04, -.19330000E+03, -.18601300E+05, 0.90869100E+04, 0.12994200E+05, 0.93001400E+04, 0.76267000E+03, -.10976500E+04, 0.60007800E+04, 0.21307600E+04, 0.93368900E+04, -.93045600E+03, 0.10045400E+05, 0.15234700E+05, -.75016800E+04, -.36027700E+05, -.76118600E+04, -.11631300E+05, -.91227700E+04, 0.70140000E+03, 0.49097200E+03, -.69462100E+04, -.72399200E+04, -.48587500E+04, -.17366400E+04, 0.85167000E+03, 0.44484700E+04, 0.86759900E+03, 0.12889900E+04, 0.98275800E+03, 0.16269500E+03, 0.33354100E+03, 0.10078900E+04, 0.76472900E+03, 0.36437100E+03, -.37102500E+05, 0.18598400E+05, -.13552800E+04, 0.18550600E+05, 0.35431200E+04, 0.31855500E+03, 0.60235100E+04, -.40884400E+04, 0.12825600E+05, 0.41885100E+03, 0.20901500E+05, -.20924500E+05, 0.10321700E+05, -.20460100E+05, 0.10462600E+05, 0.68968700E+04, 0.62016400E+04, -.39706000E+03, -.45060900E+04, 0.56281000E+04, 0.47771900E+04, 0.13193700E+05, 0.27502700E+04, -.14898700E+04, -.98697600E+03, -.13749300E+04, 0.19002600E+04, 0.19653400E+04, -.51642700E+03, 0.13148400E+04, -.68751100E+03, 0.15094900E+04, -.26517200E+04, 0.12950000E+04, -.68256700E+03, -.75225900E+03, -.64831400E+03, -.48903500E+04, -.14820700E+04, -.96039600E+03, -.33882400E+04, -.22223400E+04, -.44806300E+03, 0.13339400E+05, 0.33787400E+05, -.17054900E+05, 0.11277500E+05, -.16893400E+05, -.50394500E+04, -.12868700E+04, -.40794400E+04, 0.51384200E+04, -.13122900E+05, -.94426900E+03, -.17637500E+05, -.12338300E+05, 0.61401500E+04, 0.47232800E+05, 0.61639000E+04, 0.91408100E+04, 0.58866900E+04, 0.82789000E+03, 0.26427900E+04, 0.43173100E+04, 0.45809400E+04, 0.44233800E+04, -.48116100E+04, 0.24411200E+04, 0.97317000E+04, 0.24017900E+04, 0.48667800E+04, 0.23584100E+04, -.40245300E+03, -.26226700E+03, 0.39006100E+04, 0.20569300E+04, 0.27672600E+04, 0.20466800E+05, -.10192400E+05, -.12110400E+05, -.10229900E+05, -.10238600E+05, -.64363200E+04, -.24734400E+04, -.21618200E+03, -.60701600E+04, -.56241300E+04, -.16564100E+04, -.36647600E+05, 0.18039900E+05, 0.17525300E+05, 0.18321900E+05, 0.27740400E+04, 0.29208900E+02, 0.88447700E+04, 0.56213900E+03, 0.15174200E+05, 0.18331400E+03, 0.21379700E+05, 0.24832500E+05, -.12266500E+05, -.23086700E+05, -.12408000E+05, -.20401700E+05, -.14562200E+05, -.27530700E+04, -.57646500E+04, -.66151400E+04, -.11800700E+05, 0.80628000E+04, -.43820200E+03, 0.32500000E+03, -.28704500E+05, 0.22105400E+03, -.29041800E+04, -.17499700E+04, -.10375000E+04, -.37073200E+04, -.23106800E+04, -.11590100E+04, 0.66038100E+04, -.26000500E+05, 0.13128200E+05, -.15904800E+05, 0.13004000E+05, 0.10462000E+04, -.20950800E+04, 0.54739400E+04, -.17503700E+04, 0.73312900E+04, -.16798400E+04, 0.15303200E+05, 0.22599600E+04, 0.25579000E+04, 0.30026100E+04, -.27599000E+04, -.65932800E+04, 0.58628600E+04, 0.94852500E+03, -.24801200E+03, 0.20540200E+03, -.32237600E+04, 0.28321700E+04, 0.26187300E+04, -.33990400E+04, -.14141800E+04, 0.43144000E+04, 0.86858900E+04, -.30523100E+04, -.23352300E+04, 0.70429700E+04, 0.31230300E+04, 0.24827200E+04, -.56340800E+04, -.28668400E+04, 0.48861200E+04, -.26010000E+04, 0.83922600E+04 },
        { -.13315800E+01, 0.45838600E+00, 0.87612500E-01, 0.57056400E+00, 0.37168500E+00, -.12377100E+01, -.31161700E+00, -.56726900E+00, -.45307000E+00, 0.31234000E+00, 0.76629700E-02, -.52831200E-01, -.24482400E+00, 0.87896700E+00, -.78632200E-01, -.32811700E+00, 0.10508000E+01, 0.58891700E+00, 0.21240700E+00, 0.21319600E+00, -.44585800E+00, -.97801200E-01, -.21998900E+00, -.81986100E-01, -.18909000E+00, -.17808000E-01, 0.24651400E+00, 0.97907800E+00, -.51276800E+00, -.37320000E+00, 0.29859800E-01, -.19018700E+00, 0.48144000E+00, 0.39505800E+05, -.20407100E+05, -.67421200E+03, -.19724200E+05, -.72701400E+04, -.75073500E+03, -.41661400E+04, 0.73605900E+04, -.12720200E+05, -.10785500E+04, -.15995300E+05, 0.21743900E+05, -.11118100E+05, 0.53496400E+04, -.10844500E+05, -.68401500E+04, -.25533700E+04, 0.18449400E+04, 0.95375500E+04, -.55044100E+04, -.27433200E+04, -.93473300E+04, 0.11772200E+05, -.49977500E+04, 0.28001800E+04, -.58772900E+04, -.38464500E+04, 0.27004400E+03, -.13884000E+04, -.17894800E+03, -.45945200E+04, 0.38729800E+03, -.29578500E+04, 0.14763100E+05, -.74483400E+04, -.81233900E+03, -.73552200E+04, -.23098800E+04, -.11463500E+04, -.14277900E+04, 0.27123900E+04, -.45575600E+04, -.85414700E+03, -.66453200E+04, 0.17452500E+05, -.89316400E+04, 0.68230700E+04, -.87038700E+04, -.36651500E+04, -.59808200E+02, -.10814400E+04, 0.41344100E+04, -.52488200E+04, -.18132100E+02, -.97729100E+04, 0.21658700E+05, -.11396600E+05, 0.38369600E+04, -.10786800E+05, -.43293400E+04, -.83207900E+03, 0.63072900E+03, 0.69959000E+04, -.53627300E+04, -.13731900E+04, -.90993400E+04, -.14647900E+04, 0.93607900E+03, -.93989400E+04, 0.71821000E+03, 0.26714100E+04, -.50283300E+03, -.17180200E+04, -.32696900E+04, 0.62439400E+03, -.54986000E+03, -.62132500E+03, -.67240100E+04, 0.37538700E+04, 0.11318000E+04, 0.33596900E+04, 0.27954900E+03, 0.17480100E+04, 0.44029700E+03, -.16423000E+04, 0.15497900E+04, 0.17449800E+04, 0.15421000E+04, 0.21586200E+05, -.11332600E+05, 0.92054400E+04, -.10761100E+05, -.40003800E+04, 0.38933700E+04, -.32301000E+04, 0.50722200E+04, -.68814200E+04, 0.33428100E+04, -.91798200E+04, -.24304900E+04, 0.12977000E+04, -.13410400E+04, 0.12110500E+04, 0.68385500E+03, 0.11436200E+03, -.95786600E+02, -.94334600E+03, 0.53939700E+03, 0.84265500E+02, 0.12941000E+04, 0.73306100E+04, -.51687700E+04, 0.53510700E+04, -.36687700E+04, -.43419900E+04, 0.43597700E+02, 0.65029500E+03, 0.22275400E+04, -.92395100E+03, 0.53837800E+03, -.49326400E+04, 0.19867200E+05, -.84212500E+04, 0.98568600E+04, -.99317100E+04, -.53126300E+04, -.18696700E+04, -.25648700E+03, 0.61327800E+04, -.48254400E+04, -.13759100E+04, -.11857400E+05, 0.22588400E+04, -.14926500E+03, -.64861900E+03, -.11302500E+04, 0.10730200E+04, 0.88692400E+03, 0.42664800E+03, 0.19692400E+04, -.48387800E+03, 0.63773700E+03, -.22393700E+04, -.13135500E+05, 0.62667500E+04, -.14804300E+04, 0.65629600E+04, -.24953800E+04, -.25813700E+04, 0.72034300E+04, 0.77889700E+04, 0.87589300E+04, -.26385500E+04, 0.58051100E+04, -.12031800E+05, 0.75232600E+04, -.96702300E+04, 0.60171400E+04, 0.57193900E+04, 0.19817400E+04, -.99781700E+03, -.29205600E+04, 0.45611700E+04, 0.13103100E+04, 0.67564300E+04, -.19778500E+05, 0.97556200E+04, -.12630900E+05, 0.98588300E+04, 0.81825600E+04, 0.11332900E+04, -.42395600E+03, -.35935400E+04, 0.84900600E+04, 0.67252700E+03, 0.80734000E+04, -.63211500E+04, 0.29111500E+04, 0.79223000E+02, 0.31371500E+04, 0.97200300E+03, 0.57471500E+02, 0.19928200E+04, 0.10777600E+04, 0.18791800E+04, -.22936500E+03, 0.23199800E+04, -.58953600E+04, 0.24690900E+04, 0.45828800E+04, 0.29680400E+04, 0.17890400E+03, 0.12676300E+04, 0.22527700E+04, 0.16005100E+04, 0.20607300E+04, 0.11328600E+04, 0.25634400E+04, -.54641100E+04, 0.29150100E+04, 0.17982600E+04, 0.27221100E+04, -.92144900E+03, 0.22119200E+04, 0.46168600E+03, -.13966300E+04, 0.22806400E+04, 0.23105000E+04, -.14840300E+03, -.17450300E+04, -.40484700E+03, 0.10570100E+05, 0.92029000E+03, -.21862900E+04, 0.21675800E+04, 0.60663400E+04, 0.10008700E+05, 0.27680800E+04, 0.14230600E+04, 0.10365500E+04, 0.12879400E+05, -.71229600E+04, 0.10286800E+05, -.64281600E+04, -.53745400E+04, -.20490400E+04, 0.11471500E+04, 0.63389200E+04, -.20891400E+04, -.14517800E+04, -.73976200E+04, 0.29110700E+05, -.15451800E+05, 0.24528800E+04, -.14533200E+05, -.62545100E+04, 0.14466200E+04, -.45322800E+04, 0.44087900E+04, -.92880600E+04, 0.11327500E+04, -.11265400E+05, 0.34514100E+04, 0.19361300E+04, 0.22697700E+04, -.20715900E+04, 0.30448500E+04, -.93242900E+03, 0.94817900E+03, 0.15025500E+04, -.34508700E+03, -.15594900E+04, 0.19065100E+04, 0.40571500E+04, 0.30612800E+04, -.51057600E+03, 0.24218200E+04, -.79421100E+03, -.22952700E+04, -.29185900E+04, 0.63653100E+03, -.54775900E+03, 0.16017800E+04, -.13777700E+04, -.37923000E+04, 0.12642400E+04, -.11426000E+04, -.52982300E+04 },
        { -.25121100E+01, 0.44049300E+00, 0.12197800E-01, -.61179600E+00, -.29667300E+00, 0.24932400E+01, -.46477800E+01, 0.19612600E+00, -.18136800E+01, 0.22409900E+01, 0.58353200E-01, -.28625400E+00, -.37295600E+00, 0.83121500E+00, -.92221500E+00, -.25716200E+01, -.63276100E+00, 0.86524900E+00, 0.36501400E+00, -.30859500E+01, -.41718100E+00, 0.27012700E+00, -.48095300E+00, -.11288100E+00, 0.31384800E+00, 0.96988800E-01, 0.73054100E+00, -.24297000E+00, -.18563100E+00, 0.10009900E+00, 0.33805600E-01, -.58146700E+00, 0.26990600E+00, 0.11373100E+01, 0.12459600E+04, 0.55910100E+04, -.16028800E+03, -.53995000E+04, -.10249400E+05, 0.33248800E+04, 0.27895800E+04, 0.21065700E+04, -.10128700E+05, 0.97721500E+03, -.12096100E+05, 0.64999800E+04, 0.60745200E+04, 0.58945200E+04, -.23025300E+04, 0.27376000E+04, -.18354000E+04, -.91131400E+04, -.65306500E+03, 0.22525100E+04, 0.13881300E+05, 0.41844300E+04, -.36395500E+04, -.21841000E+04, -.21425900E+04, 0.55995900E+04, 0.80967300E+04, -.15004000E+04, 0.56604400E+04, -.57397500E+03, 0.55748300E+04, 0.11506100E+04, 0.47193200E+04, -.21360300E+04, 0.42840900E+04, -.25069200E+04, 0.91245200E+03, -.19890500E+04, -.43863400E+03, 0.31479700E+04, 0.40225200E+03, -.29686900E+04, 0.41589700E+03, 0.30346500E+04, -.11111500E+04, 0.27871800E+04, -.16415000E+04, -.69753300E+03, -.84931400E+03, -.16239300E+04, -.73320600E+02, -.48490800E+03, -.89353000E+03, 0.55571600E+04, -.10358700E+05, 0.62772800E+04, 0.18655100E+04, 0.49419200E+04, -.27574100E+04, 0.37464200E+04, -.24457700E+04, -.93770500E+04, -.84064700E+03, 0.36200500E+04, 0.16442300E+05, 0.12815500E+05, -.66720400E+04, -.59764200E+04, -.63292500E+04, -.16955700E+03, -.16461400E+04, -.11731800E+04, 0.32626000E+04, -.29605800E+04, -.17972500E+04, -.96151700E+04, -.29857100E+05, 0.13812600E+05, 0.12582400E+05, 0.14936500E+05, -.17978000E+04, -.55886700E+04, 0.10768200E+05, -.36665900E+03, 0.10452800E+05, -.51110600E+04, 0.13398900E+05, 0.21691600E+04, -.66689500E+02, 0.13120900E+04, -.12639500E+04, -.26003900E+03, -.52985700E+04, 0.13940900E+04, 0.58183600E+04, 0.22696500E+04, -.68030900E+04, 0.33844200E+04, 0.12908000E+03, -.22118500E+03, -.70719400E+03, -.41117500E+02, 0.38800000E+03, 0.82633900E+03, -.35930300E+03, -.74333500E+03, -.40223200E+03, 0.91662300E+03, -.73615800E+03, -.41109500E+04, 0.49007800E+04, 0.14330500E+05, 0.20720200E+04, -.10216300E+05, -.11616500E+05, 0.91447600E+04, 0.52024400E+04, 0.38797500E+04, -.11637400E+05, 0.59134100E+04, 0.16552300E+05, -.10932500E+05, 0.20121300E+04, -.82868800E+04, -.43940000E+04, -.11849100E+04, -.40558300E+03, 0.54213500E+04, -.44253200E+04, -.98256400E+03, -.51261500E+04, 0.32749800E+04, -.33773200E+04, -.36349700E+04, -.16331100E+04, 0.48538800E+03, 0.36925500E+04, -.34198700E+03, 0.23258100E+04, -.11761600E+02, 0.37654300E+04, -.14289600E+04, 0.21408300E+05, -.10297200E+05, -.64455000E+04, -.10677200E+05, 0.69992100E+03, 0.88365600E+04, -.76608100E+04, -.27391500E+04, -.96020500E+04, 0.73887200E+04, -.97111700E+03, 0.10991200E+04, -.33558500E+04, -.12843500E+05, -.55448300E+03, 0.54325900E+04, 0.56093200E+04, -.32821100E+04, 0.42176100E+03, 0.68057600E+03, 0.53645800E+04, -.17722700E+04, -.13790500E+05, 0.70399600E+04, -.14954800E+04, 0.70661100E+04, -.33019800E+04, -.75909900E+04, 0.32530200E+04, -.68432300E+04, 0.36973500E+04, -.46017100E+04, -.33759300E+03, -.60485900E+04, 0.34084500E+04, -.21126800E+04, 0.31560100E+04, 0.12276300E+04, 0.43873500E+03, 0.11565100E+04, -.98002700E+03, 0.29955700E+04, 0.88124100E+03, 0.20696200E+04, -.17652300E+05, 0.96057300E+04, 0.87978800E+04, 0.87120400E+04, 0.41003700E+04, 0.33370300E+04, 0.28872100E+04, -.16847700E+04, 0.34659200E+04, 0.31992600E+04, 0.92714800E+04, -.35045400E+05, 0.16686500E+05, 0.19090700E+05, 0.17567000E+05, -.68008200E+04, -.12312400E+05, 0.16916900E+05, 0.30052900E+04, 0.14181200E+05, -.11887800E+05, 0.18722300E+05, -.28092700E+05, 0.16159700E+05, 0.12063600E+05, 0.13779700E+05, 0.34295300E+04, 0.72495000E+04, 0.25415900E+04, -.86146100E+04, 0.35801100E+04, 0.74080900E+04, 0.23626700E+05, 0.82446400E+04, -.29377300E+04, 0.35917600E+04, -.41871100E+04, -.42471400E+04, -.50684800E+04, 0.52778300E+03, 0.36667300E+04, -.12890000E+04, -.48126900E+04, -.45877100E+03, 0.14958900E+05, -.58216200E+04, -.33908600E+03, -.76039200E+04, -.50361200E+04, -.93172100E+04, 0.63683300E+03, 0.66750400E+04, -.16670000E+04, -.97713700E+04, -.42443200E+04, 0.60066100E+03, -.15721900E+03, 0.10217600E+04, -.53897600E+03, -.38294700E+04, 0.19742300E+04, 0.99836600E+03, 0.32947000E+03, -.56189900E+03, -.43842000E+03, 0.12327800E+04, 0.31750200E+04, 0.18628600E+04, -.36584300E+03, 0.23329700E+04, -.81857800E+03, -.13828400E+04, -.46579900E+03, 0.67709200E+03, 0.10668400E+04, -.42436700E+03, -.10262300E+04, -.28485400E+04, 0.81962600E+03, 0.12700800E+04, 0.12851100E+04 },
        { -.29117400E+01, 0.11172900E+01, 0.20570400E-01, -.36279400E+00, -.10634400E+01, 0.23778000E+01, -.51494600E+01, -.10915700E+01, -.11279900E+01, 0.24100700E+01, -.20398500E+00, -.16169800E+00, -.48430300E+01, 0.43083900E+01, -.34784600E+01, -.35421300E+01, 0.52096700E+00, 0.82014700E+00, 0.55142000E+00, 0.20185800E+01, 0.35953800E-01, -.50377600E-02, -.82721600E-01, 0.49643000E+00, -.56695300E+01, 0.11980700E+00, -.60173500E+00, -.38031800E+00, 0.95608200E-01, -.54535900E+00, -.51441200E+00, 0.71017300E+00, -.81794300E+00, 0.20121300E+00, -.30534100E+00, 0.41995000E+05, -.10567500E+03, -.22845800E+05, -.16302000E+05, 0.13555500E+05, 0.12214000E+05, -.21163100E+04, -.10637500E+05, -.13368100E+05, 0.46511400E+05, -.23279700E+05, 0.15230700E+05, -.23356300E+05, -.24715700E+05, -.25095300E+05, 0.34371100E+04, 0.88271000E+04, -.13703600E+05, -.19007300E+05, -.28391400E+05, 0.41941100E+05, -.21058100E+05, -.23765700E+04, -.21001900E+05, -.22008300E+05, -.17689100E+05, 0.22084800E+03, 0.55418900E+03, -.14074800E+05, -.12882800E+05, -.29242000E+05, 0.59889000E+05, -.30041400E+05, 0.37978900E+04, -.30041100E+05, -.27566800E+05, -.12779000E+05, -.45311000E+03, 0.97907600E+04, -.25987800E+05, -.85047800E+04, -.36462700E+05, 0.64460500E+05, -.32281400E+05, 0.69604500E+04, -.32313100E+05, -.35520000E+05, -.25173600E+05, 0.21250600E+04, 0.72071700E+04, -.25457600E+05, -.18792400E+05, -.35735600E+05, 0.12866400E+05, -.63263700E+04, 0.11450400E+05, -.65895400E+04, -.17168200E+05, -.23475400E+05, 0.57750200E+04, -.52247700E+03, 0.16080400E+04, -.18167400E+05, -.12681800E+05, -.34036600E+05, 0.17243300E+05, 0.30120900E+03, 0.17071100E+05, 0.20625700E+05, 0.18897000E+05, 0.12302500E+04, 0.13045500E+04, 0.15373200E+05, 0.13782600E+05, 0.24123600E+05, -.84063400E+05, 0.42124100E+05, 0.20371300E+05, 0.42045000E+05, 0.94000800E+04, 0.93539900E+04, 0.44723500E+04, -.15843600E+05, 0.32947400E+05, 0.76494600E+04, 0.44020500E+05, 0.70771200E+05, -.35465200E+05, 0.51913400E+04, -.35502400E+05, -.41702600E+05, -.26280600E+05, 0.39108300E+04, 0.10853200E+05, -.29014300E+05, -.18109000E+05, -.44447600E+05, -.12397500E+05, 0.62121300E+04, -.33138200E+03, 0.62141100E+04, 0.56597300E+04, 0.33857900E+04, 0.59329700E+03, -.60150400E+03, 0.51321700E+04, 0.23253500E+04, 0.65544300E+04, -.35341900E+05, 0.18094600E+05, 0.34709500E+05, 0.17686500E+05, -.98560100E+04, -.39120600E+04, 0.29645900E+04, -.11599000E+05, 0.14929900E+05, -.19581000E+04, 0.17854900E+05, 0.91966300E+05, -.46218900E+05, 0.22867800E+05, -.45989800E+05, -.26455700E+05, -.15250100E+05, -.76337300E+04, 0.61566200E+04, -.38978600E+05, -.95823700E+04, -.46747800E+05, 0.22044000E+05, -.10936700E+05, -.12685400E+05, -.11019100E+05, 0.25768900E+04, 0.20841700E+04, -.64988600E+04, -.11348400E+04, -.86046100E+04, 0.20446000E+04, -.79843300E+04, 0.54691200E+04, -.27899100E+04, -.27930500E+04, -.27172400E+04, 0.11002100E+04, -.95341000E+04, -.35675600E+04, -.11458900E+05, -.61838700E+04, -.62244900E+04, -.93432600E+04, -.33956400E+05, 0.16713900E+05, -.38840300E+05, 0.16971600E+05, 0.23064500E+05, 0.13452400E+05, 0.18953200E+04, 0.20414700E+03, 0.11441000E+05, 0.10848800E+05, 0.14197100E+05, -.12780500E+06, 0.63920800E+05, -.17643200E+04, 0.64013100E+05, 0.56101500E+05, 0.37643600E+05, 0.51067200E+04, -.12017400E+05, 0.44933300E+05, 0.28714800E+05, 0.70168800E+05, -.28562100E+05, 0.14392900E+05, -.47033700E+04, 0.14366200E+05, 0.14885600E+05, 0.81855900E+04, -.32587200E+04, -.75003000E+04, 0.14251300E+05, 0.51658200E+04, 0.21109500E+05, 0.33584700E+05, -.16742400E+05, -.18271800E+05, -.16866700E+05, -.82163400E+04, -.94906900E+04, -.86198100E+04, -.93366600E+04, -.13643800E+05, -.70463800E+04, -.15886600E+05, -.13182400E+06, 0.66186500E+05, 0.36134000E+05, 0.65959200E+05, 0.12757400E+05, 0.12469900E+05, 0.79360400E+04, -.25857500E+05, 0.52179400E+05, 0.11031400E+05, 0.67176800E+05, 0.46820100E+05, -.23357900E+05, -.16388000E+05, -.23585700E+05, -.18119800E+05, -.30332300E+05, -.11342900E+05, -.22475200E+05, -.19430200E+05, -.22195900E+05, -.29809700E+05, 0.82134600E+05, -.41189900E+05, 0.60666900E+04, -.41109500E+05, -.35713800E+05, -.22964500E+05, -.35265700E+04, 0.65544000E+04, -.35097800E+05, -.16720900E+05, -.41846300E+05, 0.58072700E+04, -.29122700E+04, 0.37331500E+05, -.29841200E+04, -.26312100E+05, -.18398700E+05, 0.13251900E+05, 0.88056600E+04, -.80876600E+04, -.11226900E+05, -.19974300E+05, 0.19739700E+05, 0.16643900E+05, 0.14635400E+05, -.16658300E+05, -.10434000E+05, 0.16054700E+05, 0.11653900E+05, 0.10367300E+05, -.72623600E+04, -.15973900E+05, 0.15530200E+05, 0.16213900E+05, 0.33223500E+04, -.84293700E+04, 0.18944700E+05, 0.70463300E+04, -.18271600E+05, -.14511200E+05, 0.11763500E+05, 0.33541200E+04, 0.14688500E+05, -.23797600E+05, -.18768100E+05, 0.21616500E+05, -.73389200E+04, 0.72866900E+04 },
        { 0.37730500E+01, -.37976100E+01, -.45874400E+00, 0.31634700E+00, 0.11115800E+01, -.57547400E+01, 0.61663700E+01, -.52234800E+01, 0.27862600E+01, -.26674300E+01, -.10524400E+00, 0.43936800E+00, -.20686800E+01, 0.93590300E-01, -.93779900E+00, 0.10693100E+01, 0.21362900E+01, -.36892000E+00, -.10929400E+01, 0.79539300E+00, -.78177200E+00, -.60591100E-01, 0.35793300E+00, 0.19939200E+00, -.76557000E+00, -.30592500E+00, -.27283300E+00, -.14398100E+01, 0.38734000E+00, 0.48003800E+00, -.42699200E+00, 0.43240200E+00, -.30924000E+00, -.62821600E+00, 0.35695800E+00, -.10869000E+00, 0.42419800E+03, 0.15405500E+05, 0.14846900E+05, -.70271900E+04, -.74935600E+04, -.40256400E+04, 0.14858500E+05, -.89659200E+04, -.31270600E+04, 0.15046900E+04, 0.14198500E+04, 0.19698600E+04, 0.85935300E+04, 0.56613700E+04, 0.28708000E+04, 0.10492600E+05, 0.82875700E+04, 0.46381000E+04, -.44347100E+04, -.35142100E+05, 0.17526400E+05, 0.16444600E+05, 0.17704300E+05, -.33317100E+04, -.79648000E+04, 0.87515900E+04, -.43988500E+03, 0.11772300E+05, -.57354200E+04, 0.14744800E+05, -.43305400E+05, 0.21586300E+05, 0.12574700E+05, 0.22042400E+05, 0.43786800E+04, 0.70884300E+03, 0.40596300E+04, -.13576500E+05, 0.97145400E+04, 0.28403200E+04, 0.13503200E+05, -.28248700E+05, 0.14065000E+05, 0.10104400E+05, 0.14453000E+05, 0.70357900E+04, 0.71384600E+04, 0.77425800E+03, -.71714500E+04, 0.57063500E+04, 0.70919200E+04, 0.68669200E+04, -.28779600E+04, 0.13269100E+04, 0.11189900E+05, 0.20672400E+04, 0.94793000E+04, 0.11480600E+05, 0.42542700E+03, 0.11658000E+05, 0.58576800E+04, 0.88058700E+04, -.73443700E+04, 0.12718000E+05, -.62897800E+04, -.47002100E+04, -.65667800E+04, -.71253100E+04, -.49033100E+04, -.29671500E+04, -.50435200E+04, -.82621200E+04, -.41332800E+04, -.19692700E+04, 0.50510700E+05, -.24894000E+05, -.18686900E+05, -.25276500E+05, 0.28655000E+04, 0.54397900E+04, -.10649900E+05, 0.10326400E+05, -.12875200E+05, 0.48309400E+04, -.19639000E+05, -.37674200E+05, 0.18795500E+05, 0.18250600E+05, 0.19311700E+05, 0.13148800E+05, 0.11288100E+05, 0.21181500E+04, -.92724000E+04, 0.76509100E+04, 0.12331100E+05, 0.77009500E+04, 0.52050300E+04, -.25971600E+04, -.23840200E+04, -.26645000E+04, -.18929100E+04, -.16743500E+04, -.23815400E+03, 0.11612400E+04, -.92040300E+03, -.16919800E+04, -.12786000E+04, 0.11135800E+05, -.53422900E+04, -.84213400E+04, -.56118600E+04, 0.19551300E+05, 0.19435100E+05, -.11097600E+05, -.38313900E+02, -.79087400E+04, 0.19058000E+05, -.77206000E+04, -.52162700E+05, 0.25884000E+05, 0.10339700E+05, 0.26109700E+05, 0.99134500E+03, -.43173800E+04, 0.10220900E+05, -.59690000E+04, 0.14629200E+05, -.42725800E+04, 0.22659800E+05, -.17670800E+05, 0.88218600E+04, 0.11957200E+05, 0.88255000E+04, -.86213500E+04, -.86301500E+04, 0.51496800E+04, -.27350100E+04, 0.53654200E+04, -.87233100E+04, 0.11100900E+05, -.52517200E+05, 0.26265900E+05, 0.11710600E+05, 0.26196000E+05, -.91193500E+03, -.10128700E+05, 0.16158500E+05, 0.35421000E+04, 0.18546700E+05, -.72184200E+04, 0.20386800E+05, -.16424600E+05, 0.80032000E+04, 0.17794500E+05, 0.82254100E+04, -.10582300E+05, -.10484200E+05, 0.65154400E+04, -.56008300E+04, 0.90683400E+03, -.97846300E+04, 0.59896500E+04, 0.60178600E+05, -.30017800E+05, -.26312800E+05, -.30541300E+05, -.95275300E+03, 0.63772500E+04, -.13223900E+05, 0.15282800E+04, -.22187500E+05, 0.35662900E+04, -.24146500E+05, 0.21097100E+05, -.10511800E+05, -.58278900E+04, -.10897100E+05, -.47524900E+04, -.48373900E+02, -.24676600E+04, 0.48928300E+04, -.46006100E+04, -.42519700E+03, -.71846900E+04, 0.22375200E+04, -.11634000E+04, -.12672900E+04, -.81684400E+03, -.25378300E+04, -.82179800E+02, 0.12191000E+04, 0.70516300E+04, 0.59289600E+04, -.87772700E+03, 0.69126900E+03, 0.57802300E+05, -.28396200E+05, -.21525900E+05, -.29019000E+05, 0.12536000E+05, 0.16063600E+05, -.17095900E+05, 0.10026400E+05, -.19381400E+05, 0.15422200E+05, -.25630900E+05, -.20928400E+05, 0.10275900E+05, 0.98388500E+04, 0.11169800E+05, 0.38557000E+04, 0.62757000E+04, 0.71336700E+04, 0.16966100E+05, 0.19055400E+05, 0.49084500E+04, 0.45729100E+04, -.37880400E+05, 0.18866200E+05, 0.12568400E+05, 0.19111700E+05, 0.10582600E+05, 0.10675600E+05, 0.24122500E+04, -.85990900E+04, 0.66707000E+04, 0.95848600E+04, 0.14055700E+05, -.24098300E+05, 0.12086600E+05, 0.86550400E+04, 0.12378500E+05, 0.16766600E+05, 0.14129700E+05, -.25034100E+04, -.11322100E+05, 0.73019700E+02, 0.14210900E+05, 0.99260400E+03, -.91491200E+04, -.29208400E+04, -.36102100E+04, 0.42884800E+04, 0.76980400E+04, -.85230100E+04, -.38594500E+04, -.16571600E+04, 0.12370700E+04, 0.56454100E+04, -.26382600E+04, -.10490200E+05, -.23659800E+04, 0.89678900E+03, -.80387000E+04, -.60179400E+04, 0.55696000E+04, 0.33677400E+04, -.56004500E+04, -.41331500E+04, -.65016000E+03, 0.59745900E+04, 0.97392200E+04, -.55221900E+04, 0.35521400E+04, -.41432200E+04 },
        { -.81697900E+00, -.52821000E+00, -.58586700E-01, -.14011700E+01, -.64747700E+00, 0.19070700E+01, -.18606900E+01, 0.86098700E+00, -.16356800E+00, 0.74581100E+00, -.54136600E-01, 0.51399600E-01, -.61045300E+00, 0.92019600E+00, -.57630700E+00, -.88177500E+00, -.51391900E+00, 0.88932300E+00, -.53477900E+00, -.22883300E+00, 0.62494000E-01, 0.78111300E-01, -.10194500E+00, 0.11732700E+00, -.12115400E+01, 0.22230700E-01, -.52800100E+00, -.13794100E+01, 0.87523400E+00, -.92828400E-01, 0.13826800E+00, -.19436700E+00, -.45805500E+00, 0.85864100E+00, 0.41958700E+00, 0.75872700E-01, -.29619700E-01, -.83014900E+04, -.62144100E+04, 0.13588000E+04, -.46852200E+04, -.19757300E+03, -.44574000E+04, 0.16346300E+04, 0.96882800E+04, -.48550400E+04, -.26471100E+04, -.48440700E+04, -.10266900E+05, -.64731400E+04, 0.52801900E+03, 0.74239000E+03, -.17602500E+04, -.60517400E+04, -.22754400E+04, 0.11558100E+05, -.57303400E+04, -.22254400E+04, -.57788100E+04, -.77537200E+04, -.70042900E+04, 0.37309200E+04, 0.81609400E+04, -.35631000E+04, -.65326400E+04, -.11629300E+05, 0.24250800E+05, -.12058300E+05, -.49374000E+04, -.12125400E+05, -.11143400E+05, -.61204900E+04, -.12098800E+04, -.62203300E+03, -.10095800E+05, -.41023500E+04, -.10969000E+05, 0.21407900E+05, -.10690400E+05, -.72698600E+04, -.10704100E+05, -.13473600E+05, -.73138400E+04, 0.12721200E+03, 0.14691800E+04, -.96610700E+04, -.49884600E+04, -.10951700E+05, -.14644500E+05, 0.73753200E+04, -.17010700E+03, 0.73222400E+04, -.71145100E+04, -.70624800E+04, 0.40188600E+04, 0.27510200E+03, 0.71974800E+04, -.67133800E+04, 0.70211100E+04, -.75255500E+04, 0.37965100E+04, 0.50888300E+04, 0.37629000E+04, 0.10024800E+05, 0.87872400E+04, -.21121300E+04, 0.54127600E+03, 0.17392200E+04, 0.70628800E+04, 0.70906400E+04, -.14367400E+05, 0.71464200E+04, 0.51602200E+04, 0.71846900E+04, 0.17173100E+04, -.70156000E+03, 0.23568300E+04, -.45741600E+03, 0.66681000E+04, -.11322800E+04, 0.89365000E+04, 0.30905200E+05, -.15385200E+05, -.13983700E+05, -.15452400E+05, -.18284700E+05, -.16562900E+05, 0.26175900E+04, 0.23237600E+04, -.11234100E+05, -.12889000E+05, -.16606900E+05, -.32801500E+04, 0.16329800E+04, 0.14410500E+04, 0.16400700E+04, 0.21900400E+04, 0.14215200E+04, -.32246800E+02, 0.37601200E+00, 0.16166100E+04, 0.97371600E+03, 0.14185000E+04, -.23582000E+05, 0.11923100E+05, 0.71191200E+04, 0.11791500E+05, -.19930800E+03, -.60505100E+04, 0.50640600E+04, -.29116000E+04, 0.65420000E+04, -.50796100E+04, 0.12059800E+05, 0.21638100E+05, -.10734500E+05, 0.10354500E+04, -.10819000E+05, -.64606700E+04, -.10546800E+04, -.17833700E+04, 0.28305700E+04, -.12369900E+05, -.41525100E+03, -.84879300E+04, 0.43799400E+04, -.21304100E+04, -.32758800E+04, -.21900800E+04, 0.16542100E+04, 0.35945800E+04, -.14259500E+04, 0.27451900E+04, -.12360400E+04, 0.27797800E+04, -.78017300E+03, 0.15183700E+05, -.76998300E+04, 0.13181200E+04, -.75916400E+04, -.48994000E+02, 0.35299000E+04, -.43849600E+04, 0.27862500E+03, -.90435300E+04, 0.26264400E+04, -.75439000E+04, 0.18683400E+04, -.93069200E+03, -.60267400E+04, -.93458500E+03, 0.48480500E+04, 0.70137600E+04, -.22177900E+04, 0.10596500E+04, -.84419700E+03, 0.58997500E+04, -.79084200E+03, -.30775200E+05, 0.15314400E+05, 0.87682700E+04, 0.15387400E+05, 0.18660500E+05, 0.15772600E+05, -.47591000E+04, -.11146500E+05, 0.83713100E+04, 0.13500300E+05, 0.18543200E+05, -.81014200E+04, 0.40125500E+04, 0.13576900E+04, 0.40505100E+04, 0.52412700E+04, 0.45609700E+04, -.15403100E+04, -.12887100E+04, 0.62298800E+04, 0.36282600E+04, 0.55140900E+04, -.47458100E+04, 0.23016700E+04, -.65074100E+03, 0.23730100E+04, -.38905800E+04, -.28269700E+04, 0.12712700E+04, -.18711400E+03, 0.32502100E+04, -.23246700E+04, 0.13021800E+04, -.31680900E+05, 0.15853100E+05, 0.99094000E+04, 0.15842700E+05, 0.39304400E+04, -.13632400E+04, 0.47895000E+04, -.22630100E+04, 0.11559600E+05, -.17015500E+04, 0.18223600E+05, -.15042400E+05, 0.73765100E+04, -.54775900E+03, 0.75212200E+04, -.94858500E+04, -.76806000E+04, 0.28148300E+04, -.29629600E+04, 0.83011400E+04, -.64573500E+04, 0.47508800E+04, 0.21339800E+05, -.10711800E+05, -.69171100E+04, -.10669800E+05, -.11855100E+05, -.74932000E+04, 0.23194600E+03, 0.36566500E+03, -.11428000E+05, -.51730100E+04, -.10155100E+05, 0.11403100E+05, -.56926600E+04, -.21793800E+04, -.57013500E+04, -.10061500E+05, -.91764100E+04, 0.22490600E+04, -.11006300E+04, -.65757100E+04, -.67918200E+04, -.74058400E+04, 0.53563100E+04, 0.49636900E+04, 0.54742400E+04, -.53805000E+04, -.97708300E+04, 0.76554500E+04, 0.56603700E+04, 0.29776900E+04, -.15983200E+04, -.55941000E+04, 0.62145500E+04, 0.35565400E+04, -.60239700E+03, -.31212900E+04, 0.63732900E+04, 0.43379900E+04, -.57439300E+04, -.49282500E+04, 0.59654200E+04, 0.29449000E+04, 0.50349300E+04, -.79406900E+04, -.45795000E+04, 0.71004300E+04, -.23583200E+04, 0.97206300E+04 },
        { -.40202500E+00, -.32054100E+00, -.21816100E-01, -.25103000E+00, -.57205000E+00, -.14292300E+01, 0.51544300E+00, -.44481600E+00, 0.53024600E-01, 0.34342100E+00, -.37548200E-01, 0.41268900E-01, -.42373300E+00, -.44301600E+00, 0.26690700E+00, 0.72246600E+00, 0.55943800E+00, -.14656900E+00, 0.97961900E-02, 0.33053400E+00, -.17571400E+00, -.34439000E-01, -.18319800E-01, -.78165500E-01, 0.69217400E+00, -.42523000E-03, 0.59021000E-01, 0.61438800E+00, -.42705600E+00, -.18744000E-01, 0.51781100E-01, -.26837000E+00, 0.24895600E+00, 0.13396300E+00, -.10777600E+00, -.99374000E-01, -.84241900E-01, 0.38047300E+00, -.20375400E+04, 0.10705300E+04, 0.28776300E+04, 0.95250800E+03, -.19887700E+04, -.34132000E+03, -.21957700E+04, 0.11256400E+04, 0.33726400E+03, 0.10977500E+04, 0.84703100E+03, 0.73720000E+03, 0.13334300E+03, -.10058300E+04, 0.65426100E+03, 0.85712900E+03, 0.17032300E+04, -.19459400E+03, 0.13231500E+03, -.17164600E+04, 0.96878700E+02, 0.26666400E+04, 0.30360000E+04, -.12064900E+04, -.12274600E+04, 0.24084700E+03, 0.25813700E+04, 0.11523800E+04, 0.13047300E+04, -.61593000E+03, -.18381900E+04, -.65247400E+03, 0.13510800E+04, -.25606000E+03, -.27554400E+03, 0.15920000E+04, 0.36734000E+03, -.54845000E+03, -.25643100E+03, 0.24061800E+04, -.11845700E+04, -.18549600E+04, -.12028800E+04, 0.13215300E+04, 0.68937700E+03, -.11591500E+04, 0.26237900E+03, -.18015900E+02, 0.30749500E+03, 0.12530300E+04, 0.45669000E+04, -.22265700E+04, -.18727300E+03, -.22835000E+04, 0.21692400E+03, 0.12511500E+04, -.94562500E+03, -.19368700E+04, -.19374100E+04, 0.14650000E+04, -.37622900E+03, 0.30469400E+04, -.15353400E+04, -.20374500E+04, -.15237000E+04, -.34140200E+03, -.82434000E+03, -.40348600E+03, 0.47846800E+03, -.85170900E+03, -.87874700E+03, -.21599800E+04, -.45152800E+04, 0.21347700E+04, 0.59019300E+03, 0.22559400E+04, -.29328300E+03, 0.66294200E+01, 0.74297500E+03, -.13236300E+04, 0.12935400E+04, 0.18736600E+03, 0.18547600E+04, -.13320900E+04, 0.64836500E+03, 0.33825700E+03, 0.66571600E+03, 0.19556400E+04, 0.13795300E+04, -.53401100E+03, 0.19404100E+04, 0.14330800E+04, 0.72256200E+03, 0.20773900E+04, 0.83753600E+02, -.40653600E+02, -.10254500E+03, -.41862700E+02, -.13984000E+03, 0.83976900E+02, -.75110100E+02, -.29948500E+03, -.27954300E+03, 0.14044800E+03, -.18930000E+03, 0.26779500E+04, -.17877600E+04, 0.60306200E+03, -.13400200E+04, -.27515600E+04, -.17394300E+04, 0.76790100E+03, 0.11675600E+04, 0.63084500E+03, -.16627500E+04, -.22430000E+03, -.28876800E+03, 0.32478600E+03, -.15417700E+04, 0.14429600E+03, 0.16465500E+04, 0.10299900E+04, -.39654000E+03, 0.79704600E+03, 0.17150600E+04, 0.67187400E+03, 0.72468200E+02, 0.59945000E+03, -.23964800E+03, -.13709300E+03, -.29999000E+03, 0.61595900E+03, 0.56490200E+03, 0.12915500E+03, 0.28813900E+03, -.92549500E+02, 0.51986200E+03, -.35151900E+03, -.52549000E+03, 0.22874100E+03, -.28145400E+04, 0.26347900E+03, -.11414700E+04, 0.30816600E+03, 0.18123000E+03, -.45246900E+03, 0.12922700E+04, 0.36102400E+03, 0.31928800E+04, -.50274600E+02, 0.26128100E+03, -.93724200E+03, 0.25867700E+02, 0.76618200E+03, 0.56839300E+03, -.55991700E+03, -.31737200E+03, -.16417900E+03, 0.60394100E+03, -.60354100E+03, 0.69559900E+03, -.36066700E+03, 0.12262800E+04, -.34732900E+03, -.38454000E+04, -.40705900E+04, 0.15201400E+04, 0.99181500E+03, -.39130700E+03, -.31746800E+04, -.16505900E+04, -.21276100E+04, 0.10729600E+04, 0.85917400E+03, 0.10641700E+04, -.14910600E+03, 0.44413000E+02, 0.71656700E+03, -.22275600E+03, -.28988000E+03, 0.12489600E+03, 0.13639600E+04, -.19090900E+04, 0.95764500E+03, 0.17150000E+04, 0.95435500E+03, 0.16924500E+03, 0.30155600E+03, 0.12101400E+04, 0.16038600E+03, 0.35015300E+03, 0.23822200E+03, 0.13947000E+04, -.28015300E+04, 0.11090700E+04, -.10454900E+02, 0.13968800E+04, -.17711400E+04, -.82188500E+03, 0.92015900E+03, -.97112600E+03, 0.16474100E+04, -.62252200E+03, 0.18189100E+04, -.94538400E+02, 0.10874000E+03, 0.27623300E+04, 0.47234300E+02, -.69681800E+03, 0.68567900E+03, 0.17531200E+04, -.50750900E+03, -.45370200E+03, 0.88997900E+03, 0.30881200E+04, -.51969700E+01, 0.36583500E+02, -.19092200E+03, 0.25006600E+01, 0.45882300E+03, -.41215400E+02, -.18988100E+03, 0.14876900E+04, 0.18161600E+04, -.36027500E+03, 0.13567300E+04, 0.11506600E+04, -.64101700E+03, -.15033400E+04, -.57567900E+03, 0.11476500E+03, -.76055600E+03, -.30663200E+03, 0.24027300E+04, 0.11025300E+04, -.10516900E+04, 0.56950300E+03, -.83638800E+02, -.71368600E+03, -.33921900E+03, 0.36526100E+03, 0.94368100E+03, -.69313100E+03, -.52002200E+03, -.36181400E+03, 0.25329600E+02, 0.50791300E+03, -.32990900E+03, 0.59936900E+03, 0.63352800E+03, 0.41550400E+03, -.19365400E+03, -.26299000E+03, 0.60152500E+03, 0.22813500E+03, -.37486100E+03, 0.22273900E+03, -.96106000E+03, 0.14497900E+03, -.36016100E+03, -.30317000E+03, 0.26939500E+03, -.15717800E+04 },
        { 0.11200700E+00, -.54775900E+00, -.74132400E-01, -.79115200E-01, -.26857900E+00, -.29967300E-01, 0.57628200E-01, -.18050900E+00, 0.43830800E-01, 0.88469400E-01, -.54910000E-02, -.27908300E-02, -.12719000E+00, 0.36599000E+00, -.34028200E+00, 0.56044500E-01, 0.16597600E+00, -.10469800E+00, 0.10961600E+00, -.13191100E+00, 0.82183300E-01, -.91571800E-02, -.67346100E-02, -.63701200E-01, 0.41600800E+00, -.98019800E-03, -.59120500E-01, -.71516100E-01, 0.28244900E-01, -.14408100E+00, 0.95319100E-01, 0.46344300E-01, 0.11369800E+00, -.19828200E-01, 0.26029200E-01, -.16578900E-01, -.66908600E-02, 0.75090400E-01, -.10478300E+00, 0.37099700E+03, 0.10701000E+04, 0.98210900E+02, -.90071700E+02, 0.14266100E+03, 0.18413000E+03, -.80837600E+02, -.20131000E+03, -.92090400E+02, 0.47680600E+03, -.13761200E+03, 0.19770400E+02, -.71633800E+01, -.25441900E+03, -.17154600E+02, -.48585100E+03, 0.52313700E+03, -.25830700E+03, -.77209400E+03, -.26164600E+03, 0.52377700E+03, 0.49141400E+03, -.68436100E+03, -.11191700E+04, -.19749500E+03, 0.50949000E+03, 0.17375100E+03, 0.76176300E+03, -.37562500E+03, -.80962600E+03, -.38090200E+03, 0.37218800E+03, 0.41301600E+03, -.13537100E+03, 0.82691500E+03, 0.28567200E+01, 0.19900800E+03, -.12578900E+03, 0.16337200E+03, -.77959000E+02, -.30619800E+03, -.81646800E+02, 0.59170700E+03, 0.61133200E+02, -.34081100E+02, 0.33999400E+03, 0.34487800E+03, -.80197500E+02, 0.17803200E+03, 0.19100100E+04, -.93834600E+03, -.43076200E+03, -.95501300E+03, 0.16724300E+03, -.33641100E+03, -.19742000E+03, -.31813500E+03, -.74700100E+03, -.17568100E+03, -.10966900E+04, -.12244600E+04, 0.60225200E+03, 0.27963200E+03, 0.61218900E+03, -.20364300E+03, -.12374600E+03, 0.41070800E+03, -.10138600E+02, 0.56976300E+03, -.53991700E+02, 0.12095000E+03, -.18029000E+04, 0.88004100E+03, 0.62112500E+03, 0.90113800E+03, -.68454500E+02, 0.21701800E+03, -.94635700E+02, -.91466600E+03, 0.34414200E+03, 0.25509600E+03, 0.62064700E+03, -.37485400E+03, 0.17774500E+03, 0.24270000E+02, 0.18736500E+03, 0.62277100E+03, 0.10357200E+04, -.41773200E+03, 0.23516200E+03, 0.30560400E+03, 0.77617000E+03, 0.73351900E+03, -.14916100E+03, 0.75373100E+02, 0.67841700E+02, 0.74583000E+02, -.60182100E+02, -.43232400E+02, 0.50435500E+02, -.43487800E+02, -.12726100E+02, -.16624900E+02, 0.29565100E+02, 0.12323200E+04, -.72874800E+03, 0.49708700E+02, -.61635700E+03, -.74387000E+03, 0.90331300E+02, -.40945700E+03, -.31010700E+03, -.11432000E+03, 0.68013000E+02, -.47037300E+03, 0.18349600E+03, -.45197000E+02, -.79444100E+03, -.91764000E+02, 0.76471800E+03, 0.33825900E+03, -.46767900E+03, -.20174400E+03, 0.41173600E+03, 0.31198700E+03, -.11672900E+03, 0.57844800E+03, -.27403600E+03, -.29961800E+03, -.28931400E+03, 0.20125400E+03, -.16103200E+03, -.16222200E+03, -.27215200E+03, -.25879800E+03, -.61918300E+02, -.43108900E+03, -.11007700E+03, 0.56005100E+02, -.61461600E+03, 0.55162200E+02, 0.20170200E+02, -.46669400E+03, 0.36525200E+02, -.26397300E+03, 0.35185600E+03, -.35363900E+03, -.23447500E+02, 0.53261900E+03, -.19823900E+03, -.21436200E+03, -.26617400E+03, -.90922200E+01, -.28847800E+03, 0.67562700E+02, 0.23083500E+03, -.90649700E+02, -.23121400E+03, -.24232500E+03, -.85413600E+03, 0.42991700E+03, 0.10652500E+04, 0.42715700E+03, -.10225700E+04, -.95547300E+03, 0.98429300E+03, 0.11081000E+04, 0.47749700E+03, -.82664600E+03, 0.18663600E+03, -.75613800E+03, 0.38360600E+03, 0.44780900E+03, 0.37813800E+03, 0.39079400E+01, -.25054300E+03, 0.19043900E+03, -.29981400E+03, -.23101500E+03, -.19959800E+03, 0.84316700E+02, 0.21431500E+04, -.10609000E+04, -.80737800E+03, -.10716100E+04, 0.19672600E+02, -.16445900E+03, -.47119800E+03, -.30719600E+03, -.99112800E+03, -.13950400E+03, -.88927800E+03, -.11457900E+04, 0.51668300E+03, 0.59400600E+03, 0.57217300E+03, -.52402100E+03, 0.14483100E+03, -.31376900E+03, -.11618400E+04, 0.37111900E+03, 0.19277200E+03, 0.34368600E+03, 0.51129700E+04, -.25134000E+04, -.15782000E+04, -.25564900E+04, -.13216400E+02, -.65665100E+03, -.89627400E+03, -.40352200E+03, -.21602000E+04, -.57464000E+03, -.21040300E+04, 0.61879800E+03, -.29483200E+03, -.40787200E+03, -.30941500E+03, 0.43437700E+03, 0.17480800E+03, -.32213600E+03, 0.30819000E+03, 0.26467200E+03, 0.61323800E+02, -.10644400E+03, -.52237100E+03, 0.24129200E+03, -.17793100E+03, 0.26112100E+03, 0.22320600E+02, 0.30628900E+03, 0.12987600E+03, 0.70175400E+03, 0.64346400E+03, 0.17914700E+03, 0.83811200E+03, 0.18618800E+03, -.11452600E+03, -.20558100E+03, 0.96108800E+02, 0.63091000E+03, -.16620900E+03, -.22570200E+03, -.13282000E+03, 0.31714300E+02, 0.78371500E+02, -.32203100E+03, 0.32047300E+03, 0.13029400E+03, 0.19242700E+03, -.49151100E+02, 0.90073900E+02, 0.93139600E+02, 0.13239400E+03, -.17526200E+03, 0.41428700E+01, -.27499500E+03, 0.14034400E+03, -.22549600E+03, -.12851900E+03, -.11232100E+03, -.75990700E+03 },
        { -.56771900E+01, 0.49756500E+01, 0.62425200E+00, 0.35584300E+01, -.11530300E+01, -.83552100E+01, -.10017500E+01, -.58638300E+01, -.23343600E+01, 0.33438700E+01, 0.52929200E+00, -.20468600E+00, 0.96373100E+00, -.66711100E+01, 0.44944400E+00, -.11072000E+01, 0.31764000E+00, 0.44335700E+00, -.51313700E-01, -.33361800E+01, -.54510800E+00, 0.12534300E+00, 0.53429100E-01, -.79730800E+00, 0.41677300E+01, 0.19651700E+00, 0.20253700E+01, 0.69239900E+00, -.11064700E+01, 0.15154700E+01, 0.19200400E-01, 0.14912500E-01, 0.19855700E+01, -.75034000E-01, 0.58324400E+00, -.52754700E+00, -.52508900E-01, 0.13944700E+00, -.35705700E+01, -.11141000E+02, 0.20650000E+05, 0.35211800E+04, -.27964500E+04, 0.21864200E+05, -.13581200E+05, 0.69977200E+04, 0.40208200E+04, 0.67907300E+04, 0.16981600E+05, 0.78066100E+04, -.66185100E+04, -.97774800E+04, -.90038000E+03, 0.91159600E+04, 0.52639100E+04, 0.85528700E+04, -.40888200E+04, -.16403400E+05, -.42760400E+04, 0.29699500E+05, 0.26920100E+05, -.22071300E+05, -.25595700E+05, -.37548800E+03, 0.23217500E+05, 0.83243100E+04, 0.50524300E+03, -.50423900E+02, -.64579000E+04, -.25253000E+03, 0.24938800E+05, 0.17769800E+05, -.64190100E+04, 0.19249000E+05, 0.91253700E+04, 0.10635500E+05, 0.13503700E+05, -.12851500E+05, 0.65473200E+04, 0.34178800E+04, 0.64255500E+04, 0.28519200E+05, 0.98262900E+04, -.38491300E+04, 0.78678300E+04, 0.18037300E+05, 0.42438900E+04, 0.15987700E+05, 0.55166600E+05, -.27166100E+05, -.10045000E+05, -.27583300E+05, 0.63973100E+04, 0.17389700E+04, -.13096900E+05, -.13869700E+05, -.22514600E+05, 0.60411100E+04, -.21717800E+05, -.71783200E+04, 0.35021500E+04, -.62395400E+04, 0.35893700E+04, -.13835900E+05, -.12513300E+05, 0.13964600E+05, 0.75735600E+04, 0.66448800E+04, -.10348100E+05, -.11186800E+05, -.46252200E+05, 0.22325200E+05, 0.31755400E+03, 0.23128000E+05, -.57585500E+04, -.17508000E+04, 0.24015100E+04, -.21654300E+05, 0.98030200E+04, 0.19490000E+03, 0.53712300E+04, -.32059200E+05, 0.15903700E+05, 0.13260200E+05, 0.16029900E+05, 0.31059500E+05, 0.28726200E+05, -.14177200E+05, 0.41664900E+04, 0.19970000E+05, 0.19504800E+05, 0.37208800E+05, 0.88540600E+02, -.34396200E+02, -.58895200E+03, -.44284900E+02, -.32371700E+04, -.13146000E+04, 0.10637000E+04, -.13981700E+04, -.25502600E+04, -.41361300E+03, -.14968400E+04, 0.61565000E+05, -.33131900E+05, -.11037600E+05, -.30781600E+05, -.30177100E+05, -.14024300E+05, -.68450800E+04, 0.33233000E+04, -.54170300E+04, -.13236900E+05, -.35360700E+05, 0.13627800E+05, -.57502000E+04, -.18332200E+05, -.68137700E+04, 0.22050200E+05, 0.92796700E+04, -.11565000E+05, 0.12114500E+03, 0.98190700E+04, 0.68820400E+04, -.16881400E+05, 0.14791000E+05, -.70405100E+04, -.66130800E+04, -.73963100E+04, 0.84919500E+04, 0.12951500E+04, -.28485700E+04, -.24488800E+04, -.58031900E+04, 0.27964300E+04, -.17451400E+05, 0.20837400E+05, -.10582700E+05, -.19912500E+05, -.10414900E+05, 0.40256400E+04, 0.15103700E+04, -.70010500E+04, -.36269500E+04, 0.20940000E+04, 0.14629600E+04, -.11588700E+05, -.37888500E+04, 0.32378500E+04, -.86888900E+04, 0.18936600E+04, 0.59380000E+04, 0.20210700E+04, 0.42220000E+03, 0.79221800E+03, 0.17281900E+04, 0.26098800E+04, 0.64012000E+04, 0.12897300E+04, -.73437300E+03, 0.91274900E+04, -.64524100E+03, -.50918200E+05, -.43403200E+05, 0.29978800E+05, 0.23368300E+05, -.30736100E+04, -.34685700E+05, -.72259800E+04, -.15526200E+05, 0.78282200E+04, 0.59029000E+04, 0.77627400E+04, -.57170900E+04, -.70220700E+04, 0.70574200E+04, -.47057700E+04, -.82255200E+04, -.46022700E+04, -.10183600E+03, 0.25605800E+05, -.12697800E+05, -.15630000E+04, -.12802700E+05, 0.74456300E+04, 0.26950000E+04, -.75747000E+04, -.78731000E+04, -.13730000E+05, 0.26167700E+04, -.10229900E+05, -.11684000E+05, 0.41930100E+04, -.14064600E+05, 0.58460400E+04, -.24454700E+05, -.13333200E+05, -.48928000E+01, -.20356100E+05, 0.10374700E+05, -.10469600E+05, -.16306800E+05, 0.10033300E+06, -.49569300E+05, -.13942300E+05, -.50166700E+05, 0.94769300E+04, 0.14599600E+04, -.22701500E+05, -.13450000E+05, -.43006000E+05, 0.32317000E+04, -.36800200E+05, -.24710200E+03, 0.33626100E+03, 0.21711000E+04, 0.12375400E+03, 0.17415600E+05, 0.60149500E+04, -.82713400E+04, 0.95315500E+04, 0.17337300E+05, 0.16734800E+04, 0.52602700E+04, -.73968300E+03, -.37784800E+02, -.80192100E+04, 0.37017100E+03, 0.32999100E+04, 0.70210400E+04, -.72102100E+04, 0.15641000E+05, 0.14889500E+05, 0.18845000E+04, 0.28766500E+05, -.77987400E+02, -.87561700E+04, -.97195900E+04, 0.72753600E+04, 0.17130700E+05, -.11235300E+05, -.72920000E+04, -.54761100E+04, 0.98682000E+03, 0.82903000E+04, -.12307300E+05, 0.51510000E+04, 0.44497700E+04, 0.72702700E+04, -.64795700E+04, -.41940800E+04, 0.78672400E+04, 0.71451700E+04, -.10273200E+05, -.54885900E+03, -.11962600E+05, 0.10521800E+05, -.18756500E+04, -.98646900E+04, 0.93707100E+03, -.19810000E+05 },
        { -.20953800E+01, 0.91498700E+00, -.57082700E-02, -.97559300E+00, -.15531100E+01, 0.27785000E+01, -.36486200E+01, 0.54136400E+00, -.63597900E+00, 0.17062900E+01, -.17439400E+00, -.11269500E+00, -.82900800E+00, -.13331200E+01, 0.95140700E+00, 0.38599300E-01, -.16842500E+01, 0.46543900E+00, -.72934700E+00, 0.13936100E+01, 0.10413000E+00, 0.14373500E+00, 0.92673500E-01, -.12474500E-02, -.30831100E+01, 0.70800000E-01, -.20094500E+00, -.73265100E+00, 0.16931100E+00, 0.68601600E+00, -.32223800E-01, -.76484600E-01, -.38547900E+00, -.44603200E+00, -.58697500E+00, 0.24067700E+00, -.32882800E+00, 0.56741800E+00, -.52957000E+00, -.26724800E+01, 0.21145500E+00, 0.43110600E+04, -.11150900E+04, -.52355900E+04, -.44450900E+04, 0.22229100E+04, -.47345900E+03, 0.22221100E+04, -.24202800E+04, 0.11498100E+04, 0.40700200E+04, 0.57346900E+04, 0.65122300E+04, -.59473700E+03, 0.55806400E+04, -.11458700E+04, 0.60493400E+03, -.34918800E+04, 0.57158900E+03, 0.13719700E+04, 0.18866300E+04, 0.24393000E+04, 0.64918600E+04, 0.12956800E+03, 0.68532100E+03, 0.40967600E+03, 0.81000500E+04, -.40099800E+04, -.90075000E+04, -.40503700E+04, -.16913400E+04, -.37891900E+04, -.78945000E+03, -.84088400E+03, -.22214600E+04, -.33387900E+04, -.72222900E+04, 0.12560800E+05, -.62417900E+04, -.76857500E+04, -.62797300E+04, -.17265700E+04, 0.11909400E+04, -.26742800E+04, 0.11702700E+04, -.57306000E+04, 0.12000700E+04, -.62205200E+04, 0.42895600E+04, -.21469100E+04, 0.43551600E+04, -.21449200E+04, -.61484400E+03, 0.39871500E+04, 0.26613800E+04, 0.90684600E+04, 0.40001200E+04, 0.16658100E+04, 0.13170000E+04, 0.38431600E+04, -.19717600E+04, -.29474800E+04, -.19223200E+04, 0.23027900E+04, 0.29626300E+03, -.43629500E+04, -.42673300E+04, -.19772600E+04, 0.95904000E+01, 0.46633200E+03, 0.15775200E+04, -.96097800E+03, 0.40275400E+04, -.79435600E+03, -.13688700E+04, -.34232500E+04, 0.43194400E+04, 0.38945100E+04, -.85954500E+02, -.31214500E+04, 0.28090400E+04, 0.15232900E+05, -.75345900E+04, -.86437600E+04, -.76175300E+04, -.19846700E+04, -.81751000E+03, -.37437600E+03, 0.53667900E+04, -.38572900E+04, -.16130200E+04, -.10675300E+05, -.53593800E+03, 0.25897800E+03, 0.35740000E+03, 0.26801500E+03, 0.38549400E+03, 0.24598300E+03, -.29478600E+03, -.69922300E+03, 0.11043100E+03, 0.28432900E+03, 0.55850400E+03, -.49549600E+04, 0.25166800E+04, 0.13233600E+04, 0.24741700E+04, -.22743800E+04, -.44610500E+04, 0.62449400E+04, 0.46814000E+04, 0.23514100E+04, -.44958700E+04, 0.52636400E+04, -.32757700E+04, 0.16329900E+04, -.37695500E+04, 0.16375900E+04, 0.68107700E+03, 0.28956300E+04, 0.10513100E+04, 0.40921400E+04, 0.15047000E+04, 0.17157200E+04, 0.39479100E+04, 0.21813100E+04, -.11677100E+04, 0.45445300E+03, -.10905000E+04, 0.14731600E+04, 0.41043000E+04, -.25669800E+03, 0.33641100E+04, -.20288200E+03, 0.32189200E+04, 0.12586400E+04, -.23084700E+05, 0.11537200E+05, 0.68613600E+03, 0.11545200E+05, -.50142700E+04, -.31924000E+04, 0.86148800E+04, 0.37405200E+04, 0.95597600E+04, -.29683200E+04, 0.15976200E+05, 0.42245600E+04, -.21596500E+04, 0.25898600E+04, -.21099000E+04, 0.14669700E+04, 0.20373700E+04, -.32833100E+04, -.14831600E+04, -.27366000E+04, 0.23081000E+04, -.40539200E+04, -.10661000E+04, 0.47298900E+03, 0.59779000E+04, 0.53454100E+03, -.22997100E+03, -.15982200E+04, -.39338400E+04, -.89135400E+04, 0.69380100E+03, -.63664300E+02, -.11559200E+04, -.95226300E+03, 0.42686700E+03, 0.24507900E+04, 0.47731900E+03, 0.12029300E+04, 0.14118200E+04, 0.13157300E+04, 0.30559000E+04, 0.41562900E+04, 0.12391800E+04, 0.21613300E+04, -.10172300E+05, 0.50665400E+04, 0.75169000E+04, 0.50855300E+04, -.90869500E+03, 0.49981900E+03, 0.52587600E+04, 0.46857600E+04, 0.36185700E+04, 0.32974900E+03, 0.44330200E+04, -.12725200E+04, 0.39686200E+03, 0.63544600E+04, 0.62358600E+03, -.20832400E+04, -.55428800E+04, 0.74254100E+04, 0.61345100E+04, 0.20362500E+03, -.51885600E+04, 0.64898000E+04, -.24284300E+05, 0.12093300E+05, 0.19693700E+05, 0.12142000E+05, -.30750000E+04, 0.27184100E+04, 0.13321700E+05, 0.12940200E+05, 0.11464200E+05, 0.20550300E+04, 0.12703900E+05, 0.32379500E+04, -.15923400E+04, -.33967500E+04, -.16193200E+04, -.24164000E+04, -.78862600E+03, 0.12360300E+04, 0.35634700E+04, -.66196200E+03, -.75618100E+03, -.19921000E+04, 0.13860000E+04, -.64487500E+03, -.30516400E+04, -.69411500E+03, -.23305500E+03, 0.54152900E+03, -.15224700E+04, -.98039800E+03, -.58065200E+03, -.40809900E+03, -.59102200E+04, 0.70243300E+03, 0.15504600E+03, 0.13297400E+04, -.43809100E+03, 0.19895700E+03, -.63892200E+03, 0.15376800E+04, 0.24044300E+03, 0.39535700E+03, 0.24836700E+03, 0.15284700E+04, 0.81944300E+03, 0.14692600E+04, 0.14951400E+02, 0.11206000E+04, 0.15031100E+04, -.63656200E+03, -.10826600E+04, 0.21299800E+04, 0.18290500E+04, 0.83205800E+03, -.10956900E+04, -.63192100E+03, 0.25063400E+03, -.49435400E+03, -.35756100E+03 },
        { -.11716800E+01, -.15701100E+01, -.14804700E+00, -.81575600E+00, -.13222300E+01, 0.14828600E+01, -.16047900E+01, 0.13998700E+01, -.73881100E+00, 0.11311300E+01, 0.58746200E-01, -.96240400E-01, 0.46352600E+00, 0.15946100E+01, -.42407200E+00, 0.82408900E+00, -.29260600E+00, 0.12003500E+00, 0.45329200E+00, -.41315900E+00, 0.52263400E+00, -.85433100E-02, -.19755600E-03, -.20435800E+00, 0.12791900E+01, 0.10224500E-01, -.27773400E+00, -.19121400E+00, -.66810000E+00, -.31849500E+00, 0.20865800E+00, -.10826400E+00, 0.72752400E+00, -.14050200E+00, -.26345700E-02, -.39057800E+00, -.38857600E-01, 0.29113300E+00, -.28461600E+00, 0.52302700E+01, -.44580500E-01, -.97661700E-01, 0.98231400E+03, -.74795000E+03, 0.32253900E+04, -.16315000E+04, -.57405400E+04, -.16124700E+04, -.14692000E+04, -.19235400E+04, 0.17377300E+04, 0.46129200E+04, 0.18136000E+04, -.17340800E+04, 0.83786000E+03, -.23593100E+04, 0.11692800E+04, -.51235500E+04, 0.11803400E+04, 0.60210400E+03, -.15286600E+04, 0.27290800E+04, 0.36721300E+04, 0.14695100E+04, -.13214800E+04, -.80402800E+03, 0.74122500E+04, -.37229100E+04, -.55954300E+04, -.37059500E+04, -.15991700E+04, -.22039500E+03, -.12293600E+04, -.12204300E+04, -.45455900E+04, 0.10562400E+04, -.54375400E+04, 0.70862700E+04, -.35511500E+04, -.69372700E+04, -.35434800E+04, -.11920200E+04, 0.56861300E+03, -.13488200E+04, -.11800000E+03, -.38235900E+04, 0.14779900E+04, -.43761200E+04, 0.21859400E+04, -.10889400E+04, -.33821900E+04, -.10928900E+04, -.56738500E+03, 0.58840800E+03, 0.11527500E+04, 0.45539100E+04, 0.23384300E+04, 0.23249700E+03, 0.97121200E+03, -.12650600E+04, 0.69127600E+03, 0.44876000E+04, 0.63290200E+03, 0.18702300E+04, 0.71606300E+03, -.67933900E+03, -.14164900E+04, 0.47337500E+03, -.24654700E+03, 0.23386200E+04, -.14396600E+05, 0.71799300E+04, 0.76296000E+04, 0.72011500E+04, 0.16108700E+04, 0.79750900E+03, 0.18049900E+04, -.11302000E+04, 0.55990400E+04, 0.77815800E+03, 0.74115300E+04, 0.46046000E+04, -.23045800E+04, -.56176300E+04, -.23017600E+04, -.17150300E+04, -.17073800E+04, 0.11823900E+04, 0.13205700E+04, -.24644300E+04, 0.50154900E+02, -.53405800E+04, -.10333900E+04, 0.51816200E+03, 0.57531900E+03, 0.51667100E+03, 0.34048500E+03, 0.77827500E+02, 0.89922400E+02, 0.17380700E+02, 0.64403900E+03, -.14567300E+03, 0.73405300E+03, -.63351800E+04, 0.32448300E+04, 0.93288200E+04, 0.31692700E+04, -.55279300E+03, -.11251700E+04, 0.19376700E+04, 0.59900800E+03, 0.24638900E+04, 0.11230600E+02, 0.24912900E+04, -.37604400E+04, 0.18057800E+04, -.23281700E+04, 0.18803700E+04, 0.56552800E+04, 0.39182700E+04, -.74006800E+03, 0.14348600E+03, -.77765500E+03, 0.37607400E+04, -.23946700E+03, 0.42350900E+04, -.21261500E+04, -.13815900E+04, -.21170200E+04, 0.14951100E+04, 0.18579400E+04, -.91877200E+03, 0.17407300E+04, -.12851000E+04, 0.10526800E+04, -.15905000E+04, -.93310900E+04, 0.46413600E+04, -.29068100E+04, 0.46657000E+04, -.87194400E+03, -.27105300E+04, 0.29368000E+04, -.85943100E+01, 0.25083200E+04, -.17167700E+04, 0.49082300E+04, -.35563100E+03, 0.72016700E+02, -.17943600E+04, 0.17661100E+03, 0.34686200E+03, 0.68117100E+03, -.16483500E+03, -.40407200E+03, -.36242900E+03, 0.42824500E+03, -.70989900E+03, -.77738200E+04, 0.38827000E+04, 0.92953600E+04, 0.38861400E+04, 0.23834500E+04, 0.45711800E+04, -.33219300E+04, -.71007100E+04, 0.89112000E+03, 0.38406200E+04, 0.46941000E+04, -.35490800E+04, 0.17938900E+04, 0.71616900E+03, 0.17739400E+04, 0.11902800E+04, 0.18762800E+04, -.43995900E+03, -.31707100E+03, 0.32301500E+04, 0.96514600E+03, 0.44639400E+04, 0.95533300E+03, -.49039000E+03, -.23215700E+04, -.47735400E+03, -.14528700E+04, -.16157200E+02, 0.26694900E+03, 0.63430800E+03, 0.26772400E+02, 0.23744900E+03, -.25904500E+03, -.23108800E+05, 0.11545000E+05, 0.14283600E+05, 0.11560800E+05, 0.25143200E+04, 0.96828500E+03, 0.32724100E+04, -.14262600E+04, 0.88754600E+04, 0.15207300E+04, 0.10947800E+05, -.23409500E+04, 0.11099600E+04, -.53631400E+04, 0.11705400E+04, -.25406600E+04, 0.71155800E+03, 0.11328300E+04, 0.18394600E+04, 0.20980300E+04, 0.15238700E+04, 0.19292300E+04, 0.29438000E+04, -.15043200E+04, -.33097800E+04, -.14717300E+04, -.12463600E+04, -.36683600E+03, -.24698800E+02, -.15789300E+03, -.32101700E+04, 0.58713900E+03, -.24267100E+04, -.48977800E+04, 0.24621800E+04, 0.32907400E+03, 0.24494500E+04, 0.82747900E+03, -.43989200E+03, 0.11755900E+04, -.96046200E+03, -.44660500E+03, 0.10557800E+04, -.12774500E+04, 0.14864800E+04, 0.82586400E+03, 0.82764500E+03, -.69011700E+03, 0.18829500E+03, -.54033500E+02, 0.14757800E+04, 0.28472300E+03, -.23152100E+03, 0.14643100E+02, 0.94343900E+03, 0.58461800E+03, 0.90052800E+02, -.13207700E+03, 0.92628800E+03, 0.15426800E+04, -.85404800E+03, -.63108600E+03, 0.36132500E+03, 0.12412500E+04, 0.10297800E+04, 0.17026300E+03, -.98846300E+03, 0.25517900E+03, -.82624300E+03, 0.32297500E+03 },
        { -.13645900E+01, -.11050900E+01, -.10713800E+00, 0.11123100E+01, 0.14018100E+00, -.26444400E+01, -.11902500E+01, -.90473400E+00, -.10924300E+01, 0.11881000E+01, 0.10358300E-01, -.11585600E+00, -.10721000E+01, 0.73191700E+00, -.19777500E+01, 0.67809100E+00, 0.11675900E+01, -.26468400E+00, -.97412300E-02, -.12892400E+01, -.40385800E+00, 0.19713300E+00, -.38100600E-01, 0.73867700E-02, -.16614200E+00, 0.33797300E-02, 0.40901900E-01, -.30810000E+00, -.25115000E-01, 0.17268500E+00, -.18555300E+00, -.18331000E+00, 0.35367800E+00, -.40475400E+00, -.42085700E-02, -.30308500E+00, -.39927200E-01, -.63539600E+00, 0.79277300E+00, -.15196100E+01, -.13331700E+00, -.45589400E+00, 0.21322000E+00, -.45246600E+04, 0.32999600E+02, -.39861400E+02, 0.31876000E+03, -.16424900E+02, -.51378000E+03, 0.37239700E+02, 0.14642100E+04, 0.25017600E+04, 0.10399600E+04, -.20967800E+03, -.21430700E+04, 0.47811600E+02, 0.63176600E+01, -.28229900E+04, -.23655400E+02, -.15042100E+04, -.74679800E+03, 0.16521400E+04, 0.27704400E+04, 0.24349200E+03, -.69508500E+03, -.28199700E+03, 0.10738500E+05, -.53430700E+04, -.39258800E+04, -.53692000E+04, -.29708700E+04, -.23510800E+04, -.10161200E+04, 0.89256800E+03, -.41983300E+04, -.19307400E+04, -.73788200E+04, 0.12037800E+05, -.60227200E+04, -.55448500E+04, -.60190200E+04, -.39170000E+04, -.16028700E+04, -.15117400E+04, 0.10720500E+04, -.47136100E+04, -.12585300E+04, -.63426600E+04, -.21761100E+04, 0.11160800E+04, 0.16031800E+03, 0.10880700E+04, -.64258700E+03, 0.75099800E+02, 0.17757300E+04, 0.21669200E+04, 0.24728600E+04, 0.12306300E+03, -.85615800E+03, -.39866200E+04, 0.20737100E+04, 0.86741300E+03, 0.19934500E+04, 0.36170200E+04, 0.22764200E+04, -.18809400E+04, -.34434600E+04, 0.30038700E+03, 0.18170700E+04, 0.25248300E+04, -.96189100E+04, 0.48012200E+04, 0.11793700E+04, 0.48105800E+04, 0.42023500E+03, 0.11695700E+04, 0.14515200E+04, 0.17262100E+02, 0.55280800E+04, 0.70708000E+03, 0.61641100E+04, 0.12212600E+05, -.60789000E+04, -.71546400E+04, -.61061000E+04, -.42529300E+04, -.18976000E+04, -.47598300E+03, 0.28670000E+04, -.40583600E+04, -.17877100E+04, -.83045000E+04, -.14405400E+04, 0.71837700E+03, 0.56594200E+03, 0.72025900E+03, 0.60216500E+03, 0.33959500E+03, -.52252500E+02, -.47118800E+03, 0.55224900E+03, 0.26271700E+03, 0.91996500E+03, -.29000500E+04, 0.17009300E+04, 0.61848900E+03, 0.14506200E+04, -.21014400E+04, 0.11166900E+04, 0.18505400E+03, -.18873900E+03, 0.13784800E+04, 0.85781500E+03, 0.22491700E+04, 0.82637300E+04, -.41468300E+04, -.13749200E+04, -.41318000E+04, -.81018400E+03, 0.13026600E+04, -.84151700E+03, 0.29067100E+04, -.36931400E+04, 0.60617100E+03, -.33017400E+04, 0.23437300E+04, -.11306300E+04, -.15355800E+04, -.11717600E+04, 0.10833800E+04, 0.20369400E+04, -.11032200E+03, 0.18604100E+04, -.68409300E+03, 0.15863000E+04, -.10895800E+03, -.33686300E+04, 0.15929300E+04, 0.13457100E+04, 0.16860200E+04, 0.18763300E+03, 0.81699700E+03, 0.20842200E+04, 0.25439000E+04, 0.47859300E+03, 0.33785700E+03, 0.15204300E+04, -.55400100E+04, 0.26531600E+04, 0.29964800E+03, 0.27695400E+04, 0.29765200E+04, 0.91860100E+03, 0.68160000E+03, -.25281800E+03, 0.54185000E+03, 0.83428900E+03, 0.15225000E+04, -.61171700E+04, 0.30065700E+04, 0.45425500E+04, 0.30583400E+04, 0.45478200E+04, 0.28487300E+04, -.23371200E+04, -.51208800E+04, 0.15676700E+04, 0.24063800E+04, 0.37748500E+04, -.58705300E+04, 0.29199200E+04, 0.18746500E+04, 0.29350500E+04, 0.23298400E+04, 0.14985900E+04, 0.68060700E+03, 0.44136700E+01, 0.45214800E+04, 0.12302500E+04, 0.31428900E+04, -.10878900E+04, 0.48496900E+03, 0.37561400E+03, 0.54405900E+03, -.23212500E+04, -.11434700E+04, 0.20020800E+04, 0.27922100E+04, 0.26497100E+04, -.12054000E+04, 0.10849200E+04, -.15990300E+05, 0.80728700E+04, 0.24371300E+04, 0.79975900E+04, 0.45960800E+03, 0.23718000E+04, 0.19441600E+04, -.67523200E+03, 0.80307300E+04, 0.15831300E+04, 0.95243000E+04, -.36112900E+04, 0.16458100E+04, 0.38775900E+04, 0.18056600E+04, -.42565400E+04, -.17985300E+04, 0.53665000E+04, 0.70983100E+04, 0.56359000E+04, -.16292800E+04, 0.11839500E+04, 0.71266800E+04, -.36391200E+04, -.24041200E+04, -.35632300E+04, -.36750200E+04, -.17406200E+04, 0.34031400E+03, 0.24788000E+04, -.36677700E+04, -.15365300E+04, -.37055400E+04, 0.21616200E+04, -.10666100E+04, -.28423300E+04, -.10806000E+04, -.16311400E+04, -.59410500E+03, -.45617300E+03, 0.24148200E+02, -.20290400E+04, -.64824900E+03, -.44134900E+04, 0.20329700E+04, 0.14367500E+04, 0.19640900E+04, -.16094600E+04, -.72487900E+03, 0.64230800E+03, 0.15304300E+04, 0.76910300E+03, -.21830300E+03, -.95250600E+03, 0.19873400E+04, 0.28835400E+04, 0.85176300E+03, -.46015900E+03, 0.26199800E+04, 0.16475200E+04, -.19645000E+04, -.18291400E+04, 0.21855000E+04, 0.11959900E+04, 0.14846600E+04, -.20583800E+04, -.29662700E+04, 0.16478700E+04, -.99237200E+03, 0.67087000E+03 },
        { -.98978400E+00, 0.11282900E+01, 0.15719800E+00, 0.18552100E+00, -.81420000E-01, 0.36536200E+00, -.21617300E+01, 0.12582700E+01, -.93080800E+00, 0.29502300E+00, -.22085600E-01, -.10737400E+00, 0.27088200E-01, 0.92905100E+00, 0.80985100E+00, -.29766500E+00, 0.18876300E+00, 0.13855600E+01, 0.34189200E+00, 0.15185900E+00, -.38156200E+00, 0.33077700E-01, -.71058800E-01, -.25530300E+00, 0.33171900E+00, 0.55658900E-01, 0.33056100E+00, 0.82971300E+00, -.37603000E+00, 0.44506900E+00, 0.95573200E-01, 0.93225800E-01, 0.37203400E+00, 0.49831100E+00, 0.52148300E-01, -.48627400E-01, -.15578000E+00, 0.39960000E+00, -.82076200E+00, 0.34334900E+01, -.60571600E-03, 0.19032200E+00, -.11695500E+00, 0.31976700E+00, -.10029500E+05, 0.50329300E+04, 0.34178400E+04, 0.50147800E+04, 0.25831900E+04, 0.10729000E+04, 0.67095500E+03, -.34202400E+04, 0.20129600E+04, 0.15654000E+04, 0.66928600E+02, 0.19411200E+04, -.97960400E+03, -.34770400E+03, -.97053200E+03, 0.38499600E+04, 0.30988400E+04, -.32219900E+04, -.27747400E+04, -.15079400E+04, 0.28641300E+04, 0.14318700E+03, -.28471800E+04, 0.14147900E+04, -.12028900E+03, 0.14235900E+04, 0.30221500E+04, 0.19784300E+04, -.12771300E+03, 0.98156500E+03, 0.26525900E+04, 0.12261500E+04, 0.21524700E+04, -.53695500E+04, 0.26898600E+04, 0.12721800E+04, 0.26847600E+04, 0.30994100E+04, 0.11920800E+04, -.97788800E+02, 0.19232200E+03, 0.30581800E+04, 0.66565300E+03, 0.34024600E+04, 0.36286300E+03, -.18360300E+03, 0.12159000E+04, -.18143100E+03, 0.16232700E+04, 0.12174900E+04, -.16292400E+04, -.27260800E+04, -.12703700E+04, 0.18027400E+04, -.34676000E+04, 0.34789200E+03, -.21483300E+03, 0.75495500E+03, -.17393500E+03, -.19654200E+04, -.12440700E+04, 0.25935600E+04, 0.32514800E+04, 0.43870700E+03, -.10779000E+04, -.81420800E+03, 0.29014500E+04, -.14626400E+04, -.25579200E+04, -.14505700E+04, -.22190700E+03, -.64780900E+03, -.11808200E+04, -.86813500E+03, -.28602800E+04, -.54119300E+03, -.32462300E+04, -.43877700E+04, 0.21737700E+04, 0.10845500E+04, 0.21939000E+04, 0.37558400E+04, 0.20393000E+04, -.16077100E+04, -.96822300E+03, 0.22563700E+04, 0.15360100E+04, 0.39741700E+04, 0.56749000E+03, -.28219900E+03, -.99917300E+00, -.28374600E+03, -.44076200E+03, -.13848400E+03, 0.15674400E+03, 0.14022200E+03, -.33339200E+03, -.80748500E+02, -.32810900E+03, 0.23726300E+04, -.13722700E+04, -.48829100E+04, -.11862700E+04, -.74344000E+03, -.23697000E+04, -.56199800E+03, 0.67027900E+03, -.91354800E+03, -.22696100E+04, -.24728700E+04, 0.72333300E+03, -.32543000E+03, -.25665700E+04, -.36165700E+03, 0.27491300E+04, 0.10111500E+04, -.15786800E+04, -.10106500E+04, 0.20936700E+03, 0.79347800E+03, -.17344600E+04, 0.25398600E+04, -.12773200E+04, 0.70952300E+02, -.12697600E+04, 0.15752300E+04, 0.96410600E+03, -.95696700E+03, -.51409400E+03, -.12006000E+04, 0.87901000E+03, -.27664000E+04, 0.16698000E+04, -.79219800E+03, 0.18534200E+04, -.83449800E+03, 0.14061900E+04, -.25260500E+02, -.18013700E+04, -.26426800E+04, -.13665300E+04, 0.47509400E+03, -.26067600E+04, 0.12969800E+03, 0.32826400E+02, 0.16532900E+04, -.64904400E+02, -.13688800E+03, 0.88568900E+03, -.22256500E+03, -.74396000E+03, 0.92324200E+03, 0.83032200E+03, 0.97269600E+03, 0.49499300E+04, -.24521600E+04, 0.26669600E+03, -.24749900E+04, -.67989600E+04, -.48088400E+04, 0.29965400E+04, 0.41715300E+04, -.10943800E+04, -.41178900E+04, -.14699000E+04, 0.15059300E+04, -.74430100E+03, 0.38625200E+03, -.75298500E+03, -.11131100E+04, -.50908500E+03, -.65549000E+02, -.61685100E+03, -.22818000E+04, -.15621300E+03, -.16806500E+04, 0.62658900E+04, -.30982800E+04, 0.13718900E+03, -.31329300E+04, 0.89995300E+03, 0.40513300E+03, -.30429000E+04, -.24973400E+04, -.32828200E+04, 0.28789900E+03, -.33777900E+04, 0.43572400E+04, -.22585800E+04, -.57445900E+04, -.21783200E+04, -.10445300E+04, -.22542800E+04, -.14524800E+04, -.51843500E+03, -.31387300E+04, -.20590500E+04, -.47189100E+04, 0.10162500E+05, -.49810100E+04, -.42940400E+03, -.50812400E+04, 0.17104500E+04, 0.25069800E+03, -.62715800E+04, -.69960200E+04, -.61793700E+04, 0.52051300E+03, -.65771300E+04, -.31090300E+04, 0.15955100E+04, -.57118000E+03, 0.15545300E+04, 0.22344500E+04, 0.10224300E+04, -.11655600E+04, -.13648300E+04, 0.22234700E+04, 0.65528000E+03, 0.21316000E+04, 0.26093400E+04, -.13239000E+04, -.14199400E+04, -.13046500E+04, 0.62041100E+03, 0.40214900E+03, -.12866000E+04, 0.79991100E+03, 0.19581400E+03, 0.13644600E+03, 0.91955800E+03, -.65265400E+03, -.12670600E+04, -.15031700E+04, 0.11595900E+04, 0.80788200E+03, -.12009500E+04, -.10562500E+04, -.63734300E+03, 0.12751100E+03, 0.12758000E+04, -.15936100E+04, -.19711900E+04, -.14589800E+03, 0.70509500E+03, -.16413100E+04, -.57340200E+03, 0.14054300E+04, 0.13551800E+04, -.14055200E+04, -.32811300E+03, -.15537300E+04, 0.13716300E+04, 0.17998500E+04, -.11212700E+04, 0.25627600E+03, -.92672700E+03 },
        { -.50858500E+01, -.60326100E+01, -.67553100E+00, -.44156500E+01, -.21102400E+01, 0.29436900E+01, -.75815300E+01, 0.45500500E+01, -.34203700E+01, 0.49308900E+01, 0.20430300E+00, -.20500900E+00, 0.28283600E+01, 0.49917200E+01, -.77506200E+00, 0.26813700E+00, -.13914800E+01, 0.99253900E+00, -.13754700E+01, 0.49041200E+00, 0.26681300E+00, 0.16445000E+00, 0.56925800E-01, 0.72144000E+00, -.60802900E+01, -.90074800E-01, -.16785600E+01, -.46102200E+00, 0.13938000E+01, 0.51656600E+00, -.40399100E+00, 0.85042600E+00, -.29402400E+00, 0.33873700E+00, 0.14652300E+00, 0.79841700E+00, 0.43311500E+00, 0.47017500E-01, -.15142400E+01, 0.32099400E+01, -.17296700E+00, -.28018800E+00, -.15974000E+01, -.72256700E+00, 0.84090800E+00, -.31264700E+03, -.94438900E+03, 0.18575200E-02, -.27872000E+04, 0.76183900E+03, 0.83172900E+03, -.77532800E+02, -.74346100E+03, 0.74721300E+02, 0.71986700E+04, 0.48743000E+04, -.26957300E+04, -.50582300E+04, -.24372000E+04, -.72688700E+04, -.10942100E+04, 0.22278100E+03, -.44934300E+03, -.27807100E+04, 0.10005800E+03, 0.31609600E+04, 0.31250800E+04, -.18980700E+04, -.43981900E+04, -.15625300E+04, -.58185600E+04, -.48991200E+04, 0.80619900E+03, -.20449400E+04, -.37890200E+04, -.28581100E+04, -.32808900E+04, 0.12799900E+05, -.66655800E+04, -.48217300E+04, -.63999100E+04, -.58150800E+04, -.11863700E+04, -.28107300E+04, -.24136300E+04, -.63459300E+04, -.30276500E+03, -.48847700E+04, 0.83780300E+04, -.46640600E+04, 0.14078500E+04, -.41889500E+04, -.43592900E+04, 0.31690600E+04, -.60817100E+02, -.11502100E+04, -.52812800E+04, 0.23414500E+04, 0.61311000E+04, 0.54513700E+04, -.23030600E+04, -.37824000E+04, -.27257000E+04, 0.46013700E+04, -.67001800E+03, -.35671900E+04, -.11234000E+04, 0.13539600E+04, -.19555800E+04, -.43959000E+04, -.36143400E+05, 0.19628900E+05, 0.12162400E+05, 0.18071200E+05, 0.52120400E+04, 0.16206000E+04, 0.75247900E+04, -.45529400E+04, 0.10752500E+05, 0.25167400E+04, 0.13257900E+05, 0.15302300E+05, -.77719700E+04, -.26464800E+04, -.76512100E+04, -.72204500E+04, -.31632500E+03, -.19390300E+04, 0.26697400E+03, -.78184500E+04, 0.93824300E+03, -.80843400E+04, -.11087100E+04, 0.57481400E+03, 0.40738500E+02, 0.55435800E+03, 0.80254500E+03, 0.37985300E+03, -.18317000E+03, -.20248100E+03, 0.53968700E+03, 0.22748000E+03, 0.72463200E+03, -.19688800E+05, 0.11259300E+05, 0.10400900E+05, 0.98443800E+04, 0.73942800E+03, 0.14277400E+04, 0.55391700E+04, -.41113600E+04, 0.49957300E+04, 0.25735900E+04, 0.86059200E+04, -.11787300E+05, 0.47424100E+04, 0.41676900E+04, 0.58935900E+04, -.15303700E+04, -.27282900E+04, 0.14214800E+04, -.19024300E+04, 0.66882600E+04, -.18944800E+04, 0.15053100E+04, -.13230600E+04, 0.50730500E+03, 0.30974800E+04, 0.66212800E+03, -.21429900E+04, -.15413800E+04, 0.76374100E+03, 0.22771100E+03, 0.18156900E+04, -.17463700E+04, 0.55039900E+03, -.14974400E+05, 0.74914000E+04, -.58904000E+04, 0.74868700E+04, -.32907600E+04, -.26079900E+04, 0.59311700E+04, 0.27240000E+04, 0.88630800E+04, -.24220200E+04, 0.11976100E+05, -.71260100E+03, -.98566800E+03, -.23691300E+04, 0.35647600E+03, 0.21583900E+03, -.18457000E+04, -.41364800E+03, 0.23875700E+04, 0.21473800E+04, -.17361400E+04, -.14195300E+04, -.58666600E+04, 0.32301700E+04, 0.43128200E+04, 0.29332800E+04, 0.11255700E+05, 0.17804000E+04, -.52735100E+03, 0.14373600E+04, 0.60136900E+04, 0.55411500E+03, -.38734800E+04, 0.95084800E+03, -.25723400E+03, -.29628200E+03, -.47538900E+03, 0.17820500E+04, 0.13452600E+04, 0.96202700E+03, 0.39014600E+04, 0.31894700E+04, -.41416300E+03, 0.22441100E+04, -.19109300E+05, 0.93376500E+04, 0.89496100E+04, 0.95546400E+04, -.13766000E+04, 0.27809300E+04, 0.55191900E+04, -.89216500E+03, 0.33893200E+04, 0.27036700E+04, 0.10493400E+05, -.56582200E+05, 0.30599700E+05, 0.20173100E+05, 0.28290300E+05, 0.74133200E+04, 0.26420900E+04, 0.12076500E+05, -.76854700E+04, 0.16962400E+05, 0.41686000E+04, 0.21415600E+05, -.32103900E+05, 0.15104700E+05, 0.17005200E+05, 0.16052000E+05, -.45433300E+04, 0.69412000E+04, 0.11643200E+05, 0.76686100E+03, 0.53007700E+04, 0.68410900E+04, 0.22480900E+05, 0.74798200E+03, -.73280300E+03, 0.36286000E+02, -.37416500E+03, -.43542600E+04, -.19595500E+04, 0.64217400E+03, 0.13095700E+04, 0.60393900E+03, -.14911600E+04, -.45479300E+03, 0.48827100E+04, -.21885700E+04, -.17181200E+04, -.24414000E+04, -.20609400E+04, 0.52429100E+03, -.22838600E+04, -.14814900E+04, -.25724900E+04, 0.13669800E+04, -.31453500E+04, 0.10998500E+04, 0.25082700E+04, 0.25675900E+04, -.17214000E+04, -.10813700E+04, 0.14601400E+04, -.12682300E+04, 0.94997500E+03, -.29513300E+03, -.16736900E+04, 0.27494800E+04, 0.18330600E+04, -.88710600E+02, -.12658000E+04, 0.34300400E+04, 0.13158200E+04, -.21604200E+04, -.23928700E+04, 0.27210700E+04, -.10501900E+04, 0.30944500E+04, -.17064100E+04, -.29000000E+04, 0.18441200E+04, -.57936000E+03, 0.12711700E+04 },
        { -.22407600E+01, 0.23892800E+01, 0.64861800E+00, -.70925000E+00, 0.32400100E+00, 0.58149200E+00, -.20551900E+01, -.11984600E+01, -.44792800E+00, 0.14574300E+01, 0.80256900E-02, 0.31074300E-01, -.22145900E+01, 0.87712400E+00, -.25385800E+01, -.31425200E+01, 0.13462400E+01, -.78310400E+00, 0.15589300E+01, -.19386400E+01, -.92140100E+00, 0.12689100E+00, -.60859800E-01, -.13680000E+00, -.19541300E+01, 0.21087000E-01, 0.10870200E+00, -.50144300E+00, 0.11190700E+01, 0.54749700E+00, 0.80630900E-01, 0.97728900E+00, -.71310900E+00, 0.38111700E+00, -.15635500E+00, 0.50777500E+00, -.81928200E-01, -.86341800E+00, 0.72294700E+00, -.85074400E+01, -.14347900E+00, 0.16548900E+00, -.26193300E+00, -.28911900E+00, 0.13848200E+00, -.15164700E+00, 0.81771400E+04, 0.43607800E-01, -.42178700E+03, 0.24533400E+04, -.27879200E+03, -.12430600E+04, 0.21087700E+04, 0.21744200E+04, 0.37523600E+04, -.29177900E+04, 0.15647300E+04, 0.12549100E+05, 0.14590200E+04, -.18014600E+03, 0.56132400E+03, 0.10777000E+04, -.80272000E+03, -.61939100E+03, 0.13653300E+04, -.10955000E+04, 0.67889000E+04, -.32684500E+04, -.72215300E+04, -.33944200E+04, -.89110600E+03, -.34895800E+04, -.16985100E+03, 0.13660200E+04, -.22473100E+04, -.31647500E+04, -.29276500E+04, 0.98945200E+04, -.49481300E+04, 0.90209200E+02, -.49473200E+04, -.11399800E+04, -.18439500E+04, -.15973100E+04, 0.18790100E+03, -.47684500E+04, -.13599400E+04, -.55255200E+03, 0.18326600E+03, -.98592800E+00, 0.18185100E+05, -.91611000E+02, 0.24547900E+03, 0.76316400E+03, -.80426200E+03, -.31348400E+04, 0.14413600E+04, 0.14975700E+04, 0.34329000E+04, -.40728400E+04, 0.20842200E+04, -.15965800E+05, 0.20364800E+04, 0.27749000E+04, 0.36028800E+04, -.27878800E+04, -.17559000E+04, -.14909400E+03, 0.29273000E+04, 0.16823500E+04, 0.12931300E+05, -.63319700E+04, -.75283800E+04, -.64650700E+04, -.20768200E+04, -.25644700E+04, -.22052800E+04, -.71786800E+03, -.14999400E+04, -.19174300E+04, -.32529900E+04, 0.11526800E+05, -.57499300E+04, -.27431800E+04, -.57632900E+04, -.26626200E+04, -.15305900E+04, -.75271600E+03, 0.33466300E+04, -.41249600E+04, -.13726700E+04, -.53062700E+04, -.40112100E+03, 0.19761000E+03, 0.46477400E+03, 0.20055600E+03, 0.20387900E+03, 0.47065500E+03, -.27527600E+03, -.45721700E+03, 0.18953500E+03, 0.37891800E+03, -.14141200E+03, 0.51738200E+04, -.31889500E+04, -.13543700E+05, -.25866000E+04, -.15717700E+04, -.26732900E+04, -.10942500E+04, -.19242100E+04, -.15570900E+04, -.22099800E+04, 0.20135200E+04, 0.39378600E+04, -.15772000E+04, -.24817600E+04, -.19689000E+04, -.28301900E+04, -.32101900E+04, 0.19063900E+04, 0.28246700E+04, -.23421600E+04, -.29328600E+04, -.97769500E+03, -.46344200E+04, 0.25427700E+04, 0.76092500E+03, 0.23162400E+04, -.27348700E+03, -.70946600E+03, 0.10372400E+04, -.54275600E+03, 0.15104700E+04, 0.65631500E+02, 0.44142200E+04, -.17872600E+04, 0.67954800E+03, 0.10734400E+05, 0.89559700E+03, -.21243400E+04, 0.22100100E+04, 0.11567400E+04, 0.43828300E+03, -.10518200E+04, 0.19819400E+04, 0.71329400E+04, -.44130700E+04, 0.25939900E+04, 0.10053700E+05, 0.22063100E+04, 0.24520000E+04, 0.26481500E+04, -.13064400E+04, -.23796600E+04, -.27439200E+04, 0.32488200E+04, -.13500700E+04, 0.87010300E+04, -.43982000E+04, -.85846100E+04, -.43506700E+04, -.37492700E+03, -.41137000E+04, -.98564900E+03, 0.28939700E+04, -.19671400E+04, -.42654900E+04, -.49576100E+04, -.15092000E+04, 0.75371500E+03, 0.71058700E+04, 0.75448700E+03, 0.13087000E+04, 0.10775900E+04, -.56436300E+02, 0.73266300E+03, 0.20891300E+04, 0.13219500E+04, 0.27260700E+04, -.36071600E+04, 0.16663100E+04, 0.14653800E+05, 0.18036400E+04, -.25923300E+04, -.24177800E+04, 0.36864100E+04, 0.41454500E+04, 0.49703200E+04, -.27968400E+04, 0.44787200E+04, 0.17263900E+05, -.85986100E+04, -.13372200E+05, -.86307200E+04, -.24326400E+04, -.34100500E+04, -.40917300E+04, -.29603900E+04, -.42612300E+04, -.23067700E+04, -.29167400E+04, -.17901400E+04, 0.67540400E+03, 0.43089400E+05, 0.89508600E+03, -.58307400E+04, -.58673600E+04, 0.73507600E+04, 0.63675300E+04, 0.71091800E+04, -.49943300E+04, 0.97964400E+04, 0.10392800E+05, -.52326100E+04, -.84363100E+03, -.51963500E+04, -.16040700E+04, -.12943000E+04, -.29744600E+03, 0.21350100E+04, -.48278200E+04, -.97756200E+03, -.24624100E+04, 0.84663400E+04, -.43483100E+04, -.52886400E+04, -.42330700E+04, -.22080600E+04, -.91433500E+03, -.12958300E+04, 0.10754700E+04, -.48790800E+04, -.99392200E+03, -.42474700E+04, 0.43124800E+03, -.15929300E+03, 0.10441300E+04, -.10866900E+04, -.53436000E+03, -.90537100E+03, 0.55818200E+01, 0.10010800E+02, -.94860600E+03, -.29401000E+03, 0.16095100E+04, 0.15777000E+04, 0.86935700E+03, -.16896400E+03, 0.10688900E+04, 0.81744000E+03, -.28773100E+03, -.13657400E+04, 0.27993400E+04, -.36786800E+03, 0.17669700E+03, -.65015000E+04, -.92670000E+03, 0.31690900E+04, 0.32080500E+03, 0.38708800E+03 },
        { -.67383900E+01, 0.23082000E+01, 0.36994400E+00, -.36349900E+01, -.50945500E+01, 0.73317600E+01, -.90573100E+01, 0.12333100E+02, -.43811300E+01, 0.56404500E+01, -.25346500E-01, -.39713600E+00, 0.38340300E+01, 0.23527600E+01, 0.48758100E+01, 0.48073000E+01, -.27751700E+01, 0.46283700E+00, -.15077500E+01, 0.61923000E+00, -.17622200E+01, 0.44915500E+00, -.27183000E-01, 0.66923500E+00, -.62632200E+01, 0.65849700E+00, -.17770800E+01, -.13554900E+01, 0.22247900E+01, 0.84065200E+00, 0.15427800E+00, -.46515200E+00, -.12448200E+01, 0.36155600E+00, 0.17309300E-01, -.10431600E+00, -.17433000E+01, -.24977800E+01, -.94825200E+00, -.16978400E+02, -.33902400E+00, -.10520000E+01, 0.26247700E+00, 0.18445300E+01, 0.71892200E+00, -.13424300E+00, -.10223300E+00, 0.88193300E+01, -.70159300E+04, -.18758400E+04, 0.89465000E+04, 0.13701400E+05, 0.91302900E+04, -.39646200E+04, 0.75430900E+04, -.78545500E+03, 0.47749300E+03, -.40579100E+04, 0.39305200E+03, -.37986700E+04, -.46109000E+04, 0.69670900E+04, 0.70027000E+04, 0.91128600E+03, -.45710100E+04, -.88619000E+04, 0.19989200E+05, -.98647700E+04, -.23895400E+05, -.99945300E+04, -.86229800E+04, -.10356200E+05, -.70595500E+03, -.37248500E+04, -.12680600E+05, -.69096900E+04, -.12726300E+05, 0.28111100E+05, -.14080200E+05, -.14717900E+05, -.14055700E+05, -.67223600E+04, -.11499600E+04, -.33585400E+04, 0.28274200E+03, -.15747900E+05, 0.96337300E+03, -.15535400E+05, 0.99801700E+03, -.33751900E+03, 0.24905300E+05, -.49902600E+03, -.15045700E+04, 0.43834700E+04, 0.70317500E+04, 0.11201800E+05, 0.66083600E+04, 0.10024600E+04, 0.16269200E+04, 0.20725100E+04, -.94493700E+03, -.11557900E+05, -.10361000E+04, 0.10196400E+05, 0.79586700E+04, -.98974900E+04, -.57068400E+04, -.15223200E+04, 0.58627000E+04, 0.70437800E+04, 0.18898400E+05, -.90738300E+04, -.23256900E+04, -.94474700E+04, 0.96404600E+03, 0.14697000E+04, -.51013200E+04, 0.36211700E+04, 0.24504100E+04, 0.37843500E+03, 0.14672900E+03, 0.34124700E+05, -.17102500E+05, -.15468800E+05, -.17062100E+05, -.98813400E+04, -.40557400E+04, 0.20606800E+03, 0.79163100E+04, -.15196400E+05, -.22095400E+04, -.23090800E+05, -.24634600E+04, 0.12349200E+04, 0.11331900E+04, 0.12317200E+04, 0.12849000E+04, 0.10188000E+04, -.55607100E+03, -.87466700E+03, 0.13931500E+04, 0.65106000E+03, 0.15809400E+04, -.10105200E+05, 0.35188100E+04, 0.48404300E+03, 0.50532600E+04, 0.24213300E+04, -.32546500E+04, 0.33918200E+04, 0.11777500E+04, 0.69841900E+04, -.29738000E+04, 0.97852100E+04, -.19882800E+05, 0.10507700E+05, -.67868700E+04, 0.99415300E+04, 0.29178300E+04, 0.21342000E+04, 0.38858500E+04, 0.30423300E+04, 0.58771600E+04, 0.15788800E+04, 0.12849400E+05, -.13955900E+04, 0.10463400E+04, 0.49797500E+04, 0.69593100E+03, -.93721400E+03, 0.12111200E+04, 0.10874800E+04, 0.37227600E+04, 0.96597500E+03, 0.27695000E+03, 0.64653500E+04, -.51373700E+05, 0.25386700E+05, -.11131600E+04, 0.25705500E+05, -.11465200E+05, -.10784400E+05, 0.20778000E+05, 0.86353900E+04, 0.21525300E+05, -.86869800E+04, 0.31161100E+05, 0.52237900E+04, -.18874900E+04, 0.10073900E+05, -.26125700E+04, 0.10317300E+03, 0.40899500E+04, -.55788800E+04, -.58787500E+04, -.10127400E+05, 0.47394200E+04, -.63962800E+04, -.72886300E+04, 0.36674700E+04, 0.12299200E+05, 0.36440500E+04, 0.88117800E+04, 0.79134900E+04, -.11156400E+05, -.14777500E+05, 0.64968200E+03, 0.77680500E+04, 0.94945300E+04, -.73682900E+04, 0.38109300E+04, 0.10374000E+05, 0.36838700E+04, 0.44560400E+04, 0.65661900E+04, 0.72322600E+03, 0.51495600E+04, 0.86432000E+04, 0.50459100E+04, 0.94351900E+04, -.14782500E+05, 0.72311600E+04, 0.15785700E+05, 0.73913800E+04, -.73721700E+04, -.39265500E+04, 0.10839300E+05, 0.71847600E+04, 0.75133200E+04, -.36600900E+04, 0.58472300E+04, 0.13631900E+05, -.67415600E+04, 0.40492800E+03, -.68124100E+04, 0.52489500E+04, 0.44613200E+04, -.69300700E+04, 0.15583900E+04, 0.37220000E+04, 0.32547600E+04, 0.62166400E+04, -.42214900E+05, 0.20904100E+05, 0.52991000E+05, 0.21107500E+05, -.15090000E+05, -.68514400E+04, 0.28164500E+05, 0.18831600E+05, 0.22099200E+05, -.54251600E+04, 0.18838900E+05, 0.12585300E+05, -.62863200E+04, -.75347700E+04, -.62924100E+04, -.59593000E+04, -.24664400E+04, 0.12507400E+04, 0.38949800E+04, -.79385600E+04, -.73331000E+03, -.73535800E+04, 0.24351000E+04, -.14445000E+04, -.81285600E+04, -.12172800E+04, -.18919500E+04, -.42961700E+03, -.69339200E+03, -.17883800E+04, -.64258500E+04, 0.33357800E+03, -.70729800E+04, 0.27113300E+04, 0.22917000E+04, 0.41520400E+04, -.34221400E+04, -.93569700E+03, 0.15831200E+04, 0.42899300E+04, 0.13109300E+04, -.11837600E+04, -.26340200E+04, 0.57288900E+04, 0.12061200E+03, 0.17179000E+04, -.13041400E+04, 0.20111500E+04, 0.39572800E+04, -.22899800E+04, -.45598100E+04, 0.48991700E+04, 0.40581000E+04, 0.40114200E+04, -.98575100E+04, -.20285300E+03, 0.61113500E+04, -.12134300E+04, 0.13502000E+04 },
        { -.75072700E+01, 0.39004800E+01, 0.58834700E+00, -.33851400E+01, -.62331100E+01, 0.86845100E+01, -.93682300E+01, 0.14090700E+02, -.45741200E+01, 0.58133800E+01, -.15363500E-01, -.43721800E+00, 0.50679800E+01, 0.34484100E+00, 0.51741500E+01, 0.40779400E+01, -.49023400E+01, -.31543800E+00, -.15803100E+01, -.66175700E-01, -.58304700E+00, 0.41231900E+00, 0.18555200E+00, 0.67089800E+00, -.53088000E+01, 0.68941000E+00, -.19402300E+01, -.22586300E+01, 0.27067800E+01, 0.11640100E+01, 0.51214800E+00, 0.85069100E-01, -.11460800E+01, -.70574500E+00, -.14551300E-01, 0.18264100E+00, -.17221200E+01, -.23839400E+01, -.13892900E+01, -.18272100E+02, -.13030100E-01, -.72738800E+00, 0.11301800E+00, 0.15289800E+01, -.91510600E+00, -.27430100E+00, -.24078200E+00, -.95694300E+00, -.12831400E+05, -.40071800E+04, 0.17870500E+05, 0.26198500E+05, 0.18279600E+05, -.75592900E+04, 0.11776000E+05, 0.31051100E+04, -.14271400E+04, -.74768600E+04, -.15551600E+04, -.69023900E+04, -.70554600E+04, 0.10510600E+05, 0.98673100E+04, -.96365900E+03, -.69661700E+04, -.16886600E+05, 0.36236900E+05, -.17908700E+05, -.47692200E+05, -.18126500E+05, -.16430600E+05, -.20870500E+05, -.64433200E+03, -.60273900E+04, -.22169500E+05, -.14317400E+05, -.22184600E+05, 0.52340500E+05, -.26229200E+05, -.27885500E+05, -.26177100E+05, -.12787000E+05, -.29597200E+04, -.61047500E+04, 0.78737300E+03, -.28890700E+05, 0.98503600E+03, -.27656600E+05, 0.10110100E+05, -.47891300E+04, 0.47235200E+05, -.50681100E+04, -.33908800E+04, 0.72567500E+04, 0.12625600E+05, 0.21110400E+05, 0.10630100E+05, 0.14020800E+04, -.17497600E+04, 0.54669700E+04, -.25909700E+04, -.23844900E+05, -.27291700E+04, 0.19289000E+05, 0.14718000E+05, -.17368000E+05, -.74194500E+04, -.17515300E+04, 0.10497600E+05, 0.11178400E+05, 0.33180100E+05, -.15746900E+05, -.19134800E+04, -.16588200E+05, 0.23990500E+04, 0.24555300E+04, -.85135400E+04, 0.57448400E+04, 0.28859500E+04, 0.89582700E+03, -.15203000E+04, 0.67106700E+05, -.33656900E+05, -.29396100E+05, -.33563000E+05, -.18901400E+05, -.74055500E+04, -.79223700E+03, 0.15187900E+05, -.29348500E+05, -.40536500E+04, -.42330100E+05, -.44318700E+04, 0.22246500E+04, 0.22323800E+04, 0.22172000E+04, 0.23890500E+04, 0.20931800E+04, -.11091800E+04, -.16835400E+04, 0.23838500E+04, 0.13915900E+04, 0.27358300E+04, -.25439900E+05, 0.96893200E+04, 0.10290800E+04, 0.12720900E+05, 0.51109600E+04, -.79795500E+04, 0.89583600E+04, 0.21809100E+04, 0.14507100E+05, -.69853700E+04, 0.20004100E+05, -.40624000E+05, 0.21339900E+05, -.14479900E+05, 0.20311600E+05, 0.61323800E+04, 0.31752300E+04, 0.73008000E+04, 0.44445300E+04, 0.13562800E+05, 0.22816500E+04, 0.24268400E+05, -.23463500E+04, 0.18075500E+04, 0.10192900E+05, 0.11697300E+04, -.12642400E+04, 0.18954100E+04, 0.21550200E+04, 0.67553600E+04, 0.17950700E+04, 0.30139800E+03, 0.10343700E+05, -.98477300E+05, 0.48731000E+05, -.25961100E+04, 0.49276300E+05, -.22255300E+05, -.20987600E+05, 0.39844300E+05, 0.16609200E+05, 0.43008200E+05, -.16671000E+05, 0.58641100E+05, 0.16348000E+05, -.67790400E+04, 0.19407600E+05, -.81747200E+04, -.10748900E+04, 0.77868300E+04, -.12519400E+05, -.11665700E+05, -.20760200E+05, 0.91347100E+04, -.14308400E+05, -.88259900E+04, 0.45105700E+04, 0.23224800E+05, 0.44223800E+04, 0.14282000E+05, 0.12092500E+05, -.20052800E+05, -.23178200E+05, 0.11470500E+04, 0.12106400E+05, 0.14431100E+05, -.11078000E+05, 0.58082900E+04, 0.20983000E+05, 0.55460700E+04, 0.84420500E+04, 0.12652500E+05, 0.11244700E+04, 0.10699700E+05, 0.13835800E+05, 0.99288900E+04, 0.15587200E+05, -.22793500E+05, 0.11123200E+05, 0.30370100E+05, 0.11390600E+05, -.13786900E+05, -.78241000E+04, 0.18902100E+05, 0.12436800E+05, 0.10826600E+05, -.72714900E+04, 0.84356900E+04, 0.21177700E+05, -.10336400E+05, 0.37502100E+04, -.10584100E+05, 0.10378400E+05, 0.70942300E+04, -.10954700E+05, 0.14974500E+04, 0.48545600E+04, 0.56427400E+04, 0.10035300E+05, -.72327200E+05, 0.35843200E+05, 0.10201600E+06, 0.36149100E+05, -.28972400E+05, -.14428700E+05, 0.50937200E+05, 0.32615100E+05, 0.36746800E+05, -.11034600E+05, 0.31690100E+05, 0.23442200E+05, -.11674700E+05, -.16402900E+05, -.11724200E+05, -.10988000E+05, -.50396200E+04, 0.19168800E+04, 0.73489600E+04, -.12486000E+05, -.18304200E+04, -.12587400E+05, 0.70326400E+04, -.39471600E+04, -.16439800E+05, -.35229800E+04, -.40453600E+04, 0.84778200E+02, -.29097200E+04, -.38220000E+04, -.12645400E+05, 0.11336900E+04, -.12439700E+05, 0.49040600E+04, 0.38981100E+04, 0.76770200E+04, -.64711000E+04, -.18157500E+04, 0.28509500E+04, 0.72037700E+04, 0.21594400E+04, -.24660000E+04, -.51518500E+04, 0.10764100E+05, -.59640200E+03, 0.30607900E+04, -.24898500E+04, 0.33712000E+04, 0.76014100E+04, -.38849500E+04, -.88065400E+04, 0.92957600E+04, 0.75003300E+04, 0.70271200E+04, -.19469100E+05, 0.31414300E+03, 0.12118600E+05, -.20529400E+04, 0.26639500E+04 },
        { 0.29739100E+01, -.42671100E+01, -.47446700E+00, -.22431200E+01, -.47890100E+00, 0.15700600E+01, 0.20515300E+01, 0.22736400E+01, 0.17655700E+01, -.13152100E+01, -.43205700E+00, 0.23806400E+00, -.20166900E+01, 0.34523200E+01, 0.50125600E+00, 0.49685400E+01, 0.96170000E+00, -.71687200E+00, -.14757000E+01, 0.19471400E+01, -.49085700E+00, -.67711500E+00, -.17725600E+00, 0.35265400E+00, -.23376300E+01, -.79355800E-02, -.12582100E+01, -.10310300E+01, 0.38090600E+00, -.28288100E+00, -.22914700E+00, -.10572500E+01, -.13352000E+00, 0.96988500E+00, 0.61111100E+00, 0.59940400E-01, 0.15433300E+00, -.42499700E+00, -.15944100E+00, -.71661100E+01, -.21583800E-01, -.39877400E+00, 0.38167700E+00, -.29083000E+00, -.63624300E+00, -.14013100E+00, -.14772100E+00, -.47650200E-01, 0.13923100E+00, 0.50699600E+04, -.79178400E+03, -.39981800E+03, 0.15593200E+03, 0.41742700E+04, 0.15077500E+05, -.12573400E+05, 0.62512700E+04, 0.76983500E+04, 0.62857700E+04, 0.42695500E+04, 0.32355400E+04, 0.45373000E+04, 0.57704900E+04, 0.49698900E+04, 0.22353700E+04, 0.54248100E+04, 0.70370500E+04, -.35299800E+04, -.20032700E+04, -.35177400E+04, 0.39112400E+04, 0.22009700E+04, -.25670600E+04, 0.61557000E+01, -.16004100E+04, 0.12025700E+04, -.14562000E+04, 0.10373300E+05, -.52045700E+04, -.25290800E+04, -.51850700E+04, 0.27917200E+04, 0.63717500E+04, -.45731000E+04, -.28027200E+02, -.37444900E+04, 0.51770500E+04, 0.79785200E+04, 0.44281700E+04, -.22142600E+04, -.25761200E+04, -.22124300E+04, 0.34959200E+03, 0.76751800E+04, -.13182000E+04, 0.31138900E+04, -.13790400E+04, 0.60926900E+04, 0.10111000E+05, 0.12616400E+04, -.66315100E+03, -.12805800E+04, -.63213400E+03, 0.24257900E+03, -.24025000E+04, -.53587400E+04, -.10520300E+05, -.53161900E+04, -.13852500E+04, -.19935600E+04, 0.14866000E+05, -.71607300E+04, -.81249900E+04, -.74383600E+04, -.52986600E+03, 0.16914300E+04, -.53551700E+04, -.23679700E+04, -.75247500E+04, 0.14886200E+04, 0.34315400E+04, -.97733000E+04, 0.48798400E+04, 0.73268100E+04, 0.48869800E+04, 0.27397600E+04, 0.14493500E+04, 0.28104300E+04, 0.20409200E+04, 0.47707000E+04, 0.74511300E+03, 0.66346400E+04, 0.12425900E+04, -.62084000E+03, -.79317700E+03, -.62142800E+03, -.38535000E+03, -.46989900E+03, -.25821500E+03, -.35928700E+03, -.43235500E+03, -.30796400E+03, -.18442000E+04, 0.74516800E+04, -.39973900E+04, -.42427900E+04, -.37291900E+04, -.83900100E+03, 0.21374400E+04, -.42498800E+04, -.35107300E+04, -.76354400E+04, 0.16489500E+04, 0.10824600E+05, -.20289700E+04, 0.10372000E+04, 0.24241600E+04, 0.10142900E+04, 0.20743900E+03, 0.42720900E+04, -.88347600E+03, 0.72977200E+03, -.44289800E+03, 0.32918300E+04, 0.18263800E+05, -.11150500E+04, 0.58552000E+03, 0.12916500E+04, 0.55657600E+03, -.22813600E+03, 0.22837900E+04, -.45459500E+03, -.65579000E+03, 0.10448500E+03, 0.15599200E+04, 0.11456100E+05, -.55117300E+04, 0.27631000E+04, 0.15290100E+04, 0.27534100E+04, -.90260200E+03, 0.44288700E+04, -.21377800E+02, -.31503400E+04, -.66488700E+03, 0.39351400E+04, 0.34262900E+05, -.11361900E+05, 0.58017100E+04, 0.32594300E+04, 0.56832500E+04, 0.92922800E+03, -.13468800E+04, 0.36580800E+04, 0.17415800E+04, 0.57663700E+04, -.14135700E+04, -.16155300E+04, 0.48785400E+04, -.23861400E+04, -.59509200E+04, -.24391100E+04, -.42660200E+04, -.51976000E+04, -.34274700E+04, -.72478400E+04, -.41171400E+04, -.32551600E+04, -.96807300E+04, 0.17934800E+04, -.84726300E+03, -.12095200E+04, -.89658900E+03, -.10095800E+04, 0.28662800E+03, -.57934900E+03, -.12909500E+04, -.73179900E+03, 0.51785600E+03, 0.27371700E+04, -.12171500E+05, 0.60904700E+04, 0.46183000E+04, 0.60860400E+04, 0.10425700E+04, 0.31141200E+04, 0.58274100E+04, 0.69994100E+04, 0.71835900E+04, 0.19291100E+04, 0.13337600E+05, 0.18975900E+05, -.92191600E+04, -.11574000E+05, -.95004200E+04, -.74255700E+03, 0.36698600E+04, -.86202600E+04, -.51430500E+04, -.12469500E+05, 0.30963500E+04, 0.11040100E+05, -.12630100E+05, 0.63565200E+04, 0.43144400E+04, 0.63169500E+04, -.71434000E+03, 0.98947200E+04, 0.92080600E+04, 0.14993400E+05, 0.98945700E+04, 0.70658500E+04, 0.35677600E+05, -.34648300E+04, 0.17694000E+04, 0.42965400E+04, 0.17325900E+04, 0.10995700E+04, 0.34989000E+04, 0.27610900E+03, 0.20820000E+03, 0.66975400E+03, 0.23947300E+04, 0.11222700E+05, 0.13976600E+04, -.71958500E+03, 0.15633000E+04, -.69896200E+03, -.27428700E+03, -.33669500E+03, -.33626600E+03, 0.12777600E+03, -.93319900E+03, -.39340500E+03, 0.29606500E+04, -.14705600E+04, -.19165900E+04, -.72814200E+03, 0.14293300E+04, 0.18564200E+04, -.34735200E+04, -.15121700E+03, -.79537300E+03, 0.17524500E+04, 0.24487200E+04, -.91244600E+03, -.71106600E+03, 0.11646200E+04, 0.94982500E+03, -.47027000E+03, -.18426300E+04, 0.22962300E+04, 0.12967900E+04, -.62157800E+03, -.21885900E+03, -.19205800E+04, 0.39190500E+04, 0.59914700E+03, -.35402500E+04, 0.69635300E+03, -.18725800E+04 },
        { -.38548200E+00, -.68947800E-01, 0.11507900E-01, -.15502400E+00, -.51336700E+00, -.97264600E+00, 0.27717400E+00, 0.20438000E-01, -.40453600E-01, -.24847500E-01, -.10808500E-01, 0.15532200E-01, 0.27731200E-01, -.39641200E+00, 0.77158900E+00, 0.85721500E+00, 0.39914900E+00, 0.92581200E-01, -.65598100E-01, 0.49176800E+00, -.30852600E+00, -.76147300E-02, -.64535700E-03, -.48571500E-01, 0.36237500E+00, 0.11678000E-01, 0.11389200E+00, 0.80587000E+00, -.42210600E+00, 0.22405100E+00, 0.19034800E-01, -.31161500E+00, 0.24739000E+00, 0.18053700E+00, -.93569500E-01, -.18519900E+00, -.10402400E+00, 0.39125900E+00, 0.69314000E+00, 0.21568700E+00, 0.18666600E-01, -.16896500E-01, -.30721100E-01, 0.30352700E+00, -.96922400E-01, -.91541000E-02, -.65489700E-01, 0.57805800E-02, 0.22098300E-01, -.62626300E-01, -.85099200E+03, -.16887500E+04, -.38527300E+03, 0.84884400E+02, 0.91644800E+03, 0.71119400E+03, -.38447200E+03, 0.10330200E+04, -.35544500E+03, 0.36849400E+03, 0.55799000E+03, -.97550000E+03, -.10328800E+04, -.61350800E+03, 0.66958200E+03, 0.58053100E+02, -.22100200E+04, 0.10763800E+04, 0.12951500E+04, 0.11052800E+04, 0.85298600E+03, 0.92014800E+03, 0.10465800E+03, -.17862300E+03, 0.95873200E+03, 0.63708300E+03, 0.11810600E+04, -.22901400E+04, 0.11349100E+04, 0.14158400E+04, 0.11452400E+04, 0.75088900E+03, 0.59728300E+03, -.95100000E+02, -.57647900E+03, 0.84468100E+03, 0.36994200E+03, 0.20842900E+04, -.18814200E+03, 0.71369700E+02, -.27919800E+03, 0.94485100E+02, -.32297600E+03, 0.60909400E+02, -.10790700E+04, -.18508800E+04, -.56154800E+03, 0.23231400E+02, 0.11487700E+04, 0.21593900E+03, -.12331300E+03, 0.14123000E+03, -.10806400E+03, -.72081500E+03, -.59197000E+03, 0.64733400E+03, 0.53953900E+03, -.96516100E+02, -.28790900E+03, -.45634400E+03, 0.44236600E+04, -.21399700E+04, -.24704200E+04, -.22115800E+04, 0.19031400E+03, 0.15338900E+03, -.15301700E+04, -.27536400E+03, -.18632400E+04, 0.13587500E+03, -.16220400E+04, -.27933200E+04, 0.13764600E+04, 0.20441300E+04, 0.13970200E+04, 0.80427700E+03, 0.46269200E+03, -.20699700E+03, -.11961200E+04, 0.68917000E+03, 0.43335900E+03, 0.16816000E+04, 0.37351700E+03, -.18459700E+03, -.13123400E+03, -.18680000E+03, -.14364300E+03, -.97894200E+02, 0.61602300E+02, 0.18134000E+03, -.10380700E+03, -.62063600E+02, -.26791500E+03, 0.10467600E+04, -.57788300E+03, -.23866200E+04, -.52323600E+03, 0.10270300E+04, 0.45468700E+03, -.14191500E+04, -.92731200E+03, -.80707700E+03, 0.30160900E+03, 0.30640400E+03, 0.54473500E+02, -.70471200E+02, 0.51927500E+03, -.27206100E+02, -.28642400E+03, -.35489500E+03, -.40802800E+03, -.12044900E+04, -.17242700E+03, -.12799400E+03, 0.98115200E+03, -.96422700E+02, 0.28374900E+02, 0.34309500E+03, 0.48303100E+02, -.22775200E+03, -.31555900E+03, -.38323400E+03, -.10546800E+04, -.13408600E+03, -.18194000E+03, 0.68510700E+03, 0.26383000E+04, -.12780700E+04, 0.60927500E+03, -.13203300E+04, 0.44872600E+03, 0.26797600E+03, -.15911500E+04, -.20398300E+04, -.15475800E+04, 0.39942100E+03, 0.91677900E+03, -.15518100E+04, 0.77739900E+03, 0.10992700E+04, 0.77579900E+03, -.36309900E+03, -.27807400E+03, 0.79922000E+03, 0.19927900E+03, 0.85472800E+03, -.16136300E+03, 0.33822400E+03, 0.11033800E+04, -.51513600E+03, -.10044100E+04, -.55206400E+03, -.84849300E+03, -.12076800E+04, 0.14994000E+04, 0.25010700E+04, 0.18620600E+03, -.10996400E+04, -.14049100E+04, 0.16716000E+04, -.81465200E+03, -.59337600E+03, -.83608400E+03, -.56942700E+03, -.39344700E+03, -.37061300E+03, -.29579500E+03, -.11535400E+04, -.36812000E+03, -.53970900E+03, 0.11505800E+04, -.55117000E+03, -.88881100E+02, -.57506600E+03, 0.38638600E+03, 0.37069300E+03, -.83560000E+03, -.86504800E+03, -.92930000E+03, 0.22018400E+03, 0.54526700E+02, 0.51856300E+04, -.25257700E+04, -.39729300E+04, -.25922700E+04, 0.63486300E+03, 0.37121200E+03, -.23434700E+04, -.80994900E+03, -.24516900E+04, 0.31999100E+03, -.14832900E+04, 0.25158700E+04, -.12077600E+04, -.11560900E+04, -.12574800E+04, 0.57205000E+03, 0.61748900E+03, -.23812300E+04, -.28931100E+04, -.21074700E+04, 0.20784700E+03, 0.12641800E+04, -.22232300E+04, 0.11302300E+04, 0.91064000E+03, 0.11117300E+04, 0.69231300E+03, 0.55091100E+03, -.30722300E+03, -.13428900E+04, 0.65220900E+03, 0.36630300E+03, 0.17610400E+04, 0.27497100E+03, -.13625600E+03, 0.77379800E+03, -.13722100E+03, 0.31743000E+03, 0.24544400E+03, -.23714100E+03, -.19712900E+03, -.13851300E+03, 0.35306700E+03, 0.23896300E+03, -.45531200E+03, -.25626400E+03, -.53344600E+03, 0.41954500E+03, -.39149100E+02, 0.52265300E+02, -.61204400E+03, -.93199400E+02, 0.16293100E+03, 0.25029300E+03, -.58390100E+03, -.11134600E+04, -.28579700E+03, 0.78970600E+02, -.63104500E+03, -.39725900E+03, 0.46505700E+03, 0.61891000E+03, -.46160500E+03, -.52145900E+03, -.31239200E+03, 0.69454800E+03, 0.95834200E+03, -.49558500E+03, 0.14134600E+03, 0.75270500E+02 },
        { 0.14668200E+01, -.17726900E+01, -.18806200E+00, -.45492700E+00, 0.36085000E-01, -.20675900E+01, 0.29437300E+01, -.12544000E+01, 0.13353000E+01, -.10912100E+01, -.53213000E-01, 0.25302900E+00, -.49052600E+00, 0.55612400E+00, 0.74940000E+00, 0.13627200E+01, 0.11000900E+01, -.58899700E-01, -.10458000E+01, 0.11078600E+01, -.85002700E+00, -.72740200E-01, 0.11143800E+00, 0.34276400E+00, -.19529500E+01, -.45587200E-01, -.57965200E+00, -.93432400E+00, 0.77425800E+00, 0.61189300E+00, -.12232100E+00, -.36615500E+00, -.55450400E+00, 0.66181400E+00, 0.34453600E+00, -.26402200E+00, 0.16072100E+00, -.14615800E+00, -.60947800E+00, -.50785900E+01, -.15465600E-01, -.38697100E+00, 0.10633200E+01, 0.89727200E+00, -.68813500E+00, -.26577100E+00, 0.13369900E+00, -.34861300E-01, 0.16573200E+00, -.19612000E+00, 0.11794000E+01, -.17298900E+04, -.92173200E+03, 0.66123500E+03, -.23136000E+03, 0.27918400E+04, -.15200000E+04, 0.92821400E+01, -.13968200E+04, -.12625600E+04, 0.73570100E+03, -.16965200E+04, -.20429900E+04, -.13880400E+04, 0.87236700E+03, 0.14406900E+04, -.24165100E+04, 0.10793700E+04, 0.22404000E+03, 0.12091800E+04, -.69113100E+03, -.33724900E+03, 0.40565600E+03, 0.18384200E+03, 0.18690600E+04, -.88866900E+03, 0.26600800E+04, 0.93733400E+03, -.50317400E+03, 0.70705000E+02, -.46694500E+03, -.72620400E+03, 0.30688200E+02, -.28201800E+03, 0.11501900E+03, 0.53206200E+03, -.61991200E+03, 0.29301200E+04, 0.76922100E+04, -.39360600E+04, -.17875900E+04, -.38441900E+04, -.13000400E+04, 0.29841200E+03, -.75068500E+03, -.12233200E+03, -.36274000E+04, 0.63423100E+03, -.28703400E+04, -.27133700E+04, 0.12991800E+04, 0.23505000E+04, 0.13552900E+04, 0.42238700E+03, -.56488000E+03, 0.22049700E+03, -.71676800E+03, 0.96353500E+03, -.73475400E+02, -.78664900E+03, -.28330100E+04, 0.16711000E+04, 0.21443200E+03, 0.14107800E+04, 0.58202300E+03, 0.50902200E+03, -.14377300E+03, -.17115800E+04, -.13311100E+04, 0.80150300E+03, 0.16631000E+04, 0.69599700E+03, -.41655100E+03, 0.24567200E+04, -.34751700E+03, -.76579500E+03, 0.13649200E+04, -.12852800E+04, -.72539000E+03, -.33467500E+03, 0.61613400E+03, 0.29719600E+04, 0.34709000E+03, -.16552700E+03, -.28268200E+03, -.17369900E+03, -.27674600E+02, -.12539700E+03, 0.25501600E+02, 0.38785600E+02, -.28889400E+03, 0.32498800E+02, -.53154400E+03, -.48613400E+04, 0.24572800E+04, -.60010800E+03, 0.24273000E+04, 0.77641600E+03, 0.18792500E+04, -.54581800E+03, -.20698700E+04, 0.57461400E+03, 0.15337900E+04, 0.44876000E+04, -.56960500E+04, 0.25907100E+04, 0.14407100E+04, 0.28478000E+04, -.28846700E+04, -.21857700E+04, 0.75713100E+03, -.20622300E+04, 0.40982000E+04, -.21991900E+04, 0.55864400E+04, -.21980900E+04, 0.97510300E+03, 0.23602600E+04, 0.10984600E+04, -.12728200E+04, -.16139000E+04, 0.38999200E+03, -.15887100E+04, 0.66068500E+03, -.13404500E+04, 0.14852800E+04, -.37154400E+04, 0.20416300E+04, -.68172800E+03, 0.18518700E+04, -.11989800E+04, -.17431200E+04, 0.96973900E+03, -.20434300E+04, 0.25287500E+04, -.13204100E+04, 0.62632700E+04, 0.42503800E+04, -.22529800E+04, -.82643600E+03, -.21227600E+04, -.12505100E+04, -.22601500E+04, 0.41668100E+03, 0.12986200E+04, -.88336500E+02, -.21574100E+04, -.23406100E+04, -.57613300E+03, 0.41880100E+03, -.86735700E+03, 0.28803200E+03, 0.42427500E+03, -.23901800E+04, 0.25757200E+04, 0.37440300E+04, 0.11786000E+04, -.20686800E+04, -.28652600E+04, 0.23753100E+04, -.11083300E+04, -.65983800E+03, -.11876100E+04, 0.42652100E+02, -.23808500E+03, 0.12964900E+03, 0.37299500E+03, -.30171400E+04, -.46845800E+01, -.25181400E+04, 0.75550100E+04, -.36611700E+04, -.39389900E+04, -.37771400E+04, -.41361200E+03, -.34233500E+03, -.15835500E+03, 0.11956400E+04, -.40614300E+04, -.36205500E+03, -.24581800E+04, -.41781800E+04, 0.23916000E+04, -.10081200E+04, 0.20760400E+04, 0.48734700E+03, 0.10403900E+04, -.41551900E+03, -.27392100E+04, -.17261600E+04, 0.11934000E+04, 0.40955600E+04, 0.12791900E+05, -.61713200E+04, -.80598300E+04, -.63937800E+04, -.17654900E+04, -.73390600E+03, 0.67920300E+02, 0.13770000E+04, -.69940500E+04, -.91066600E+03, -.13771300E+04, -.29596000E+04, 0.15447300E+04, 0.39045500E+03, 0.14799400E+04, 0.22870000E+03, 0.10435900E+04, -.47814600E+03, -.65779600E+03, 0.31986600E+04, 0.16927600E+03, 0.39213000E+04, 0.20636200E+04, -.99723900E+03, 0.59663400E+03, -.10318500E+04, -.53833300E+03, 0.10169000E+04, -.14304900E+04, -.43295800E+03, 0.22512600E+03, 0.47571900E+03, 0.24280300E+04, -.58740600E+03, 0.82228900E+02, -.12817700E+03, 0.13558300E+03, 0.97241100E+02, -.28385700E+03, -.10415700E+04, -.12277500E+03, 0.61502100E+03, -.84666300E+01, -.44144100E+03, -.71367200E+02, -.21265600E+03, -.88562200E+02, 0.28972800E+03, -.59329700E+03, 0.40102600E+03, 0.22100100E+03, 0.22880800E+03, -.77219700E+03, -.22688200E+03, 0.62304200E+03, -.16395500E+03, -.29988100E+03, -.93728300E+02, -.86610200E+02 },
        { 0.25532900E+01, 0.75166300E-01, -.78782900E-01, 0.11148700E+01, 0.14625800E+01, -.10896500E+01, 0.21227300E+01, -.40888200E+01, 0.13966100E+01, -.17799100E+01, -.56809600E-01, 0.44830300E-01, -.11110600E+01, -.12459000E+01, 0.18168900E+01, -.26888100E+01, 0.15489600E+01, 0.10077200E+01, -.74425800E+00, 0.63303600E+00, -.78324700E+00, 0.35744300E-03, -.11619100E+00, 0.78898400E-01, 0.97610700E+00, 0.17637500E-01, 0.88191500E+00, 0.25409200E+01, -.17042600E+01, 0.11042900E+01, -.99850600E+00, -.83410000E+00, -.20368800E+00, -.73083300E+00, -.57151800E+00, -.59287600E+00, -.16455900E+00, -.76941400E+00, 0.32476500E+01, -.80525700E+01, -.18618400E+00, -.18302600E+00, 0.44001900E+00, 0.41971100E+00, -.30674900E+00, 0.27434400E+00, 0.16105500E+00, 0.21042300E-01, -.14700000E+00, -.58268000E+00, -.23016000E+01, -.40941300E+00, 0.32612800E+04, 0.67944300E+01, 0.66692100E+04, -.86610800E+04, 0.41731600E+04, 0.62441400E+04, 0.43302300E+04, 0.41443800E+04, 0.19608500E+04, -.32695900E+03, -.14349000E+04, 0.33060300E+04, 0.92018300E+03, 0.27427700E+04, 0.18840200E+04, -.10911300E+04, -.13085700E+03, -.94159200E+03, 0.45080400E+04, 0.38749500E+04, -.23772600E+04, 0.20831100E+03, 0.26227200E+03, 0.21398900E+04, 0.16686900E+04, -.22177000E+04, 0.10455500E+04, 0.15312800E+04, 0.11095700E+04, 0.38289300E+04, 0.48645900E+04, -.27392700E+04, -.11912700E+04, 0.81048300E+03, 0.39130600E+04, 0.98593700E+04, 0.14359100E+04, -.82745200E+03, -.52918300E+03, -.71716000E+03, -.15603200E+01, 0.29682900E+04, -.21349200E+04, 0.13968700E+04, 0.38802400E+04, 0.17775700E+04, 0.44361900E+04, -.67938600E+04, 0.33265100E+04, 0.57136600E+04, 0.33963400E+04, -.11655500E+03, 0.64795700E+03, 0.28287500E+03, -.44760300E+04, -.27306000E+04, 0.20113100E+04, 0.75531600E+03, 0.17508400E+05, -.83542300E+04, -.13300100E+05, -.87558900E+04, -.12254200E+04, 0.13730200E+04, -.64475700E+04, 0.26200200E+04, -.21369300E+04, 0.92666700E+02, 0.90023300E+02, -.10021900E+05, 0.49016100E+04, 0.72846900E+04, 0.50112500E+04, 0.47195500E+04, 0.30833200E+04, -.13588700E+04, -.25005500E+04, 0.33229500E+04, 0.21855000E+04, 0.82353500E+04, 0.59361700E+03, -.28507800E+03, -.40838300E+03, -.29688100E+03, -.65665700E+03, -.49682000E+03, 0.40218600E+03, 0.25965200E+03, -.10226700E+03, -.32161400E+03, -.13219000E+04, 0.12416600E+05, -.62183400E+04, -.11080600E+05, -.62097500E+04, -.74806000E+03, 0.26801500E+04, -.85086200E+04, -.22139100E+04, -.42637100E+04, 0.17195400E+04, 0.48037000E+04, 0.22547800E+04, -.13714000E+04, -.11780100E+03, -.11274100E+04, -.90419200E+02, 0.19229300E+04, -.26428200E+04, -.19092800E+04, -.33884600E+04, 0.14810600E+04, 0.13087300E+05, 0.29799100E+04, -.16091800E+04, 0.14456300E+04, -.14903600E+04, -.14929100E+03, 0.11095800E+04, -.21417500E+04, -.27116200E+04, -.23027500E+04, 0.88269600E+03, 0.60888900E+04, -.65337400E+04, 0.34698900E+04, 0.53824200E+04, 0.32659300E+04, 0.85985600E+03, -.48008500E+03, -.65102000E+03, -.66866500E+04, -.16120800E+04, 0.78782800E+03, 0.22119800E+05, -.15877700E+05, 0.78204600E+04, 0.46646900E+04, 0.79396300E+04, 0.24026700E+04, 0.13650700E+03, 0.44369900E+04, -.78234400E+03, 0.41710400E+04, -.24750800E+03, 0.36060500E+04, 0.54503900E+04, -.25320300E+04, -.53135500E+04, -.27251900E+04, -.48985100E+04, -.24402400E+04, 0.12629900E+04, 0.54900100E+03, -.54157800E+04, -.57599800E+03, -.53787300E+04, 0.34720200E+04, -.16256700E+04, -.21894700E+04, -.17360500E+04, -.94168300E+03, -.45497800E+03, -.12907800E+04, -.18795100E+04, -.22340700E+04, 0.54149700E+03, -.77395800E+03, 0.89278600E+04, -.43411200E+04, -.42265100E+04, -.44637300E+04, -.20877200E+02, -.96205200E+03, -.15382200E+04, 0.16767300E+04, -.59537500E+03, -.16312600E+04, 0.80299700E+03, 0.21712700E+05, -.10340100E+05, -.21456200E+05, -.10860700E+05, -.10160100E+04, 0.36457000E+04, -.11304300E+05, 0.15225300E+04, -.35019900E+04, 0.15843000E+04, 0.53666400E+04, 0.15036500E+05, -.72582100E+04, -.94976300E+04, -.75173100E+04, -.15625200E+04, -.16738400E+04, -.34618700E+04, 0.22815400E+04, 0.10589200E+04, -.29503700E+04, 0.12257300E+05, -.39032700E+04, 0.20290200E+04, 0.19104100E+04, 0.19519100E+04, 0.27300000E+04, 0.25680000E+04, -.20958000E+04, -.36672300E+04, -.37551000E+03, 0.18444600E+04, 0.85224400E+04, -.12914800E+04, 0.65282800E+03, 0.29228700E+04, 0.64579800E+03, 0.11637600E+04, 0.16546800E+04, -.13250300E+04, -.16582100E+04, -.19819800E+04, 0.12922100E+04, 0.41406700E+04, -.81283600E+03, -.12543700E+04, -.16607900E+04, 0.11422900E+04, 0.12413400E+04, -.16849300E+04, -.45240900E+03, -.37259100E+03, 0.99703600E+03, 0.20164300E+04, -.19730500E+04, -.21738800E+04, 0.48702900E+02, 0.93273100E+03, -.17212400E+04, -.16266500E+04, 0.17263600E+04, 0.17236900E+04, -.17817000E+04, -.14229500E+03, -.13314700E+04, 0.21962800E+04, 0.19271200E+04, -.22419100E+04, 0.39967600E+03, -.92732800E+03 },
        { -.12617200E+01, -.82527400E+00, -.53603100E-01, -.92333600E+00, -.10911900E+01, -.73582700E+00, -.37688500E+00, 0.76750800E+00, -.52991200E+00, 0.10565400E+01, 0.29464300E-01, -.11295000E-01, 0.11903000E+01, -.14597100E+01, 0.28668100E+00, 0.18161500E+01, -.59908500E+00, -.28467000E+00, -.87953600E+00, -.95019900E-01, 0.61423700E-01, 0.10719200E+00, 0.73538100E-01, 0.65999300E-01, -.12338000E+01, -.37346600E-01, -.48075100E+00, -.22800900E+00, 0.89631300E+00, 0.48639400E-01, 0.26888700E+00, 0.19997200E+00, 0.55225700E+00, 0.65389000E+00, -.67209500E-01, 0.20468200E+00, -.38853700E-01, 0.11774600E+00, 0.18076700E+00, -.53203700E+00, 0.23645600E-02, 0.93281700E-01, -.92208800E+00, -.18118400E-01, 0.19433000E+00, -.22177200E+00, -.35578300E+00, 0.22780200E-01, 0.54015700E-01, -.24056900E-01, 0.66857700E+00, -.44112000E-01, 0.90585400E-02, -.50746400E+03, 0.18358000E+04, -.79187100E+03, 0.44695000E+03, 0.57000000E+03, 0.39650900E+03, -.98045300E+03, -.67269100E+03, 0.11485700E+04, 0.12193600E+04, 0.37416100E+03, -.15813200E+03, 0.37648800E+03, 0.14521300E+04, -.66865800E+03, -.13086000E+04, -.72559400E+03, -.20690800E+04, -.14789800E+04, 0.58166100E+03, 0.84965600E+02, -.84794300E+03, -.45221000E+03, -.15646700E+04, 0.37004100E+04, -.18551400E+04, -.57615000E+03, -.18501400E+04, -.18266000E+04, -.80704400E+03, -.38979300E+03, 0.14154500E+03, -.94193700E+03, -.40576400E+03, -.21396600E+04, -.97866100E+03, 0.57446100E+03, 0.26234100E+04, 0.48996900E+03, -.94733700E+03, 0.20028700E+03, 0.71384900E+03, -.18222400E+03, 0.55464300E+03, -.23374400E+03, 0.30676200E+04, 0.19582500E+04, -.90305900E+03, -.32696300E+04, -.97905300E+03, 0.13316300E+03, -.51561200E+03, -.12728300E+04, -.14406900E+04, -.16106100E+03, -.99649800E+03, 0.66832700E+02, -.21163300E+05, 0.10644400E+05, 0.82225300E+04, 0.10583400E+05, 0.45572800E+04, 0.62428000E+04, 0.21971400E+04, -.24218400E+04, 0.52489600E+04, 0.53905600E+04, 0.77705500E+04, 0.35724200E+04, -.17893800E+04, -.62244200E+03, -.17854300E+04, -.22728600E+04, -.13302100E+04, 0.67861700E+03, 0.12610500E+04, -.83442800E+03, -.45110500E+03, -.35103100E+04, -.48230200E+03, 0.24170100E+03, 0.14851800E+03, 0.24108100E+03, 0.26526500E+03, 0.14482500E+03, -.10107000E+03, -.13226500E+03, 0.16082400E+03, 0.36824700E+02, 0.35381600E+03, -.14237400E+05, 0.68935600E+04, 0.69418200E+04, 0.71198300E+04, 0.16046000E+04, 0.31305900E+04, 0.33474400E+04, 0.45103700E+03, 0.45941200E+04, 0.27010000E+04, 0.52818000E+04, -.29282300E+04, 0.16505400E+04, 0.97026500E+03, 0.14642200E+04, 0.16741700E+04, -.10340800E+04, -.19773100E+03, -.13239000E+04, 0.12614700E+04, -.44805300E+03, -.18317000E+04, -.76806400E+03, 0.55204700E+03, 0.72730800E+03, 0.38403500E+03, -.20329200E+03, -.14286400E+04, 0.29271800E+03, -.59566700E+03, 0.56060600E+03, -.13160000E+04, -.17830200E+03, -.30056400E+04, 0.13687100E+04, -.24684700E+03, 0.15015800E+04, 0.72404200E+03, -.46596700E+03, 0.11519700E+04, 0.29376100E+03, 0.11679300E+04, -.64000700E+03, 0.81713400E+03, 0.30614300E+04, -.13314700E+04, -.28220200E+04, -.15314600E+04, -.60154300E+03, -.19396700E+04, -.46618000E+03, -.31940600E+03, -.42220300E+03, -.11913400E+04, -.17057800E+04, -.76350300E+03, 0.34093500E+03, -.32146900E+03, 0.38079000E+03, 0.29993600E+04, 0.13799500E+04, -.14982200E+04, -.17306200E+04, 0.47377900E+03, 0.83045300E+03, -.45009200E+03, -.21768400E+04, 0.10969400E+04, 0.12923500E+04, 0.10877000E+04, 0.65814200E+03, 0.77067000E+03, -.11555400E+03, -.27960300E+03, 0.16902700E+04, -.32042400E+02, 0.28021000E+04, -.83093200E+04, 0.40914600E+04, 0.51401100E+04, 0.41551400E+04, 0.30633500E+03, 0.12572000E+04, 0.18602000E+04, -.51874400E+03, 0.22152900E+04, 0.11965000E+04, 0.37146800E+04, -.33394300E+05, 0.16729400E+05, 0.13300000E+05, 0.16701100E+05, 0.64034800E+04, 0.89268000E+04, 0.43693400E+04, -.30032000E+04, 0.91996100E+04, 0.78009400E+04, 0.12189200E+05, -.12733700E+05, 0.62646500E+04, 0.10611700E+05, 0.63675300E+04, 0.64710800E+03, 0.25633600E+04, 0.37360800E+04, 0.41848600E+03, 0.34923400E+04, 0.23094500E+04, 0.57090100E+04, 0.21984400E+04, -.11505600E+04, 0.43864700E+03, -.10990400E+04, -.13015000E+04, -.93748700E+03, 0.33807700E+03, 0.79404000E+03, -.73595600E+03, -.49352200E+03, -.15690000E+04, 0.12889900E+04, -.70843600E+03, -.28267000E+03, -.64382600E+03, -.81850400E+03, -.10886800E+04, 0.30578200E+03, 0.30863000E+03, -.37697800E+03, -.34654500E+03, -.24171000E+04, 0.61020100E+03, 0.62259900E+03, 0.84313000E+03, -.61857500E+03, -.26112700E+03, 0.70723400E+03, 0.34541400E+03, 0.10174400E+03, -.26544700E+03, -.52726400E+03, 0.97561300E+03, -.11435300E+03, 0.63142300E+02, -.32714400E+03, 0.11825400E+04, 0.35946300E+03, -.34186300E+03, -.68832400E+03, 0.10020400E+04, -.92956800E+01, 0.50478700E+03, -.81764500E+03, -.79447400E+03, 0.65155300E+03, -.79618800E+02, 0.24344200E+03 },
        { 0.12461500E+01, -.12732100E+01, -.14963700E+00, -.36260000E+00, 0.60752400E+00, 0.11455700E+00, 0.21572000E+00, -.11649900E+01, 0.42185300E+00, -.36234500E+00, 0.47662800E-01, 0.13891500E+00, -.60789800E+00, 0.21620900E+01, -.49427800E+00, -.12905700E+00, 0.54444900E+00, 0.34247700E-01, 0.76485000E-01, 0.67290200E+00, -.29305000E+00, -.93497000E-01, -.60289000E-01, -.45296900E-01, 0.10450300E-01, 0.10178500E-01, 0.10023800E-01, 0.63257500E+00, 0.25769600E+00, -.31877900E+00, 0.25400800E+00, 0.33922800E+00, 0.17712100E+00, 0.18864900E+00, 0.23865000E-01, 0.14463900E+00, -.39805800E-01, 0.35653500E+00, -.13917700E+00, 0.35142800E+01, 0.80182200E-02, 0.85232700E-02, 0.21536400E-01, 0.29244900E+00, -.41495100E-01, 0.74383200E-01, 0.11535900E+00, -.12276700E-02, -.38425900E-01, 0.55129400E-01, 0.64049300E+00, -.18166800E+00, -.55667800E-01, -.13857900E+00, -.37042700E+04, 0.38877900E+04, -.19739600E+04, -.12158900E+04, -.19441800E+04, -.22853000E+03, 0.44893200E+03, -.18865800E+04, -.19655500E+04, -.19765200E+04, 0.44740800E+03, -.17408400E+04, -.48815300E+04, 0.24120500E+04, 0.38088600E+04, 0.24404900E+04, 0.73063400E+03, -.27158300E+03, 0.86149100E+03, -.46816700E+03, 0.19934200E+04, -.26939500E+03, 0.20261200E+04, -.58980200E+04, 0.29468200E+04, 0.40196700E+04, 0.29489300E+04, 0.36685500E+03, -.77650100E+03, 0.13596000E+04, -.30064200E+03, 0.19885100E+04, -.47191400E+03, -.16588000E+03, 0.47658200E+03, -.28859900E+03, -.55506800E+03, -.23867000E+03, 0.18589300E+03, -.31489400E+03, -.30762700E+03, -.63635200E+03, -.26843900E+03, -.27279000E+03, -.37699400E+04, 0.62220900E+04, -.31633500E+04, -.14727300E+04, -.31110400E+04, -.11768500E+04, -.41684900E+03, 0.63878700E+03, 0.45951300E+04, -.58260700E+03, -.84214500E+03, -.17337300E+04, 0.10262400E+05, -.50596000E+04, -.27044000E+04, -.51320800E+04, -.39724500E+03, -.94896300E+03, -.50643000E+03, 0.18316800E+04, -.39732900E+04, -.72432500E+03, -.73795500E+04, -.14909800E+04, 0.74880600E+03, 0.11169200E+04, 0.74505400E+03, 0.72700400E+03, -.62014000E+02, -.31575300E+03, -.86567500E+03, -.93012000E+02, 0.62971100E+02, 0.29232000E+03, 0.63407200E+03, -.31780200E+03, -.35944700E+03, -.31699400E+03, -.88885700E+02, 0.11653600E+03, -.10783300E+03, 0.62714500E+02, -.26012900E+03, 0.86329800E+02, -.47932300E+01, 0.98226600E+03, -.41537200E+03, -.24369900E+04, -.49161800E+03, 0.13019400E+04, -.21760400E+04, 0.13486200E+04, 0.12136600E+04, -.28188000E+03, -.18342400E+04, -.40489000E+04, 0.89347100E+03, -.52788900E+03, 0.15560600E+04, -.44679800E+03, -.10995000E+04, -.73926000E+03, 0.50645700E+03, 0.46650400E+03, 0.46285600E+03, -.42953600E+03, -.34010800E+04, -.50074500E+03, 0.19218900E+03, 0.75722500E+03, 0.24978700E+03, 0.15465800E+03, 0.64533900E+03, 0.30366300E+03, 0.10965400E+04, 0.53709200E+03, 0.56830700E+03, -.19395800E+04, 0.56454600E+03, -.20821500E+03, -.99773000E+02, -.28198200E+03, 0.66631200E+03, 0.44702000E+02, 0.13576600E+03, 0.38264500E+03, 0.63329200E+02, 0.54369200E+03, -.64212600E+04, 0.16253700E+04, -.85269000E+03, 0.88140200E+01, -.81232700E+03, -.29786400E+03, 0.19492100E+04, -.15830500E+04, -.10054500E+04, -.83190400E+03, 0.16627300E+04, 0.12955100E+04, 0.18675500E+04, -.90381200E+03, -.17814700E+04, -.93328900E+03, -.50482200E+03, -.24362500E+03, 0.11865100E+04, 0.29013400E+04, 0.58217700E+03, -.34924800E+03, 0.13404000E+04, 0.34095500E+04, -.17091900E+04, -.21288400E+04, -.17043900E+04, -.85260800E+03, -.54279500E+03, 0.10146800E+02, 0.15788600E+04, -.13106600E+04, -.54462800E+03, -.26082900E+04, -.22736800E+04, 0.11678900E+04, 0.96722700E+03, 0.11365700E+04, 0.98268000E+03, 0.77960700E+02, -.52101300E+03, -.27362400E+04, -.89257300E+03, 0.51508400E+03, -.15350900E+04, 0.13748200E+05, -.67762900E+04, -.44414300E+04, -.68759900E+04, -.13348600E+03, -.20199500E+04, -.24207300E+03, 0.24550200E+04, -.55860500E+04, -.15983400E+04, -.11172400E+05, -.87488300E+04, 0.44312300E+04, 0.29026500E+04, 0.43740000E+04, 0.23684800E+04, -.25538100E+03, -.28928200E+03, -.63026800E+04, -.19478300E+03, 0.10520300E+04, -.45270600E+04, -.24631900E+04, 0.12630300E+04, 0.95348300E+03, 0.12314400E+04, 0.60173700E+02, -.43873700E+03, 0.27384700E+03, -.34928600E+03, 0.14888100E+04, -.24233600E+03, -.77572900E+03, 0.57809400E+03, -.25721300E+03, 0.88061200E+02, -.28940600E+03, 0.32179700E+03, 0.46285800E+03, -.45260300E+03, -.37010600E+03, -.44666300E+03, 0.53298200E+03, -.56014900E+03, -.75896600E+03, -.36129400E+03, -.23735800E+03, 0.23327000E+03, -.15907600E+03, 0.88813200E+02, -.52919600E+03, 0.60467900E+02, -.43686300E+03, -.59428400E+02, 0.44862600E+02, -.12711000E+04, -.20932700E+03, -.16290200E+03, -.10317800E+04, -.49626200E+03, 0.26825200E+03, 0.14722400E+03, -.55365000E+03, -.31619200E+03, -.60631100E+02, -.69141800E+03, 0.14058500E+04, 0.51757800E+03, 0.48461900E+03, 0.19008700E+03 },
        { 0.28958300E+01, -.87240300E+00, -.19108800E+00, 0.38276900E+00, 0.16819800E+01, -.60499000E+00, 0.11739800E+01, -.19204300E+01, 0.10437000E+01, -.12833200E+01, -.15778600E-01, 0.22367900E+00, -.15873600E+01, 0.13973400E+01, -.68426300E+00, -.48922100E+00, 0.17037100E+01, -.57852100E+00, 0.29489200E+00, 0.49088600E+00, -.11545400E+01, -.78626100E-02, 0.69038000E-02, 0.19222500E+00, -.99412000E+00, -.38350200E-01, 0.34635100E+00, 0.51585100E+00, 0.87594900E+00, 0.16278900E+00, -.40224500E-01, 0.35708500E+00, -.42897200E+00, 0.22175200E+00, -.15470700E+00, 0.15202900E+00, -.18717800E-01, -.54971300E+00, 0.13208100E+01, -.32429000E+01, -.13534400E+00, -.23538100E+00, 0.25096200E+00, 0.36140500E+00, -.59157500E+00, -.12440500E+00, 0.22916500E+00, 0.54868200E-03, -.57215500E-01, 0.14859100E+00, 0.79058100E+00, -.10499200E+00, 0.20208500E+00, -.40188900E+00, 0.12821700E+01, 0.59522100E+04, -.28895500E+04, -.47969600E+04, -.29756600E+04, -.59591900E+03, 0.38078000E+03, -.86418900E+03, 0.77587800E+03, -.24826600E+04, 0.66752500E+03, -.17356200E+04, 0.69135800E+04, -.33601300E+04, -.50849400E+04, -.34570200E+04, -.19924900E+04, -.12569700E+04, 0.14568600E+03, 0.15469300E+04, -.32496700E+04, -.72387400E+03, -.48265300E+04, 0.60993600E+04, -.30427800E+04, -.39217400E+04, -.30502900E+04, -.14340800E+04, -.18908400E+04, 0.24943400E+03, 0.12146500E+04, -.26137000E+04, -.14410700E+04, -.56067700E+04, 0.23539500E+03, -.81888400E+01, 0.23165300E+04, -.11823300E+03, -.57212800E+03, -.14382900E+04, 0.70607700E+03, -.68887700E+03, 0.43659900E+03, -.74484300E+03, 0.78915300E+03, -.31900400E+04, 0.16779700E+04, -.26135700E+04, 0.15955500E+04, 0.12811800E+04, 0.12720700E+04, -.18895700E+03, -.91684300E+02, 0.25239900E+04, 0.65519600E+03, 0.19734000E+04, -.11854400E+05, 0.59305200E+04, 0.57908600E+04, 0.59294900E+04, 0.13103900E+04, 0.14319900E+04, 0.19176800E+04, -.18934300E+04, 0.45075400E+04, 0.12435700E+04, 0.38301600E+04, 0.10779400E+05, -.53648100E+04, -.75125000E+04, -.53896800E+04, -.23324600E+04, -.99918400E+03, -.81181000E+03, 0.18745200E+04, -.42058200E+04, -.85845500E+03, -.72093000E+04, -.13666700E+04, 0.68062800E+03, 0.85433700E+03, 0.68337700E+03, 0.35160100E+03, 0.31250000E+03, -.39531900E+02, -.30538600E+03, 0.51588900E+03, 0.21724400E+03, 0.10508900E+04, -.31303200E+04, 0.14233900E+04, 0.28268600E+04, 0.15666600E+04, -.93503200E+03, 0.40267700E+03, 0.18122400E+04, 0.41958400E+03, 0.18559400E+04, 0.24404000E+03, -.94649800E+03, 0.34462200E+04, -.14778600E+04, -.41020300E+04, -.17230200E+04, 0.21420100E+04, -.27548100E+03, 0.24992500E+03, 0.18070100E+04, -.11322600E+04, -.27331000E+03, -.67505800E+04, 0.13595400E+04, -.50338300E+03, -.12963000E+04, -.67941000E+03, 0.84606900E+03, -.20809800E+03, -.20637900E+03, 0.14413900E+03, -.18434700E+03, 0.14221600E+03, -.24614200E+04, 0.48137300E+04, -.25923300E+04, -.27896000E+03, -.24047800E+04, 0.10882600E+03, 0.95764800E+03, -.45138300E+03, 0.22025300E+04, -.14754000E+04, 0.44252200E+03, -.72615000E+04, 0.25163900E+04, -.10862700E+04, 0.80712500E+03, -.12592000E+04, 0.40450000E+02, -.37041600E+03, -.12664400E+04, -.83976500E+03, -.17755500E+04, 0.17604100E+03, -.10578200E+04, -.84572900E+04, 0.41480800E+04, 0.69915800E+04, 0.42284200E+04, 0.14742200E+04, -.74426000E+03, 0.10269100E+04, -.13216700E+04, 0.45179100E+04, -.12009300E+04, 0.36698500E+04, -.39699700E+04, 0.19705400E+04, 0.28374300E+04, 0.19848100E+04, 0.12639300E+04, 0.18766500E+03, 0.69438700E+03, 0.62185600E+03, 0.42144400E+04, -.17250300E+03, 0.24806200E+04, -.15726100E+04, 0.68974000E+03, 0.41185700E+04, 0.78627600E+03, -.10594200E+04, -.27381500E+03, 0.60680400E+03, -.25295700E+03, 0.49083900E+03, -.13485600E+03, 0.15755700E+03, -.16620800E+05, 0.83166300E+04, 0.92512600E+04, 0.83157600E+04, 0.13986000E+04, 0.18712800E+04, 0.33225200E+04, -.22061800E+04, 0.65957800E+04, 0.15798600E+04, 0.40169200E+04, 0.79413900E+03, -.56311400E+03, 0.11022400E+05, -.39770700E+03, -.14945200E+04, -.13525000E+04, 0.15494200E+04, 0.71059500E+03, -.28788800E+03, -.68475700E+03, -.39290000E+04, 0.76107400E+04, -.38741100E+04, -.26496700E+04, -.38054300E+04, -.14298100E+04, -.19159700E+04, 0.17112900E+03, 0.22838400E+04, -.32332800E+04, -.14735000E+04, -.59821600E+04, 0.13052800E+04, -.71986000E+03, -.29631100E+04, -.65248100E+03, -.54657400E+03, -.47644100E+03, -.22517200E+03, 0.86370900E+02, -.14569400E+04, -.36020500E+03, -.25393500E+04, 0.18584100E+04, 0.86024200E+03, 0.92186500E+03, -.96338900E+03, -.49265600E+03, 0.61373500E+03, 0.66546400E+03, 0.25427000E+03, -.58443100E+03, -.78886100E+03, 0.97943100E+03, 0.13934100E+04, 0.63423200E+03, -.94334700E+02, 0.11700700E+04, 0.16799200E+04, -.12627500E+04, -.10702900E+04, 0.12978700E+04, 0.64995500E+03, 0.10110300E+04, -.21703100E+04, -.14120000E+04, 0.15420400E+04, -.68250200E+03, 0.46500500E+03 },
        { -.10004300E+01, 0.20836300E+01, 0.24513500E+00, 0.75131400E+00, 0.58009300E+00, 0.41006100E+00, -.35812500E+01, 0.37003100E+01, -.14759200E+01, 0.16354400E+00, -.14779800E-02, -.18041900E-01, 0.51362900E+00, 0.99958700E-02, 0.86780300E+00, -.13154400E+00, -.26659700E+00, 0.84324500E+00, -.57946600E+00, 0.83870400E+00, -.13152500E-01, 0.56997900E-01, -.36226200E-02, 0.14539800E+00, -.15790600E+01, -.14894800E-01, -.70052300E-01, 0.48288200E+00, 0.15243700E+00, 0.43077700E+00, -.99594500E-01, -.32850500E-01, 0.44486100E-01, 0.22403300E+00, -.16147600E+00, 0.15511900E+00, -.37069400E-02, -.30716700E+00, -.24407400E+00, -.11376500E+01, 0.16240000E-01, -.11473200E+00, -.27254100E+00, -.36411200E-01, 0.44749300E-01, 0.64281300E-02, -.25791600E+00, -.12218000E-01, 0.39566100E-01, 0.16197200E+00, -.43645400E+00, 0.27800300E-01, 0.26933000E+00, 0.31885700E+00, 0.52732600E+00, -.59022500E+00, 0.14103300E+03, -.74435400E+03, 0.32705500E+00, -.19271700E+03, -.95222100E+03, 0.19733100E+04, 0.24523500E+04, -.17009400E+03, -.35642100E+03, -.76320100E+03, 0.47584500E+04, -.22376000E+04, -.29009400E+04, -.23792800E+04, -.12609000E+04, -.10552400E+04, 0.11580300E+03, 0.59542900E+03, -.30624500E+04, -.27036200E+03, -.33910500E+04, 0.52878100E+04, -.26035000E+04, -.39143400E+04, -.26442300E+04, -.74308200E+03, -.17452600E+04, 0.45194000E+03, 0.86044500E+03, -.28508500E+04, -.12204500E+04, -.39776400E+04, -.20005400E+04, 0.11214800E+04, 0.15898400E+04, 0.10000700E+04, 0.80709800E+03, -.18165000E+04, 0.15296000E+04, -.17663600E+03, 0.10896300E+04, -.94213300E+03, 0.15137000E+04, -.19787400E+04, 0.10745300E+04, -.30631900E+04, 0.98967100E+03, 0.70586200E+03, 0.94914900E+03, -.66470000E+03, -.99403000E+03, 0.20822900E+04, 0.37223000E+03, 0.12656500E+04, -.11572000E+05, 0.55205700E+04, 0.71489000E+04, 0.57874500E+04, -.35003700E+03, -.26862600E+04, 0.39370100E+04, -.17024500E+04, 0.38384900E+04, -.17986800E+04, 0.39893400E+04, 0.39443100E+04, -.18980400E+04, -.58855300E+04, -.19720500E+04, -.13141800E+04, -.23152600E+04, 0.19511200E+04, 0.23631500E+04, -.17162200E+04, -.15750900E+04, -.36416300E+04, -.81253000E+03, 0.39822000E+03, 0.69555600E+03, 0.40627700E+03, 0.27257100E+03, 0.23275100E+03, -.13848600E+03, -.18248300E+03, 0.41471100E+03, 0.10448800E+03, 0.61046400E+03, -.12295900E+04, 0.53925700E+03, 0.65678800E+04, 0.61579600E+03, -.17592400E+04, -.26784800E+04, 0.31617600E+04, 0.32904200E+03, -.46251400E+02, -.17381500E+04, -.12797800E+04, 0.36760300E+04, -.15551000E+04, -.30295400E+04, -.18379600E+04, 0.19715700E+04, 0.19141000E+03, 0.88329000E+03, 0.27641500E+04, -.16618400E+04, 0.91731400E+02, -.74937400E+04, 0.72386200E+02, 0.10931500E+03, -.29624100E+04, -.35605300E+02, 0.60559900E+03, 0.20113900E+03, 0.31647400E+03, 0.93518600E+03, 0.52572700E+03, 0.34754000E+03, -.21745100E+04, 0.58806700E+04, -.31622000E+04, 0.18630400E+04, -.29384900E+04, -.87558200E+03, 0.12500000E+04, -.13558900E+04, 0.16857900E+04, -.17235100E+04, 0.46506300E+03, -.77089400E+04, 0.25044300E+04, -.11201000E+04, -.91957400E+03, -.12528600E+04, 0.74901200E+01, 0.10170800E+04, -.13747900E+04, 0.39452800E+03, -.82862800E+03, 0.11303200E+04, -.15286600E+04, -.28375200E+04, 0.12659100E+04, 0.27866800E+04, 0.14184900E+04, 0.11055000E+04, 0.11876500E+04, -.16888600E+04, -.21740200E+04, 0.25346700E+04, 0.68237400E+02, 0.15436400E+04, -.35901400E+04, 0.17255700E+04, 0.19904000E+04, 0.17948700E+04, 0.73492100E+03, -.12680600E+03, 0.81121700E+03, 0.33297100E+03, 0.42747000E+04, -.36091500E+03, 0.29067400E+04, -.20185400E+04, 0.88065200E+03, 0.36485100E+04, 0.10093200E+04, -.77467800E+03, -.16300900E+03, 0.66085600E+03, 0.88976700E+03, 0.12607700E+04, -.19666300E+03, 0.12858800E+04, -.14126300E+05, 0.67291800E+04, 0.12803900E+05, 0.70665900E+04, -.10176800E+04, -.45162100E+04, 0.62155100E+04, -.16670200E+04, 0.44614700E+04, -.29680600E+04, 0.35473400E+04, 0.65683800E+03, -.57745800E+03, 0.85310600E+04, -.32867200E+03, -.83541600E+03, -.98296700E+03, 0.11607300E+04, 0.25351200E+04, 0.65457500E+03, -.74760900E+03, -.14932400E+04, 0.72936700E+04, -.37261900E+04, -.24676200E+04, -.36468600E+04, -.12787500E+04, -.16665800E+04, 0.75170800E+03, 0.24613800E+04, -.34082500E+04, -.10206800E+04, -.50936100E+04, -.29844400E+03, 0.10406700E+03, -.17109500E+04, 0.14940400E+03, 0.12774800E+01, -.91409300E+03, 0.84011400E+03, 0.68974700E+03, -.91831400E+03, -.70460100E+03, -.23623200E+04, 0.11308300E+04, 0.48885200E+03, 0.72132600E+03, -.66330300E+03, -.54254100E+03, 0.52715300E+03, 0.83260700E+03, 0.12116600E+03, -.63942500E+03, -.67435100E+03, 0.93844100E+03, 0.16537100E+04, 0.34796600E+03, -.13869700E+03, 0.98858400E+03, 0.13206500E+04, -.11359600E+04, -.78466600E+03, 0.77791700E+03, 0.47270200E+03, 0.81679900E+03, -.18040100E+04, -.13671900E+04, 0.12471600E+04, -.25113500E+03, 0.44334500E+03 },
        { -.48095100E+01, 0.34018100E+01, 0.87383900E+00, 0.26776400E-01, -.10637500E+01, -.17641800E+01, -.19587200E+01, -.17693600E+01, -.13580600E+01, 0.23384400E+01, 0.28041800E-01, -.14630900E+00, -.84376100E+00, -.34952300E+01, -.17860200E+01, -.44875300E+01, -.11557900E+01, -.91241700E+00, 0.19986900E+01, -.12455600E+01, -.24017100E+00, 0.21395300E+00, 0.31666000E+00, -.14822800E-01, 0.17089800E+01, 0.13612400E+00, 0.19828200E+01, -.23283900E+00, 0.21708400E+00, 0.15467100E+01, -.21583500E-02, 0.11756200E+01, -.21494900E+00, 0.16752700E+00, -.22904700E-01, 0.76386800E+00, -.19287200E+00, -.20027700E+00, 0.44917600E+00, -.14098700E+02, 0.42609800E+00, 0.68688100E+00, -.14005400E+01, 0.39034100E+00, -.34700700E-01, -.40711400E+00, -.69559300E+00, -.58059500E-02, -.16184700E-01, 0.39735000E+00, -.47456900E+00, 0.82310400E+00, 0.45636000E+00, 0.32528200E+00, 0.46884300E+00, 0.19285900E+01, 0.30329600E+00, 0.84836400E+04, 0.56236200E-01, 0.31590900E+03, -.77415500E+03, -.34366500E+03, -.35930900E+04, -.92998800E+03, -.18885400E+03, -.37973300E+04, -.10125500E+05, 0.50700300E+04, -.83100400E+04, 0.50618700E+04, 0.42323200E+03, -.21697300E+04, 0.23042100E+04, -.80182700E+03, 0.41158900E+04, -.11732200E+04, 0.28868200E+04, -.88683300E+04, 0.44365400E+04, 0.41325900E+04, 0.44331500E+04, 0.22018000E+04, -.10441100E+04, 0.15205400E+04, -.18156600E+04, 0.21690400E+04, -.29747100E+01, 0.65918800E+03, 0.28879800E+04, -.15562800E+04, 0.12815700E+05, -.14455100E+04, 0.23601300E+04, -.24100200E+03, -.20928600E+04, -.25068300E+04, -.46218200E+04, 0.41584400E+02, -.30127200E+04, 0.73819300E+04, -.38170300E+04, -.12291600E+05, -.36902400E+04, -.22654900E+04, -.17488500E+03, 0.63944500E+03, 0.63526600E+04, -.52473500E+02, -.92444300E+03, -.49722200E+03, 0.41334000E+05, -.20595300E+05, -.72631900E+04, -.20665300E+05, -.47229800E+04, -.72419100E+04, -.46738000E+04, 0.37553900E+04, -.13508700E+05, -.59296200E+04, -.18656900E+05, 0.13017400E+03, -.69907600E+02, 0.47008900E+04, -.65963200E+02, 0.48718400E+03, 0.31071900E+03, 0.68739500E+03, 0.21245000E+03, 0.42549100E+02, 0.13593800E+04, -.34769800E+04, 0.12627900E+04, -.63380500E+03, 0.30895400E+03, -.63125400E+03, -.32532100E+03, 0.10461200E+03, -.14074600E+03, 0.37809300E+03, -.51681400E+03, -.52667400E+02, -.15216200E+03, 0.33370400E+04, -.21983500E+04, -.19188200E+05, -.16674700E+04, 0.34438100E+04, -.70614400E+04, 0.25281200E+04, 0.30071500E+04, 0.20350500E+04, -.62360400E+04, -.32233900E+04, -.18655100E+05, 0.94134500E+04, -.30038200E+04, 0.93275600E+04, 0.28736800E+04, -.20175400E+03, 0.15790100E+04, -.42410300E+04, 0.67300400E+04, 0.15370400E+04, 0.54752100E+04, -.33675000E+04, 0.16223500E+04, 0.36086200E+04, 0.16836300E+04, 0.35849100E+03, -.21867700E+04, 0.25496700E+03, -.10576900E+04, 0.79443800E+03, -.11193300E+04, 0.14221700E+04, -.59944900E+04, 0.30752000E+04, -.27645700E+04, 0.29999300E+04, -.27484500E+04, -.25031300E+04, 0.28425600E+04, 0.20452700E+04, 0.47585400E+04, -.15833600E+04, -.54955700E+03, 0.13222500E+05, -.64126100E+04, 0.14854200E+05, -.66119800E+04, -.27400100E+04, 0.11837500E+04, -.46464600E+04, -.31422500E+04, -.75139500E+04, 0.22714400E+04, -.68660100E+04, 0.15163200E+05, -.75113800E+04, 0.11665500E+03, -.75809100E+04, -.53632500E+04, -.33540000E+04, -.85723300E+03, 0.66807700E+04, -.50369800E+04, -.28300200E+04, -.38459800E+04, 0.70726200E+04, -.35496800E+04, 0.81948000E+04, -.35357800E+04, -.12245100E+04, 0.95079500E+03, -.18154100E+04, 0.64645900E+03, -.69996600E+04, 0.88421400E+03, -.10279300E+04, 0.25100100E+04, -.12683100E+04, 0.78679600E+04, -.12555800E+04, 0.28221000E+03, -.42646800E+03, -.13507900E+04, -.87285400E+03, -.21081200E+04, -.10820000E+03, -.28543500E+04, 0.55305900E+05, -.27763300E+05, -.16515500E+05, -.27648900E+05, -.43199100E+04, -.11603100E+05, -.59059500E+04, 0.52953300E+04, -.17741800E+05, -.92166500E+04, -.26569000E+05, -.10288400E+04, 0.50590600E+03, 0.23252300E+05, 0.51269600E+03, 0.15238100E+04, -.14068100E+04, -.25816100E+04, -.46445400E+04, -.33419300E+04, -.15892800E+03, -.41420800E+04, -.24850400E+04, 0.13417700E+04, -.35576200E+04, 0.12421800E+04, 0.35943000E+04, 0.12689900E+04, -.70350000E+03, -.19008400E+04, 0.25974500E+04, 0.21137200E+04, -.12507500E+04, 0.11193300E+04, -.57126300E+03, 0.11774000E+04, -.56016300E+03, -.23965000E+03, -.10197900E+04, 0.18230300E+04, 0.14785300E+04, 0.18662400E+04, -.36086500E+03, -.41963700E+04, -.17983700E+04, -.16540700E+04, -.10538500E+04, 0.87090500E+03, 0.13293700E+03, -.53600100E+03, -.11876900E+04, -.10945000E+04, -.88989100E+03, 0.11245400E+03, -.51206200E+03, -.29845800E+04, -.85890600E+03, 0.17255800E+03, -.26603100E+04, 0.11226700E+04, 0.20622800E+04, 0.50951800E+03, 0.12640900E+04, -.44589700E+03, -.18680800E+04, -.21700500E+04, 0.40834000E+04, 0.79240500E+03, 0.70618900E+03, -.34701100E+03 },
        { -.35347200E+01, 0.16756100E+01, 0.15782300E+00, -.72886600E+00, -.14771700E+01, 0.43166800E+01, -.58727200E+01, 0.28869400E+01, -.24829300E+01, 0.32356800E+01, -.15201200E-01, -.33400500E+00, -.57366400E+00, 0.27372400E+01, -.48290000E+00, 0.90805400E+00, 0.22473200E+00, -.14409800E+00, 0.21708900E+00, -.78473000E+00, -.82995400E+00, 0.17971700E+00, -.19611300E+00, 0.32279300E+00, -.17517700E+01, 0.10966200E+00, -.78365800E+00, -.60870400E+00, 0.88397900E+00, -.15305600E+00, 0.18326300E+00, -.15989700E+00, -.20460700E+00, 0.47127300E+00, 0.17000300E-01, 0.60307800E-01, -.35442700E+00, -.75681800E+00, 0.12690500E+01, -.62692200E+01, -.14127100E+00, -.19369900E+00, 0.14275000E+01, -.12160500E+00, -.50388600E+00, 0.18944800E-01, 0.52375700E+00, -.15092500E-01, -.28065900E-01, 0.13833700E+00, -.22455400E+01, 0.16042100E+00, 0.48103100E+00, -.25911900E+00, 0.11850100E+01, -.74783300E+00, 0.59868100E+00, -.22059300E+00, 0.96982500E+01, -.10966800E+04, 0.44311100E+02, 0.29261400E+03, 0.22309000E+03, 0.37075200E+01, 0.35947800E+03, -.61787900E+02, 0.15273500E+04, -.74724800E+03, -.48199600E+04, -.76375100E+03, -.18133500E+04, -.43916000E+03, 0.41964400E+03, 0.61284000E+03, -.49026300E+03, -.18736800E+03, -.11287200E+04, 0.25522600E+04, -.12949100E+04, -.15902500E+04, -.12769700E+04, -.14997400E+04, -.64064200E+03, -.73086700E+02, 0.15153300E+03, -.70638900E+03, -.66201900E+03, -.20071800E+04, -.31402200E+04, 0.16021400E+04, 0.34333500E+04, 0.15696600E+04, -.70042800E+03, -.61601700E+03, 0.25030200E+03, -.15013400E+04, 0.37952700E+03, -.14957800E+03, 0.23315700E+04, -.24145000E+04, 0.12232000E+04, -.23761900E+04, 0.12080400E+04, 0.69240700E+03, 0.25327100E+03, -.14580200E+03, -.83111700E+03, 0.41123900E+03, 0.53800500E+03, 0.82327500E+03, 0.21837000E+04, -.86608700E+03, 0.17391800E+04, -.10873700E+04, 0.10748000E+04, 0.28022400E+04, -.20504800E+04, -.10142600E+04, -.10213200E+04, 0.21525400E+04, -.15539100E+04, 0.60631200E+04, -.30465600E+04, -.15693500E+04, -.30311200E+04, -.17523300E+04, 0.77596200E+03, -.65632500E+03, 0.10732000E+04, -.15956200E+04, 0.50053000E+03, -.38105700E+04, -.44296100E+03, 0.22274700E+03, 0.49558300E+03, 0.22149800E+03, 0.16437400E+03, 0.91384000E+01, 0.70649300E+01, -.86874800E+02, 0.12912200E+03, -.65312200E+01, 0.33163400E+03, -.89342900E+04, 0.42488200E+04, -.54637700E+04, 0.44698800E+04, 0.27971400E+04, 0.39819800E+04, 0.34472800E+03, 0.46834300E+03, 0.40933400E+04, 0.27133000E+04, 0.38075700E+04, -.19470700E+04, 0.10750300E+04, -.23171900E+04, 0.97374600E+03, 0.78061900E+03, 0.36613100E+03, -.23521800E+03, -.87678200E+03, -.13505700E+03, 0.36779200E+03, -.10803900E+04, 0.25576500E+02, 0.10206300E+03, 0.81857900E+03, -.11518400E+02, 0.61375000E+03, -.14382200E+04, -.81775700E+02, -.82974500E+03, -.19784800E+03, -.89745100E+03, -.72057400E+03, 0.47328900E+04, -.24183600E+04, -.33741500E+04, -.23624600E+04, 0.25123100E+03, 0.13584300E+04, -.59423400E+03, 0.20616700E+04, -.17179700E+04, 0.55849900E+03, -.45191900E+04, 0.83143000E+04, -.39783300E+04, 0.51812700E+04, -.41590800E+04, -.14872100E+04, -.31112800E+04, -.10030200E+04, -.91162500E+03, -.39912100E+04, -.19205800E+04, -.42430000E+04, 0.22229800E+04, -.10920200E+04, 0.44015500E+04, -.11122800E+04, 0.58167800E+03, -.11215000E+04, -.96341100E+03, -.53543400E+03, -.16382000E+04, -.11040700E+04, -.10001500E+04, -.23374900E+04, 0.11977100E+04, 0.48551600E+04, 0.11681000E+04, 0.89601200E+03, 0.81044800E+03, -.37540200E+03, -.97575500E+03, 0.38748300E+03, 0.69525500E+03, 0.13294600E+04, -.97457200E+03, 0.46359500E+03, 0.28382200E+04, 0.48751300E+03, -.77116500E+03, 0.63899900E+02, 0.79766800E+03, 0.12036600E+04, 0.15837100E+04, -.19210900E+03, 0.12161000E+03, -.12014500E+04, 0.84807500E+03, 0.13233000E+03, 0.61098300E+03, 0.24425400E+04, 0.51046500E+04, -.24464400E+04, -.12485300E+04, 0.47857400E+03, 0.38455000E+04, -.58823500E+03, 0.28118300E+04, -.14234000E+04, 0.63312300E+04, -.14064600E+04, -.16012900E+04, 0.36849200E+03, 0.65631100E+03, 0.28441200E+04, 0.10137200E+04, -.48486200E+03, -.22902700E+04, 0.44602000E+03, -.23197000E+03, -.13904100E+04, -.22286800E+03, 0.11250800E+03, 0.22688000E+03, 0.17880900E+03, 0.29665000E+03, -.42425700E+03, 0.11140400E+03, -.10280700E+04, 0.13443900E+04, -.71707800E+03, -.13315800E+04, -.67158700E+03, -.10026200E+04, -.80892600E+03, 0.49868800E+03, 0.77571200E+03, 0.15214800E+03, -.74726800E+03, -.16767500E+04, 0.61664600E+03, 0.23314600E+03, 0.35572600E+03, -.18996300E+03, -.24561600E+02, 0.30352000E+02, -.16131800E+03, -.35088600E+03, 0.32729900E+03, -.14144700E+02, 0.80192200E+02, -.80345800E+02, 0.20820400E+03, 0.41472000E+02, 0.53359200E+03, 0.12126300E+04, -.42249400E+02, -.25586300E+03, 0.19033000E+04, 0.45253400E+02, -.11139600E+03, -.14116200E+03, -.36369400E+02, 0.49764300E+02, -.56771000E+03, -.75416400E+02 },
        { -.20503500E+01, 0.50077300E+00, -.45749500E-01, -.11709300E+01, -.14977500E+01, 0.27649800E+01, -.39590700E+01, 0.10311400E+01, -.91376300E+00, 0.15881200E+01, -.14744000E+00, -.11428300E+00, -.93109900E+00, 0.42786700E+00, 0.18852400E+00, -.29707400E+00, -.68262700E+00, 0.90642700E+00, -.40539600E+00, -.42055300E+00, -.60027300E+00, 0.16651600E+00, -.25854900E+00, -.28783000E+00, -.17929300E+01, 0.10534000E+00, -.16170400E+00, -.10191500E+01, 0.10989100E+00, -.25089800E+00, 0.12507400E+00, 0.13925900E+00, 0.20529000E-01, 0.73539600E+00, 0.17250500E+00, 0.25124200E+00, -.25651600E+00, 0.65818600E+00, -.19105400E+00, -.92057800E+00, 0.79793000E-01, 0.55936600E+00, -.46591000E-02, -.26308300E+00, 0.74272200E+00, -.16770100E-01, -.64963800E-01, 0.35655500E-02, 0.53224500E-01, -.54072900E-01, -.93908600E+00, -.51646500E+00, 0.57570200E+00, 0.26342500E+00, 0.69467700E+00, -.39261800E+00, 0.58822300E+00, 0.12292300E-01, 0.82776100E-02, -.31713200E+04, -.12156800E+04, 0.75538600E+03, 0.48007100E+03, 0.13020100E+03, -.84508200E+03, 0.23473800E+04, 0.11481400E+04, -.57498300E+03, 0.15894600E+03, -.57306600E+03, -.29578600E+04, -.14417500E+04, 0.54336100E+03, 0.86162100E+03, 0.76145300E+01, -.14628000E+04, -.21315300E+02, 0.31581900E+04, -.15725700E+04, -.80284500E+03, -.15780500E+04, -.28259900E+04, -.19404000E+04, 0.42266900E+03, 0.69224300E+03, -.28647600E+03, -.21744900E+04, -.93488700E+03, 0.40080600E+03, -.22525700E+03, -.15259800E+04, -.19867200E+03, -.12859400E+04, -.19590100E+04, 0.13377800E+04, 0.79412200E+03, 0.73109500E+03, -.14594200E+04, 0.99954700E+03, -.11459700E+04, 0.54623300E+03, -.34314300E+03, 0.57226700E+03, 0.76243300E+03, -.60461900E+01, -.10858900E+04, -.18899200E+04, 0.58963200E+03, 0.37206600E+03, -.74634600E+03, -.12155900E+05, 0.60293700E+04, 0.55187500E+04, 0.60763800E+04, 0.73283000E+03, 0.21360900E+03, 0.28735300E+04, -.26253000E+04, 0.10801500E+04, 0.80525600E+03, 0.45104900E+04, 0.51852000E+04, -.25733400E+04, -.16580200E+04, -.25915300E+04, -.33544800E+04, -.66079700E+03, -.22997500E+03, 0.11275600E+04, -.13124200E+04, -.11761200E+04, -.10368600E+04, -.34462200E+03, 0.16991700E+03, 0.16178800E+03, 0.17215200E+03, 0.35204800E+03, 0.79140700E+02, -.87422800E+02, -.19528800E+03, -.18536500E+02, 0.15032900E+03, 0.89966100E+02, -.72481400E+04, 0.38390800E+04, 0.31275400E+04, 0.36233100E+04, 0.67180600E+02, 0.25706200E+04, 0.15731100E+04, -.18060700E+04, 0.59986100E+03, 0.24135700E+04, 0.35788300E+04, -.56647200E+03, 0.23447800E+03, 0.12821700E+04, 0.28321900E+03, -.30366700E+04, -.21532300E+04, 0.96281500E+03, 0.62843000E+01, 0.12556900E+04, -.22746800E+04, 0.61977900E+03, -.28782200E+04, 0.13947200E+04, 0.72854200E+03, 0.14393700E+04, -.11609100E+04, -.18023200E+04, 0.88247900E+03, -.45251400E+03, 0.15525400E+04, -.14481100E+04, 0.83189500E+03, 0.62372000E+04, -.30893900E+04, -.21325200E+03, -.31237700E+04, -.10364000E+03, 0.17691500E+04, -.96169900E+03, 0.15542900E+04, -.15681000E+04, 0.64162500E+03, -.31040000E+04, 0.59750300E+04, -.30690900E+04, -.16782100E+04, -.29868900E+04, -.95589200E+03, -.25867700E+04, -.21503400E+03, 0.21085800E+04, -.12707300E+03, -.24083700E+04, -.26022600E+04, -.12912100E+04, 0.63355300E+03, 0.42552400E+02, 0.64461800E+03, 0.45137400E+04, 0.99029200E+03, 0.14188700E+03, 0.28821800E+03, 0.98238800E+03, 0.64009100E+03, -.18008700E+04, -.13888000E+04, 0.66152900E+03, 0.48578400E+03, 0.69369800E+03, 0.10907200E+04, -.22374900E+03, 0.69742500E+03, 0.34158300E+03, 0.10253400E+04, -.31872600E+03, -.59445800E+03, -.15004300E+04, 0.75769800E+03, 0.73481400E+03, 0.75090700E+03, -.32344800E+03, 0.25452400E+03, 0.16525900E+04, 0.15939900E+04, 0.44246700E+03, 0.14948900E+03, 0.72791900E+03, -.16349400E+05, 0.81728000E+04, 0.79130200E+04, 0.81712500E+04, 0.38958300E+03, 0.71202800E+03, 0.43879000E+04, -.35354100E+04, 0.14733900E+04, 0.13224100E+04, 0.66501400E+04, 0.80752500E+03, -.40183400E+03, 0.40731200E+03, -.40184900E+03, -.84783700E+03, 0.45313500E+03, 0.32403900E+04, 0.42364500E+04, -.43665400E+02, -.33115000E+03, 0.17949000E+03, 0.20181200E+04, -.10094600E+04, -.25605300E+03, -.10087700E+04, -.15345600E+04, -.72641300E+03, 0.49958900E+03, 0.16672000E+04, 0.39631600E+03, -.11531200E+04, -.66485100E+03, 0.18811100E+04, -.90857600E+03, -.39647200E+02, -.93989700E+03, -.13364800E+04, -.45237300E+03, 0.30578900E+02, 0.43423600E+03, -.40941900E+03, -.62615900E+03, 0.30027200E+03, 0.32888500E+03, 0.95552400E+03, 0.10120000E+04, -.70327100E+03, -.68850600E+03, 0.86265300E+03, 0.21272400E+02, 0.92916600E+02, 0.29595900E+03, -.84215600E+03, 0.72577500E+03, 0.22454700E+04, 0.51536600E+02, -.45842600E+03, 0.19734600E+04, 0.36118100E+03, -.85841800E+03, -.76967700E+03, 0.16178400E+04, -.22308100E+03, 0.76377100E+03, -.53863800E+03, -.22994400E+04, 0.60043600E+03, -.29855700E+03, 0.55985000E+03 },
        { -.12643700E+01, -.48345100E+00, 0.19257500E-01, -.63295000E+00, -.12926000E+01, -.32388500E+00, -.19714300E+00, 0.36502800E+00, -.45458200E+00, 0.80986000E+00, 0.32018500E-01, -.10053600E+00, 0.28122100E+00, 0.71222500E+00, 0.28387200E+00, 0.76112400E-01, -.45253000E+00, 0.87582800E-01, 0.13248600E+00, -.20029000E+00, 0.11454400E+00, 0.41310900E-01, 0.46684500E-02, -.15202700E+00, 0.11551900E+01, 0.40562400E-01, 0.25552700E+00, 0.38909800E+00, -.16793600E+00, 0.21163900E+00, 0.18511000E+00, 0.46160400E+00, 0.36020200E+00, -.26228100E-01, 0.15864100E+00, -.93850800E-03, -.90980000E-01, 0.11232800E+00, 0.11371000E-01, 0.15633100E+01, 0.32097500E-01, 0.23376600E+00, -.48206900E+00, -.21170000E+00, 0.32296900E+00, 0.18125400E-01, -.45043800E-01, 0.13558100E-01, -.69622100E-01, -.20268600E+00, -.12640800E+01, -.22783100E+00, 0.30245700E+00, 0.70421900E+00, 0.68802100E-02, -.40089000E+00, -.13009900E-01, -.36130300E-01, -.13178800E-01, 0.60388900E-01, -.93048600E+03, 0.95837200E+02, -.74624400E+03, -.14148000E+03, -.56197500E+03, -.15179200E+04, 0.17477200E+03, -.79679900E+02, -.27801300E+04, -.87783700E+02, -.12094100E+04, -.18775300E+04, 0.74949200E+03, -.30108300E+03, -.39103600E+03, -.15446400E+04, -.67701800E+03, 0.70324300E+03, -.35463600E+03, -.93160300E+03, -.35196800E+03, -.50474200E+03, -.16317800E+04, 0.82325400E+03, 0.30354500E+03, -.61010900E+03, -.13990700E+04, -.12118800E+04, -.23606100E+04, 0.11744800E+04, 0.40350200E+04, 0.11796500E+04, 0.69972900E+03, -.91238000E+03, 0.32912700E+03, -.15199800E+04, -.23483900E+03, -.63437300E+03, -.24938400E+02, 0.14853400E+04, -.76010700E+03, -.36179900E+04, -.74244900E+03, 0.47427200E+03, 0.13605900E+04, -.66135400E+03, 0.13147300E+04, 0.67265300E+02, 0.10838700E+04, 0.91627200E+03, 0.10704200E+05, -.52973100E+04, -.22297300E+04, -.53520000E+04, -.12167900E+04, -.29152400E+04, -.20695000E+04, -.94814700E+03, -.29312700E+04, -.23031800E+04, -.39385700E+04, 0.22907600E+04, -.11529000E+04, -.13539400E+04, -.11458500E+04, -.12102900E+04, -.14371500E+04, 0.60447900E+03, 0.53703900E+03, -.91486900E+03, -.12479900E+04, -.21546700E+04, 0.23844600E+02, -.11683400E+02, 0.19260100E+03, -.11859300E+02, 0.15453100E+03, 0.27049900E+03, -.12406200E+03, 0.15516900E+02, -.12155500E+01, 0.22332800E+03, 0.98347000E+02, 0.27040900E+04, -.16415300E+04, -.12824100E+04, -.13519600E+04, 0.27789900E+03, -.36754200E+04, -.25472700E+02, -.78242200E+03, -.22908100E+03, -.32795600E+04, -.13632900E+04, -.18566600E+04, 0.98831500E+03, -.17980100E+04, 0.92830800E+03, -.10338400E+03, -.66329300E+03, 0.93728900E+03, 0.54621100E+03, 0.65814800E+03, -.52747500E+03, 0.62611200E+03, -.81663200E+03, 0.41963800E+03, 0.46407000E+03, 0.40834800E+03, -.48939500E+03, -.30736600E+03, -.30892500E+02, -.22491600E+03, 0.14619200E+03, 0.11388200E+02, 0.10050900E+04, -.23847800E+02, 0.37408700E+01, -.46507200E+03, 0.13727500E+02, -.11771100E+04, -.36603600E+03, 0.73576800E+03, 0.13201700E+04, 0.66103900E+03, -.29939100E+03, -.19111200E+03, 0.25888200E+04, -.11898100E+04, 0.25708100E+04, -.12944600E+04, -.97825000E+03, 0.16574400E+04, -.12648200E+04, -.63820600E+03, -.21829100E+04, 0.18418800E+04, -.17297200E+04, 0.22740300E+04, -.11133300E+04, 0.12865500E+04, -.11365600E+04, -.29745000E+03, 0.11178100E+04, -.39711400E+03, 0.13971000E+04, -.59722500E+03, 0.69647100E+03, 0.45448500E+03, 0.30941400E+03, -.13505600E+03, 0.18979300E+04, -.15436300E+03, 0.61446000E+03, 0.14071400E+04, -.59634400E+03, 0.30361400E+03, -.48558400E+03, 0.12565900E+04, 0.96586800E+03, 0.10202400E+04, -.52241300E+03, 0.17698500E+04, -.51042200E+03, -.88680400E+03, -.92057500E+03, 0.26755900E+03, 0.13898300E+03, -.21937100E+03, -.79357800E+03, -.54557100E+03, 0.15317200E+05, -.76810600E+04, -.29199700E+04, -.76583000E+04, -.13076200E+04, -.47614200E+04, -.29886800E+04, -.16486400E+04, -.45054700E+04, -.38224900E+04, -.62002000E+04, -.10486400E+04, 0.51624300E+03, 0.79926500E+04, 0.52359400E+03, -.11411600E+04, -.22864200E+04, 0.11598600E+04, -.69819300E+03, 0.21888700E+02, -.17103400E+04, -.74664300E+03, 0.23221800E+04, -.11343700E+04, -.12331300E+04, -.11612500E+04, -.63221400E+03, -.95505300E+03, 0.10831100E+03, 0.30319400E+03, -.87610000E+03, -.79900500E+03, -.14272400E+04, 0.12310200E+04, -.64063800E+03, -.13530200E+04, -.61583400E+03, -.22667900E+03, -.45821400E+03, 0.22134800E+03, 0.54731800E+03, -.63941500E+02, -.49243100E+03, -.14643700E+04, -.11496700E+03, 0.13387000E+03, 0.27247400E+03, -.36499100E+03, -.73172000E+03, 0.76744200E+03, 0.43963300E+03, 0.14159700E+03, -.53086000E+03, -.77066900E+03, 0.72316100E+03, -.57417000E+03, -.19299900E+03, -.33997300E+03, -.40477100E+03, 0.47648600E+03, -.22684900E+03, -.44765600E+03, 0.37793700E+03, 0.50798000E+03, 0.17546300E+03, -.21165900E+04, 0.86995200E+03, 0.14135400E+04, 0.24856600E+03, 0.63820500E+03 },
        { -.64737800E+00, 0.10936500E+01, 0.11698900E+00, 0.37824800E+00, 0.35312000E+00, 0.13492000E+00, -.17084500E+01, 0.16140400E+01, -.73975100E+00, 0.10829200E+00, -.22347100E-01, 0.38539200E-02, -.72276800E+00, 0.75042800E+00, -.41020000E+00, 0.14103800E+00, 0.25489200E+00, 0.38532700E-01, 0.18244500E+00, 0.61689000E+00, 0.22503700E+00, -.11124200E+00, -.13324800E-01, -.91371700E-02, -.28053600E+00, -.12222400E-01, -.23834000E+00, -.26929400E+00, 0.16380200E+00, -.29073800E+00, 0.13430300E+00, 0.69266400E-01, -.33374900E-01, 0.13245500E+00, -.11777000E+00, 0.38506400E-01, -.22712900E-01, 0.21066500E+00, -.60106100E+00, 0.96299200E+00, 0.75358500E-01, 0.27514100E-01, -.75154000E-01, 0.43908500E+00, 0.46664100E-01, 0.33839700E-03, -.13045500E+00, -.68323600E-02, 0.48320100E-01, 0.76093500E-02, 0.90307800E+00, -.15406900E-01, -.62740300E-01, -.48738900E+00, -.18538900E+00, -.44428800E-01, 0.90093700E-01, 0.12622700E+00, -.23611900E-02, -.37217600E-01, 0.32331900E+00, 0.62943400E+03, 0.20896100E+04, 0.38457900E+03, -.69800500E+02, 0.84803700E+02, 0.10663200E+04, -.53580800E+03, 0.18506100E+04, -.53257800E+03, -.35848900E+03, 0.48469500E+03, -.43813800E+03, 0.17086000E+03, -.39275600E+03, 0.63486000E+03, -.34447500E+03, 0.11672100E+04, -.58713500E+03, 0.54619200E+03, -.58298000E+03, -.56284600E+03, 0.26040400E+03, -.37590900E+03, 0.52123700E+03, -.49603700E+02, 0.26640800E+03, -.42235200E+03, 0.20323500E+04, -.99224400E+03, -.17939200E+04, -.10151600E+04, -.63034200E+03, 0.37209200E+03, 0.57232300E+03, 0.18914900E+04, 0.45093600E+03, 0.24974300E+03, -.55721100E+03, -.13186000E+04, 0.69120700E+03, 0.18799200E+04, 0.65886600E+03, -.32771600E+03, -.68184100E+03, 0.15211100E+02, -.17331300E+04, 0.21881600E+03, -.73463500E+03, 0.35739400E+03, -.12143400E+05, 0.60895800E+04, 0.51002100E+04, 0.60707200E+04, 0.24172100E+04, 0.37994400E+04, 0.21898300E+04, 0.15709100E+03, 0.26701300E+04, 0.30044300E+04, 0.42956400E+04, 0.39395500E+03, -.19783900E+03, -.31006000E+03, -.19636700E+03, -.23086300E+03, -.27379300E+03, 0.16274200E+01, 0.81955000E+03, 0.75126800E+02, -.13808000E+03, -.53492900E+03, -.25116400E+03, 0.12628900E+03, -.62450300E+02, 0.12549000E+03, 0.57982400E+02, -.89010900E+02, 0.45738600E+02, -.11744700E+03, 0.82720500E+02, -.82913200E+02, 0.11863300E+03, -.64440000E+04, 0.33901400E+04, 0.50217800E+04, 0.32214900E+04, 0.82474100E+03, 0.28797500E+04, 0.18942900E+04, 0.15795200E+04, 0.15002400E+04, 0.22153400E+04, 0.21037800E+04, 0.17733500E+03, -.10742400E+03, 0.14491700E+04, -.88680300E+02, 0.52490600E+02, -.71643900E+03, -.17742200E+03, -.22529800E+03, 0.25824500E+03, -.63287000E+03, -.11546400E+04, -.13839200E+03, 0.10557800E+03, -.65235400E+02, 0.69023000E+02, -.17319000E+03, -.52753400E+03, 0.27275700E+03, -.26116200E+02, 0.28205700E+03, -.67376800E+03, -.76235800E+03, -.13103600E+04, 0.63996600E+03, 0.70333800E+03, 0.65229300E+03, 0.10558800E+04, -.32973000E+03, -.10741600E+03, -.11473800E+04, 0.26149200E+02, -.25599300E+03, -.45369300E+03, 0.10379200E+04, -.54618300E+03, -.34140800E+04, -.51856400E+03, -.14347500E+03, -.14949800E+04, 0.76504200E+02, -.21589500E+03, 0.60974000E+03, -.12191900E+04, 0.37092800E+02, -.46478400E+04, 0.23065200E+04, -.11998400E+04, 0.23233700E+04, 0.14578300E+04, 0.24373000E+03, 0.53865800E+02, -.30790800E+04, 0.15900100E+04, 0.23072200E+03, 0.19852800E+04, -.20892800E+04, 0.10403200E+04, -.89257200E+03, 0.10442400E+04, -.13418800E+03, -.88123600E+03, 0.10347000E+04, -.14813200E+03, 0.17857900E+04, -.94110000E+03, 0.61541500E+03, -.11266500E+04, 0.56725100E+03, -.58115100E+03, 0.56372300E+03, 0.55723600E+03, 0.61352200E+03, 0.45104200E+03, 0.33708800E+03, -.88677300E+02, 0.63096400E+03, 0.11246100E+03, -.18415100E+05, 0.92855400E+04, 0.85150000E+04, 0.92053600E+04, 0.32174600E+04, 0.55763800E+04, 0.39390700E+04, 0.86717400E+03, 0.43935000E+04, 0.43735800E+04, 0.66332300E+04, -.31952200E+03, 0.16262800E+03, -.28508700E+04, 0.16088100E+03, 0.10065900E+04, 0.12906100E+04, 0.87666000E+03, 0.15832800E+04, -.28365300E+03, 0.12398400E+04, -.85227300E+03, 0.71932600E+03, -.39007700E+03, 0.10675500E+04, -.35949900E+03, -.22013800E+03, 0.23172500E+03, -.24827300E+03, 0.44309900E+03, -.22525100E+03, 0.24782300E+03, -.54794600E+03, -.59253800E+03, 0.30119600E+03, 0.80396900E+03, 0.29663700E+03, 0.16162000E+03, -.21331100E+03, -.97007300E+02, -.10881700E+03, -.28251600E+03, -.52342200E+02, -.13363100E+02, 0.33907200E+03, 0.26023700E+03, 0.25942600E+03, -.17478500E+03, 0.24715500E+03, -.26814900E+03, 0.41589600E+03, 0.27547200E+02, 0.17690700E+03, 0.17081700E+03, 0.67851100E+02, -.12114400E+03, 0.29004700E+03, 0.30423200E+02, 0.47846600E+03, -.27295800E+03, -.15855100E+03, -.97372300E+02, 0.36214300E+02, -.11302200E+03, 0.27087400E+03, 0.65127900E+03, -.40448800E+03, -.34658900E+03, -.22691800E+03, -.23744700E+03 },
        { -.11129300E+01, 0.14009200E+01, 0.14822900E+00, 0.37061200E+00, -.47627200E-01, 0.12392200E+01, -.24296300E+01, 0.98510300E+00, -.11139800E+01, 0.80812800E+00, 0.43860900E-03, -.15563400E+00, -.30772700E+00, 0.11405800E+01, -.87215800E+00, -.62250600E+00, 0.34405300E+00, 0.53424200E+00, 0.80512400E+00, -.15459500E+01, -.53128700E+00, 0.12423100E+00, -.11703200E+00, -.15311500E+00, 0.65189300E+00, 0.27298100E-01, 0.33542400E+00, 0.39315100E+00, -.71717000E-01, -.24210800E+00, 0.13827300E+00, 0.52441700E+00, 0.51297600E+00, -.43716400E-02, 0.58897100E-01, 0.21548100E+00, -.59044700E-01, -.44495700E+00, 0.91968000E+00, 0.92251900E+00, -.76432400E-01, 0.34421400E-01, -.19537500E+00, -.55144900E+00, 0.17010600E+00, 0.64273600E-01, 0.89471400E-01, 0.10211200E-01, -.87302700E-01, 0.31262800E+00, -.14346100E+01, -.48047600E+00, 0.80622100E-01, 0.14861200E+00, 0.83673100E+00, -.29011200E+00, 0.22591900E+00, -.73987500E-01, 0.38786900E-01, -.32104300E-01, -.20765500E+00, 0.60850400E+00, -.14743400E+04, -.59289000E+03, 0.26804200E+03, -.24158600E+03, 0.38550600E+03, -.18092700E+03, -.44141100E+04, -.19319500E+03, 0.77729800E+01, -.27879500E+03, 0.28306900E+03, 0.96857500E+02, -.25228800E+03, -.34868100E+03, -.53916800E+03, 0.13321400E+03, -.69106500E+02, -.21229200E+04, -.67331200E+02, 0.37284900E+03, -.23927500E+03, 0.19415300E+03, -.59361300E+03, -.49350800E+03, -.13808300E+03, -.15984000E+03, -.40920800E+04, 0.20254300E+04, 0.39104900E+04, 0.20451700E+04, 0.43582100E+03, -.58571700E+03, -.78503700E+03, -.26275800E+04, 0.46100300E+03, -.35005400E+03, 0.22002200E+04, -.87542600E+03, 0.39714500E+03, -.27695500E+04, 0.43828500E+03, 0.68553700E+03, 0.89696900E+03, 0.37087300E+03, 0.17208400E+04, 0.76045100E+03, 0.93101700E+03, 0.53538000E+03, 0.99889300E+04, -.49268500E+04, -.34655200E+04, -.49923000E+04, -.20093300E+04, -.34077900E+04, -.22017500E+04, -.67409100E+03, -.21490200E+04, -.26113300E+04, -.37794000E+04, 0.88160200E+03, -.43804600E+03, -.12191600E+04, -.44109600E+03, -.79196400E+02, 0.43923500E+03, 0.23236400E+03, -.31949400E+03, -.42620700E+03, 0.38523000E+03, -.50982600E+03, 0.45618900E+02, -.24090200E+02, 0.38192700E+03, -.22736800E+02, -.26597600E+02, 0.77822600E+02, -.32520700E+02, 0.12871400E+03, 0.42980100E+02, 0.33652000E+02, 0.12236200E+02, 0.32944900E+04, -.18349200E+04, -.57222100E+04, -.16459800E+04, -.85600500E+02, -.17361600E+04, -.18113100E+04, -.18414400E+04, -.52434800E+03, -.11698000E+04, -.97477300E+03, -.99930200E+03, 0.55118900E+03, -.31666800E+04, 0.49972800E+03, 0.14695900E+04, 0.16778600E+04, 0.22421500E+03, 0.23067900E+03, -.67295800E+03, 0.15129000E+04, -.16745100E+03, 0.64975400E+03, -.34132900E+03, -.25079700E+03, -.32433900E+03, 0.84184800E+03, 0.56273300E+03, -.51292400E+03, -.20236500E+03, -.52111800E+03, 0.82477200E+03, -.12455700E+03, 0.32165400E+04, -.16054900E+04, -.64090500E+02, -.16058000E+04, -.99855200E+03, 0.84597800E+03, -.35658800E+02, 0.16385000E+04, -.13363000E+04, 0.69435400E+03, -.15873100E+04, 0.14034600E+04, -.64467300E+03, 0.54546300E+04, -.70264700E+03, -.51014600E+03, 0.41406200E+03, -.14321200E+03, 0.10728400E+03, -.15975600E+04, 0.47766200E+03, -.14192300E+04, 0.52889500E+04, -.26188200E+04, 0.34356400E+04, -.26443500E+04, -.17923500E+04, -.87994600E+03, -.91788600E+03, 0.24805100E+04, -.17292600E+04, -.10112000E+04, -.23941500E+04, 0.15432300E+04, -.76272400E+03, 0.27869600E+04, -.77154600E+03, 0.29852800E+03, 0.84339000E+03, -.12473000E+04, -.12011200E+03, -.10946200E+04, 0.89063700E+03, 0.90008500E+02, 0.27489400E+04, -.13895000E+04, 0.17108900E+04, -.13746800E+04, -.10648900E+04, -.74904800E+03, -.97840600E+03, 0.23571700E+02, -.40661000E+01, -.87525600E+03, -.63286400E+03, 0.14004600E+05, -.69611900E+04, -.63285600E+04, -.69973700E+04, -.24054200E+04, -.47028500E+04, -.38044100E+04, -.15890600E+04, -.30766500E+04, -.34979300E+04, -.54541700E+04, 0.35156800E+04, -.17695700E+04, 0.65404200E+04, -.17588200E+04, -.19357500E+04, -.16202100E+04, -.20844500E+04, -.10945400E+04, -.27643400E+02, -.17542300E+04, -.26566900E+03, -.29319700E+02, 0.47369200E+02, -.20027700E+04, 0.14570400E+02, 0.42972900E+03, 0.12920300E+02, 0.35757200E+03, -.62836300E+03, -.81421600E+03, 0.15570100E+03, 0.20082300E+01, 0.31362900E+03, -.17142200E+03, -.15839200E+04, -.15688000E+03, -.29405300E+03, -.73880100E+02, 0.71092600E+03, 0.47591200E+03, 0.30105100E+03, -.13687800E+03, -.49495800E+03, 0.36023100E+01, -.23459000E+03, -.30483600E+03, 0.19438800E+03, -.22475200E+03, 0.10449500E+03, -.50453300E+03, -.23472500E+03, -.80643100E+02, 0.16125100E+02, -.18238600E+03, 0.11525000E+03, -.24803800E+03, 0.91915900E+02, -.32633500E+03, 0.94891900E+03, 0.15735900E+03, 0.14032500E+03, 0.43057200E+03, 0.11743500E+03, -.31762400E+03, -.77470900E+03, 0.32202700E+03, 0.34532800E+03, -.77368500E+02, 0.18850000E+03 },
        { 0.10146000E+01, 0.13320500E+01, 0.12346800E+00, -.47761300E+00, 0.59385200E+00, 0.78108800E+00, 0.18499700E+01, -.13000800E+01, 0.95027200E+00, -.11285000E+01, -.58440500E-02, 0.36443900E-01, -.22957800E+00, -.11748200E+01, 0.16276500E+01, -.67204600E+00, -.56137100E+00, 0.49193900E+00, -.52963300E+00, 0.43683200E+00, -.52568200E-01, -.89433400E-01, 0.89528300E-02, 0.98793700E-01, -.24085700E+00, -.44443300E-01, 0.94804300E-01, 0.42492900E+00, -.69517600E-01, 0.92541900E-01, -.15121000E+00, 0.83436300E-01, -.28927800E+00, 0.76118700E-01, 0.14098000E+00, 0.25653900E+00, 0.23285400E+00, 0.18699800E+00, 0.42619000E+00, 0.54194900E+00, -.89168000E-03, 0.80995900E-01, -.20552300E+00, -.64466400E+00, 0.22513000E+00, -.22256500E-01, -.12982700E+00, 0.18407000E-02, -.69237000E-01, 0.13099000E-01, -.66828000E+00, -.22353700E+00, 0.86832000E-01, 0.32257700E-01, -.26540000E+00, 0.37854500E-01, -.50047400E-01, 0.83531300E-01, -.33138800E-01, 0.62992200E+00, -.18936700E-02, -.14024800E+01, -.94404500E+00, -.77082100E+03, 0.48242300E+03, -.10237800E+04, 0.27338900E+04, -.13519100E+04, -.15798800E+04, -.13673900E+04, -.33155700E+03, -.12379400E+03, -.67599600E+03, -.15715800E+03, -.16993000E+04, 0.29706400E+03, -.16502100E+04, 0.21587800E+04, -.10898300E+04, -.50582200E+03, -.10798900E+04, -.44562200E+03, -.30063400E+03, -.95644000E+03, -.17197900E+03, -.16100000E+04, 0.23428700E+03, -.10325200E+04, -.18871800E+04, 0.95581400E+03, 0.31462200E+04, 0.94284400E+03, -.17229600E+03, 0.35565800E+03, -.41826500E+03, -.10748200E+04, 0.41345200E+03, 0.49544200E+03, 0.16688100E+04, -.17884500E+04, 0.88589000E+03, -.83100800E+03, 0.89457400E+03, 0.85133400E+03, 0.10014500E+04, 0.30789800E+03, 0.63689000E+03, 0.10871600E+04, 0.31374200E+03, 0.12849700E+04, -.20664800E+04, 0.12021600E+04, 0.15786100E+04, 0.10337700E+04, 0.15422800E+04, 0.11151700E+04, 0.80619800E+03, 0.66690900E+03, 0.12720700E+04, 0.11197800E+04, -.82272300E+03, 0.30930900E+04, -.15460600E+04, -.21256300E+04, -.15470300E+04, -.42743200E+03, -.21764000E+03, -.82803500E+03, 0.11080300E+03, -.19748900E+04, 0.45240500E+03, -.25285600E+04, -.40750200E+03, 0.20324000E+03, 0.25763200E+03, 0.20382500E+03, 0.86155100E+02, 0.10439800E+03, 0.83817000E+02, -.31767800E+02, 0.32094500E+03, -.13726200E+02, 0.24588200E+03, -.39979200E+04, 0.18556000E+04, 0.23729600E+03, 0.19994200E+04, 0.12520000E+04, -.43048400E+02, 0.11665000E+04, 0.44199700E+03, 0.69593300E+03, 0.39669700E+03, 0.65750500E+03, 0.13516100E+04, -.60548000E+03, -.64998600E+03, -.67582500E+03, 0.20414700E+04, 0.39364900E+03, -.78123400E+03, 0.80243000E+03, -.91707100E+03, 0.52176000E+03, -.40983900E+04, 0.14431800E+04, -.66656400E+03, 0.39372800E+02, -.72160100E+03, 0.74628200E+03, 0.53158800E+03, -.45694800E+03, 0.28499200E+03, -.24658900E+03, 0.43641800E+03, -.18326400E+04, -.14043200E+04, 0.67539000E+03, 0.20063800E+04, 0.70310600E+03, 0.60731400E+03, -.70982700E+02, 0.49298700E+03, -.23331400E+03, -.74312200E+03, 0.49711200E+03, -.13645700E+04, -.17024200E+04, 0.95687000E+03, 0.15985800E+04, 0.85096200E+03, 0.35174400E+03, 0.90203500E+03, -.50780800E+03, -.16856000E+04, -.32777400E+03, 0.10548300E+04, 0.75948600E+03, -.11114600E+04, 0.57153800E+03, 0.10564100E+04, 0.55608100E+03, 0.16810900E+04, 0.53276800E+03, -.26794400E+03, -.43823300E+03, 0.12033200E+04, -.11103100E+03, 0.11787800E+04, 0.24822100E+03, -.10789400E+03, 0.35871800E+03, -.12380700E+03, 0.20884000E+03, -.28092000E+03, 0.20551500E+03, 0.65658800E+03, 0.17664100E+04, -.52268100E+03, 0.11043600E+04, 0.17806400E+03, -.10878900E+03, 0.24325700E+04, -.89344700E+02, -.55967800E+03, -.24251300E+03, -.51121400E+03, -.83239600E+03, -.44791200E+03, -.15177400E+03, -.21419800E+03, -.71648800E+04, 0.37653300E+04, 0.32548700E+04, 0.35838800E+04, 0.29487700E+04, 0.17167100E+04, 0.16553700E+04, 0.32260600E+03, 0.22199500E+04, 0.19828800E+04, 0.54505100E+03, -.78041500E+03, 0.37610400E+03, 0.75552500E+04, 0.38933300E+03, -.10461100E+04, -.10732700E+04, -.50925000E+03, -.17000400E+04, -.45112500E+03, -.17647000E+03, -.32277200E+03, 0.26096100E+04, -.12976500E+04, -.56472600E+03, -.13050700E+04, -.53439200E+03, -.42459500E+03, -.77248000E+03, -.16036400E+03, -.21414700E+04, 0.71294800E+02, -.15767400E+04, 0.85551800E+03, -.45099800E+03, -.11049400E+04, -.42805400E+03, -.12399200E+02, 0.73942100E+02, -.55312000E+03, -.36241800E+03, -.14566700E+04, 0.42909000E+03, -.17807200E+04, 0.60163000E+03, 0.25277400E+03, 0.28674700E+03, -.35900700E+03, -.94038900E+02, 0.75303100E+01, -.37814700E+02, 0.61873100E+02, -.42838600E+03, -.71279300E+02, 0.51945400E+03, -.77873300E+03, 0.13243100E+03, -.20822700E+02, -.72813300E+02, 0.53610800E+03, -.30179500E+03, -.34105200E+03, 0.26313900E+03, -.16819700E+03, 0.55310000E+03, -.13498400E+04, 0.49759200E+03, 0.89333700E+03, -.20231000E+03, 0.18779300E+03 },
        { 0.86398400E+00, 0.15423600E+01, 0.14895800E+00, 0.25254900E+00, 0.12032200E+01, 0.29588600E+01, -.31058100E+00, 0.13346000E+00, 0.24401100E+00, -.11081500E+01, 0.44280000E-01, -.60818000E-01, 0.69386100E+00, -.62074800E+00, 0.26669500E+00, -.50939200E+00, -.65165000E+00, 0.43827600E+00, -.16013800E-01, -.12631900E+01, -.27614200E+00, 0.20635700E-01, -.25991000E-01, 0.14291300E-01, -.17307700E+00, -.94696600E-02, 0.11008800E-01, 0.47183300E+00, -.27737500E+00, 0.49971800E+00, -.10670300E+00, 0.36344900E+00, 0.23958700E+00, 0.29513600E+00, 0.20002000E+00, -.81158400E-01, 0.92651900E-01, 0.38143400E+00, 0.12468400E+00, 0.34455200E+01, -.82277800E-01, 0.74386400E-01, 0.11200100E+00, -.48860600E+00, 0.40613400E+00, 0.72391200E-02, -.48948300E-01, 0.15629700E-01, -.89392400E-01, 0.69101700E-01, -.11412000E+01, 0.21423100E-02, 0.37341200E+00, 0.28074600E+00, 0.90773500E+00, -.42123400E+00, 0.71337800E+00, -.34148100E+00, 0.63070000E-01, 0.31031100E+00, -.24715900E-01, -.17022900E+01, -.68259400E+00, 0.75218100E+00, 0.36810400E+03, -.49029700E+03, 0.34610700E+03, -.17582000E+03, -.47509600E+04, -.17309600E+03, -.11755300E+04, -.83841700E+03, -.33057100E+01, -.16363100E+03, 0.41951800E+02, -.35072000E+03, -.50976400E+03, 0.41199600E+04, -.20618600E+04, -.27549800E+04, -.20606400E+04, -.95062000E+03, 0.15851700E+03, -.10504600E+04, 0.27283600E+03, -.93364900E+03, -.13110200E+03, -.16808500E+04, 0.74499300E+03, -.38209400E+03, 0.35670600E+04, -.37282600E+03, -.21973600E+03, 0.17409400E+03, -.33807000E+03, -.55629200E+03, -.93704400E+03, 0.39480800E+03, 0.16231300E+03, -.12275000E+04, 0.61218200E+03, -.23225400E+04, 0.61436900E+03, 0.93672600E+03, 0.18331200E+03, -.22924300E+03, -.60070300E+03, 0.15416200E+03, 0.14074000E+03, 0.22543400E+03, -.50785400E+03, 0.22592000E+03, -.34469400E+03, 0.25759000E+03, 0.28232200E+03, 0.65393800E+03, -.45455100E+03, -.25682200E+03, 0.62784600E+03, 0.37489200E+03, -.81169200E+03, 0.56706600E+04, -.28558700E+04, -.49471900E+03, -.28349600E+04, -.11062400E+04, 0.76698600E+03, -.12456500E+04, 0.10662100E+04, -.14087600E+04, 0.73744300E+03, -.31491700E+04, -.30074900E+03, 0.15229100E+03, 0.22445700E+03, 0.15038700E+03, 0.10569400E+03, 0.11629600E+02, 0.52739900E+02, -.55699200E+02, 0.99096000E+01, -.63165200E-01, 0.22804500E+03, -.37541000E+04, 0.15989600E+04, -.43204000E+04, 0.18792300E+04, 0.79499100E+03, 0.12081100E+04, 0.57617400E+03, 0.13762100E+04, 0.33404100E+04, 0.46456600E+03, 0.80039000E+03, -.44111000E+04, 0.22445500E+04, -.15659900E+04, 0.22057300E+04, 0.80770700E+03, 0.62721600E+03, -.35427200E+03, -.11941900E+04, 0.21327500E+04, 0.31147300E+03, 0.79570100E+02, -.47865600E+03, 0.24462200E+03, 0.78702700E+03, 0.23964300E+03, 0.15048700E+03, -.13638200E+04, 0.24551400E+03, -.37167500E+03, 0.74077300E+02, -.10909700E+04, -.26844200E+03, -.40151900E+04, 0.20088200E+04, -.31254400E+04, 0.20073300E+04, -.15976700E+04, -.14149100E+04, 0.18599200E+04, 0.11101300E+04, 0.24648500E+04, -.16737900E+04, 0.15064700E+04, 0.34934500E+04, -.16573400E+04, 0.36705500E+04, -.17482800E+04, -.48755400E+03, -.18594600E+04, -.49546400E+03, -.10157400E+04, -.21541100E+04, -.92312700E+03, -.20402500E+04, 0.39290800E+04, -.19434800E+04, 0.25834400E+04, -.19652000E+04, -.10253600E+04, -.29282800E+03, -.86783400E+03, -.36343000E+02, -.20511600E+04, -.58656200E+03, -.10739200E+04, -.16053100E+04, 0.81892700E+03, 0.37295700E+04, 0.80211900E+03, 0.33177100E+03, 0.10275400E+04, 0.14156600E+03, -.26003200E+03, -.59110400E+03, 0.79828700E+03, 0.16487000E+04, 0.17068000E+04, -.85631400E+03, 0.85954300E+03, -.85320600E+03, -.12869600E+04, -.46886800E+03, 0.74790400E+03, 0.17551200E+04, 0.21645100E+03, -.52019300E+03, -.58878400E+03, -.16613700E+04, 0.69483600E+03, -.27173100E+04, 0.83902800E+03, 0.67183200E+03, 0.13182800E+04, -.45516800E+03, 0.39054800E+03, 0.24124600E+04, 0.69346900E+03, -.12066300E+04, 0.29986700E+04, -.15007900E+04, 0.40392600E+04, -.14997400E+04, -.27791300E+04, -.50161500E+03, 0.13221200E+04, 0.29099700E+04, 0.13966800E+03, -.72011600E+03, -.42323300E+03, -.63994500E+03, 0.33884700E+03, -.13090800E+04, 0.32007600E+03, 0.25413600E+03, 0.73976200E+03, -.43487800E+03, 0.42672700E+02, 0.95608300E+03, 0.55966400E+03, 0.15499600E+03, 0.12230900E+04, -.63520800E+03, -.10691000E+04, -.61104400E+03, -.79499200E+03, -.43296400E+03, 0.47096200E+02, 0.53434400E+03, 0.55279100E+03, -.48489100E+03, -.10898600E+04, 0.30162900E+03, 0.73760800E+02, 0.19450500E+03, -.13355600E+03, 0.19465200E+03, -.13521600E+03, -.27578600E+02, -.24533800E+03, 0.26701300E+03, 0.43978300E+02, 0.15169300E+03, -.67155600E+02, 0.12877500E+03, 0.48955100E+02, 0.28511200E+03, 0.70778100E+03, 0.16062100E+03, -.21187000E+03, 0.11652700E+04, 0.84288100E+02, -.20752200E+03, -.28884200E+03, -.55224800E+01, 0.11171000E+03, -.49036300E+03, -.27985000E+03 },
        { -.26953300E+01, 0.21687600E+01, 0.17432800E+00, 0.12088000E+01, -.22169000E+00, -.11752800E+01, -.21800500E+01, -.31431500E+01, -.14553300E+01, 0.21289500E+01, 0.30951800E+00, -.13336100E+00, -.28332500E+00, -.37207200E+00, -.28527600E+01, -.17702600E+01, 0.71203200E+00, -.93622200E+00, 0.83705400E+00, -.19608600E+01, -.86740800E-01, 0.57368100E+00, 0.11087500E+00, -.14919300E+00, 0.11056100E+01, -.39743800E-01, -.60929100E+00, -.94719800E+00, 0.62327200E+00, -.21042000E+00, 0.53643700E+00, 0.21037000E+00, 0.66754400E+00, 0.68640100E+00, 0.10470400E+00, -.24517400E+00, 0.68846400E-02, 0.48144000E+00, 0.35704100E+00, -.14861000E+01, 0.57948700E-01, -.58953600E-01, 0.14611000E+01, 0.94721900E+00, -.28124500E+00, -.15921800E+00, 0.51327300E+00, -.18911300E-01, -.11157900E+00, 0.87355500E-01, 0.49114200E+00, 0.41800500E+00, -.21243700E+00, -.83225500E-01, -.51917200E+00, -.59217300E-01, -.11663600E+01, -.38159200E-01, -.20603200E-01, 0.32984800E+00, -.23361500E+00, -.74838900E+00, -.27376500E-01, 0.10597100E+01, -.43917200E+00, 0.86227400E+04, -.11407000E+05, 0.57053200E+04, 0.42729700E+04, 0.57022000E+04, 0.13736100E+04, -.17579200E+03, 0.22562900E+04, -.12235200E+04, 0.33581300E+04, 0.14825700E+03, 0.37463400E+04, -.85960600E+04, 0.42924300E+04, 0.32474200E+04, 0.42964900E+04, 0.22324400E+04, 0.18282300E+03, 0.23487300E+04, -.10469300E+04, 0.24041200E+04, 0.78701100E+02, -.48986100E+02, 0.13335700E+04, -.64131600E+03, 0.21378300E+03, -.66907700E+03, 0.11993000E+04, -.16359200E+04, 0.20352200E+04, 0.80709900E+03, -.46032100E+03, -.12013900E+04, 0.13023700E+04, 0.60582600E+04, -.30042600E+04, -.35075600E+04, -.30280000E+04, -.31357600E+04, -.20548800E+04, 0.82784000E+03, 0.35268500E+04, 0.75354000E+03, -.17687700E+04, -.66312000E+04, 0.11132100E+05, -.55028800E+04, 0.11144300E+04, -.55632000E+04, -.18026400E+04, -.32117800E+04, 0.35541400E+03, 0.23137800E+04, -.26621000E+04, -.29394600E+04, -.58822100E+04, -.90517200E+04, 0.45101700E+04, 0.32838200E+04, 0.45246100E+04, 0.32861500E+04, 0.10814800E+04, 0.20594200E+04, -.35680000E+03, 0.28813800E+04, 0.88783300E+03, 0.46232000E+04, 0.98423200E+03, -.49017700E+03, -.34585300E+03, -.49190900E+03, -.34118100E+03, -.15744700E+03, -.13746800E+03, 0.25283900E+03, -.45729300E+03, -.11214900E+03, 0.10512400E+03, 0.17801100E+04, -.10690000E+04, 0.55907800E+03, -.88831000E+03, 0.20603900E+04, -.17927700E+04, 0.22636400E+04, 0.24517000E+04, 0.22906100E+04, -.20766000E+04, -.36088300E+04, -.56876900E+04, 0.28882900E+04, 0.11760200E+02, 0.28438900E+04, -.12093700E+04, -.21917700E+04, 0.30618500E+04, 0.61590600E+03, 0.38523100E+04, -.21192100E+04, -.38149100E+04, -.33759900E+04, 0.17401800E+04, -.17877300E+03, 0.16882000E+04, -.14326500E+04, -.23592000E+04, 0.14374900E+04, 0.23297700E+02, 0.12165800E+04, -.17971300E+04, -.19353400E+04, 0.22966700E+04, -.11772000E+04, -.27289200E+04, -.11426000E+04, -.23268200E+04, -.13871800E+04, -.43556900E+03, 0.14504500E+04, 0.22456300E+04, -.18967200E+04, -.76884500E+04, 0.80128800E+04, -.39217000E+04, 0.10660100E+04, -.40076600E+04, -.25584600E+04, -.48774000E+03, -.18990300E+04, 0.30430300E+02, -.41897200E+04, -.13529500E+03, -.33189000E+04, 0.10444900E+05, -.52136900E+04, -.55554200E+04, -.52214300E+04, -.38285600E+04, -.16941400E+04, -.10525300E+03, 0.29867800E+04, -.98437700E+03, -.19626100E+04, -.12830800E+05, 0.20347100E+04, -.98869400E+03, -.72531100E+03, -.10166300E+04, -.16042600E+04, -.10499700E+04, 0.82191500E+03, 0.10450600E+04, -.10207200E+04, -.66038900E+03, -.42066400E+04, 0.26216200E+03, -.13598100E+03, -.70614100E+03, -.13190500E+03, 0.11314100E+04, -.15033100E+03, 0.13594300E+03, -.46550300E+03, -.14387600E+04, 0.13577800E+03, 0.62952000E+03, 0.18289500E+05, -.91072700E+04, 0.13757500E+04, -.91381700E+04, -.19143100E+04, -.48795300E+04, 0.12440300E+04, 0.46131400E+04, -.37164300E+04, -.46696800E+04, -.11520700E+05, 0.85207600E+03, -.42394300E+03, -.90498600E+03, -.42860500E+03, 0.28997700E+04, -.56709600E+03, 0.19603900E+03, -.19949000E+04, -.35158400E+04, -.15519300E+03, -.21319000E+04, -.28971900E+04, 0.14460100E+04, 0.91741200E+03, 0.14481900E+04, 0.24307500E+04, 0.54458900E+03, 0.88628100E+03, 0.82209700E+03, 0.25474900E+04, 0.46430600E+03, -.18893500E+04, -.21939100E+04, 0.10682100E+04, 0.80229500E+03, 0.10962800E+04, 0.11908200E+04, -.10514200E+02, 0.10103000E+04, 0.10118100E+04, 0.14901500E+04, -.39800300E+03, 0.15355200E+04, -.16274700E+04, -.97562600E+03, -.11279300E+04, 0.10820400E+04, 0.41527700E+03, -.40429000E+03, -.10510600E+04, -.29364700E+03, -.61414700E+02, 0.32666100E+03, -.11342800E+04, -.19233100E+04, -.43765600E+03, 0.16738600E+03, -.20639600E+04, -.87337900E+03, 0.81270300E+03, 0.94410500E+03, -.95873200E+03, -.95939600E+03, -.60626200E+03, 0.17201100E+03, 0.25125900E+04, -.48443300E+03, 0.79492100E+03, -.61463100E+03 },
        { 0.14425400E+01, 0.37523400E+00, -.11497900E-01, 0.56054900E+00, 0.11439900E+01, 0.77672400E+00, 0.55808200E+00, -.10641100E+01, 0.70593900E+00, -.70630500E+00, -.87615400E-01, 0.12956500E-01, 0.61359000E+00, -.13890800E+01, 0.51298800E+00, -.23433900E+01, -.29584300E+00, 0.26679800E+00, -.31905800E-01, -.54620100E+00, -.95019600E-01, 0.63443300E-01, 0.82846200E-01, 0.41539200E-01, -.74228600E+00, -.68853500E-02, -.12803500E-01, -.32896100E-01, -.13045400E+00, 0.16736300E+00, -.41041500E+00, 0.76394400E+00, -.31531300E+00, -.39283600E+00, 0.23848000E-01, 0.29180900E+00, 0.16078400E+00, -.46310300E+00, -.52684700E-01, -.15199600E+01, -.18738000E-01, 0.15862000E+00, -.21598400E+00, -.94138300E+00, 0.33650500E+00, 0.18497500E-01, 0.35705300E+00, 0.83297500E-03, -.13855300E+00, 0.36877000E-01, -.20417300E+01, -.16931400E+00, 0.10729400E+00, 0.12917400E+00, -.14184900E+00, 0.36621200E+00, -.22467100E+00, -.56820500E-01, -.31009500E-01, 0.10788600E+00, 0.59146400E+00, -.11089200E+01, -.86709400E+00, 0.84886100E+00, -.41109000E+00, 0.86331300E-01, -.40016500E+04, 0.20011000E+04, 0.93075400E+03, 0.20011300E+04, 0.12157800E+04, 0.86836100E+03, -.84678500E+02, -.10497600E+04, 0.15096300E+04, 0.81863700E+03, 0.18229900E+04, -.18763400E+04, 0.94330200E+03, 0.47338000E+03, 0.93820300E+03, 0.93745800E+03, 0.12812700E+04, -.53507300E+03, -.75467100E+03, 0.10077500E+04, 0.82919500E+03, 0.11226100E+04, 0.33388300E+03, -.19925000E+03, -.67884500E+03, -.16656000E+03, 0.22376900E+03, 0.45424700E+03, -.61581900E+03, 0.36074700E+02, -.37897600E+03, 0.26489700E+03, -.34074500E+03, 0.23650700E+02, -.46648500E+02, 0.11069700E+04, -.11771000E+02, 0.93785800E+02, -.62181000E+03, 0.22291800E+03, -.28835500E+03, -.32457400E+03, -.24471400E+03, -.10563400E+04, 0.69545600E+04, -.35389000E+04, -.69354700E+04, -.34758500E+04, -.90304200E+03, 0.31756800E+00, -.21482300E+04, 0.22733000E+03, -.23295300E+04, -.42652600E+03, -.20507000E+04, -.30575500E+04, 0.15334100E+04, 0.30292100E+04, 0.15293100E+04, 0.12888700E+04, 0.12750700E+04, -.27778100E+03, -.79334600E+03, 0.13245400E+04, 0.10375800E+04, 0.10820200E+04, 0.46653500E+03, -.23443700E+03, -.28669200E+03, -.23331500E+03, -.18346600E+03, -.17434400E+03, 0.33676800E+02, 0.13002900E+03, -.20389700E+03, -.13120900E+03, -.22447700E+03, 0.50963400E+04, -.26045800E+04, -.64221700E+04, -.25474200E+04, -.56102100E+03, -.10767800E+03, -.16717800E+04, 0.53449900E+03, -.11103600E+04, -.49964800E+03, -.18396400E+04, -.32309900E+04, 0.16139900E+04, 0.11444700E+04, 0.16156000E+04, -.97987500E+02, 0.92772100E+03, -.52161600E+03, -.18140800E+04, 0.13995100E+04, 0.73750300E+03, 0.23897900E+04, -.33518600E+03, 0.12295100E+03, 0.73817700E+03, 0.16787800E+03, -.51098000E+02, -.32407900E+03, 0.21799300E+03, 0.13048200E+03, 0.19738300E+03, -.46695100E+03, 0.81016800E+03, -.15303800E+03, 0.10408600E+03, -.20686500E+04, 0.75136600E+02, -.36207800E+03, 0.45127500E+02, 0.14970100E+03, 0.31667800E+03, 0.51962100E+03, -.15203600E+03, 0.10758000E+04, -.42122100E+04, 0.21051600E+04, 0.18708400E+04, 0.21055100E+04, 0.10291900E+04, 0.36673100E+03, 0.93085100E+03, 0.40400700E+02, 0.18557500E+04, 0.36982000E+03, 0.15404600E+04, 0.35970600E+04, -.17874800E+04, -.36820200E+03, -.17991200E+04, -.17030400E+04, -.48623700E+03, -.49087000E+03, 0.38716900E+03, -.13579100E+04, -.38042000E+03, -.14744500E+04, 0.14723800E+04, -.74759400E+03, -.19894600E+03, -.73667800E+03, -.10749200E+04, -.25825500E+03, 0.41281300E+02, 0.39679400E+02, -.13182900E+04, -.26418800E+03, -.45867900E+03, 0.36504300E+03, -.18166500E+03, -.12489000E+04, -.18219700E+03, -.24255000E+03, 0.41544500E+03, -.24897800E+03, 0.47790600E+03, 0.39060800E+03, 0.10991300E+03, 0.10391400E+04, 0.10189800E+05, -.51893500E+04, -.12026300E+05, -.50918300E+04, -.11860000E+04, 0.23105800E+03, -.34181100E+04, 0.51026800E+03, -.26931400E+04, -.49324500E+03, -.33434700E+04, 0.66688700E+03, -.33336400E+03, -.43359600E+04, -.33300600E+03, -.65244500E+03, 0.14829900E+04, -.97432900E+03, 0.85319300E+03, 0.56157500E+03, 0.50164900E+03, 0.26075200E+04, -.48654600E+04, 0.24579000E+04, 0.82870400E+03, 0.24329700E+04, 0.13175400E+04, 0.16231600E+04, -.17121700E+03, -.13972800E+04, 0.19675800E+04, 0.12867600E+04, 0.25264100E+04, -.11937000E+04, 0.60464100E+03, 0.10576100E+04, 0.59731500E+03, 0.24609100E+03, 0.18662000E+03, 0.29560800E+03, -.92253300E+02, 0.97943400E+03, 0.12743900E+03, 0.47159200E+03, -.73024700E+03, -.48778600E+03, -.47030000E+03, 0.52422600E+03, 0.40589900E+03, -.39790200E+03, -.41549000E+03, -.22148300E+03, 0.39723100E+03, 0.46042800E+03, -.60017600E+03, -.46152100E+03, -.17366300E+03, 0.20280000E+03, -.38775400E+03, -.52499600E+03, 0.77254100E+03, 0.48780000E+03, -.24787800E+03, -.26262600E+03, -.53649500E+03, 0.15402200E+04, 0.42748000E+03, -.10239200E+04, 0.40085800E+02, -.40735300E+03 },
        { -.28602000E+01, 0.56772300E+00, -.33744100E-01, -.19194300E+01, -.13806700E+01, 0.54816300E+01, -.68098300E+01, 0.23781000E+01, -.16361600E+01, 0.22777200E+01, -.14902100E+00, -.16486400E+00, -.12271600E+01, 0.22941800E+01, -.10959400E+01, -.23463000E+01, -.11478100E+01, 0.21165100E+01, 0.22798900E+00, -.39890000E+00, -.15641400E+00, 0.15047000E+00, -.49736600E+00, -.45657000E+00, -.22649700E+01, 0.12386700E+00, -.38312800E+00, -.10265800E+01, 0.72963800E+00, -.83016800E+00, 0.98635900E+00, 0.13420500E-01, 0.82565100E+00, 0.25761300E+01, 0.43948300E+00, 0.69831400E+00, -.33519100E+00, 0.20027200E+01, -.18356700E+01, 0.61136900E+01, 0.15864700E+00, 0.82426700E+00, -.12271100E+01, -.80677400E+00, 0.10555400E+01, -.29127200E+00, -.85589500E+00, 0.20953500E-01, 0.13434900E+00, 0.38046000E+00, 0.58903200E+00, -.38351100E+00, 0.97950800E+00, 0.88252200E+00, 0.17211800E+01, 0.76218300E-01, 0.83466200E+00, -.29188900E+00, 0.84023500E-01, 0.89126300E+00, 0.44754700E+00, 0.17471800E+01, 0.15014100E+01, 0.14641300E+01, 0.18039100E+00, 0.21073400E+00, 0.18325300E+00, -.48520900E+02, -.25240100E+04, 0.39264600E+00, -.94291600E+03, -.23349500E+04, 0.51540900E+03, 0.36082300E+03, 0.14369200E+04, -.24804200E+04, 0.11161700E+03, 0.27596500E+04, -.13282800E+04, -.21155100E+04, -.13793800E+04, -.25241300E+03, -.20118700E+04, 0.44996600E+03, 0.11825900E+04, -.12558000E+03, -.24633400E+04, -.20861700E+04, -.39850600E+04, 0.18678500E+04, 0.39859600E+03, 0.19931800E+04, 0.10058400E+04, -.15301700E+04, 0.14212800E+04, 0.49506200E+03, 0.34204300E+04, -.11093700E+04, 0.75013200E+03, 0.30607000E+04, -.16014000E+04, -.39355400E+04, -.15306700E+04, 0.45858700E+03, -.29485600E+02, -.11165400E+04, -.31686500E+03, -.91092200E+03, 0.12838000E+03, -.23227700E+04, -.25108700E+03, -.50967600E+03, 0.11149600E+04, 0.12515600E+03, -.64044800E+04, -.10888700E+05, 0.40147600E+04, -.13823600E+04, 0.53848700E+03, -.81822200E+04, 0.11740000E+04, 0.85881200E+04, -.42698300E+04, -.31920600E+04, -.42936400E+04, -.19228800E+04, -.86484500E+03, -.44933600E+03, 0.26072700E+04, -.12252600E+04, -.16376400E+04, -.27578700E+04, 0.53131100E+02, -.29216600E+02, 0.36223300E+02, -.26631600E+02, 0.25002200E+03, 0.23664300E+03, -.21580000E+03, -.27269200E+03, -.29982600E+03, 0.33047400E+03, 0.20742000E+02, 0.11123300E+05, -.52010300E+04, 0.14950900E+04, -.55621200E+04, -.74627600E+04, -.90237300E+04, 0.17376000E+04, -.33911100E+03, -.27744100E+04, -.71671600E+04, -.50086600E+04, 0.18502900E+04, -.11774900E+04, -.89305500E+03, -.92511900E+03, -.31132400E+04, -.26250900E+03, 0.70117600E+03, 0.10121200E+04, -.33421400E+03, -.47779800E+03, 0.10984900E+04, -.25798100E+04, 0.98118400E+03, -.25535600E+04, 0.12896800E+04, -.57525500E+03, 0.27486300E+03, 0.13123000E+04, 0.24495400E+04, 0.18842600E+04, 0.55564900E+03, 0.14223300E+04, -.86856500E+03, 0.60180400E+03, -.50876400E+04, 0.43440600E+03, -.36526800E+04, -.12055100E+04, 0.14960000E+04, 0.19134400E+04, 0.84802100E+03, -.22090600E+04, 0.57806700E+03, 0.37667500E+04, -.22606400E+04, -.20172100E+04, -.18831700E+04, 0.18800200E+04, 0.27333500E+04, -.16343400E+04, 0.26997300E+04, -.13825200E+04, 0.22511600E+04, -.19674500E+04, 0.20440100E+04, -.10522600E+04, 0.27660000E+04, -.10222900E+04, -.15039500E+04, -.35527700E+03, 0.35681700E+03, 0.14193000E+04, -.98515900E+03, -.84963400E+02, -.93441000E+03, -.15014400E+04, 0.66485600E+03, 0.20016500E+04, 0.75045600E+03, 0.13542700E+04, 0.17370200E+04, 0.30142600E+03, 0.12978400E+04, 0.59329200E+03, 0.16213600E+04, -.10809900E+04, 0.18112800E+04, -.83694900E+03, -.28881500E+04, -.90536600E+03, -.45504900E+03, -.75532600E+03, 0.19377100E+04, 0.38826000E+04, 0.86032600E+03, -.60687500E+03, -.82102100E+03, 0.11399400E+05, -.64851100E+04, 0.11445200E+04, -.57009100E+04, -.11461400E+05, -.17743100E+05, 0.45026600E+04, -.96084800E+03, -.26571400E+04, -.13560200E+05, -.41856000E+04, 0.34968600E+03, -.12478900E+03, -.35801000E+04, -.17406600E+03, -.13196900E+04, -.88978500E+03, 0.34885600E+04, 0.57047000E+04, 0.25701800E+04, -.12007500E+04, 0.44704100E+03, 0.25960500E+04, -.12515900E+04, -.23136000E+04, -.12977500E+04, -.13855800E+04, -.13397900E+04, 0.11079800E+04, 0.26081400E+04, 0.62441300E+03, -.16669400E+04, -.17378800E+04, 0.38511800E+04, -.18152300E+04, -.21364400E+04, -.19253300E+04, -.11996500E+04, -.47435800E+03, -.24878500E+03, 0.72704400E+03, -.12971300E+04, -.81511200E+03, -.92448600E+03, -.11996300E+03, 0.13135500E+03, 0.78316600E+03, -.35354300E+03, -.37915200E+03, 0.70983600E+03, 0.56123200E+03, 0.10265800E+03, -.25100200E+03, -.39234900E+03, 0.72869300E+03, 0.51827200E+04, 0.30926000E+03, -.30722200E+03, 0.18581100E+04, 0.62039400E+03, -.94263700E+03, -.24156500E+03, 0.12207400E+04, 0.83570300E+03, 0.23237700E+03, -.54500500E+03, -.35522500E+04, 0.48687800E+03, 0.26189500E+03, 0.21966000E+03 },
        { -.50997300E+01, 0.32709100E+01, 0.40214300E+00, 0.30177200E+01, -.40566700E+00, -.88245400E+01, -.10117800E+01, -.64558200E+01, -.22370700E+01, 0.32132000E+01, 0.52374800E+00, -.14440100E+00, 0.36996800E+00, -.45893400E+01, 0.11932200E+01, -.26438100E+00, 0.13367200E+01, 0.93411400E+00, -.18743100E+00, -.14281500E+01, -.85037800E+00, 0.14479900E+00, -.10391000E+00, -.81360600E+00, 0.36023300E+01, 0.15605100E+00, 0.14287600E+01, 0.15747100E+01, -.20691800E+01, 0.94782100E+00, -.21567000E-01, -.55493100E+00, 0.16620100E+01, 0.74077100E+00, 0.46520600E+00, -.68186300E+00, -.77051000E-01, 0.48819200E+00, -.14443300E+01, -.49781200E+01, 0.51790100E+00, 0.16598800E-01, 0.97983500E+00, 0.55067300E+00, 0.62882100E+00, 0.86128000E-01, 0.36985700E+00, -.12098700E-02, 0.11033100E+00, 0.68203900E+00, 0.54168200E+01, -.17689400E+01, -.13524700E+01, -.31588300E+01, -.45326500E+01, 0.18853600E+01, -.28373100E+01, 0.42965000E+00, -.13942800E+00, 0.16748500E+01, 0.97371900E+00, -.25289000E+01, -.20214500E+01, -.24211900E+00, 0.30228300E+00, 0.23014500E+00, 0.30820200E+01, 0.22809600E+00, 0.19176700E+05, 0.43684300E+00, 0.40337700E+03, 0.69043900E+03, 0.39645300E+03, 0.15842900E+04, -.86305800E+03, 0.20377300E+04, -.80409200E+03, -.11278200E+05, 0.55951100E+04, 0.11389700E+05, 0.56411700E+04, -.21587400E+04, -.42504100E+04, 0.38997500E+04, 0.99071700E+03, 0.39696400E+04, -.41303100E+03, -.15706500E+04, 0.29818300E+04, -.13168600E+04, -.69358500E+04, -.14894100E+04, -.19964100E+04, 0.14410600E+04, 0.96360800E+03, 0.29112200E+04, 0.51806900E+04, 0.14059000E+04, 0.44554800E+04, 0.88042100E+04, -.42143500E+04, 0.47929900E+04, -.44039500E+04, -.46144200E+04, -.21553600E+03, 0.24294900E+04, 0.78059700E+04, -.50371100E+02, -.39172700E+04, 0.47840500E+03, -.80013200E+05, 0.40590200E+05, 0.41689700E+05, 0.39995800E+05, 0.14111300E+05, 0.15601600E+05, 0.21803900E+05, 0.78187600E+04, 0.24229600E+05, 0.13950300E+05, 0.18591700E+05, -.13717800E+05, 0.68624800E+04, -.26184000E+04, 0.68582200E+04, 0.23619500E+04, -.53331300E+04, 0.45295400E+04, 0.83513500E+03, 0.31452200E+04, -.15463400E+04, 0.34948500E+04, -.84701100E+03, 0.42686600E+03, -.23938300E+03, 0.42343000E+03, 0.98207800E+02, 0.47680200E+03, -.12867400E+03, -.35796400E+03, 0.47836400E+03, 0.27935500E+01, 0.92327200E+03, -.41156400E+05, 0.21660500E+05, 0.40123900E+05, 0.20572300E+05, 0.45352600E+04, 0.46785500E+04, 0.18414900E+05, 0.11002600E+05, 0.13820300E+05, 0.62625300E+04, 0.39983700E+04, 0.17280700E+05, -.86923300E+04, 0.66772800E+04, -.86409100E+04, 0.25049600E+04, -.60186500E+04, 0.24079800E+04, 0.81453100E+04, -.59214300E+04, -.38992700E+04, -.31605100E+05, 0.41080700E+04, -.17399100E+04, -.29239300E+04, -.20571200E+04, 0.21578700E+04, 0.35232400E+04, -.94804100E+02, 0.26765600E+04, -.24697200E+03, 0.26835400E+04, -.14495400E+05, -.94520200E+04, 0.45887400E+04, 0.20091000E+05, 0.47219600E+04, 0.88582100E+04, -.19798400E+04, 0.12725100E+03, -.72031300E+04, -.22971400E+04, 0.20907300E+04, -.21591800E+05, 0.93448400E+04, -.47843800E+04, -.25662500E+05, -.46679100E+04, -.35247400E+03, 0.13502100E+04, -.50626000E+04, -.42484600E+04, -.21328800E+04, 0.24743300E+03, 0.27243500E+04, -.16755400E+05, 0.82870000E+04, -.13283400E+05, 0.83789900E+04, 0.10119200E+05, 0.57895700E+04, 0.79046800E+03, -.50949900E+04, 0.57425400E+04, 0.34060500E+04, 0.61817900E+04, 0.19254000E+04, -.95123000E+03, -.14294000E+05, -.96149200E+03, -.40100400E+03, -.42843000E+04, 0.55965500E+03, 0.16136900E+04, 0.63943600E+04, -.41370100E+04, 0.10451400E+04, -.83083300E+04, 0.41503700E+04, 0.24492300E+04, 0.41538500E+04, 0.55762600E+04, 0.25088200E+03, -.38040300E+04, -.12225100E+05, -.33817200E+04, 0.27633600E+04, -.43936800E+04, -.11665700E+06, 0.59461100E+05, 0.68882900E+05, 0.58304700E+05, 0.18380700E+05, 0.19039300E+05, 0.36524600E+05, 0.14777300E+05, 0.36297100E+05, 0.17963200E+05, 0.25743800E+05, -.26979500E+05, 0.13490200E+05, 0.62136100E+04, 0.13491400E+05, 0.12828400E+05, -.35954500E+04, -.20133800E+04, -.21143600E+05, 0.14190600E+04, 0.50307800E+04, -.13917400E+05, 0.10714100E+05, -.55553700E+04, 0.30330400E+04, -.53575700E+04, -.42386000E+04, -.70383700E+04, 0.13199100E+04, 0.37157100E+04, -.47326900E+04, -.36664900E+04, -.11678100E+05, -.15114600E+04, 0.76552300E+03, 0.15494800E+04, 0.75457400E+03, 0.24704700E+04, 0.23759400E+03, -.84579000E+03, -.12558100E+04, -.43511200E+04, 0.16716700E+04, -.83165200E+04, 0.17261700E+04, 0.11309800E+04, 0.12160000E+04, -.16220800E+04, -.10060500E+03, -.27558700E+03, 0.52306900E+03, 0.10102900E+04, -.28390700E+04, 0.10218300E+03, 0.20907600E+04, -.22282100E+04, 0.14403900E+03, -.65148800E+03, 0.15079000E+03, -.99132500E+03, -.24123000E+04, -.13849300E+04, -.24892500E+04, -.12784000E+04, 0.19825700E+04, -.49581800E+04, -.29880000E+02, 0.34602800E+04, 0.11723400E+04, 0.27925400E+03 },
        { -.85853300E+01, 0.36668100E+01, 0.65624300E+00, -.41644900E+01, -.59731100E+01, 0.10565700E+02, -.10321600E+02, 0.12930800E+02, -.48796800E+01, 0.67936800E+01, 0.77953100E-01, -.52572000E+00, 0.41487800E+01, 0.89977000E+00, 0.16365500E+01, 0.24269500E+01, -.45226900E+01, -.41780900E+00, 0.22039000E+00, -.48647600E+00, 0.62579700E+00, 0.19469900E+00, 0.11894800E+00, 0.40455000E+00, -.39619100E+01, 0.64951800E+00, -.17455500E+01, -.20402700E+01, 0.15886500E+01, 0.44780800E+00, 0.32530900E+00, -.62606700E-01, -.11871500E+01, 0.45611100E+00, -.33488500E+00, 0.18295900E+00, -.16539600E+01, -.22705500E+01, -.14709300E+01, -.17999900E+02, -.24274000E+00, -.27560300E+00, 0.70106900E+00, 0.33100700E+00, -.36630900E+00, -.35526400E+00, 0.16237400E+00, 0.28207200E-01, 0.29958500E+00, -.22542000E+00, -.20162000E+01, 0.75687700E+00, 0.16830600E+00, 0.13997600E+01, 0.22363100E+00, -.23996400E+00, -.22900300E+00, -.17987100E+00, 0.19396400E+00, -.70919100E+00, 0.62292700E+00, -.69005100E+00, -.53979700E+00, 0.86323700E+00, -.87612500E+00, 0.23536500E+00, 0.88008900E+00, 0.31498000E+00, -.27817800E+00, 0.11964800E+02, 0.26356900E+03, 0.77808200E+03, -.18541600E+03, 0.27367900E+03, -.10216500E+04, 0.77324100E+03, -.12905100E+04, -.26475500E+03, 0.11214200E+03, -.63773400E+03, 0.13460600E+03, -.36372500E+02, 0.23013600E+03, 0.86543400E+02, -.60482900E+01, -.54724600E+03, 0.79337900E+03, -.20502000E+04, 0.32603300E+04, -.15559600E+04, 0.22467700E+04, -.16251300E+04, 0.28471600E+03, 0.16649300E+04, -.83445400E+03, 0.11341400E+03, -.17506700E+04, 0.12113100E+04, -.39034600E+03, -.31340400E+04, 0.16457700E+04, 0.17873700E+04, 0.15657700E+04, -.55729700E+03, 0.77088900E+03, 0.99305500E+03, 0.50696900E+03, 0.11366700E+04, 0.31552400E+03, 0.31586500E+04, -.83665400E+04, 0.44122400E+04, 0.38872300E+04, 0.41857900E+04, 0.24568700E+04, 0.27596400E+04, 0.16803400E+04, 0.20732200E+04, 0.41024800E+04, 0.23715800E+04, 0.12539400E+04, -.17244500E+04, 0.84551100E+03, -.90325900E+03, 0.86648600E+03, 0.12502100E+04, 0.60039300E+03, 0.12419600E+02, -.18161300E+03, -.38537800E+03, 0.10438200E+04, -.10278200E+04, -.40746800E+03, 0.20694900E+03, 0.24720600E+03, 0.20322600E+03, -.11568300E+03, -.85568600E+02, 0.13516800E+03, 0.48368700E+02, 0.27218500E+03, -.13112800E+03, 0.53487500E+03, -.58259700E+04, 0.31444800E+04, -.15555400E+04, 0.29143700E+04, 0.25000800E+04, 0.40694900E+04, 0.33858400E+03, 0.81184700E+03, 0.30519200E+04, 0.37901300E+04, -.44381500E+02, -.28591900E+03, 0.15069000E+03, -.90955700E+03, 0.14331400E+03, 0.98287200E+03, -.25682200E+02, 0.10560400E+04, 0.18656700E+04, 0.63693200E+03, 0.33199700E+02, -.56865100E+04, 0.10162200E+04, -.39902100E+03, 0.84410100E+03, -.50819800E+03, 0.85356000E+03, 0.70589500E+03, -.43588000E+03, -.68336800E+03, -.96245100E+03, 0.58535900E+03, -.25195100E+04, -.89545700E+04, 0.44065900E+04, 0.57459000E+04, 0.44798000E+04, -.37445400E+03, -.31060600E+04, 0.20488400E+04, -.20415800E+04, 0.30783300E+04, -.16523900E+04, -.12245800E+04, -.22459600E+03, 0.79329800E+02, 0.22396900E+04, 0.11123600E+03, -.44324400E+03, -.17711600E+04, 0.59538300E+03, -.13986000E+04, -.79647400E+03, -.17151500E+04, 0.72331200E+03, -.21627700E+04, 0.10633300E+04, -.27432900E+03, 0.10770300E+04, 0.11526400E+04, 0.82437700E+02, 0.54254400E+03, -.35833800E+03, 0.10799700E+04, -.13277000E+03, 0.72450800E+03, -.66216100E+03, 0.36382200E+03, 0.10922300E+03, 0.32774100E+03, 0.93519300E+02, -.79103100E+03, 0.24224000E+03, -.45058300E+03, 0.36125200E+03, -.57882200E+03, 0.12550700E+04, 0.55157000E+04, -.27642600E+04, -.35142200E+03, -.27551700E+04, -.56522700E+03, -.13301800E+04, -.15783300E+04, -.90206900E+03, -.25926000E+04, -.94191600E+03, -.41704700E+04, -.15072000E+05, 0.79309700E+04, 0.43511700E+04, 0.75413200E+04, 0.40655900E+04, 0.46360700E+04, 0.32211700E+04, 0.30123100E+04, 0.72948400E+04, 0.40253500E+04, 0.24017100E+04, 0.50245500E+04, -.25158600E+04, 0.33541400E+04, -.25066900E+04, -.25598500E+03, -.33797300E+04, -.15252100E+04, -.23448500E+04, -.30552900E+04, -.17917300E+04, -.78831000E+04, 0.12844100E+04, -.71104800E+03, -.85247400E+03, -.64077700E+03, -.38449300E+02, 0.88796600E+01, -.24723100E+03, 0.54135300E+02, -.10278200E+04, 0.36373100E+03, -.28467800E+04, -.70468800E+03, 0.32897900E+03, -.18709400E+03, 0.35548900E+03, 0.70067300E+02, -.12225300E+03, 0.39067300E+03, 0.40387400E+03, 0.30956700E+03, -.39098600E+01, -.19843200E+04, 0.46228700E+03, 0.25924300E+03, -.33117900E+03, 0.14894900E+02, 0.43651700E+03, -.52609400E+03, -.14287400E+03, 0.36600100E+02, -.15060800E+03, 0.24224900E+03, -.23965300E+03, -.12252200E+04, 0.11298400E+03, 0.22037400E+03, -.46387100E+03, 0.53747800E+03, -.10233700E+03, -.23754300E+02, -.14815900E+03, -.31323900E+03, 0.18952600E+03, -.10344100E+04, 0.73806100E+03, 0.43214900E+03, -.54795200E+03, -.48768100E+03 },
        { -.18146200E+01, 0.25863500E+00, -.36277400E-01, -.28475600E+00, -.55979100E+00, 0.83027000E+00, -.25935400E+01, -.63934000E+00, -.88455500E+00, 0.15310300E+01, -.42360600E-01, -.20054500E+00, -.94221400E+00, -.24134800E+00, -.16681700E+00, -.17894000E+01, -.32692500E+00, 0.89799600E+00, -.88751300E+00, -.21377800E+01, -.60057900E+00, 0.27710600E+00, -.14272500E+00, 0.53658400E-01, -.74081800E+00, 0.55986700E-01, 0.53499800E+00, -.24447900E+00, -.15697000E+00, 0.81121600E+00, -.64616800E+00, 0.15423400E+00, -.32199800E+00, -.10912800E+00, 0.66053100E+00, -.15423500E+00, 0.53020700E-01, -.59771600E+00, 0.94297800E+00, -.10354500E+01, -.16288500E+00, -.99262700E-01, 0.35759100E+00, -.18878100E+00, -.21570300E+00, 0.15122300E-01, 0.30451700E+00, 0.55716000E-02, -.18176200E+00, -.45718500E+00, -.24321500E+01, 0.26357800E+00, 0.44456500E+00, 0.78596100E+00, -.25460500E+00, 0.87818500E-01, -.19213800E+00, 0.10192500E-01, -.49827700E-01, -.51259100E+00, 0.90697200E+00, -.91749900E+00, -.79860100E+00, 0.52820700E+00, -.65220700E+00, 0.10658600E+00, 0.10606100E+00, 0.62490900E-01, 0.10607800E-01, 0.62867900E-02, 0.12309700E+04, 0.17273100E+04, -.87885700E+03, -.23645800E+02, 0.26277800E+03, 0.12245600E+04, 0.15531100E+03, 0.31006000E+03, -.14486700E+03, -.83508300E+03, -.15531200E+03, 0.65539900E+03, 0.13841200E+04, -.10671500E+04, -.79288400E+03, 0.16560400E+03, 0.79589600E+03, 0.97464100E+03, -.17471900E+04, 0.81420900E+03, -.10736000E+04, 0.87354200E+03, -.66295500E+03, -.16982100E+04, 0.42154300E+03, -.69236700E+03, 0.92831000E+03, -.12855800E+04, 0.13351500E+03, -.16099400E+04, 0.73841100E+03, 0.10005900E+04, 0.80526100E+03, 0.47266200E+03, -.11496800E+03, 0.38709300E+03, -.10930500E+03, 0.71788400E+03, 0.46407200E+03, 0.46998000E+03, 0.83457200E+04, -.42365000E+04, -.76229200E+04, -.41709500E+04, -.56987100E+03, -.52098900E+03, -.27465300E+04, -.19525100E+04, -.49606300E+04, -.44145400E+03, -.28186100E+04, -.20407400E+04, 0.10379300E+04, 0.15842300E+04, 0.10206600E+04, 0.70062800E+03, 0.12758000E+04, -.94377600E+03, -.11481400E+04, 0.93206400E+03, 0.69868200E+03, 0.93040100E+03, 0.25201000E+03, -.12905300E+03, -.27928100E+02, -.12601100E+03, -.13854500E+03, -.16222800E+03, 0.11914400E+03, 0.13818700E+03, -.10384500E+03, -.10985300E+03, -.16418600E+03, 0.77679700E+04, -.38905400E+04, -.97328500E+04, -.38828200E+04, 0.42873500E+03, 0.21702300E+04, -.39561500E+04, -.28648400E+04, -.47408700E+04, 0.17302400E+04, -.26878500E+04, 0.12172000E+04, -.63236300E+03, 0.19123000E+03, -.60850200E+03, -.42182900E+03, 0.25534100E+04, -.16702400E+04, -.10925500E+04, -.87862500E+03, 0.17010000E+04, 0.26697900E+04, 0.44977000E+03, -.29842100E+03, 0.12659000E+03, -.22416600E+03, 0.20674500E+03, 0.23875400E+03, -.52086900E+03, -.52263700E+03, -.16562900E+03, 0.11622600E+03, 0.16874400E+04, 0.10631100E+05, -.52614900E+04, -.29945100E+03, -.53157700E+04, 0.35626700E+03, 0.32239900E+04, -.29053600E+04, 0.12664800E+04, -.38076600E+04, 0.21866400E+04, -.13792700E+04, -.62347200E+04, 0.31037700E+04, 0.52646800E+04, 0.31165400E+04, 0.10016100E+03, -.13847100E+04, 0.23136300E+04, 0.16654900E+04, 0.42175800E+04, -.13833800E+04, 0.24735200E+04, 0.34292100E+04, -.17045500E+04, 0.11293300E+04, -.17150500E+04, -.14894100E+04, -.61272500E+03, -.97923700E+02, 0.74475100E+03, -.10580300E+04, -.56510900E+03, -.90463200E+03, 0.10338300E+04, -.54983200E+03, 0.71325000E+02, -.51727000E+03, -.10483600E+04, -.11406700E+04, 0.62911100E+03, 0.24705900E+02, -.20770000E+03, -.91455700E+03, -.40015200E+03, 0.36211600E+04, -.18052000E+04, -.69598200E+03, -.18104100E+04, -.60535200E+03, 0.11185500E+03, -.81886900E+03, 0.49655700E+03, -.77730300E+03, -.24644000E+03, -.68421600E+03, 0.11921700E+05, -.60618000E+04, -.13406900E+05, -.59565000E+04, -.66626800E+03, 0.16057100E+03, -.45370500E+04, -.33372400E+04, -.68044200E+04, -.42847300E+02, -.38970600E+04, 0.79664800E+04, -.39813600E+04, -.29187500E+04, -.39833100E+04, -.15912700E+04, 0.41307200E+03, -.19529900E+04, 0.72091300E+03, -.21553600E+04, -.69719000E+03, -.81837700E+03, -.31819500E+04, 0.16266300E+04, 0.14881400E+03, 0.15910700E+04, 0.99061200E+03, 0.17826300E+04, -.88011100E+03, -.14367500E+04, 0.10382500E+04, 0.11981600E+04, 0.25476200E+04, -.11160000E+04, 0.58516600E+03, 0.57533600E+03, 0.55833300E+03, -.59106200E+02, 0.47202100E+03, -.11254700E+03, -.16749700E+03, 0.69240900E+03, 0.21502900E+03, 0.16786900E+04, -.30868600E+03, -.28375900E+03, -.65485500E+03, 0.56022700E+03, 0.75960100E+02, -.14184500E+03, -.46118900E+03, -.21763000E+03, 0.57258200E+03, 0.31294500E+03, -.74970200E+03, -.49864500E+03, -.13944700E+03, 0.29694600E+03, -.30142900E+03, -.61350600E+02, 0.56834300E+03, 0.56093700E+03, -.16556500E+03, -.27076800E+03, -.34599100E+03, 0.11810000E+04, 0.36437100E+03, -.79215700E+03, -.41603700E+03, -.51672300E+02 },
        { -.23390800E+01, 0.12220300E+01, 0.63263800E-01, -.12199500E+00, -.83683200E+00, 0.10037200E+01, -.32639200E+01, -.11801100E+01, -.99269400E+00, 0.14645400E+01, -.85987800E-01, -.17869200E+00, -.32654300E+01, 0.37650200E+01, -.14969600E+01, 0.92855800E+00, 0.15609200E+00, 0.93540800E+00, -.28091500E-01, 0.46433700E+00, -.28512500E+00, 0.78001500E-01, -.27693300E+00, -.25065500E+00, 0.35257500E-01, 0.11285000E+00, 0.48749200E+00, 0.62464800E+00, -.12486500E+01, -.29480600E+00, 0.91693400E-01, -.47837800E+00, 0.46851800E+00, 0.10234000E+00, 0.27978300E+00, -.28282600E+00, -.23968400E+00, 0.89644900E-01, -.53745500E-01, 0.49214500E+01, 0.50166200E-01, -.15704700E+00, 0.58055800E+00, 0.96897200E+00, -.34352600E+00, 0.18598300E+00, -.28371000E+00, -.26426800E-01, 0.22872500E-01, 0.20520400E-01, -.24610900E+00, -.72450800E+00, 0.17220100E+00, 0.13280200E+00, 0.65211600E+00, -.83051800E+00, 0.85149100E-01, 0.70733300E-01, -.76550300E-01, -.56953000E+00, 0.13973700E+01, 0.16392000E+01, 0.40419700E+00, 0.47687400E+00, -.12880700E+01, 0.13895100E+00, 0.20679400E-01, 0.54390200E+00, -.31850500E+00, 0.10389300E+00, -.12314600E+01, 0.19381500E+04, -.98388300E+03, 0.72755000E+03, 0.11372000E+04, 0.17161800E+04, 0.78375800E+03, 0.91519800E+03, -.47251700E+03, -.32380900E+04, -.45659500E+03, -.10577300E+04, 0.14837100E+04, -.12803700E+04, -.30091200E+03, 0.13267900E+04, 0.10974900E+04, 0.15622600E+04, 0.72993200E+04, -.36587900E+04, -.36967100E+04, -.36479600E+04, -.23811500E+04, -.14769100E+04, -.61810200E+03, 0.11080900E+04, -.20240400E+04, -.13283600E+04, -.12431900E+04, -.28109800E+04, 0.13931100E+04, 0.42069600E+04, 0.14048100E+04, -.36354700E+03, -.57006200E+03, 0.12112500E+04, 0.72003500E+03, 0.15656700E+04, -.24901800E+03, 0.31173300E+04, -.21967000E+05, 0.11260900E+05, 0.49072000E+04, 0.10981800E+05, 0.66019800E+04, 0.90437800E+04, 0.23369300E+04, -.21447500E+04, -.29168500E+03, 0.77228800E+04, 0.50337100E+04, -.55560300E+04, 0.27930200E+04, 0.70132300E+03, 0.27790400E+04, 0.81929600E+03, 0.61889100E+03, -.48987900E+03, -.80799600E+03, 0.25364500E+04, 0.72660600E+03, 0.30647000E+04, 0.71154400E+02, -.37396400E+02, 0.21954400E+03, -.35729300E+02, -.13867700E+03, -.24881000E+03, 0.20338200E+03, 0.15178300E+03, -.12298300E+03, -.22458500E+03, -.17102100E+03, -.16034500E+05, 0.84470200E+04, -.23388600E+04, 0.80165800E+04, 0.52808900E+04, 0.10013800E+05, 0.81177600E+03, -.80150600E+03, 0.11940100E+04, 0.84617100E+04, 0.49382400E+04, -.65032900E+04, 0.32143500E+04, 0.13462400E+03, 0.32516000E+04, 0.99664400E+03, 0.21031600E+04, -.33197900E+03, -.91945300E+03, 0.43737800E+04, 0.10331900E+04, 0.67921300E+03, 0.10234400E+04, -.43756100E+03, 0.20162400E+04, -.51127500E+03, 0.11722300E+04, 0.31855000E+03, -.72366700E+03, -.20380200E+04, -.74154900E+03, -.82109600E+02, -.17492100E+04, 0.81652800E+04, -.40764400E+04, 0.79457100E+04, -.40900200E+04, 0.12875800E+04, 0.24983100E+04, -.28788200E+04, -.91604000E+03, -.24682700E+04, 0.24404200E+04, -.43687100E+04, 0.35920700E+04, -.18077300E+04, 0.14027400E+04, -.17953800E+04, -.27199300E+04, -.58180600E+04, 0.19035400E+04, 0.66087700E+03, 0.37165500E+04, -.53693300E+04, -.10237600E+03, 0.97055100E+03, -.50070700E+03, -.75763800E+03, -.48628100E+03, -.22740400E+03, -.21190900E+03, 0.17056800E+03, 0.25539300E+03, 0.16405600E+02, -.70243100E+03, -.23192100E+03, 0.27732300E+04, -.14221200E+04, -.12175200E+04, -.13873000E+04, -.12814700E+04, -.22691800E+04, 0.48799400E+03, -.59597900E+03, -.23271600E+04, -.19568400E+04, 0.72749200E+03, 0.34250200E+04, -.17111100E+04, 0.12300000E+04, -.17118400E+04, -.19684800E+03, 0.41917000E+02, -.18059600E+04, -.20763200E+04, -.30910400E+04, 0.87369200E+02, -.29038800E+04, -.36615000E+05, 0.18806800E+05, 0.42899400E+04, 0.18303900E+05, 0.92773700E+04, 0.14327500E+05, 0.48488100E+04, -.22403800E+04, 0.28051400E+04, 0.11882500E+05, 0.10715600E+05, 0.79751400E+04, -.39922500E+04, -.74949400E+03, -.39857300E+04, -.86336000E+03, -.53454100E+03, -.27356800E+04, -.29738900E+04, -.55979200E+04, -.57448000E+03, -.65333100E+04, -.46608000E+04, 0.22821000E+04, -.11966500E+04, 0.23305800E+04, 0.70249000E+03, 0.18703500E+04, -.94822700E+03, -.15791300E+04, 0.35655500E+04, 0.14910400E+04, 0.33185700E+04, -.36123100E+04, 0.18359700E+04, 0.15232900E+04, 0.18067900E+04, 0.82049800E+02, 0.46794200E+03, 0.11841100E+03, -.12403600E+03, 0.26208200E+04, 0.43387600E+03, 0.14494400E+04, -.31985200E+02, -.72702800E+02, -.82524600E+03, 0.51052200E+03, 0.16776200E+03, -.47036900E+03, -.72175400E+03, -.55348300E+03, 0.97041600E+03, 0.27771100E+03, -.98681700E+03, -.28530300E+04, -.47045000E+03, 0.36052500E+03, -.17527800E+03, 0.25820400E+03, 0.91881300E+03, 0.36680200E+03, -.24696900E+03, -.79378200E+03, -.71265000E+03, 0.81914200E+03, 0.99167000E+03, -.69003800E+03, -.97885900E+03, -.12580900E+03 },
        { -.81615600E+00, 0.16115800E+01, 0.16409300E+00, 0.59323500E+00, -.52366200E-01, 0.44962800E+00, -.15026000E+01, 0.60260800E+00, -.81480900E+00, 0.28612600E+00, -.12945600E-01, -.13338200E+00, -.11870300E+00, 0.14003600E+01, -.21462800E+00, -.73738600E-01, -.23939700E-02, 0.57530700E+00, 0.21860800E+00, 0.35308300E+00, -.40728200E-02, -.54371000E-01, -.38156500E-01, -.11409000E+00, 0.34089800E+00, 0.25720600E-01, 0.87642400E-01, 0.52698000E+00, -.12839400E+00, -.71851000E-01, 0.19000100E+00, 0.15399200E+00, 0.27121300E+00, 0.17650000E+00, 0.27526700E-01, 0.36056100E-01, -.62181200E-01, 0.25809000E+00, -.33915500E+00, 0.24357600E+01, 0.73899200E-01, 0.42676600E-01, -.27434200E+00, 0.32259400E+00, 0.52149100E-01, -.13956300E-01, -.11147000E+00, 0.23841500E-02, -.43809600E-02, 0.82011700E-01, 0.13157000E+01, -.28684000E+00, -.18708600E+00, -.27693500E+00, 0.32837200E+00, 0.46491800E-02, -.94272800E-01, 0.45141200E-01, -.11845100E-01, 0.16482700E+00, 0.21391500E+00, 0.17003300E+00, -.11889100E+00, 0.15654700E+00, -.32646700E+00, 0.14022400E-01, -.43562600E+00, 0.85362100E-02, -.14385500E+00, 0.16584900E-01, -.21160700E+00, 0.10166300E+00, -.36455000E+03, -.18595400E+03, 0.13582500E+03, 0.25798500E+03, 0.16626700E+03, 0.31690000E+03, -.16757600E+03, -.40181500E+03, -.15848800E+03, -.44562300E+03, 0.28714800E+02, -.49032400E+03, -.24503500E+03, 0.23432100E+03, 0.28854800E+03, -.18360500E+02, 0.11774700E+04, -.56846300E+03, -.19536100E+03, -.58868500E+03, -.28007900E+03, 0.97168400E+03, -.94696400E+03, 0.73913500E+02, 0.13218100E+03, 0.76109500E+03, 0.31202800E+03, -.12669300E+04, 0.66146600E+03, 0.13328400E+04, 0.63351500E+03, 0.49821100E+03, 0.93142200E+02, 0.87209500E+03, 0.39098400E+03, 0.29804600E+03, -.28365700E+03, -.51820800E+02, -.12104500E+05, 0.60987600E+04, 0.29494700E+04, 0.60528200E+04, 0.16037200E+04, 0.26402100E+04, 0.17956700E+04, 0.54159400E+03, 0.45066600E+04, 0.19919200E+04, 0.38199100E+04, -.84820000E+03, 0.40654800E+03, 0.20822500E+03, 0.42423200E+03, 0.63990900E+02, -.22163700E+03, 0.15263900E+03, 0.32563700E+03, 0.73918800E+03, 0.20907700E+03, 0.30697100E+03, -.22916000E+03, 0.11669700E+03, 0.45196000E+02, 0.11457100E+03, 0.15897000E+02, 0.15785100E+02, 0.68085700E+02, 0.13483400E+02, 0.78127900E+02, -.42342500E+02, 0.77238800E+02, -.48423500E+04, 0.24005100E+04, 0.25202600E+04, 0.24214600E+04, -.40064000E+03, 0.10575000E+04, 0.95912100E+03, 0.12424800E+04, 0.25691700E+04, 0.94043300E+03, 0.99590200E+03, -.44999700E+03, 0.25307000E+03, 0.17967400E+03, 0.22503300E+03, 0.93162900E+03, 0.15840100E+03, -.14267800E+03, -.34568400E+03, -.24129900E+02, 0.29464600E+03, -.24382800E+04, 0.62536100E+03, -.27120000E+03, -.34894400E+03, -.31240100E+03, 0.49551000E+03, 0.17640600E+03, 0.24333600E+03, 0.30274100E+03, -.31356100E+03, 0.77819100E+02, -.15562000E+04, -.52326900E+04, 0.25933200E+04, 0.13089300E+04, 0.26161600E+04, 0.34164600E+03, -.12703700E+04, 0.12685500E+04, -.74447500E+03, 0.13155700E+04, -.64005000E+03, 0.33683200E+03, -.84489300E+03, 0.44626700E+03, -.22861100E+04, 0.42221600E+03, 0.79086100E+03, -.21711000E+03, 0.51251700E+03, -.32677100E+03, 0.17430700E+03, -.17296400E+03, 0.67149900E+03, -.33286200E+03, 0.17182000E+03, -.14441100E+03, 0.16627400E+03, 0.23971300E+03, 0.59784900E+03, -.47897100E+03, -.70644000E+03, -.49419200E+03, 0.37711100E+03, -.18472800E+03, -.65394600E+03, 0.34334500E+03, 0.41128400E+01, 0.32684000E+03, 0.39104800E+02, 0.14992600E+03, -.19453700E+03, -.47144800E+03, 0.20061300E+03, 0.14403100E+03, 0.76340200E+03, 0.22461700E+04, -.11283200E+04, -.14309100E+04, -.11230100E+04, -.21471000E+03, -.20352500E+03, -.13591500E+04, -.74408800E+03, -.69001800E+03, -.48259800E+02, -.73732600E+03, -.17392000E+05, 0.87639500E+04, 0.41880400E+04, 0.86972300E+04, 0.18843700E+04, 0.36022800E+04, 0.27915800E+04, 0.13617800E+04, 0.71929700E+04, 0.27666400E+04, 0.52166600E+04, 0.91234100E+03, -.45826100E+03, -.23866300E+04, -.45611000E+03, -.48258000E+03, -.42654300E+03, -.20400400E+04, -.15073700E+04, 0.89974400E+02, 0.26167900E+03, -.32937900E+03, -.30966000E+03, 0.14025100E+03, -.46959400E+03, 0.15489400E+03, -.19042200E+03, -.14117200E+03, -.94784300E+02, -.42029000E+03, -.34553500E+02, 0.17763400E+03, 0.54007400E+02, -.24654700E+03, 0.10264000E+03, 0.51679700E+02, 0.12340000E+03, -.15264500E+03, -.21931400E+03, 0.25086600E+03, 0.24913200E+03, 0.23607900E+03, -.11505700E+03, -.70184100E+03, 0.34522900E+03, 0.14431700E+03, 0.16165300E+03, -.22966600E+03, 0.13243200E+03, -.21183100E+03, 0.42461800E+02, 0.48413700E+02, -.14342000E+03, 0.19758300E+03, 0.15443800E+03, 0.16325500E+03, -.81221800E+02, -.20297100E+02, 0.42801600E+03, 0.16699200E+03, -.20543100E+03, -.22985500E+03, -.11864700E+02, -.40562900E+02, 0.14198000E+02, 0.25551800E+02, -.55793500E+03, 0.53806000E+02, -.12738600E+03, -.14899000E+03 },
        { -.31779300E+01, -.74355000E+01, -.10349100E+01, -.34838200E+01, -.47548700E+00, 0.86951600E+00, -.55308000E+01, -.30979900E-01, -.24801800E+01, 0.30436400E+01, 0.14998000E+00, -.30221500E+00, -.20343900E+01, 0.74865500E+01, -.14471300E+01, -.15652400E+00, 0.85548000E+00, 0.20137300E+01, -.61374000E+00, -.14221300E+00, 0.36045700E+00, 0.17338400E-01, -.44933100E+00, 0.75084000E-01, -.16358000E+01, 0.21872900E-01, -.45489000E+00, 0.80657900E+00, -.72193100E+00, 0.12409700E+01, -.61640200E+00, -.72676200E-01, -.24866200E+00, -.32680200E+00, -.18698300E+00, -.27993500E+00, 0.90949600E-03, -.84713600E+00, 0.52606700E+00, -.69555900E+01, -.16061800E+00, -.99597000E-01, -.24680100E+00, -.17575700E+00, 0.20989200E+00, 0.32543500E+00, -.28912000E-01, 0.15319700E-01, -.23540500E-01, -.23802300E+00, -.13096400E+01, -.48953100E+00, 0.80570700E+00, 0.49240300E+00, 0.86666700E+00, -.90854600E+00, 0.11055700E+01, -.33731100E+00, 0.21052400E-01, 0.52829700E+00, 0.12359800E+01, -.21656000E+01, -.18415400E+01, 0.13062100E+00, -.98781100E-02, -.23894200E-01, -.90957600E+00, 0.31350100E+00, -.37460900E+00, 0.74681700E-01, -.25087600E+00, 0.83411700E+00, 0.18147000E+01, -.82698400E+03, -.15995600E+04, 0.12819600E+03, -.60159700E+03, -.40825400E+04, 0.20367100E+04, 0.42771400E+04, 0.20408500E+04, 0.10198800E+04, -.30732000E+03, 0.23674300E+03, -.12702300E+04, -.32154300E+03, 0.76302200E+03, -.40509500E+03, -.70432600E+04, 0.35589000E+04, 0.69388700E+04, 0.35211400E+04, 0.48915900E+03, 0.27175300E+04, -.67268400E+03, -.24797000E+04, 0.20160600E+04, 0.19875500E+04, 0.31958000E+04, -.20700400E+04, 0.10808600E+04, -.65790100E+03, 0.10353500E+04, 0.24164500E+03, 0.12515000E+04, 0.63401700E+03, 0.84140200E+03, 0.18542600E+02, 0.67401600E+03, 0.22009300E+03, 0.78019600E+04, -.39492000E+04, 0.61005300E+03, -.38996500E+04, 0.30270100E+03, 0.50908600E+03, -.16479700E+04, 0.26707600E+04, 0.33034500E+04, -.15306300E+03, -.20331000E+04, 0.19140000E+04, -.97920500E+03, -.53048700E+03, -.95716900E+03, 0.26003100E+03, 0.11332600E+04, -.97378200E+03, -.11954100E+04, -.21970500E+04, 0.13870800E+04, -.25745700E+04, -.28127000E+03, 0.14369200E+03, 0.39159300E+02, 0.14067700E+03, -.29690900E+02, 0.25774500E+02, 0.10654300E+03, 0.85177800E+02, 0.38644400E+03, -.65566400E+02, 0.34650200E+03, -.17767100E+04, 0.62288400E+03, 0.73585400E+03, 0.88907900E+03, 0.12337600E+04, -.12770900E+04, 0.14930300E+03, 0.45440500E+03, 0.39616200E+04, -.12622200E+04, 0.11738300E+04, -.82892300E+03, 0.46545600E+03, 0.15267300E+03, 0.41451000E+03, 0.19658900E+04, -.12656100E+04, -.11540400E+03, -.63973200E+03, -.24096300E+04, 0.66976400E+02, -.69151600E+03, 0.63496000E+03, -.26509900E+03, 0.14089300E+04, -.31810200E+03, -.49874400E+03, -.40181400E+03, -.53557400E+03, -.16448500E+03, -.54771600E+03, -.11668800E+03, -.59006900E+03, -.79486000E+04, 0.39389600E+04, -.11054600E+04, 0.39757800E+04, 0.18471900E+04, -.21703100E+04, 0.25447600E+04, -.80334400E+03, 0.19556600E+03, -.60515000E+03, 0.31493800E+03, -.81054700E+03, 0.50270400E+03, 0.11890900E+04, 0.40473000E+03, 0.79232600E+03, 0.21253000E+04, -.16079000E+04, -.23753000E+04, -.42646500E+04, 0.22901300E+04, 0.15009800E+02, -.49682000E+04, 0.24891200E+04, 0.13513200E+04, 0.24841500E+04, 0.19031500E+04, -.56695200E+03, 0.46893900E+03, -.16925300E+04, 0.10950700E+04, 0.75339500E+02, 0.20510700E+04, -.10553200E+04, 0.56043200E+03, 0.80781800E+03, 0.52769500E+03, 0.54354400E+03, 0.22236500E+03, -.16738300E+03, 0.34070000E+03, 0.26499300E+04, 0.56345000E+02, -.95222800E+03, 0.98134600E+03, -.49799600E+03, 0.72596400E+03, -.49079200E+03, -.27135700E+03, -.48417900E+03, -.57785500E+03, -.62216400E+03, 0.58636100E+03, -.42913300E+03, -.58816100E+03, 0.59512900E+04, -.31256700E+04, 0.23316000E+04, -.29726600E+04, 0.20897000E+04, 0.83917700E+03, -.22424700E+04, 0.24108300E+04, 0.54608000E+04, 0.23494200E+03, -.14272400E+04, -.32795600E+04, 0.16360800E+04, 0.73020600E+04, 0.16392200E+04, 0.51003400E+03, -.11713500E+04, -.71292600E+03, -.25325600E+04, 0.23872400E+04, -.23699700E+03, -.40022800E+03, 0.23251300E+04, -.11655100E+04, 0.17292500E+04, -.11626400E+04, 0.58234100E+03, -.10507500E+03, -.84435300E+03, -.11739200E+04, -.47245900E+04, 0.59654000E+03, -.29257400E+04, 0.77602700E+03, -.42233300E+03, -.94633000E+03, -.38805000E+03, 0.55993300E+03, 0.34466000E+02, -.70331200E+02, -.42529600E+03, -.21928400E+04, 0.55372300E+03, -.15178700E+04, 0.23899900E+03, 0.29692700E+03, 0.15239100E+03, -.24092400E+03, 0.12634700E+03, -.32779200E+03, 0.67675000E+02, 0.23941600E+03, -.73266800E+03, 0.42170200E+03, 0.17589000E+03, -.11753100E+04, 0.10061900E+03, -.81857600E+01, -.64228000E+03, 0.11506900E+02, -.24649200E+03, -.61571000E+02, 0.16993200E+03, -.54252100E+01, 0.83140100E+03, -.10181800E+04, 0.13660200E+04, 0.58080800E+03, 0.25439600E+03, -.24215400E+01 },
        { -.23656000E+01, -.10789600E+01, -.93855800E-01, -.18302600E+00, -.12638600E+01, -.21690800E+01, -.84228600E+00, -.19833700E+00, -.11671600E+01, 0.19559300E+01, 0.34356600E-01, -.88623500E-01, -.53541900E+00, 0.14719500E+01, -.18242700E+01, 0.56069100E+00, 0.49946700E+00, -.50320600E+00, -.24111700E-01, -.13735000E+01, -.27551700E-01, 0.42828300E-01, -.16080100E+00, 0.11294600E+00, -.34077100E+00, -.62264800E-02, -.47523900E+00, -.68208600E+00, 0.29073200E+00, -.15871600E+00, -.74465000E-02, 0.82315800E-01, 0.80713800E-01, 0.75012100E-02, 0.19716700E+00, -.16569600E+00, 0.39500900E-01, -.11648400E+00, -.13007000E+01, 0.49651400E+00, 0.68105600E-01, -.28590000E+00, -.25214100E+00, 0.99271700E+00, -.21025800E+00, 0.11193100E-01, -.21981800E+00, -.13606700E-01, 0.20057200E+00, 0.19552900E+00, 0.26321400E+01, -.17047000E+00, -.24667300E+00, -.10383100E+01, -.25857500E+00, 0.15933900E+00, 0.34342000E+00, 0.60275400E-01, 0.19108500E-02, 0.19433600E+00, -.57624300E+00, -.20716000E+00, -.11841000E+00, -.29865300E+00, 0.11243400E+01, 0.80506700E-01, -.28222400E-01, 0.77353300E-01, 0.30179700E+00, 0.79887800E-01, -.42977100E+00, -.19399800E+00, 0.78716900E+00, 0.27536100E+00, 0.12485400E+04, -.51410800E+03, 0.10186200E+04, 0.16696400E+04, -.81324000E+03, -.16133100E+04, -.83349600E+03, -.13301500E+03, 0.39434300E+03, -.40830700E+03, -.13114000E+03, 0.39679700E+03, -.65858400E+03, 0.29525100E+04, 0.23177600E+04, -.12302900E+04, -.41539300E+04, -.11571300E+04, -.10520900E+04, -.27607300E+04, 0.68223200E+03, 0.27971200E+03, -.20292100E+04, -.22582100E+04, -.20115400E+04, 0.22168600E+04, -.11947100E+04, -.59217700E+03, -.11094400E+04, 0.35017200E+03, -.52873300E+03, -.14605900E+04, -.86778500E+03, -.48753000E+03, 0.43414900E+03, -.79877600E+02, 0.43666000E+04, -.23282900E+04, -.63509000E+04, -.21866800E+04, -.52763400E+03, -.11262200E+04, -.27156600E+04, -.53498400E+04, -.74705300E+04, -.36913300E+03, 0.97299500E+03, -.96742800E+03, 0.52210300E+03, 0.15381500E+04, 0.48448000E+03, -.97328800E+03, -.90111400E+03, 0.17818100E+03, -.71223000E+03, 0.11439100E+04, -.16157600E+04, 0.23410400E+04, 0.67818700E+03, -.34437100E+03, -.24799600E+03, -.33924500E+03, 0.37780200E+02, 0.36967200E+01, -.10989400E+03, 0.95407400E+02, -.38869800E+03, 0.12822100E+03, -.68302200E+03, 0.46990400E+04, -.23140600E+04, -.30367200E+04, -.23514700E+04, -.10722000E+04, -.90143500E+03, -.23137200E+04, -.46044300E+04, -.66780900E+04, -.69149000E+03, 0.15674400E+04, -.13441500E+04, 0.61177200E+03, 0.10897300E+04, 0.67197200E+03, -.16412200E+04, 0.89280300E+03, -.79061600E+03, -.17328100E+04, 0.17712900E+04, 0.11744200E+03, 0.85971300E+04, -.63333900E+03, 0.20073200E+03, 0.88067700E+03, 0.31742800E+03, -.53416600E+03, 0.12861600E+03, -.42367300E+03, -.82295200E+03, 0.29148900E+03, -.87368900E+02, 0.39492400E+04, 0.14738400E+05, -.72964000E+04, -.18149800E+04, -.73755900E+04, -.23760200E+03, 0.45497600E+04, -.40462100E+04, 0.13548800E+04, -.34334400E+04, 0.28172400E+04, 0.29531100E+04, -.28944300E+04, 0.13980300E+04, 0.50822900E+03, 0.14486300E+04, -.53999100E+03, -.17950200E+03, 0.14992700E+04, 0.29347300E+04, 0.54995600E+04, -.63320700E+03, 0.71276800E+03, 0.21960400E+04, -.11007500E+04, -.25305200E+03, -.10985200E+04, -.88481800E+03, -.34564400E+03, 0.42307100E+03, 0.19192400E+04, -.53376600E+02, -.11628200E+03, -.46605500E+03, 0.15268600E+04, -.81337900E+03, -.42154500E+03, -.76376600E+03, -.44775700E+03, 0.27626600E+03, -.18687300E+03, -.33132600E+03, -.31165000E+04, 0.21364300E+03, 0.14253100E+02, -.41857000E+04, 0.21049200E+04, 0.18600000E+04, 0.20933700E+04, 0.16285700E+03, 0.11582300E+04, 0.16317200E+04, 0.60621900E+03, 0.74303500E+03, 0.62487900E+03, 0.28280000E+04, 0.75407100E+04, -.39764400E+04, -.97376300E+04, -.37780600E+04, -.17095000E+04, -.18475400E+04, -.41883000E+04, -.82564100E+04, -.11463100E+05, -.10064200E+04, 0.28716800E+04, -.45720800E+03, 0.23271400E+03, -.15062700E+04, 0.23057000E+03, -.63920000E+03, 0.27736600E+04, 0.16389900E+04, 0.15315200E+04, -.17116800E+04, 0.64021400E+03, 0.55822300E+04, -.27171600E+04, 0.14049200E+04, 0.77814300E+03, 0.13588200E+04, -.16779600E+03, 0.77440700E+03, -.15660200E+03, -.87437900E+03, 0.31065000E+04, -.18232500E+03, 0.46967300E+04, -.23884800E+03, 0.17000700E+03, 0.12330100E+04, 0.11974200E+03, -.36443700E+03, -.71889000E+02, 0.16839200E+01, 0.64952900E+01, 0.18922300E+04, -.36407700E+03, 0.34340200E+04, -.87383500E+03, -.23226300E+03, -.26091900E+03, 0.37257900E+03, -.75259300E+03, 0.79524000E+03, -.12593500E+03, -.90924400E+02, 0.65293300E+03, -.72124200E+03, -.25701000E+03, 0.97797200E+02, -.40817700E+03, -.15086000E+03, 0.40663400E+03, -.69784700E+03, 0.69188000E+03, 0.28129500E+03, -.20095800E+03, 0.79481000E+02, -.66779600E+03, 0.10224600E+04, -.39451300E+03, -.50589000E+03, 0.11848500E+03, 0.71990700E+03 },
        { -.11177400E+01, 0.18077900E+01, 0.22335100E+00, 0.46889200E+00, 0.13766800E+00, 0.14565400E+01, -.37659000E+01, 0.36862900E+01, -.14579800E+01, 0.46245500E+00, -.22201900E-01, -.93973400E-01, -.22306200E+00, 0.16947500E+01, 0.20747000E+00, -.16639300E+01, 0.31832700E+00, 0.12385000E+01, 0.71664600E-01, 0.57473100E+00, -.34143900E+00, 0.93250900E-01, -.10642500E-01, 0.20461300E+00, -.18141200E+01, -.16368000E-01, 0.63515100E-01, 0.89211100E+00, -.29473200E+00, 0.75493000E+00, -.39982800E+00, -.34496600E+00, 0.75019800E-02, 0.35201400E+00, -.31009000E-02, -.37845500E-01, 0.35407900E-01, -.19165100E+00, -.49449200E+00, -.23572300E+01, 0.32845600E-01, -.84182900E-02, -.64602500E+00, -.38017200E+00, 0.43351400E+00, -.85134600E-01, -.41681300E+00, -.10243600E-02, 0.12459800E+00, 0.13543000E+00, -.86790700E-01, -.63037900E-01, 0.26386900E+00, 0.41336800E+00, 0.26737100E+00, -.11363700E+00, 0.66139900E+00, -.16094400E+00, 0.14153500E-01, 0.29211400E+00, 0.13121000E+00, -.12318700E+00, 0.17779600E+00, -.12149000E+00, 0.69401100E+00, -.54198000E-01, -.63884000E-01, -.24798000E+00, 0.33420700E-01, 0.44004100E-01, 0.50153100E-01, -.44569400E+00, 0.16416900E+01, -.13372200E+00, 0.22892400E+00, -.46038000E+03, -.25417500E+03, 0.56463200E+02, -.17354900E+02, -.31726700E+03, -.27287500E+02, 0.60731400E+03, -.12707100E+03, 0.24747100E+03, 0.42765100E+03, -.16978000E+03, -.51477400E+03, -.76830300E+03, -.71908500E+03, 0.32325600E+03, -.26256000E+03, 0.36055800E+03, 0.45722900E+03, -.73389600E+03, 0.10513500E+04, 0.27645200E+03, 0.54938900E+02, -.76875000E+03, -.13904500E+03, 0.64314700E+03, -.37218500E+03, -.19366900E+02, -.32234900E+03, -.17876900E+03, 0.87972800E+02, -.10935100E+04, -.85806500E+03, -.51180500E+03, 0.62513500E+03, -.22820400E+03, 0.13353900E+05, -.66777300E+04, -.10913900E+04, -.66803500E+04, -.17349400E+04, -.31517300E+04, -.11606100E+04, -.44851900E+03, -.61143100E+04, -.21875000E+04, -.37377700E+04, 0.35368400E+04, -.17377600E+04, -.22815300E+04, -.17682300E+04, -.25044600E+02, 0.65584500E+03, -.11970400E+04, -.48585500E+03, -.18505100E+04, 0.30749400E+02, -.14608800E+04, 0.23779200E+03, -.12262300E+03, 0.91466500E+01, -.11897400E+03, 0.19001300E+02, -.37597000E+02, -.96431800E+02, -.90147600E+02, -.11741400E+03, 0.70769300E+02, -.40624400E+02, 0.25318700E+04, -.11656900E+04, -.11724200E+04, -.12678800E+04, -.26293300E+03, -.34618400E+04, 0.21958400E+04, -.14343600E+03, -.19925300E+04, -.29245300E+04, 0.48080700E+03, -.19262100E+03, 0.48595100E+02, -.30296700E+03, 0.96170600E+02, -.87551200E+03, -.24662100E+03, 0.58360200E+03, 0.10478000E+04, 0.83152400E+03, -.36829200E+03, 0.26321800E+04, -.41991200E+02, -.31706800E+02, 0.78146100E+03, 0.20084000E+02, -.26390000E+03, 0.69427100E+03, -.41470800E+03, 0.48262900E+03, 0.42661300E+03, 0.55378300E+03, 0.93455600E+03, 0.39885100E+04, -.19544900E+04, 0.87840600E+02, -.19975600E+04, -.85138900E+03, 0.84183100E+03, -.73863700E+03, 0.55312800E+03, -.91264600E+03, 0.27497200E+03, -.10975700E+04, 0.47749100E+04, -.24248200E+04, 0.60669600E+03, -.23860200E+04, -.57986200E+03, 0.15068700E+04, -.24530500E+04, 0.29343900E+03, -.78627700E+03, 0.11069000E+04, -.24281000E+04, -.18714000E+04, 0.92788300E+03, 0.90659200E+03, 0.93574300E+03, 0.33351600E+03, -.87506000E+03, 0.12898900E+04, 0.98808900E+03, 0.16415600E+04, -.47151500E+03, 0.77866800E+03, 0.12737700E+04, -.66599300E+03, -.51427000E+03, -.63679900E+03, -.18303400E+03, -.57743500E+03, 0.88440100E+03, 0.15744400E+04, 0.16337100E+03, -.68940400E+03, -.16094400E+04, -.25018700E+04, 0.12585000E+04, 0.14178900E+04, 0.12511000E+04, -.15642700E+03, 0.16437600E+01, 0.21702300E+04, 0.19274300E+04, 0.11066900E+04, -.29372500E+03, 0.69081900E+03, 0.19037300E+05, -.95027700E+04, -.19412400E+04, -.95263400E+04, -.25319000E+04, -.56886100E+04, -.49556000E+03, -.59569400E+03, -.88807900E+04, -.42496000E+04, -.48461700E+04, -.13721900E+04, 0.68913100E+03, 0.21795300E+04, 0.68723200E+03, -.18102600E+03, 0.25400400E+03, 0.34879200E+04, 0.34053900E+04, 0.77634400E+03, -.94714500E+03, 0.36997900E+03, 0.37040500E+03, -.16795500E+03, -.47202900E+02, -.18519000E+03, 0.24032600E+03, 0.38497100E+03, 0.18783200E+03, 0.10286000E+04, 0.22422500E+03, -.10766500E+03, -.76521000E+03, 0.82514000E+03, -.37515900E+03, -.66693500E+03, -.41265500E+03, 0.50333300E+03, 0.60475200E+03, -.82196600E+03, -.83849000E+03, -.91019700E+03, 0.59218100E+03, 0.72612200E+02, -.45357100E+03, -.14603500E+03, 0.42476800E+01, 0.21116100E+03, -.14793200E+03, 0.25042500E+03, -.82034400E+01, -.59286400E+02, 0.25004600E+03, -.22704300E+03, -.18354300E+03, -.33831300E+02, 0.12924000E+03, 0.41852400E+02, -.28057900E+03, -.13175800E+03, 0.16099600E+03, 0.18859500E+03, 0.29354600E+03, 0.80743800E+02, 0.17489400E+03, 0.10474500E+03, 0.54294600E+03, -.17316500E+03, 0.20894600E+02, 0.22950700E+03 },
        { -.39024700E+01, 0.19804000E+01, 0.25071500E+00, -.25280000E+00, -.18482700E+01, -.63225100E+00, -.25956300E+01, 0.41330500E+00, -.19090900E+01, 0.31426100E+01, 0.50986100E+00, -.40956800E-02, -.28279100E+00, 0.11982300E+01, -.48711900E+01, -.79007000E+00, 0.38335000E+00, -.20760300E+01, 0.19522100E+01, -.15983800E+01, 0.76701500E+00, 0.28457500E-01, 0.19050300E+00, -.20391900E+00, 0.66214700E+00, -.22055500E-01, -.61819200E+00, -.22444600E+01, 0.20091700E+01, -.11589200E+01, 0.94179000E+00, 0.95545300E+00, 0.48082700E+00, 0.82928800E+00, 0.32299000E+00, 0.61334600E+00, 0.20872300E+00, 0.72874700E+00, -.14443300E+01, 0.29920300E+01, 0.11771900E+00, 0.19194200E+00, -.25979800E+00, 0.72735400E+00, -.18430300E+00, -.58312500E+00, 0.12779200E+00, 0.28777800E-01, 0.34485000E-01, 0.12173000E+00, 0.32899100E+01, 0.98262700E+00, -.11729000E+01, 0.33292500E+00, -.19390600E+01, 0.90637300E+00, -.12577300E+01, 0.41492500E+00, 0.16332800E-01, -.75470500E+00, 0.80468200E-01, -.82233300E+00, -.10752600E+00, -.75196900E-01, -.49363700E+00, 0.30761900E+00, 0.18477200E+01, 0.18709300E+00, 0.58675300E+00, -.36327000E-01, 0.11493700E+01, -.29715200E+00, -.26204200E+01, -.20578500E+00, 0.20193900E-01, -.83453800E+00, -.17570300E+04, 0.10516600E+04, -.53924400E+03, -.28059000E+03, -.52587100E+03, 0.94129300E+03, 0.11914900E+04, -.78367700E+02, 0.94240700E+03, 0.23155800E+03, 0.10676900E+04, -.17382400E+04, 0.89325700E+04, -.44085300E+04, -.23147500E+04, -.44657800E+04, 0.25071200E+03, 0.24971900E+04, -.73380300E+03, 0.32654600E+04, -.27483400E+04, 0.14692700E+04, -.43219000E+04, 0.21965100E+03, -.41306300E+02, 0.17947500E+04, -.10967700E+03, -.70794800E+03, -.90739300E+03, -.90348700E+03, -.24925100E+04, -.62699700E+03, -.76769400E+03, 0.39974800E+03, -.68284700E+04, 0.34864900E+04, 0.25468200E+04, 0.34160100E+04, 0.12959800E+04, 0.27350300E+04, -.36709900E+03, -.11277200E+04, 0.83018900E+03, 0.24118900E+04, 0.90979900E+04, 0.35642000E+04, -.18074000E+04, -.28530400E+03, -.17814100E+04, 0.26297800E+03, 0.75529500E+03, -.10233900E+04, -.68083600E+02, -.14147400E+04, 0.92816000E+03, -.34363000E+04, -.31743200E+03, 0.16240800E+03, -.17193700E+03, 0.15866100E+03, -.51028900E+02, -.12601700E+03, -.30840000E+02, -.17367500E+03, 0.71352000E+01, -.66227500E+02, 0.44932700E+03, 0.46750800E+04, -.23545600E+04, 0.65331500E+04, -.23362800E+04, -.15643700E+04, -.54668300E+03, 0.84441900E+03, 0.14989400E+04, -.10831900E+04, -.24690400E+03, -.39677900E+02, -.71912600E+04, 0.36314200E+04, 0.15428500E+04, 0.35957300E+04, 0.97460000E+03, -.14388400E+04, 0.10762000E+04, -.81483200E+03, 0.48673500E+04, -.96554900E+03, 0.34576000E+04, -.53746100E+03, 0.35597900E+03, 0.17100900E+04, 0.26900600E+03, -.12219100E+04, -.70692900E+03, 0.11679600E+03, -.54996300E+03, 0.25872100E+03, -.92381200E+03, 0.13346200E+04, -.13340800E+05, 0.66151300E+04, 0.91064600E+03, 0.66658200E+04, -.12798400E+04, -.38017000E+04, 0.33980700E+04, -.22587100E+04, 0.56704800E+04, -.26379700E+04, 0.76795300E+04, -.10171300E+04, 0.54428800E+03, -.41735400E+04, 0.50776900E+03, -.53983900E+03, -.78303000E+03, 0.26127500E+03, -.46055800E+03, 0.11880600E+04, -.11027700E+04, -.78037100E+03, -.58731500E+04, 0.29317200E+04, -.14951800E+04, 0.29356600E+04, 0.10497000E+04, -.34741500E+03, 0.12889700E+04, -.37475700E+03, 0.31526100E+04, -.97327300E+02, 0.31101600E+04, -.19426600E+03, 0.13020900E+03, -.14175200E+04, 0.96469500E+02, -.20087400E+03, -.34616400E+03, 0.56404800E+03, 0.91976000E+03, -.38162900E+03, -.74442600E+03, 0.80321100E+03, -.59712300E+04, 0.29794400E+04, 0.59158400E+03, 0.29860300E+04, 0.10809900E+04, 0.12236400E+04, 0.19043800E+04, 0.56326500E+03, 0.68323600E+03, 0.10793000E+04, 0.21198200E+04, -.49505800E+04, 0.25828900E+04, 0.54887000E+04, 0.24795600E+04, 0.47792700E+03, 0.22748500E+04, 0.48766200E+03, -.43866000E+03, 0.70725600E+03, 0.21055400E+04, 0.99941500E+04, -.76179200E+04, 0.38070300E+04, -.17351200E+04, 0.38094500E+04, 0.17651700E+04, 0.28123200E+04, 0.32521600E+04, 0.26517200E+04, 0.87237000E+03, 0.21988500E+04, 0.40847300E+04, 0.27610300E+03, -.17636400E+03, 0.74210600E+03, -.13794500E+03, 0.47032400E+03, 0.27711400E+03, 0.20797500E+03, 0.80680500E+03, 0.11330800E+04, 0.27222100E+03, -.15507900E+04, 0.10561200E+04, -.56222300E+03, 0.38070900E+03, -.52744600E+03, 0.25202900E+03, 0.71385600E+02, -.37690800E+03, -.80236900E+03, -.68170000E+02, 0.45606100E+03, -.89233800E+03, 0.73153300E+02, 0.24264400E+03, 0.48878900E+02, -.37339500E+02, 0.70412200E+03, -.51873200E+03, 0.11349600E+03, 0.18769300E+03, 0.13025100E+03, 0.13055500E+03, -.11245400E+03, -.10203500E+03, 0.37414900E+03, 0.16689600E+03, -.19892500E+03, -.64747300E+03, 0.10288100E+03, -.93497700E+02, -.94051000E+03, -.18446400E+02, 0.15252900E+03, 0.11575900E+04, -.17504200E+03, -.75827100E+03, -.12092800E+03, -.64702100E+03 },
        { 0.18760000E+01, -.31124700E+00, -.13119300E+00, -.10476300E+01, -.26141000E+00, 0.37745000E+01, 0.12493000E+00, 0.10194600E+01, 0.83940800E+00, -.10795600E+01, -.14840100E-01, 0.47091500E-01, 0.46421300E+00, 0.40952900E+00, -.55527400E+00, -.38912400E+00, 0.60332900E-01, -.45059800E+00, -.16179900E+00, -.10903100E+01, -.81658300E-01, 0.74186800E-01, -.71941900E-01, 0.10805000E+00, -.59793200E+00, -.48912900E-01, -.60149100E+00, -.76119200E+00, 0.15174800E+01, -.10712000E+01, 0.15921600E+00, 0.41114800E+00, -.21624300E+00, -.32601500E+00, -.19026600E+00, 0.37365400E+00, -.35946400E-02, -.38674700E+00, 0.63566500E-01, 0.21934000E+00, -.11347800E+00, -.16745200E+00, -.11365700E+01, -.27602300E+00, 0.35363500E-01, -.31089900E-01, -.50693100E+00, 0.28590000E-01, 0.39309800E-01, 0.25347300E+00, -.16990000E+01, 0.13893500E+00, 0.33802100E+00, 0.49266500E+00, 0.27560200E+00, 0.95305200E-01, 0.44222000E+00, 0.19921400E+00, 0.12315900E+00, -.10629800E+00, -.43074700E+00, 0.85565200E+00, 0.70240000E+00, 0.59421500E+00, 0.76957300E-01, 0.51095500E-01, -.22859000E+00, 0.22652700E+00, 0.89883700E-01, 0.49658800E-01, 0.12654900E+00, -.16234200E+00, -.22908200E+00, 0.26519200E+00, 0.33224400E+00, 0.32933000E+00, 0.49304300E-01, 0.29748000E+04, -.14788400E+04, -.26649200E+04, -.14880800E+04, -.78289000E+03, -.12592400E+03, 0.92996000E+02, 0.91810800E+03, -.62756200E+03, -.57084800E+03, -.83642700E+03, 0.58049800E+03, -.27587000E+03, -.29365800E+04, -.29033900E+03, 0.20501300E+03, -.42070100E+03, -.14763100E+03, 0.28108600E+03, -.67679900E+03, -.14595000E+03, -.17085100E+03, -.15192500E+04, 0.77348700E+03, 0.14213000E+04, 0.76033400E+03, 0.42596400E+03, -.52209600E+02, 0.19974600E+03, -.87415700E+03, 0.92116400E+02, 0.97995700E+02, -.23230100E+03, -.21306400E+04, 0.92596100E+03, -.29904600E+04, 0.10704400E+04, -.10530000E+04, -.17920500E+04, 0.41232500E+03, 0.25883500E+03, 0.20806100E+04, -.19072700E+04, -.19125200E+03, 0.12062800E+04, -.59775900E+03, -.39507300E+03, -.60233700E+03, -.40959400E+03, -.55558500E+03, 0.34147700E+03, 0.50256800E+03, -.25761600E+03, -.82373200E+03, -.26603300E+03, 0.14852000E+02, -.75844500E+01, 0.59419100E+01, -.74496700E+01, 0.63729600E+02, 0.33017600E+02, -.70430000E+02, -.57265300E+02, -.61813500E+02, 0.78884300E+02, -.25922500E+02, 0.27548400E+04, -.13663800E+04, -.35923300E+03, -.13745300E+04, -.14137300E+04, -.75763000E+03, -.10142700E+04, 0.77057400E+03, 0.23569100E+03, -.11902100E+04, -.24366500E+04, 0.36601000E+04, -.18490400E+04, -.66964200E+03, -.18297800E+04, -.11393800E+04, 0.22569300E+03, 0.32178700E+03, 0.74505500E+03, -.71976600E+03, -.54245300E+03, -.28916300E+04, -.66558200E+01, -.31726100E+02, -.11708600E+04, 0.43492700E+01, 0.26460300E+03, 0.38038700E+03, 0.49393400E+03, 0.35455100E+03, -.17386500E+03, 0.20695300E+03, -.43191600E+03, 0.15677800E+04, -.79051800E+03, 0.96470700E+03, -.78323400E+03, -.46746600E+03, 0.47937400E+03, -.52034800E+03, 0.45949500E+03, 0.38917300E+03, -.25099400E+03, -.80479200E+03, -.33777200E+04, 0.16310400E+04, -.87313900E+03, 0.16867100E+04, 0.93325700E+03, 0.47893900E+03, 0.12104600E+04, -.18338200E+02, 0.98588100E+03, 0.61581700E+03, 0.14971400E+04, 0.42529000E+04, -.21387300E+04, -.12222400E+04, -.21275800E+04, -.10986700E+04, 0.76839700E+03, -.11184700E+04, 0.66056800E+03, -.13607600E+04, 0.33964500E+03, -.15898400E+04, -.12221200E+04, 0.61297300E+03, 0.49200100E+03, 0.61011900E+03, 0.17508800E+03, 0.58249600E+03, -.18461500E+03, -.46390900E+03, -.65413200E+03, 0.63955900E+03, 0.10973600E+04, 0.49352900E+04, -.24633900E+04, -.35568000E+04, -.24671900E+04, -.36686100E+03, -.66806800E+03, -.53857100E+03, 0.22736500E+04, -.58360600E+03, -.76860700E+03, -.15240000E+04, -.15997400E+04, 0.62727800E+03, -.43244600E+04, 0.81129900E+03, -.18486700E+04, -.24465400E+04, 0.12929500E+03, 0.90983000E+03, 0.29493700E+04, -.28664000E+04, -.15876600E+04, 0.66017500E+04, -.32975600E+04, -.77334200E+04, -.33009800E+04, -.69756800E+03, -.66412900E+03, -.89826900E+03, 0.35921000E+04, -.71443200E+03, -.10495900E+04, -.11350500E+04, -.12991600E+03, 0.66486100E+02, -.89850700E+03, 0.65310500E+02, -.63686900E+03, -.22623800E+03, 0.80223000E+03, 0.55246800E+03, 0.72915400E+03, -.55826000E+03, 0.26614000E+03, 0.10807300E+04, -.53662200E+03, -.85236900E+02, -.53947200E+03, -.41604600E+03, -.99137600E+02, 0.74392600E+02, 0.32740200E+03, 0.21643600E+03, -.50802400E+03, -.73850800E+03, 0.49464700E+02, 0.69240500E+02, 0.17245500E+03, -.15582100E+03, -.25435400E+03, 0.30859700E+03, 0.13841300E+03, 0.52150900E+02, 0.24093400E+03, -.24796700E+03, 0.12930100E+03, 0.52337300E+03, 0.10805900E+03, -.10001600E+03, 0.36580400E+03, -.10709700E+03, -.20774600E+03, -.22423700E+03, 0.48977500E+01, 0.17762600E+03, -.14851800E+03, 0.37344900E+03, -.52736900E+03, -.15520500E+03, -.13684200E+03, 0.13221600E+03 },
        { -.26231900E+01, 0.67643700E+00, 0.17889700E+00, 0.13247000E+01, 0.53204700E+00, -.62041800E+01, 0.16766100E+00, -.49508900E+01, -.90983500E+00, 0.19113700E+01, 0.30785800E+00, 0.19725900E-01, -.95480300E+00, -.13917300E+01, 0.35282000E-01, -.70639700E+00, 0.14331500E+01, 0.80024800E+00, -.18687200E+00, 0.93432600E+00, 0.26539500E+00, -.24587200E+00, 0.66353400E-03, -.22202900E+00, 0.30914300E+01, 0.39975000E-01, 0.68725900E+00, 0.11267900E+01, -.17987700E+01, 0.55397100E+00, -.15503100E+00, -.10092900E+01, 0.96337800E+00, 0.11516300E+01, 0.35852700E+00, -.45953900E+00, 0.12973200E+00, 0.38869400E+00, -.72509600E+00, -.97803400E+01, 0.36780000E+00, 0.94234000E-02, 0.17434500E+01, 0.74502200E+00, -.16415000E+00, -.92479400E-01, 0.82274300E+00, -.58820300E-01, -.25808300E+00, -.22278500E+00, -.48958100E+00, 0.26457600E+00, 0.12145500E-01, 0.21906200E+00, -.98299000E+00, -.17335700E+00, -.69766900E+00, 0.57632600E-01, -.23341600E+00, -.40755300E+00, 0.38775000E+00, -.10696400E+01, -.18060900E+00, -.60589800E-02, 0.20860500E-01, 0.31133000E+00, 0.18373000E+01, -.32260200E+00, 0.22060500E+00, -.15568200E+00, -.84293200E-01, 0.12021500E+00, -.11439800E+01, -.23016900E+00, -.54595400E+00, 0.79556500E+00, -.74265000E+00, 0.96376300E+00, -.37424800E+02, 0.34051400E+04, 0.33457900E+00, 0.21208200E+04, 0.23830500E+04, -.80730300E+03, 0.24422000E+03, 0.40752100E+03, 0.21704600E+04, 0.27282700E+04, 0.13121500E+05, -.64968900E+04, -.12048200E+04, -.65621000E+04, -.36505600E+03, 0.30434200E+04, -.60595800E+03, 0.48960100E+04, -.28963200E+04, 0.16496400E+04, -.70475800E+04, 0.30972900E+04, -.14613500E+04, -.11934600E+04, -.15493000E+04, -.11245000E+04, -.22165000E+04, -.16699000E+04, -.33072900E+04, -.10801800E+03, -.19430000E+04, -.30615300E+04, -.94708800E+04, 0.50454300E+04, 0.75358500E+04, 0.47271100E+04, 0.34540300E+04, 0.59443600E+04, -.20293300E+04, -.57600100E+04, -.21556800E+04, 0.58529800E+04, 0.12106400E+05, -.57641100E+03, 0.20600100E+03, 0.50260700E+04, 0.28577200E+03, 0.28269600E+03, 0.15164400E+04, -.37585500E+03, 0.75382900E+02, 0.42596800E+03, 0.17700400E+04, 0.64008300E+02, -.31964600E+03, 0.16907000E+03, -.52342000E+03, 0.16000900E+03, -.16302600E+03, -.24897900E+03, 0.54168500E+02, -.10644100E+03, 0.15243600E+02, -.20550800E+03, -.50521800E+02, 0.33705000E+04, -.22630300E+04, 0.10392300E+05, -.16898200E+04, 0.75166200E+03, 0.38613200E+04, -.18027500E+04, -.36941900E+04, -.43352000E+04, 0.43809700E+04, 0.44253800E+04, -.14749900E+05, 0.75473000E+04, 0.36666700E+04, 0.73744400E+04, 0.84898600E+03, -.30326600E+04, 0.71398800E+03, -.35297900E+04, 0.75861100E+04, -.14516400E+04, 0.10828400E+05, -.35932700E+04, 0.20030000E+04, 0.31771100E+04, 0.17960500E+04, -.34078200E+04, -.38890500E+04, 0.39122600E+03, -.26908500E+04, 0.16145800E+04, -.34214800E+04, 0.48566900E+04, -.17635900E+05, 0.87291400E+04, -.59886000E+04, 0.88207000E+04, -.10302800E+04, -.48725000E+04, 0.45076000E+04, -.31042500E+04, 0.72302300E+04, -.28809000E+04, 0.14935500E+05, 0.93637500E+03, -.15875800E+03, -.40702400E+04, -.46471100E+03, -.35081800E+04, -.49223700E+04, 0.16957300E+04, 0.18683800E+04, 0.21453500E+04, -.49212800E+04, -.34617100E+04, -.10845200E+05, 0.54725100E+04, -.25613300E+04, 0.54255200E+04, 0.12624700E+04, -.18870700E+04, 0.27598400E+04, -.13732200E+04, 0.53793600E+04, -.91650200E+03, 0.38349300E+04, 0.15577600E+04, -.68924600E+03, -.25021100E+04, -.77652000E+03, -.44938800E+03, -.91453600E+03, 0.53799300E+03, 0.10403300E+04, -.11048500E+02, -.13362400E+04, -.92353500E+03, -.18651000E+05, 0.92990900E+04, 0.50700400E+04, 0.93240200E+04, 0.23828800E+04, 0.41138500E+04, 0.31680700E+04, -.35156700E+04, 0.14670200E+04, 0.38686800E+04, 0.12111600E+05, -.85287000E+04, 0.44887700E+04, 0.14306500E+05, 0.42459800E+04, 0.38754700E+04, 0.82264900E+04, -.28458900E+04, -.83563100E+04, -.50433600E+04, 0.84326800E+04, 0.15801800E+05, -.21377100E+05, 0.10677200E+05, 0.38725800E+04, 0.10687000E+05, 0.34534100E+04, 0.76922000E+04, 0.48211700E+04, -.15267600E+04, 0.61799000E+03, 0.68833900E+04, 0.19170100E+05, 0.39452700E+03, -.22085800E+03, 0.35772400E+04, -.19824400E+03, 0.10445000E+04, 0.56725600E+03, -.90395700E+03, 0.12807100E+02, 0.14182800E+04, 0.71411600E+03, 0.18923700E+04, -.65992800E+02, -.76480800E+02, 0.24277200E+04, 0.30764300E+02, -.16645900E+02, -.18068800E+03, -.15037800E+03, -.77381700E+03, 0.38256600E+03, 0.58894400E+03, 0.21169700E+04, 0.34655600E+02, 0.17303500E+03, -.32159100E+03, 0.30544600E+03, 0.14641800E+04, -.11136800E+04, -.18571500E+03, 0.99975900E+02, 0.16871700E+03, 0.51683100E+03, -.35176200E+03, -.63285900E+03, 0.43264700E+03, 0.28816300E+03, -.62769000E+03, -.11446400E+04, 0.54866600E+03, 0.34440100E+03, -.16274600E+04, -.39787100E+03, 0.20054500E+03, 0.19418600E+04, 0.14957600E+03, -.12400000E+04, 0.30709200E+03, -.13398300E+04 },
        { -.14859000E+01, -.73796900E+00, -.40780200E-02, -.98010500E+00, -.16466300E+01, 0.39983600E+00, -.45817100E+00, 0.22301200E+00, -.42081000E+00, 0.86313900E+00, 0.48940900E-01, -.11114800E+00, 0.15008900E+01, -.12703300E+01, 0.11836100E+01, 0.21533200E+00, -.69869000E+00, 0.41062500E+00, 0.62997700E-02, -.14162800E+00, 0.64930600E+00, -.34372000E-01, 0.46543000E-01, -.12456900E+00, 0.89834800E+00, 0.88638700E-02, -.29973400E+00, 0.20657600E+00, -.73091100E+00, 0.36814500E-01, 0.78041000E-01, -.90430300E-01, 0.71696200E+00, 0.18288000E+00, 0.61033000E-01, -.24199100E+00, 0.22704100E-01, 0.66857300E+00, -.37560000E+00, 0.54367900E+01, -.23547500E-01, 0.90377200E-02, 0.30395900E+00, -.22389200E+00, 0.15215300E+00, 0.86072900E-01, -.14488100E+00, 0.11608200E-01, -.48198400E-01, 0.39372700E-01, -.30389900E+00, 0.30204400E+00, 0.10368300E+00, 0.35401800E+00, 0.18148400E+00, -.16456500E+00, 0.23555100E+00, -.81206300E-01, 0.43518400E-01, -.41506100E+00, 0.12333400E-01, -.38827800E+00, -.31329000E+00, 0.20041400E+00, 0.18798000E+00, -.16946900E-01, 0.25677000E-01, 0.30210500E-01, -.56594500E-01, -.16495600E-01, 0.26782300E+00, 0.17175100E+00, -.41758700E+00, -.25484700E+00, -.44169500E+00, 0.30488700E+00, 0.22258300E-01, -.40277400E+00, -.33568300E+00, 0.14805500E+04, -.46319700E+00, 0.68203400E+03, 0.35418100E+03, -.32989200E+03, -.19203000E+03, 0.94497400E+01, 0.42441300E+03, 0.86453200E+03, 0.30784800E+04, -.15199200E+04, -.25231700E+03, -.15399900E+04, 0.22937800E+02, 0.98307700E+03, -.79816800E+03, 0.79887200E+03, -.12753700E+04, 0.65254900E+03, -.19024000E+04, 0.19301700E+03, -.70387700E+02, -.16168300E+04, -.96187200E+02, -.14354700E+03, -.49518600E+03, -.10135000E+03, -.96451500E+03, 0.82769400E+02, -.41352800E+03, -.91925200E+03, -.26789300E+04, 0.12577200E+04, -.11439300E+04, 0.13400500E+04, 0.55729100E+02, 0.26061200E+03, -.12317800E+04, -.21318100E+04, 0.94789700E+03, 0.36419100E+03, 0.37286800E+04, 0.12858200E+03, -.89909700E+02, 0.21730200E+04, -.64768900E+02, -.32359800E+03, 0.17428800E+03, 0.14483400E+03, 0.14379500E+03, 0.37161900E+03, 0.21199200E+03, -.34671200E+03, -.11570200E+03, 0.60794400E+02, -.20460600E+03, 0.57922100E+02, -.27604900E+02, -.32746500E+02, 0.39628400E+02, 0.12938500E+01, 0.27881400E+02, -.42392800E+02, -.12519300E+02, 0.56632000E+04, -.32261800E+04, 0.11140200E+04, -.28312500E+04, -.87549200E+03, 0.12170700E+04, -.33470700E+04, -.22313500E+04, -.22751200E+04, 0.13295500E+04, -.92615300E+03, -.30598300E+04, 0.15924600E+04, 0.16456100E+04, 0.15299100E+04, -.85522600E+02, -.71707500E+02, -.72056800E+03, -.18513700E+04, 0.10054400E+04, 0.58725800E+03, 0.27451200E+04, -.21873300E+04, 0.11136700E+04, -.93110100E+01, 0.10944800E+04, -.13967300E+04, -.18827600E+04, 0.61981600E+03, -.86047900E+03, 0.67329200E+03, -.14026700E+04, 0.22745700E+04, -.39391600E+04, 0.19467700E+04, -.33869600E+04, 0.19713500E+04, -.52152300E+02, -.98263700E+03, 0.93070600E+03, -.86355400E+03, 0.13802500E+04, -.39849600E+03, 0.41956800E+04, -.45154300E+04, 0.23676600E+04, -.18965400E+03, 0.22574700E+04, -.91705200E+02, -.12964200E+04, 0.20757100E+04, 0.83686100E+03, 0.13875300E+04, -.10605100E+04, 0.95185400E+03, -.25536900E+04, 0.12949400E+04, 0.12418200E+03, 0.12772600E+04, -.21365100E+02, -.47380600E+03, 0.38467900E+03, -.50039000E+03, 0.94379000E+03, -.48141200E+02, 0.76682800E+03, -.13099400E+04, 0.69152400E+03, 0.35745200E+03, 0.65528500E+03, 0.38318200E+03, 0.57039600E+03, -.37323600E+03, -.68327300E+03, -.44551200E+03, 0.42317100E+03, 0.55346400E+03, -.30764700E+04, 0.15319400E+04, 0.49736400E+03, 0.15379300E+04, 0.57511900E+03, 0.11482800E+04, 0.37035300E+02, -.73871100E+03, 0.33103000E+02, 0.96697900E+03, 0.30757900E+04, -.13666900E+04, 0.44290900E+03, -.36619800E+03, 0.68471500E+03, -.39407400E+02, 0.12044000E+04, -.31632600E+04, -.36952600E+04, -.18162500E+02, 0.14172800E+04, 0.40116200E+04, -.31079700E+04, 0.15543000E+04, -.46193100E+02, 0.15531400E+04, 0.88107300E+03, 0.22626400E+04, -.57223700E+03, -.65974800E+03, -.76516300E+03, 0.19894300E+04, 0.53308900E+04, 0.62769800E+03, -.29275000E+03, 0.13973800E+04, -.31401500E+03, 0.10681700E+03, 0.13206000E+03, -.42080400E+03, -.48108600E+03, -.13167200E+03, 0.25567000E+03, 0.49683200E+03, 0.11693800E+04, -.62464300E+03, 0.37038100E+03, -.58498600E+03, -.56873300E+03, -.53561000E+03, 0.30918400E+03, 0.33065900E+03, 0.30750500E+03, -.31886300E+03, 0.73985600E+02, 0.80426400E+02, 0.15841900E+03, -.44128700E+02, -.16864600E+02, 0.35302500E+03, -.18554000E+03, 0.50018600E+02, 0.86863700E+02, -.14273600E+03, 0.44232300E+02, -.59144800E+01, 0.53280300E+03, 0.11497100E+03, 0.26249200E+02, 0.15644800E+03, -.11075000E+03, -.89282900E+02, 0.34343800E+02, -.41030600E+03, 0.62234400E+02, -.69866800E+02, 0.59970600E+03, -.59959100E+03, -.27010700E+03, 0.10723000E+03, -.39109000E+03 },
        { -.73858500E+01, 0.14990200E+01, 0.31706100E+00, -.41959200E+01, -.53229600E+01, 0.96574700E+01, -.99697600E+01, 0.11553600E+02, -.46370800E+01, 0.62366400E+01, 0.98663800E-01, -.46957800E+00, 0.18062400E+01, 0.42408000E+01, 0.23411300E+00, 0.24421600E+01, -.25355100E+01, 0.57584500E-02, 0.35905200E+00, -.27240500E+00, 0.63697300E+00, 0.22214500E+00, -.14203600E+00, 0.26623500E+00, -.26224100E+01, 0.53365300E+00, -.22584900E+01, -.20844200E+01, 0.14923900E+01, -.69632000E+00, 0.77093500E+00, -.13685600E+01, -.48360300E+00, 0.12020800E+01, -.41455500E-01, -.12096500E-01, -.14794400E+01, -.13816300E+01, -.15086500E+01, -.15892200E+02, -.12716800E+00, -.54799500E+00, 0.97766800E+00, 0.65918500E-01, -.75198400E+00, -.35387100E+00, -.24478300E+00, -.13680000E-01, 0.34146100E+00, -.51288500E-01, -.15928500E+01, 0.84992200E+00, 0.49297200E+00, 0.13582600E+01, 0.11117300E+01, -.68404600E+00, 0.26729900E+00, -.31380200E+00, 0.14934000E+00, -.72756700E+00, 0.11774000E+01, 0.13083000E+01, 0.19813800E+00, 0.76473800E+00, -.99911400E+00, 0.50398700E-01, -.99892100E-01, 0.11375500E+00, -.54553700E+00, 0.20770700E+00, -.82048600E-01, 0.79480100E-01, -.83761500E+00, -.49667000E+00, -.92805800E+00, 0.43526100E+00, 0.13660100E+00, -.11634600E+01, -.14779400E+00, -.71505000E+00, 0.95545900E+01, -.16145500E+03, -.64469800E+03, -.86211300E+01, -.70942000E+03, -.14616800E+03, -.35536200E+03, 0.46109800E+02, 0.15290900E+04, -.67844100E+03, -.12133800E+04, -.76172900E+03, -.23734300E+03, 0.42433800E+03, -.15764200E+04, -.48487000E+03, -.19694600E+04, 0.51858300E+03, -.26106600E+03, -.26913400E+04, 0.14412500E+04, -.78830800E+03, 0.13454200E+04, 0.88163600E+03, 0.68799200E+03, 0.11200200E+04, 0.98021600E+02, 0.10814300E+04, 0.67755800E+03, -.23212600E+03, -.20408600E+05, 0.10051800E+05, -.22856100E+04, 0.10209400E+05, 0.13177200E+04, 0.21896200E+04, 0.80992400E+02, -.28270500E+04, 0.93016400E+04, 0.12759100E+04, 0.92491000E+04, 0.13530100E+04, -.70729200E+03, 0.94322500E+03, -.67350100E+03, -.77471900E+03, -.13046500E+04, 0.99247000E+03, 0.84752800E+03, 0.56221100E+03, -.11645600E+04, -.13384700E+04, -.40708200E+03, 0.20846900E+03, 0.23661400E+01, 0.20323000E+03, 0.55696200E+02, 0.12144500E+03, 0.55201300E+02, 0.41556900E+02, 0.13170300E+03, 0.77096800E+02, 0.21722900E+03, 0.32810900E+04, -.19254700E+04, 0.41651700E+03, -.16378200E+04, -.29875400E+04, 0.27674800E+04, -.54156200E+04, -.27496700E+04, 0.25388200E+03, 0.20324200E+04, -.24055000E+04, 0.20841000E+04, -.99380000E+03, 0.87791600E+03, -.10416400E+04, -.73769700E+03, 0.57629600E+03, -.99416800E+03, -.13868600E+04, -.12130000E+04, 0.66552600E+03, -.23957800E+04, -.19320200E+04, 0.10115200E+04, -.14434300E+04, 0.96809000E+03, -.78818100E+03, -.14511200E+04, 0.11803200E+04, -.51403400E+03, -.11534900E+03, -.92245500E+03, 0.10153900E+04, -.28899800E+03, 0.68580200E+02, -.75652100E+03, 0.14889000E+03, 0.28350900E+03, -.11416200E+03, -.23364200E+03, -.49310900E+03, 0.19205300E+03, 0.19360900E+03, -.13093800E+04, -.10408200E+05, 0.52373100E+04, -.19270700E+04, 0.52019700E+04, 0.22652400E+04, -.85809000E+03, 0.44708000E+04, 0.10108500E+04, 0.26071500E+04, -.43413700E+03, 0.44342200E+04, 0.72533300E+03, -.37128500E+03, 0.37156600E+03, -.36589900E+03, -.52760900E+03, 0.78796100E+03, -.85266400E+03, -.15589500E+03, -.97067900E+03, 0.69510300E+03, -.39370400E+03, -.59294500E+04, 0.30266000E+04, 0.25806100E+04, 0.29621600E+04, 0.13097200E+04, 0.16709200E+04, -.10288700E+04, -.28604600E+04, -.90722700E+03, 0.18378400E+04, 0.28430000E+04, 0.55246700E+04, -.27667300E+04, -.28217500E+04, -.27604800E+04, -.44696800E+03, -.40886100E+03, -.23864400E+04, 0.51502000E+01, -.17708400E+04, -.50822600E+03, -.87155200E+03, -.26465000E+05, 0.12960000E+05, -.27680700E+04, 0.13243500E+05, 0.10319800E+04, 0.45512000E+04, -.21463600E+04, -.46869900E+04, 0.12367800E+05, 0.30456100E+04, 0.10716000E+05, 0.67495700E+04, -.33712100E+04, -.47790500E+04, -.33716300E+04, -.71925300E+03, -.78013200E+03, -.46710200E+04, -.12449500E+04, -.33668000E+04, -.44345400E+03, -.65323000E+03, 0.18636200E+04, -.94773800E+03, -.77858400E+02, -.93066700E+03, -.10456500E+04, -.87877900E+03, 0.10714000E+02, -.91356500E+03, -.50292000E+03, -.62463900E+03, -.10447400E+04, 0.30584200E+04, -.15821500E+04, -.39030600E+03, -.15267900E+04, -.17372400E+04, -.17670800E+04, 0.12972700E+04, 0.18305800E+04, 0.11194900E+04, -.18004900E+04, -.21192400E+04, 0.54012300E+03, 0.58211900E+03, 0.22388900E+03, -.44183100E+03, -.24252800E+03, 0.41878400E+03, 0.34123400E+03, 0.32440400E+03, -.45205500E+03, -.45174900E+03, 0.29956700E+03, 0.14556500E+04, 0.22813500E+02, -.16307400E+03, 0.13995400E+04, 0.29233700E+03, -.77321200E+03, -.44141700E+03, -.67344500E+02, 0.37211900E+03, -.22822200E+03, -.20720400E+03, -.21499100E+04, 0.41527000E+03, -.13060000E+03, -.49357300E+02 },
        { -.49235400E+01, 0.49268600E+01, 0.59466800E+00, 0.12631100E+01, -.20836200E+01, -.18131200E+01, -.20467800E+01, -.28241400E+01, -.19334000E+01, 0.27889600E+01, 0.41093000E+00, -.27959400E+00, 0.93001800E+00, -.71450100E+00, -.10738400E+01, 0.88724100E+00, -.50067900E+00, 0.40050300E-01, 0.55702600E+00, -.97441900E+00, 0.71010900E+00, 0.13865800E+00, -.41926100E-01, -.53819000E+00, 0.37156400E+01, 0.10510400E+00, 0.33407700E+00, 0.68051300E+00, -.11756600E+01, -.55370300E+00, 0.49586300E+00, -.84148500E+00, 0.13297000E+01, 0.71674700E-01, 0.27602900E+00, -.57388200E+00, -.10089000E+00, 0.80399400E+00, -.14753100E+01, 0.70592600E+01, 0.20012000E+00, -.57278900E-01, 0.87104100E+00, 0.12394200E+01, -.41389500E+00, 0.28394500E+00, -.18622800E+00, 0.16913600E-01, -.81418200E-01, -.73720000E-01, 0.75860900E+00, 0.27951000E+00, 0.31087800E+00, 0.43419000E+00, 0.82278500E+00, -.68824900E+00, 0.39098000E+00, 0.19881000E+00, 0.58824600E-01, -.10832300E+01, 0.65792200E+00, 0.17111900E+01, 0.68903900E+00, -.16773900E+01, -.13874600E+01, -.36081500E+00, -.88163900E-01, -.54629500E-01, -.43050000E+00, -.11591600E+00, -.11202600E+01, 0.67842200E+00, -.39760800E+00, -.66869900E+00, -.10897900E+01, 0.14315700E+00, -.42058800E+00, -.18852700E+01, -.56664500E+00, 0.22441400E+00, -.29843200E+00, 0.13418400E+04, 0.11040900E+04, -.41312100E+02, 0.29574700E+03, -.13072700E+03, 0.71800000E+03, 0.81509600E+02, 0.47707100E+04, -.23349300E+04, -.28357900E+04, -.23868100E+04, -.52901200E+03, -.27887100E+03, 0.19966200E+03, 0.21148100E+04, -.15911800E+04, -.24238500E+03, -.49957500E+04, 0.21245500E+04, -.99943700E+03, -.11172900E+04, -.10598500E+04, -.39499700E+03, -.83207700E+03, -.45940300E+03, -.57309900E+03, 0.36862000E+03, -.53558800E+03, -.69546000E+03, -.14281800E+05, 0.69901900E+04, -.17160400E+04, 0.71543300E+04, 0.23283300E+04, 0.15735100E+04, -.49955800E+03, -.54015500E+04, 0.30217900E+04, 0.17055800E+04, 0.82357500E+04, 0.33405800E+04, -.17017500E+04, 0.15103400E+04, -.16690900E+04, -.42781700E+03, -.14125800E+03, -.70417500E+03, 0.25171800E+02, -.90402100E+03, -.33967100E+03, -.20769700E+04, 0.13727400E+02, -.27327900E+01, -.39539100E+03, -.67927700E+01, -.30635800E+02, -.40189700E+02, -.28299200E+02, -.58935400E+02, -.68077800E+02, 0.26405100E+02, 0.13288600E+03, 0.10335900E+05, -.55431700E+04, 0.87521800E+04, -.51596600E+04, -.13687100E+04, 0.38738200E+03, -.42016500E+04, -.29414000E+04, -.48951800E+04, 0.63680400E+03, -.66913300E+04, -.67564000E+04, 0.34411700E+04, 0.22298600E+04, 0.33788100E+04, -.30095700E+03, -.10393200E+04, 0.32481600E+03, -.21718100E+04, 0.34606700E+04, -.15321100E+04, 0.10099100E+05, -.23971400E+04, 0.12473000E+04, 0.81420900E+03, 0.12019100E+04, -.25994500E+04, -.20680900E+04, 0.91087400E+03, -.13248200E+04, 0.54375700E+03, -.22965100E+04, 0.51296400E+04, 0.15027900E+03, -.12230500E+03, -.25932800E+04, -.72087600E+02, -.88684700E+03, -.16172100E+03, -.20871700E+03, 0.11459700E+03, 0.16498300E+04, -.59882600E+03, 0.53863700E+04, -.92979200E+04, 0.47608300E+04, -.44228300E+04, 0.46431900E+04, -.14129700E+04, -.12433400E+04, 0.36613600E+04, 0.73263000E+03, 0.41016500E+04, -.15458900E+04, 0.45177600E+04, -.32164300E+04, 0.16127300E+04, -.30117400E+04, 0.16058500E+04, 0.79148000E+02, 0.30388500E+03, 0.48675500E+03, 0.21945600E+03, 0.19138800E+04, 0.15118000E+03, 0.40968500E+04, -.24739300E+04, 0.12792700E+04, -.22744900E+03, 0.12350900E+04, 0.33370500E+02, -.24640000E+02, 0.65922500E+03, 0.90423500E+00, -.56128200E+03, -.12427500E+03, -.25202900E+03, -.28771000E+04, 0.14343300E+04, -.13963400E+04, 0.14391600E+04, 0.12100800E+04, 0.10930900E+04, 0.94542400E+03, 0.14413800E+04, 0.48618900E+02, 0.93673400E+03, 0.93404800E+03, -.13682400E+05, 0.65230000E+04, 0.19845900E+04, 0.68721200E+04, 0.18478400E+04, 0.18271100E+04, -.18151000E+04, -.73392100E+04, 0.21110200E+04, 0.21011300E+04, 0.63773900E+04, -.23972100E+04, 0.12013100E+04, -.61438700E+04, 0.11968200E+04, 0.17673600E+04, 0.26783800E+04, 0.87155700E+03, 0.28874300E+04, -.15114800E+04, 0.18742500E+04, 0.74484200E+03, 0.65076400E+03, -.32319600E+03, 0.20122700E+04, -.32514100E+03, 0.14879200E+03, 0.11867500E+03, -.44287000E+03, -.14378600E+03, 0.83156600E+03, -.29038600E+03, 0.31322300E+03, 0.33851600E+04, -.17405200E+04, 0.84231000E+03, -.16908400E+04, -.80046800E+03, -.61454800E+03, -.29224300E+03, 0.26335700E+03, 0.23368900E+03, -.66815000E+03, 0.10430200E+04, -.26986200E+03, 0.35815500E+03, -.21227900E+03, 0.13488000E+02, 0.15062100E+03, 0.13545000E+03, 0.16284400E+03, 0.19251600E+03, 0.35208400E+02, -.27913800E+03, -.44028800E+02, -.62779200E+03, 0.26083900E+03, -.27690500E+02, -.40169700E+03, -.14626000E+04, 0.22575500E+03, 0.28303700E+01, -.21458100E+04, 0.36535200E+02, 0.80240000E+02, 0.11795900E+04, -.96225900E+02, -.53921800E+03, 0.18448400E+03, -.27762500E+03 },
        { 0.64589500E+00, -.54005300E+00, 0.77436500E-02, -.21803900E+00, -.28828300E+00, -.24346200E+01, 0.20180700E+01, -.99768300E+00, 0.89271100E+00, -.58283800E+00, -.64947000E-01, 0.20488300E+00, -.79042400E+00, 0.45300600E+00, 0.72557100E+00, 0.36839500E+00, 0.99427700E+00, 0.27101000E+00, -.47150000E+00, 0.10602000E+01, -.37409200E+00, -.71794700E-01, 0.76619100E-02, -.18473100E+00, 0.94498300E+00, -.78029500E-02, -.23174400E+00, 0.40770500E-01, -.16408700E+00, -.82540100E+00, 0.41312000E+00, -.42510900E+00, 0.47015200E+00, 0.34679100E+00, 0.26350100E+00, 0.14992400E+00, 0.74967600E-01, 0.32704400E+00, 0.55616600E+00, -.15855100E+00, 0.71909700E-01, -.20132300E+00, -.16338300E+00, -.35262600E+00, -.34227600E+00, -.11149900E+00, -.27642800E+00, -.19983300E-01, -.19907500E-01, 0.41696500E-01, -.83327600E+00, 0.28131200E+00, 0.26891100E+00, 0.43498700E+00, 0.31106700E+00, -.16440400E+00, 0.36047800E+00, 0.55588200E-01, -.31567900E-01, -.20107700E+00, 0.70352400E+00, 0.45107400E+00, -.24287500E-01, 0.53128100E+00, -.35480500E+00, -.18410500E-01, -.25787600E+00, -.11401500E+00, -.65242100E-01, -.11449700E-02, 0.20179100E+00, -.35834600E-01, -.41070500E-01, -.36741400E+00, -.52506800E-01, 0.55974600E+00, -.12640500E+00, -.31836600E+00, -.48795000E-01, 0.27707500E+00, -.69827000E-01, -.18411100E+00, -.45319400E+03, 0.16314900E+03, -.13396100E+03, -.23181200E+03, -.42546000E+03, -.60897800E+03, -.33635000E+04, 0.17259500E+04, -.13368100E+04, 0.16812200E+04, -.14807000E+03, -.70809400E+03, 0.67399400E+01, -.66150700E+03, 0.11763700E+04, -.29320400E+03, 0.11532800E+04, -.84485000E+03, 0.47467700E+03, -.47735900E+03, 0.42346000E+03, 0.49105300E+03, 0.21108700E+03, 0.51077800E+03, 0.19893100E+03, 0.24221300E+03, 0.30889600E+03, -.92760800E+03, -.62835400E+04, 0.30426200E+04, -.15496000E+04, 0.31481700E+04, -.27927500E+03, -.50909000E+02, 0.19230400E+03, -.22241700E+03, 0.48979900E+04, -.62684400E+03, 0.32110900E+04, 0.26195000E+04, -.13280000E+04, -.35437200E+03, -.13090700E+04, -.63061300E+03, -.43506100E+03, 0.42197000E+02, 0.55516600E+03, -.52989900E+03, -.65276800E+03, -.16611200E+04, -.13737600E+03, 0.71412800E+02, 0.26578200E+02, 0.68701400E+02, 0.64077900E+02, 0.87455100E+02, -.23683700E+02, -.39598900E+02, 0.46169300E+02, 0.82946200E+02, 0.12134900E+03, 0.39315800E+04, -.20914800E+04, 0.11197400E+04, -.19621100E+04, -.17581600E+04, 0.94163200E+01, -.23127500E+04, -.23856000E+03, 0.56270800E+03, -.54836000E+03, -.27483200E+04, 0.23130900E+04, -.11305000E+04, 0.36965900E+02, -.11562200E+04, -.73051800E+03, 0.26975900E+03, -.62394400E+03, -.83228200E+03, -.18987800E+04, 0.42773200E+02, -.61417100E+03, -.10691300E+04, 0.56019700E+03, -.13669500E+04, 0.53535900E+03, -.65337700E+03, -.78808200E+03, 0.79122700E+03, 0.11847200E+03, 0.11640300E+03, -.51968800E+03, 0.94581400E+03, 0.51189500E+04, -.25976200E+04, -.15611900E+04, -.25566800E+04, 0.71616500E+03, 0.15582600E+04, -.13666800E+04, 0.94003900E+03, -.24268900E+04, 0.95929200E+03, -.32487500E+04, -.40047200E+04, 0.20156700E+04, -.13142300E+04, 0.19996600E+04, 0.99134500E+03, 0.14099400E+03, 0.17119800E+04, 0.20695200E+03, -.33103400E+03, 0.52858800E+03, 0.16905300E+04, 0.14460800E+04, -.72774200E+03, 0.54053100E+03, -.72416000E+03, -.72350200E+03, 0.42183000E+03, -.80329800E+03, -.11262400E+03, -.10701900E+04, 0.27102500E+03, -.22351100E+03, -.30248600E+04, 0.15415000E+04, 0.15098700E+04, 0.15114800E+04, 0.62995100E+03, 0.76171400E+03, -.30879900E+03, -.86249000E+03, 0.57379000E+03, 0.84711300E+03, 0.61745500E+03, 0.28003300E+04, -.14015300E+04, -.23984000E+04, -.13998000E+04, 0.28240900E+02, -.12072400E+03, -.95827500E+03, 0.83960600E+03, -.72394700E+02, -.23239800E+03, -.79683500E+03, -.61189900E+04, 0.29037300E+04, -.13078000E+04, 0.30738800E+04, -.79820200E+03, 0.23479900E+03, -.95258200E+03, -.38030200E+03, 0.60401400E+04, -.67972500E+03, 0.19285400E+04, 0.39690000E+04, -.19810700E+04, -.53251700E+04, -.19851200E+04, 0.36909500E+02, 0.14800600E+02, -.21987700E+04, 0.91969300E+03, -.32337300E+03, -.19594600E+03, -.11866000E+04, 0.83225100E+03, -.42542700E+03, -.35578300E+03, -.41583200E+03, -.38780500E+03, -.44174900E+03, 0.24586600E+03, -.22272700E+03, -.93887300E+03, -.44326200E+03, -.73499700E+03, 0.24120400E+04, -.12340900E+04, -.77227800E+03, -.12051300E+04, -.89416000E+03, -.71329500E+03, 0.33586800E+03, 0.72343800E+03, -.56172600E+03, -.83410000E+03, -.12572000E+04, 0.21941700E+03, 0.23370700E+03, 0.24920200E+03, -.24862800E+03, -.26696200E+03, 0.35889400E+03, 0.22112700E+03, 0.13007300E+03, -.19875500E+03, -.16622000E+03, 0.20289100E+03, 0.83099200E+03, 0.16180300E+03, -.10117300E+03, 0.53170900E+03, 0.46324900E+00, -.46872900E+03, -.18385300E+03, 0.20638100E+02, 0.27601400E+03, 0.51513500E+02, 0.24697300E+03, -.87180300E+03, 0.60202200E+02, 0.35698600E+02, 0.13824300E+03 },
        { -.56707100E+01, 0.16810300E+01, 0.30444200E+00, -.22061200E+01, -.32860300E+01, 0.40244100E+01, -.55301900E+01, 0.48817500E+01, -.29340100E+01, 0.45677200E+01, -.55578100E-01, -.38892300E+00, -.14936800E+01, 0.32471800E+01, -.47435700E+01, 0.77135200E+00, -.64533000E+00, -.21682400E+01, 0.22743500E+01, -.22404600E+01, 0.58083600E+00, 0.17450600E+00, 0.71217900E-01, -.28146300E+00, 0.20844200E+00, -.15879200E-01, -.10151700E+01, -.31917500E+01, 0.18901200E+01, -.13268100E+01, 0.89377100E+00, 0.12347400E+01, 0.39677100E+00, 0.53039300E+00, -.14943500E+00, 0.49001000E+00, -.86707100E+00, -.66992600E+00, -.56291100E+00, -.66875500E+01, -.11011400E+00, -.18824500E+00, -.94064400E+00, 0.44994300E+00, 0.12202200E+00, -.20654300E+00, -.41825800E+00, -.17088600E+00, 0.22995600E+00, 0.53920000E+00, -.96677500E+00, 0.16518500E-01, -.55645300E-02, 0.37290000E+00, 0.36215900E+00, 0.78767000E+00, -.67068000E+00, 0.28646800E+00, 0.53641500E+00, -.16965200E+01, 0.19042600E+01, 0.39367600E+01, 0.14239200E+01, 0.56374000E+00, -.10870300E+01, 0.25440800E+00, 0.12434800E+01, 0.69806500E+00, 0.27107900E-01, 0.58075300E-01, -.35258800E-01, 0.25567900E+00, -.23840500E+01, 0.26563900E+00, -.68092700E+00, 0.27111000E+00, -.13553600E+00, 0.17984600E+01, 0.24948100E+00, -.13532000E-02, 0.11749200E+00, 0.15846000E+00, -.66927500E+00, -.72593400E+03, -.15119900E+04, -.46585400E+03, 0.18071400E+03, 0.56175700E+03, 0.16346500E+04, -.82507000E+03, 0.20732200E+04, -.81822700E+03, -.84147500E+03, -.11269400E+04, -.51101000E+03, -.11984000E+04, -.23781100E+04, -.78600500E+03, 0.70478900E+02, 0.25825700E+03, -.14314400E+03, -.14633000E+04, -.12011300E+03, 0.46427800E+03, 0.69693700E+03, -.28985000E+03, 0.10746900E+04, 0.80156500E+03, 0.71453600E+03, 0.23071300E+04, -.48864100E+04, 0.24833300E+04, -.29774900E+04, 0.24355700E+04, 0.15735400E+04, 0.21551300E+04, -.64328700E+02, 0.19147400E+03, 0.12286400E+04, 0.20143400E+04, 0.27155900E+04, -.35214300E+04, 0.17518900E+04, 0.72548900E+03, 0.17643200E+04, -.94580100E+02, -.58038800E+03, 0.68293800E+03, -.33277000E+03, 0.15943300E+04, -.37656700E+03, 0.17121000E+04, -.61668700E+02, 0.31529100E+02, 0.59073200E+02, 0.30623500E+02, -.32374900E+02, 0.34107400E+02, 0.98394000E+02, 0.17295300E+03, 0.61500600E+02, -.76082300E+01, -.35205200E+02, 0.14735000E+02, -.21960400E+03, -.34733300E+04, -.33127800E+02, 0.49299200E+03, 0.30116000E+04, -.24829100E+04, -.28192500E+04, -.16017200E+04, 0.30722600E+04, 0.10854400E+04, -.25494700E+04, 0.13026500E+04, 0.70604800E+03, 0.12701300E+04, 0.41131200E+03, 0.11483500E+04, -.97849000E+03, -.15498700E+04, 0.10017200E+04, 0.10530600E+04, 0.24813100E+04, -.75100900E+03, 0.35888100E+03, 0.54044100E+03, 0.37394200E+03, -.28559500E+03, -.29292000E+03, -.17434100E+03, -.87072000E+03, -.73109400E+02, -.14400000E+03, 0.15436400E+04, 0.53282100E+04, -.26642700E+04, 0.16234100E+04, -.26718600E+04, -.20366500E+02, 0.12807900E+04, -.12712200E+04, 0.44108400E+03, -.12580000E+04, 0.12765000E+04, -.68284700E+03, -.57745000E+04, 0.29225700E+04, 0.19530300E+04, 0.29002700E+04, 0.29095300E+03, -.11949600E+04, 0.25163400E+04, 0.16329700E+04, 0.32551500E+04, -.14177700E+04, 0.27642200E+04, -.58889300E+03, 0.31382900E+03, 0.91260800E+03, 0.28808300E+03, 0.36524700E+03, -.49793000E+02, 0.55806400E+03, 0.18739100E+03, -.22633100E+03, -.86678500E+01, 0.32735300E+03, -.16077500E+04, 0.82507900E+03, 0.54242700E+03, 0.79731000E+03, 0.28163600E+03, 0.33155400E+03, -.60696100E+03, -.18167200E+04, -.14005900E+04, 0.52271900E+03, 0.24324000E+04, 0.18617200E+03, -.96754900E+02, 0.33475500E+04, -.91650300E+02, -.66982000E+03, -.16958100E+03, -.85261200E+03, -.30696800E+04, -.17208100E+04, -.51759700E+02, -.13042900E+04, -.83900700E+04, 0.41676100E+04, -.50324100E+04, 0.41701700E+04, 0.23619900E+04, 0.41583000E+04, -.77516600E+03, -.10943800E+04, 0.17840400E+04, 0.39072900E+04, 0.57169400E+04, 0.18411100E+04, -.91918900E+03, 0.72042500E+04, -.92181900E+03, -.16229700E+04, -.13330700E+04, -.12439700E+04, -.53158800E+04, -.39629700E+04, -.77874900E+03, -.27343300E+04, -.58877200E+03, 0.31652000E+03, -.37005400E+03, 0.29259800E+03, -.20043400E+03, 0.30255400E+03, -.78700600E+03, -.12455000E+04, 0.69829700E+03, 0.33213500E+03, 0.11631000E+04, -.56176700E+03, 0.26392500E+03, -.44626800E+03, 0.28832200E+03, -.91865600E+03, -.81530100E+03, 0.10034800E+04, 0.11736400E+04, 0.19433000E+04, -.80056500E+03, 0.67451800E+03, 0.38943700E+02, 0.15267300E+03, -.27541600E+03, 0.12562900E+03, -.28964300E+03, 0.25527100E+03, -.13774500E+03, 0.88859200E+02, -.16355200E+03, -.42140900E+03, -.51351200E+02, -.24506400E+03, -.39666800E+03, -.52720300E+01, 0.31286200E+03, 0.27025200E+03, 0.54729800E+02, 0.59694000E+02, -.13249300E+03, -.11491500E+03, -.28470100E+03, -.10314600E+04, -.31558600E+03, 0.69511400E+03, -.24960700E+03, 0.19859600E+03 },
        { -.46803800E+00, 0.35863700E+00, 0.10372600E-01, 0.25697100E+00, 0.58726000E+00, -.50172700E+00, -.22466400E+01, 0.26677100E+01, -.91821600E+00, -.39816400E-01, -.31275200E-01, 0.65549800E-01, -.26568300E+00, 0.99146700E+00, 0.51019000E+00, 0.52294700E+00, 0.27322200E+00, 0.89100300E+00, -.91227500E+00, 0.12661300E+01, 0.11030500E+00, -.94520100E-01, -.95969600E-01, 0.19740700E+00, -.13372400E+01, -.34565400E-01, -.29374300E+00, 0.11811900E+00, 0.29422600E+00, 0.23436900E+00, -.21511800E-01, -.49091100E+00, -.16524300E+00, 0.65514900E+00, 0.78009600E-01, -.51500000E-01, 0.41602400E-01, 0.25483900E+00, -.54365400E+00, -.15087300E+00, 0.18898500E-01, -.19602900E+00, 0.68852600E-01, 0.24768800E+00, -.23314100E-01, -.56187200E-01, -.26026400E+00, -.18263800E-01, 0.11144200E+00, -.87916000E-01, 0.78339200E+00, 0.35800500E+00, 0.33983000E-01, -.40785900E-01, -.19157800E+00, -.25419500E+00, 0.47506300E+00, 0.11094000E-01, -.15944700E-01, 0.19204600E+00, -.28530800E+00, -.15114200E+00, -.25387300E+00, 0.23427800E+00, -.84340400E-01, -.35893200E-01, -.44644900E+00, 0.93974500E-02, -.29703200E-01, 0.79213400E-02, 0.12283300E+00, -.16258100E+00, 0.84494300E+00, -.65477600E-01, 0.75737900E-01, 0.30217300E+00, 0.27353200E-01, 0.59992600E-01, -.18423300E-01, -.24342800E-01, -.12376100E-01, -.95136700E-01, -.36730300E+00, -.14850200E+00, -.25986500E+03, -.28850900E+03, -.59054700E+02, -.20262400E+03, -.50284800E+03, 0.28072200E+03, -.94066300E+03, 0.25079100E+03, -.22461700E+03, -.52869600E+03, -.14328800E+03, -.12195600E+03, -.32397300E+03, -.26126600E+03, -.75889500E+02, 0.16222200E+03, -.48127600E+02, -.54248200E+03, -.79080300E+02, 0.22176700E+03, 0.38368900E+02, 0.14260300E+03, 0.30138900E+03, 0.22255500E+03, 0.18593300E+03, -.58245500E+03, -.29895700E+04, 0.14473300E+04, -.21378800E+04, 0.14975400E+04, 0.29288000E+03, 0.55276300E+03, -.40437800E+03, -.91817200E+02, 0.25243800E+04, 0.38044900E+02, 0.17805400E+04, 0.12483700E+04, -.63603300E+03, -.92770400E+02, -.62336100E+03, -.31503000E+03, -.24432900E+03, -.98279500E+01, 0.17871500E+03, -.32495900E+03, -.38628100E+03, -.80721000E+03, -.47202700E+02, 0.25374600E+02, 0.94226200E+00, 0.23595300E+02, 0.15640300E+02, 0.37567600E+02, -.84630600E+01, -.72263600E+01, 0.76345000E+01, 0.41078800E+02, 0.58720700E+02, 0.22866300E+04, -.12703800E+04, -.51087900E+03, -.11448700E+04, -.28141200E+03, 0.99112000E+03, -.20911400E+04, -.55849800E+03, 0.31341900E+02, 0.42193000E+03, -.13925100E+04, 0.52909400E+03, -.24274700E+03, 0.88230000E+02, -.26504500E+03, -.70214700E+03, 0.11160600E+03, -.22026200E+03, -.60851900E+03, -.40467700E+03, -.12687300E+03, 0.78047500E+03, -.70938900E+03, 0.38019900E+03, -.44115700E+03, 0.35483400E+03, -.55038300E+03, -.58393400E+03, 0.37412800E+03, -.28774900E+03, -.37190300E+02, -.46768200E+03, 0.10694400E+04, 0.31561700E+04, -.16037800E+04, -.53515500E+03, -.15770400E+04, 0.40204900E+03, 0.93094800E+03, -.84282900E+03, 0.49034300E+03, -.93521000E+03, 0.54969500E+03, -.11424800E+04, -.33542100E+04, 0.17124700E+04, 0.17255400E+03, 0.16773900E+04, 0.28208800E+03, -.28129400E+03, 0.13801400E+04, -.50563300E+02, 0.21845700E+03, -.32987000E+02, 0.14638000E+04, 0.13352800E+04, -.66986200E+03, -.85383000E+02, -.66914800E+03, -.58416600E+03, 0.16425100E+03, -.46638700E+03, 0.35435500E+02, -.61959500E+03, 0.40106100E+02, -.11981400E+03, -.17817300E+04, 0.91165000E+03, 0.91650300E+03, 0.88940600E+03, 0.27168100E+03, 0.33998700E+03, -.12215100E+03, -.61216100E+03, -.24077700E+03, 0.45270000E+03, 0.46054500E+03, 0.40224700E+03, -.20212700E+03, -.42929400E+03, -.20077100E+03, -.37549500E+02, 0.44251000E+02, -.41609600E+03, -.45286700E+02, -.28920000E+03, -.23991500E+02, 0.31152000E+02, -.35783300E+04, 0.16885400E+04, -.25732300E+04, 0.17942600E+04, 0.44148100E+03, 0.14193800E+04, -.14339800E+04, -.55815700E+03, 0.30855700E+04, 0.52887900E+03, 0.15177300E+04, 0.80758200E+03, -.40136300E+03, -.14935100E+04, -.40455200E+03, -.46175700E+02, 0.13272900E+03, -.97839600E+03, -.12929500E+03, -.86751800E+03, -.26351700E+02, -.67041100E+02, -.56846100E+02, 0.23832900E+02, 0.14254200E+01, 0.28284900E+02, -.21410500E+03, -.19345700E+03, 0.22859600E+03, -.19243700E+03, 0.10497900E+03, -.24517300E+03, -.47570400E+02, 0.11553000E+04, -.59764200E+03, -.32130600E+03, -.57609100E+03, -.55684800E+03, -.41580500E+03, 0.27101000E+03, 0.46488300E+03, 0.17348200E+03, -.53157600E+03, -.25316100E+03, 0.48610700E+02, 0.11616600E+03, 0.49437200E+02, -.64108200E+02, -.15643000E+03, 0.21791700E+03, 0.63973200E+02, 0.70457400E+02, -.36948700E+02, -.18478600E+03, 0.50264800E+02, -.12591000E+03, 0.58807800E+02, -.41139200E+02, 0.98310400E+02, -.57534200E+02, -.15800900E+03, -.63930000E+02, -.10035900E+03, 0.99985900E+02, -.72749200E+02, 0.76705300E+02, -.95202400E+02, 0.47379200E+02, 0.61108900E+01, 0.74170800E+02 },
        { -.28351900E+01, 0.10731700E+01, 0.61999200E-01, -.14950800E+01, -.15371200E+01, 0.42947200E+01, -.53497200E+01, 0.55341600E+00, -.10658600E+01, 0.25496700E+01, -.12530200E+00, -.83161700E-01, -.10400700E+01, 0.50512100E-01, -.32071300E-01, -.40125400E+00, -.15508200E+01, 0.84614800E+00, -.22495200E+00, 0.16480400E+01, 0.18258200E+00, 0.94985400E-01, -.15783000E-02, 0.20334600E+00, -.42060500E+01, 0.47690800E-01, -.57975200E+00, -.13482500E+00, 0.65621900E-03, 0.49405700E+00, -.53983600E-01, 0.18847400E-01, -.25078400E+00, 0.68578200E+00, -.58943100E+00, 0.37939500E+00, -.30576100E+00, 0.32990300E+00, 0.15219000E-01, -.37670500E+01, 0.14799400E+00, 0.41818400E+00, -.33550700E+00, 0.82473500E-02, 0.30511300E+00, -.64809300E-01, -.37116300E+00, -.17041700E-01, 0.11198500E-01, 0.43162500E+00, 0.16627000E+00, -.51604600E+00, 0.25527400E+00, 0.22148200E+00, 0.58642600E+00, -.32577300E+00, 0.28391000E+00, -.14663100E+00, -.36618600E-01, -.14641400E+00, 0.82995800E+00, 0.14542800E+01, 0.51491400E+00, 0.16033000E+00, -.13311500E+00, 0.78021200E-01, 0.36554000E+00, 0.27839100E+00, -.16010600E+00, -.24992100E-01, -.66751500E+00, 0.11173600E+00, 0.85887200E+00, -.37828700E+00, -.67475800E+00, 0.87485200E+00, -.15369000E+00, -.76866600E+00, -.16231600E+00, 0.88880000E-01, -.50382100E-01, 0.10171700E-01, 0.58487000E+00, 0.10686700E+00, 0.13719000E+01, 0.78147400E+03, 0.12288600E+03, 0.18772500E+04, 0.30435500E+04, -.16029300E+04, 0.32511400E+04, -.15207500E+04, -.59517600E+03, -.20293700E+03, 0.20828800E+03, -.49903400E+03, -.12449500E+04, -.46681800E+03, -.36636300E+03, -.12799200E+04, 0.55539500E+03, -.48766000E+03, 0.63598900E+03, -.41039100E+03, 0.38491900E+03, -.32271900E+03, -.52722500E+03, 0.96065200E+03, 0.14967900E+03, 0.25478900E+04, 0.29777900E+04, -.14286500E+04, 0.25319200E+04, -.14937700E+04, 0.10119900E+03, -.14274300E+04, 0.88783100E+02, -.28142200E+04, -.62516000E+04, -.16874000E+03, -.15568100E+04, -.73026800E+04, 0.36683700E+04, 0.14568500E+04, 0.36495600E+04, 0.72706700E+03, -.83448300E+02, 0.95768400E+03, -.88634500E+03, 0.31743000E+04, 0.19612900E+02, 0.37080300E+04, 0.13063300E+03, -.68779500E+02, 0.64091700E+02, -.65276900E+02, -.83283900E+02, -.44248900E+02, 0.73031300E+02, 0.15878400E+03, -.54125600E+02, -.69164000E+02, -.21848900E+03, 0.23923700E+03, 0.37458100E+02, -.10294700E+04, -.11562100E+03, 0.11220100E+04, -.40498400E+03, 0.65945600E+03, -.23939200E+04, -.38201100E+04, 0.69804300E+03, 0.14290100E+04, -.18685700E+04, 0.90373300E+03, -.39395500E+03, 0.93534600E+03, 0.15357900E+04, -.11116200E+03, 0.32204400E+03, 0.76246600E+03, 0.18377200E+04, 0.23348200E+03, -.13158600E+04, 0.81562900E+03, -.47066400E+03, 0.98232300E+03, -.40708100E+03, 0.55157200E+03, 0.58864400E+03, -.10641200E+04, -.10339500E+04, -.48170000E+02, 0.59311500E+03, -.95822600E+03, -.16177400E+04, 0.87476000E+03, 0.22582100E+04, 0.80810300E+03, -.41372700E+03, -.68874600E+03, 0.56856800E+03, -.44886600E+03, 0.13028100E+04, 0.48311100E+02, 0.23302300E+04, 0.21123300E+04, -.10883700E+04, 0.27654200E+04, -.10571800E+04, -.17268600E+04, -.87449000E+03, -.42780000E+03, 0.12979300E+04, 0.24545900E+04, -.11655000E+04, -.15364500E+04, 0.52283900E+03, -.24539400E+03, -.11219100E+04, -.25834700E+03, 0.68686400E+03, -.60317200E+03, 0.60590000E+03, 0.37299100E+03, 0.72557200E+03, -.41989100E+03, -.11281600E+04, 0.35820900E+04, -.18424600E+04, -.14157100E+04, -.17880400E+04, -.35499000E+03, -.27679600E+03, -.43740600E+03, -.31077700E+02, -.11327200E+04, -.37864100E+03, 0.75350100E+03, 0.99255300E+03, -.49494800E+03, 0.28592000E+04, -.49706600E+03, 0.87740900E+01, -.29724400E+03, -.48187900E+02, -.14039900E+04, -.16891200E+04, -.13782700E+03, -.17509300E+03, 0.40919500E+04, -.19390400E+04, 0.32209800E+04, -.20543700E+04, 0.27001600E+02, -.25209100E+04, 0.82892900E+03, -.39692000E+04, -.89055300E+04, -.52782600E+03, -.43486200E+03, 0.26251700E+04, -.13210100E+04, 0.84515800E+04, -.13113700E+04, -.30615900E+03, -.15283000E+04, 0.90701900E+03, -.19247000E+04, -.30128900E+04, -.78140900E+03, -.27108500E+03, 0.61306500E+03, -.28474500E+03, 0.44680800E+03, -.30635600E+03, 0.49743100E+03, 0.32467700E+03, -.93400100E+03, -.15082700E+03, 0.39019300E+03, 0.41161000E+03, 0.10534300E+04, -.35056800E+04, 0.17891900E+04, 0.52852500E+03, 0.17496100E+04, 0.95173700E+03, 0.47925100E+03, 0.23579300E+03, -.30856200E+02, 0.20173800E+04, 0.40729700E+03, 0.14731400E+04, -.23990500E+03, -.15295500E+03, -.52533000E+03, 0.28486300E+03, 0.19456600E+02, -.23338900E+03, -.32463500E+03, -.13885500E+03, 0.50465100E+02, 0.68096600E+01, -.18894100E+03, -.64657400E+03, -.51532300E+03, 0.97188400E+02, -.56833800E+03, 0.17299100E+03, 0.40258100E+03, 0.17387900E+03, -.36428900E+03, -.35035900E+03, -.20527700E+03, -.11880500E+04, 0.65921600E+03, 0.47878600E+03, -.31190800E+02, 0.30640100E+02 },
        { 0.59847400E+00, 0.17030300E+00, -.10971800E-01, -.47947300E+00, 0.62196900E+00, 0.19079300E+01, -.83759200E+00, 0.82462600E+00, 0.15363100E-01, -.59988500E+00, 0.24306300E-01, -.24966300E-01, 0.37813500E-01, 0.50011300E+00, 0.54631400E+00, -.13192500E+00, 0.54750800E-01, 0.36885500E+00, -.25464500E+00, -.45936500E-02, -.17084100E+00, 0.20134500E-01, -.74876400E-01, 0.74926800E-01, -.11006100E+00, 0.78969800E-02, 0.69003900E-01, 0.30048800E+00, -.63792900E-01, -.34872500E-01, -.18136700E+00, -.41459400E+00, -.25827500E+00, -.91081600E-01, 0.18772800E-01, 0.23106100E-02, 0.12301800E-01, -.15984800E+00, 0.23418000E+00, -.13742000E+01, -.61521300E-01, -.12246600E+00, -.37383400E-02, 0.10329300E-01, -.44509100E-01, 0.33851700E-01, -.52856800E-01, -.13702300E-02, 0.21291600E-01, 0.32824800E-01, -.38626200E+00, 0.77637600E-01, 0.11063800E+00, 0.63247200E-02, 0.23640800E+00, -.21702900E-01, 0.26560900E+00, -.53365400E-02, 0.20083800E-01, 0.80651700E-01, -.13393200E+00, -.51168800E+00, -.21665300E+00, -.46699000E-01, 0.19908400E+00, -.37616700E-01, -.29633600E-01, -.13576400E-01, 0.16629200E-01, 0.17052700E-01, 0.55312200E-01, 0.48251500E-01, 0.26787500E-01, 0.11515000E+00, -.33971600E-01, -.61704500E-01, 0.82357300E-01, 0.19998200E+00, -.26941400E-01, 0.89557700E-01, 0.41630200E-01, 0.52258400E-01, -.28424600E+00, 0.50255600E-01, -.11640500E+00, -.10432400E+00, -.80498600E+02, 0.42334700E+02, -.10690500E+04, 0.52125800E+03, -.59822800E+03, 0.53474600E+03, -.40950600E+02, -.39550800E+03, 0.33966800E+03, -.12485800E+03, 0.72877400E+03, -.29350500E+03, 0.35820000E+03, 0.81791100E+03, -.42234200E+03, -.81271800E+02, -.40975700E+03, -.73078200E+02, -.26271800E+03, -.93881800E+02, -.12176700E+02, -.11012200E+03, -.18202400E+03, -.31129500E+03, 0.27083400E+04, -.13426600E+04, 0.95056400E+02, -.13548400E+04, -.20416800E+03, -.36119700E+03, -.35792100E+03, -.25151500E+03, -.12420800E+04, -.31570200E+03, -.10436200E+04, -.22012700E+03, 0.11056600E+03, 0.24934100E+03, 0.10974900E+03, -.43244500E+02, 0.27117900E+02, -.22395100E+02, -.74831300E+02, 0.16590800E+03, -.94682500E+02, 0.66372300E+02, 0.69945800E+02, -.35345500E+02, -.80681600E+01, -.34967800E+02, 0.10854400E+02, 0.52772100E+01, -.22834400E+02, -.40196700E+01, -.31390100E+02, 0.12004100E+02, -.37716800E+02, -.18648800E+02, -.24971900E+01, 0.10979100E+03, 0.10322000E+02, 0.23456900E+03, -.48963200E+03, 0.24783500E+03, -.23091900E+03, -.28722300E+03, -.49740400E+03, 0.29741900E+03, 0.67259000E+03, -.33445000E+03, -.50208700E+02, -.33605000E+03, -.96010000E+02, 0.39897100E+02, -.82339900E+02, -.11227700E+02, -.47795400E+03, 0.14220200E+02, 0.14637900E+03, 0.31487900E+03, -.16179700E+03, -.15698300E+03, -.15734200E+03, 0.19314700E+02, 0.15705900E+03, -.12962900E+03, 0.50021800E+02, 0.44399900E+02, 0.12377200E+03, 0.79436000E+02, 0.23088000E+04, -.11438100E+04, -.89934700E+03, -.11541200E+04, 0.14163900E+03, 0.73594200E+03, -.55010500E+03, 0.59088600E+03, -.86005000E+03, 0.45319200E+03, -.57917900E+03, 0.84426700E+03, -.40837600E+03, 0.96008300E+02, -.42248700E+03, -.21945300E+03, 0.19124000E+03, -.32385200E+03, 0.22285000E+03, -.81633700E+02, 0.21086700E+03, -.46243500E+03, 0.54017500E+03, -.26527900E+03, 0.14002300E+03, -.26950800E+03, -.13110800E+03, -.12249800E+03, -.88005200E+02, 0.73072200E+02, -.46419700E+02, -.97261900E+02, -.85335000E+02, 0.43170900E+03, -.22210100E+03, -.94662500E+02, -.21528600E+03, -.12046400E+03, -.10361600E+03, 0.67781400E+02, 0.26386000E+03, 0.43367400E+03, -.11905800E+03, -.17900200E+03, -.15020100E+04, 0.75126400E+03, 0.24715400E+03, 0.75087500E+03, 0.20902300E+03, 0.41680900E+03, 0.22109300E+03, -.10173400E+03, 0.48329100E+03, 0.32122000E+03, 0.79017500E+03, 0.34617500E+04, -.17233500E+04, 0.30975100E+03, -.17319000E+04, -.16947400E+03, -.64626300E+03, -.39406900E+03, -.43888300E+03, -.17475400E+04, -.57777300E+03, -.11899800E+04, -.12486100E+04, 0.62425600E+03, -.71766200E+03, 0.62457200E+03, 0.27066200E+03, 0.88508400E+03, 0.18266400E+03, 0.27293000E+03, 0.59522700E+03, 0.54848800E+03, 0.85962900E+03, -.36284300E+03, 0.18749700E+03, 0.53546800E+00, 0.18150300E+03, -.21148000E+02, -.31920100E+02, 0.12483200E+03, 0.61181000E+02, 0.12614000E+02, -.72495700E+02, 0.27861500E+03, -.23091000E+03, 0.11799100E+03, 0.13422500E+03, 0.11483600E+03, 0.11350800E+03, 0.92374900E+02, -.99910900E+02, -.13730200E+03, -.17087900E+03, 0.83648000E+02, 0.23303300E+03, -.59308000E+02, -.42545900E+02, 0.11707100E+02, 0.52931300E+02, -.71916000E+02, 0.52067900E+02, -.28487300E+02, -.18699100E+02, 0.38285200E+02, 0.20397600E+02, 0.10394600E+02, -.17101900E+03, -.40457100E+01, -.19459600E+02, -.11194300E+03, -.35942600E+02, 0.16616400E+02, 0.41112700E+02, 0.13468900E+02, 0.99361000E+01, 0.61379200E+02, 0.33948700E+03, 0.24530000E+03, -.15402100E+03, 0.68061200E+02, 0.93580200E+02 },
        { -.77976000E+00, 0.20687400E+01, 0.22505600E+00, 0.79991800E+00, 0.36916100E+00, 0.11536700E+00, -.24960800E+01, 0.26260000E+01, -.11636300E+01, -.23766900E+00, 0.65318600E-02, -.42902700E-01, -.51024600E+00, 0.24212300E+01, -.94790300E-01, 0.60019900E+00, 0.29768100E+00, 0.73902000E+00, -.22334500E+00, 0.74514200E+00, -.18714200E+00, -.24933200E-01, -.14608000E+00, -.42203700E-01, -.88023800E-01, 0.27713800E-01, 0.13340500E+00, 0.51901500E+00, -.14234100E-01, -.21268300E+00, 0.13387600E+00, -.33294800E+00, -.35598600E-01, 0.22030600E+00, 0.22052200E+00, 0.16135200E-01, -.14959700E-01, -.55507000E-01, -.45914400E+00, 0.13031900E+01, 0.42443600E-01, -.16330100E+00, 0.17245400E+00, 0.36006600E+00, -.39520100E+00, 0.54882100E-01, -.31703000E-01, -.18111800E-01, 0.23284100E-01, -.66638200E-01, 0.81020500E+00, -.10290400E+00, -.37258800E-01, 0.21921000E-02, 0.59133500E+00, -.30784800E+00, 0.17070000E+00, 0.76977400E-01, -.48238800E-01, 0.20130200E-01, 0.18480400E+00, 0.56803700E+00, 0.30454500E+00, -.28422700E+00, -.72378200E+00, -.20433800E-01, -.71775600E+00, 0.26318200E-01, -.18220900E+00, 0.11029100E-01, -.51456300E-02, 0.99430500E-01, 0.10565800E+01, 0.19463500E+00, 0.55623900E-01, -.77938000E-01, 0.26732700E-01, 0.41441700E+00, 0.17835900E+00, -.86247200E+00, -.69394900E-03, 0.19380300E+00, 0.23216000E+00, -.63485200E-01, -.34349400E+00, -.89123200E-01, -.48696900E+00, 0.47731800E+03, 0.14554700E+04, -.74993100E+03, -.27654400E+03, -.72775500E+03, 0.96092500E+02, 0.46450500E+01, -.16355900E+03, 0.20386100E+03, -.75867200E+03, -.61598700E+02, -.26869700E+03, 0.77479000E+03, -.41315200E+03, 0.16821900E+03, -.38765000E+03, -.23233600E+03, -.10135400E+03, -.35774500E+03, -.82269300E+02, -.17865300E+03, -.10767300E+03, 0.37578800E+03, 0.55390800E+04, -.27149600E+04, -.50953400E+02, -.27752500E+04, 0.15409100E+02, 0.39495800E+03, -.76870700E+03, 0.51122100E+03, -.26690400E+04, 0.52444900E+03, -.20273700E+04, -.19651700E+04, 0.98911200E+03, 0.39527800E+03, 0.98190700E+03, 0.25879400E+03, -.55556400E+02, 0.32372400E+03, -.18228700E+03, 0.67836400E+03, 0.26350600E+02, 0.10412200E+04, 0.83143300E+02, -.42711200E+02, 0.19547100E+02, -.41555900E+02, -.24849600E+02, -.12121800E+02, -.57918000E+01, 0.24146900E+02, -.29432600E+02, -.18055500E+02, -.11526900E+03, -.20381300E+04, 0.10233800E+04, -.20830700E+04, 0.10145200E+04, 0.12263400E+04, 0.44162200E+03, 0.53538800E+03, -.14175200E+03, -.16502000E+03, 0.59411600E+03, 0.22876700E+04, -.91952400E+03, 0.45611800E+03, -.12476300E+03, 0.45923500E+03, 0.59859800E+02, -.38614800E+02, 0.61652600E+03, 0.21381900E+03, 0.36097100E+03, 0.29386000E+03, -.26330100E+02, 0.30358700E+03, -.15449500E+03, 0.51376300E+03, -.15257800E+03, 0.26594300E+03, 0.17266600E+03, -.35928600E+03, -.23707200E+03, 0.62282800E+01, 0.19471600E+03, -.28773800E+03, 0.16089200E+03, -.62022400E+02, -.24036300E+03, -.81064600E+02, 0.76711700E+02, 0.16067500E+03, -.34784000E+00, -.48624400E+02, 0.10835700E+03, 0.32454800E+03, 0.42931300E+03, 0.21610500E+04, -.10551700E+04, 0.16108100E+04, -.10775600E+04, -.51027800E+03, -.45289100E+02, -.93410000E+03, -.15104600E+03, -.23801800E+03, -.17829400E+03, -.12823900E+04, -.61011300E+03, 0.30982900E+03, 0.49031900E+03, 0.30598500E+03, 0.58727000E+02, -.38592200E+03, 0.39366000E+03, -.18419900E+02, 0.31778900E+03, -.23421100E+03, -.36260400E+03, 0.85800900E+03, -.44152900E+03, -.28491800E+03, -.42833900E+03, -.20850300E+03, -.12027100E+03, -.11183100E+03, -.68481000E+02, -.39633800E+03, -.10976500E+03, 0.30777900E+03, -.37623000E+04, 0.18816700E+04, 0.20310700E+04, 0.18807300E+04, 0.12484000E+03, 0.58217500E+03, 0.44812000E+03, -.13970300E+04, 0.38969800E+03, 0.58269900E+03, 0.19168000E+04, 0.57409700E+04, -.28102700E+04, -.88061500E+03, -.28838300E+04, 0.52571500E+03, 0.87368600E+03, -.86857100E+03, 0.28733100E+03, -.35951700E+04, 0.10692100E+04, -.90544000E+03, -.38541900E+04, 0.19260000E+04, 0.25994600E+04, 0.19271000E+04, 0.24860100E+03, 0.84487900E+03, 0.68850000E+03, -.14478100E+04, 0.20208700E+03, 0.83143500E+03, 0.22785900E+04, -.47457500E+03, 0.24502600E+03, -.96893300E+02, 0.23689400E+03, 0.82305400E+02, 0.24067500E+02, 0.12184100E+03, -.32050800E+02, 0.39229400E+03, 0.93485000E+02, 0.67574400E+03, -.12430400E+04, 0.63129700E+03, 0.27714000E+03, 0.62096600E+03, 0.32723200E+03, 0.46091300E+02, 0.20499900E+03, -.60482000E+02, 0.58653300E+03, 0.14780200E+03, 0.50016100E+03, -.75258600E+02, -.15605400E+03, -.82244300E+02, 0.12114700E+03, 0.40281200E+02, -.73686700E+02, -.62654400E+02, -.65069200E+02, 0.36770100E+02, -.10572800E+02, -.44395000E+02, -.46538600E+03, -.99281000E+02, 0.26361500E+02, -.29720900E+03, 0.18181300E+03, 0.18631900E+03, 0.82497700E+02, 0.17629600E+03, -.43700200E+02, -.14715800E+03, 0.24727200E+02, 0.52458800E+03, -.33839300E+02, 0.60457100E+02, -.32975500E+01 },
        { -.20175700E+00, -.61980900E+00, -.44836200E-01, -.39791300E+00, -.62365800E+00, -.10035800E+01, 0.36227800E+00, 0.28028200E+00, 0.73917800E-01, 0.34818500E+00, -.31143400E-01, 0.37050000E-01, 0.56163200E+00, -.13245300E+01, 0.88959300E+00, -.40782200E+00, 0.22561400E-01, -.15275700E+00, 0.11331700E+00, -.23082700E+00, 0.14880800E-01, -.63596500E-02, 0.10743400E-01, 0.32946500E-01, -.13918000E+00, -.87179600E-02, 0.30346900E-01, -.22798300E+00, 0.12091700E+00, -.14077800E+00, -.55221600E-01, -.76429000E-02, -.18056100E+00, -.17810200E+00, -.25767600E-01, 0.94273800E-01, 0.39121400E-01, -.33570900E+00, 0.30265300E+00, -.15608000E+01, -.49254100E-01, -.97881300E-01, 0.23573300E+00, -.13516100E+00, -.31145200E-01, -.89243500E-02, 0.12207800E+00, -.10612900E-01, -.21385100E-01, -.88064500E-01, -.86620600E+00, 0.50996100E-01, 0.48491700E-01, 0.30230800E+00, -.25954400E-01, -.65627500E-01, -.97963100E-01, 0.31994100E-01, -.35743200E-01, -.36255400E-01, -.18103700E+00, -.70282500E-01, 0.58195700E-01, 0.20591500E+00, -.30093000E+00, 0.34393600E-01, 0.20069800E+00, -.10851300E-02, 0.19393500E-01, -.60089400E-02, 0.10923600E+00, -.53354000E-01, -.36390400E+00, -.28414900E-02, -.12460800E-01, 0.20779000E-01, 0.24120100E-01, 0.22660300E+00, 0.84639600E-01, -.20871700E+00, 0.16386300E-01, 0.25310600E-01, -.13653100E+00, 0.84812100E-01, -.47548300E-01, -.16114300E+00, -.10287000E+00, 0.89751100E-01, -.13693100E+04, 0.67446400E+03, 0.39768500E+03, 0.68483800E+03, -.33701700E+02, -.19891400E+03, 0.13040100E+03, -.47211200E+03, 0.51995400E+03, -.13192700E+03, 0.43307100E+03, 0.99296300E+02, -.59147000E+02, -.23222600E+03, -.51088100E+02, -.38510700E+02, 0.14034100E+02, 0.13120900E+03, 0.20960700E+03, 0.21030800E+02, 0.11769200E+02, 0.37529200E+02, 0.27775200E+04, -.13885800E+04, -.45984300E+03, -.13888600E+04, -.42017000E+03, -.63973200E+03, -.64204700E+03, -.74282600E+03, -.12804200E+04, -.46291400E+03, -.11422800E+04, -.69665800E+03, 0.34927000E+03, 0.14459400E+03, 0.34767300E+03, -.11382400E+03, -.37532000E+02, 0.11682500E+03, -.72781800E+02, 0.38428300E+03, -.86368400E+02, 0.29914500E+03, 0.54898600E+02, -.27781100E+02, 0.11525100E+02, -.27419300E+02, -.17128700E+01, 0.71683400E+01, 0.23445800E+01, 0.23781900E+02, -.10247300E+02, 0.29780100E+01, -.27622500E+02, 0.13086100E+04, -.63513600E+03, -.14101400E+04, -.65140700E+03, 0.36947200E+03, 0.29747500E+03, -.92022500E+03, -.86545900E+03, -.80119400E+03, 0.28738600E+03, -.33724200E+03, -.86773900E+02, 0.40280600E+02, -.18205500E+03, 0.43971100E+02, -.31724300E+03, 0.15487400E+03, -.20890400E+02, -.80801900E+01, -.28382800E+03, 0.35075600E+02, 0.28889600E+03, -.40943000E+03, 0.19723900E+03, -.15246300E+03, 0.20504800E+03, -.11718200E+03, -.21701500E+03, 0.10331700E+03, -.14038400E+03, 0.14431500E+03, -.20658300E+03, 0.41004200E+03, 0.13029700E+04, -.64323600E+03, -.46886200E+03, -.65021500E+03, 0.16215000E+03, 0.39510500E+03, -.32954900E+03, 0.35645800E+03, -.57674600E+03, 0.27474500E+03, -.38302200E+03, 0.36696300E+03, -.18767800E+03, 0.13322700E+04, -.18480300E+03, -.36538700E+03, -.36904900E+03, 0.26928400E+03, 0.37351700E+03, -.16285900E+03, -.28800100E+03, -.33844100E+03, 0.99649400E+03, -.49605200E+03, -.23152600E+02, -.49711200E+03, -.30911500E+03, -.24165500E+02, -.25776100E+03, 0.14408500E+02, -.44285000E+03, -.58794400E+02, -.32005600E+03, 0.25045000E+03, -.13199800E+03, 0.18381300E+03, -.12411300E+03, 0.28927700E+02, 0.12728500E+03, -.14699200E+03, -.65274900E+02, 0.19751600E+02, 0.15069100E+03, -.18247000E+03, 0.79643000E+03, -.39793700E+03, -.40339300E+03, -.39850000E+03, -.73179200E+02, -.11834300E+03, -.22942300E+03, 0.91816300E+02, -.11691100E+02, -.12975000E+03, -.23529100E+03, 0.42584800E+04, -.21246800E+04, -.95454500E+03, -.21284200E+04, -.39632000E+03, -.59372500E+03, -.12768000E+04, -.12004900E+04, -.21079600E+04, -.37913000E+03, -.17475800E+04, 0.92384700E+03, -.46297600E+03, -.41484000E+03, -.46167100E+03, -.97333000E+02, -.19231000E+03, -.43249500E+03, -.41475600E+02, 0.56075900E+02, -.19001000E+03, -.34386500E+03, -.22523600E+03, 0.11526000E+03, -.18396400E+02, 0.11282600E+03, 0.67750700E+02, 0.12707700E+03, -.71736600E+02, -.14533100E+03, -.17095600E+03, 0.88371300E+02, 0.16896900E+03, -.30204700E+03, 0.15467200E+03, -.74584200E+02, 0.14980300E+03, -.17627100E+02, 0.53293300E+02, 0.46401500E+02, 0.73949500E+02, 0.11420700E+03, -.25454300E+02, 0.25406000E+03, -.46773200E+02, -.41642300E+02, -.71446800E+02, 0.39021100E+02, -.66514100E+02, 0.23650900E+02, -.19372700E+02, -.18605000E+02, 0.65693800E+01, 0.42938300E+02, -.23143400E+02, 0.31345400E+02, -.44925000E+02, -.15380000E+01, -.93317800E+02, 0.35785400E+02, 0.77400300E+02, 0.44498700E+02, 0.68096300E+02, 0.12042200E+01, -.24654500E+02, 0.90246000E+01, 0.87786000E+02, -.42730000E+01, -.21251400E+01, 0.65639500E+02 },
        { -.10107400E+01, -.90189500E+00, -.70619300E-01, -.77998100E+00, -.76865900E+00, 0.76606400E+00, -.13992000E+01, 0.19312300E+01, -.74296600E+00, 0.78254800E+00, 0.17234300E-01, -.47065900E-01, 0.86351900E+00, 0.66299800E+00, 0.47701900E+00, 0.10396500E+01, -.53366600E+00, 0.18091500E+00, -.65757300E+00, 0.33992100E+00, 0.19774400E-01, 0.44656100E-01, -.42105900E-02, 0.17138600E+00, -.15240900E+01, -.50136900E-01, -.47004600E+00, -.11646400E+00, 0.53678000E+00, 0.15111000E+00, 0.59976500E-01, 0.31792200E-01, 0.61068000E-01, 0.39307400E+00, 0.12389400E+00, 0.17163100E+00, 0.69417900E-01, 0.17388800E+00, -.30207400E+00, 0.82523100E+00, -.31860200E-01, -.60186800E-01, -.58687600E+00, -.21046100E+00, 0.19064800E+00, 0.35182900E-01, -.21008800E+00, -.14906700E-01, 0.95725800E-01, 0.45116000E-02, 0.49883100E+00, 0.35845300E-01, -.47662700E-01, 0.45423000E+00, 0.57378100E-01, -.24832500E+00, 0.20901000E+00, -.10593900E+00, -.43402000E-01, 0.12354300E+00, -.18317600E+00, -.41656800E+00, -.14481800E+00, 0.23815200E+00, 0.69465100E-01, -.21558000E-01, -.27259400E+00, 0.60775500E-01, -.64641200E-01, 0.27396500E-01, -.10665000E+00, 0.15563300E+00, -.45036300E-01, 0.19976100E+00, 0.25876400E+00, -.25944000E+00, 0.58696400E-01, 0.61082100E-01, 0.57172000E-02, 0.84765600E-01, 0.54190800E-01, -.50309500E-01, 0.32253800E+00, -.83756900E-01, -.37700100E+00, -.19136400E+00, -.39856900E+00, -.80827200E+00, -.11962500E+01, -.67643400E+02, 0.10509400E+04, 0.37966100E+00, 0.24149100E+03, -.44415800E+03, 0.46297900E+03, -.33687500E+03, 0.37208700E+02, -.40855600E+03, 0.20032700E+03, 0.20115400E+04, -.10803400E+04, -.49289100E+03, -.10079400E+04, -.58697000E+03, -.31951500E+03, -.27489800E+03, 0.72352600E+03, -.63141700E+02, -.36798500E+03, 0.34334100E+03, 0.13858500E+05, -.68154400E+04, 0.82542800E+01, -.69392400E+04, -.12965700E+03, -.10953600E+04, -.14214000E+04, 0.31482300E+03, -.70598100E+04, -.22689400E+03, -.68874800E+04, -.34220500E+04, 0.17233800E+04, 0.34048900E+03, 0.17092300E+04, 0.36636700E+03, 0.14552400E+03, 0.36905400E+03, -.31292100E+03, 0.13149600E+04, 0.16987100E+03, 0.17300000E+04, 0.20114100E+03, -.10331700E+03, 0.54484000E+02, -.10052700E+03, -.34018100E+02, -.32025700E+02, 0.29938300E+01, 0.61188200E+02, -.69880500E+02, -.41092900E+02, -.12908900E+03, -.31862500E+04, 0.15768800E+04, -.39736400E+04, 0.15887200E+04, 0.31199200E+04, 0.28073500E+03, 0.96999200E+03, -.10943000E+04, -.12024100E+04, 0.80136900E+03, 0.22421600E+04, -.44134200E+03, 0.21517900E+03, -.57976700E+03, 0.22044600E+03, -.89984400E+02, 0.34941100E+03, 0.74032600E+03, 0.11472900E+04, 0.14991400E+03, 0.44608100E+03, -.45717200E+03, 0.56981900E+03, -.31368100E+03, 0.46163200E+03, -.28575800E+03, 0.57062000E+03, 0.65145800E+03, -.57325900E+03, -.40099400E+02, 0.12879500E+03, 0.49421200E+03, -.58796300E+03, 0.12733700E+04, -.58215500E+03, -.45194600E+03, -.63661300E+03, -.29898300E+03, 0.21659000E+03, -.10859500E+03, 0.74460700E+03, 0.40562300E+02, 0.23616800E+03, -.78009300E+03, 0.46298600E+04, -.22651200E+04, 0.39515900E+04, -.23113600E+04, -.16181800E+04, -.13980800E+03, -.15812600E+04, 0.22557900E+03, -.46616400E+03, -.41809500E+03, -.21308700E+04, 0.75945600E+03, -.36009600E+03, 0.18679400E+03, -.37696700E+03, -.14113400E+03, -.57435800E+03, 0.35783000E+03, 0.25570600E+03, 0.81212800E+02, -.46965700E+03, -.58581400E+03, 0.24758900E+04, -.12717000E+04, -.67161700E+03, -.12356200E+04, -.49241700E+03, -.49688200E+03, 0.10774900E+03, 0.57383800E+03, -.11114800E+03, -.41570000E+03, -.51523400E+03, -.35984100E+04, 0.17998900E+04, 0.24871700E+04, 0.17982400E+04, 0.75219900E+02, 0.37805000E+03, 0.55738500E+03, -.15257000E+04, 0.41473300E+03, 0.44690800E+03, 0.12808800E+04, 0.14938600E+05, -.73623900E+04, -.99349200E+03, -.74913500E+04, 0.10719000E+04, -.10066100E+04, -.13945600E+04, -.45288200E+03, -.94270100E+04, 0.23083200E+03, -.65759600E+04, -.38201700E+04, 0.19068800E+04, 0.44807100E+04, 0.19106000E+04, 0.22106500E+03, 0.35410100E+03, 0.11356200E+04, -.17627000E+04, 0.40641000E+03, 0.46483700E+03, 0.44368500E+03, -.76456100E+03, 0.40947900E+03, -.17809200E+03, 0.38186900E+03, 0.15841700E+03, 0.21650500E+03, 0.67695700E+02, 0.32722200E+03, 0.56925200E+03, 0.21738600E+03, 0.54408200E+03, -.24215400E+04, 0.12335300E+04, 0.36331900E+03, 0.12084900E+04, 0.59905600E+03, 0.40397000E+03, 0.65938000E+02, -.16779700E+03, 0.75501100E+03, 0.39719800E+03, 0.98856600E+03, -.18579500E+03, -.28718200E+03, -.26781700E+03, 0.31119100E+03, 0.32207300E+02, -.16057500E+03, -.20828200E+03, -.13713800E+03, 0.10095700E+03, 0.11882200E+03, -.16522600E+03, -.13151800E+04, -.19546100E+03, 0.57137300E+02, -.83878800E+03, 0.32974700E+03, 0.35106200E+03, 0.22341500E+03, 0.17152400E+03, -.17223300E+03, -.73199200E+02, -.14294000E+03, 0.14672000E+04, -.11693300E+02, -.20996100E+02, 0.33448900E+02 },
        { 0.21791700E+00, -.17370300E+01, -.16309500E+00, -.64244500E+00, -.32380200E+00, -.16530400E+01, 0.76534700E+00, -.69977200E+00, 0.38383500E+00, 0.84788000E-01, 0.47176500E-02, 0.12324100E+00, -.26228400E+00, 0.49912900E+00, 0.38855300E+00, 0.14189400E+00, 0.39829900E+00, 0.13925400E+00, -.52052200E+00, 0.10948500E+01, 0.23046400E+00, -.49425600E-01, -.11712600E-01, 0.14450800E-01, -.17389900E-01, -.17812600E-01, -.20490000E+00, -.33244600E+00, 0.20235200E+00, -.43585900E+00, 0.79316500E-01, -.24813800E+00, -.16062600E+00, -.47297600E-01, 0.87014000E-01, 0.11385900E+00, 0.88037900E-01, 0.98196300E-03, -.16765200E-01, -.89471800E+00, 0.35078500E-01, -.81238400E-01, -.14029000E+00, -.44409300E-01, -.18035300E+00, -.15776200E-01, -.17341900E+00, -.71046000E-02, 0.20239000E-01, -.94784600E-01, -.30016800E+00, 0.13359600E+00, 0.10135200E+00, 0.17650400E+00, -.15632100E+00, 0.20344300E-01, 0.67647200E-02, 0.15647900E+00, -.20664000E-01, 0.32172900E-01, -.29224000E-01, 0.20091600E+00, -.11117800E+00, -.86891400E-03, -.35981700E+00, -.31636100E-01, -.25784900E+00, -.81906900E-01, -.41565500E-01, -.18544800E-02, 0.88261700E-01, -.91644700E-01, 0.38951000E+00, -.23210600E-01, -.12587700E-01, 0.25642400E+00, -.13312600E-01, 0.37903100E-01, -.49232400E-01, -.36024400E-03, -.20348400E-01, 0.24861900E-01, 0.19727200E+00, 0.44628200E-01, 0.11331800E+00, 0.38664200E-02, 0.56121700E+00, 0.17834700E+00, 0.37361700E+00, -.62831900E-01, 0.67224800E+03, -.10567100E+00, 0.25851600E+02, -.12727100E+03, 0.78909500E+02, -.89678400E+02, -.17865300E+03, -.83883800E+02, 0.10392300E+03, -.13659700E+03, 0.66838500E+02, -.42776600E+03, 0.68461600E+02, 0.42157700E+01, 0.13581200E+03, 0.46393600E+02, 0.20597900E+03, 0.93739000E+02, 0.14620800E+03, -.11672900E+03, 0.16405100E+04, -.80430700E+03, -.40842200E+03, -.82041700E+03, -.19710400E+03, -.32227200E+03, -.21171500E+03, -.23423300E+02, -.82560500E+03, -.21288000E+03, -.81708000E+03, -.29643500E+03, 0.15081200E+03, -.25892600E+03, 0.14819500E+03, 0.66179900E+02, -.19550100E+02, 0.82170900E+02, 0.84532800E+02, 0.89050600E+02, 0.13185500E+02, 0.18055500E+03, -.52620400E+01, 0.23819300E+01, 0.32413800E+02, 0.26376500E+01, -.75331200E+01, 0.11732200E+01, 0.12467600E+02, 0.91749200E+01, 0.36024700E-01, -.47269800E+01, -.85575100E+00, 0.10012100E+04, -.47512600E+03, -.90821400E+03, -.50096400E+03, 0.24330000E+03, 0.16689000E+03, -.25415500E+03, 0.13941400E+01, -.43907300E+03, 0.18092300E+03, -.54017200E+03, 0.14912400E+03, -.79560100E+02, -.25433500E+03, -.74637700E+02, -.34008400E+02, 0.98735200E+02, -.74332300E+02, 0.23570800E+03, 0.12156500E+03, 0.47197600E+02, -.54129200E+03, -.22180800E+03, 0.11091800E+03, -.13145300E+03, 0.11060000E+03, -.74911900E+01, -.10615900E+03, 0.38615600E+01, -.70241000E+02, 0.23154400E+02, -.37471200E+02, -.69036400E+02, -.10499300E+03, 0.52987600E+02, 0.43463800E+03, 0.52111100E+02, -.14280200E+03, -.15333300E+03, 0.13677700E+02, -.13180800E+03, 0.14076100E+03, -.12880700E+03, -.39465000E+03, 0.24691600E+03, -.12986600E+03, 0.86120600E+03, -.12325800E+03, -.26529700E+03, -.19946700E+03, 0.26852600E+02, -.35814000E+02, -.12105100E+03, -.14311800E+03, -.20278600E+03, 0.62450200E+03, -.31406800E+03, -.15904200E+02, -.31227900E+03, -.11139500E+03, 0.48192000E+02, -.78197500E+02, 0.35112700E+02, -.24353700E+03, 0.11406800E+01, -.48028400E+03, 0.70191900E+02, -.36429100E+02, 0.55751300E+02, -.35136300E+02, -.13788100E+02, -.35638800E+02, 0.16737400E+02, -.60505300E+02, -.24801300E+03, 0.11578000E+02, 0.30303200E+02, 0.85793000E+03, -.42850900E+03, 0.20878100E+03, -.42899100E+03, -.24321000E+03, -.32825600E+03, -.78262400E+02, -.53846300E+02, -.33152700E+03, -.28246400E+03, -.21012300E+03, 0.26936000E+04, -.13187300E+04, -.72768600E+03, -.13472200E+04, -.20932000E+03, -.33114200E+03, -.35969800E+03, 0.34322400E+02, -.12935300E+04, -.20085000E+03, -.14148600E+04, 0.87151800E+03, -.43555900E+03, 0.14906900E+04, -.43588500E+03, -.34781900E+03, -.76254700E+03, 0.29900300E+02, -.36654100E+03, -.48499900E+03, -.59426200E+03, -.22654700E+03, 0.12615800E+03, -.65047300E+02, -.72852400E+02, -.63143900E+02, 0.91778700E+02, 0.43435300E+02, -.98790000E+02, 0.50935400E+02, 0.10094900E+03, 0.43555600E+02, -.88688300E+02, -.13909000E+03, 0.72521200E+02, -.24698000E+03, 0.69600100E+02, 0.43309900E+02, 0.28302900E+02, 0.21143300E+02, 0.94475300E+02, 0.17812000E+03, -.29625400E+02, -.86047200E+02, -.60164800E+01, -.35169600E+02, -.67231200E+02, 0.23964300E+02, 0.14122500E+02, -.27379100E+01, -.23058300E+02, -.25038300E+02, 0.69549700E+01, -.17867000E+02, -.40072800E+02, -.56375900E+02, -.23740100E+02, 0.23723000E+02, -.11947700E+03, 0.10574300E+03, 0.81067300E+01, 0.31027100E+02, 0.13413000E+02, -.26144600E+02, -.67466400E+02, -.34993600E+03, 0.10355400E+03, 0.15046500E+03, -.38538700E+02, -.26928700E+02 },
        { -.39242900E+01, 0.11350500E+01, 0.11786500E+00, -.10004200E+01, -.73542900E+00, 0.38935900E+01, -.64811300E+01, 0.16961000E+01, -.27192100E+01, 0.28467200E+01, 0.11745900E+00, -.44010700E+00, 0.30669800E+00, 0.92914000E+00, 0.15449600E-02, -.22234900E+01, -.73995800E+00, 0.11592200E+01, 0.46284500E+00, -.22722300E+01, -.29905300E+00, 0.26115900E+00, -.53210200E+00, 0.71999700E-01, -.68861200E+00, 0.26311700E+00, 0.55795600E+00, 0.28135100E+00, -.17897800E+00, -.32871000E-01, -.37617100E+00, -.10981500E+01, -.61722700E+00, 0.39705300E+00, 0.27165900E+00, -.71392600E-01, -.51597900E+00, -.63415600E+00, -.49256400E+00, -.19601400E+01, -.16421600E+00, -.12188700E+00, 0.10011400E+01, 0.74589900E+00, -.29301400E+00, 0.31620200E-01, 0.39655900E+00, 0.34811100E+00, -.22538200E+00, -.95310600E-01, -.50399600E+00, 0.53545400E+00, 0.13236400E+00, 0.60345900E+00, 0.11434700E+01, -.34840200E+00, 0.50261000E+00, 0.33765000E-01, -.25514400E+00, 0.11187000E+00, -.76374400E+00, -.19171900E+01, -.89353100E+00, -.80813200E+00, 0.51087300E+00, -.34755800E-01, -.16069500E+00, -.29681200E+00, -.11167900E+00, 0.19241700E+00, 0.22266500E+00, 0.30140500E+00, -.41630100E+00, 0.30299200E+00, -.12144000E+00, -.67489500E+00, 0.40666900E+00, -.44501100E+00, -.16010600E+00, -.46804100E+00, -.24047000E+00, 0.37583800E+00, 0.12862800E+01, 0.69688400E-01, -.25105600E+01, -.64313900E-01, 0.33039200E+00, 0.92216000E+00, -.12065700E+01, -.18636700E+00, -.27689000E+00, 0.20288300E+02, 0.75746600E+02, 0.40873800E+03, -.76212500E+03, -.23437500E+03, -.27994100E+03, 0.34671500E+03, -.10003000E+03, -.75538300E+03, 0.37958600E+03, -.44544300E+03, 0.35737200E+03, 0.13142200E+03, -.24445100E+03, 0.11157000E+04, 0.47667200E+03, 0.63069900E+03, -.11264500E+03, -.10707000E+04, 0.46407500E+04, -.23360400E+04, -.26208400E+04, -.23220000E+04, -.13529600E+04, -.24124200E+04, -.18742800E+04, -.17138200E+04, -.12911700E+04, -.21103000E+04, -.20272200E+04, -.68070900E+03, 0.32570300E+03, 0.14226100E+03, 0.33905200E+03, -.27685900E+03, -.30654100E+03, 0.39860100E+03, 0.12148800E+03, 0.83754100E+03, -.43343300E+03, 0.22140400E+03, -.49665000E+02, 0.26218300E+02, 0.51217400E+02, 0.25110200E+02, -.64240800E+00, 0.26932900E+02, 0.17593700E+02, 0.39055100E+02, 0.24048800E+00, 0.12365700E+02, 0.23616500E+02, 0.45372000E+04, -.25004700E+04, -.35711800E+04, -.22565300E+04, 0.35256200E+02, 0.56225400E+03, -.34266100E+04, -.17363900E+04, -.15109300E+04, 0.35344400E+03, -.15731000E+04, 0.17331400E+04, -.83227500E+03, -.66772400E+03, -.86610200E+03, -.88657900E+03, -.14087400E+03, -.60855700E+02, 0.80526900E+02, -.85338800E+03, -.25617100E+03, -.20496800E+04, -.69489100E+03, 0.34714800E+03, -.96837900E+03, 0.34714100E+03, -.22689000E+03, -.77849900E+03, 0.37138200E+03, -.46315200E+03, 0.18729900E+02, -.64360600E+03, 0.12943600E+03, -.22103400E+04, 0.11001600E+04, -.12430000E+04, 0.11303300E+04, 0.37804700E+03, -.58417500E+03, 0.56249100E+03, 0.10369000E+03, 0.12331700E+04, -.52478400E+03, 0.81996000E+02, -.23814100E+04, 0.12483600E+04, 0.30220000E+04, 0.11865900E+04, -.37914400E+02, -.41667000E+03, 0.12956300E+04, 0.14018300E+03, 0.19907600E+03, -.10288300E+03, 0.40347100E+03, 0.34659800E+04, -.17174500E+04, -.18689100E+03, -.17474100E+04, -.11044300E+04, -.19557900E+03, -.12589700E+04, -.33983600E+03, -.13287600E+04, -.24659600E+03, -.16860600E+04, -.90771700E+03, 0.47273100E+03, 0.13354000E+04, 0.45428800E+03, 0.37685600E+03, 0.70992800E+03, -.59000500E+03, -.80133000E+03, -.59384500E+03, 0.86175000E+03, 0.34319500E+03, 0.26427800E+04, -.13243800E+04, -.16473500E+04, -.13208300E+04, -.68157500E+03, -.19926600E+03, -.13305200E+04, -.10801100E+02, -.90671700E+03, -.37677200E+03, 0.88596100E+03, 0.65374300E+04, -.33726500E+04, -.38814300E+04, -.32757200E+04, -.12911000E+04, -.21125200E+04, -.40728400E+04, -.29922700E+04, -.24367000E+04, -.18456300E+04, -.32243200E+04, 0.22724300E+04, -.11352500E+04, -.19171400E+04, -.11318100E+04, -.71647400E+03, -.90553200E+02, -.25847200E+04, -.43018100E+03, -.95916700E+03, -.23567600E+03, 0.19000400E+04, -.40259700E+03, 0.21832400E+03, 0.42175300E+03, 0.17936400E+03, -.68249100E+02, -.17629200E+03, 0.44613600E+03, -.16067900E+03, 0.33548700E+03, -.11565500E+03, -.88019300E+01, -.73239900E+03, 0.34418500E+03, -.11824900E+03, 0.35436200E+03, 0.93144300E+02, -.11833300E+03, 0.41019900E+03, 0.45976100E+03, 0.10704800E+04, -.40237500E+03, 0.19924700E+01, 0.94376700E+02, 0.27378800E+02, -.78903300E+02, -.16681900E+02, -.59295800E+02, -.16342300E+02, 0.16246700E+01, 0.27557500E+02, -.49046500E+02, 0.67723000E+02, -.75460600E+02, 0.10606900E+03, -.64366000E+02, -.17987900E+02, -.64107000E+02, 0.19544700E+03, -.89346700E+02, -.58346400E+02, 0.12081400E+03, 0.89716400E+02, -.20695300E+03, 0.29209300E+03, 0.38720600E+01, -.14430300E+03, 0.13959900E+02, -.13413800E+02 },
        { 0.33814800E+01, -.42461000E+00, -.15956400E+00, -.13103200E+01, 0.32679700E+00, 0.45930200E+01, 0.83391500E+00, -.14508500E-01, 0.16164000E+01, -.19743800E+01, 0.27751400E-01, 0.18842700E+00, 0.48788200E+00, 0.97471400E+00, -.34417400E+00, -.93623700E+00, 0.15528800E+00, -.38821600E+00, 0.32839500E+00, 0.16760200E+00, 0.40124400E+00, -.22778200E+00, -.60467600E-01, -.44793900E-02, 0.73455900E+00, -.49210400E-01, -.38384500E+00, 0.18734100E+00, 0.45878100E+00, -.62337000E+00, 0.15197500E+00, -.17653600E+00, -.39115400E+00, 0.49432600E+00, -.22538500E+00, 0.24015400E+00, 0.45630400E-01, 0.35569400E+00, -.81929400E-01, -.46712100E+00, -.32470800E-01, 0.11691200E+00, 0.83208200E+00, -.65577500E+00, -.64562200E+00, -.14659100E+00, 0.97399100E-01, -.15350100E-01, -.22616700E-01, -.22032400E+00, -.14163900E+01, 0.59044200E+00, 0.52161500E+00, 0.87558400E+00, 0.10462100E+01, 0.14574900E+00, 0.19994200E+00, 0.15627900E+00, -.11603500E-01, 0.36915600E+00, -.13034500E+01, -.16485400E+01, -.67668100E+00, 0.99442900E+00, -.46936800E+00, 0.13746300E+00, -.31056000E+00, 0.82806200E-01, -.96578400E-01, 0.26009200E-02, -.33154000E+00, 0.23826200E+00, -.18270400E+00, 0.33089100E+00, 0.32355500E+00, 0.76774100E+00, -.36334000E+00, 0.10275700E+01, 0.47252700E+00, -.75939400E+00, -.13827300E+00, -.11388600E+00, -.40835400E+00, 0.17305400E+00, 0.95711700E+00, 0.22731500E+00, -.92407100E-01, -.25424700E+00, 0.22238400E+01, -.11151900E+01, -.75144700E+00, -.40677600E-01, 0.83729700E+03, 0.93566300E+03, -.47762300E+03, -.21425800E+03, -.29219000E+02, 0.64719500E+03, -.26161100E+03, 0.11787700E+04, -.58872200E+03, -.51184700E+03, -.59026900E+03, -.21099400E+03, -.31456000E+03, 0.59546300E+03, 0.33137200E+03, -.48664600E+03, -.23803300E+03, -.50747800E+03, 0.96616100E+04, -.48347300E+04, -.37033200E+04, -.48334700E+04, -.44953500E+03, -.53474100E+03, -.24044300E+04, 0.10915700E+04, -.22007200E+04, -.22217700E+03, -.41786200E+04, -.25495400E+04, 0.12603500E+04, 0.13281000E+04, 0.12736900E+04, 0.37638800E+03, -.24345900E+03, 0.89671000E+03, 0.55761700E+03, 0.14589100E+04, -.35844400E+02, 0.10630600E+04, -.24139100E+02, 0.13472800E+02, -.50656400E+02, 0.12170200E+02, -.24150200E+02, -.40866300E+01, 0.45466800E+02, 0.43263900E+02, 0.78653100E+01, -.31237300E+02, -.76125600E+01, 0.21004800E+04, -.13430700E+04, -.31015700E+04, -.10515900E+04, 0.14462300E+04, 0.10960000E+04, -.22416700E+04, -.42019600E+03, -.67945300E+03, 0.11814000E+04, -.11941500E+04, 0.16787400E+04, -.79521000E+03, 0.20690800E+02, -.83954300E+03, -.63129400E+03, 0.84889000E+03, -.15207100E+03, 0.67819300E+02, -.15317000E+04, 0.13019800E+04, -.17027100E+04, -.32257500E+03, 0.16572500E+03, -.11231900E+04, 0.16150200E+03, -.29559600E+02, -.38254900E+03, 0.20456600E+03, -.34347100E+02, -.42195600E+02, -.97904400E+02, -.24692000E+03, -.45991800E+04, 0.22951100E+04, -.23400700E+04, 0.23050900E+04, -.11836100E+04, -.15920800E+04, 0.70979200E+03, -.96718600E+03, 0.14955100E+04, -.10905500E+04, 0.18875800E+04, -.17748500E+04, 0.97312400E+03, 0.25098600E+04, 0.88846800E+03, -.34588900E+03, -.21985800E+03, 0.58666400E+03, -.19099600E+03, 0.10432100E+03, -.23708800E+03, 0.59031700E+03, 0.10188100E+04, -.49115400E+03, 0.14770600E+04, -.50874100E+03, -.79567800E+03, 0.47807100E+02, -.25152400E+03, 0.22010400E+02, -.57230000E+03, 0.17484800E+03, -.11099200E+04, -.14050300E+04, 0.72466700E+03, 0.54377000E+03, 0.70345600E+03, -.88397100E+02, 0.27736200E+03, 0.57870300E+01, -.82147900E+03, 0.29624000E+03, 0.49400100E+03, 0.10685300E+04, -.62302900E+03, 0.30740600E+03, -.68049600E+03, 0.31090800E+03, -.18246500E+03, 0.29148500E+03, -.94515300E+03, -.13418500E+04, 0.21076800E+03, 0.19272300E+03, 0.81950400E+03, 0.11575900E+05, -.59048200E+04, -.51238000E+04, -.57942900E+04, 0.39425500E+03, 0.57359100E+03, -.42405400E+04, 0.68977300E+03, -.31847000E+04, 0.91421000E+03, -.53350900E+04, -.11982200E+04, 0.60128900E+03, -.20716400E+04, 0.59842200E+03, -.26974900E+03, 0.57552300E+03, -.21553000E+04, -.25113900E+04, 0.52995100E+03, 0.53000200E+03, 0.10203400E+04, -.13421800E+04, 0.69325900E+03, -.12935600E+02, 0.66992200E+03, -.15862800E+03, -.65362500E+02, 0.24667200E+03, -.36376800E+03, 0.36906000E+03, 0.94819600E+02, 0.91756400E+03, -.57276300E+03, 0.26270100E+03, -.19087600E+02, 0.28505000E+03, -.96161500E+02, -.37154500E+03, 0.41471100E+03, 0.52298700E+03, 0.59140200E+03, -.37721400E+03, -.10688100E+03, 0.12416200E+03, -.37577900E+02, -.13693100E+03, 0.70634500E+02, 0.26334900E+03, -.10761500E+03, 0.69357500E+02, 0.44441600E+02, -.56397900E+02, 0.17025400E+03, -.38949800E+02, -.49332200E+03, -.30523500E+02, -.87428900E+01, -.50845200E+03, 0.52483700E+03, -.21813400E+03, 0.14026700E+03, -.18338100E+03, 0.18037200E+03, -.15007900E+03, 0.54051800E+03, 0.56789400E+03, -.21420400E+03, 0.14150400E+02, -.30685400E+03 },
        { -.19699900E+01, -.47868900E+00, 0.57952000E-01, 0.31675200E+00, -.10047600E+01, -.42595300E+01, 0.52135900E+00, -.43265000E+00, -.91036100E+00, 0.19290200E+01, 0.44607000E-01, -.30901900E-01, -.16106100E+00, -.26676300E-01, -.89015000E+00, 0.73093900E+00, 0.87667800E+00, -.95865000E+00, -.46342400E+00, -.36763400E+00, -.16940200E+00, 0.91843800E-01, 0.18149100E+00, 0.51700200E+00, -.13048800E+01, -.59294100E-01, -.49679400E+00, -.17265700E+01, 0.13537900E+01, 0.26518000E+00, -.33952900E+00, 0.14896500E-01, -.83542400E+00, -.69607500E+00, 0.12354800E+00, -.10472800E+00, 0.21677700E+00, -.12412700E+01, 0.72406700E+00, -.73224000E+01, -.18764300E+00, -.67521900E+00, 0.75104900E+00, 0.42081400E+00, -.36836700E+00, 0.13022000E+00, 0.19721800E+00, -.10076400E-01, 0.21563400E-01, 0.70895500E-01, -.48188600E+00, 0.37678000E-01, -.22662100E+00, -.36136500E+00, -.19087600E+00, 0.51333200E+00, -.58638000E+00, 0.22331400E+00, 0.13040400E-03, -.67865800E-01, -.12771400E+00, 0.10337300E+00, -.28925800E+00, -.52216800E+00, -.29913200E+00, -.89768100E-01, -.58608800E-01, -.15337500E+00, 0.38537800E-03, 0.14768400E-01, 0.56478300E+00, -.45810100E-01, -.47676700E+00, 0.26507700E+00, -.22047700E+00, -.27830300E+00, 0.10575000E+00, 0.21440300E+00, 0.42555500E-01, -.69992300E+00, 0.59266700E-01, 0.29845000E+00, 0.10178500E+01, 0.21388700E+00, -.21780400E+01, -.12109700E+00, 0.53971800E-01, 0.69936300E+00, -.21060300E+00, -.39804200E+00, 0.28216400E+01, 0.38382500E-01, 0.22484500E+00, 0.46788700E+03, -.56183700E+03, -.25908300E+03, -.69757300E+03, 0.33288400E+03, 0.20995200E+03, -.53469300E+03, 0.26697300E+03, 0.71602800E+03, 0.26669300E+03, 0.87496500E+02, -.26481400E+01, -.25220900E+02, -.43828700E+03, 0.55473500E+01, 0.35067500E+02, 0.51576300E+03, -.12023100E+04, 0.60576600E+03, 0.12209600E+03, 0.59630200E+03, -.25278900E+03, 0.56050200E+03, -.31316400E+03, -.29662700E+03, 0.11024400E+04, 0.26220500E+03, 0.13536000E+04, -.93739500E+02, 0.44162700E+02, -.27935300E+03, 0.46477400E+02, -.67931100E+02, 0.11441200E+03, -.80958000E+02, -.35858300E+03, 0.19615100E+03, -.43595100E+02, 0.17474600E+03, -.22099500E+02, 0.11298200E+02, 0.39065000E+02, 0.10990200E+02, -.11269900E+02, -.97749200E+01, -.19301000E+02, -.16178900E+02, 0.22845300E+01, 0.16874000E+01, -.10405900E+02, -.92820500E+03, 0.36821700E+03, -.10597300E+04, 0.46186800E+03, -.20423100E+03, 0.94216900E+03, -.77037300E+03, -.35953100E+03, 0.53405300E+03, 0.67643000E+03, 0.17595800E+04, -.90424000E+03, 0.46532900E+03, -.12170600E+03, 0.45214700E+03, -.47645700E+03, -.41778000E+03, 0.30357300E+03, -.28874900E+03, 0.42432700E+03, -.38231200E+03, 0.48356300E+03, -.74672300E+02, 0.55140700E+02, -.12263000E+03, 0.37952900E+02, -.39534200E+02, -.33141400E+03, 0.19575000E+03, -.11477300E+03, 0.88132200E+02, -.36902100E+03, 0.94499700E+02, 0.50069400E+03, -.25172800E+03, -.27390900E+03, -.25267000E+03, 0.60817800E+03, 0.39603400E+03, -.57002700E+02, 0.26782500E+03, -.24140200E+03, 0.37860500E+03, -.17655300E+03, 0.66924900E+03, -.28015700E+03, 0.29810600E+03, -.33293200E+03, 0.41741500E+03, -.83735000E+02, 0.38988300E+02, -.10323200E+03, -.84277600E+03, 0.21003800E+02, -.48205300E+03, 0.21486700E+03, -.10414500E+03, -.45002200E+01, -.10567200E+03, -.32851700E+03, -.47452700E+03, -.27386000E+03, -.30199600E+03, -.10360000E+03, -.40567000E+03, -.12186600E+03, -.40535600E+03, 0.20634900E+03, 0.52526700E+03, 0.20362400E+03, 0.21275200E+03, 0.37213700E+03, -.39765400E+03, -.34821400E+03, -.21639600E+03, 0.31026100E+03, 0.23864700E+03, -.10067200E+04, 0.50289700E+03, 0.45649400E+03, 0.50315500E+03, -.13188500E+02, 0.34186000E+03, -.14825100E+03, -.27265300E+03, 0.61286400E+02, 0.24333300E+03, 0.76668600E+03, -.21871800E+04, 0.10673700E+04, -.29893200E+03, 0.10831000E+04, -.14986000E+03, 0.14970900E+04, -.10969600E+04, -.86321700E+03, 0.10976500E+04, 0.10478400E+04, 0.27757400E+04, -.99725700E+03, 0.49832200E+03, -.37390100E+03, 0.49956600E+03, 0.86435300E+02, 0.80041000E+03, -.38248700E+03, 0.25310700E+03, 0.10148300E+02, 0.55497800E+03, 0.75022800E+03, -.62212100E+03, 0.31537300E+03, -.11133400E+03, 0.31217200E+03, 0.16084800E+02, 0.11463400E+02, 0.42160300E+03, -.21407900E+02, 0.15357800E+03, 0.14264700E+02, 0.19178800E+03, -.57341800E+03, 0.28080600E+03, -.14812700E+02, 0.28628800E+03, 0.61729000E+02, 0.77295400E+02, 0.12333400E+03, -.14942800E+03, 0.41298700E+03, 0.47833900E+02, 0.36128200E+03, 0.57873500E+01, -.45292100E+02, 0.63044000E+02, -.13694300E+01, -.29490000E+02, -.19916500E+02, 0.41969000E+01, -.12718500E+02, 0.29483800E+02, -.89864700E+01, -.14885900E+02, 0.41215800E+03, -.26671300E+02, 0.24276300E+02, 0.24572700E+03, 0.19759400E+02, 0.59502600E+02, -.47113300E+02, 0.30603300E+03, 0.37592600E+02, -.10781600E+03, 0.35416800E+03, -.35507900E+03, -.19458300E+03, 0.51325700E+02, 0.65007500E+02 },
        { 0.95169500E+00, -.11997200E+01, -.17677900E+00, -.92854100E-01, 0.36813500E-01, -.11959200E+01, 0.24324800E+01, -.19826400E+01, 0.93373600E+00, -.47275900E+00, -.84699500E-02, 0.10628800E+00, -.45061600E+00, 0.41426000E+00, -.54702100E+00, 0.13686000E+01, 0.11952000E-01, -.11084700E+01, -.98266700E-02, 0.66408700E+00, 0.23949300E+00, -.17029400E+00, -.55753200E-01, -.14901100E-01, 0.71685500E+00, 0.57002600E-02, -.19264400E+00, -.52198000E+00, 0.52756100E+00, -.72448200E+00, 0.54391300E+00, -.31962800E-03, -.20866200E+00, -.24801600E-01, 0.75476800E-02, 0.11995000E+00, -.50963300E-01, 0.42976000E+00, 0.37432700E+00, 0.26212100E+01, 0.16030600E-01, -.61505900E-01, 0.47957100E+00, 0.76939700E+00, -.57512700E+00, -.45760600E-02, 0.12883100E+00, -.13444700E-01, 0.37814500E-01, -.25216500E-01, 0.16651600E+01, -.17827600E-01, -.44945400E+00, -.67435600E+00, -.33695300E+00, -.24014200E+00, -.39331300E+00, 0.16177200E+00, -.19755000E-01, 0.16356900E+00, -.52786800E+00, -.19965800E-01, -.35743800E-01, 0.15923600E+00, -.25502300E+00, 0.96892100E-01, -.10498200E+00, 0.14086900E+00, 0.50467100E-01, 0.31378500E-02, -.23065700E+00, 0.23948400E+00, -.46858900E+00, 0.32075000E-01, 0.86230400E-01, -.62033700E+00, 0.75791300E-01, 0.94289200E-01, 0.53271200E-01, 0.11512100E+00, 0.23606400E-01, -.18961400E+00, 0.69066800E-01, -.70550900E-01, 0.25318100E+00, -.12766800E+00, 0.35262500E+00, 0.49972300E+00, 0.63491700E+00, 0.42498100E-01, 0.52406300E+00, 0.11043000E-02, -.25418100E+00, 0.17098300E+00, 0.44340900E+03, 0.21873700E+03, 0.15289800E+03, -.16881700E+02, -.55246100E+03, 0.39890700E+03, -.19811500E+03, -.55177100E+03, -.19838600E+03, -.10592900E+03, -.77642500E+02, -.72734500E+02, -.23699900E+02, -.75477100E+02, -.11683200E+03, 0.20776500E+03, -.15023500E+04, 0.72789100E+03, 0.77050900E+03, 0.75445400E+03, 0.48990800E+03, -.52334900E+03, 0.74077500E+03, 0.20134400E+03, 0.28880900E+02, -.23681800E+03, -.22024200E+03, -.14062300E+03, 0.67863800E+02, 0.49906200E+03, 0.71065300E+02, 0.81612300E+02, -.33593000E+02, 0.33750100E+02, 0.41075800E+02, -.13090500E+03, -.24516800E+01, -.55309600E+02, 0.58772400E+02, -.29133000E+02, -.73069900E+02, -.29394700E+02, 0.74494000E+01, -.84735600E+01, 0.43309200E+01, 0.17870500E+02, -.81486700E+01, -.27883000E+01, -.15026400E+01, -.65766700E+03, 0.32367300E+03, 0.29799500E+04, 0.32921600E+03, -.88357500E+02, -.13923400E+04, 0.11780100E+04, 0.46141500E+03, -.22110600E+02, -.11147700E+04, -.10247000E+04, 0.98146200E+03, -.48978500E+03, 0.23080800E+03, -.49092400E+03, 0.56256300E+03, 0.46726800E+02, -.35368100E+03, 0.19255200E+03, -.25230500E+03, -.32740700E+02, 0.49873300E+03, 0.72872300E+03, -.37701800E+03, -.60038800E+02, -.36398000E+03, 0.98685800E+02, 0.51739700E+03, -.25755500E+03, 0.61594700E+02, -.38257200E+03, 0.40255800E+03, 0.57277700E+02, -.15242100E+04, 0.76180100E+03, 0.42151200E+03, 0.76276400E+03, -.47557000E+03, -.62367300E+03, 0.20089300E+03, -.51049600E+03, 0.65537000E+03, -.59024700E+03, 0.16664100E+04, -.13996300E+04, 0.68084900E+03, -.14741700E+04, 0.69916600E+03, -.71935100E+02, 0.52524000E+03, 0.27024200E+03, 0.37805700E+01, 0.89397000E+03, 0.38080700E+03, 0.10203500E+04, -.95653900E+03, 0.48031100E+03, -.52381900E+03, 0.47669100E+03, 0.59003600E+03, 0.32310300E+03, 0.29709000E+03, 0.35535400E+03, 0.51980300E+03, 0.31148700E+03, 0.87271700E+03, 0.67875900E+03, -.33719700E+03, -.61814800E+03, -.34056400E+03, -.18459000E+03, -.22372800E+03, 0.24036900E+03, 0.31130900E+03, -.43270700E+02, -.24544000E+03, -.24271600E+03, 0.87826600E+03, -.43972300E+03, -.70055000E+03, -.43874700E+03, 0.10858900E+03, -.23150100E+03, 0.15925800E+03, 0.58061500E+03, -.80453900E+00, -.18186300E+03, -.10131800E+04, -.24439000E+04, 0.11924900E+04, 0.21503500E+04, 0.12287300E+04, 0.42309500E+03, -.16452100E+04, 0.19301700E+04, 0.75301300E+03, 0.53899800E+03, -.11648000E+04, -.70935300E+03, 0.60666600E+03, -.30335300E+03, -.47430000E+03, -.30370800E+03, 0.18094600E+03, -.36605900E+03, 0.43799500E+03, 0.48766100E+03, 0.58450700E+01, -.28292300E+03, -.13558400E+04, 0.35538300E+03, -.17616800E+03, 0.65878700E+03, -.17808300E+03, -.45189600E+02, -.13159600E+02, -.27229100E+03, 0.22800900E+02, -.13827000E+03, -.67002400E+02, 0.35456400E+02, 0.40893500E+03, -.20656800E+03, 0.51074900E+03, -.20344600E+03, 0.54777100E+02, -.14763500E+02, -.20912200E+03, -.36193700E+02, -.29599500E+03, -.91119700E+01, 0.46696300E+02, -.73338100E+02, 0.62000600E+02, -.26417900E+02, -.44359000E+01, 0.22447200E+01, 0.23806200E+02, 0.32881500E+01, 0.28177100E+02, -.12016100E+02, -.17314000E+02, 0.35038700E+02, -.49378500E+03, -.20889100E+01, -.44806700E+02, -.16969100E+03, -.22624000E+03, -.39211700E+02, 0.30535700E+02, -.45221600E+03, -.42887900E+02, 0.10800900E+03, -.92352800E+02, 0.33923000E+03, 0.55302600E+02, 0.21859900E+02, -.18489200E+02 },
        { -.78287600E+00, 0.18190100E+01, 0.22728500E+00, 0.62950500E+00, 0.22537000E-01, 0.36244500E+00, -.18916300E+01, 0.18459900E+01, -.77423400E+00, 0.75718600E-01, -.27821800E-01, -.85909500E-01, 0.42685500E+00, -.82361600E+00, 0.10975200E+01, -.23466600E+00, -.61250300E+00, 0.56749000E+00, 0.11204400E+00, 0.80204500E+00, 0.32802300E+00, 0.37147700E-01, 0.20961600E+00, -.61252300E-01, 0.15365200E+00, 0.15518200E-01, 0.18828400E+00, 0.15697900E+00, 0.16404300E+00, 0.94809200E+00, 0.12792300E+00, 0.17081900E+00, 0.13233000E+00, -.19790500E+00, -.13228000E+00, 0.17685100E-01, -.60578500E-01, 0.26352800E+00, -.45764200E+00, 0.28599800E+01, -.79245900E-02, 0.27982800E+00, -.23712600E+00, -.17057800E+00, 0.59970200E+00, 0.78697800E-01, 0.17584000E-02, 0.15723700E-01, -.84373000E-01, 0.52820100E-01, -.82715400E+00, 0.35613600E-01, 0.15070400E+00, -.11349900E-01, 0.20643200E+00, 0.34318500E+00, 0.46121400E-02, -.53897800E-01, 0.39055500E-01, -.22908700E+00, 0.35632600E+00, 0.33479400E+00, -.14183800E+00, -.13558100E+00, 0.77134500E-01, -.74674000E-01, 0.82444100E-01, 0.61778600E-02, -.10046500E+00, -.34359000E-01, -.20147700E+00, 0.75179900E-01, 0.37385900E-01, 0.65147600E-02, -.22424900E+00, 0.61735500E-01, 0.27276000E-01, -.27027500E-01, -.12136100E+00, 0.15621700E+00, -.30526400E-01, 0.18500500E-01, -.78070100E-01, 0.70500200E-01, -.34117400E+00, -.86029200E-01, 0.82173300E+00, -.17991200E+00, -.53020800E+00, -.47590700E-01, 0.13023800E+01, -.18267600E-01, -.25860500E+00, 0.11994800E+00, -.62405300E+00, -.16142100E+03, 0.69101000E+02, -.21536000E+02, -.89884500E+03, 0.55385200E+03, -.27418900E+03, -.39377600E+03, -.27729700E+03, -.56209400E+02, -.12912100E+03, 0.41505500E+03, 0.43305700E+03, 0.14359100E+03, -.14767100E+03, 0.42586100E+03, 0.94006700E+03, -.49449300E+03, -.11528000E+04, -.46717100E+03, 0.51755100E+03, -.86811700E+02, -.73375300E+03, -.54424700E+03, -.72719700E+03, 0.26652800E+03, -.87812500E+03, -.14184600E+04, 0.69883900E+03, 0.10739900E+04, 0.70888500E+03, 0.52492700E+02, -.25137600E+03, 0.33770000E+03, 0.50704300E+02, 0.76510900E+03, -.20759200E+03, 0.37591300E+03, 0.56578500E+02, -.27314200E+02, -.82658500E+02, -.28197800E+02, -.59355000E+01, 0.16790700E+02, 0.16756300E+02, 0.46250000E+02, -.56648700E+01, 0.64236200E+01, -.37528500E+00, 0.12939700E+04, -.80351700E+03, 0.50759100E+03, -.64433200E+03, 0.69836800E+03, 0.23953900E+03, -.12320100E+04, -.96985400E+03, -.11674300E+04, 0.50354400E+03, -.16885200E+04, 0.32644600E+03, -.13773600E+03, 0.25550800E+03, -.16302400E+03, 0.99827400E+02, 0.23475400E+03, -.14327100E+03, -.20118000E+03, -.60652100E+03, 0.25079500E+03, 0.58947700E+03, 0.16725800E+03, -.81260000E+02, -.21041900E+03, -.82644600E+02, -.74120700E+02, 0.45182400E+01, 0.34586800E+01, -.22483100E+03, -.24028800E+03, -.41995500E+02, 0.46099700E+03, -.48983000E+03, 0.24237300E+03, -.13467100E+04, 0.25019700E+03, -.26674400E+03, -.24828300E+03, -.31255400E+02, 0.13803100E+03, 0.39899800E+03, -.17618600E+03, 0.12931700E+04, -.27144000E+04, 0.14020200E+04, 0.48097000E+03, 0.13556000E+04, -.51693100E+03, -.27393200E+03, 0.11295400E+04, 0.25075400E+03, 0.12326100E+04, -.40408200E+03, 0.14492100E+04, 0.16882000E+03, -.74322900E+02, -.16648900E+03, -.84966500E+02, -.54471100E+01, 0.12458000E+03, -.11345400E+03, 0.79430100E+02, -.30340200E+02, 0.12454600E+03, 0.26928000E+03, -.16050900E+03, 0.90534900E+02, 0.59826900E+02, 0.80347600E+02, -.29980900E+02, 0.19138000E+03, -.51915400E+02, -.25113100E+03, 0.47625200E+02, 0.23942600E+03, 0.21792000E+03, 0.99749300E+03, -.50043600E+03, -.10112900E+04, -.49892000E+03, 0.10143300E+03, 0.11685400E+03, -.69215600E+03, -.28412000E+03, -.31293700E+03, 0.83134300E+02, -.57940700E+03, 0.81110800E+03, -.49615200E+03, -.80406500E+03, -.39901700E+03, 0.88385500E+03, 0.87085200E+01, -.11816600E+04, -.10118400E+04, -.10688200E+04, 0.53089900E+03, -.15814800E+04, 0.13809600E+04, -.68861900E+03, -.21488000E+04, -.69132500E+03, 0.75059900E+02, 0.24615200E+03, -.13771400E+04, -.72112600E+03, -.62194600E+03, 0.26577300E+03, -.14583900E+04, -.32373600E+03, 0.17310700E+03, 0.48838800E+03, 0.16082200E+03, -.14431800E+03, 0.61082200E+01, -.18301300E+03, -.38918100E+03, -.34022100E+02, -.26216500E+02, 0.56535600E+03, 0.41941100E+03, -.22409700E+03, 0.18968900E+03, -.21033300E+03, -.17146700E+03, -.16284000E+03, -.33268700E+02, 0.28719700E+03, 0.17130100E+03, -.23050500E+03, 0.20029600E+03, -.25939200E+02, 0.59479100E+02, -.12577100E+03, 0.25498600E+02, -.12342400E+02, 0.38989500E+02, 0.34572700E+02, 0.56985300E+02, -.57621100E+02, -.90365400E+01, 0.28806500E+02, -.55480800E+03, -.51214800E+02, -.51761300E+02, -.33724500E+03, -.96731400E+02, 0.18120800E+01, 0.26069200E+02, -.53496000E+03, 0.42232700E+02, 0.95815200E+01, 0.27275600E+03, 0.39093800E+03, -.46116200E+02, 0.25199000E+02, -.28779000E+02 },
        { -.32052500E+01, 0.30697800E+00, 0.25228300E+00, 0.36220300E+00, 0.17175500E+00, -.42108300E+01, -.15363200E+01, -.18298900E+01, -.14139800E+01, 0.22754700E+01, 0.23658500E-01, -.87807100E-01, -.15537600E+01, -.10208600E+01, 0.93340700E-01, -.29765300E+00, 0.11549500E+01, 0.72368300E+00, -.59974400E-01, 0.11177800E+01, -.31617700E+00, -.45593500E-01, 0.13624500E+00, 0.18699800E+00, 0.29221200E+00, -.63789600E-03, 0.99637300E+00, 0.10308400E+01, -.16889800E+01, 0.15810700E+01, -.72600000E+00, -.78150900E+00, -.40643200E+00, 0.22471100E+00, -.83940900E-01, -.51609600E+00, 0.71220300E-01, 0.90606100E-01, 0.17726300E+00, -.92853600E+01, 0.14438400E+00, 0.35778800E+00, 0.90820700E+00, 0.40441600E+00, 0.50075400E+00, 0.21675700E+00, 0.82042900E+00, -.23442600E-01, 0.18506100E+00, -.30673200E+00, 0.29053100E+01, -.57966200E+00, -.54863100E+00, -.14051500E+01, -.14607100E+01, 0.49213900E+00, -.31124100E+00, -.35001600E-01, -.13352400E+00, 0.57154900E+00, -.85943600E+00, -.13579500E+01, -.61205900E+00, -.19025300E+01, 0.11803800E+01, -.17748300E+00, 0.21964000E+00, -.31654300E+00, 0.18505600E+00, 0.35524200E-01, -.90183700E-01, -.18016300E-01, 0.91238200E+00, -.17371400E+00, 0.58285400E-01, 0.31068200E+00, -.44080900E+00, -.12466500E+01, 0.17710500E+00, 0.31868000E+00, 0.54476300E-01, 0.48749300E-01, -.17355100E+01, -.30574100E+00, 0.14390300E+01, 0.17459600E+00, 0.31590800E+00, -.74214500E+00, 0.72449900E+00, -.85745400E+00, 0.31316600E+01, 0.54506400E-01, 0.46617700E+00, 0.13376200E+01, -.46992500E+00, -.23246800E+01, 0.15190400E+04, -.12143600E+03, -.30065400E+04, 0.11622700E+04, -.56927500E+03, 0.25768700E+02, -.57843500E+03, -.22648700E+03, -.78557500E+03, 0.37055800E+03, -.62202400E+02, -.59543500E+03, -.84669600E+03, 0.17799500E+04, 0.37147200E+04, -.19737400E+04, -.32980600E+04, -.18479300E+04, 0.20229400E+04, 0.95340400E+03, -.85677900E+03, 0.24578000E+04, -.39271700E+03, 0.14274100E+04, -.29161500E+04, -.34719500E+04, 0.17133400E+04, 0.31917000E+04, 0.17374600E+04, 0.56807300E+03, 0.57050900E+01, 0.63939000E+03, -.43418600E+02, 0.11556900E+04, 0.14682300E+03, 0.72851200E+03, 0.31187800E+03, -.15374100E+03, -.36487000E+03, -.15585700E+03, 0.11498700E+01, -.23000600E+02, -.14286500E+01, 0.69650000E+02, -.15333800E+02, -.29784800E+02, -.10878300E+03, -.69148000E+03, 0.95129300E+02, 0.59917000E+04, 0.34650300E+03, 0.13156700E+04, -.17396300E+04, -.31026900E+02, 0.51682300E+02, -.59435500E+03, -.82742300E+03, -.31122600E+04, 0.17754100E+04, -.84079100E+03, 0.13658200E+04, -.88844100E+03, 0.20260300E+04, 0.89651000E+03, -.12532200E+03, -.32640500E+03, -.25975200E+04, 0.98238700E+03, 0.35828400E+04, 0.22529800E+04, -.11409600E+04, 0.27500000E+03, -.11249500E+04, 0.49070100E+03, 0.18295900E+04, -.46572300E+03, 0.50330700E+03, -.11047300E+04, 0.13114100E+04, 0.92953400E+03, -.15416700E+04, 0.76667500E+03, -.17916700E+04, 0.77599100E+03, -.81545700E+03, -.34630700E+03, 0.11027900E+03, -.71657100E+02, 0.81778200E+02, -.30778300E+03, 0.56608600E+04, -.88020400E+04, 0.44440800E+04, -.28373700E+04, 0.43993500E+04, -.18319900E+03, 0.16166300E+04, 0.20405700E+04, -.29677800E+03, 0.36535600E+04, 0.74417000E+03, 0.53549800E+04, -.32742000E+04, 0.16554500E+04, -.52948700E+03, 0.16322700E+04, 0.14570500E+04, 0.63622900E+03, 0.68063700E+03, 0.16581900E+03, 0.10329400E+04, 0.68339700E+03, 0.31750600E+04, 0.89399300E+03, -.43212700E+03, -.15398300E+04, -.45010000E+03, -.42686600E+03, -.37599800E+02, 0.16036100E+03, 0.12635700E+03, 0.10198600E+04, -.14889100E+03, -.33959100E+03, 0.30208300E+04, -.15152800E+04, -.21629500E+04, -.15097000E+04, 0.10124600E+04, 0.85795500E+03, -.11517300E+04, 0.66507700E+03, 0.33075100E+03, 0.76345700E+03, -.38431300E+04, 0.86394400E+03, -.68253500E+03, -.13429000E+04, -.41309100E+03, 0.30954000E+04, 0.10682200E+03, -.65963200E+02, 0.27930800E+04, 0.94712500E+03, 0.10352200E+04, -.34745600E+04, 0.57579300E+04, -.28779700E+04, -.60425400E+04, -.28810200E+04, 0.92378800E+03, 0.19455000E+04, -.26527600E+04, 0.93137200E+03, 0.41393400E+03, 0.14560300E+04, -.65913000E+04, -.10597200E+04, 0.55106800E+03, 0.19139300E+04, 0.52726700E+03, -.24848600E+03, 0.50559600E+03, -.48418500E+03, -.10242400E+04, -.11381000E+04, 0.37492100E+03, 0.19175900E+04, 0.14421800E+04, -.74716300E+03, 0.10919400E+04, -.71899600E+03, -.14471200E+03, -.19827400E+03, -.30622600E+03, 0.10912300E+03, -.97562500E+03, -.45382500E+02, 0.88834100E+03, -.25178100E+03, 0.10187200E+03, -.40805700E+02, -.61931900E+01, 0.16927900E+03, -.11695800E+03, 0.12891400E+03, 0.75814900E+02, -.53943100E+02, 0.19166400E+03, 0.11382100E+03, -.18775600E+04, -.59458600E+01, -.15362500E+03, -.87935200E+03, -.76895500E+03, 0.55635300E+02, 0.80221000E+02, -.17659400E+04, 0.24670400E+02, 0.27357900E+03, 0.13733800E+04, 0.13414600E+04, -.52764600E+03, 0.14205900E+03, -.17616300E+03 },
        { -.17376100E+01, 0.55614300E+00, 0.29874200E-02, -.43525700E+00, -.44998200E+00, 0.83832800E+00, -.21231300E+01, -.17024000E+01, -.39073900E+00, 0.13146900E+01, -.14542500E+00, -.78243700E-01, -.24351000E+01, -.82312300E-01, -.11519400E+01, -.10003400E+01, -.21079700E+00, 0.21010100E+00, 0.17456400E+00, 0.72175600E+00, 0.47108500E-01, -.37446400E-01, -.59195500E-01, 0.20697100E-01, -.22939400E+01, 0.62137300E-01, -.15737500E+00, -.51051600E+00, 0.12739300E-02, -.47788800E+00, -.10812900E-01, 0.24034100E+00, -.26379000E+00, 0.15269800E+00, -.33282100E+00, 0.33406500E+00, -.21108300E+00, 0.10143900E+00, -.56406200E+00, 0.12835800E+01, 0.12624900E-01, 0.11419200E+00, -.13944500E+00, 0.35550900E+00, 0.29070600E+00, -.80754900E-01, -.30760700E+00, -.10259200E-01, 0.65154400E-01, 0.31301300E+00, 0.58745500E+00, -.38647200E+00, 0.10229800E+00, -.52444800E+00, 0.22769200E+00, 0.53897100E+00, 0.13996800E+00, 0.18146000E+00, -.17493900E-01, -.17330300E+00, 0.27539200E+00, 0.11638000E+01, 0.64758900E-01, 0.56891600E+00, -.54665200E-02, 0.67601900E-01, 0.63307100E+00, 0.36331500E+00, 0.31268800E-01, 0.49154300E-01, -.77259200E+00, 0.25007200E+00, -.36764600E+00, 0.55281500E-01, 0.12006700E-02, 0.45253800E+00, -.12730700E+00, 0.38357100E+00, -.28690300E-01, 0.28229600E+00, 0.32254500E-01, -.12930400E+00, -.42933900E+00, 0.17873900E+00, 0.80919800E+00, 0.11583500E+00, 0.72414900E-01, 0.23195400E+00, 0.13588200E+01, -.16695100E+00, -.22368100E+00, 0.55424800E-02, -.37178900E+00, 0.24617500E+00, 0.51373600E+00, -.69773200E+00, 0.34524800E+00, 0.61071900E+02, 0.33066600E+03, 0.55415100E+03, -.27988300E+03, -.43638300E+03, -.27941200E+03, 0.19829800E+03, 0.75037300E+02, 0.45978100E+03, 0.94751600E+03, 0.45058500E+03, 0.45094400E+02, -.78513600E+03, -.16999100E+04, 0.88589400E+03, -.35610500E+03, 0.84970400E+03, 0.62203200E+02, -.11433900E+03, -.25956800E+03, -.13099600E+04, -.50741000E+03, 0.13588700E+03, 0.85683000E+03, 0.32871500E+03, -.17065200E+03, -.11565800E+03, -.16578400E+03, -.94676700E+02, -.29879500E+03, 0.78385900E+02, 0.37024100E+03, 0.17158800E+03, -.16873500E+03, -.17367700E+03, -.15470500E+03, 0.77933800E+02, 0.59240300E+02, 0.77449800E+02, 0.25632000E+01, 0.48394800E+02, 0.25509900E+02, 0.35576200E+01, 0.37973900E+02, 0.23276500E+02, 0.86391600E+02, 0.21632200E+04, -.12595100E+04, -.21883400E+04, -.10767700E+04, 0.19238200E+03, 0.11900700E+04, -.12089600E+04, -.73885800E+03, -.15798000E+04, 0.12441500E+04, -.12670000E+04, -.24099400E+03, 0.14663300E+03, -.23576300E+03, 0.12141500E+03, -.81730000E+03, -.45332700E+02, -.41800200E+02, -.46439000E+03, -.23986500E+03, 0.13401300E+03, -.12020000E+04, -.75947600E+03, 0.39271400E+03, -.31334800E+03, 0.38032800E+03, -.26256800E+03, -.84008900E+03, 0.16346400E+03, -.38922700E+03, 0.22062700E+03, -.56449500E+03, -.21862000E+02, -.43616800E+03, 0.21532300E+03, -.17862400E+04, 0.22218500E+03, -.12750800E+03, -.30902300E+03, 0.89462000E+02, 0.25724500E+03, 0.53669900E+03, -.25502700E+03, -.10187900E+04, 0.93549900E+01, 0.62050800E+02, 0.19344600E+04, -.68336800E+01, -.60062200E+03, -.12788700E+04, 0.26983500E+03, 0.34665800E+03, 0.56288600E+03, -.11659300E+04, -.32687200E+03, 0.15605700E+04, -.76970200E+03, 0.84845100E+03, -.77824000E+03, -.88052300E+03, -.95385300E+02, -.41192200E+03, -.23814100E+03, -.76140100E+03, -.84806100E+02, -.12059800E+04, -.10245000E+04, 0.52659800E+03, 0.80402200E+03, 0.51431200E+03, 0.79837400E+02, 0.17725700E+03, 0.39206600E+02, -.31046300E+03, 0.22010200E+03, 0.34727300E+03, 0.74571100E+03, -.92365900E+03, 0.46030500E+03, -.92994000E+02, 0.46114700E+03, -.26655400E+03, 0.28458100E+02, -.40484100E+03, -.11725700E+04, -.25647800E+03, 0.67921500E+02, 0.13839300E+04, -.71708100E+03, 0.33670400E+03, -.89445900E+03, 0.35977000E+03, -.22229000E+02, 0.45502000E+03, -.95241000E+03, -.17422600E+04, -.14779700E+04, 0.73435600E+03, 0.70266700E+02, -.19756200E+04, 0.99116100E+03, -.10586600E+03, 0.98772900E+03, -.43150800E+03, -.49214100E+02, -.78809600E+03, -.22050000E+04, -.33503400E+03, 0.23216000E+03, 0.19791300E+04, 0.40339300E+01, 0.11012400E+02, -.51747500E+03, -.20133600E+01, -.13991300E+03, -.31053000E+03, 0.23379400E+02, -.78610900E+02, 0.45308000E+03, -.22640300E+03, -.28710900E+02, -.77766500E+02, 0.25641700E+02, -.49774700E+03, 0.36564200E+02, -.18919100E+03, -.15708100E+03, 0.13749900E+03, 0.29338200E+03, 0.34068000E+03, -.26018200E+03, -.36694900E+03, 0.20451000E+03, 0.71615100E+02, -.81410100E+02, -.11082300E+02, -.60208400E+01, 0.58245800E+02, 0.25467300E+02, 0.60528600E+02, -.86352400E+02, -.18152600E+02, 0.18331600E+02, 0.15885900E+03, 0.20262100E+02, 0.22017800E+01, 0.15151600E+02, 0.33583100E+03, -.13564200E+03, -.17309300E+02, 0.12107200E+03, 0.10620200E+03, -.36976200E+02, -.13399500E+03, -.22175000E+03, 0.14317600E+03, -.36246000E+02, -.34188100E+02 },
        { -.17133600E+01, -.49933800E+00, 0.54276400E-01, -.32958000E+00, -.14883200E+01, -.92675400E+00, -.23079200E+00, 0.18606800E-03, -.65005100E+00, 0.85626300E+00, 0.67732200E-01, -.10658400E+00, 0.51640300E+00, 0.10575600E+01, 0.99772500E-01, 0.52124900E-01, -.62413900E-01, 0.64642300E-01, 0.25382000E+00, -.12332500E+00, 0.23551900E+00, -.29325100E-01, 0.50638100E-01, -.22065900E+00, 0.15696100E+01, 0.39931400E-01, -.60330100E-01, 0.21349500E+00, -.34704100E+00, 0.30719100E+00, 0.29130600E+00, 0.55627100E+00, 0.63792800E+00, 0.32116000E+00, 0.36129200E+00, -.18702400E+00, 0.81998000E-02, 0.42471700E+00, -.69710500E+00, 0.16467200E+01, 0.11127800E+00, 0.69916100E-01, 0.17192200E+00, 0.12928500E+00, -.15388800E-01, -.84152300E-03, 0.13498800E+00, -.48484400E-03, -.12308100E-01, -.16586500E+00, 0.46739600E+00, 0.66663800E-01, 0.42004000E-03, 0.10477700E+00, -.15331500E+00, -.36297700E+00, -.11898900E+00, -.25408600E-01, -.12107500E-01, -.10995400E+00, 0.33672000E+00, -.29332700E+00, -.16475200E+00, -.46092300E-01, 0.46078300E-01, 0.45114700E-01, -.30684700E-01, -.59791900E-01, 0.22866700E-02, 0.43053000E-02, 0.23274700E+00, 0.25598200E-01, -.57771400E-01, 0.14317300E+00, -.54183300E-01, -.26924000E+00, -.20230800E-01, 0.33094200E-01, 0.19501100E-01, -.74170900E-01, 0.49252400E-01, 0.16090700E+00, -.62708900E+00, 0.45791900E-01, 0.48628900E+00, -.11434000E+00, -.11764500E+00, 0.16923800E+00, 0.13410900E+01, -.10729800E-01, -.33238500E+00, 0.22423700E-01, 0.86887700E-02, -.38562700E+00, 0.56369400E+00, 0.49402000E+00, -.69849400E-01, -.12309300E+00, 0.13248300E+04, -.99653300E+03, 0.49347300E+03, 0.77321400E+03, 0.49789500E+03, 0.22025300E+03, 0.27072400E+02, -.28140500E+03, -.59252800E+03, 0.79319300E+02, 0.62858400E+02, -.86524600E+03, -.17929100E+04, 0.95389800E+03, 0.20716300E+04, 0.89104400E+03, -.83200200E+03, 0.23886100E+03, 0.10826700E+04, 0.68223300E+03, 0.95613500E+03, -.12949300E+03, 0.17394900E+04, 0.17793900E+04, -.87806400E+03, -.16043000E+04, -.88983700E+03, 0.91006500E+01, 0.34151300E+03, -.37199100E+03, -.19739000E+02, -.72160700E+03, 0.28117300E+03, -.47093600E+03, -.14217500E+03, 0.69965000E+02, 0.13888500E+03, 0.70989700E+02, 0.17275700E+02, -.10695800E+02, -.24147100E+02, -.69093200E+02, 0.24866500E+02, -.13906000E+01, 0.34002600E+02, -.17507000E+04, 0.10199400E+04, -.29061500E+03, 0.87238100E+03, -.12624500E+04, -.26393200E+03, 0.18330500E+04, 0.12483500E+04, 0.11847700E+04, -.43110500E+03, 0.23632200E+04, -.32446700E+03, 0.13965100E+03, -.39735400E+03, 0.16218700E+03, -.12317200E+03, -.36421500E+03, 0.18625200E+03, 0.22020500E+03, 0.59626500E+03, -.17055100E+03, -.15636600E+04, -.13184200E+03, 0.73467900E+02, -.18681900E+03, 0.65081700E+02, 0.18264200E+03, -.10801500E+03, 0.11779400E+03, 0.55383700E+03, 0.48242800E+03, 0.27974700E+02, -.10504700E+04, 0.15382900E+04, -.76615900E+03, 0.63754800E+03, -.77555900E+03, 0.14494000E+03, 0.44481300E+03, -.26947500E+03, 0.92483000E+02, -.83103400E+03, 0.36357000E+03, -.26840000E+04, 0.42209800E+04, -.21374800E+04, -.10128200E+04, -.21083800E+04, 0.76720300E+03, 0.21569400E+03, -.16630700E+04, 0.10190600E+02, -.16052500E+04, 0.33278400E+03, -.22936600E+04, -.39251100E+03, 0.18677400E+03, 0.61431700E+03, 0.19802400E+03, -.14538800E+03, -.50552600E+03, 0.26981200E+03, -.58767400E+02, 0.26645900E+03, -.37877800E+03, -.68756000E+03, -.34985700E+03, 0.16616300E+03, 0.14149200E+03, 0.17568500E+03, 0.16972300E+03, -.92447500E+02, 0.59400500E+02, 0.22096000E+03, 0.46141800E+03, -.21290700E+03, -.13460500E+03, -.13870300E+04, 0.69593500E+03, 0.12818400E+04, 0.69344200E+03, -.15107900E+02, 0.18686700E+03, 0.61852600E+03, 0.87035600E+02, 0.26770300E+03, 0.14244800E+03, 0.11691300E+04, -.16542600E+04, 0.95648500E+03, 0.20519200E+04, 0.81540400E+03, -.14725400E+04, 0.22622300E+03, 0.16605300E+04, 0.11906500E+04, 0.10331300E+04, -.25998900E+03, 0.28273200E+04, -.57056700E+03, 0.28613100E+03, 0.15430000E+04, 0.28652300E+03, -.24746300E+03, 0.32229000E+03, 0.97597600E+03, 0.69718200E+03, 0.17345200E+03, 0.12260800E+03, 0.20815200E+04, 0.42890900E+03, -.22455700E+03, -.96004600E+03, -.21296100E+03, 0.11908000E+03, -.14743300E+03, 0.36961100E+03, 0.65685500E+03, 0.82187900E+02, -.87357200E+02, -.82516600E+03, -.92004100E+02, 0.60276100E+02, -.69069600E+03, 0.45969800E+02, 0.16199100E+03, 0.20212900E+03, -.96404800E+02, -.36017300E+03, -.40362300E+03, 0.31357100E+03, -.67599400E+03, 0.13260100E+03, -.60922400E+02, 0.20264700E+03, -.44609000E+02, 0.34258600E+02, -.35176600E+02, -.51011400E+02, -.51827300E+02, 0.59514300E+02, 0.74421000E+01, -.30165800E+02, 0.11963300E+04, 0.55183600E+02, 0.65644500E+02, 0.61771700E+03, 0.29121800E+03, -.12826100E+03, -.55253800E+02, 0.78538800E+03, -.16005900E+02, 0.33963000E+02, -.54819500E+02, -.89697600E+03, -.43493400E+02, -.24648400E+02, 0.26444900E+02 },
        { 0.49202600E+01, -.22767100E+01, -.27706600E+00, -.14868500E+01, 0.82379400E+00, 0.46661100E+01, 0.14512000E+01, 0.66319400E+01, 0.16545900E+01, -.31781300E+01, -.47145300E+00, 0.15272300E+00, 0.17233000E+01, 0.38783800E+01, 0.31741400E+01, 0.28150200E+01, -.68719100E+00, 0.21908000E+00, -.18124900E+01, 0.22420100E+01, -.24469800E+00, -.60316600E-01, -.14650700E+00, 0.66301400E+00, -.23636600E+01, -.17626000E+00, -.15528200E+01, -.99387000E-01, 0.79148400E+00, -.79232400E+00, 0.16641500E+00, -.29921200E+00, -.13375500E+00, 0.40616800E+00, 0.47848000E+00, 0.51826000E+00, 0.34621000E+00, -.22466600E+00, 0.16619500E+01, 0.95300600E+00, -.12986600E+00, -.43182100E+00, -.60549700E+00, -.20317200E+01, -.14128800E+00, 0.19353500E+00, -.24660400E+00, -.71281000E-01, 0.18499600E+00, 0.41060500E+00, -.18051000E+01, -.78704100E+00, -.91002400E-01, -.88922600E+00, -.11238400E+01, -.72156100E+00, 0.22131800E+00, -.12847900E+00, -.10951300E+00, 0.95068500E+00, -.59809600E+00, 0.79349600E+00, 0.77450900E+00, -.36683300E+00, 0.15265100E+01, -.53531600E+00, 0.10915200E+00, -.49224200E+00, 0.46542500E+00, -.32688000E-01, -.32782000E+00, -.78557000E+00, -.10619400E+00, -.66084400E-01, 0.10206000E+01, 0.59258600E+00, 0.21301400E+00, 0.55520100E+00, 0.21331900E+00, -.26610100E+00, -.18804300E-01, -.84962800E+00, 0.22224600E+01, -.12323000E+00, -.30466700E-01, 0.40140700E+00, 0.18932600E+01, -.18475900E+01, -.38475100E+01, 0.12334600E+01, 0.22311000E+01, -.80202100E-01, 0.14079300E+00, 0.14536300E-01, -.13877600E+01, 0.11924800E+01, -.55455100E+00, -.21715000E+01, -.30030300E+00, 0.37381800E+04, -.18676800E+04, -.19182800E+04, -.18720500E+04, -.90471000E+02, 0.31041000E+00, 0.15113200E+03, 0.17414500E+04, -.51953900E+03, -.12175500E+03, 0.86001400E+03, -.11455700E+04, 0.59207200E+03, -.23266800E+04, 0.57635400E+03, 0.18625100E+04, 0.25435400E+04, -.23589800E+04, -.39516700E+04, -.38976400E+04, 0.30470700E+04, 0.11507700E+04, -.22724600E+04, 0.11213900E+04, 0.21965700E+04, 0.11339900E+04, -.29881200E+03, -.11590700E+04, 0.12252300E+04, 0.10718400E+04, 0.13601100E+04, -.54878000E+03, 0.86482600E+03, 0.13836300E+02, -.54997700E+01, -.14003300E+03, -.66366000E+01, 0.12422200E+02, 0.92828100E+02, 0.24863100E+01, 0.54156100E+02, 0.34589700E+02, 0.38663800E+02, -.57193100E+02, 0.39690600E+04, -.23625300E+04, -.24786900E+04, -.19763600E+04, 0.20043300E+04, 0.36314900E+04, -.36181800E+04, -.29676500E+04, -.54065000E+04, 0.38580100E+04, -.21153200E+04, -.34929300E+04, 0.18057100E+04, 0.65338900E+03, 0.17475000E+04, -.13573500E+04, 0.63888700E+03, 0.36482800E+02, -.16739800E+04, -.23587900E+03, 0.88484400E+03, 0.36430300E+04, -.17555300E+04, 0.91803000E+03, 0.15069000E+02, 0.88060100E+03, -.89323200E+03, -.14320200E+04, 0.39674900E+03, -.11744000E+04, 0.28617400E+03, -.11162700E+04, 0.27050800E+04, -.69543100E+03, 0.34341600E+03, -.32728200E+04, 0.36083600E+03, -.67233700E+03, -.49423800E+03, -.32350700E+03, -.22784500E+03, 0.62270100E+03, -.35851500E+03, 0.17353700E+04, -.27792500E+04, 0.15502800E+04, 0.27114200E+04, 0.13854900E+04, -.23167200E+04, -.31540100E+04, 0.25306400E+04, 0.16972600E+04, 0.37090500E+04, -.32734800E+04, 0.11745900E+04, -.89029500E+03, 0.46452400E+03, 0.11586900E+04, 0.44616600E+03, -.99585000E+03, 0.54609400E+03, 0.70575300E+02, -.13843700E+03, -.87468600E+03, 0.48171200E+03, 0.48157800E+03, -.19870300E+04, 0.10160000E+04, 0.90306500E+03, 0.99580200E+03, -.19789000E+03, 0.49434400E+03, -.18466800E+03, -.13686800E+04, -.14234400E+03, 0.78706600E+03, 0.31882500E+04, -.27924400E+04, 0.13920600E+04, -.10511300E+03, 0.13951000E+04, 0.44923800E+03, 0.53570000E+03, -.90896400E+03, -.25714800E+04, 0.15473800E+03, 0.74397800E+03, 0.10597700E+04, 0.90390300E+03, -.57541700E+03, -.35040700E+04, -.44227500E+03, 0.23574500E+04, 0.45986800E+04, -.42025600E+04, -.54138000E+04, -.69838300E+04, 0.51569700E+04, 0.41580200E+03, -.55604500E+04, 0.27841400E+04, -.12376000E+04, 0.27784200E+04, 0.46649200E+03, 0.82490500E+03, -.19256600E+04, -.51547800E+04, 0.36023500E+03, 0.13403400E+04, 0.10873000E+04, -.69185600E+03, 0.37237200E+03, -.13788800E+03, 0.34362300E+03, -.52843700E+03, -.29611200E+03, -.35760000E+03, -.10530400E+04, 0.73389200E+03, -.27711800E+03, 0.14566700E+04, 0.12806000E+04, -.66679600E+03, -.83307200E+02, -.64387900E+03, -.10987700E+04, -.10425500E+04, 0.48003500E+03, 0.11485600E+04, 0.59052900E+03, -.10030500E+04, -.55297200E+03, 0.12388000E+03, 0.89341100E+02, -.30468500E+03, 0.27678900E+02, 0.33214500E+02, 0.21724400E+03, 0.27046200E+03, 0.12689200E+03, -.17404600E+03, -.11947400E+03, 0.17901700E+03, -.64156000E+03, 0.19034400E+02, -.11426800E+03, -.37793100E+03, 0.19561400E+03, 0.82080700E+02, 0.12716800E+03, -.66623800E+03, 0.27434800E+03, -.24590800E+03, 0.54361900E+02, 0.17062800E+03, 0.19694000E+03, 0.70125900E+01, -.17197400E+03 },
        { -.34743900E+01, -.49597500E+01, -.66424100E+00, -.23306800E+01, -.16763700E+00, 0.18110500E+01, -.63870400E+01, -.54482300E+00, -.25924500E+01, 0.37514400E+01, 0.11781000E+00, -.27506600E+00, -.15936300E+01, 0.51798500E+01, -.27663900E+01, -.71857700E+00, 0.14210900E+01, 0.80914100E+00, 0.35044700E+00, -.16300400E+01, -.29914400E+00, 0.18207100E+00, -.47401400E+00, 0.88005200E+00, -.44831200E+01, -.89986800E-01, -.12136900E+01, -.19649100E+01, 0.19563600E+01, 0.31489600E+00, -.35463200E+00, 0.21279000E+00, -.76131800E+00, 0.15402800E+00, -.11647800E+00, 0.33620000E+00, 0.18976400E+00, -.13240300E+01, 0.17448200E+01, -.88267200E+01, -.34204300E+00, -.45450500E+00, 0.10753300E+01, -.58414600E+00, -.26438700E+00, 0.60224200E-01, 0.34150500E+00, -.82361800E-02, -.59001000E-01, 0.16515700E+00, -.18993100E+01, 0.18584200E+00, 0.36514900E+00, -.86787200E-01, 0.54031900E+00, 0.17440800E+00, 0.15404700E+00, -.51674100E-01, 0.44992200E-01, 0.89273000E+00, -.16033000E+01, -.16404800E+01, -.61979100E+00, 0.14091800E+01, 0.15937300E+00, -.29039300E-01, 0.51406600E+00, 0.25980900E-01, -.59044900E-01, -.56628100E-01, -.26792700E+00, -.12357500E+00, -.12883800E+01, -.82383400E-01, -.35845400E+00, -.27643800E+00, 0.19656600E+00, -.53033400E+00, -.20199700E+00, -.23208700E+00, -.26669500E-01, -.20048100E+00, 0.27913300E+00, -.31336200E+00, 0.15830200E+01, 0.55895200E+00, -.54549800E+00, 0.57583900E+00, -.12993800E+00, -.34564800E+00, 0.50559600E-02, 0.79203000E-03, -.14299500E+00, -.30971000E+00, -.14738600E+00, 0.12607400E+01, -.11029800E+00, 0.74268500E+00, -.17424100E+00, -.81167700E-01, -.96754000E+01, 0.61245800E+03, 0.30385000E+01, 0.11165900E+03, -.29470200E+02, -.40536300E+03, -.58367400E+03, -.50792200E+03, -.23038500E+02, -.46537500E+03, 0.51963500E+04, -.25534800E+04, 0.60720600E+03, -.26052800E+04, -.15705200E+03, 0.13725200E+04, -.13677000E+04, -.10321600E+02, -.18526100E+04, 0.86927700E+03, -.16364400E+04, 0.37506900E+02, -.11469800E+02, -.36941000E+03, -.17101700E+02, -.29292700E+03, 0.10086500E+03, 0.18801800E+03, 0.75391600E+02, -.29688100E+03, 0.12561000E+03, -.32017300E+02, 0.41879300E+02, -.21656600E+02, 0.22579700E+02, -.21156100E+02, 0.17228400E+02, -.17238200E+02, -.50501800E+02, -.38264300E+02, -.31010600E+01, -.58625400E+01, -.66402400E+02, -.17487000E+04, 0.78989200E+03, -.81921900E+02, 0.86211200E+03, 0.29972900E+03, 0.45054400E+03, 0.80136700E+03, 0.27463500E+03, 0.76431800E+03, 0.34352400E+02, 0.22290100E+04, -.30336300E+04, 0.15206000E+04, -.16907100E+03, 0.15151100E+04, -.23210700E+03, -.49935300E+03, 0.64833100E+03, -.24804000E+03, 0.12758800E+04, -.53599600E+03, 0.21363900E+04, -.33990600E+03, 0.18363000E+03, 0.29428200E+03, 0.16975600E+03, -.16786800E+03, -.26059700E+03, 0.32858600E+03, 0.30853400E+03, 0.32195200E+03, -.32589500E+03, 0.52418000E+03, 0.24225600E+04, -.12082500E+04, 0.23209500E+03, -.12194300E+04, 0.85009600E+03, 0.10504400E+04, -.81066800E+03, -.42812200E+01, -.12375800E+04, 0.87460600E+03, -.11995300E+04, 0.32829300E+04, -.15884400E+04, -.74660900E+03, -.16348900E+04, -.13517300E+03, -.28395400E+03, -.41518700E+03, 0.51107300E+03, -.10396800E+04, -.21400800E+03, -.19512400E+04, -.16968000E+04, 0.85159000E+03, -.38035300E+03, 0.84727700E+03, -.35934500E+03, -.46721200E+03, 0.50264300E+03, -.11799900E+03, 0.74180200E+03, -.41934500E+03, 0.94674800E+03, 0.38394000E+03, -.18692600E+03, -.22177700E+03, -.19409500E+03, -.12383400E+03, -.10343400E+03, -.15386600E+02, 0.18048800E+03, 0.32424800E+03, -.23564200E+03, -.36830500E+03, -.97631100E+03, 0.48802800E+03, 0.68349700E+03, 0.48889000E+03, 0.22760000E+02, 0.22854100E+03, 0.33865700E+03, 0.31875000E+03, 0.72096200E+03, 0.17265600E+03, 0.73241900E+03, 0.60416300E+04, -.29909800E+04, 0.13248600E+03, -.30395500E+04, -.55079900E+02, 0.17977400E+04, -.12464700E+04, 0.23366500E+03, -.19269600E+04, 0.98427600E+03, -.11973200E+04, -.76265600E+03, 0.38420900E+03, 0.14024600E+03, 0.38245100E+03, 0.21528800E+03, 0.67190000E+03, 0.52984600E+03, 0.96176000E+03, 0.10851200E+04, 0.39790700E+03, 0.11036500E+04, -.25026000E+03, 0.13322000E+03, -.20889400E+03, 0.12613300E+03, 0.33504800E+03, 0.32072400E+03, 0.83218100E+02, 0.54324300E+02, -.18700400E+03, 0.23410700E+03, 0.32477300E+02, -.12026500E+03, 0.62072500E+02, -.30773100E+02, 0.63269200E+02, 0.52862200E+02, 0.53555600E+02, 0.88024500E+01, -.20905900E+03, -.44919800E+03, 0.23365400E+03, -.88829800E+02, -.42977300E+02, -.13899400E+03, 0.12946300E+03, -.23890300E+02, 0.13391100E+02, -.76806900E+02, 0.43244200E+01, -.60840600E+02, 0.81929200E+02, 0.38596200E+02, 0.44903400E+01, 0.27016500E+03, 0.60565700E+02, 0.21512800E+02, 0.16263800E+03, -.96284000E+02, 0.16142800E+03, -.35077600E+02, 0.35713300E+03, -.39914600E+02, -.22107000E+02, 0.21928500E+03, -.61151000E+02, -.17716300E+03, 0.17848300E+02, 0.32647200E+02 },
        { -.30963500E+01, 0.21911200E+01, 0.22401200E+00, 0.40412000E+00, -.93677900E+00, -.11892100E+01, -.18634200E+01, -.14656700E+01, -.13200400E+01, 0.21204600E+01, 0.23537900E+00, -.18548300E+00, 0.20742200E+01, -.32709700E+01, 0.85744800E+00, -.23443600E+01, -.75027800E+00, 0.27895300E+00, -.44484800E+00, -.11925200E+01, 0.12155400E-01, 0.44761500E+00, 0.28285600E+00, 0.10263000E+00, 0.32362300E-01, 0.43075700E-03, 0.35007700E-01, 0.43884800E+00, -.49420400E+00, 0.10131700E+01, -.56997000E+00, 0.28342700E+00, 0.39076500E+00, -.50448800E-01, 0.72703000E-01, -.16446100E+00, 0.13277400E+00, -.89507700E+00, -.35760400E+00, -.91640800E+01, 0.85511900E-01, -.16969800E+00, 0.25639400E+00, 0.26847500E+00, 0.77404900E-01, -.20510700E+00, 0.25326800E+00, -.22873100E-01, -.17011700E+00, -.52505700E+00, -.19226200E+01, 0.71239800E+00, 0.53887600E+00, 0.13488400E+01, -.54323000E+00, 0.33698400E-01, -.22884300E+00, -.10490900E-01, -.13621000E+00, -.10473000E+01, 0.66825800E+00, 0.27847100E-01, 0.42665200E+00, 0.21369400E+00, -.21578800E+00, 0.64832400E-01, 0.81691700E+00, -.26315900E+00, 0.97661400E-01, -.68307500E-01, 0.73243700E+00, -.49384200E+00, -.81729900E+00, -.48609000E+00, -.47716000E+00, 0.81362200E+00, -.21573400E+00, 0.32850100E+00, 0.26081500E+00, 0.60508100E+00, 0.90665200E-01, 0.87730700E-01, 0.44095600E+00, -.71805200E-01, 0.28454700E+00, 0.17246600E+00, -.60601500E-01, -.17330700E+01, -.26619500E+01, 0.17666900E+01, 0.63569700E+00, 0.41709500E-01, -.58396100E+00, 0.14265000E+00, 0.36525600E+00, 0.17222800E+01, -.26192400E+00, 0.74732000E+00, 0.39749400E+00, 0.16922900E+00, -.58697500E-01, 0.12425800E+04, 0.27632200E+01, -.31744900E+03, 0.51359100E+03, -.15459000E+04, -.13538800E+04, -.14838500E+04, 0.37892100E+03, 0.30102800E+04, 0.32228300E+04, -.16222300E+04, -.72555900E+03, -.16150700E+04, -.43147800E+03, 0.11768400E+04, 0.28270500E+03, 0.18789900E+04, 0.71950800E+03, 0.40164300E+03, -.16902500E+04, 0.16611800E+03, -.61301000E+02, -.96540300E+01, -.81198900E+02, 0.65131500E+02, 0.62647100E+03, -.50040400E+03, -.53123700E+03, -.98327600E+03, 0.56563400E+03, 0.42162300E+03, 0.17248400E+03, -.88278600E+02, -.60943100E+02, -.86463900E+02, -.35426200E+02, -.77502500E+02, -.24295300E+01, -.11302800E+02, -.17316900E+02, -.40510800E+02, -.92988900E+02, -.21451900E+04, 0.15161300E+04, -.13826000E+04, 0.10640300E+04, -.26387000E+03, 0.29223200E+03, 0.73120600E+03, 0.56777500E+03, 0.16376300E+04, -.23756100E+03, 0.24553900E+04, -.36707300E+04, 0.17701900E+04, 0.66767800E+03, 0.18342000E+04, 0.14517700E+02, -.36557200E+03, 0.66954900E+03, -.28412300E+03, 0.18128100E+04, -.51820200E+03, 0.32663000E+04, -.41286900E+03, 0.18784900E+03, 0.15896600E+04, 0.20444600E+03, -.99731100E+02, 0.28911900E+03, 0.78660100E+02, 0.24028200E+03, 0.36388400E+03, 0.81531300E+02, 0.28407600E+03, 0.23043400E+04, -.11446000E+04, 0.27539300E+04, -.11637400E+04, 0.46758700E+03, 0.10096700E+04, -.59083500E+03, -.51222600E+03, -.17074200E+04, 0.92362200E+03, 0.66864800E+03, 0.88969800E+03, -.59208500E+03, -.95163800E+03, -.44051500E+03, 0.11474800E+04, 0.94006900E+03, -.67430400E+03, -.27952300E+03, -.93994700E+03, 0.85162800E+03, 0.34939500E+03, -.29136100E+04, 0.14307800E+04, -.66764200E+03, 0.14556200E+04, 0.74339100E+03, -.27306900E+02, 0.97026200E+03, 0.11759300E+03, 0.92523400E+03, -.24865500E+02, 0.24542300E+04, 0.77451100E+03, -.41804700E+03, -.96018000E+03, -.38938700E+03, -.29767300E+03, -.64868300E+03, 0.37905500E+03, 0.45847100E+03, 0.82381800E+01, -.77405000E+03, -.55131900E+03, -.14603900E+04, 0.73403400E+03, 0.16054200E+04, 0.73109800E+03, 0.58952800E+03, -.76316500E+02, 0.13593200E+04, 0.66602200E+03, 0.11730000E+04, 0.87221800E+02, -.30924400E+04, 0.32950500E+04, -.14903200E+04, -.27212600E+04, -.16578400E+04, -.39318800E+03, 0.17287800E+04, 0.33300000E+03, 0.22334300E+04, 0.14495800E+04, 0.53679400E+03, 0.16563200E+03, -.13402300E+04, 0.66446900E+03, 0.19263400E+04, 0.67136800E+03, 0.97644300E+03, -.28541400E+03, 0.27276300E+04, 0.15631500E+04, 0.20661500E+04, -.20495600E+03, -.51776200E+04, -.83036400E+03, 0.38569900E+03, -.65095600E+02, 0.41666500E+03, 0.44298000E+03, 0.74410700E+03, -.42514500E+03, -.42382200E+03, -.40434800E+03, 0.59382900E+03, 0.40293300E+03, -.30279700E+03, 0.18709200E+03, 0.65109000E+03, 0.15451600E+03, -.94934000E+01, 0.20438700E+03, -.12515900E+03, -.44634700E+03, -.65269500E+03, 0.45267900E+03, 0.11062900E+04, -.28067100E+03, -.12081200E+03, 0.64799800E+02, 0.37392000E+02, 0.36010700E+02, -.14519100E+03, -.49542400E+02, -.81585200E+02, 0.12068300E+03, 0.84466500E+02, -.16971000E+02, 0.43436200E+03, 0.43996800E+02, 0.62470100E+02, 0.25213900E+03, -.39830100E+03, 0.35291200E+03, 0.93335200E+02, 0.33415800E+03, -.15987500E+03, 0.69667500E+02, -.84202900E+02, -.16108600E+03, -.58066500E+02, -.15217000E+02, 0.54164800E+02 },
        { 0.29866000E+01, -.20540400E-01, -.10435800E+00, 0.57795800E+00, 0.12925100E+01, 0.10215300E+00, 0.16942900E+01, -.18194100E+01, 0.14289200E+01, -.20868400E+01, -.73203400E-02, 0.20246100E+00, 0.54342400E+00, -.10129500E+01, 0.80469500E+00, -.55789800E+00, 0.53417300E+00, -.25273300E+00, -.50249400E-01, 0.71075600E+00, -.70566000E-01, -.17718600E+00, 0.80455300E-01, 0.81773600E-01, 0.88270700E+00, -.52529700E-02, 0.33648100E+00, 0.73688300E+00, -.90674300E-01, 0.14901400E+00, -.10459800E+00, -.49072100E-01, -.36539400E+00, -.40818000E+00, -.53886700E-01, 0.24489400E-01, 0.10735900E+00, 0.85141300E-01, -.91715600E-02, 0.68070700E+00, -.16245100E-01, -.19780500E+00, 0.29307700E+00, 0.24401700E+00, -.15824000E+00, 0.37993100E-01, 0.18594900E+00, -.59093100E-02, 0.12864900E-01, -.19241400E+00, 0.96971800E+00, 0.45111200E+00, -.26375600E-01, -.15858800E+00, 0.27881500E+00, 0.16349500E+00, 0.52022600E+00, -.16139700E-01, -.14311700E-01, 0.62662600E+00, -.88718900E+00, -.23678600E+01, -.12054700E+01, -.23927500E+00, 0.13808300E+00, -.83284300E-01, -.34410600E+00, -.17136000E+00, -.53799600E-01, -.33124700E-01, 0.34729200E-01, 0.14043300E+00, 0.11134900E+01, 0.51809200E+00, 0.26693900E+00, -.27613000E+00, 0.13081100E+00, -.76596200E-02, 0.93312500E-03, 0.66922700E-01, -.36541800E-01, -.18927700E-01, -.56044900E+00, -.34158600E+00, 0.60383100E+00, -.20118000E+00, 0.11198900E+01, 0.15015900E-01, 0.49234900E+00, 0.40917500E+00, 0.62396900E+00, -.56735900E-01, 0.14435500E+00, -.71122400E+00, -.47823700E+00, 0.52160000E+00, -.20524800E+00, 0.57509100E+00, -.43121600E+00, -.18967700E+00, -.22322100E+00, 0.29975100E+00, 0.45100300E+01, -.55880700E+02, -.33976200E+03, -.15239300E+03, -.45115700E+03, -.16602300E+03, -.35641700E+03, -.27325700E+01, -.41650700E+04, 0.20743800E+04, 0.11918500E+04, 0.20828900E+04, -.40361300E+03, 0.59701600E+03, 0.13235600E+04, 0.99209200E+03, 0.14995600E+04, 0.53658100E+03, 0.22269800E+04, 0.10204800E+04, -.50802400E+03, -.11127900E+03, -.50777300E+03, -.17741400E+03, 0.10485700E+03, -.98872800E+02, -.42077300E+01, -.45777500E+03, 0.87198200E+02, -.29442500E+03, 0.17321400E+02, -.88576200E+01, -.77349400E+02, -.87907000E+01, 0.33105300E+02, -.13910600E+02, -.44733100E+02, -.29574400E+02, 0.13354200E+02, -.58139900E+00, -.26640900E+02, 0.57264300E+03, -.22456600E+03, 0.43511300E+04, -.29613500E+03, -.18358400E+04, -.80025700E+03, 0.13040400E+04, 0.12209400E+04, -.27520900E+03, -.54025900E+03, -.17645400E+03, -.24248500E+03, 0.11402000E+03, 0.43812300E+03, 0.11926400E+03, 0.69553200E+03, -.18041200E+02, -.38722200E+03, -.34233000E+03, 0.19753200E+03, -.16998900E+03, 0.16756700E+04, 0.65920200E+03, -.33527400E+03, -.56276500E+03, -.32927100E+03, 0.23043200E+03, 0.38411300E+03, 0.15773000E+03, 0.65117700E+03, -.34621000E+02, 0.20927200E+03, 0.13561800E+03, 0.12622200E+04, -.63059800E+03, -.19298300E+03, -.63377600E+03, -.50416900E+01, 0.49303700E+03, -.34753400E+03, 0.28781000E+03, -.56825900E+03, 0.22841200E+03, 0.45062700E+03, -.22354500E+03, 0.84412900E+02, -.37698500E+04, 0.11623800E+03, 0.68062500E+03, 0.18637600E+03, 0.30963700E+03, 0.48944700E+03, 0.65222000E+03, 0.10667500E+01, 0.53112100E+03, -.21952200E+04, 0.10963400E+04, -.28803300E+03, 0.10932800E+04, 0.51383200E+03, 0.38479100E+02, 0.34615900E+03, 0.46437200E+02, 0.80783400E+03, 0.16047900E+02, 0.13690500E+04, -.12848100E+02, 0.49205200E+01, -.38235600E+03, 0.24404100E+01, 0.74326800E+02, 0.16146900E+03, -.13109000E+03, 0.13829000E+03, 0.36686600E+03, -.93574900E+02, 0.71045800E+02, 0.14559100E+04, -.72751100E+03, -.71443200E+03, -.72681800E+03, 0.37868200E+03, 0.20002800E+03, 0.40635200E+00, 0.11108600E+04, -.24127500E+02, 0.17933900E+03, -.10711200E+04, -.36159100E+04, 0.18327100E+04, 0.26341800E+04, 0.18050100E+04, -.14524000E+04, -.74066000E+02, 0.22812100E+04, 0.19833500E+04, 0.16755600E+04, 0.24207700E+02, 0.23875300E+04, 0.23288500E+04, -.11639200E+04, -.20639700E+04, -.11648700E+04, 0.46699000E+03, 0.79248800E+03, -.15094000E+03, 0.17802700E+04, -.12551400E+03, 0.49749300E+03, -.77464400E+03, 0.42792300E+03, -.21526000E+03, 0.18455100E+03, -.21490400E+03, -.28689300E+02, 0.26647100E+02, 0.64207600E+02, 0.24664400E+03, -.28427700E+03, -.42310000E+02, -.19677400E+03, 0.87213600E+03, -.43268900E+03, 0.16832600E+01, -.43190100E+03, -.15587900E+03, 0.27856400E+01, -.18927100E+03, -.18929900E+03, -.65037600E+03, 0.10670100E+03, -.21953000E+03, 0.12277300E+02, 0.13909600E+02, 0.16137600E+03, -.59050500E+02, 0.24369900E+01, 0.17253900E+02, 0.37991900E+02, 0.20949800E+02, 0.25508900E+02, -.32170300E+02, 0.36010100E+02, 0.14009300E+04, 0.63040900E+02, -.37925500E+02, 0.58545300E+03, -.32008900E+03, -.31186100E+02, -.65430500E+02, -.17189300E+03, -.19264300E+02, 0.12001600E+03, 0.40420300E+03, -.11947300E+04, -.21509100E+03, 0.42166200E+02, 0.23172800E+02 },
        { 0.20107900E+01, -.15927100E+01, -.14173100E+00, 0.15634300E+00, 0.31133300E+00, -.38239600E+01, 0.42418900E+01, -.19133000E+01, 0.15790600E+01, -.17467900E+01, -.38037200E-01, 0.25914100E+00, -.61561800E+00, -.96638200E-01, 0.13402000E+01, 0.23297000E+01, 0.17151200E+01, -.65703500E-01, -.82837400E+00, 0.18332100E+01, -.78144700E+00, -.14514600E+00, 0.29784200E+00, 0.41244400E+00, -.12887100E+01, -.95898300E-01, -.39101200E+00, -.59730400E+00, 0.14214800E+00, 0.49674200E+00, -.71468600E+00, 0.75403800E-01, -.10285700E+01, -.10977900E+01, -.40421100E+00, -.21641000E+00, 0.23565000E+00, -.10703800E+01, 0.30343500E+00, -.68499400E+01, -.61099500E-01, -.26378000E+00, 0.90510300E+00, 0.73923900E+00, -.68669500E+00, 0.45022200E-01, 0.29563900E+00, -.22134500E-01, 0.61244400E-02, -.21793300E+00, -.11473200E+01, 0.65432800E+00, 0.19520300E+00, 0.15133800E+00, 0.38401700E+00, -.17399500E+00, 0.62552000E+00, 0.27435900E+00, -.88176200E-02, -.21715500E+00, -.63161700E+00, -.10917300E+01, -.85834800E+00, -.10670100E+01, -.25646500E-01, -.76349000E-01, -.70334300E-01, -.44305400E+00, -.69847800E-01, -.14426800E-01, -.65599100E-01, 0.19609600E+00, 0.17304600E+00, 0.32225700E+00, -.58380600E-01, -.57701200E-01, 0.23015200E+00, 0.17875500E+00, -.30853100E-01, -.42303500E+00, -.20958300E-01, 0.19590700E+00, -.43979400E+00, 0.16539800E+00, 0.13818900E-01, -.30603800E-01, 0.21164900E+00, 0.57162400E+00, 0.95812900E+00, -.28831800E+00, -.75709600E+00, -.29410100E-01, 0.12985400E+00, -.26475100E+00, -.84646600E+00, -.14095700E-01, 0.33787200E+00, 0.75857700E+00, 0.13589800E+00, -.13848800E+00, -.27201800E-02, -.74115900E+00, 0.52770400E+00, -.31539000E+03, 0.39109200E+03, -.75618200E+03, -.63733300E+03, -.93520000E+03, 0.35718300E+03, 0.14986000E+04, 0.65424300E+04, -.32819100E+04, -.55128900E+03, -.32735800E+04, -.10854600E+04, -.14642600E+04, -.71214800E+03, -.41503300E+03, -.16622800E+04, -.16372400E+04, -.40148900E+04, -.66539000E+03, 0.34578700E+03, -.16056500E+03, 0.33293700E+03, -.36617800E+02, 0.34289700E+03, -.17785700E+03, -.38806000E+03, -.23698600E+03, 0.20332200E+03, 0.62574900E+03, 0.18443200E+03, -.93431400E+02, 0.38327800E+01, -.92308700E+02, -.30368000E+02, -.57328400E+02, 0.15931300E+02, 0.34714400E+02, -.45051300E+02, -.34176000E+02, -.78210000E+02, 0.46053400E+03, 0.45782800E+02, -.21627300E+04, -.23176200E+03, 0.31615500E+03, -.45860300E+03, -.61323800E+03, -.76527400E+03, 0.43699100E+03, -.93821600E+03, 0.64249500E+03, -.93604600E+03, 0.42468400E+03, -.10072500E+03, 0.46807100E+03, -.20931500E+03, -.14751500E+03, 0.94554700E+02, 0.46794300E+03, 0.10828000E+04, -.49225800E+03, 0.73537400E+03, -.61112100E+03, 0.28920000E+03, 0.63951400E+03, 0.30408600E+03, -.19486500E+03, 0.61421100E+02, 0.35525900E+02, -.13859300E+03, 0.13456600E+03, -.10824300E+02, 0.24620700E+03, -.31230500E+03, 0.16026200E+03, 0.24978600E+04, 0.14873900E+03, 0.19004900E+03, 0.28198200E+02, -.92745600E+01, -.76845300E+03, -.54527600E+02, 0.32492300E+02, 0.81055900E+03, 0.10276100E+04, -.61313000E+03, 0.11802700E+04, -.51285900E+03, 0.25988300E+03, 0.70381200E+03, -.13252800E+03, -.86395300E+01, -.11801900E+04, 0.96221100E+03, -.32382000E+03, 0.38996200E+03, -.21139000E+03, -.84848500E+03, -.19404300E+03, 0.28764800E+03, 0.11091700E+03, -.13701700E+02, 0.19733000E+03, -.85368100E+02, 0.24384700E+02, 0.51818100E+03, 0.10958300E+04, -.56594100E+03, -.29495200E+03, -.54772500E+03, -.81708900E+02, -.32609900E+03, 0.20996700E+01, 0.12062800E+03, -.92041900E+03, -.28795800E+03, -.79769300E+03, 0.93246700E+03, -.46404700E+03, 0.25395100E+03, -.46609000E+03, -.64491000E+02, -.73050700E+03, 0.66403300E+03, 0.87371900E+03, 0.28744100E+03, -.59111400E+03, -.21800800E+04, 0.84679400E+04, -.41375400E+04, -.18622900E+04, -.42391300E+04, -.10009100E+04, -.18192200E+04, -.13569400E+04, -.82493700E+03, -.20974300E+04, -.22171700E+04, -.42603000E+04, 0.50860600E+02, -.30502000E+02, 0.20554600E+04, -.24435700E+02, 0.22650500E+03, -.14795300E+04, 0.16448200E+04, 0.10652400E+04, 0.11599000E+04, -.12329500E+04, -.32050300E+04, -.52529700E+03, 0.24316400E+03, 0.24373500E+03, 0.26400200E+03, 0.38123800E+03, 0.56542700E+03, -.36227600E+03, -.25038900E+03, 0.12754400E+02, 0.42920400E+03, 0.11116700E+03, -.97212800E+03, 0.50778400E+03, 0.45224600E+03, 0.48643900E+03, 0.20253900E+03, 0.17680400E+03, 0.82287900E+02, -.18237600E+02, 0.33990000E+03, 0.13586300E+03, 0.97916300E+03, -.29194000E+03, -.11726300E+03, -.98827400E+02, 0.87210200E+02, -.36711700E+02, -.10843900E+03, -.11521500E+03, -.99207900E+02, 0.10229000E+03, 0.10208100E+03, -.99005600E+02, -.16420300E+03, -.66383400E+02, 0.48172400E+02, -.15046300E+03, -.18073300E+03, 0.24619400E+03, 0.11357000E+03, 0.22613300E+03, -.16487700E+03, -.10524400E+03, -.42926500E+03, 0.45883900E+03, 0.68937000E+02, -.54153500E+02, 0.48545000E+02 },
        { 0.29941800E+01, 0.93535800E-01, 0.11347500E+00, 0.13080900E+01, 0.14911700E+01, -.19902400E+01, 0.45548000E+01, 0.66576100E+00, 0.96008600E+00, -.25861200E+01, 0.19163700E+00, 0.11517700E+00, 0.21927400E+01, 0.35204900E-02, 0.69374400E+00, 0.15237600E+01, 0.61277000E+00, -.14604500E+01, 0.12541000E+01, 0.10235300E+01, 0.30701500E+00, -.21885500E+00, 0.31731100E+00, 0.73298400E-01, 0.17490900E+01, -.64333100E-01, 0.37519700E+00, 0.10518900E+01, 0.19632300E+00, 0.90149500E+00, 0.21250500E+00, 0.49623500E+00, 0.40067800E+00, -.73678800E+00, -.46379900E+00, -.39266300E+00, 0.65670200E-01, -.68546300E+00, -.26569400E+01, -.19274900E+01, 0.26638900E+00, -.40489800E-01, 0.30895500E+00, 0.12841400E+01, -.17555800E+00, -.38952200E-01, 0.44812200E+00, -.18367800E-01, 0.21941500E+00, -.19671900E+00, 0.41473400E+01, 0.19464500E+00, -.73861800E+00, -.11626000E+01, -.96122800E+00, 0.34347600E-01, -.21934400E+00, -.71512900E-01, -.37267700E-01, 0.12913700E+00, -.11493400E+01, -.62572700E-01, 0.45233800E+00, -.72956900E+00, 0.20503500E+00, 0.34079000E-02, 0.90278200E+00, -.17049100E+00, 0.20910400E-01, 0.11908500E-01, -.17960300E+01, 0.42589800E+00, -.11155100E+01, 0.11973500E+00, 0.60486700E+00, -.11945800E+01, 0.10497100E+00, -.14650400E+00, 0.19617900E+00, 0.36482700E+00, 0.39799900E-01, -.33530300E+00, -.10097200E+01, -.50961600E+00, 0.62903200E+00, -.58153400E+00, -.36854300E+00, -.14540700E+01, 0.15534200E+01, 0.10311500E+01, -.80981700E+00, -.40107200E-01, -.23243400E+00, -.31335500E+00, 0.56871600E+00, -.12060300E+01, 0.34569800E+00, -.22093500E+00, 0.16181600E+00, -.97113800E-01, 0.11621300E+00, -.16918100E+00, 0.59300100E+00, -.73539500E+00, 0.93150400E+03, -.22659600E+03, 0.23912900E+03, 0.25681000E+03, 0.76759300E+03, 0.21833600E+04, 0.59859900E+04, -.29920600E+04, -.24243200E+04, -.29941900E+04, 0.23126900E+03, -.11814600E+03, -.22696500E+04, -.17408100E+04, -.25315500E+04, -.11323300E+03, -.37056700E+04, -.14512700E+04, 0.71383200E+03, 0.79500300E+03, 0.72539800E+03, 0.21243200E+03, -.13984900E+03, 0.79390300E+02, -.14434400E+03, 0.89345500E+03, -.11249400E+03, 0.90183000E+03, 0.13238600E+02, -.54285300E+01, 0.79740800E+01, -.65925200E+01, -.50502200E+02, 0.94270000E+01, 0.73466700E+02, 0.70412400E+02, -.19831300E+02, -.12778200E+01, 0.54613200E+02, 0.14159500E+04, -.99114100E+03, -.53086100E+04, -.70929000E+03, 0.17973800E+04, 0.15825400E+04, -.24916300E+04, -.20741300E+04, -.85191800E+03, 0.11947300E+04, -.69140300E+03, -.72164300E+03, 0.40038600E+03, 0.10026600E+03, 0.36060300E+03, -.79809800E+03, 0.21348100E+03, 0.20882600E+03, -.20294000E+03, 0.69674700E+02, 0.34859100E+03, -.27525400E+03, -.11389800E+04, 0.58680100E+03, 0.85895500E+03, 0.56805500E+03, -.58038500E+03, -.80399900E+03, -.11310900E+03, -.85913500E+03, 0.20249400E+03, -.56647300E+03, 0.50624300E+03, -.22858900E+04, 0.11372400E+04, 0.15675100E+03, 0.11416000E+04, -.72101800E+03, -.91771500E+03, 0.64758600E+03, -.54662800E+03, 0.10474000E+04, -.53345000E+03, 0.12669200E+04, -.79495600E+03, 0.50082600E+03, 0.37798500E+04, 0.39828500E+03, -.76647500E+03, -.78087000E+03, 0.26113900E+03, -.17593100E+02, 0.34739300E+03, -.55477900E+03, 0.40893900E+03, 0.17667800E+04, -.86906400E+03, 0.39883100E+03, -.88341400E+03, -.26525000E+03, 0.25265500E+03, -.14473700E+03, 0.81699000E+02, -.92592500E+03, 0.29896800E+03, -.70757100E+03, -.12058700E+04, 0.62255900E+03, 0.69994900E+03, 0.60302700E+03, -.10387500E+03, -.98301100E+02, 0.16548000E+03, -.67616300E+03, -.58848900E+03, 0.24145700E+03, 0.63609800E+03, -.48372900E+03, 0.23729700E+03, -.87149100E+02, 0.24171100E+03, -.42242100E+03, -.72617500E+03, 0.39573600E+02, -.10072500E+04, -.33724800E+03, -.60523200E+03, -.12323600E+04, 0.74079400E+04, -.38048000E+04, -.50086100E+04, -.37069800E+04, 0.11365900E+04, 0.98819400E+03, -.40909000E+04, -.30271200E+04, -.33559900E+04, 0.75294400E+03, -.42799200E+04, -.18725700E+04, 0.93335900E+03, 0.12843800E+04, 0.93602500E+03, -.71019000E+03, -.19996500E+04, 0.47544200E+03, -.20220300E+04, -.30855600E+03, -.12714500E+04, -.29446500E+04, -.43389200E+03, 0.23496100E+03, -.90785100E+02, 0.21643900E+03, 0.66479700E+02, 0.10360100E+03, -.43058600E+03, -.53507300E+03, 0.47501900E+03, 0.92280800E+02, 0.33140300E+03, -.42487300E+02, 0.10218800E+00, -.16435100E+03, 0.21044000E+02, -.21709800E+03, -.36865700E+03, 0.41030500E+03, 0.71548600E+03, 0.10924500E+04, -.51782700E+03, 0.62795300E+03, -.68200600E+02, 0.19279100E+02, -.29987900E+03, 0.10297700E+03, 0.94293900E+01, 0.37666400E+02, -.40334700E-01, 0.36944200E+02, -.63285000E+02, -.43205600E+01, 0.32472900E+02, -.11231800E+04, -.13314000E+03, 0.25439400E+02, -.58909100E+03, 0.20024500E+03, 0.10320300E+03, 0.14879600E+03, -.10557900E+02, 0.53578100E+02, -.19626500E+03, -.70425200E+03, 0.10159900E+04, 0.44923400E+03, -.68446000E+02, -.10598600E+03 },
        { -.21398500E+01, 0.15513800E+01, 0.12273000E+00, 0.16332800E-02, -.73071400E+00, 0.24299200E+01, -.38087000E+01, 0.85282500E+00, -.14805000E+01, 0.19977300E+01, -.28696200E-01, -.19581200E+00, -.65829300E+00, 0.13834000E+01, -.13361800E+01, -.46644000E+00, 0.12030500E+00, 0.95002800E-01, 0.52155400E+00, -.26229100E+01, -.79659900E+00, 0.18263200E+00, -.25680500E+00, -.10976800E+00, 0.53102800E+00, 0.37292600E-01, 0.19546500E-01, -.89019700E+00, 0.38665600E+00, -.21139200E+00, 0.47173600E+00, 0.31472700E+00, 0.70201200E+00, 0.10759400E+01, 0.88282000E+00, 0.14195500E+00, 0.63086600E-01, -.26230200E-03, 0.12837800E+01, -.30747900E+01, 0.12936000E+00, -.86161900E-01, 0.22563800E+00, -.28904700E+00, -.35357300E+00, -.29565000E-01, 0.27464900E-01, -.11037500E-01, -.16269300E-01, 0.12823000E+00, -.11000900E+01, -.13027600E+00, 0.22296700E+00, -.47190700E+00, 0.18527300E+00, -.59179200E+00, 0.18047000E+00, 0.30008100E-01, 0.42969200E-01, 0.39685900E+00, 0.27140200E+00, 0.13095800E+01, 0.76586000E+00, -.32468100E+00, 0.52139800E+00, -.13832600E+00, -.13683600E+00, -.46396900E+00, 0.42160800E-01, -.51931200E-01, -.29547500E+00, -.36490800E+00, -.20376200E-01, -.54309700E+00, -.14215400E+00, 0.44098900E+00, -.13922300E+00, -.82083500E+00, -.14561700E+00, -.13763600E+00, -.12889200E+00, -.17473600E+00, 0.12067700E+01, 0.27161000E-01, 0.59363400E+00, 0.52844800E+00, -.31981500E+00, -.11803000E+00, 0.31459700E+00, -.10033200E+00, -.67054300E+00, -.17077100E-01, 0.89348800E-01, -.27811300E+00, 0.34646300E+00, 0.26753900E+00, 0.17408300E+00, -.79827500E+00, 0.98320800E+00, 0.50435400E+00, 0.37043700E+00, -.25855300E+00, -.14732400E+00, 0.79438100E+00, -.23955900E+00, 0.72097100E+03, 0.10275800E+04, 0.11890600E+04, 0.18709000E+02, -.15200500E+04, -.50474600E+04, 0.25420200E+04, -.12890900E+03, 0.25257500E+04, 0.92322200E+03, 0.40597500E+03, 0.44178000E+03, -.49740200E+03, 0.14458900E+04, 0.54954500E+03, 0.22678200E+04, 0.12709400E+04, -.64569100E+03, -.40946800E+03, -.63561400E+03, 0.19350400E+02, -.15037100E+03, -.37166000E+03, -.23995900E+02, -.15693400E+03, -.19043600E+03, -.81038400E+03, -.13554600E+03, 0.68715000E+02, 0.48476600E+02, 0.67839700E+02, -.87181800E+01, 0.46475900E+02, 0.15987600E+02, -.77030900E+01, 0.73490600E+01, 0.29793900E+02, 0.13616200E+03, -.64103700E+03, 0.10103000E+03, -.63450700E+03, 0.32209900E+03, 0.57250000E+03, 0.89578000E+03, -.51744400E+03, -.58369300E+03, -.91558500E+02, 0.11161900E+04, -.66447500E+03, 0.11986500E+04, -.56614500E+03, -.61860600E+02, -.59930800E+03, -.17368100E+03, 0.41783600E+02, -.42372800E+01, 0.14213400E+03, -.32618900E+03, 0.18395400E+03, -.25350100E+04, 0.13501000E+03, -.45510500E+02, -.28367200E+02, -.67548600E+02, 0.86412700E+02, -.16277900E+03, -.14434600E+03, -.19357200E+03, -.36512400E+01, -.11260500E+03, -.96774100E+03, -.58232400E+03, 0.28694900E+03, -.65660600E+03, 0.29572900E+03, -.88660700E+02, -.30821600E+03, 0.41954200E+03, 0.52459500E+03, 0.50146100E+03, -.86556600E+02, -.12274300E+04, -.76765200E+03, 0.47742000E+03, 0.94861300E+03, 0.38289700E+03, -.32501800E+03, -.35381100E+03, -.24503000E+03, -.58802500E+03, 0.20164400E+03, -.39776400E+03, 0.24405100E+03, 0.16913800E+04, -.83511800E+03, 0.36103000E+03, -.84640600E+03, -.24948500E+03, -.13642800E+03, -.37191900E+03, -.75686000E+02, -.10147200E+03, -.13843300E+03, -.15242100E+04, -.43888100E+03, 0.23192600E+03, 0.36421300E+03, 0.21929200E+03, 0.64484400E+02, -.19069300E+03, 0.26560100E+03, 0.45156600E+03, 0.56454000E+03, -.10113400E+03, -.52794100E+03, -.63829000E+03, 0.31786900E+03, 0.80624000E+02, 0.31906400E+03, -.30509300E+03, 0.12482000E+03, -.45810300E+03, -.93009900E+03, -.92838000E+03, 0.46445100E+02, 0.19425900E+04, -.75718500E+04, 0.37219300E+04, 0.32319500E+03, 0.37905800E+04, 0.14796000E+04, 0.11916800E+04, 0.22940100E+03, -.12871500E+04, 0.17709000E+04, 0.14502000E+04, 0.24601900E+04, -.18319000E+04, 0.91808300E+03, 0.62665800E+03, 0.91524100E+03, -.24636600E+03, 0.45994100E+02, -.65342500E+03, -.15778300E+04, -.15124100E+04, 0.19665200E+03, 0.28821300E+04, 0.46941100E+03, -.22325900E+03, -.39451900E+03, -.23566300E+03, -.40053700E+03, -.55828000E+03, 0.31370600E+03, 0.27825000E+03, 0.28343600E+03, -.42055800E+03, -.58220800E+03, 0.46621400E+02, -.40225400E+02, -.22486400E+03, -.23566900E+02, 0.47867400E+01, 0.13883900E+03, -.10852900E+03, -.11708300E+03, 0.59009400E+02, 0.52138000E+02, -.19747700E+03, 0.16072400E+03, 0.11386300E+03, -.66321400E+02, 0.70474300E+01, -.51914400E+02, 0.77990600E+02, -.46492400E+02, 0.69561600E+02, -.92165800E+02, -.72141600E+02, 0.43878300E+00, -.54626900E+03, 0.35565400E+01, -.29890700E+00, -.16532600E+03, 0.22176000E+03, -.13595700E+03, -.51334200E+02, -.85146500E+02, 0.28706500E+02, 0.14929600E+03, -.21749300E+03, 0.20771900E+03, 0.20460900E+03, -.15115900E+02, 0.47870300E+02 },
        { -.22143300E+01, -.11620500E+01, -.28047500E+00, -.15556800E+01, -.13113600E+01, 0.18646600E+01, -.35824300E+01, -.93886500E+00, -.63357600E+00, 0.21743400E+01, -.16553800E+00, -.51158500E-01, -.24217500E+01, 0.99740300E+00, -.27415000E+00, 0.52373300E+00, -.53164300E+00, 0.10533600E+01, -.73329700E+00, 0.18719400E+01, 0.15279300E+00, -.61068300E-01, -.15514900E+00, 0.16009200E+00, -.37045900E+01, 0.75902600E-01, -.45090400E+00, -.35946700E+00, -.33875400E+00, -.80627000E-01, -.17412700E+00, -.56726200E+00, -.42573300E+00, 0.49512000E+00, -.37044400E+00, 0.12334700E+00, -.29469600E+00, 0.81735800E-01, -.45312500E+00, -.32611400E+01, 0.87123600E-01, -.27604000E-01, 0.14798100E+00, 0.64475200E+00, -.14583300E-01, -.13475500E+00, -.60503600E+00, -.33860400E-01, 0.19744500E+00, 0.13224600E+00, 0.12515400E+01, -.25156600E+00, 0.10001200E+00, -.31205500E+00, -.26192400E+00, -.37360300E+00, 0.36988700E+00, 0.10526600E+00, -.54813100E-01, 0.25868700E+00, 0.14841900E+00, 0.95775200E-01, -.59122600E+00, 0.11264200E+01, -.72237400E-01, 0.95287400E-01, 0.19440400E+00, 0.28900100E+00, -.34434500E-01, 0.95953500E-01, -.73840200E+00, 0.13180600E+00, 0.38839200E+00, -.45637000E+00, 0.80181400E-01, 0.63505000E+00, 0.72838400E-01, -.54174300E+00, -.10100800E+00, 0.10470600E+00, -.15131200E-01, -.29712000E+00, -.82710300E-01, 0.69947100E-01, 0.14668800E+01, 0.22184100E+00, -.10539700E+01, -.39813800E+00, 0.83474900E+00, -.71138100E-01, -.16841200E+01, 0.22155200E-01, -.15621100E+00, -.17789300E+00, -.28732700E+00, -.84538700E+00, 0.28032100E+00, 0.85154000E+00, -.31660600E+00, -.32621300E-02, 0.19031300E+00, -.44535600E+00, 0.13379600E+00, 0.82456500E+00, -.23847400E+00, 0.15604600E+00, -.23572700E+03, 0.20541500E+03, 0.30969500E+02, 0.42884700E+03, 0.10055000E+04, -.50125200E+03, -.24813600E+03, -.50323900E+03, 0.42641300E+03, 0.50597500E+03, -.51731800E+03, 0.15383600E+03, -.26744800E+03, 0.36268000E+03, -.52939500E+03, -.96704000E+03, 0.48288000E+03, 0.62573500E+03, 0.48363700E+03, 0.30128200E+03, 0.44443200E+02, 0.17230000E+03, -.10050600E+03, 0.57412200E+03, 0.70650900E+01, 0.24081300E+03, -.38998500E+01, 0.20109300E+01, -.14866500E+02, 0.19170700E+01, -.19103100E+02, -.13466800E+01, 0.59393700E+01, -.12579100E+01, -.21577100E+02, -.27057300E+01, -.21667000E+01, -.11821800E+04, 0.56978400E+03, -.12448700E+03, 0.59089100E+03, 0.55013400E+03, 0.27369300E+03, -.49248700E+02, -.78969600E+02, 0.25300500E+03, 0.11168400E+03, 0.56914200E+03, 0.69977000E+03, -.34636000E+03, 0.83971100E+02, -.34983000E+03, 0.10880100E+03, 0.15177900E+03, 0.15116400E+03, 0.11583400E+03, -.60485500E+03, 0.41697900E+03, -.77603800E+03, 0.27473200E+03, -.13329300E+03, 0.60220200E+02, -.13721000E+03, 0.46990900E+01, 0.27533200E+02, -.25296000E+03, -.26584000E+03, -.12772800E+03, 0.16939300E+03, -.20302500E+03, -.30290800E+03, 0.15117700E+03, -.34479000E+03, 0.15205100E+03, -.21074300E+03, -.22826000E+03, 0.16916500E+03, 0.16063000E+03, 0.27508100E+03, -.16751100E+03, 0.35195700E+02, -.25936900E+03, 0.14301500E+03, 0.34798000E+03, 0.12981800E+03, -.14278000E+03, 0.66843200E+02, -.24777200E+03, -.22244600E+03, 0.18375000E+03, 0.11828600E+03, 0.61829900E+02, 0.82069500E+03, -.41010700E+03, 0.14938300E+03, -.41006100E+03, -.13101900E+03, -.16713400E+03, -.49394000E+01, 0.88674500E+02, -.30229600E+03, -.24672500E+02, -.51909400E+03, -.29864000E+03, 0.14949900E+03, -.38753700E+02, 0.14936000E+03, -.52172900E+02, -.17325800E+02, 0.61133500E+02, -.17784400E+03, 0.18691300E+03, 0.65647800E+02, 0.43411400E+03, -.16306600E+03, 0.81452300E+02, 0.19792900E+03, 0.81604400E+02, -.54361700E+02, 0.12054100E+03, -.12757300E+03, -.15991500E+03, -.80649700E+01, 0.34321400E+02, 0.18647400E+03, -.61647300E+02, 0.23093600E+02, -.14059600E+03, 0.29835800E+02, 0.86295200E+03, 0.92983700E+03, -.67708100E+03, -.35454300E+02, -.15584900E+03, 0.66071700E+03, -.34839000E+02, 0.47882600E+03, -.23939100E+03, 0.22716700E+02, -.23906600E+03, -.15904100E+03, 0.16942600E+03, -.22975700E+03, 0.23223200E+03, -.21281200E+03, 0.52489600E+02, -.44266800E+03, -.39713300E+03, 0.19868100E+03, 0.22733100E+03, 0.19906600E+03, -.48599900E+02, -.83358800E+02, 0.87049600E+02, -.26390900E+01, 0.37270100E+03, -.79845000E+02, 0.29553300E+03, -.18686700E+03, 0.92390000E+02, 0.46573100E+02, 0.93583100E+02, 0.91011100E+02, 0.11134600E+02, 0.15811500E+02, -.33416900E+02, 0.24509400E+03, -.19399300E+02, 0.33231600E+01, -.13284600E+02, -.11521400E+01, -.50775800E+02, 0.51722700E+02, 0.61005400E+02, -.12778900E+02, -.13655400E+02, 0.30333100E+00, -.16842800E+02, 0.10066700E+02, 0.36901200E+02, -.57928700E+03, -.30135600E+02, 0.91550900E+01, -.21735400E+03, 0.99023900E+02, -.52123800E+02, 0.37355100E+02, -.94593600E+02, 0.41790500E+02, -.24000700E+02, 0.88145000E+02, 0.43594400E+03, -.13694700E+02, 0.56310400E+02, -.56381900E+02 },
        { 0.11017800E+01, -.56642300E+00, -.72344700E-01, 0.68271800E-01, -.17957700E-01, -.70850100E+00, 0.28912500E+01, -.26107000E+01, 0.11205600E+01, -.54289900E+00, 0.14143800E-01, 0.61861500E-01, -.42798400E+00, -.35781700E+00, -.82020600E+00, 0.68392600E+00, -.18759800E-01, -.18668200E+01, 0.41203000E+00, 0.18266800E+00, -.11224500E+00, -.61365900E-01, 0.40661000E-01, 0.15568500E+00, -.66325700E+00, -.83534400E-02, 0.10898500E+00, -.72789300E+00, 0.51059700E+00, 0.11564700E+00, -.16512000E-01, 0.49825100E+00, -.29814000E+00, -.21147800E+00, -.84485600E-01, -.13327200E-02, 0.35146800E-02, -.25178900E+00, 0.53259900E-01, -.26136200E+01, 0.54398400E-01, 0.24740600E-01, 0.44264700E+00, 0.31441800E+00, -.44319700E+00, 0.39895800E-02, 0.35886200E+00, -.90984700E-03, 0.14537900E-01, -.19231200E+00, -.14367400E+00, 0.60238500E-01, 0.15732900E-02, 0.36438600E+00, 0.27603500E+00, -.27269200E+00, -.37163600E+00, -.67386000E-01, 0.31224200E-02, -.37241900E+00, -.12794000E+00, 0.12808000E+01, 0.98379400E+00, -.55704400E+00, -.21758000E+00, 0.61241500E-01, 0.56502900E+00, -.87859200E-02, 0.14180800E-02, -.27761500E-01, -.49234300E+00, 0.26434000E+00, -.17179400E+01, -.28660000E+00, -.43447500E+00, -.65119500E-01, -.65052700E-01, -.34163600E+00, -.27064300E+00, 0.49769600E+00, 0.98290900E-02, 0.16064500E+00, -.67001300E+00, -.43268100E-01, 0.40479100E+00, 0.72468600E-02, -.25598900E+00, 0.10406600E+01, 0.28148300E+01, -.72326000E+00, -.15215700E+01, -.12725600E-01, 0.46066600E-01, -.27180300E+00, 0.76750400E+00, -.13387400E+01, 0.26773300E+00, 0.85319700E+00, 0.20647100E+00, -.19958800E+00, -.25610000E+00, -.11207200E-01, 0.54321700E+00, -.44960000E+00, 0.14934200E+00, 0.26760900E+00, 0.31129300E+00, -.49768200E+03, 0.43551700E+02, -.52476500E+02, 0.69394800E+04, -.34831600E+04, -.36336500E+03, -.34750200E+04, -.30027800E+03, -.72585100E+03, -.14520600E+04, -.54794700E+03, -.23786700E+04, -.74404200E+03, -.31209800E+04, -.98636900E+03, 0.49467500E+03, -.15941300E+03, 0.49280800E+03, -.11946600E+03, -.13547500E+03, 0.27708000E+03, 0.59728300E+02, 0.75878400E+02, -.70351500E+02, 0.66014300E+03, 0.67553900E+02, -.33944600E+02, 0.46227100E+02, -.33793900E+02, 0.69263000E+01, -.11902400E+02, -.62395700E+00, 0.24226400E+02, -.63787200E+01, -.11684800E+02, -.67523700E+02, 0.19027600E+03, -.72594100E+02, -.63214000E+03, -.99820000E+02, 0.66973300E+03, -.73864900E+03, -.34826700E+03, -.47709400E+03, 0.26539600E+03, -.84148600E+03, 0.67394700E+03, -.13637400E+03, 0.62033200E+02, -.52053800E+03, 0.67660000E+02, 0.17597200E+03, -.38787200E+03, 0.16765400E+03, 0.48608400E+03, 0.48348900E+03, -.65727900E+03, -.73805200E+01, -.12378500E+03, 0.58666800E+02, 0.20580300E+03, 0.61695600E+02, -.46166200E+02, 0.21534400E+03, 0.12540400E+03, -.14171700E+02, -.53106500E+02, 0.77309700E+02, 0.13143600E+03, -.38807500E+03, 0.19683200E+03, 0.12887800E+04, 0.19002900E+03, 0.35057600E+03, 0.24264100E+02, -.53029600E+02, -.46866500E+03, 0.62579500E+02, 0.50881100E+01, -.26154000E+02, 0.32121200E+03, -.17130900E+03, 0.50896000E+03, -.15768200E+03, -.17969200E+03, 0.61731900E+03, 0.29517700E+03, 0.11506900E+03, -.57438900E+03, 0.64479300E+03, -.50273800E+03, -.10974600E+03, 0.52963800E+02, -.88785700E+03, 0.55647800E+02, 0.19756000E+03, 0.20238900E+03, -.10445600E+03, 0.56018000E+02, -.17281500E+02, 0.62558000E+02, 0.34868200E+03, 0.10658900E+04, -.53721400E+03, -.25819400E+03, -.53255800E+03, -.93539200E+02, -.14998100E+03, -.15449000E+03, 0.28579000E+02, -.57667600E+03, -.96973500E+02, -.30223500E+03, -.43336500E+03, 0.21752000E+03, 0.31986600E+03, 0.21642900E+03, -.27733400E+02, -.28306500E+03, 0.22543500E+03, -.40710700E+02, 0.41568300E+03, -.21355800E+03, -.30538500E+02, 0.79084900E+04, -.39685300E+04, -.68587400E+03, -.39667700E+04, 0.54468300E+02, -.11528600E+04, -.17465100E+04, -.76398100E+03, -.26081500E+04, -.12401300E+04, -.32210800E+04, -.71711200E+03, 0.35866400E+03, 0.10027400E+04, 0.35878900E+03, 0.90212300E+02, -.55367300E+03, 0.41035600E+03, -.14173100E+03, 0.92923800E+03, -.48284600E+03, -.72952300E+02, -.10409700E+03, 0.49571400E+02, 0.24656100E+03, 0.52009800E+02, 0.18842000E+03, 0.13920500E+03, -.64273200E+02, -.13072700E+03, -.13879000E+03, 0.12522600E+03, 0.70973600E+02, -.85009800E+03, 0.42802000E+03, 0.53306700E+03, 0.42488900E+03, 0.25375400E+03, -.13616600E+02, 0.13631400E+03, 0.96826800E+02, 0.22972000E+03, -.18454000E+02, 0.23304500E+03, -.69396500E+02, -.63740200E+02, -.60343900E+01, -.27917300E+01, -.66450800E+02, -.59888200E+02, -.16466500E+02, -.51680400E+02, 0.40930000E+02, 0.56221100E+02, -.57917400E+02, -.58140500E+03, -.44869600E+02, 0.39745700E+00, -.27427100E+03, -.13467000E+03, 0.96725700E+02, 0.23893500E+01, -.28625000E+02, -.89615000E+02, -.81963500E+02, -.17973800E+03, 0.66885600E+03, -.74340500E+01, -.27801400E+02, 0.53659400E+02 },
        { 0.12253000E+01, 0.12015700E+01, 0.71229700E-01, -.13266500E+00, 0.65116000E+00, 0.75913600E+00, 0.90815700E+00, 0.78599000E+00, 0.60351200E+00, -.10032000E+01, -.10544800E-01, 0.88388000E-01, -.28805500E+00, -.77201000E+00, 0.15718500E+01, 0.11504500E+01, 0.98703700E-01, 0.17645600E+00, -.10338800E+01, -.25764000E+00, -.75364100E+00, 0.86114700E-01, -.10276100E+00, 0.24900600E+00, -.65740900E+00, -.45312500E-01, 0.13020500E+00, -.11396800E+00, 0.20293100E+00, 0.19991600E+00, -.36652900E+00, -.67059500E+00, -.50060600E+00, -.15041800E+00, 0.20592900E+00, -.31335800E+00, 0.96835900E-01, -.34704100E+00, 0.12451800E+01, -.20345200E+01, -.69240800E-01, -.22517700E+00, 0.55158800E+00, 0.84670100E-01, -.49883100E+00, 0.43585700E-01, -.50650700E-02, 0.64501500E-02, -.49388800E-01, -.16710200E+00, -.17332100E+01, 0.11876100E+00, 0.39172400E+00, 0.20692500E+00, 0.18405400E+00, -.11173800E+00, -.18148900E-01, 0.28865300E-01, 0.38685200E-01, -.49408300E+00, -.67784300E-01, 0.14507400E+01, 0.88289100E+00, -.29004300E+00, -.10321300E+00, -.72280200E-02, -.45484400E+00, -.34968900E-01, 0.73247100E-02, -.47934800E-02, 0.71365800E-01, -.78448000E-01, -.46565400E+00, -.27751800E+00, 0.56875100E-01, 0.19627900E+00, -.17529100E+00, -.21388400E+00, -.17128900E+00, 0.38744800E-01, -.73267800E-01, 0.18342900E+00, 0.53573500E+00, 0.19067700E-01, -.16065300E+00, 0.14426700E+00, -.71156500E+00, 0.19631400E+00, -.16804300E+00, -.26465800E+00, -.39553500E+00, 0.93043300E-02, 0.16263900E+00, 0.17622700E+00, 0.34555600E+00, -.17295300E+00, 0.10816400E+00, -.10098500E+00, 0.52898800E+00, 0.77329200E-01, 0.13973700E+00, 0.16005200E-02, -.32666600E+00, -.26533400E+00, -.13694800E+00, -.58327500E-01, -.15460100E+00, -.35819700E+00, 0.54648100E+02, 0.64935100E+02, 0.45486000E+04, -.22747000E+04, 0.67741900E+03, -.22771600E+04, -.39128400E+03, -.14728500E+04, -.10846700E+04, -.14606700E+04, -.20681900E+04, -.12887100E+04, -.20743600E+04, -.10715300E+04, 0.53388300E+03, -.21281400E+03, 0.53542600E+03, 0.50898700E+02, 0.14577800E+02, 0.10645600E+03, -.19440700E+03, 0.41622300E+03, -.39462900E+02, 0.65998400E+03, 0.53876000E+02, -.26763200E+02, 0.67915100E+02, -.26918700E+02, -.82198500E+01, -.17404300E+02, 0.14513300E+02, 0.26581500E+02, -.23934600E+02, -.18671300E+02, -.37055900E+02, -.92802700E+03, 0.40327300E+03, -.97156700E+03, 0.46143700E+03, 0.65153400E+03, -.10813100E+04, -.19201100E+03, -.10352100E+04, 0.30583500E+03, -.10332100E+04, 0.13668200E+04, 0.12465800E+04, -.61758900E+03, -.52737300E+03, -.62365600E+03, 0.22155900E+03, 0.39268100E+02, -.82203000E+02, 0.63715000E+03, -.10737700E+03, -.12441400E+03, -.13909900E+04, 0.32497000E+03, -.15580900E+03, 0.99700500E+02, -.16332300E+03, 0.15667400E+03, 0.43139500E+03, -.23642900E+03, -.60173700E+02, -.14322300E+03, 0.31375300E+03, -.43866000E+03, -.11201100E+04, 0.55993500E+03, 0.10717200E+04, 0.55816200E+03, 0.13004900E+03, -.23335400E+03, 0.37206000E+03, -.12643100E+03, 0.54122600E+03, -.15591400E+03, 0.38121700E+02, 0.15962800E+04, -.77079500E+03, 0.11370200E+04, -.79648400E+03, -.23892400E+03, 0.78437500E+03, -.36019700E+03, 0.78973300E+02, -.90499400E+03, 0.84624900E+03, -.11547700E+04, 0.12847800E+04, -.64099900E+03, -.16720600E+03, -.64216600E+03, 0.15820400E+03, 0.72309100E+02, -.34413600E+03, -.14650500E+02, -.40193300E+03, 0.13715800E+02, -.67045700E+03, 0.84678300E+03, -.42164200E+03, 0.37040200E+02, -.42317300E+03, 0.11466100E+03, -.45726600E+02, -.17185400E+03, 0.68141300E+01, -.51972700E+03, 0.38739500E+02, -.57106400E+03, -.10168500E+04, 0.50811900E+03, 0.69494500E+03, 0.50820500E+03, -.15211000E+03, -.19175500E+03, 0.23297600E+03, -.38632700E+03, 0.64836900E+02, -.17633000E+03, 0.45573500E+03, 0.49220100E+04, -.24863700E+04, 0.70949700E+03, -.24677900E+04, -.61683300E+02, -.21555900E+04, -.14517200E+04, -.22928200E+04, -.25049000E+04, -.18771000E+04, -.18084900E+04, -.14788900E+04, 0.73840300E+03, 0.19103000E+04, 0.73928300E+03, -.17888900E+03, -.51713500E+03, 0.55495000E+03, -.31609700E+03, 0.27665800E+03, -.44206300E+03, 0.27636700E+03, -.25022500E+03, 0.12637700E+03, -.39712700E+02, 0.12462700E+03, 0.48502900E+02, 0.74278800E+02, 0.24027900E+02, -.32118000E+01, 0.15950700E+03, 0.99841700E+02, 0.54406700E+02, -.12618000E+04, 0.62760400E+03, 0.25889800E+03, 0.63066200E+03, 0.37432300E+03, 0.13130200E+03, 0.16439200E+03, 0.19264200E+02, 0.59741900E+03, 0.46894600E+02, 0.53698800E+03, -.92503600E+02, -.59666400E+02, -.53331200E+02, 0.69648500E+02, -.42796600E+02, -.80708500E+02, -.78636100E+02, -.70804400E+02, 0.44848700E+02, 0.71172300E+02, -.62406400E+02, -.73295100E+03, -.10352300E+03, 0.26865800E+02, -.32604800E+03, 0.50405700E+02, 0.63765100E+02, 0.31051800E+02, 0.72934000E+02, -.76200000E+02, -.76296100E+02, -.21933600E+03, 0.77712300E+03, 0.35072800E+02, -.41885300E+02, 0.48435400E+02 },
        { 0.69263200E+01, -.82537600E+00, -.79663900E+00, 0.33485900E+01, 0.12081000E+01, 0.38207700E+00, 0.49207400E+01, -.12725500E+01, 0.23171500E+01, -.45273300E+01, -.14394900E+00, -.43714500E-02, -.12974200E+01, 0.31045200E+01, -.22191900E+01, 0.10516100E+01, 0.14655000E+01, -.18209700E+01, 0.57482600E+00, -.14293300E+01, 0.31901100E+00, -.18743800E+00, -.17494400E+00, -.29020600E+00, -.36412300E+00, -.14776700E+00, -.13350000E+01, -.30264100E+01, 0.34360900E+01, -.20375100E+01, 0.11386400E+01, 0.16765200E+01, 0.19858900E+00, -.95923100E+00, 0.48212900E-01, 0.41231400E+00, 0.21904100E+00, -.81338600E+00, -.13503800E+01, 0.91783700E+01, -.14754600E+00, -.38450800E+00, 0.43711000E+00, -.94847700E+00, -.43380900E+00, 0.96437700E-02, -.68935300E+00, 0.16806500E-01, -.28383300E+00, 0.15592000E+00, -.42105900E+01, -.11306700E+00, 0.12927800E+01, 0.21267300E+01, 0.34038900E+01, -.10433400E+01, 0.14238900E+01, -.19783600E+00, 0.62326100E-01, 0.60930900E+00, 0.43232500E+00, 0.39457900E+00, 0.84370700E-01, 0.13723000E+01, -.13538900E+01, -.17346900E+00, -.13285700E+01, -.25902200E+00, -.68686000E+00, -.12409600E+00, -.85504300E+00, 0.39255300E+00, -.45176700E+00, 0.64406100E-01, -.18477200E+00, -.65528700E-01, -.20905500E-01, 0.53251800E+00, -.22396500E+00, -.16469000E+01, -.26811500E+00, 0.97307100E+00, 0.22873400E+01, 0.39911500E+00, -.44555100E+01, -.90199900E-01, -.19400800E+01, 0.73817600E+00, 0.14606500E+01, -.84425000E+00, 0.15215700E+00, -.12045400E+00, 0.31297200E+00, 0.59533300E+00, -.65022200E+00, -.60012700E+00, 0.24890800E+00, 0.15055300E+01, 0.56905600E+00, -.33179300E+00, -.51301100E+00, 0.99595500E+00, 0.13117300E+00, -.19230800E+01, 0.79315000E+00, 0.19383100E+00, 0.12800300E+01, 0.16461400E+01, 0.28337500E+01, -.40259400E+04, -.44299700E+04, 0.21751000E+04, -.31694800E+03, 0.22255800E+04, -.21184000E+04, -.16654400E+03, 0.29724200E+04, 0.46455500E+04, 0.44354500E+04, -.23267700E+03, 0.26345700E+04, 0.34858100E+04, -.17428900E+04, -.88273000E+03, -.17430900E+04, -.78841500E+03, 0.83088600E+02, -.17570500E+03, 0.89252000E+03, -.10120800E+04, -.32214200E+02, -.27516600E+04, -.18440400E+03, 0.92318900E+02, -.23396000E+02, 0.92429900E+02, 0.33231300E+02, 0.53560900E+02, -.53402400E+02, -.86456600E+02, 0.30746800E+02, 0.61709200E+02, 0.10393300E+03, 0.82586200E+04, -.40521500E+04, -.85580600E+02, -.41227600E+04, -.21071400E+04, 0.21954500E+04, -.64941800E+03, 0.28456800E+04, -.92356200E+03, 0.17440600E+04, -.54698300E+04, -.45230600E+04, 0.22501100E+04, 0.33335100E+03, 0.22618300E+04, -.16894900E+04, -.86482700E+02, -.26299400E+03, -.17140300E+04, 0.13763800E+04, 0.18387400E+03, 0.27765200E+04, -.21915400E+04, 0.10540000E+04, -.12232200E+04, 0.10965400E+04, -.96298200E+03, -.22721100E+04, 0.11870700E+04, 0.21807300E+03, 0.80152900E+03, -.16776400E+04, 0.15393800E+04, 0.26370800E+04, -.13239300E+04, -.26446300E+04, -.12949800E+04, 0.95549600E+03, 0.69574200E+03, -.10450400E+04, 0.14915100E+03, -.14411600E+04, 0.72707100E+03, -.21027800E+04, 0.21147300E+03, -.19113500E+03, 0.96849100E+03, -.11030000E+03, -.17669400E+03, -.32547600E+04, 0.12875900E+04, 0.52961000E+03, -.11619600E+04, -.26556900E+04, -.60205500E+03, -.13768300E+04, 0.69209100E+03, 0.89809600E+03, 0.68553500E+03, -.19890500E+04, -.12402000E+04, 0.57906300E+03, -.33666700E+03, 0.10752000E+04, -.10259000E+04, -.28308000E+03, -.26380000E+04, 0.13269900E+04, 0.11559400E+04, 0.13180900E+04, 0.35127400E+02, 0.60456200E+03, 0.11113100E+03, -.28844200E+03, 0.99310500E+03, 0.36801700E+03, 0.92979100E+03, 0.22405500E+04, -.11228100E+04, -.13240200E+04, -.11203700E+04, -.30082700E+03, 0.21669300E+03, -.57663400E+03, 0.56598900E+03, -.82023900E+03, 0.14664400E+03, 0.28614600E+04, 0.20736100E+04, -.10313800E+04, -.11582000E+03, -.10140700E+04, -.40358000E+04, 0.24124200E+03, 0.31184300E+04, 0.73904200E+04, 0.36172000E+04, 0.15532000E+02, -.22287200E+04, 0.79144100E+03, -.39931800E+03, -.27533500E+04, -.39829000E+03, 0.19930800E+03, 0.77881500E+03, -.97743700E+03, -.25096600E+03, -.96168900E+03, 0.76070700E+03, 0.67535100E+04, 0.10067300E+04, -.49856400E+03, -.13082300E+04, -.50635300E+03, 0.23082200E+03, 0.32296300E+01, 0.16069500E+02, 0.40287500E+03, -.43675200E+03, -.58305400E+02, -.62901400E+03, 0.30206200E+04, -.15104100E+04, -.23460200E+04, -.15109900E+04, -.11807000E+04, -.42238500E+03, -.66083000E+02, 0.49889100E+03, -.10820300E+04, -.25870200E+03, -.22436600E+04, 0.26114100E+03, 0.44358400E+01, 0.14997200E+03, -.14404600E+03, 0.82762500E+02, 0.14594300E+03, 0.90563400E+02, 0.10541500E+03, -.34403900E+02, -.14169100E+03, 0.64424000E+02, 0.30749700E+04, 0.28575000E+03, -.24270600E+01, 0.79008000E+03, 0.32706500E+03, -.20787200E+03, -.84972000E+02, 0.54533100E+03, 0.16719900E+03, 0.47216000E+01, 0.92921700E+01, -.23127600E+04, 0.60365900E+02, 0.11034400E+02, -.14044700E+03 },
        { -.16396400E+01, 0.53770600E+00, -.49502600E-02, -.76565600E-01, -.57434600E+00, 0.92693100E+00, -.26932000E+01, -.81359400E+00, -.67026300E+00, 0.13562900E+01, -.11322600E+00, -.10550000E+00, -.28634700E+01, 0.23774200E+01, -.13028300E+01, -.22227100E+01, 0.38951100E+00, 0.53919600E+00, 0.14116900E-01, 0.99797400E+00, -.23498900E+00, 0.76812200E-02, -.81937300E-01, 0.33097300E+00, -.30554100E+01, 0.44290800E-01, -.25264200E+00, -.13874700E+00, -.59214400E-01, -.24456900E+00, -.52089400E+00, 0.49333300E+00, -.70834600E+00, -.27280600E+00, -.13460700E+00, 0.48431600E+00, 0.45921700E-02, -.32940200E+00, 0.11267100E+01, -.61782100E+00, -.11205300E+00, -.17548400E+00, 0.21803800E+00, -.17581700E+00, -.31489100E+00, 0.74437600E-01, 0.16641600E+00, -.15986700E-01, -.97985100E-01, -.19940800E+00, -.18841200E+01, 0.14685600E+00, 0.29682800E+00, 0.45151800E+00, 0.89177700E-01, 0.16054000E+00, -.10386100E+00, 0.58151300E-01, -.63672200E-01, -.36855500E+00, 0.10175900E+00, -.10068200E+00, -.20824800E+00, 0.19846700E+00, -.47789400E+00, 0.10670800E-01, -.31852800E+00, 0.99849300E-01, -.51333100E-01, -.57905400E-02, 0.51240700E+00, -.25569300E-01, -.78412900E-01, 0.51121700E-01, -.74566400E-01, -.63807400E-02, -.15849200E+00, -.55194400E-01, -.12477900E+00, -.56105000E-01, 0.26202500E-01, 0.12275100E+00, -.35374600E+00, -.23992000E+00, 0.91226500E+00, 0.21123900E+00, -.66669000E+00, 0.83303200E+00, 0.42546000E+00, -.63687600E+00, -.66757400E+00, 0.16616700E-01, 0.12475300E+00, -.56997700E+00, 0.81807600E-01, 0.82120500E+00, -.21445400E+00, 0.10952100E-01, 0.62903000E+00, 0.20555400E+00, 0.10052400E+00, 0.40507900E+00, 0.66134600E-01, 0.12096600E+00, -.51371900E+00, 0.33878500E+00, -.36308800E+00, -.77581500E+00, 0.30581600E+00, -.20838100E+00, 0.55352700E+04, -.27561700E+04, -.68170100E+02, -.27748300E+04, -.48000100E+03, -.76876700E+03, -.94942000E+03, 0.43830800E+03, -.11634000E+04, -.64537300E+03, -.25391300E+04, -.14239300E+04, 0.70462600E+03, 0.18504200E+03, 0.71132500E+03, 0.90079000E+02, -.26726800E+02, 0.34327700E+03, 0.11652100E+03, 0.68395600E+03, -.71809600E+02, 0.62041500E+03, 0.39886200E+01, -.12455400E+01, 0.45919600E+02, -.19911000E+01, -.56080000E+01, -.49801600E+01, 0.43945700E+01, 0.22316400E+02, -.92193300E+01, -.75416100E+01, -.28841600E+02, 0.12112500E+04, -.78599800E+03, -.29054300E+03, -.61235200E+03, 0.55774300E+03, -.47525400E+03, -.14468800E+03, 0.11216300E+03, -.14220900E+03, -.50885700E+03, -.49620700E+03, 0.34144400E+03, -.14960400E+03, -.49426500E+03, -.17154000E+03, 0.30809700E+02, -.55765500E+02, -.36441100E+02, 0.91554600E+02, -.11647900E+03, -.92489800E+02, -.27085400E+03, 0.11903900E+03, -.58821100E+02, -.15959700E+03, -.59781900E+02, -.54482100E+02, -.79303500E+02, -.31631100E+02, -.14224800E+03, -.95993100E+02, -.14314600E+02, 0.20651800E+03, -.80775700E+03, 0.40065000E+03, 0.37614300E+02, 0.40372400E+03, 0.57201300E+02, -.22410600E+03, 0.21291300E+03, -.10706700E+03, 0.33559900E+03, -.17583600E+03, 0.15741800E+03, 0.93647700E+03, -.42291000E+03, 0.14605200E+04, -.46409000E+03, -.64355700E+03, -.22491500E+03, 0.19478100E+03, 0.13660900E+03, -.90497500E+03, -.56577900E+02, -.84370000E+03, 0.98204300E+03, -.48113800E+03, 0.27284200E+01, -.49014700E+03, -.32172200E+03, -.13540900E+03, -.20200600E+03, -.60558100E+02, -.34077100E+03, -.12867700E+03, -.47776400E+03, 0.17867200E+03, -.76718500E+02, 0.13751300E+03, -.88820500E+02, -.13687400E+03, 0.11827100E+03, -.22720500E+03, -.35233100E+03, -.31558900E+03, 0.19912300E+03, 0.46379700E+03, -.88353700E+03, 0.43904000E+03, 0.45182700E+03, 0.44134200E+03, -.65914400E+02, -.64599000E+02, 0.51900100E+02, -.58521500E+03, 0.13257500E+03, -.28954100E+02, 0.57218600E+03, 0.76922600E+04, -.39131200E+04, 0.55142500E+03, -.38634800E+04, -.45721500E+03, -.12298900E+04, -.11199900E+04, 0.67524300E+03, -.21983900E+04, -.10629100E+04, -.37103300E+04, -.11041200E+04, 0.55045600E+03, 0.87016800E+03, 0.55209300E+03, -.10037400E+03, -.23936600E+03, 0.12568700E+03, -.71497500E+03, 0.27857100E+03, -.12075600E+03, 0.47810200E+03, -.27068500E+03, 0.14745700E+03, -.13270500E+03, 0.13487200E+03, 0.21643100E+03, 0.72861300E+02, 0.13580300E+02, -.81089800E+00, 0.10501000E+03, 0.84108900E+02, 0.36235200E+03, -.67641900E+03, 0.32524300E+03, -.20454500E+03, 0.33785500E+03, 0.11113900E+03, -.13628500E+03, 0.30837000E+03, 0.33170100E+03, 0.56910900E+03, -.20807900E+03, 0.56080800E+02, 0.24904700E+01, -.81065300E+02, -.57252600E+02, 0.50979100E+02, 0.13465500E+02, -.58292700E+02, -.32623900E+02, -.21912400E+02, 0.23145500E+02, 0.57978800E+02, -.36384500E+02, -.27740500E+03, -.53911100E+02, 0.16838500E+02, -.33634100E+03, 0.78425800E+02, 0.16139300E+02, 0.47801200E+02, -.40711700E+01, -.94691400E+01, -.14924800E+03, -.11613900E+03, 0.46254300E+03, 0.19374300E+02, 0.90177000E+01, -.47458700E+02 },
        { -.58168800E+01, -.81652000E+01, -.89814400E+00, -.36123200E+01, -.17237800E+01, -.85498500E+00, -.68670900E+01, -.95718900E+00, -.32558700E+01, 0.50277800E+01, 0.21478500E+00, -.26939800E+00, -.20108900E+01, 0.65598500E+01, -.30789700E+01, -.76465200E+00, 0.12775700E+00, 0.11864700E+01, 0.16648300E+00, -.22208900E+01, 0.65769100E+00, 0.25083400E+00, -.24297900E+00, -.10219400E+00, 0.21547900E+00, 0.60999400E-01, -.24405600E+00, 0.44411200E-02, -.55919200E+00, 0.23289300E+01, -.29599000E+00, 0.12809000E+01, 0.73419100E+00, -.12790600E+01, 0.97928500E+00, -.21917200E+00, 0.37472800E+00, -.45294500E-01, -.17859400E+01, 0.87381700E+00, 0.27990400E+00, 0.13969800E+00, 0.30215900E+00, 0.12138000E+01, -.56155500E+00, -.30170400E-01, 0.71798100E+00, -.45685700E-01, 0.12829200E+00, -.26407000E+00, 0.17632000E+01, 0.61139100E+00, -.29788600E+00, -.90333100E+00, 0.30346100E+00, 0.17242300E-01, 0.61769300E+00, 0.23550100E-01, -.63040900E-01, 0.43474000E+00, -.80804400E+00, -.43319000E+01, -.22969400E+01, -.97434200E+00, 0.72650600E+00, -.89208100E-01, 0.95247600E+00, -.57414200E+00, 0.62910400E-01, 0.59631000E-01, -.93524500E+00, 0.52847000E+00, 0.85044700E+00, 0.51490600E+00, 0.75180000E+00, -.11728600E+01, 0.31147000E+00, -.58178000E+00, -.43081500E+00, 0.65227900E+00, 0.84300300E-01, 0.18424000E+00, -.20131800E+01, -.43678700E-02, -.36900000E+00, -.49907700E+00, 0.33470700E+01, -.14308000E+01, 0.30839000E+01, 0.71387300E+00, -.32181400E+01, -.13084000E+00, 0.93577400E-01, -.65168200E+00, 0.38366600E+00, -.17728600E+01, 0.57675500E+00, 0.28424200E+00, 0.88478900E+00, 0.29578000E+00, -.25019800E+00, -.87982400E+00, 0.17469300E+01, 0.62526000E+00, 0.77135600E+00, 0.76567900E+00, 0.19446700E+00, 0.22126400E+01, 0.22785200E+01, 0.40719200E+00, -.32857900E+01, 0.96795400E+02, -.81923500E+03, -.12125700E+02, 0.11145100E+04, 0.24116700E+04, 0.17336600E+04, 0.75855100E+04, 0.52649000E+04, 0.19078500E+04, -.28175900E+03, -.22176900E+04, 0.11014700E+04, 0.12572400E+04, 0.11079900E+04, 0.10273500E+04, 0.42646100E+03, 0.33987500E+03, 0.36709400E+03, 0.11693300E+04, 0.29762400E+03, 0.19044700E+03, -.18329800E+03, 0.92378800E+02, 0.48580200E+00, 0.91607800E+02, -.58778300E+02, 0.22999300E+02, -.45408400E+01, -.44911600E+02, 0.20956800E+02, 0.97144500E+01, 0.47955100E+02, 0.10943300E+04, -.73435900E+03, 0.14286000E+04, -.55857200E+03, 0.19787800E+04, 0.24249400E+04, 0.13949000E+04, 0.43038400E+04, 0.14927200E+04, 0.18774900E+04, -.35937500E+04, 0.43870800E+03, -.19553400E+03, -.28163000E+03, -.22060700E+03, -.11682900E+03, 0.92466200E+02, 0.45689400E+03, -.71634500E+03, -.15415600E+04, 0.88391300E+03, -.11224600E+04, 0.55120200E+03, -.27786900E+03, -.35321700E+03, -.27706900E+03, -.26724300E+03, -.95196100E+03, -.33984600E+03, -.87597000E+03, -.52835800E+03, -.20592400E+03, 0.15982800E+03, 0.25319200E+03, -.12856300E+03, -.31774700E+04, -.12577200E+03, 0.31312400E+00, -.20568500E+03, 0.28200300E+02, 0.53272300E+03, -.30739300E+03, -.12987000E+03, -.80160000E+03, -.65396800E+03, 0.36170400E+03, 0.30533400E+04, 0.33390500E+03, -.20113800E+04, -.28150900E+04, -.16673400E+03, -.17066800E+04, -.17876300E+04, -.22701800E+04, 0.78116500E+02, 0.28856000E+04, -.14319300E+04, 0.13757400E+04, -.14410000E+04, -.13984500E+04, -.68434500E+03, -.43354000E+03, -.54070200E+03, -.11484400E+04, -.41124000E+03, -.22524400E+04, -.12194500E+04, 0.62176300E+03, 0.72186100E+02, 0.61058000E+03, -.67321200E+03, 0.23653900E+03, 0.47276600E+02, -.79435600E+03, 0.61826400E+03, 0.43701700E+03, 0.22614700E+04, -.18619900E+04, 0.92840600E+03, 0.10800600E+04, 0.93040900E+03, 0.23487000E+03, 0.78453000E+03, -.48651400E+03, -.17038200E+04, 0.39123800E+03, 0.75271000E+03, 0.15188900E+04, 0.13385900E+04, -.69107100E+03, 0.19490100E+04, -.69865300E+03, 0.15932100E+04, 0.36640600E+04, 0.29937100E+04, 0.10850300E+05, 0.49583400E+04, 0.28145700E+04, -.32305700E+04, -.40787900E+03, 0.20530700E+03, -.19264700E+02, 0.20446100E+03, 0.22759600E+03, 0.11399000E+04, -.10280400E+04, -.16927800E+04, 0.14488800E+03, 0.11314300E+04, 0.60102700E+03, -.12922100E+04, 0.66093100E+03, -.99718000E+02, 0.64607100E+03, 0.50348300E+03, -.55141300E+02, 0.25866400E+03, -.19767300E+02, 0.25191400E+03, 0.81282900E+02, 0.16304300E+04, -.35431500E+03, 0.16792300E+03, -.14683500E+04, 0.17680800E+03, -.16513500E+03, -.15291100E+03, 0.25792800E+03, 0.24708400E+03, 0.45628500E+03, -.27364300E+03, -.43653200E+03, 0.24465900E+03, -.11114900E+03, -.97006900E+02, 0.68545000E+02, 0.32496200E+03, -.57229700E+02, 0.34515300E+01, 0.48906400E+02, -.45912800E+02, 0.60631300E+02, 0.23973700E+02, -.90652600E+03, 0.12885500E+03, 0.75938900E+02, -.97317900E+03, 0.43629700E+03, -.26616400E+03, 0.12066400E+03, -.29614000E+03, 0.18093200E+03, -.22979400E+03, 0.29666500E+03, 0.87222200E+03, -.60371700E+02, 0.22238100E+03, -.32692900E+03 },
        { -.40347600E+01, 0.18496900E+01, 0.64296600E+00, -.23299300E+01, -.14431300E+01, 0.22650500E+01, -.35796500E+01, 0.38478500E+01, -.16283600E+01, 0.26876900E+01, 0.11032300E+00, 0.30688200E-01, -.14031700E+01, 0.83608700E+00, -.42949200E+01, 0.94745800E+00, 0.21118800E+00, -.21283800E+01, 0.22401200E+01, -.14628200E+01, -.48152500E-01, 0.23083200E+00, 0.19375100E+00, 0.10678300E+00, -.10632700E+01, -.63108900E-01, -.38045800E+00, -.26776900E+01, 0.13785900E+01, -.14023600E+01, 0.46868700E+00, 0.30606400E+00, 0.58473000E+00, 0.73635100E+00, 0.10795900E+00, 0.29639900E+00, 0.54530900E-01, 0.23221100E+00, -.13798000E+01, 0.39428900E+01, -.25546400E-01, -.21883000E+00, 0.15846100E+00, 0.83990800E-01, 0.24030100E+00, -.50868500E+00, -.40556400E+00, -.13467700E-01, 0.34780900E+00, 0.10288000E+01, 0.27976300E+01, 0.74515100E-01, -.10010500E+01, -.67526000E+00, 0.28614100E+00, 0.55418000E+00, 0.17818100E+00, 0.31209100E+00, 0.91451900E-01, -.13417600E+00, -.18316400E+01, 0.19561500E+01, 0.17004800E+01, -.14609700E+01, 0.17673200E+01, -.21036900E-01, 0.37560800E+00, -.57542300E-01, 0.49835500E+00, 0.34168400E-01, -.86703800E+00, -.12556200E+00, -.26510200E+01, 0.10240200E+00, 0.23243800E+00, 0.48995300E-01, 0.18827600E+00, 0.89550000E+00, 0.33421100E+00, -.26787300E-01, 0.75234100E-01, -.48232900E+00, 0.72729100E+00, 0.41715000E+00, -.20385900E+00, 0.18001200E-01, 0.26906400E+01, -.90028400E+00, -.22603000E+00, 0.13387900E+00, 0.19548500E+01, 0.15341100E-01, -.45093800E+00, 0.11358000E+01, 0.43711100E-01, -.18920200E+01, 0.74673000E+00, -.17091300E+00, -.75878800E+00, -.16869300E+00, -.32487800E+00, 0.22458800E+00, -.10481900E+01, -.17754800E+01, 0.60521600E+00, -.23238300E+00, -.24810600E+00, 0.99077600E-01, -.79678800E+00, -.16770800E-02, 0.91327700E+00, -.52665500E+00, 0.85606200E+04, -.46088400E+01, -.82483700E+03, -.15177000E+04, 0.36783900E+03, -.91488100E+02, -.63614100E+03, -.13445400E+04, -.26958200E+04, -.14783800E+03, 0.73210200E+02, -.17980300E+03, 0.73993900E+02, 0.19114900E+03, 0.32202500E+03, -.13380400E+03, -.28024600E+03, -.20596500E+03, 0.17667200E+03, -.65971500E+02, 0.58857400E+02, -.29334700E+02, 0.40418000E+02, -.29526100E+02, -.24697600E+02, -.26412600E+02, -.99370400E+00, 0.22297300E+02, -.20620300E+02, -.18102600E+02, -.72073700E+01, -.51159300E+04, 0.25112200E+04, -.81219000E+03, 0.25545000E+04, 0.41321800E+03, -.36607000E+03, 0.12235500E+04, 0.80472700E+02, 0.13569300E+04, -.56350300E+03, 0.13105400E+04, 0.96760700E+02, -.44746000E+02, -.25126300E+03, -.48566600E+02, -.10706900E+04, -.12966100E+03, 0.36002400E+03, 0.62090500E+03, 0.10680600E+03, -.14103100E+02, -.12245400E+03, 0.39725300E+03, -.20155900E+03, -.31555700E+03, -.19830800E+03, 0.10283700E+03, -.87304100E+02, -.18854000E+03, -.24218800E+03, -.24062500E+03, 0.95286800E+02, -.17909300E+03, -.13379800E+03, 0.66836100E+02, -.53636100E+03, 0.61298300E+02, 0.86571100E+02, -.23088800E+03, 0.10392000E+03, 0.19988900E+03, 0.74375900E+03, -.42047100E+03, 0.12648000E+03, 0.46152500E+04, -.22993800E+04, 0.24224200E+04, -.23054400E+04, -.62034600E+02, -.26220000E+03, -.74914800E+03, 0.24650700E+03, -.10894300E+04, -.29771200E+02, -.20899400E+04, 0.14494400E+04, -.72174100E+03, 0.12107000E+03, -.72348200E+03, -.84707700E+03, -.54584600E+03, -.14606000E+03, 0.25280400E+03, -.17405500E+03, -.43464700E+03, -.31738200E+03, 0.87956800E+03, -.43573700E+03, 0.43688400E+02, -.43943900E+03, -.30119300E+03, -.12049700E+03, 0.11126000E+03, 0.25513300E+03, -.16440900E+03, -.18297400E+03, -.10302500E+03, 0.19908600E+04, -.99657600E+03, -.84240100E+03, -.99539800E+03, -.47768100E+03, -.50656200E+03, -.10738200E+02, 0.10673000E+04, 0.18044700E+03, -.51881900E+03, -.26320300E+03, -.14334700E+04, 0.69917800E+03, 0.10028200E+05, 0.70626200E+03, -.89491500E+03, -.21346300E+04, 0.10691700E+04, 0.31297300E+03, -.31621600E+03, -.20342500E+04, -.32394500E+04, 0.13730400E+04, -.68768900E+03, -.94620700E+02, -.68545800E+03, -.43737000E+03, -.53480900E+03, 0.19553000E+03, 0.14179900E+04, 0.82573800E+03, -.65343700E+03, -.84857300E+02, -.33227400E+03, 0.17103900E+03, 0.21952600E+03, 0.16743500E+03, 0.20251400E+03, 0.20765800E+03, 0.28446700E+02, 0.92848100E+02, 0.41185400E+03, 0.11186100E+03, 0.10784100E+03, -.12342600E+04, 0.61627100E+03, 0.22447600E+02, 0.61742700E+03, 0.38792200E+03, 0.41709400E+03, -.16596800E+03, -.36666900E+03, 0.25404900E+03, 0.29206100E+03, 0.47120000E+03, -.11866500E+03, -.80918600E+02, -.71362900E+02, 0.10425700E+03, -.12788000E+02, -.39927400E+02, -.14412200E+03, -.48747900E+02, 0.50573300E+02, 0.74427000E+02, -.10015600E+03, 0.25601300E+03, -.40061400E+02, 0.33028800E+02, 0.70193500E+02, 0.27723000E+03, 0.33388100E+02, 0.71363200E+02, 0.57718800E+03, -.64478800E+02, -.45550200E+02, 0.13134400E+02, 0.22216600E+02, -.12402100E+03, 0.15842800E+02, 0.56574300E+02 },
        { -.51706900E+01, 0.12353200E+01, 0.22589800E+00, -.16577500E+01, -.28920100E+01, 0.32190200E+01, -.62466200E+01, 0.59503400E+01, -.32135600E+01, 0.42270600E+01, 0.34476200E-01, -.30971500E+00, -.13177700E+01, 0.56376000E+01, -.75062500E+01, 0.31508200E+00, 0.23657300E+00, -.29733000E+01, 0.25435400E+01, -.17113100E+01, 0.93789700E+00, 0.11903100E+00, 0.19235700E+00, 0.20453400E-01, -.12057000E+01, 0.61945200E-01, -.15244200E+01, -.36584400E+01, 0.31394600E+01, -.20451200E+01, 0.13036600E+01, 0.13407800E+01, 0.48904000E+00, 0.10967300E+01, 0.43837100E+00, 0.11084600E+01, 0.15012300E+00, 0.75997800E+00, -.22503100E+01, 0.45388800E+01, 0.68799600E-01, -.14547200E+00, -.13614400E+01, -.48258000E+00, 0.31902000E+00, -.34920900E+00, -.35500800E+00, 0.75760200E-01, 0.24349200E+00, 0.72123700E+00, 0.16637800E+01, 0.68963100E+00, -.10582200E+01, 0.76923500E+00, 0.51241500E-01, 0.19478500E-01, -.95461500E-01, -.50341200E-01, 0.29286000E+00, -.70581300E+00, -.60359600E+00, 0.65021100E+00, 0.81055100E+00, -.79277800E-01, -.59803800E-01, 0.55255100E-01, 0.66456900E+00, 0.35533500E+00, 0.14251200E+00, 0.81973800E-01, -.25690400E+00, 0.26293700E+00, -.24365700E+01, 0.29549900E+00, 0.13860900E+00, -.71065500E+00, 0.20085500E+00, 0.37940200E+00, -.11298600E+00, 0.41008000E+00, -.30994400E-01, 0.47123600E-01, 0.75561500E-01, -.11804800E+00, 0.56396200E+00, -.21216600E-01, 0.19372600E+00, -.56122600E+00, -.23085900E+01, 0.95552300E+00, 0.25182700E+00, 0.71581400E-01, 0.15487500E+00, -.72970800E+00, -.37795900E+00, -.44343800E-01, -.21711400E+00, 0.61717400E-01, -.38534700E+00, -.17901400E+00, -.34203000E+00, 0.28119500E+00, 0.14607400E+00, -.64238500E+00, -.10146400E+00, -.52436100E+00, 0.45634200E+00, -.55034500E+00, 0.49698200E+00, 0.66419500E-01, 0.26017500E+00, -.52806100E-01, 0.20234200E+00, 0.13797500E+02, -.16638900E+03, 0.12183300E+03, -.52585300E+03, -.87656900E+03, -.99545400E+03, 0.78147800E+02, 0.18702700E+03, 0.45537900E+03, -.22859100E+03, -.58875400E+03, -.22637100E+03, -.22674200E+03, -.13649000E+02, -.87580600E+02, 0.13408200E+02, -.30826000E+03, 0.15947600E+02, 0.20494600E+03, 0.52535200E+01, -.25705400E+01, 0.24038700E+02, -.28098900E+01, 0.14606700E+02, -.39603200E+01, -.14394700E+02, -.56224400E+01, 0.19100700E+02, -.26979200E+00, -.87807600E+01, 0.25252600E+03, -.15109400E+03, 0.10449700E+04, -.11970400E+03, -.45026100E+03, -.34204800E+03, 0.53233600E+02, -.26403400E+03, -.51848400E+03, -.29575300E+03, 0.73375000E+03, -.74818000E+03, 0.37898500E+03, -.18714600E+03, 0.37531600E+03, 0.32688800E+03, -.18936000E+03, -.30333900E+02, -.12033400E+03, 0.57130800E+03, -.43980900E+03, 0.53684900E+03, -.15777900E+03, 0.89879500E+02, -.14036700E+02, 0.81683100E+02, -.76540900E+01, 0.53729700E+02, 0.26192800E+03, 0.27822400E+03, 0.11557700E+03, -.12053800E+03, -.26812300E+02, 0.16927200E+03, -.83054000E+02, 0.68794600E+03, -.95270100E+02, 0.14459300E+03, 0.18358800E+03, -.96382500E+02, -.10292700E+03, -.15586500E+03, 0.13305900E+03, -.67573800E+02, 0.10976500E+04, -.52921800E+03, -.13696800E+04, -.55269400E+03, -.10980100E+03, -.42288500E+02, 0.27982800E+03, 0.53677800E+03, 0.15197000E+03, -.86132000E+02, -.50176100E+03, -.88082000E+03, 0.44179800E+03, -.33578300E+03, 0.44105500E+03, 0.31094400E+03, 0.13528600E+03, 0.10165100E+03, 0.26212000E+02, 0.35112700E+03, 0.36276400E+02, 0.52949100E+03, 0.32572500E+03, -.16278200E+03, -.11179200E+03, -.16314200E+03, -.28046000E+02, -.11633400E+03, 0.13993000E+01, 0.26339200E+03, 0.22556900E+02, -.17810400E+03, -.52488900E+03, 0.69929000E+02, -.34266200E+02, -.78063200E+02, -.34115900E+02, 0.66110900E+02, -.92744800E+02, -.58527100E-01, 0.32337900E+02, -.11515000E+03, -.93757200E+02, -.51377300E+03, 0.10234900E+04, -.51709400E+03, 0.14112300E+03, -.49804200E+03, -.57153600E+03, -.25053900E+03, -.53119000E+03, -.10273700E+04, -.14600300E+04, -.24469400E+03, 0.45194300E+03, -.31830400E+03, 0.16097900E+03, -.65223100E+01, 0.16105800E+03, 0.13496400E+03, -.14467600E+03, 0.35045600E+02, -.13791800E+03, -.11203200E+03, -.13545400E+03, -.38224300E+03, 0.18750400E+03, -.92252900E+02, -.12407700E+03, -.90539200E+02, 0.85266000E+02, 0.83541700E+02, -.14934400E+02, 0.39319100E+02, -.16748800E+03, 0.57085300E+02, -.26456300E+03, 0.22758500E+03, -.11583600E+03, 0.77636700E+02, -.11260500E+03, -.18533300E+02, 0.85443300E+01, -.44361200E+02, -.15997900E+01, -.20175800E+03, 0.28502000E+02, 0.12313600E+03, 0.26011800E+01, -.25879600E+02, 0.34211500E+02, -.17945900E+02, -.48040700E+02, -.55772900E+01, 0.99905900E+00, -.88741900E+01, 0.22888900E+02, -.23588200E+01, -.17330600E+02, 0.26593600E+03, 0.29768700E+01, 0.16059400E+01, 0.16180400E+03, -.17377800E+03, 0.68599600E+02, -.22514000E+02, -.62078900E+02, -.50353800E+02, 0.40267000E+02, -.18050300E+02, -.25445200E+03, 0.26832600E+01, -.37130300E+02, 0.47242600E+02 },
        { -.18504900E+01, -.84427800E+00, -.86596300E-01, 0.17664600E+00, -.70035800E+00, -.25520400E+01, -.60926400E+00, -.59684800E+00, -.99543600E+00, 0.19152600E+01, 0.20131000E-01, -.83800400E-01, -.45246400E+00, 0.13299300E+00, -.10940900E+01, 0.75632800E+00, 0.43005500E+00, -.65523900E+00, -.30357000E+00, -.56231500E+00, -.15953300E+00, 0.11719700E+00, 0.76751300E-01, 0.42242300E+00, -.17491500E+01, -.53997200E-01, -.30062600E+00, -.83449200E+00, 0.66105800E+00, 0.57060000E+00, -.34863700E+00, 0.59841200E-01, -.34424300E+00, -.42091800E+00, 0.46412600E-01, -.22388500E+00, 0.14733500E+00, -.89521700E+00, -.66482500E-01, -.50254300E+01, -.35493300E-01, -.48960200E+00, -.31459100E-01, 0.96178400E+00, -.14663700E+00, 0.83189100E-01, -.10110100E+00, -.78573700E-02, 0.12951000E+00, 0.22725100E+00, 0.15639200E+01, -.38074300E+00, -.24929800E+00, -.79913500E+00, -.32057800E+00, 0.45728700E+00, -.30382800E+00, 0.80516500E-01, -.75949800E-02, -.57286500E-01, 0.19593700E+00, 0.70034600E+00, 0.13507600E+00, -.49313000E+00, 0.48111800E+00, 0.50655700E-01, 0.25639600E-01, 0.97927400E-01, 0.16996000E+00, 0.68804800E-01, 0.14923700E+00, -.35893800E-01, -.24762800E+00, 0.16958100E+00, 0.25650000E+00, -.34539800E+00, -.42799700E-01, -.19072600E-01, 0.34017400E-01, -.30747300E+00, 0.86299400E-01, 0.27223200E+00, 0.75031700E+00, 0.90546600E-01, -.17265000E+01, -.22743700E+00, -.34611800E+00, 0.91090700E+00, -.25502400E+00, -.13649900E+00, 0.15256500E+01, 0.57272600E-01, -.21783400E+00, 0.73891900E+00, 0.16197000E+00, -.10796000E+01, 0.28412400E+00, -.27279900E+00, 0.10566300E+00, -.10824900E+00, -.72311200E-01, -.58626000E+00, -.44281100E-01, 0.58392100E-01, 0.30671300E+00, -.52884500E-01, 0.57540100E+00, 0.75334500E+00, -.76382100E+00, -.13211000E+00, -.45738500E+00, 0.34584100E-01, 0.15868700E-01, -.41010500E-01, -.11448200E+04, -.10472100E+04, 0.19770800E+03, -.11125600E+03, 0.15080400E+03, -.78620500E+03, 0.83525300E+03, -.16739300E+02, 0.40473800E+01, -.49636300E+03, 0.81639900E+01, -.18199200E+03, 0.52435500E+02, 0.18152700E+02, 0.17601500E+03, 0.42297500E+02, 0.32528800E+02, 0.13821700E+03, -.49661400E+02, 0.25274500E+02, 0.49349500E+02, 0.24866800E+02, -.42902900E+01, -.83092900E+01, 0.17579600E+02, 0.11149500E+02, 0.33725000E+02, -.88220700E+01, 0.10537500E+02, 0.29885600E+04, -.15800300E+04, -.57843300E+03, -.14949900E+04, -.81895700E+03, 0.92422900E+02, -.80007400E+03, -.21928700E+03, -.12713600E+04, 0.24911900E+03, -.61732900E+03, -.99774300E+03, 0.51123600E+03, -.20610600E+03, 0.49870200E+03, -.42470100E+03, 0.10692100E+03, -.41376500E+03, -.65678600E+03, 0.37627900E+03, 0.95238000E+01, 0.61473500E+03, -.46944500E+03, 0.23239200E+03, -.63234500E+03, 0.23458100E+03, -.14424600E+03, -.45039700E+03, 0.29180000E+03, 0.10958300E+03, 0.24579400E+03, -.40511600E+03, 0.19043000E+03, -.14014500E+03, 0.68114500E+02, -.27207700E+03, 0.72396700E+02, 0.10624100E+03, -.10232000E+03, -.88529900E+02, -.88307000E+02, -.31026000E+02, -.62284300E+02, 0.65818100E+02, 0.96713300E+03, -.46650700E+03, 0.69771600E+03, -.48316800E+03, -.59778100E+02, -.63543400E+03, 0.52270300E+03, 0.73031500E+03, -.36472900E+03, -.55642400E+03, -.67589700E+03, 0.77245700E+02, -.31833900E+02, 0.67489800E+03, -.38826900E+02, -.54852700E+03, -.26335100E+03, -.22285700E+02, -.15018500E+03, 0.42053300E+02, -.28356100E+03, -.17046500E+03, -.33155800E+03, 0.17544300E+03, 0.38891900E+03, 0.16579100E+03, 0.12322500E+03, 0.18421000E+03, -.98314700E+02, -.12802800E+03, 0.16616400E+03, 0.14923400E+03, 0.19037500E+03, 0.20035800E+03, -.10197200E+03, -.22790700E+03, -.10031000E+03, -.16405100E+02, -.35448800E+02, -.27316100E+03, -.51466000E+03, -.29557800E+03, -.94355100E+01, -.14854700E+03, 0.29795300E+04, -.15146300E+04, 0.77207200E+02, -.14909300E+04, -.19004200E+04, -.13213600E+04, -.33917900E+03, -.13461300E+03, -.11519900E+04, -.87647200E+03, 0.91061300E+02, 0.64409600E+02, -.32091600E+02, -.51441500E+03, -.32584500E+02, -.53728800E+02, -.16193500E+03, -.42087100E+03, -.97360900E+03, -.38352100E+03, -.45987000E+02, -.31350600E+02, -.24065800E+03, 0.12896800E+03, -.73030800E+03, 0.11973200E+03, 0.12563100E+03, 0.14811900E+03, -.72076100E+02, -.11028200E+03, 0.22100100E+01, 0.14223200E+03, 0.14151300E+03, -.30241100E+03, 0.14315500E+03, -.53147800E+03, 0.15100100E+03, -.14470600E+03, 0.43803400E+02, 0.70377200E+02, 0.99161900E+02, 0.35298100E+02, 0.36251900E+00, 0.14930400E+03, 0.51648900E+02, -.20481100E+02, -.26225300E+02, 0.17345900E+02, 0.12780500E+02, -.24709500E+02, -.20458000E+02, 0.20027400E+01, 0.19077500E+02, 0.26665900E+02, -.53228000E+02, 0.10135100E+04, -.12481700E+01, 0.31622200E+02, 0.23348600E+03, 0.14750200E+03, -.17873800E+02, 0.37712800E+02, 0.15779400E+03, 0.13615500E+02, 0.31482200E+01, 0.30278700E+02, -.70126500E+03, -.82091600E+01, -.63959300E+02, 0.11048100E+01 },
        { -.10391000E+01, -.89476600E+00, -.41188300E-01, -.37628800E+00, -.84817500E+00, 0.28047500E+00, -.92392600E+00, 0.76052000E+00, -.60419900E+00, 0.98832200E+00, 0.27453000E-02, -.81031200E-01, 0.33311100E+00, 0.13289900E+01, 0.43956800E+00, -.34399700E+00, -.39569200E+00, 0.24750500E+00, -.10417600E+00, 0.38503700E+00, -.10820800E-01, 0.10939400E-01, 0.12608700E-01, 0.89833500E-01, -.62803100E+00, 0.62649100E-02, -.21394400E+00, 0.23249300E+00, 0.90927500E-01, 0.17614400E+00, 0.11748900E-01, 0.39572600E+00, -.73827800E-02, -.31367200E-01, 0.62728300E-01, 0.13033300E+00, 0.12237500E-01, 0.78164700E-01, 0.59809400E-01, 0.11773300E+01, -.63790400E-03, 0.98203600E-01, -.47013000E+00, -.66085100E-01, 0.14949700E+00, 0.87318800E-01, -.28708000E-01, 0.59319900E-02, -.28354800E-01, -.58006300E-01, 0.28615000E-01, -.17164500E+00, 0.71892000E-01, -.52414600E-01, -.14080300E+00, 0.12816700E+00, -.11090100E+00, 0.67369200E-01, -.14059300E-01, 0.20175900E+00, 0.55281900E+00, -.86416000E-01, -.27168900E+00, 0.92377600E-01, -.33005700E-01, -.56776900E-01, 0.45403200E-01, 0.26373700E-01, 0.16381400E-01, -.57963200E-02, -.31647600E-01, -.15250100E-01, 0.37188700E-01, -.72883600E-01, 0.43279500E-01, -.81744900E-01, 0.13037500E+00, -.23644300E+00, -.69965700E-01, 0.50203500E-01, -.23638300E-01, -.13843800E+00, -.31366000E+00, -.81472400E-01, 0.70444500E+00, 0.13591100E+00, 0.19526300E-01, -.37371200E+00, 0.32640900E+00, -.18458300E+00, -.60085000E+00, -.19593600E-01, 0.84530800E-01, -.16006100E-01, -.25965800E+00, -.12307100E+00, 0.38938500E-01, 0.10623600E-01, -.75183400E-01, -.17821400E-01, 0.83157200E-01, -.35454700E-02, 0.57705700E-01, -.25212400E+00, 0.22943100E+00, -.93917200E-01, -.29486500E+00, 0.25047200E+00, 0.30421100E+00, 0.64988000E-01, 0.85784900E-01, 0.66218400E-01, -.10035900E+00, 0.16103100E+00, -.24921100E+00, 0.70439100E+03, -.14319700E+03, -.62606500E+01, -.44296500E+03, 0.61647600E+03, -.20031200E+03, 0.20330400E+03, -.97505900E+02, 0.92946300E+02, -.10164000E+03, 0.79447300E+01, -.38773000E+02, 0.27533000E+02, 0.37691300E+02, -.10251900E+03, -.26795700E+01, -.32433900E+03, -.14415000E+02, 0.68214300E+01, -.15002400E+02, 0.72290900E+01, -.23480900E+01, 0.57359700E+01, 0.24220600E+01, -.35385600E+00, 0.86644700E+01, 0.38784800E+01, 0.10064300E+02, 0.80775600E+03, -.32017900E+03, -.48829200E+03, -.40289900E+03, -.27305100E+03, 0.54165100E+03, -.25130100E+03, -.38637100E+02, -.79383500E+03, 0.50311500E+03, -.65812700E+03, -.60143000E+03, 0.29061900E+03, 0.20289300E+03, 0.30078200E+03, -.12144500E+03, -.15289300E+02, 0.10155100E+03, -.18032400E+03, 0.46322600E+02, 0.13439600E+03, 0.36544400E+03, -.21650100E+03, 0.10786100E+03, 0.35771900E+02, 0.10808200E+03, -.31681500E+02, -.17764400E+03, 0.18493100E+02, -.43836500E+02, 0.10557300E+03, -.86704100E+02, 0.14053500E+03, 0.32219100E+03, -.16047900E+03, -.37112800E+03, -.15883000E+03, -.58183700E+02, -.52889300E+01, -.11285700E+03, 0.38248900E+02, -.97721800E+02, 0.33481100E+01, -.10570600E+03, -.70558900E+03, 0.33202100E+03, 0.13187600E+03, 0.35216000E+03, 0.21698400E+03, -.20527400E+03, 0.88557900E+02, 0.98332600E+02, 0.64505300E+03, -.21743600E+03, 0.43148400E+03, -.49993800E+03, 0.24506900E+03, 0.21924000E+03, 0.24965200E+03, -.88417200E+02, -.10997000E+03, 0.19035800E+03, 0.27053800E+02, 0.16885100E+03, -.47704500E+02, 0.83658700E+02, -.32152400E+03, 0.15600000E+03, 0.34599400E+02, 0.16065300E+03, 0.46842900E+02, 0.28335400E+02, 0.42682100E+02, -.67774800E+02, 0.18910300E+03, 0.38892000E+01, 0.15297400E+03, 0.71217500E+03, -.35536300E+03, -.38570000E+03, -.35607600E+03, -.11112700E+02, 0.29753600E+02, -.15213800E+03, 0.20702200E+03, -.54117000E+02, 0.11206600E+02, -.33451100E+01, 0.25869900E+03, -.88574700E+02, -.35260700E+03, -.12638600E+03, -.96250700E+02, 0.11631800E+04, -.33158900E+03, -.31984100E+02, -.79230500E+03, 0.10223200E+04, -.46928400E+03, 0.95411200E+03, -.47718000E+03, -.70972700E+03, -.47730200E+03, -.28404400E+02, 0.12861200E+03, -.32281600E+03, 0.13881500E+03, -.13801100E+03, 0.77052500E+02, 0.68980400E+02, 0.16200200E+03, -.86436700E+02, 0.37659100E+01, -.81266500E+02, -.40312100E+02, -.38794300E+02, -.58231600E+02, -.35197300E+02, 0.34915100E+02, -.70383700E+02, -.16248600E+02, 0.29349700E+03, -.14024900E+03, -.10517200E+03, -.14679700E+03, -.59141500E+02, 0.23939300E+02, -.90345000E+02, -.89981700E+02, -.21181100E+03, 0.57265200E+02, -.22859500E+03, 0.20887500E+02, 0.29171400E+02, -.38201800E+01, -.15228100E+02, 0.10224700E+02, 0.28212600E+02, 0.18904200E+02, 0.21117500E+02, -.22318800E+02, -.21857900E+02, 0.94956200E+01, 0.44950700E+03, 0.17982500E+02, -.61459500E+01, 0.17600700E+03, 0.39213700E+02, -.76229300E+01, -.24322200E+01, 0.57301400E+02, 0.27627900E+02, 0.29522300E+02, 0.72980200E+02, -.40098800E+03, -.16831400E+02, 0.78201200E+01, 0.20362500E+01 },
        { 0.23172700E-01, -.62329100E-02, -.49940100E-01, -.95800200E+00, 0.29541800E+00, -.19110200E+00, 0.42409000E+00, -.49799900E+00, 0.31930700E+00, -.44312900E+00, -.93903600E-02, 0.43056800E-01, -.63325500E-01, -.58271700E+00, 0.16618600E+00, -.28360200E+00, -.33894000E-01, 0.23114500E+00, 0.78423800E-01, -.34108700E-01, 0.16864800E-01, -.36618800E-02, -.28297000E-02, -.76498400E-01, 0.25458000E+00, 0.36110300E-01, 0.16129800E+00, 0.17736700E+00, -.33196200E+00, 0.58170500E-01, -.42266000E-01, -.73481600E-01, 0.53617600E-01, -.26587900E-01, -.57709700E-01, -.76272200E-01, -.52883600E-01, -.18049500E-02, 0.32593700E-01, -.27042800E-01, 0.18659400E-01, 0.35131800E-01, 0.15720000E+00, 0.57523100E-01, -.49285400E-02, -.13996000E-01, -.33659700E-02, 0.12063200E-01, -.29528700E-01, -.90049800E-02, 0.64685200E-01, -.66126000E-01, 0.36622800E-01, -.58431800E-01, 0.17080500E-01, 0.72101800E-02, -.32388100E-01, 0.22169600E-01, 0.23962300E-01, 0.84503900E-01, 0.13832200E+00, 0.67388500E-01, -.27321600E-01, 0.80111800E-02, -.58788700E-01, 0.14013600E-01, -.14293400E+00, -.38526300E-01, -.19880600E-01, -.49576000E-02, 0.74554300E-01, -.93643900E-01, 0.53485200E+00, -.76027600E-01, -.11576300E+00, 0.29620100E+00, -.12221600E+00, 0.78150600E-01, 0.54629200E-01, -.91234600E-01, -.32676000E-01, 0.56423400E-01, -.13549500E+00, 0.81141800E-01, -.78976500E-02, 0.73678100E-01, -.33502400E-01, 0.33629700E+00, 0.71590000E+00, -.46089600E+00, -.67967900E-01, 0.21003600E-02, 0.27268500E-01, -.10331500E-01, -.52765300E-01, 0.13826800E+00, -.44708400E-01, -.38815100E-01, 0.20373700E-01, 0.21731900E-01, 0.92959800E-02, 0.88672400E-01, -.57840300E-02, 0.15961400E-01, -.67786500E-01, 0.11583300E+00, -.38027400E-01, 0.85194500E-01, -.24713900E+00, -.37483200E-01, 0.12172200E+00, -.71637000E-01, 0.12896100E-01, 0.78696600E-01, -.65976000E-01, -.14157300E+00, 0.28888800E+03, 0.69923700E+03, 0.56039100E+03, 0.38187800E+02, -.16091200E+02, -.29888600E+03, 0.14818400E+03, 0.11256000E+03, 0.14937400E+03, 0.13162700E+03, 0.56630800E+02, 0.23716900E+02, 0.18524300E+01, 0.16154300E+03, 0.34138100E+02, -.19867200E+02, -.13014000E+02, 0.66431200E+01, 0.47265900E+01, 0.65366000E+01, -.97280800E+01, 0.19479100E+00, 0.77333800E+01, 0.96605900E+00, -.85516800E+00, -.24545600E+01, 0.74497200E+01, 0.26930500E+03, -.15646200E+03, -.30538100E+03, -.13423100E+03, 0.16762300E+03, 0.15460300E+03, 0.36672800E+01, 0.27757200E+03, 0.14607100E+03, 0.16906200E+03, -.44041300E+03, 0.32543900E+03, -.15963600E+03, -.84886000E+01, -.16273500E+03, -.65393200E+02, 0.11147600E+03, -.37348200E+02, -.18585000E+02, -.29040500E+03, 0.22266300E+03, -.35762400E+03, 0.60602200E+02, -.33779700E+02, -.96163700E+02, -.31064900E+02, 0.85175900E+01, -.44360900E+02, -.99700800E+02, -.85186200E+02, -.69104000E+02, 0.45685400E+02, -.48150700E+02, -.16139500E+03, 0.79722900E+02, -.29726800E+03, 0.82911400E+02, -.39036500E+02, -.11114000E+03, 0.48719200E+02, 0.46551900E+02, 0.75330100E+02, -.78299600E+02, -.56053500E+01, -.27886400E+03, 0.14089700E+03, 0.65376800E+03, 0.13912200E+03, -.70515900E+02, -.10232700E+03, -.82064100E+02, -.21527200E+03, -.19215000E+03, -.66295100E+02, 0.85497300E+02, 0.52001600E+03, -.25833200E+03, 0.30549100E+03, -.26031800E+03, -.18204100E+03, -.10085300E+03, -.81596400E+02, -.66953500E+02, -.19062500E+03, -.57332300E+02, -.37788100E+03, -.16684900E+03, 0.86259600E+02, 0.73168500E+02, 0.83347200E+02, -.21663700E+01, 0.47725800E+02, 0.10078000E+00, -.12405000E+03, 0.36555300E+02, 0.79756800E+02, 0.23376200E+03, -.23182900E+02, 0.10830700E+02, 0.71769000E+02, 0.11549700E+02, -.41627300E+02, 0.56593800E+02, -.93220100E+02, -.18958100E+03, -.18502800E+02, 0.57047900E+02, 0.16955600E+03, 0.23185200E+03, -.12411600E+03, 0.77001000E+02, -.11418400E+03, 0.58853600E+02, 0.93692500E+02, 0.29993700E+03, 0.89936900E+03, 0.57286900E+03, 0.14651300E+03, -.37882400E+03, 0.17038500E+03, -.85626300E+02, 0.60000100E+02, -.85518300E+02, -.80762600E+02, 0.50400000E+02, -.15332900E+03, -.19560300E+03, -.51197000E+02, 0.65736900E+02, 0.53782900E+02, -.18984700E+03, 0.97070300E+02, -.60754100E+02, 0.94503300E+02, 0.11784800E+02, 0.46617200E+01, 0.14739600E+02, -.25827100E+02, 0.66312000E+02, 0.21555700E+02, 0.19361300E+03, -.21476400E+03, 0.10555100E+03, -.17346700E+03, 0.10726900E+03, 0.90775900E+01, 0.12906300E+02, 0.43652800E+02, 0.19652300E+02, 0.12091300E+03, -.92376600E+01, 0.17507900E+02, 0.86226400E+01, -.44563700E+01, -.18998600E+02, 0.16498500E+02, 0.34477800E+02, -.10020100E+02, -.94408300E+01, -.11286200E+01, -.53360900E+01, 0.11092100E+02, -.26251100E+01, -.38959300E+02, -.19765700E+01, 0.11099900E+02, -.99572100E+02, 0.10219900E+03, -.42281200E+02, 0.19705500E+02, 0.62541600E+01, 0.22350600E+02, -.23807300E+02, 0.19966800E+02, 0.73287000E+02, -.25744000E+01, 0.11517400E+02, -.29902800E+02 },
        { 0.12871500E+01, 0.75348300E+00, 0.54342500E-01, 0.29348400E+00, 0.85047800E+00, -.43828300E+00, 0.17786300E+01, -.18937400E+01, 0.10055300E+01, -.11241900E+01, -.54524700E-01, 0.51680000E-01, -.46050700E+00, -.59184500E+00, -.90590800E+00, -.21651700E+01, 0.32365800E+00, -.36474100E+00, 0.68427500E+00, -.49871100E+00, 0.99214500E-01, -.24458500E-01, 0.59946300E-01, -.16686800E+00, 0.10465200E+01, 0.25251200E-01, 0.22036400E+00, -.48135400E-01, 0.10700500E+00, -.15398100E+00, 0.97023900E-01, 0.63367500E+00, -.90887900E-01, -.19730700E-01, 0.12325400E-01, 0.30288700E+00, 0.15817500E-01, -.35059100E-02, 0.35669500E+00, -.14125400E+01, 0.33937800E-01, 0.26578400E+00, -.25965000E+00, -.30942600E+00, 0.95513400E-01, -.22418000E+00, 0.26094600E+00, 0.12678400E-01, -.12825900E+00, -.10452900E-01, -.68979100E+00, 0.13843300E-02, -.16499100E+00, 0.23057100E+00, -.50484500E+00, 0.34331500E+00, -.68148200E+00, 0.36197600E-01, -.16756700E-01, -.37749300E-01, 0.34271900E+00, -.96478300E+00, -.54793400E+00, 0.77511900E+00, -.49754700E+00, 0.16345500E+00, 0.75241400E+00, -.78510600E-01, 0.10907800E-01, -.25530000E-02, 0.26676900E+00, -.18209200E+00, 0.11570000E+00, -.29811600E+00, -.32778800E+00, 0.49922000E-01, 0.53231900E-01, -.15254000E+00, -.11451500E+00, 0.32034400E+00, 0.45667200E-01, 0.56281700E-01, -.51190000E+00, 0.41911300E-01, 0.63475500E+00, 0.15854100E+00, -.65310300E-01, 0.66536600E-01, 0.21169000E+00, -.57922600E-01, -.98798300E+00, 0.24306500E-01, -.15680700E+00, -.22472400E+00, 0.75726700E+00, 0.43471300E+00, -.81411600E-01, 0.38347400E+00, 0.47075900E+00, -.35043300E-01, 0.37596900E-01, 0.33053300E+00, -.20530500E+00, 0.63769500E-01, -.23465800E+00, 0.28124700E+00, 0.23873500E+00, 0.10825500E+00, -.39006600E+00, -.60373900E-02, 0.34851600E+00, 0.77863300E-01, 0.87052600E-01, 0.20986400E+00, 0.14389200E+00, -.97948200E+00, -.61275700E+00, -.93661100E+03, -.78561800E+03, 0.26981800E+02, -.15865200E+03, 0.40712800E+03, -.19827200E+03, 0.21525300E+03, -.20375800E+03, -.92077400E+02, -.11266700E+03, 0.40633000E+02, -.61749400E+01, -.82331900E+02, -.66959600E+02, -.40521000E+03, 0.20546300E+02, -.10757100E+02, -.36682000E+02, -.10165700E+02, 0.37524300E+01, 0.26990500E+01, 0.13682600E+02, 0.86832800E+01, -.67789000E+01, 0.12168700E+01, -.20169700E+01, -.10182100E+03, 0.14309700E+03, -.14330900E+04, 0.53397000E+02, -.59051800E+02, 0.44253900E+03, -.43799700E+03, -.81114200E+03, -.36496400E+03, 0.40681100E+03, 0.11264200E+03, -.10397900E+03, 0.39126100E+02, 0.34783500E+03, 0.52028600E+02, -.21123900E+03, 0.12684100E+03, 0.11109100E+02, 0.51130700E+02, -.98726000E+02, 0.21924400E+03, 0.17541400E+03, -.25652300E+03, 0.12919100E+03, 0.16174700E+03, 0.12661400E+03, -.42976500E+02, -.69579200E+02, -.13523600E+03, -.99359500E+02, 0.10116100E+03, -.52309700E+02, 0.21009000E+03, 0.20206300E+03, -.10067900E+03, -.36922100E+03, -.95577300E+02, -.56556200E+02, -.62561000E+01, -.94527500E+02, -.32369800E+01, -.53655100E+02, 0.39868200E+02, 0.27265400E+02, -.10061300E+04, 0.48516500E+03, 0.26057600E+03, 0.50146400E+03, 0.52929700E+03, 0.17583700E+03, -.13086900E+03, 0.84283700E+02, 0.62118600E+03, 0.13100200E+03, 0.47393300E+03, -.38648100E+03, 0.18631800E+03, 0.61489700E+02, 0.19203200E+03, 0.10326800E+03, 0.75983800E+02, 0.11796100E+03, 0.45526600E+02, 0.47050500E+02, 0.10985600E+03, 0.95408700E+02, -.38658600E+03, 0.18725500E+03, 0.15534500E+03, 0.19298900E+03, 0.26154000E+03, 0.10310100E+03, 0.12614500E+02, -.16041600E+03, -.82418200E+02, 0.98441100E+02, -.39222000E+02, 0.72058400E+03, -.35981400E+03, -.45527200E+03, -.36040200E+03, -.21441300E+02, 0.21035600E+02, -.59234400E+02, 0.37066900E+03, -.16765300E+03, 0.81436200E+00, 0.74475100E+02, -.86925300E+03, 0.47959800E+03, -.11120700E+04, 0.44276600E+03, 0.22897400E+03, 0.43410100E+03, -.30759000E+03, -.15965100E+04, -.61833300E+03, 0.41621400E+03, 0.21215900E+03, 0.79655500E+03, -.40002600E+03, -.61204300E+03, -.39944900E+03, -.15316000E+02, 0.92319400E+02, -.15217400E+03, 0.38642600E+03, -.28403000E+03, 0.50376000E+02, 0.29108000E+03, 0.32648200E+03, -.17073100E+03, 0.10628200E+03, -.16474200E+03, -.17688400E+03, -.53481800E+02, -.14915300E+03, -.11514700E+03, -.31820800E+02, -.82312000E+02, -.18228000E+03, 0.49562200E+03, -.23976900E+03, 0.43780600E+02, -.24819700E+03, -.89878100E+02, -.22467200E+02, -.72857100E+02, -.37057900E+02, -.16155900E+03, 0.15692300E+02, -.24151700E+03, -.26011500E+02, 0.68985200E+02, -.99359900E+01, -.17507600E+02, -.92983500E+01, 0.39309100E+02, 0.25741200E+02, 0.99868800E+01, -.17276300E+02, -.30490200E+02, 0.18840700E+02, 0.17091100E+03, -.41206800E+00, -.20025600E+02, 0.17866300E+03, 0.19527000E+02, 0.24466200E+02, -.72330200E+01, 0.14756100E+03, 0.16536200E+02, 0.24073800E+02, 0.39505100E+02, -.17231800E+03, -.14661400E+01, -.24199400E+02, 0.95700100E+01 },
        { 0.60421800E+01, -.52268500E+01, -.46098800E+00, -.34904200E+01, 0.10241600E+01, 0.53852200E+01, 0.33514200E+01, 0.60286900E+01, 0.30380100E+01, -.47024000E+01, -.56097100E+00, 0.25473000E+00, 0.14600700E+01, 0.33072600E+01, 0.46714900E+01, 0.15864200E+01, -.19152500E+01, 0.19060900E+01, -.24230500E+01, 0.37206200E+01, -.57234600E-01, -.52709600E+00, -.17659000E+00, 0.68673700E+00, -.27828600E+01, -.80790500E-01, 0.18853100E+00, 0.18589000E+01, 0.24041100E+00, -.18837400E+00, -.58089700E+00, -.63035900E+00, -.12328600E+01, -.99870700E+00, 0.32342700E+00, 0.74842700E+00, 0.29301900E+00, 0.12263600E+00, -.11814500E+01, 0.97085800E+01, -.19314500E-01, 0.64514200E-04, -.29118000E+01, -.78935200E+00, 0.60813500E+00, 0.20223800E+00, -.11461300E+01, -.30707700E-01, 0.25941000E+00, 0.15245200E-01, 0.10700300E+01, -.54100600E+00, -.20862600E+00, -.33570700E+00, 0.87942300E+00, -.90866900E+00, 0.22580300E+01, -.73239600E-01, -.79379000E-01, 0.12986100E+00, -.32882300E+00, -.54928700E-01, -.92747500E-01, -.16415600E+01, 0.80742200E+00, -.14377400E+01, -.10459800E+01, -.63966600E+00, -.32249600E+00, 0.25171400E-01, -.11100400E+01, 0.67775400E-01, 0.74609300E+00, -.43992900E+00, -.11934000E+00, -.87064000E+00, 0.10126800E+01, -.18829200E+01, -.10735900E+01, 0.21002800E+01, 0.19630500E+00, -.16530000E+00, -.21467400E+00, -.49283000E+00, 0.10091800E+01, -.25614400E+00, 0.41965800E+01, -.18197600E+01, -.37675800E+01, 0.29336600E+01, 0.90163800E+00, -.36755300E-01, -.13683700E+01, 0.68991800E+00, 0.20226200E+01, -.14935600E+01, 0.78250100E+00, 0.28666400E+01, 0.20407300E+00, -.32974200E+00, -.79134400E+00, 0.97182200E+00, 0.70362400E+00, -.20294000E+00, 0.51298400E+00, 0.62885300E+00, 0.74901200E+00, 0.18412000E+01, 0.30225100E+00, 0.54556200E+00, -.94815700E+00, 0.21001100E+00, 0.80906500E-01, -.23352500E+00, 0.61003200E-01, 0.97697000E+00, -.71352900E+01, 0.41039700E+00, 0.17574900E+04, 0.13844500E+03, 0.53637600E+03, -.21395900E+04, 0.10601600E+04, 0.11446100E+04, 0.10691400E+04, -.25245400E+02, -.33578700E+03, 0.79881100E+03, 0.38017600E+03, 0.14349900E+04, -.30220800E+03, 0.33707400E+03, 0.18736900E+02, -.83653700E+01, -.12775500E+01, -.92141900E+01, -.95226400E+01, 0.15462800E+02, 0.10570800E+02, 0.17856700E+02, -.43258800E+02, 0.97824400E+01, -.50843900E+02, 0.36976900E+03, -.39823100E+03, -.31890700E+04, -.18580100E+03, 0.11696000E+04, 0.90930200E+03, -.44283500E+03, -.16814500E+03, 0.11991700E+04, 0.69127400E+03, -.20028400E+03, -.62088700E+03, 0.33547300E+03, -.27953900E+03, 0.31000000E+03, -.11809400E+04, 0.41580100E+03, 0.35637300E+03, -.18232800E+03, -.63223900E+03, 0.57122100E+03, 0.83269900E+03, -.75828100E+03, 0.36165300E+03, 0.96902200E+02, 0.37528300E+03, -.31571300E+03, -.76265800E+03, -.14602200E+03, -.69689800E+03, -.68188100E+02, -.53447300E+03, 0.14209400E+04, -.80431100E+03, 0.39710100E+03, -.18298700E+04, 0.41210700E+03, 0.37547200E+02, -.42640300E+03, 0.18654600E+03, 0.15280600E+03, 0.47018900E+03, -.30457600E+03, 0.49429200E+03, 0.18915600E+04, -.91291000E+03, 0.36263200E+04, -.94551700E+03, -.10306300E+04, -.12985900E+04, -.20719800E+03, 0.16276700E+03, -.15479900E+04, -.10606600E+04, -.15326700E+04, 0.20548500E+04, -.10136100E+04, 0.42810600E+03, -.10286300E+04, -.13250300E+04, -.17014800E+03, -.36122100E+03, -.24292500E+03, -.12567200E+04, -.54950400E+02, -.40393100E+03, -.91168600E+03, 0.47522400E+03, 0.67416100E+03, 0.45567900E+03, -.89533000E+01, 0.59501600E+03, -.32978500E+03, -.11323900E+04, -.58822100E+03, 0.81195100E+03, 0.16550200E+04, -.50475200E+03, 0.24704400E+03, -.35183900E+03, 0.25196700E+03, -.17391400E+03, 0.23526700E+03, -.29591300E+03, -.67900900E+03, 0.39998200E+01, 0.28634100E+03, 0.14000400E+04, 0.25198200E+04, -.13548700E+04, -.10769000E+04, -.12586100E+04, 0.60709000E+02, 0.14784400E+03, -.29456700E+03, 0.33314700E+03, 0.17051100E+04, 0.22722700E+03, -.11688600E+04, -.64541800E+02, 0.28670300E+02, -.89461200E+03, 0.30605300E+02, -.27647400E+03, 0.21429000E+03, -.46670200E+03, -.52907900E+03, -.31782500E+02, 0.33343200E+03, 0.15148900E+04, -.50857700E+03, 0.27288400E+03, -.18520000E+03, 0.25190500E+03, 0.12239900E+03, 0.20303200E+03, -.11160000E+03, -.34940500E+03, 0.12783900E+03, 0.22071700E+03, 0.64413700E+03, -.59425400E+03, 0.28131500E+03, -.23238800E+03, 0.29638600E+03, -.22160500E+03, -.39447500E+03, 0.57110900E+03, 0.57902900E+03, 0.94726700E+03, -.48645600E+03, -.28273000E+03, 0.13462400E+00, -.79068800E+02, -.88308600E+02, 0.26268100E+02, 0.67134100E+02, 0.15118400E+02, 0.11416800E+03, -.46797200E+01, -.34530600E+01, 0.73527600E+01, 0.10565400E+02, -.26294100E+03, -.35690300E+02, -.59740000E+01, -.37003200E+03, 0.34015300E+03, 0.11621700E+03, 0.43793000E+02, 0.38455500E+03, 0.19227900E+03, -.32534900E+03, 0.97158900E+02, 0.47282800E+03, -.10516700E+02, -.18838800E+01, -.13309900E+03 },
        { -.25090000E+01, -.10950600E+01, -.20620200E-01, -.14764000E+01, -.22681800E+01, -.16599400E+00, -.12304400E+01, 0.23413300E+01, -.12727800E+01, 0.13677600E+01, 0.10525400E+00, -.12471700E+00, 0.15506000E+01, -.86314400E+00, 0.12429100E+01, 0.27749500E+01, -.89940000E+00, 0.34516600E-01, -.14139500E+01, -.16959900E+00, 0.21428200E+00, 0.12285700E+00, -.10564200E-01, -.47211200E-01, -.37271400E+00, -.76831200E-01, -.68991200E+00, -.15045700E+00, 0.63733500E+00, 0.21361300E+00, 0.37360900E+00, -.84992800E-01, 0.94168000E+00, 0.10043800E+01, 0.26428000E+00, -.14021200E-02, -.16094500E-01, 0.54954000E+00, 0.41980300E+00, -.34033100E-01, -.18884700E-02, -.22273300E-01, -.82133600E+00, -.89477600E-01, 0.11667200E+00, -.23341600E+00, -.42373100E+00, -.16785500E-01, 0.89391300E-01, -.23256200E+00, -.29769400E-01, 0.26990600E+00, 0.18110900E+00, 0.18491700E+01, 0.76868800E-01, -.67435900E+00, 0.23283800E+00, -.12143600E+00, -.99761100E-01, -.57315000E-01, -.20313100E+00, -.70254100E+00, -.28710800E+00, 0.57973500E+00, -.20073900E+00, 0.52557400E-02, -.77048400E+00, 0.15991300E+00, -.20180500E+00, 0.11778000E-01, 0.19253700E+00, 0.35664900E+00, -.80302600E+00, 0.15567600E+00, 0.16652100E-03, -.37719700E+00, -.16597600E+00, 0.11201800E+00, 0.58244700E-01, 0.13265100E+00, 0.94849300E-01, 0.73836400E-01, 0.25562900E+00, -.26428000E+00, -.73085900E+00, -.20084700E+00, -.13927000E+01, -.10790500E+01, -.15216300E+01, 0.97763900E+00, -.18772200E+00, 0.12474400E-01, 0.12037700E+00, -.62707500E-01, -.57121300E+00, 0.80074200E+00, -.25884600E+00, -.53329800E+00, 0.12445100E+00, 0.12514500E+00, 0.14271700E+00, 0.21542700E+00, 0.10353600E+00, -.33238300E+00, 0.54659700E-01, 0.21354600E-01, -.37722400E+00, -.11656500E+00, 0.89822700E+00, -.10628200E+00, -.24744100E+00, 0.29914000E+00, -.11023500E+00, 0.10655200E+00, 0.29052600E+00, 0.43670000E+00, 0.75230800E+00, -.23380300E-01, -.26223000E+00, 0.22899500E+03, 0.27630300E+02, -.60259700E+02, 0.32008600E+02, 0.33437200E+03, 0.30211700E+02, -.90060300E+02, -.21528800E+03, 0.22672400E+03, 0.10938500E+03, 0.63840300E+02, -.13648800E+03, -.12271900E+03, 0.43425200E+02, -.21881500E+02, -.28776300E+02, -.21725500E+02, 0.12179500E+02, 0.47068100E+01, -.59347300E+00, 0.13706400E+02, -.12482300E+02, 0.26079400E+01, -.10635100E+02, -.13395500E+04, 0.76223600E+03, -.71467700E+03, 0.66987600E+03, 0.11784700E+03, 0.92098900E+02, -.10941400E+02, -.21841500E+03, 0.29494300E+03, 0.29362700E+03, 0.40784900E+03, 0.70484000E+02, -.46902300E+02, 0.25908900E+03, -.35189400E+02, -.11311400E+03, 0.16151300E+03, -.49362300E+02, 0.12578900E+03, -.82499400E+02, 0.15521300E+03, 0.48702600E+03, -.69514400E+02, 0.18367000E+02, 0.18132600E+02, 0.34781900E+02, 0.75076400E+02, 0.10491800E+03, 0.36151500E+02, 0.15456400E+03, 0.86556400E+01, 0.65671600E+02, 0.19062200E+03, -.96315300E+02, 0.48548200E+02, 0.37779800E+03, 0.48757700E+02, -.22429500E+03, -.90891900E+02, -.59506100E+02, -.23390800E+03, 0.59938300E+02, -.93376900E+02, 0.43000800E+03, -.11574000E+04, 0.52368100E+03, -.49787500E+02, 0.57857600E+03, 0.56864200E+03, 0.59596900E+03, 0.88792600E+02, -.12033900E+03, 0.50925100E+03, 0.39088700E+03, 0.69105300E+03, -.60195100E+03, 0.29907700E+03, -.24030300E+03, 0.30103600E+03, 0.54677100E+02, 0.92035700E+02, 0.20832600E+03, 0.19042500E+03, 0.19816700E+03, 0.93894300E+02, 0.73469900E+03, -.21569400E+03, 0.10648400E+03, 0.81803600E+01, 0.10781700E+03, -.73694200E+02, -.11271900E+02, 0.69186200E+01, -.14912700E+03, -.63509800E+02, -.20968900E+02, 0.42545700E+03, 0.72404400E+03, -.36186600E+03, -.30238000E+03, -.36197100E+03, -.92080800E+02, -.50700400E+02, -.71836100E+02, 0.31312400E+03, -.52127400E+02, -.56984100E+02, -.39580200E+03, -.14940200E+04, 0.78366500E+03, -.61381800E+03, 0.74744800E+03, 0.35169000E+03, 0.48676200E+03, -.12179300E+03, -.32031800E+03, 0.44799400E+03, 0.78173900E+03, 0.63333200E+03, 0.74419500E+03, -.37226800E+03, -.37139900E+03, -.37197800E+03, -.18804500E+03, -.32059700E+02, -.12491100E+03, 0.28897000E+03, -.36053300E+02, -.89913100E+02, -.22489100E+03, 0.99937700E+02, -.52710000E+02, 0.11481300E+03, -.49740300E+02, -.10172700E+03, 0.11814900E+02, -.27393900E+01, -.27202500E+02, -.32705600E+01, -.93599900E+01, -.71105600E+02, 0.32944500E+03, -.16147700E+03, 0.33327200E+03, -.16464100E+03, -.14324900E+03, -.22198400E+03, 0.13915400E+03, 0.17167400E+03, -.32103800E+02, -.15512400E+03, -.28087900E+03, -.36684500E+02, 0.38074300E+01, 0.28039800E+02, -.29478900E+02, -.30356600E+02, 0.48690800E+02, 0.49507100E+02, 0.14112200E+02, -.15550600E+02, -.42711200E+02, 0.24233600E+02, 0.17767700E+03, -.18438800E+02, -.38338100E+02, 0.13244600E+03, -.58613500E+01, 0.21128800E+02, -.19022800E+02, 0.57209300E+02, 0.26511200E+02, -.26024600E+02, 0.26568500E+02, -.16381000E+03, 0.69608300E+01, -.82846600E+01, -.27973200E+01 },
        { -.27024200E+01, 0.45513200E+01, 0.41925200E+00, 0.19699000E+01, -.10098700E+01, -.14549000E+01, -.12426700E+01, -.11604200E+01, -.14526600E+01, 0.13872100E+01, 0.10057300E+00, -.31471700E+00, 0.91634200E+00, -.21519700E+01, 0.20486600E-01, -.79161100E+00, -.20463800E+00, -.27882300E+00, 0.18791800E+00, -.32845900E+00, 0.15718000E+00, 0.17227400E+00, 0.13107300E+00, -.15460800E+00, 0.76590500E+00, 0.48594200E-02, -.10766000E+00, 0.12510200E+00, 0.37255200E-02, 0.95467900E-02, 0.28073700E+00, 0.97752000E-01, 0.33746400E+00, 0.17853900E+00, -.15268700E+00, -.16800100E-01, -.39963000E-01, 0.20577800E+00, 0.37545100E+00, 0.45405400E+00, 0.10905300E-01, 0.12259300E+00, -.26610400E-01, 0.23420300E+00, -.20084400E+00, -.18164800E+00, -.75368800E-01, 0.23345900E-01, 0.66850400E-02, 0.18220500E+00, 0.18664800E+01, -.15800900E+00, -.20853900E+00, -.54762100E+00, -.10022300E+01, 0.81814100E+00, -.64057800E+00, 0.20828500E+00, 0.18606100E-01, 0.81256600E-01, 0.37876100E+00, -.49292000E+00, -.54579500E+00, 0.10985800E+00, -.30482400E+00, -.29228700E-01, 0.97249600E+00, 0.45273100E-01, 0.19360600E+00, -.13383600E-01, -.52959100E-01, -.20009500E+00, 0.15970600E+00, -.67528000E+00, -.44269200E+00, 0.49609900E+00, 0.67398400E-01, -.68973400E+00, -.29034700E+00, 0.52691600E+00, -.78570200E-01, 0.11376000E+00, -.89039300E+00, 0.14127200E+00, 0.14902500E+01, 0.21051100E+00, 0.43854900E-02, 0.13719400E+00, 0.23559300E+01, -.73181900E+00, -.11480900E+01, 0.12814000E-01, -.12698400E+00, 0.32788000E-01, 0.71735200E+00, -.50254500E+00, 0.24751600E+00, 0.25638800E+00, 0.39162600E+00, 0.18288500E+00, 0.19521200E+00, 0.61727300E-01, -.22126300E+00, -.35308100E-02, -.85380000E-01, 0.30928100E+00, -.19587600E+00, 0.34029200E+00, -.13207500E+01, -.14358100E+00, 0.68016200E+00, -.15909500E+00, 0.23407400E+00, 0.23298500E+00, -.29453100E+00, -.13621900E+01, 0.23505400E+01, 0.11144800E+01, 0.12510000E+00, -.55352400E+00, -.12098400E+04, -.76624500E+02, 0.46072500E+02, -.41510000E+03, 0.38456100E+02, -.55004800E+02, 0.10293800E+03, 0.12740800E+01, -.23880700E+02, -.86069700E+02, 0.21211400E+02, 0.45957100E+02, 0.19226000E+02, -.10381300E+02, 0.22175800E+02, -.96864100E+01, 0.52032700E+01, -.84340900E+01, -.13973200E+02, -.87715800E+01, -.73648600E+01, -.30377200E+01, 0.71789800E+01, -.26971700E+03, 0.34293900E+03, 0.23222200E+04, 0.13333900E+03, -.24059600E+02, -.20598300E+03, 0.94704100E+02, -.13789400E+03, -.14243300E+03, -.13754900E+03, -.40183700E+03, -.39542300E+02, -.72364000E+01, -.15775500E+03, 0.19761500E+02, 0.63924200E+03, -.11216200E+03, -.65179700E+02, 0.83055400E+02, 0.39215500E+03, -.21571200E+03, -.35029700E+03, 0.48827000E+02, -.30756700E+02, -.20267000E+03, -.22069200E+02, 0.69201300E+02, 0.18422700E+03, 0.10489700E+03, 0.27102900E+03, 0.98402600E+02, 0.92112500E+02, -.10159600E+03, 0.17088200E+03, -.82093400E+02, 0.88175800E+03, -.88688100E+02, 0.34620600E+02, 0.71300000E+02, -.41219800E+01, -.10403300E+03, -.17948900E+03, 0.83545000E+02, -.45139600E+03, 0.41095700E+03, -.27741500E+03, -.13343200E+04, -.20447100E+03, -.17910200E+03, 0.35219400E+03, -.94466900E+01, 0.10153600E+03, -.27630300E+03, 0.35785800E+03, 0.35647300E+02, -.14442500E+03, 0.61741900E+02, -.30587700E+03, 0.73021800E+02, 0.30967000E+03, -.10159900E+03, 0.66827700E+02, -.14253800E+02, 0.30474000E+03, -.11861300E+03, 0.48138100E+02, 0.26017800E+03, -.14358000E+03, -.21588700E+03, -.12988700E+03, 0.27858000E+02, -.18846500E+03, 0.65214000E+01, 0.26663800E+03, 0.18294000E+03, -.22894900E+03, -.53488800E+03, 0.38120300E+03, -.18764200E+03, 0.53695400E+02, -.19051800E+03, -.10253000E+03, -.13270400E+03, -.36751600E+02, 0.48111600E+02, -.10819200E+03, -.16240600E+03, -.10962900E+03, -.50783500E+03, 0.33523200E+03, 0.14943000E+04, 0.24867800E+03, 0.12526100E+03, 0.14445600E+03, -.67902600E+02, -.25383700E+03, -.26229500E+03, 0.21062700E+03, -.14159500E+04, 0.36948500E+03, -.18421500E+03, 0.34595400E+03, -.18394100E+03, -.11722600E+03, -.26226900E+03, 0.78271000E+02, 0.91372900E+02, -.10090100E+03, -.26247100E+03, -.41262100E+03, 0.30097600E+03, -.16439400E+03, -.27132100E+03, -.14945700E+03, 0.60280200E+02, 0.94842500E+01, 0.64567100E+02, 0.18657900E+03, -.95891300E+02, -.11342300E+02, -.27934400E+03, -.60127600E+02, 0.43438200E+02, -.14272400E+02, 0.30331700E+02, 0.10173700E+03, 0.13839600E+03, -.55530300E+02, -.11469100E+03, -.18784900E+03, 0.14060300E+03, 0.11095200E+03, -.27806200E+02, -.25354300E+02, 0.98164600E+01, 0.18948400E+01, -.10402400E+02, -.37783600E+02, -.47281100E+02, -.19709600E+02, 0.23222900E+02, 0.17590900E+02, -.12988500E+02, 0.10624200E+03, -.92800600E+01, 0.96483200E+01, -.11205800E+02, -.11393400E+03, 0.16428500E+02, -.11488800E+00, -.21872000E+03, -.63587500E+02, 0.58025600E+02, -.71709900E+02, -.87511400E+02, 0.19477100E+02, -.88328800E+01, 0.28284600E+02 },
        { 0.13821500E+01, 0.16976200E+01, 0.11488900E+00, 0.84562400E+00, 0.13296700E+01, 0.16779400E+01, -.32663500E+00, 0.18357800E+01, 0.13485700E+00, -.12988000E+01, -.46122300E-02, 0.38201200E-01, 0.59743600E+00, -.66730800E+00, 0.58622200E+00, 0.77414100E+00, 0.15234900E+00, -.23658900E+00, -.40913600E+00, -.80459800E+00, -.53285200E+00, 0.60143100E-01, -.61290600E-01, 0.16659200E+00, -.27220500E+00, -.51265300E-01, -.16719900E+00, -.41853200E+00, 0.19817500E+00, -.27187500E+00, -.18943000E+00, -.31516500E+00, -.22497300E+00, -.95137600E-02, 0.21639100E+00, -.91845800E-01, 0.16071500E+00, -.24061800E+00, 0.67281200E+00, -.19587000E+01, -.42351100E-01, -.24975600E+00, 0.35759400E+00, -.15936100E+00, -.15318000E+00, 0.63245800E-01, 0.93248100E-01, -.82439100E-02, 0.25027400E-01, 0.19803100E+00, -.45417600E+00, 0.33114700E-01, -.19547600E+00, -.37310500E+00, 0.18471400E+00, -.46618400E-01, -.49167600E-01, -.13315300E+00, 0.38747900E-01, -.48351100E-01, -.68048700E+00, 0.45665200E+00, 0.63166900E+00, -.75310700E+00, 0.53193700E+00, -.92476400E-01, -.39963200E+00, -.20629600E+00, 0.11586800E-01, -.15471700E-01, -.23351400E-01, -.14509800E+00, 0.29024600E+00, -.30032700E-01, 0.49552000E-01, 0.20204700E+00, -.64470000E-01, -.21774700E+00, -.41381800E-01, -.23856800E+00, -.42825100E-01, 0.11571000E+00, 0.71048800E+00, -.51407300E-02, -.34989700E+00, 0.23086100E+00, 0.15281000E+00, -.98021600E-01, -.12971000E+01, 0.97119900E-01, 0.68966000E+00, -.18319000E-02, 0.15329500E-01, 0.15206900E+00, -.21079300E+00, 0.12305200E+01, -.14543100E+00, -.41562700E+00, 0.45426000E+00, -.33564800E-01, -.13955000E+00, 0.15033200E+00, -.98446300E-01, -.13935800E-01, -.14170900E+00, 0.23337700E+00, 0.26846800E+00, 0.56486300E+00, 0.31899500E-01, 0.29592400E-01, -.10334600E+00, 0.51351300E-01, 0.60726800E-02, 0.93007200E-01, 0.40871900E+00, -.68018800E-01, 0.88187500E-01, 0.33727900E+00, -.19904900E+00, 0.50167200E-01, 0.63428900E-01, -.62787500E+03, 0.30832100E+03, 0.45459100E+03, 0.31383700E+03, -.39283800E+02, -.19380900E+03, 0.39505000E+03, 0.22066800E+03, 0.46794500E+03, -.11213700E+03, 0.13327100E+03, -.99881600E+00, 0.10856000E+01, -.74126300E+01, 0.52139100E+00, 0.43675800E+01, 0.78448200E+01, 0.31612600E+01, 0.78019600E+01, -.23363900E+01, 0.22598700E+01, -.15854700E+02, 0.22454000E+03, -.25451800E+03, -.11459200E+04, -.11250900E+03, 0.34251500E+03, 0.18146300E+03, 0.57166400E+02, 0.25883400E+03, 0.64205800E+02, 0.75945800E+02, -.27948900E+03, -.38496000E+03, 0.21217100E+03, -.77626200E+02, 0.19240800E+03, -.32577700E+03, 0.27684800E+03, 0.14743100E+03, -.18177800E+03, -.35276200E+03, 0.37445300E+03, 0.58922400E+03, -.21928000E+03, 0.10974500E+03, 0.11265200E+03, 0.10935700E+03, -.10149100E+03, -.26115300E+03, -.22229200E+02, -.13744000E+03, -.55458600E+01, -.17448500E+03, 0.49808000E+03, -.31004800E+03, 0.15240100E+03, -.68591100E+03, 0.15615300E+03, -.94591100E+01, -.12465300E+03, -.26058200E+02, -.16205700E+03, 0.60408800E+02, -.59208200E+02, 0.33670200E+03, 0.91335500E+03, -.41880300E+03, 0.10928000E+04, -.45658800E+03, -.47306300E+03, -.60883800E+03, -.12803900E+03, 0.12142500E+03, -.16784200E+03, -.50589000E+03, -.58294800E+03, 0.17684600E+03, -.79645700E+02, 0.42495400E+03, -.88581900E+02, -.41140200E+03, 0.37674100E+02, 0.47443900E+02, -.74518600E+02, -.41791800E+03, 0.94146800E+02, -.58240600E+02, -.76014100E+03, 0.39165200E+03, 0.43782400E+03, 0.38005300E+03, 0.31782900E+02, 0.37564600E+03, -.12551400E+03, -.60175500E+03, -.24518600E+03, 0.42887200E+03, 0.67415200E+03, -.26678000E+03, 0.13025900E+03, -.12524500E+03, 0.13332600E+03, 0.36624600E+01, 0.94765300E+02, -.99421700E+02, -.29269100E+03, 0.56646200E+02, 0.11286600E+03, 0.27777900E+03, 0.11475900E+04, -.63129500E+03, -.56900400E+03, -.57379600E+03, -.10328500E+03, -.12021400E+03, 0.30210800E+02, 0.39225700E+03, -.18095100E+03, -.16009400E+03, -.79066000E+03, -.11838900E+03, 0.58105000E+02, -.36455300E+03, 0.58958400E+02, -.61772200E+02, 0.12633100E+03, -.29028300E+03, -.50457600E+03, -.67652600E+02, 0.15688300E+03, 0.41790200E+03, -.66855200E+02, 0.45846700E+02, -.10704800E+03, 0.33083400E+02, 0.64496400E+02, 0.77107100E+02, -.45679700E+02, -.13106500E+03, -.45463300E+01, 0.90545800E+02, 0.21162000E+03, 0.16667200E+02, -.18579500E+02, -.12014500E+03, -.84426000E+01, -.16132800E+03, -.33370300E+03, 0.35429700E+03, 0.35428400E+03, 0.31543300E+03, -.29403400E+03, -.15791200E+03, 0.27251600E+02, -.34140200E+02, -.23276000E+02, -.75658100E+01, 0.43351600E+02, 0.17161100E+02, 0.75280200E+02, 0.62171800E+01, -.50764400E+01, -.83464600E+01, 0.50791600E+01, -.15647400E+03, -.13173500E+01, -.93599900E+01, -.11249600E+03, 0.13324500E+03, 0.34653000E+02, 0.19955200E+02, 0.12873500E+03, 0.91679900E+02, -.15173000E+03, 0.50467500E+02, 0.16875400E+03, 0.19688400E+01, -.12088100E+02, -.83206300E+02 },
        { -.94191300E+01, -.11799500E+02, -.12398900E+01, -.73998900E+01, -.34829900E+01, 0.44265200E+01, -.13764500E+02, 0.64021500E+01, -.62786600E+01, 0.88935000E+01, 0.38852700E+00, -.42504100E+00, 0.32872700E+01, 0.10245500E+02, 0.47019300E+01, 0.14437100E+01, -.22990400E+01, 0.49327400E+01, -.50888000E+01, 0.29392900E+01, -.60440100E+00, 0.29981200E+00, -.42441600E+00, 0.19185300E+01, -.13113600E+02, -.18125400E+00, -.29104300E+01, 0.17514800E+01, 0.39384200E+00, 0.30156300E+01, -.21482200E+01, 0.30996500E+00, -.14640900E+01, -.63335300E+00, 0.12246600E+01, 0.19512300E+00, 0.86544800E+00, -.66766000E+00, -.34356700E+01, 0.72514100E+01, -.34380500E+00, -.82694500E+00, -.86829000E+00, 0.32294700E+00, 0.47914100E+00, 0.12140000E+01, 0.66188400E+00, -.14999300E+00, 0.28208800E+00, -.59517600E+00, 0.13288900E+01, 0.55466700E+00, 0.52531200E-01, -.98019000E+00, 0.54675100E+00, -.53149800E+00, 0.19361700E+01, -.11669300E+00, -.33394100E+00, 0.58865200E+00, -.25892300E+01, -.58845300E+01, -.36655800E+01, -.28576200E+00, 0.14895100E+01, -.45176500E+00, 0.22675400E+00, 0.22597200E+00, -.71916000E-01, 0.57916100E-01, -.34534900E+00, 0.11338200E+01, -.17736700E+01, 0.23307000E+01, 0.20566200E+01, -.33081900E+01, 0.82732400E+00, 0.55282900E+00, 0.65432300E+00, -.17102500E+01, 0.28721800E+00, -.12909500E+01, -.26346400E-01, -.83528400E+00, -.12671800E+01, -.15072500E+01, 0.16415900E+01, -.26526300E+01, -.50970900E+01, 0.32684100E+01, 0.22790500E+01, -.14167100E+00, -.52697400E+00, 0.41699000E+00, -.24588400E+01, 0.31343300E+01, -.31021500E+00, -.20258800E+01, -.11487700E+01, -.17418000E+00, -.23921000E+00, -.18120100E+01, 0.13633200E+01, -.53775900E+00, 0.22609700E+01, -.23962600E+01, -.24426000E+01, -.68865100E+00, 0.45837600E+01, 0.60646500E+00, -.32389100E+01, 0.36593800E+00, -.67719900E+00, -.14821700E+01, -.24940400E+01, 0.56109200E+01, -.19971400E+01, -.38554700E+01, -.25338500E+00, 0.37895700E+00, -.17283200E+01, 0.49256300E+00, 0.56375700E+02, 0.50883100E+02, 0.10710600E+01, -.49456400E+03, -.14315200E+03, 0.44162300E+03, 0.50009800E+03, -.27560200E+03, -.45071900E+02, 0.17885500E+03, 0.14323600E+02, -.12700100E+02, -.25924300E+02, -.75496500E+01, 0.20420300E+02, -.90177500E+01, -.26505400E+02, -.71387900E+01, 0.37059500E+02, -.72920800E+01, -.44858200E+02, -.17009900E+04, 0.21917900E+04, 0.38358800E+04, 0.84561900E+03, 0.88204200E+03, 0.13056100E+04, -.20371700E+03, -.56295100E+03, -.12463700E+04, 0.11544200E+04, 0.73021200E+03, -.34762200E+04, 0.15508500E+04, 0.13931000E+03, 0.17384300E+04, -.32706800E+01, -.76509100E+02, -.29164200E+03, -.95881100E+03, 0.18164400E+04, -.32110400E+03, 0.21012500E+04, -.11131800E+04, 0.49334600E+03, -.57577500E+03, 0.56169700E+03, -.58342600E+03, -.81038400E+03, 0.67265200E+03, -.78574900E+02, 0.68702100E+03, -.83830500E+03, 0.10626300E+04, 0.20585200E+04, -.10037000E+04, 0.13054200E+04, -.10476800E+04, 0.48184200E+03, 0.59342300E+03, -.85674600E+03, -.61146600E+03, -.13981800E+04, 0.62537400E+03, -.15105400E+04, 0.14996800E+04, -.12216200E+04, -.20182600E+04, -.74649000E+03, -.63217500E+03, -.65862800E+03, 0.61012100E+03, 0.42415100E+03, -.54107300E+03, -.53369300E+03, -.89031500E+03, -.10358000E+04, 0.44675400E+03, -.93958300E+03, 0.52173100E+03, -.54622100E+03, -.19911800E+03, 0.36284900E+03, 0.27548800E+03, 0.11682000E+04, -.33057200E+03, 0.73470200E+03, 0.10892200E+03, -.14337300E+03, -.43096800E+03, -.53665300E+02, -.32644100E+02, -.31531600E+03, 0.37378700E+02, 0.41297500E+03, 0.92484600E+03, -.44908900E+03, -.15605500E+03, -.14595100E+03, 0.90400200E+02, 0.53456100E+03, 0.73619500E+02, 0.54346100E+03, 0.19878900E+03, -.33076700E+03, -.34569600E+03, -.29019100E+03, 0.99211800E+02, -.33471600E+03, -.22114800E+04, 0.16072300E+04, 0.29809500E+04, 0.10863500E+04, 0.87651500E+03, 0.14337400E+04, -.37634500E+03, -.10802300E+04, -.17576500E+04, 0.13703300E+04, 0.77767400E+03, -.56996400E+03, 0.28552100E+03, 0.11494000E+02, 0.28917000E+03, 0.93336600E+03, 0.31420900E+03, -.53558900E+03, -.82707100E+03, -.52199500E+03, 0.21441000E+03, -.66542300E+03, 0.98601300E+02, -.13738200E+03, -.87487800E+03, -.43639000E+02, 0.26272900E+03, 0.63391400E+02, -.57495200E+02, -.10528900E+03, -.12718900E+03, 0.58326700E+01, -.19321200E+02, 0.97832700E+03, -.39265400E+03, -.25614800E+03, -.48757800E+03, -.41254900E+03, 0.89228700E+02, -.17765300E+03, -.16030000E+03, -.10880800E+04, 0.18970900E+03, -.37895200E+03, 0.19731800E+02, -.50983700E+02, -.77388300E+01, -.41101400E+02, -.46890800E+01, -.75312600E+01, -.41781900E+02, 0.82465400E+01, 0.38770000E+02, -.20779100E+02, 0.30469100E+01, 0.52657300E+02, 0.80844800E+02, -.67724800E+01, 0.53867300E+02, -.17227300E+03, 0.12207200E+03, 0.31846400E+02, -.29474800E+03, -.83591600E+02, 0.18193800E+03, 0.22617200E+02, -.12572300E+03, 0.15796300E+02, -.14420300E+02, 0.40809100E+02 },
        { -.36067900E+01, -.51366800E+01, -.65332800E+00, -.30610700E+01, -.73203300E+00, 0.99358900E+00, -.52780700E+01, 0.13552400E+00, -.22081100E+01, 0.33854900E+01, 0.17766900E+00, -.25678700E+00, -.45796900E+01, 0.68236000E+01, -.42090100E+01, -.11247200E+01, 0.16896600E+01, 0.58096600E+00, 0.91157600E+00, -.20624900E+01, 0.50811800E+00, 0.10586500E+00, -.35831900E+00, -.56073300E-01, 0.55869400E+00, 0.33311300E-01, 0.17581900E+00, -.68282600E+00, -.40037200E+00, 0.99551100E+00, -.63918600E+00, 0.72393800E-01, -.50856500E+00, -.70897100E+00, 0.20684200E+00, -.40615500E+00, 0.67421500E-01, -.11744900E+01, 0.11266900E+00, -.90657800E+01, -.86058300E-01, -.15900000E+00, 0.73863700E+00, 0.28702900E+00, -.26630700E+00, 0.13947800E+00, 0.33343000E+00, -.12798400E-01, -.21781900E-01, -.39248600E+00, -.28958700E+01, 0.27382700E+00, 0.82687600E+00, 0.41636400E+00, 0.49344800E+00, -.59116000E+00, 0.49608900E+00, -.19984400E+00, 0.21614100E-01, -.67112800E+00, 0.16353700E+01, 0.44429700E+00, -.97574400E-01, -.65375700E+00, 0.11702400E+00, 0.52055600E-01, -.32723200E-01, 0.13031300E+00, -.89161000E-01, 0.56682100E-01, 0.36724700E+00, 0.38845300E+00, -.11533900E+00, 0.51714100E+00, 0.61186000E-01, -.29199900E+00, 0.20152800E+00, 0.25291500E+00, -.18334800E-01, 0.51909500E-02, 0.81516500E-01, 0.27078400E+00, 0.50306900E+00, 0.35759000E+00, -.20286800E+01, -.43053400E+00, 0.87701800E+00, -.84204900E+00, -.14124100E+01, 0.84999400E+00, 0.78781900E+00, 0.14946900E-01, 0.10597500E+00, 0.39598500E+00, -.24889600E+00, 0.78469300E+00, -.85671200E-01, -.13501200E+01, 0.63027900E+00, 0.28684400E+00, 0.20124100E+00, -.49461400E+00, -.52659300E+00, 0.99152000E+00, -.14677200E+00, 0.42535600E+00, -.12927000E+00, -.95288900E-01, 0.36160900E+00, -.11828000E+00, -.13798000E+01, 0.26874100E+00, 0.10626300E+00, -.37835400E-01, 0.67955100E-01, 0.20413800E+01, -.90981300E+00, -.55718600E+00, 0.97707800E-01, 0.82922300E+00, -.85475100E+00, 0.17054700E+01, 0.12997200E+00, -.12368900E+04, -.44365500E+00, 0.23096000E+03, 0.49353600E+03, -.55244600E+03, -.30431200E+03, -.18159900E+03, 0.24224800E+03, 0.55295200E+03, -.48169700E+02, 0.24078400E+02, 0.81608200E+02, 0.24150100E+02, -.61424300E+00, -.24854500E+02, -.11432500E+02, -.11755900E+02, 0.23114200E+02, -.16664100E+02, 0.28484600E+02, 0.17672000E+04, -.88558900E+03, 0.57090800E+04, -.88508600E+03, -.77992900E+03, -.10592000E+04, 0.24561000E+02, -.11833500E+03, -.43764400E+03, -.76608900E+03, -.13674900E+03, 0.25932800E+04, -.13032300E+04, -.58998900E+03, -.12970000E+04, 0.18463600E+04, -.47267300E+03, -.85513700E+03, 0.27271200E+03, -.64572000E+02, -.86594400E+03, -.20960400E+04, 0.10272200E+04, -.50966200E+03, -.71515800E+03, -.51194900E+03, 0.31794400E+03, 0.82044700E+03, -.29072600E+01, 0.44418900E+03, -.27788800E+03, 0.55848700E+03, -.10124500E+04, -.11180500E+04, 0.55929100E+03, 0.15668100E+04, 0.56129500E+03, -.18387200E+02, -.45994200E+01, 0.54280000E+03, 0.26548800E+03, 0.28949700E+03, -.58156500E+02, -.26614700E+01, 0.91407800E+02, -.27530000E+02, -.33446600E+04, -.44673800E+02, -.32719100E+03, 0.57502000E+03, 0.54869600E+03, 0.20129700E+03, -.84133000E+03, 0.59844500E+03, 0.29841000E+02, -.49677000E+02, 0.21816800E+02, -.27093700E+03, 0.24574000E+02, 0.14045800E+04, 0.16971100E+03, -.43199900E+03, -.38629000E+03, 0.30606700E+03, -.27255800E+02, -.65552000E+03, 0.11643400E+04, -.58818400E+03, -.46573600E+03, -.58204600E+03, 0.83072400E+02, -.39124300E+03, -.16064300E+03, 0.63483900E+03, 0.90525700E+02, -.41673600E+03, -.12709900E+04, -.12769200E+04, 0.64064900E+03, 0.89347800E+03, 0.63818000E+03, -.13052200E+03, -.30067200E+03, 0.33331700E+03, -.47802300E+03, 0.13847100E+03, -.28542400E+03, 0.16369300E+03, 0.10493000E+04, -.52598800E+03, 0.32695800E+04, -.52832500E+03, -.44860600E+03, -.79229600E+03, 0.11920900E+03, -.11478800E+03, -.68002700E+03, -.52177900E+03, 0.26572400E+03, -.17299900E+04, 0.86341700E+03, 0.18365700E+04, 0.86434900E+03, -.16924000E+03, -.68792100E+03, 0.79118100E+03, -.32434800E+03, 0.37478500E+03, -.53577200E+03, -.20608600E+03, 0.35442700E+03, -.18586300E+03, -.31371200E+03, -.17836300E+03, 0.23355100E+02, -.11856500E+03, 0.14294000E+03, 0.43664900E+03, -.28084900E+03, -.76578500E+02, -.33339600E+03, -.59208600E+03, 0.29665100E+03, -.30395700E+03, 0.29562300E+03, 0.35351600E+03, 0.32970300E+03, -.18368700E+03, -.92319200E+02, 0.15952000E+03, 0.17742200E+03, 0.68958800E+03, 0.33583700E+02, 0.50745300E+01, 0.30542000E+02, 0.44251100E+02, -.16623400E+02, -.12675900E+03, -.13490100E+03, -.32980600E+02, 0.43167000E+02, 0.86300400E+02, -.40001900E+02, 0.18873000E+03, -.34724000E+02, 0.48295100E+02, -.89967300E+02, -.34837700E+03, -.12563000E+03, -.21204300E+02, -.64557900E+03, -.19220900E+03, 0.14294400E+03, -.28460900E+03, -.13411500E+03, 0.61110600E+02, -.15202400E+02, 0.43278300E+02 },
        { -.95374000E+01, 0.33776700E+01, 0.64049100E+00, -.50290500E+01, -.72418900E+01, 0.12130200E+02, -.12054500E+02, 0.14280000E+02, -.55828500E+01, 0.81381100E+01, 0.75781600E-01, -.58374200E+00, 0.46082900E+01, 0.37282600E+01, 0.24740100E+01, 0.32150300E+01, -.45120200E+01, -.62865900E+00, 0.52262500E+00, -.96525700E+00, -.96011200E-02, 0.38396900E+00, 0.18676100E+00, 0.55792900E+00, -.34654900E+01, 0.72155700E+00, -.22956000E+01, -.12892100E+01, 0.16959000E+01, 0.10996800E+01, 0.48194000E+00, 0.77396300E+00, -.61140600E+00, 0.37755700E+00, -.87790100E-01, 0.12351500E+00, -.18544800E+01, -.28406900E+01, 0.67742400E+00, -.20467000E+02, -.24975500E+00, -.76442500E+00, 0.11295100E+01, 0.27556300E+00, -.11029000E+01, -.22180800E+00, 0.50567300E+00, 0.28940400E-02, 0.10330700E+00, -.87539300E-01, -.38069600E+01, 0.69532700E+00, 0.96847100E+00, 0.16552500E+01, 0.23407800E+01, -.49784300E+00, 0.64922500E+00, -.29715800E+00, 0.16631100E+00, -.11164100E+01, 0.16511500E+01, 0.61071000E+00, 0.72732600E-02, -.55014500E+00, -.97460100E+00, -.91802800E-02, 0.84112900E+00, -.19100200E+00, -.41962900E+00, 0.12922500E+00, -.20888200E+00, 0.26528100E+00, 0.21776100E+00, 0.42362700E-01, -.11188400E+01, 0.82268000E+00, -.34971600E+00, -.71187900E-01, 0.36799100E-01, -.23511600E+00, 0.68450200E-01, -.20968800E-02, -.32874800E+00, 0.44214400E+00, 0.13452800E+01, 0.62159400E+00, 0.96621500E+00, 0.54559500E+00, 0.35268000E+01, -.84205700E+00, -.16892000E+00, 0.99804200E-01, 0.26963000E+00, -.69173800E+00, 0.24536600E+00, 0.88425400E+00, -.12119800E+00, -.11075900E+01, 0.73881400E+00, 0.69109000E+00, 0.36933200E+00, 0.49941600E-01, 0.17940400E+00, 0.12404700E+00, -.51466500E-01, 0.29164300E+00, -.96640100E+00, -.80712400E+00, 0.11849000E+01, -.54850000E-01, -.54535300E+00, 0.86850200E-01, -.10280000E+00, -.77265600E-01, -.36586400E+00, 0.45388000E+00, 0.21827900E+01, -.93474900E+00, -.12541600E+00, 0.16836900E+00, 0.14947300E+00, -.75204900E+00, -.34140900E-01, -.20978600E+00, 0.10141000E+02, 0.89611400E+02, 0.44762400E+02, -.12642700E+03, -.16464100E+03, -.28115000E+02, 0.28799000E+02, 0.20254900E+03, -.23624700E+02, 0.11839000E+02, 0.10788300E+01, 0.11524800E+02, 0.72394300E+01, -.22889300E+01, -.92392600E+00, 0.74800100E+01, 0.60821700E+01, -.65135200E+00, 0.13163500E+02, 0.33347900E+03, -.18354600E+03, 0.10953000E+04, -.16424900E+03, -.41065200E+03, -.25180000E+03, 0.28924000E+03, 0.23669200E+03, 0.16493500E+03, -.24108800E+03, -.20094400E+03, 0.88036700E+03, -.44283800E+03, -.13840700E+02, -.43919700E+03, 0.39624700E+03, -.25293100E+03, -.16184500E+03, 0.44208000E+02, -.17179500E+03, -.29429200E+03, -.41774900E+03, 0.32454300E+03, -.16802100E+03, -.98206600E+02, -.16193300E+03, 0.12970200E+03, 0.14017800E+03, -.45413800E+02, 0.61952100E+02, -.97075100E+02, 0.11433400E+03, -.18961300E+03, -.22449400E+03, 0.11086300E+03, -.47303900E+03, 0.11301000E+03, -.10264800E+03, -.14255000E+01, 0.19186400E+03, 0.28466800E+03, 0.28095700E+03, -.91556700E+02, 0.18061800E+03, -.10776500E+03, 0.54885200E+02, -.10852800E+04, 0.52470800E+02, 0.12782300E+03, -.73407100E+02, 0.25525000E+01, 0.22909800E+02, 0.38112700E+02, -.55777400E+02, 0.15669700E+03, -.16240400E+03, 0.80716900E+02, -.10474000E+03, 0.83150700E+02, 0.41414400E+03, 0.14566300E+03, -.13181400E+03, -.92846900E+02, -.77059800E+01, 0.11909600E+03, 0.17296700E+02, 0.30559100E+03, -.15349800E+03, -.44801100E+02, -.15276100E+03, 0.39291800E+02, 0.93172300E+02, -.15808000E+03, -.47519800E+02, -.20427400E+03, 0.75799800E+02, -.16720900E+03, -.48517300E+03, 0.24228600E+03, -.52819300E+01, 0.24347100E+03, 0.50419300E+02, -.97455400E+02, 0.29380600E+03, 0.23704100E+03, 0.31919200E+03, -.70175200E+02, 0.21482500E+03, 0.38709200E+02, -.34474300E+02, 0.31256100E+03, -.17264300E+02, -.21534900E+03, -.33927600E+03, 0.27718200E+03, 0.25104300E+03, 0.26192600E+03, -.32072600E+03, 0.29435400E+02, -.54390300E+03, 0.26954100E+03, -.13653100E+03, 0.27495000E+03, 0.38612800E+02, -.96838900E+02, 0.42385800E+03, 0.50331700E+03, 0.50942600E+03, -.10194000E+03, 0.16925900E+03, 0.27512200E+03, -.13879700E+03, 0.21023300E+03, -.13293000E+03, -.38991200E+01, -.10124300E+03, 0.24282600E+02, 0.18277100E+03, -.32614300E+02, -.88620000E+02, -.14587800E+03, -.21693900E+03, 0.10798100E+03, 0.96115000E+02, 0.10998600E+03, 0.97397000E+02, -.33667000E+02, 0.83962900E+02, 0.33245800E+02, 0.17714200E+03, -.45559900E+02, 0.22116000E+03, 0.33010200E+02, 0.21360400E+02, 0.23343000E+02, 0.62328700E+01, -.30720900E+02, 0.98791300E+00, -.12885500E+02, 0.15048400E+02, -.46041300E+01, 0.67875300E+01, 0.20262400E+01, 0.19754300E+03, -.23389700E+02, -.64713800E+01, 0.11794100E+03, -.12219700E+03, -.33048600E+02, -.27562100E+02, -.50696100E+02, -.29595600E+02, -.49611200E+01, -.42159600E+02, -.18131300E+03, -.15403100E+02, 0.20515400E+02, 0.23184300E+02 },
        { -.26491400E+01, 0.18415400E+01, 0.59599400E+00, -.14889900E+01, 0.36926400E+00, 0.13044900E+01, -.31420900E+01, -.74111900E+00, -.73504400E+00, 0.13110100E+01, 0.13270200E+00, -.45048700E-01, -.87277500E+00, -.10800200E+00, -.20495600E+00, -.32729800E+01, 0.47912600E+00, 0.97463700E+00, 0.34701100E+00, -.37843000E+01, -.64204000E+00, 0.30521500E+00, -.48215400E+00, -.36275800E+00, -.22614300E+01, 0.38545600E-01, 0.13226300E-01, -.53219300E+00, 0.38522700E+00, 0.78425000E+00, -.40542300E+00, -.39191500E-01, -.44135000E+00, 0.36156900E+00, 0.38219800E+00, -.80332500E-01, 0.31535800E-01, -.57414500E+00, 0.15749900E+00, -.28085900E+01, -.18967800E+00, -.17379000E+00, -.12596900E+00, 0.47237500E+00, -.80814300E-01, 0.47525500E-01, 0.17862700E+00, 0.16831500E-01, -.38333900E-01, -.87218700E-01, 0.52255200E+00, -.23017400E-01, 0.30274800E+00, 0.31073100E+00, 0.47418700E+00, 0.36231000E+00, 0.38309600E+00, -.98202900E-01, -.50210600E-02, -.28989100E+00, 0.42490300E+00, -.72076200E+00, -.58221100E+00, 0.29138900E+00, -.38298400E+00, 0.14015200E+00, -.46631100E+00, 0.39873700E+00, -.78991900E-01, 0.47958200E-01, 0.56029200E+00, 0.50859200E+00, 0.31672900E+00, 0.23684100E+00, -.12942900E-02, -.40127000E+00, 0.41214900E-01, 0.94922900E-01, -.17886900E+00, 0.32240800E+00, 0.55632600E-01, 0.46258100E+00, -.39960500E+00, -.14408900E+00, -.76906600E+00, -.26796200E+00, -.50547200E-01, 0.12594000E+01, 0.11214000E+01, -.64718900E+00, 0.97055000E+00, 0.19128900E-01, -.11324900E+00, 0.10704600E+01, 0.72719700E+00, -.86061600E+00, 0.26733400E+00, 0.60172300E+00, 0.71472800E+00, -.37242300E+00, -.26926500E+00, -.32123500E+00, 0.52492300E+00, -.34663500E+00, 0.71722200E+00, -.76194200E+00, -.10526700E+01, 0.30920700E+00, 0.19707200E+01, 0.10916600E+00, -.73157400E-01, 0.91857600E-01, -.49882400E+00, 0.27033100E+00, -.68731300E+00, 0.19588500E+01, 0.24996200E+01, -.18593000E+01, -.44965600E+00, 0.31242900E+00, -.24839900E+00, -.15118500E+01, -.23518400E+00, -.71216900E+00, -.76475400E-01, -.45510000E+03, -.17095400E+03, 0.47881700E+03, 0.64449500E+03, 0.23458000E+03, -.12129100E+03, -.83713900E+02, -.19247400E+01, 0.10554400E+01, -.73130700E+01, 0.11189800E+01, 0.13003400E+02, 0.97138400E+01, 0.41485100E+00, -.45093000E+01, 0.10010600E+02, 0.10667900E+02, -.46786500E+02, -.60846400E+03, 0.27617400E+03, -.47203600E+03, 0.30349600E+03, 0.75553600E+03, 0.16332300E+04, -.54945100E+03, -.50615200E+03, -.39140600E+02, 0.13279600E+04, 0.68408900E+03, -.26194800E+04, 0.13082900E+04, 0.13006600E+02, 0.13092900E+04, -.61539400E+03, 0.29261800E+03, -.43252000E+02, -.13332300E+04, 0.26814300E+03, 0.24268300E+03, 0.30101800E+04, -.13470300E+04, 0.65376400E+03, -.31985400E+03, 0.67281100E+03, -.66613400E+03, -.12064700E+04, 0.35615900E+03, -.25246400E+03, 0.54292700E+03, -.11299200E+04, 0.18753000E+04, -.48779400E+03, 0.24320700E+03, -.65631200E+02, 0.25747300E+03, 0.34248300E+02, -.17409900E+03, -.94190800E+02, -.40526800E+03, -.31565400E+03, -.20337700E+02, 0.86731500E+03, 0.24319600E+04, -.12274400E+04, 0.37007700E+03, -.12157200E+04, -.85701500E+03, -.18153600E+04, 0.31199900E+03, 0.10612300E+04, -.59462100E+03, -.16092300E+04, -.13734300E+04, -.13969400E+04, 0.70072400E+03, 0.72239000E+03, 0.69726200E+03, -.64311500E+03, -.23289500E+03, 0.61638500E+03, -.19910300E+03, 0.12151500E+03, -.15359400E+03, 0.58916100E+03, -.16385100E+04, 0.82271800E+03, 0.74064600E+03, 0.81911400E+03, 0.12962300E+03, 0.25556500E+03, 0.43982100E+02, -.54060900E+03, 0.28713400E+03, 0.27521000E+03, 0.95065800E+03, 0.43506400E+03, -.21992100E+03, -.54374200E+03, -.21795100E+03, -.39146800E+02, 0.56009100E+02, -.39954400E+03, -.56539300E+03, -.33262100E+03, -.28881300E+02, 0.30455700E+03, 0.58528600E+03, -.31500100E+03, -.22232700E+03, -.29146300E+03, 0.22609700E+03, 0.64971400E+03, -.27629000E+03, -.43970400E+02, -.37740900E+03, 0.54440100E+03, -.21993000E+03, 0.55010100E+03, -.27838400E+03, -.11707400E+04, -.27672700E+03, -.17448800E+03, -.39459500E+02, -.71927600E+03, -.11871800E+04, -.73987400E+03, -.23493800E+02, 0.10049900E+04, 0.29121000E+03, -.14201600E+03, -.67548100E+03, -.14804100E+03, 0.15332700E+03, 0.23832000E+03, -.29294600E+03, -.30090400E+03, -.24426400E+03, 0.16476100E+03, 0.58697600E+02, 0.13350400E+04, -.66858000E+03, -.74325200E+03, -.66828500E+03, -.62646300E+03, -.27118700E+03, 0.17791100E+03, 0.38711400E+03, -.35321700E+03, -.24865800E+03, -.54149300E+03, 0.36763600E+02, -.19740300E+02, -.43949600E+02, -.35799900E+02, 0.66668800E+02, 0.24139000E+02, 0.12382200E+03, 0.17290100E+02, 0.74852400E+01, -.23582300E+02, 0.17288400E+02, 0.91774300E+02, 0.54088500E+02, -.85976700E+01, 0.94994000E+02, 0.56781000E+02, 0.15707200E+03, 0.55298700E+02, 0.19551500E+03, 0.11187000E+03, -.62715200E+02, 0.36563200E+02, -.90831700E+02, 0.63866800E+02, -.56408100E+02, -.97542300E+02 },
        { -.75337900E+01, 0.64904800E+01, 0.88028400E+00, 0.45219300E+01, -.68041100E-01, -.11439500E+02, -.16902300E+01, -.80371400E+01, -.36049900E+01, 0.45034200E+01, 0.97755200E+00, -.20635800E+00, 0.14387700E+01, -.55048300E+01, 0.29331700E+00, -.31366700E+01, 0.17368000E+01, 0.12435600E+01, 0.10993000E+01, -.12821800E+01, 0.65926500E-02, 0.19958700E+00, -.87849100E-01, -.11126500E+01, 0.66623900E+01, 0.24714800E+00, 0.16250600E+01, 0.17507000E+01, -.18986900E+01, 0.20901300E+00, 0.94504300E+00, -.56470200E+00, 0.22859200E+01, 0.17660200E+01, 0.14067200E+00, -.52053300E+00, -.36966100E+00, 0.11815200E+01, -.12517300E+01, -.91440300E+00, 0.37854000E+00, 0.16155200E+00, 0.17352600E+01, -.33130200E+00, 0.55158600E+00, -.66999300E-01, 0.61025200E+00, 0.46144600E-01, -.53671000E-01, 0.61612300E+00, 0.43462800E+01, -.14009200E+01, -.13659800E+01, -.29735800E+01, -.45327500E+01, 0.20738800E+01, -.38167900E+01, 0.11421600E+00, 0.97527600E-02, 0.18029200E+01, 0.67766300E+00, -.27078500E+01, -.14576100E+01, 0.15411700E+01, 0.24628200E+00, 0.58610000E+00, 0.36178700E+01, 0.86792300E+00, 0.98807600E+00, -.33500900E-01, -.22288100E+00, 0.61520900E-01, 0.37930300E+00, 0.78415100E+00, -.73630000E-01, 0.39716800E+00, -.32154600E+00, 0.12977300E+01, 0.45707600E+00, -.96429200E+00, -.85154900E-01, -.25811400E-01, -.70115700E-01, 0.34403100E+00, 0.64507700E+00, 0.44088500E+00, 0.19070300E+00, 0.13338700E+01, 0.27990000E+01, -.12683100E+01, 0.11854000E+01, -.83606500E-02, 0.92938300E+00, -.35065800E+00, 0.14392500E+01, 0.20193100E+01, -.10837900E+01, -.78865100E+00, 0.94825300E+00, 0.59534300E+00, -.10131000E+00, 0.80839500E+00, 0.14584400E+00, 0.15657800E+00, -.10643900E+01, 0.63554900E+00, 0.16153200E+00, -.24906300E+00, -.25146400E+01, -.40612800E+00, 0.21868400E+01, -.62636000E+00, 0.18571700E-01, 0.76278000E+00, -.86079800E+00, -.32610800E+01, 0.44628000E+01, 0.48171100E+00, -.44201500E+00, 0.31728900E-01, 0.12370900E+01, -.40083300E+00, -.19913600E+00, -.11426300E+01, -.11935700E+00, -.71040200E+00, 0.45324100E+03, -.22642800E+03, 0.14639100E+03, 0.23002700E+03, 0.24322700E+03, -.14863100E+03, -.36130500E+02, 0.18160000E+02, -.23441600E+02, 0.18483700E+02, -.10357600E+02, -.75171300E+01, 0.16515200E+02, -.29002500E+01, 0.26479200E+02, -.41195800E+01, 0.18293000E+02, 0.36860400E+04, -.18953700E+04, 0.11115400E+04, -.18416100E+04, 0.49792600E+03, 0.16506000E+04, -.13015400E+04, -.59924500E+03, -.14631800E+04, 0.13737600E+04, -.21898300E+04, -.24507000E+03, 0.11821900E+03, -.54489800E+02, 0.12171400E+03, -.71140800E+02, 0.42637400E+03, -.65989800E+03, -.12859400E+04, -.73899600E+03, 0.28623100E+03, 0.18278500E+04, -.57047400E+03, 0.26499400E+03, -.56554300E+03, 0.28203800E+03, -.53868200E+03, -.82047900E+03, 0.11499700E+03, -.20582700E+03, 0.22453600E+03, -.78542400E+03, 0.15676800E+04, -.14039900E+04, 0.69952500E+03, -.14807800E+04, 0.73038200E+03, 0.12453200E+02, -.16556400E+03, 0.35472200E+03, 0.33273800E+03, 0.94521300E+02, -.28961900E+02, 0.18959400E+04, 0.14314200E+04, -.69752000E+03, 0.83940400E+03, -.71692900E+03, -.16252400E+04, -.26652700E+04, 0.86133100E+03, 0.10057300E+04, -.72670600E+03, -.22223400E+04, -.67591700E+03, -.31701500E+02, 0.15972400E+02, 0.12904800E+04, 0.12237400E+02, -.16123900E+03, -.14497300E+03, -.84269400E+02, -.72661000E+03, -.44853600E+03, -.11609200E+03, -.54145300E+03, -.98662600E+03, 0.49395900E+03, 0.74477700E+03, 0.49275300E+03, 0.31501600E+03, 0.43127000E+03, -.10180800E+03, -.29115300E+03, 0.20506100E+03, 0.44888900E+03, 0.13115600E+02, 0.28450400E+03, -.14378500E+03, -.69950900E+03, -.14318800E+03, -.76591200E+02, 0.10202900E+03, -.38637300E+03, -.61421700E+03, -.31489400E+03, 0.10265500E+02, 0.41955000E+03, 0.37970600E+04, -.19275700E+04, 0.11816700E+04, -.18876900E+04, -.39686300E+03, -.88140400E+02, -.39144300E+03, 0.15825500E+03, -.14652100E+04, -.38878900E+02, -.21267400E+04, 0.50816400E+03, -.25937700E+03, -.13624900E+04, -.25856200E+03, -.25808500E+03, 0.81691300E+01, -.69322700E+03, -.98751500E+03, -.66491400E+03, 0.64238100E+02, 0.10241600E+04, 0.21430600E+03, -.10891300E+03, -.54119300E+03, -.11350300E+03, 0.17572200E+03, 0.36084900E+03, -.40583500E+03, -.18796700E+03, -.47919900E+03, 0.29206600E+03, 0.28815800E+03, 0.87523600E+03, -.43680200E+03, -.14159600E+04, -.43952500E+03, -.42268900E+03, 0.74517500E+02, -.60107900E+02, 0.29749200E+03, -.18698600E+02, -.97075600E+02, 0.30002500E+03, 0.52568900E+02, 0.14426000E+02, -.77314200E+02, 0.26838000E+02, 0.15341500E+03, -.61553000E+02, 0.47614600E+02, 0.18977900E+02, 0.23043800E+02, 0.52437100E+02, -.13163300E+02, 0.16225500E+03, 0.65615400E+02, 0.33635800E+02, -.18119700E+03, -.17988200E+02, 0.31302300E+02, 0.50410200E+02, -.19149800E+03, 0.66536200E+02, 0.66812900E+01, 0.13076600E+03, -.75645900E+02, 0.49216500E+01, -.59607200E+02, -.15382300E+03 },
        { -.22436200E+01, -.17664900E+01, -.12096700E+00, 0.43180300E+00, -.10198700E+01, -.11853400E+01, -.18399500E+01, -.76792000E+00, -.13710000E+01, 0.19196200E+01, 0.46711400E-01, -.21344800E+00, -.53578700E+00, 0.12070000E+01, -.30532300E+01, -.50110900E+00, 0.51233900E+00, -.54334000E+00, 0.13979800E+01, -.20953300E+01, 0.53904400E+00, 0.12002800E+00, -.41365500E-02, -.48932800E+00, 0.28374200E+01, 0.55203200E-01, 0.63727000E-01, -.44961300E+00, -.52698300E+00, -.13367700E+00, 0.33359000E+00, 0.51641800E+00, 0.10971200E+01, 0.26653000E+00, 0.30583000E+00, -.12165300E+00, -.67521100E-01, -.92163600E-01, -.37406000E-01, -.37941300E+00, 0.13214600E-01, 0.81811000E-01, -.36637600E-01, -.16217900E+00, 0.19863100E+00, -.84176000E-01, 0.18913700E+00, 0.44710700E-02, -.11277700E+00, 0.17591400E-01, -.16469500E+01, 0.57933100E-01, 0.16884600E+00, 0.73904200E+00, 0.28764200E+00, -.30580600E+00, -.21573200E+00, -.19388400E+00, 0.85807700E-02, -.58375300E+00, 0.68862900E+00, 0.60899500E+00, 0.51168300E+00, -.58719100E-01, 0.95152700E-02, 0.67237200E-01, 0.83436800E+00, -.11940300E+00, -.50104800E-01, -.40545100E-01, -.73914700E-02, -.34746900E-01, -.11155500E+01, -.37705200E+00, -.84566700E+00, 0.41139600E+00, -.16937100E+00, -.23951900E+00, -.72539500E-01, -.47988300E-02, 0.30298600E-01, 0.84109900E-01, 0.46244800E+00, 0.27417700E+00, -.67790100E-01, 0.37585000E+00, -.40748300E+00, 0.84253400E+00, 0.10576400E+00, -.58796900E+00, -.83837600E+00, 0.39194800E-01, -.19932300E+00, -.79079800E-01, 0.57974500E+00, 0.58312900E+00, 0.45417700E-01, -.14993500E+00, 0.60665100E+00, 0.26851300E+00, 0.18946900E+00, 0.12983800E-01, -.60311200E+00, 0.44056700E+00, -.47395900E+00, 0.41069600E+00, -.46753700E-01, -.51717300E+00, -.12145800E+00, -.93916600E-01, 0.48783600E+00, -.66053000E-01, 0.46481600E-01, -.19535000E+00, 0.34802400E-01, 0.31974600E+00, -.11535900E+01, -.23329900E+00, 0.37997600E-01, 0.23448100E+00, -.27619500E+00, -.55142900E+00, -.29815000E-01, 0.77077400E-01, 0.91898400E-02, -.18285400E+00, -.11772000E-01, 0.14474200E+03, 0.13440000E+03, 0.91563600E+02, 0.50526900E+01, -.13059900E+02, -.37474500E+01, 0.19065600E+01, 0.75142300E+01, 0.18695900E+01, 0.47107700E+01, 0.42555500E+01, -.33452300E+01, -.25067300E+01, 0.18228700E+01, 0.32252700E+01, -.43920900E+01, -.13364700E+03, 0.58498000E+02, -.67015700E+03, 0.66002700E+02, 0.38060000E+03, 0.73967800E+03, -.20417800E+03, -.16562300E+03, 0.11723700E+03, 0.54982200E+03, 0.25963400E+03, -.69313900E+02, 0.34527800E+02, -.11455100E+03, 0.34572700E+02, -.18557200E+03, 0.11733200E+03, 0.15628900E+02, -.24983300E+03, -.29599000E+03, 0.12497900E+03, 0.35036000E+03, -.41056700E+03, 0.19772000E+03, -.70448000E+02, 0.20487700E+03, -.16961500E+03, -.38213100E+03, 0.68830500E+02, -.73280900E+02, 0.11198300E+03, -.33849700E+03, 0.53828900E+03, -.39233800E+03, 0.19650700E+03, -.39644400E+03, 0.19573700E+03, 0.67274500E+02, -.14143000E+03, 0.30796500E+02, -.11685800E+03, 0.83342900E+02, -.11718600E+03, 0.31684900E+03, 0.11318300E+04, -.57415700E+03, 0.49251800E+03, -.56542100E+03, -.46251500E+03, -.88894000E+03, -.49989200E+02, 0.25596100E+03, -.26933300E+03, -.74403100E+03, -.68759200E+03, 0.24986000E+03, -.12397600E+03, 0.32995300E+03, -.12478600E+03, -.23660200E+03, -.35107600E+02, -.10356200E+02, -.16527800E+03, -.27291800E+03, 0.73535100E+01, -.15679500E+03, -.79238500E+03, 0.39768200E+03, 0.49777100E+03, 0.39626000E+03, 0.82227000E+02, 0.20811300E+03, 0.26822800E+02, -.35220300E+03, -.84093700E+01, 0.23069800E+03, 0.31873700E+03, -.81735900E+02, 0.39591600E+02, -.69461900E+02, 0.40827600E+02, -.21895100E+02, 0.55875000E+02, -.83500400E+02, -.17380500E+03, -.69163200E+02, 0.30547200E+02, 0.10999200E+03, 0.55024100E+03, -.28617500E+03, -.32602600E+03, -.27722400E+03, 0.33021800E+02, 0.19104000E+03, -.10546100E+03, -.22192400E+02, -.44617100E+02, 0.11334500E+03, -.22125600E+03, -.11964700E+03, 0.58224700E+02, -.11533100E+03, 0.59877400E+02, -.37265300E+02, 0.51280300E+02, -.18840100E+03, -.31532700E+03, -.16726300E+03, 0.41141200E+02, 0.23692900E+03, 0.53013800E+02, -.24173700E+02, -.16398200E+03, -.26493900E+02, 0.35656200E+02, 0.54158300E+02, 0.74861200E+01, -.22499200E+02, -.35795100E+02, 0.45816700E+02, 0.24133500E+02, 0.21542800E+03, -.10759000E+03, -.26454500E+03, -.10773500E+03, -.15229400E+03, -.17662300E+03, 0.20377900E+03, 0.21751400E+03, 0.89406900E+02, -.17977900E+03, 0.92369600E+01, 0.11191000E+02, -.19108700E+02, -.32287300E+01, -.49851600E+00, 0.35018000E+02, 0.82788000E+01, 0.35275200E+02, -.11974100E+01, 0.46928200E+01, -.20122900E+01, 0.73441200E+00, -.13639000E+02, 0.13288100E+02, -.47150800E+00, 0.13499000E+01, 0.58993900E+02, 0.35911000E+02, 0.22579700E+02, 0.13977400E+03, 0.48187100E+02, -.74145000E+02, 0.36670400E+02, 0.23507900E+02, 0.30946600E+01, -.87060300E+01, -.57450700E+02 },
        { -.19270400E+01, -.74223200E+00, -.33922800E-01, -.40338100E+00, -.13459700E+01, -.36993300E+00, -.83537700E+00, -.31760800E+00, -.82275400E+00, 0.11467700E+01, 0.60792500E-01, -.13837800E+00, -.60240900E+00, 0.17051900E+01, -.18264200E+01, 0.44224800E-01, 0.20283200E+00, -.18207200E+00, 0.69130200E+00, -.10474600E+01, 0.66606300E+00, -.48589400E-01, -.10216300E+00, -.26549100E+00, 0.18319600E+01, 0.19564100E-01, -.29520400E+00, -.13178200E+00, -.50587800E+00, -.32244100E+00, 0.22003000E+00, 0.18449800E+00, 0.52129300E+00, 0.67615000E-01, 0.10157000E+00, -.15239700E+00, -.10859100E-01, 0.45082000E+00, -.83299900E+00, 0.39087400E+01, 0.45340300E-01, 0.21667900E-01, 0.31590900E+00, 0.17005100E+00, 0.29874300E-01, 0.36476900E-01, 0.74457300E-01, -.90857100E-02, 0.28744400E-01, 0.16275500E-02, 0.10368800E+01, 0.38288700E-01, -.10804900E+00, -.21157900E+00, 0.13781900E+00, -.53240500E-01, 0.96283000E-01, -.51086700E-01, -.17814400E-01, 0.30417100E-01, -.23682500E+00, -.50092600E+00, -.28001200E+00, -.59881500E-01, 0.15176000E+00, 0.33128400E-01, -.21206300E-01, 0.12117900E-01, 0.92631300E-02, 0.39831800E-02, -.32508200E+00, -.57572300E-02, 0.73152200E+00, 0.15950800E-01, 0.75629500E-01, 0.50667700E+00, -.27505200E+00, 0.17039100E+00, 0.20653300E-01, 0.16986400E+00, -.27515300E-01, 0.11338400E-01, -.11752600E+01, 0.89393800E-01, 0.10021100E+01, 0.12748500E+00, 0.60714200E+00, -.30744600E+00, 0.14024100E+01, -.60514300E+00, -.79567200E+00, -.22056900E-01, 0.16509000E+00, -.18674600E+00, 0.70057500E-02, -.67540900E-01, 0.38962700E-01, 0.79704400E-01, 0.15734900E+00, 0.78815400E-01, -.47980000E-01, 0.29955700E+00, -.10023700E+00, -.96500600E-01, -.96758500E-01, 0.35270800E+00, 0.17001200E-01, 0.25909200E+00, 0.31084700E+00, 0.42973200E-01, -.46881000E+00, 0.87215200E-01, 0.39075600E-01, -.82904500E-01, -.22856400E+00, 0.61776800E+00, 0.21803800E+00, -.27439900E+00, 0.22292800E-01, 0.23720200E+00, -.42101100E+00, 0.12037200E+00, -.16867700E-01, 0.20492400E+00, 0.16858100E-02, 0.28713500E+00, 0.32990500E-01, -.66201800E+00, -.10692900E+03, -.18669700E+02, 0.44485700E+01, 0.96313400E+02, -.18082400E+01, 0.87661500E+00, 0.18347300E+01, 0.80796600E+00, 0.58738000E+01, -.19988200E+01, -.66305400E+01, -.13470900E+01, 0.26221200E+01, -.43719700E+00, 0.12302400E+01, -.16314600E+03, 0.85748300E+02, 0.70857000E+03, 0.79941600E+02, 0.64783700E+02, 0.24439600E+02, 0.14160100E+03, 0.93084500E+02, 0.14488900E+03, -.39063700E+02, 0.16438300E+03, 0.24961200E+03, -.12360200E+03, -.11125700E+03, -.12477600E+03, 0.10927400E+03, -.22212100E+02, -.75506500E+02, 0.14663000E+03, 0.60099800E+02, -.12503300E+03, -.18009900E+03, 0.28616200E+02, -.88467400E+01, -.95798800E+02, -.13015800E+02, -.89172400E+01, -.68934500E+02, 0.59163100E+02, 0.50173500E+02, -.33714500E+02, -.82274100E+02, 0.48998900E+02, 0.24890700E+03, -.12339700E+03, -.46845100E+03, -.13240500E+03, 0.76782400E+02, 0.10528700E+03, -.16426300E+02, 0.17917600E+03, 0.77785400E+02, 0.37798100E+02, -.18370700E+03, 0.72398300E+03, -.36363800E+03, -.36547200E+03, -.36088100E+03, -.25987200E+03, -.25993200E+03, 0.16025900E+02, 0.43481800E+02, -.26104800E+03, -.17319000E+03, -.43502800E+03, 0.56129100E+03, -.28048000E+03, -.24295500E+03, -.27962500E+03, -.79127900E+01, 0.11228200E+03, -.23069000E+03, -.35853900E+02, -.17891900E+03, 0.67293200E+02, -.11425900E+03, 0.20938400E+03, -.10531900E+03, -.12800500E+00, -.10444500E+03, 0.17493500E+02, 0.10629200E+03, -.10171700E+03, -.48767600E+02, -.14822600E+03, 0.87302500E+02, -.17072200E+03, 0.40118300E+02, -.19771400E+02, -.13836200E+03, -.19930800E+02, 0.13460900E+03, -.84107300E+01, 0.30513500E+02, 0.15325100E+03, 0.51955500E+01, 0.15111800E+02, -.25511900E+03, 0.14161200E+03, -.72651600E+02, 0.42777200E+03, -.76799600E+02, -.25687900E+02, -.29841100E+02, 0.76814200E+02, 0.38601500E+02, -.46909800E+02, -.51471500E+02, -.68401100E+02, -.76678500E+02, 0.39354100E+02, -.31366600E+03, 0.39391200E+02, 0.22216500E+03, 0.28562600E+02, 0.77705600E+02, 0.34022400E+03, 0.11465000E+03, 0.24306800E+02, -.38316500E+03, 0.55618900E+02, -.26659200E+02, -.16643100E+02, -.26442300E+02, 0.53200600E+02, 0.19742100E+02, 0.84655900E+01, 0.52305300E+02, 0.38361100E-01, 0.10198300E+02, -.41839200E+02, -.27312600E+03, 0.13628600E+03, 0.16282000E+03, 0.13692900E+03, 0.20431800E+02, -.57908900E+01, 0.98869700E+02, -.23310100E+02, 0.76519900E+02, -.14347400E+02, 0.20733800E+03, 0.37639500E+01, -.21794100E+02, 0.71413100E+01, 0.47861600E+00, -.29783500E+02, 0.93644800E+01, -.87557100E+01, -.42241400E+01, 0.12942800E+02, -.38892500E+01, -.86563100E+01, -.21705500E+02, -.56219800E+01, 0.84234000E+00, -.22661900E+02, -.51722400E+02, 0.15992200E+02, -.20243000E+02, -.23940000E+02, -.10664800E+02, -.28787000E+02, 0.35472000E+02, 0.27921100E+02, -.32224600E+02, -.15224500E+01, 0.30808200E+02 },
        { -.22149800E+01, 0.23175700E+00, -.54709300E-01, -.13113600E+01, -.10705400E+01, 0.35892500E+01, -.45556100E+01, 0.85997000E+00, -.10613400E+01, 0.19901500E+01, -.75860800E-01, -.93102500E-01, -.17351200E+01, 0.57678700E+00, -.13124700E+01, -.54268500E+00, -.64071000E+00, 0.10783600E+01, 0.11342100E+00, 0.59812100E+00, 0.44099900E+00, 0.50913000E-01, -.22714600E+00, -.96331200E-02, -.26804300E+01, 0.31625500E-01, -.52980200E+00, -.10257100E+01, 0.94851100E-01, -.55331100E+00, 0.23938100E+00, -.10551400E+01, -.88603100E-01, 0.11160300E+01, -.20725800E+00, 0.23717100E+00, -.18014400E+00, 0.78890500E+00, -.13344000E+01, -.12532300E+01, 0.16877200E+00, 0.30531400E+00, -.49459700E+00, -.20214000E+00, 0.38738000E+00, -.11509300E+00, -.79374500E+00, -.69745600E-02, 0.18144800E+00, 0.49066300E+00, 0.14323600E+01, -.46889300E+00, -.41890900E-01, -.27360200E+00, 0.14145700E+00, 0.15665000E-01, 0.19399600E-01, -.10879000E+00, 0.26484000E-01, 0.25601200E+00, 0.47170000E+00, 0.17874800E+01, 0.70258500E+00, 0.90353000E+00, -.13455200E+00, 0.13280100E+00, -.20041300E+00, 0.52955100E+00, -.19781300E+00, 0.73400900E-01, -.59532300E+00, 0.12436700E+00, 0.25615200E+00, -.29183600E+00, -.36966600E-01, 0.12674600E+00, 0.22980800E+00, -.76596500E+00, -.11422700E+00, -.32765100E+00, -.14405700E-01, -.87900500E-01, 0.11328200E+01, 0.29698800E-01, -.44770000E+00, 0.50353300E+00, -.12061100E+01, -.96172200E+00, -.28987300E+01, 0.12383000E+00, -.25647000E+00, 0.31197900E-01, 0.37250100E+00, 0.27816900E+00, -.78149400E+00, -.25524600E+00, -.18557100E+00, 0.22568600E-01, -.89768400E+00, -.23817900E+00, 0.17635400E+00, -.10142600E+00, -.45756600E+00, -.17412900E+00, -.19819400E+00, -.40693600E+00, -.14328600E+00, -.51175200E+00, -.75241700E+00, -.72263900E-01, 0.89158500E+00, 0.17826800E-01, 0.15076400E+00, 0.16703800E+00, -.33741400E+00, -.47258000E+00, -.21319100E+01, 0.11708500E+01, 0.15206700E+00, 0.57125000E+00, -.22614500E+00, 0.41315700E+00, 0.18407000E-01, 0.73633600E+00, 0.29845300E-01, -.16315600E+00, 0.19669100E+00, 0.44177100E+00, 0.47785900E+00, -.22244700E+03, 0.70254400E+02, -.27180200E+03, 0.21460800E+02, -.10769700E+02, 0.15173500E+02, -.10797200E+02, -.27116800E+02, 0.46059600E+01, 0.13462300E+02, -.69484400E+01, -.35140000E+01, -.33269700E+01, -.23036500E+01, -.15325500E+04, 0.75993900E+03, -.36217500E+04, 0.76726700E+03, 0.56723100E+03, 0.46268000E+03, -.36710700E+03, -.46215900E+03, -.12588600E+03, 0.48926400E+03, 0.88453300E+03, -.15519600E+04, 0.78581400E+03, 0.17166700E+03, 0.77626800E+03, -.10327400E+04, 0.29675700E+03, 0.63353100E+03, 0.11707500E+03, 0.23733000E+03, 0.60554900E+03, 0.85161600E+02, -.54752700E+03, 0.29336700E+03, 0.28464300E+03, 0.27283200E+03, -.80735300E+02, -.25663500E+03, 0.17121100E+02, -.11224300E+03, 0.30213500E+03, -.11920500E+03, -.22442000E+03, 0.80701500E+03, -.40312300E+03, 0.35048200E+03, -.40640300E+03, -.10066900E+02, -.52320100E+01, -.29282300E+03, -.27765500E+03, -.44443900E+03, 0.14210700E+03, -.74064100E+03, -.87244200E+02, 0.67683400E+02, 0.25244900E+04, 0.43006800E+02, 0.32323300E+03, 0.38814900E+03, -.43811000E+03, -.24023100E+03, 0.26343000E+03, 0.27718800E+03, -.40806000E+02, 0.18149700E+03, -.90248700E+02, 0.45166200E+03, -.90359500E+02, -.77136700E+03, -.44954100E+03, 0.39559600E+03, 0.29040000E+03, 0.75758300E+02, -.29698800E+03, -.13714000E+03, -.52578600E+02, 0.28067100E+02, -.12767900E+03, 0.26256200E+02, -.77575300E+02, -.20572400E+03, 0.28312400E+03, 0.30903800E+03, 0.43297800E+03, -.20252000E+03, -.22546700E+02, 0.13570000E+03, -.67758700E+02, 0.32912500E+03, -.67615000E+02, -.39997200E+02, 0.22548000E+03, -.23854200E+03, -.26073500E+03, -.13054300E+03, 0.19113200E+03, 0.36211600E+02, -.11637100E+04, 0.59616000E+03, -.15008600E+04, 0.58360500E+03, 0.46564100E+03, 0.72404200E+03, -.51704100E+03, -.54352800E+03, -.11922900E+03, 0.67648100E+03, 0.63522400E+03, 0.77654600E+03, -.38509800E+03, 0.39474100E+03, -.38758400E+03, -.13329600E+03, 0.30816000E+03, -.43521500E+03, -.46138200E+03, -.40193100E+03, 0.25734200E+03, -.23343900E+03, -.66320200E+03, 0.33462700E+03, -.11369900E+03, 0.33271000E+03, -.74581100E+02, 0.66095600E+02, 0.82471400E+02, -.24565800E+03, 0.24719800E+03, 0.77687200E+02, 0.24710500E+03, -.41896100E+03, 0.20895000E+03, 0.15458000E+03, 0.20985900E+03, 0.38971000E+02, 0.28170300E+03, -.21907500E+03, -.42407500E+03, -.33184300E+03, 0.35815300E+03, 0.13781500E+02, -.48919000E+02, -.27975600E+02, -.40049400E+02, 0.83041000E+01, 0.33533100E+02, -.10395200E+02, -.10165600E+02, -.23858300E+02, -.16583500E+02, 0.16452200E+01, -.85522300E+01, -.25878600E+03, 0.22646700E+02, 0.22669700E+02, -.51683900E+02, 0.35966600E+03, 0.20110500E+02, 0.53397900E+02, 0.33296300E+03, 0.50244300E+02, 0.65699500E+02, 0.93809500E+02, 0.20438100E+03, -.92790700E+01, 0.42033800E+01, 0.34674400E+02 },
        { -.10495300E+01, 0.20678600E+01, 0.23602700E+00, 0.74455300E+00, 0.46006800E+00, 0.68253000E+00, -.29551500E+01, 0.29022300E+01, -.12434300E+01, 0.22549000E+00, -.10027300E-01, -.82929900E-01, 0.19178500E-01, -.93973600E+00, 0.33532200E+00, -.30461400E-01, -.30138400E+00, 0.58435100E+00, -.37019400E+00, 0.33261200E+00, 0.25341600E+00, -.15296100E-01, 0.29824500E-01, 0.75905800E-01, -.92685500E+00, -.71894200E-02, 0.22464500E+00, 0.25080100E-01, -.42962800E-01, 0.41082200E+00, -.31839200E+00, -.21768900E+00, -.38347700E+00, -.25653400E+00, -.20998500E+00, -.35249700E-01, 0.10775400E-01, -.34321700E+00, -.43153100E+00, 0.43704800E+00, -.97700800E-01, 0.14226500E+00, -.92063900E-01, 0.34419900E-01, 0.38305200E+00, 0.87555100E-01, -.20358800E-01, 0.17455500E-01, -.75076700E-02, -.18725200E+00, -.81459300E+00, 0.85497000E-01, 0.14299500E+00, 0.38987100E+00, -.16589000E+00, -.17144100E+00, 0.32928600E+00, -.33713100E-01, 0.24243100E-01, -.14190900E+00, 0.29388400E-01, -.57703400E+00, -.51468400E+00, -.88099600E-01, -.81834100E-01, 0.57610000E-01, 0.18684900E+00, 0.51851100E-01, -.30767700E-01, 0.20049600E-01, 0.19266000E+00, 0.89057200E-01, -.76633800E+00, -.12360100E+00, -.28691300E+00, -.29069900E+00, 0.14236600E+00, -.29258800E+00, -.13427400E+00, -.53551800E-01, 0.35377200E-01, 0.10789300E+00, -.55746100E+00, 0.12649100E+00, -.82660800E+00, -.21364300E+00, 0.69879800E-01, 0.55855500E+00, 0.10253200E+01, -.80905700E+00, -.50203200E+00, 0.81365900E-02, -.17511600E-01, 0.33773900E+00, -.64387300E-01, -.61981500E+00, 0.29272900E+00, 0.42971900E+00, -.85229800E-01, -.16052200E+00, -.18455200E+00, -.21256700E+00, 0.18523000E+00, 0.70851800E-01, 0.10563600E+00, 0.15106900E+00, 0.45471700E-01, 0.36625300E+00, -.22032300E+00, 0.71376300E-01, 0.17677800E+00, 0.68235800E-02, 0.33782300E-02, -.28240200E-01, -.43111500E+00, -.50484000E+00, -.12194500E+01, -.11818600E+00, 0.50651400E-01, 0.26803300E+00, 0.23326600E+00, -.18807100E+00, -.57578200E-01, 0.64512100E-01, 0.39448300E-02, -.17271200E+00, 0.10104600E+00, 0.34771700E+00, -.78307700E+00, 0.12142300E+00, 0.40024700E+02, -.15654400E+03, -.32369100E+02, 0.16157100E+02, 0.12498500E+02, 0.16128900E+02, -.94162800E+01, -.20198200E+01, 0.18976900E+02, 0.17244000E+01, 0.20317600E+02, -.61803400E+01, 0.13705700E+02, 0.31237600E+03, -.19307600E+03, -.75604200E+03, -.15615900E+03, 0.21361800E+03, 0.45482900E+03, -.40563000E+03, -.16190800E+03, -.43446500E+03, 0.36505800E+03, -.27316700E+03, -.40204200E+03, 0.20839600E+03, -.33433000E+02, 0.20115100E+03, -.45137600E+03, 0.21929000E+03, -.36830700E+02, -.13015100E+03, -.27974100E+02, 0.29054400E+03, -.16483900E+02, -.28660500E+03, 0.15563200E+03, -.24166200E+03, 0.14316200E+03, -.13689200E+03, -.31691100E+03, 0.34017000E+02, -.13735600E+03, 0.35577600E+02, -.19575600E+03, 0.11499000E+03, 0.36779200E+03, -.18298000E+03, -.64964200E+03, -.18871200E+03, 0.13926200E+03, -.23084000E+02, -.14533700E+03, 0.84907000E+02, -.30435600E+02, 0.18735300E+01, -.40659400E+03, 0.23313600E+03, -.88887200E+02, 0.10003200E+04, -.11651700E+03, -.14692200E+03, -.32930800E+03, 0.37088200E+02, -.97241900E+01, -.10730700E+03, -.23244500E+03, -.25743700E+03, 0.83862900E+03, -.41837400E+03, 0.34984600E+03, -.41885800E+03, -.58971900E+03, -.77986400E+02, -.13505800E+03, 0.10109000E+02, -.24670200E+03, -.65654600E+02, -.37914600E+03, -.28847300E+03, 0.14514400E+03, 0.19905000E+03, 0.14430000E+03, 0.88832100E+02, 0.13228100E+03, 0.46224900E+02, -.16779300E+03, 0.92673700E+02, 0.14192000E+03, 0.18335100E+03, 0.69999400E+03, -.35023400E+03, -.37511400E+03, -.34986200E+03, 0.12101100E+03, 0.54074200E+02, -.30886800E+03, -.48398700E+02, -.20921400E+03, 0.66572800E+02, -.27221000E+03, 0.12733500E+03, -.76830600E+02, 0.11132500E+02, -.64683100E+02, 0.11317300E+03, 0.34789800E+03, -.27679300E+03, -.24828900E+03, -.44552600E+03, 0.29204100E+03, -.28593600E+03, 0.73570200E+03, -.36610100E+03, -.65546600E+03, -.36725700E+03, 0.23227300E+03, 0.88574500E+02, -.47157700E+03, -.16806400E+03, -.24113900E+03, 0.10669100E+03, -.38535300E+03, -.20180600E+03, 0.10448600E+03, -.32191300E+03, 0.10175600E+03, 0.23222400E+02, 0.69085200E+02, -.10036600E+03, -.16193400E+03, 0.92147300E+02, 0.56322000E+02, 0.15610800E+03, -.33658300E+03, 0.16710400E+03, -.15164800E+03, 0.16855200E+03, -.61924200E+02, 0.63090800E+02, 0.40593100E+02, -.62222800E+02, 0.19431100E+02, 0.48394900E+02, 0.55860200E+02, 0.17744900E+02, 0.12616900E+02, -.37729000E+02, 0.45810600E+01, 0.10287400E+02, 0.97367300E+01, -.76140200E+01, -.36901600E+01, 0.37750500E+01, -.10996200E+01, -.20127700E+02, -.41951100E+02, 0.11485600E+02, 0.21346100E+02, -.44972900E+02, 0.16923300E+03, -.36008900E+02, 0.14722300E+02, 0.73361600E+02, 0.37820400E+02, -.76530600E+01, 0.84218800E+02, 0.34541200E+02, -.30316200E+02, -.35396300E+02, 0.80579500E+01 },
        { -.91494100E+00, 0.29512800E+00, 0.83538700E-01, 0.42828100E+00, -.11219500E+00, -.14398800E+01, -.25504600E+00, -.30713000E+00, -.50078100E+00, 0.45109600E+00, 0.38299400E-01, -.44908700E-01, -.24746900E-01, -.31950000E+00, 0.26463600E+00, 0.40886500E+00, 0.22244700E+00, -.48957600E-02, -.34770700E+00, 0.52153900E+00, 0.77797300E-01, -.34217500E-01, 0.64463000E-01, 0.10931200E+00, 0.12392800E-01, -.18977700E-01, 0.86145200E-02, 0.41590000E+00, -.37241500E+00, 0.46419800E+00, -.16250600E+00, -.28601200E+00, -.30588000E-01, 0.11526900E+00, 0.52608700E-01, -.21576500E+00, 0.74490600E-01, 0.78898100E-01, -.10745000E+00, -.20509700E+01, 0.59441000E-01, -.63401500E-01, 0.34119500E+00, 0.24038000E+00, -.85372500E-02, 0.35687800E-01, -.11485200E-01, -.12810900E-01, 0.39387900E-01, -.67917600E-01, 0.93485300E+00, 0.56496100E-01, -.12798800E+00, -.19142600E+00, -.29709300E+00, -.10752500E+00, -.22506400E-02, 0.28440500E-02, -.38385600E-01, 0.14421400E+00, 0.62668500E-01, -.31288900E+00, -.17280200E+00, -.14988000E+00, 0.24143200E+00, -.52348200E-02, -.29666100E+00, -.49870500E-01, 0.43778900E-01, 0.24781700E-02, 0.46369000E+00, -.10335600E+00, -.17739200E-01, 0.61804900E-01, 0.44039200E-01, -.34845300E+00, -.17338400E-01, 0.11121800E+00, 0.22108900E+00, -.31277300E+00, 0.64935400E-01, 0.11067600E+00, 0.25956800E+00, 0.26731800E-01, -.89138900E+00, -.24573700E+00, -.15839100E+00, 0.53804300E-01, -.10187200E+01, 0.26944900E+00, 0.57935800E+00, 0.35372700E-01, 0.45212900E-02, 0.33708000E+00, -.13611800E+00, -.35806100E+00, 0.82962400E-01, -.12715200E+00, -.83212200E-02, -.71433800E-01, 0.56232700E-01, -.22719600E+00, -.18645600E+00, 0.28790700E+00, -.76598600E-01, -.17807800E+00, -.30652800E+00, -.35158100E+00, -.49442200E+00, -.11957200E+00, 0.54664500E+00, -.92373300E-01, -.60978200E-01, 0.18247800E+00, 0.46854000E-02, 0.27969300E+00, 0.24400600E+00, -.68162800E-01, 0.78788700E-01, -.24520500E+00, -.19792700E+00, -.12201800E+00, 0.80006800E-01, -.53976700E-01, -.17782800E-01, -.23588900E+00, 0.49342700E-01, 0.15973200E+00, -.43970800E-01, 0.34047000E-01, 0.21796400E-01, -.12435000E+03, 0.16023000E+02, -.80219100E+01, -.26420900E+01, -.79373700E+01, -.58005300E+01, 0.52462500E+00, -.33765300E+01, -.70142900E+01, -.10860900E+02, 0.14917000E+01, -.85720400E+01, -.76743900E+03, 0.39303500E+03, -.71965700E+03, 0.38422200E+03, 0.19171200E+03, 0.30840400E+03, -.14560700E+03, -.10333100E+03, 0.36471800E+03, 0.26295100E+03, 0.46659100E+03, -.34401800E+03, 0.17119800E+03, 0.93080700E+02, 0.17189700E+03, -.21603600E+03, 0.64482800E+02, 0.75959800E+02, -.23513400E+02, 0.48704200E+02, 0.12312900E+03, 0.28237400E+03, -.20847700E+03, 0.10452600E+03, 0.16891300E+02, 0.10441700E+03, -.58624100E+02, -.87197700E+02, 0.39885400E+02, -.54127100E+02, 0.71535100E+02, -.53328900E+02, 0.14626700E+03, 0.24286800E+02, -.11774600E+02, 0.17808500E+03, -.65668500E+01, -.31195400E+02, 0.51157600E+01, 0.73957100E+01, 0.11704400E+02, -.52899200E+02, 0.25074400E+02, 0.73717800E+02, 0.10944000E+03, -.55322100E+02, 0.17967700E+03, -.55119400E+02, 0.13919700E+03, 0.10318100E+03, -.10521700E+03, -.69932600E+02, -.78046400E+02, 0.87871500E+02, -.20144100E+02, -.30015100E+03, 0.14984600E+03, 0.15801900E+03, 0.14938900E+03, -.74776300E+02, -.12558300E+03, 0.14535200E+03, 0.97502000E+01, 0.73585700E+02, -.83071800E+02, 0.11176400E+03, -.44744500E+02, 0.21730800E+02, 0.19609900E+01, 0.22238700E+02, -.18972400E+02, -.60034600E+02, 0.54117100E+02, 0.73224700E+02, 0.11159700E+03, -.54884100E+02, 0.99007700E+02, -.20542900E+03, 0.10302100E+03, 0.12878100E+03, 0.10257000E+03, -.97129200E+02, 0.63005300E+02, 0.19461800E+02, -.59819500E+02, 0.67673500E+02, 0.68140800E+02, 0.31342300E+03, -.60878100E+03, 0.31061100E+03, -.49725500E+03, 0.30711500E+03, 0.21045600E+03, 0.33233500E+03, -.16433800E+03, -.78108400E+02, 0.35009300E+03, 0.28868200E+03, 0.35252900E+03, -.32541400E+02, 0.16667800E+02, 0.13278400E+03, 0.15467300E+02, -.16382300E+03, 0.89725600E+02, 0.33487000E+02, 0.17518200E+02, 0.37575700E+02, 0.81141400E+02, 0.37200100E+03, -.76336700E+02, 0.37422300E+02, -.45168700E+02, 0.37068900E+02, -.34833400E+02, 0.29395500E+02, 0.26877400E+02, -.19422800E+02, 0.34535000E+02, 0.22806200E+02, -.39114700E+01, -.32015900E+01, 0.17525700E+01, 0.71946400E+02, 0.12819800E+01, -.21604700E+02, 0.51512600E+02, -.59889100E+02, -.84559900E+02, -.76286500E+02, 0.73211300E+02, -.47977900E+02, -.27805800E+02, -.10521800E+02, -.41187000E+01, 0.92458600E+00, 0.10094000E+02, -.34301200E+01, 0.13095800E+02, -.91306900E+01, -.17461300E+01, -.22059100E+01, 0.73804600E+01, -.52030800E+02, 0.40519900E+01, 0.38980800E+01, 0.10756300E+02, 0.53774300E+02, 0.14124600E+02, 0.77097400E+00, 0.69465800E+02, 0.17984000E+02, 0.14076000E+02, 0.12867900E+02, 0.34320500E+02, -.11067600E+01, 0.22924100E+01, 0.37982100E+01 },
        { -.20828600E+01, -.11626000E+01, -.94050500E-01, -.53870000E+00, -.13983000E+01, -.84620800E+00, -.68070200E+00, -.11007600E+01, -.77134800E+00, 0.17317900E+01, 0.39249900E-01, -.11817300E+00, -.12869600E+01, 0.21587900E+01, -.27404400E+01, 0.11041900E+00, 0.39195800E+00, -.51777800E+00, 0.73154400E+00, -.11176600E+01, 0.70457200E+00, -.50095500E-01, -.11777300E+00, -.11342400E+00, 0.10502700E+01, -.39750900E-02, -.51040100E+00, -.69782500E+00, -.14117200E-01, -.40992600E+00, 0.21298600E+00, 0.45402300E+00, 0.39042400E+00, 0.72641500E-01, 0.16428900E-01, -.54137700E-01, -.91243600E-02, 0.23692500E+00, -.90930500E+00, 0.28134100E+01, 0.56187200E-01, 0.66728000E-01, -.33167100E+00, 0.27994900E+00, 0.33220900E-01, 0.80442600E-01, -.21385400E+00, 0.56500500E-02, 0.71305500E-01, 0.85406200E-01, 0.84099500E+00, -.92866900E-01, 0.15041900E+00, -.70098000E+00, 0.14531800E+00, 0.19379600E+00, 0.46320800E+00, 0.21411100E-01, 0.46746000E-01, -.58115000E-01, -.11719100E+00, 0.72412900E+00, 0.22844400E+00, -.15791200E+00, 0.61493100E+00, 0.15476400E-01, 0.12970100E+00, 0.96813600E-01, 0.13116400E+00, 0.28172500E-01, -.66119800E+00, -.90340100E-01, 0.72310300E+00, 0.30317900E+00, 0.76126500E+00, 0.98219200E-01, 0.93656300E-03, 0.26847600E+00, -.93751300E-01, 0.19860000E+00, -.48490000E-01, -.42940800E-02, -.81741400E+00, 0.10404200E+00, 0.75699600E+00, -.59682500E-01, -.58252800E-01, -.38991400E+00, 0.20916300E+01, -.14296400E+00, -.34322300E-01, -.35469100E-01, 0.66109100E-01, -.26548300E+00, 0.18373600E+00, -.42482900E+00, 0.15623700E+00, 0.19091100E-01, 0.24544400E+00, 0.20213200E+00, 0.36818600E+00, -.24772900E-02, -.21446500E+00, -.12841600E+00, -.63162600E-01, -.48585700E-01, -.40645500E+00, -.63199700E+00, 0.76950300E+00, -.17814400E-01, -.18320900E+00, 0.13059700E+00, 0.18607800E-01, 0.82881200E-01, -.10806300E+00, 0.40822400E+00, 0.10725400E+01, 0.11973200E+00, 0.11304700E+00, -.23983800E+00, 0.20818500E+00, -.59025900E+00, -.31991900E-01, 0.87546300E-01, -.67824000E-02, 0.27780300E-01, -.69841200E-01, -.25784400E+00, 0.61016700E+00, -.18747000E+00, 0.26655900E+00, -.84291800E+00, 0.45646900E+02, -.22834800E+02, -.10562400E+02, -.22680700E+02, -.31455400E+01, 0.37960100E+01, -.12182300E+02, -.98365700E+01, -.24722600E+02, 0.34758100E+01, -.15968000E+02, -.12373800E+04, 0.64903900E+03, -.13968400E+04, 0.61940600E+03, 0.25252700E+03, 0.28492800E+03, -.12455400E+03, -.12142400E+03, 0.64605700E+03, 0.30275600E+03, 0.72003400E+03, -.22148800E+03, 0.10706600E+03, 0.19095900E+03, 0.11050300E+03, -.18728200E+03, 0.11557200E+03, 0.17586200E+03, 0.42417000E+02, -.56057400E+02, 0.18052000E+03, 0.48752100E+03, -.17043200E+03, 0.81439400E+02, 0.11001200E+03, 0.84695000E+02, -.30612700E+01, 0.66171300E+02, 0.83237700E+02, 0.10570800E+03, 0.14445600E+03, 0.32077700E+02, 0.91760500E+02, -.25552100E+03, 0.12729100E+03, 0.62896800E+03, 0.13870500E+03, -.17279700E+03, -.59186300E+01, 0.79876300E+02, -.19466900E+03, -.12933200E+03, 0.58652600E+02, 0.50876900E+03, -.29719300E+03, 0.13925800E+03, 0.12599900E+03, 0.14797700E+03, 0.34307400E+03, 0.29556200E+03, -.11836300E+03, -.78472100E+02, 0.15529700E+03, 0.18658900E+03, 0.34265000E+03, -.10661200E+04, 0.53224900E+03, 0.20851000E+03, 0.53177400E+03, 0.17683400E+03, -.14384100E+03, 0.39141700E+03, 0.44818000E+02, 0.23993700E+03, -.74330500E+02, 0.51598900E+03, -.11871000E+03, 0.57633100E+02, -.18714800E+02, 0.59123800E+02, -.73456000E+02, -.88968400E+02, 0.72715900E+02, 0.15327700E+03, 0.10080000E+03, -.10334300E+03, 0.14284100E+03, -.78978400E+03, 0.39570600E+03, 0.46249500E+03, 0.39459500E+03, -.18829600E+03, 0.68130000E+02, 0.21327200E+03, -.15810600E+03, 0.12626300E+03, 0.68755600E+02, 0.50770700E+03, -.91475500E+03, 0.47332800E+03, -.10923900E+04, 0.46202500E+03, 0.27653600E+03, 0.32414700E+03, -.17679900E+03, -.36510400E+01, 0.67199600E+03, 0.30376300E+03, 0.65674600E+03, -.57090500E+03, 0.28564100E+03, 0.65833700E+03, 0.28391200E+03, -.39270100E+03, 0.64170300E+02, 0.31521300E+03, -.12103200E+03, 0.23876200E+02, 0.59826400E+02, 0.69541100E+03, -.11038600E+03, 0.52351400E+02, 0.12656700E+03, 0.53055800E+02, -.87868300E+02, 0.39415800E+02, 0.11666100E+03, 0.23422900E+02, -.13061500E+02, 0.52885800E+02, -.39776200E+02, 0.18698800E+03, -.93143100E+02, 0.12653800E+03, -.94122100E+02, -.37492800E+02, 0.67042800E+01, -.60859200E+02, -.40182400E+02, -.88218700E+02, 0.65898700E+02, -.38071300E+02, -.48113300E+02, -.30482500E+02, 0.20411300E+02, -.43711800E+01, 0.27385300E+02, -.13836800E+02, 0.38940600E+02, -.14110100E+02, -.78265800E+01, -.31499300E+01, 0.23806800E+02, -.70935400E+02, -.12064600E+01, -.65767900E+01, 0.42643300E+02, 0.44298400E+02, 0.21281600E+02, 0.64759800E+01, 0.10012400E+03, 0.22182800E+02, 0.79223600E+01, -.43833300E+02, 0.42777000E+02, 0.33597000E+02, 0.16190800E+02, -.19568200E+02 },
        { 0.14695400E+01, 0.19091500E+01, 0.21933400E+00, 0.87837500E+00, 0.33437200E+00, 0.52010600E-01, 0.18634200E+01, 0.51724300E-01, 0.92398200E+00, -.13546100E+01, -.54138700E-01, 0.92747200E-01, 0.51309700E+00, -.15589300E+01, 0.60991900E+00, 0.96316900E-01, -.11997500E+00, -.45786200E+00, 0.46132900E-01, 0.27449400E+00, -.13257900E+00, -.37873800E-01, 0.98649400E-01, 0.71464600E-02, 0.29260200E+00, -.12887200E-01, 0.89402900E-01, -.14430000E+00, 0.29656800E+00, -.32022700E+00, 0.16052700E+00, -.82293400E-01, -.83056000E-01, 0.60638700E-01, -.15664600E+00, 0.80550500E-01, -.61680700E-01, 0.87583800E-01, 0.36602900E+00, 0.14090100E+00, 0.14909200E-03, -.24453900E-01, -.12021500E+00, -.11104900E+00, -.41796100E-01, 0.15939400E-01, -.17892300E+00, 0.50006200E-02, -.78015200E-02, 0.53141500E-01, -.48040100E-01, -.76695300E-01, 0.59144000E-01, -.29335800E-01, -.22764800E-01, 0.25396300E+00, -.83355300E-01, 0.84638600E-01, 0.46742500E-02, -.21561700E-01, -.12834300E+00, 0.77729400E+00, 0.41959000E+00, 0.12962300E+00, -.16151800E+00, 0.41354200E-02, -.20628000E+00, 0.93162200E-01, 0.52005100E-02, -.77203700E-02, -.63236700E-01, -.51762100E-01, -.20821100E-01, -.44852300E-01, 0.99054200E-01, 0.16192200E+00, -.84011500E-01, 0.95969400E-01, 0.41459900E-01, -.76234100E-01, -.43598300E-01, 0.29073100E-02, 0.35025800E-01, -.56817700E-01, 0.35457600E+00, 0.73907600E-01, -.33569500E+00, 0.22433000E-01, 0.33208100E+00, -.22990100E+00, 0.65457800E+00, 0.12209300E-02, 0.17133400E+00, 0.71172000E-02, -.22642200E+00, -.95511100E-01, -.25153300E-01, -.28008200E-01, -.98529600E-01, -.37287400E-01, 0.33166200E-01, 0.18060700E+00, -.79652600E-01, -.37508000E+00, 0.12301000E-02, -.19130000E+00, -.28802500E-01, -.19105200E+00, 0.28342600E-02, -.12244000E-01, 0.37562900E+00, -.92962100E-01, 0.14583400E-01, 0.65841800E-01, -.34965300E-01, -.48336000E-01, 0.51348600E+00, 0.10159800E+00, -.51340800E-01, 0.17092400E-01, 0.77233200E-01, 0.84639500E-01, -.15316100E-01, 0.66675000E-01, 0.37746300E-02, 0.39284900E-01, 0.30879000E-01, -.35772400E+00, 0.23056600E+00, 0.90042600E-02, 0.15817400E+00, -.61981500E-01, 0.15470100E+00, 0.36409300E+01, -.51736100E+00, -.13201700E-01, 0.18715400E+01, 0.86411400E+00, -.86816800E+00, 0.17029300E+00, -.10055100E+01, 0.14495800E+01, 0.31731700E+00, -.65481500E+02, 0.41949700E+02, -.15857100E+02, 0.32753400E+02, -.15483500E+02, -.43914100E+02, 0.12786200E+03, 0.61713600E+02, 0.93416200E+02, -.55267800E+02, 0.71427000E+02, -.22004000E+02, 0.98492300E+01, -.14260300E+02, 0.11037300E+02, 0.50838500E+02, -.15749200E+01, 0.44212900E+02, -.22080700E+02, -.42053700E+02, 0.19161900E+01, 0.12772800E+02, -.12901300E+02, 0.31217900E+01, 0.67766600E+02, 0.60763300E+01, 0.83977500E+01, -.30019700E+01, -.19827700E+02, 0.24222000E+01, -.82094500E+01, -.81546800E+01, 0.45203800E+01, -.12765800E+03, 0.63765400E+02, 0.11377200E+02, 0.63474500E+02, 0.13460500E+02, -.43726700E+02, 0.43074000E+02, 0.10267100E+02, 0.58474200E+02, -.40599000E+02, 0.66577600E+02, 0.17526900E+03, -.95583800E+02, -.70975800E+02, -.87645300E+02, -.25481200E+02, -.44095000E+02, -.93077800E+02, 0.19867200E+02, 0.32262300E+01, -.45768000E+02, -.81625500E+02, 0.31956000E+02, -.16017900E+02, -.13911500E+01, -.15876700E+02, -.45926700E+01, 0.81045700E+01, -.32749700E+00, -.79898100E+01, -.43761100E+02, 0.16536000E+02, 0.60992600E+01, -.32781700E+01, 0.19127100E+01, 0.14886600E+01, 0.16466300E+01, -.10363900E+02, 0.11881200E+02, 0.88978600E+00, -.19236000E+02, -.33199100E+02, 0.17000300E+02, -.69700700E+01, 0.15733500E+03, -.78757700E+02, -.96599200E+02, -.78632300E+02, -.25146500E+02, -.17434000E+02, -.19396600E+02, 0.30208400E+02, -.36820500E+02, -.20174600E+02, -.62592500E+02, 0.13792900E+03, -.65562900E+02, -.11122900E+03, -.69077600E+02, -.43390600E+02, -.87141100E+02, 0.80802500E+02, 0.71195400E+02, 0.85917100E+02, -.90261700E+02, -.34586700E+02, 0.13057300E+03, -.65298400E+02, -.71593000E+02, -.65148300E+02, -.24312700E+02, -.32275800E+02, -.15834500E+02, 0.22378300E+02, -.29261600E+02, -.29945700E+02, -.25022000E+02, 0.13748400E+02, -.70431300E+01, 0.24859300E+02, -.66663000E+01, 0.22770800E+02, 0.10591200E+02, 0.38504700E+01, 0.10731100E+02, -.45667800E+01, 0.66803700E+01, -.17404000E+02, -.56075400E+01, 0.36059100E+01, -.21104300E+02, 0.28695900E+01, 0.15219800E+02, -.10109400E+02, 0.15230700E+02, 0.11828700E+02, 0.25349200E+02, -.15089300E+02, 0.35624700E+01, 0.10850900E+01, -.31432300E+01, 0.32052200E+01, -.30217900E+00, 0.18785500E+00, 0.20019100E+01, 0.42569400E+01, 0.21538300E+01, -.28534300E+00, -.38477900E+00, 0.67675700E+00, 0.22953000E+01, -.14388500E+01, -.21164900E+01, 0.63658000E+01, -.13137200E+02, 0.12844800E+02, -.64545000E+00, 0.18811300E+02, 0.58412400E+01, -.99186400E+01, 0.16573900E+01, 0.32086200E+01, 0.23415500E+01, 0.15631100E+01, -.26941600E+01 },
        { -.74216200E+01, -.10976300E+02, -.12521300E+01, -.43632100E+01, -.14864200E+01, -.26620500E+01, -.90217000E+01, 0.18555500E+00, -.46759200E+01, 0.64994500E+01, 0.26561300E+00, -.36552000E+00, -.33345600E+01, 0.89058900E+01, -.27797500E+01, 0.29177800E+00, 0.57153300E+00, 0.21396500E+01, -.79054100E+00, -.23729300E+01, 0.16157200E+00, 0.38953900E+00, -.47429300E+00, -.17336000E+00, -.10537800E+01, 0.12455100E+00, -.24761000E+00, -.14528200E+00, -.67904400E+00, 0.25834900E+01, -.50651500E+00, 0.94983100E+00, 0.57597900E+00, -.17619700E+01, 0.12824600E+01, -.45419200E+00, 0.34075500E+00, -.40342200E+00, -.28203000E+01, -.14713400E+01, 0.33973400E+00, -.15369700E-01, -.24830700E+00, 0.21910400E+01, -.91876300E-01, -.71844200E-01, 0.59593700E+00, -.48462800E-01, 0.28720100E+00, -.17064200E+00, 0.20751900E+01, 0.21890200E+00, -.53488800E+00, -.10815000E+01, -.31523800E+00, -.79296800E+00, 0.65567300E+00, -.52954000E-01, -.41525300E-01, 0.55365000E+00, -.26811200E+00, -.46767000E+01, -.22737100E+01, -.15810400E+01, 0.16661900E+01, -.32138300E-01, 0.70804200E+00, -.52328900E+00, 0.30036300E+00, 0.17067800E+00, -.44197800E+00, 0.51047000E+00, 0.11624200E+01, 0.67349100E+00, 0.81650200E+00, -.12828600E+01, 0.35838700E+00, -.47187800E+00, -.19028000E+00, 0.58541600E+00, 0.22746800E+00, 0.19514800E+00, -.78864100E+00, 0.19736700E-02, -.21168800E+01, -.66823500E+00, 0.51906600E+01, -.14616600E+01, -.17078500E+01, 0.17344000E+01, -.12594100E+01, -.45215300E-01, -.49041500E+00, 0.33767000E+00, 0.61243700E-01, -.28909500E+00, 0.29525600E+00, 0.23101800E+00, 0.34198700E+00, -.20310300E+00, -.14962300E+00, -.14299400E+01, 0.17422000E+01, 0.12898200E+01, 0.11033700E+01, 0.82453800E-01, -.99154700E+00, 0.14596600E+01, 0.19469100E+01, 0.27248700E+00, -.39615600E+01, 0.29323700E+00, -.31500100E+00, -.80613600E+00, -.72849800E+00, 0.79666800E+00, 0.28371400E+01, -.29294800E+01, -.24031100E+00, -.70057700E+00, -.35245100E+00, -.82104100E+00, -.38699500E-01, -.13738300E+01, -.67366600E-01, 0.27574000E+00, -.94706400E-01, 0.22708900E+01, -.25639900E+01, 0.40345600E+00, -.88053700E+00, -.19334300E+01, -.13807900E+01, 0.16000500E-01, -.45227300E+02, 0.15249600E+00, 0.19851100E+02, -.99156300E+01, -.20995100E+02, -.12475900E+02, 0.18621800E+01, -.98409700E+00, -.33053600E+02, -.11630300E+03, 0.11493500E+03, 0.54452600E+04, 0.54805300E+02, -.54512200E+03, -.58936400E+03, -.14075500E+03, -.75223000E+02, -.15893400E+03, -.45150800E+03, 0.48330900E+03, 0.11646300E+04, -.58614200E+03, 0.16673000E+03, -.58309700E+03, 0.14659500E+04, 0.28277500E+02, -.92140200E+03, 0.18972500E+03, 0.12403600E+03, -.24448400E+03, 0.24073400E+03, 0.52683100E+03, -.25515400E+03, -.55846700E+03, -.25692600E+03, -.87417000E+02, 0.38177200E+03, 0.21068100E+03, 0.17461900E+03, -.20284000E+03, 0.28982100E+03, 0.23913800E+03, -.26933600E+02, 0.18742500E+02, 0.48278200E+03, 0.20843000E+02, -.28621900E+03, 0.25658700E+03, 0.19625300E+03, 0.35048100E+03, -.10345300E+03, 0.20962300E+03, 0.36910700E+03, -.17850200E+04, 0.88451700E+03, -.37691300E+04, 0.89454900E+03, 0.35807900E+03, 0.10099000E+04, 0.10703400E+04, 0.19187300E+03, -.17703300E+03, 0.98274700E+03, 0.83802500E+03, -.17103900E+04, 0.85125300E+03, -.74868700E+03, 0.85442800E+03, 0.12527800E+04, 0.43535700E+03, 0.97872100E+02, 0.14744600E+03, 0.62753700E+03, 0.28156900E+03, 0.82946500E+03, 0.79843600E+03, -.41097900E+03, -.79277400E+03, -.39908400E+03, -.11731800E+03, -.24059300E+03, -.21573200E+03, 0.33498800E+03, 0.15827900E+02, -.31244700E+03, 0.16609200E+03, -.14515400E+04, 0.72939900E+03, 0.56186500E+03, 0.72517500E+03, 0.27941100E+03, 0.19894300E+02, 0.42126900E+03, -.11293800E+03, 0.40022400E+03, 0.11208200E+03, 0.47520600E+03, -.17045200E+04, 0.85953900E+03, 0.29527400E+04, 0.84564000E+03, 0.21376800E+03, 0.37087700E+03, -.99485100E+02, -.23638500E+03, -.50481600E+03, 0.43315900E+03, 0.12082000E+04, -.17740200E+04, 0.89109600E+03, 0.27951700E+03, 0.88543100E+03, 0.31958200E+03, 0.35782800E+02, 0.74658600E+03, 0.27738300E+03, 0.64155700E+03, 0.10335900E+03, 0.75224400E+03, 0.88209500E+03, -.44806100E+03, -.31476600E+03, -.44363100E+03, -.95500400E+02, -.97647400E+02, -.19464700E+03, 0.12047800E+03, -.41253200E+03, -.13870900E+03, -.36203200E+03, 0.12465200E+04, -.62942400E+03, 0.24336600E+03, -.62417100E+03, -.18432200E+03, -.27051600E+02, -.26982300E+03, 0.33382900E+01, -.53966500E+03, 0.10102300E+02, -.63824100E+03, 0.64909000E+01, 0.37470600E+02, 0.11589100E+02, -.33228100E+02, -.40364400E+02, 0.58710200E+01, 0.19914000E+02, 0.78591400E+01, 0.16833500E+02, -.31154900E+02, 0.46949700E+02, 0.10877500E+03, 0.72288700E+01, -.15420600E+02, 0.14489000E+02, -.40409000E+03, -.72626700E+02, -.75675300E+02, -.67597500E+03, -.78927200E+02, 0.10783800E+03, -.15241000E+03, -.14976600E+03, 0.42098100E+02, -.28238200E+02, 0.25069000E+02 },
        { 0.14840400E+01, -.47152000E+00, -.75230700E-01, 0.68877200E+00, 0.10713700E+01, -.16887000E+01, 0.18983100E+01, -.20939500E+01, 0.90554200E+00, -.12393900E+01, -.88058400E-02, 0.10499600E+00, -.63231200E+00, -.33471400E+00, -.34088000E+00, -.47115500E+00, 0.65569600E+00, 0.33189700E-01, 0.40569000E-01, 0.17554200E-01, -.49493100E-01, -.41658900E-01, -.44169700E-02, -.84577500E-01, 0.73729000E+00, -.10345900E+00, 0.33743200E+00, 0.25142300E+00, -.24501800E+00, -.32882200E-01, -.48686900E-01, 0.27233300E-01, 0.13290800E+00, -.12636000E+00, 0.40353400E-01, -.24005400E-01, 0.27045200E+00, 0.36403300E+00, 0.16002900E+00, 0.27373300E+01, 0.47203100E-01, 0.82552900E-01, -.14749300E+00, -.19775200E-01, 0.78934900E-01, 0.43499200E-01, -.33449700E-01, -.26110900E-02, -.39955700E-01, 0.17145900E-01, 0.45696100E+00, -.11656500E+00, -.75646400E-01, -.26625600E+00, -.19899600E+00, 0.11751500E+00, -.37915400E-01, 0.50130700E-01, -.32427500E-01, 0.15531200E+00, -.16153100E+00, -.54339900E-01, 0.17030700E-01, -.10384500E+00, 0.12846100E+00, -.12892600E-01, -.69380800E-01, -.31358100E-01, 0.58414800E-01, -.35723300E-01, -.57972600E-01, -.20450700E-01, 0.13434000E+00, 0.10968500E-02, 0.12169100E+00, -.62687200E-01, 0.16783800E-01, -.55794800E-01, -.33806900E-01, 0.83423600E-01, -.27628700E-01, 0.13675300E-01, -.80302400E-01, -.53274800E-01, 0.11232300E+00, 0.50693800E-02, 0.20195300E+00, -.11080100E+00, 0.18277300E-01, 0.21043500E-01, 0.10642400E+00, -.27799400E-01, 0.35346100E-01, 0.17455600E-01, -.28518200E-01, -.21737500E+00, 0.46915300E-01, 0.78287300E-01, 0.14259500E-01, -.38985900E-01, -.26447000E-01, 0.21693100E-01, 0.10297700E-01, -.11452900E+00, 0.40644000E-01, -.39632400E-01, 0.22253700E-01, 0.71819100E-01, 0.74277500E-02, 0.20819700E-01, 0.41546900E-01, 0.35224500E-02, 0.15270400E-01, 0.13843100E-01, 0.36194200E-02, -.48096800E-01, -.13627700E+00, 0.10296700E+00, 0.61523500E-03, 0.23684400E-01, 0.15928100E-01, 0.28566200E-01, -.69975100E-02, 0.25142400E-01, -.23646600E-01, 0.11318300E-01, 0.23067000E-01, -.11158600E+00, 0.58141900E-01, 0.16080200E-01, 0.82554900E-01, -.57914000E-01, 0.32444700E-01, 0.66274100E-04, 0.87232100E-02, 0.87684500E+01, 0.78840600E+00, 0.78219000E+00, -.11769700E+01, -.48810000E+00, -.10814900E+01, 0.10913800E+01, -.51555400E+00, -.60804800E+02, 0.35476700E+02, 0.61797200E+01, 0.29966400E+02, 0.41257000E+00, -.37904200E+02, 0.69706700E+02, 0.34527900E+02, 0.59487700E+02, -.43032300E+02, 0.75926000E+02, -.14579600E+02, 0.66268500E+01, -.11910400E+02, 0.71468300E+01, 0.28737900E+02, -.22647700E+01, 0.30369700E+02, -.31538400E+01, -.16615800E+02, -.74071400E+00, -.35459600E+01, 0.88021300E+01, -.59468900E+01, 0.40255300E+02, -.46573400E+01, 0.53551200E+01, 0.48585100E+01, -.12826000E+02, -.18111800E+01, -.81660400E+01, 0.89487200E+00, -.87893900E+01, -.74845100E+02, 0.37503900E+02, 0.27312000E+02, 0.37624500E+02, 0.12266300E+02, -.19655700E+02, 0.30011900E+02, 0.11958700E+02, 0.33912000E+02, -.17495800E+02, 0.34407700E+02, 0.11514100E+03, -.61607400E+02, -.34896100E+02, -.57327900E+02, -.24885600E+02, -.11678700E+02, -.52373000E+02, 0.66949800E+01, -.10561400E+02, -.12009500E+02, -.64002500E+02, 0.12365800E+02, -.61908500E+01, -.15729800E+01, -.64347600E+01, 0.11989000E+01, 0.19554000E+01, 0.24070500E+01, -.54502600E+01, -.23431100E+02, 0.64426900E+01, -.13618700E+02, -.48799400E+01, 0.25736900E+01, 0.94803100E+00, 0.24395900E+01, -.48288700E+01, 0.52910800E+01, 0.88929900E+00, -.42729700E+01, -.97068300E+01, 0.84257500E+01, -.53331600E+01, 0.32568700E+02, -.16310900E+02, -.24154700E+02, -.16408300E+02, -.13148500E+02, -.70996800E+01, 0.11736600E+01, 0.45848900E+01, -.91804200E+01, -.74018400E+01, -.96245300E+01, 0.76208700E+02, -.35932900E+02, -.46678400E+02, -.38589300E+02, -.22083700E+02, -.49172300E+02, 0.36785500E+02, 0.42487500E+02, 0.41153400E+02, -.50379500E+02, -.68011800E+00, 0.17875900E+02, -.89645000E+01, 0.24105100E+01, -.93418100E+01, -.13111900E+02, -.15223300E+02, 0.11181800E+02, 0.66580000E+01, -.13946600E+01, -.12274800E+02, 0.12640800E+02, 0.50705000E+01, -.26496600E+01, 0.15942500E+02, -.31622100E+01, 0.84653800E+01, 0.98928500E+00, 0.89233500E+01, 0.90557500E+01, 0.26596700E+01, 0.19488400E-01, -.51713400E+01, 0.82677600E+01, -.38769200E+01, -.10006100E+02, -.43411300E+01, 0.77476800E+01, -.36801800E+01, 0.32649900E+01, 0.55598000E+01, 0.88558400E+01, -.63457100E+01, -.34073400E+01, 0.67624500E+00, -.28147000E+01, 0.13186700E+01, -.31850900E-01, -.20259300E-01, 0.11081600E+00, 0.24126100E+01, 0.78580500E+00, -.32814600E+00, -.58773600E-01, 0.97449700E+00, -.11073800E+02, -.23359800E+00, -.99475500E+00, -.45041700E+01, -.72706900E+01, 0.72414200E+01, -.13064200E+01, 0.62593700E+01, 0.28229900E+01, -.39062100E+01, -.33336300E+01, 0.13455100E+02, 0.25609700E+01, 0.21596900E+01, -.12940000E+01 },
        { 0.43201300E+00, -.23071700E+00, 0.32183000E-01, -.10134000E+00, -.26753400E+00, -.17908600E+01, 0.14462400E+01, -.46824700E+00, 0.61078800E+00, -.94852600E+00, -.26651800E-01, 0.12833900E+00, -.35148900E+00, 0.40401100E+00, 0.13445200E+01, 0.73503900E+00, 0.86938700E+00, 0.50394900E+00, -.42490900E+00, 0.11525300E+01, -.76180100E+00, 0.15321600E-01, 0.10283400E-01, -.92534600E-01, 0.18231100E+00, 0.18507500E-01, 0.48364900E-01, 0.51842300E+00, -.16109900E+00, -.66795100E-01, 0.20646300E+00, 0.81685000E-01, 0.50861100E+00, 0.33420300E+00, 0.75469100E-01, 0.37504900E-01, -.60986400E-01, 0.14828400E+00, 0.61192000E+00, -.28349100E+00, 0.42641000E-01, -.67816600E-01, -.18524800E+00, -.17894000E+00, -.25910600E+00, -.66204300E-01, -.13834500E+00, 0.48002600E-03, -.38940100E-01, 0.75289300E-01, -.72463200E-01, -.61242400E-01, 0.23929400E+00, 0.28730900E+00, 0.55181000E+00, 0.48725300E-01, 0.20880600E+00, -.17515900E-01, -.87117400E-02, -.93484400E-01, 0.56486200E+00, 0.54716000E-01, -.11411500E+00, 0.28922900E+00, -.29578700E+00, -.22587600E-01, -.75337700E-01, -.24821100E-01, -.99178300E-01, 0.26005000E-02, -.63272000E-01, 0.17481100E+00, 0.43113500E-01, -.22698700E+00, -.17619700E+00, 0.30934400E+00, -.13396300E+00, -.33479900E+00, -.14324200E+00, 0.52299900E+00, -.35352300E-01, -.78355300E-01, 0.33366100E+00, -.84488100E-01, 0.21412500E+00, 0.10548100E+00, 0.18468700E+00, 0.11235000E-01, 0.12424700E+00, -.14567700E+00, 0.32631600E-02, -.32126500E-02, 0.23006900E-01, -.22186200E-01, 0.26379800E+00, -.20689600E+00, 0.85610900E-01, 0.20501500E+00, 0.21067300E+00, 0.39961400E-01, -.11042200E-01, 0.17781800E+00, 0.10698100E+00, -.20658800E+00, 0.99052600E-01, 0.51979200E-01, -.30023500E-01, 0.63080200E-01, 0.10471400E+00, 0.66290600E-01, -.24106100E-01, 0.48524200E-02, 0.32768600E-01, -.69353700E-01, -.96941200E-01, -.47078200E+00, -.37645500E+00, 0.40042200E-01, 0.26303700E-02, 0.18023200E+00, -.68170500E-01, -.16905700E+00, 0.39826800E-02, 0.10680000E+00, 0.54820700E-02, 0.95126900E-02, 0.22297300E-01, 0.14333300E+00, 0.65757600E-01, -.24774500E-01, -.60307800E-01, 0.57638800E+00, -.36730700E+00, -.27437000E-03, -.30883000E-01, -.18245300E-03, -.37721700E+01, 0.17643900E+00, 0.49807500E+01, 0.10128800E+01, -.35929300E+00, -.11703600E+01, 0.12359100E+01, 0.25878200E+02, -.10597700E+01, -.51364600E+03, -.12670300E+02, -.31717900E+02, -.12590300E+03, 0.71739800E+02, 0.17201500E+02, -.10066500E+03, -.77768200E+02, -.58603400E+02, -.10007800E+03, 0.49799700E+02, 0.26628300E+02, 0.50078200E+02, -.29634400E+02, 0.56982600E+02, 0.11079500E+03, -.20134400E+02, -.56815500E+02, 0.10319100E+03, 0.83555500E+02, 0.11493200E+03, -.58625200E+02, 0.11834800E+03, -.58089300E+02, 0.46450500E+02, 0.62639200E+02, -.90638200E+02, 0.28925600E+01, -.60475900E+01, 0.51012100E+02, -.89840500E+02, 0.10470800E+03, -.52824600E+02, -.64588600E+02, -.51613200E+02, -.55290100E+02, 0.13654100E+02, -.41984100E+02, -.62242400E+02, -.87299000E+02, 0.43088200E+02, 0.36158600E+01, -.27337600E+03, 0.13127700E+03, 0.38013500E+03, 0.13650800E+03, 0.89869200E+02, 0.10532200E+03, -.91199900E+02, 0.27895700E+01, 0.18983700E+03, 0.52662800E+02, 0.14393600E+03, -.77613700E+02, 0.38447300E+02, 0.17111400E+03, 0.38778800E+02, -.17316500E+02, -.31181100E+02, 0.95710700E+02, 0.37100800E+02, -.36572300E+00, -.86917800E+01, -.85898600E+01, 0.13293100E+02, -.65141400E+01, -.53497800E+02, -.66713100E+01, 0.23258900E+01, 0.21387100E+01, 0.25411300E+02, 0.44388800E+02, 0.31382700E+02, -.48678200E+01, -.20338700E+02, 0.97820200E+02, -.48793300E+02, -.27935100E+02, -.48887300E+02, -.11524400E+02, 0.19344500E+02, -.30849200E+02, -.98858200E+01, -.38581700E+02, 0.99888100E+01, 0.26208900E+02, -.39863700E+02, 0.26977500E+02, -.22388700E+03, 0.20691200E+02, -.15458800E+02, -.72888300E+02, 0.40553900E+02, 0.22982600E+02, -.44486900E+02, -.48549800E+02, -.48167700E+01, 0.27881000E+03, -.13893300E+03, -.44705700E+02, -.13939300E+03, -.65665500E+02, 0.24726900E+02, -.80899400E+02, -.62006200E+02, -.12245100E+03, 0.19858700E+02, 0.32945700E+02, -.78819100E+02, 0.38842300E+02, 0.40920700E+02, 0.39454900E+02, -.30505300E+01, 0.12392200E+02, -.11354400E+02, -.50604500E+02, 0.24575600E+02, 0.13876600E+02, 0.62267200E+02, -.36225800E+02, 0.18121400E+02, -.89478300E+01, 0.18136900E+02, 0.40647100E+02, 0.66401500E+02, -.46277000E+02, -.82609200E+02, -.48199500E+02, 0.67067300E+02, 0.64215700E+01, -.20616200E+01, 0.16102600E+01, -.78705800E+01, 0.22442400E+01, 0.98983100E+01, -.61796600E+01, 0.98608400E+00, -.18640900E+01, -.25477100E+01, 0.57229700E+01, -.44640100E+01, -.18761100E+02, -.35052000E+00, 0.34582300E+01, -.31057400E+01, 0.28415200E+02, 0.11244500E+02, 0.10883800E+02, 0.37902500E+02, 0.74301500E+01, 0.10046400E+02, 0.14653000E+02, 0.15386900E+02, -.16557200E+01, 0.17813300E+01, 0.18739100E+01 },
        { -.25152000E+01, 0.24828100E+01, 0.64971600E+00, -.11573200E+01, -.12839700E+00, 0.42798300E+00, -.14522200E+01, -.22512800E+00, -.42759800E+00, 0.12113800E+01, 0.10466400E+00, -.10258700E-01, 0.10668500E+01, -.36920900E+01, 0.10103800E+01, -.15041800E+01, -.49657300E+00, 0.59676500E+00, -.32642100E+00, -.14544100E+01, -.34316100E+00, 0.23133600E+00, 0.12107400E+00, 0.19503900E+00, -.31912700E+00, 0.14073100E-01, 0.89100500E+00, 0.42246300E+00, -.88310600E+00, 0.13929600E+01, -.10826400E+01, -.17168100E+00, -.32934200E+00, -.47483300E+00, -.12586200E+00, -.38146800E+00, 0.24370800E-01, -.51664300E+00, 0.85130200E+00, -.38040300E+01, -.13274900E+00, -.64888400E-01, 0.50818400E+00, 0.40178900E+00, -.27009700E-01, 0.45871900E-01, 0.48457200E+00, 0.11787000E-01, -.64238700E-01, -.22001700E+00, 0.41172200E+00, 0.26903500E+00, -.23060000E+00, -.73240000E+00, -.13823600E+01, 0.84165400E+00, -.51678500E+00, 0.15871700E+00, -.13650100E-01, -.30395900E+00, -.59807100E+00, -.16589000E+01, -.10590700E+01, -.46754600E-02, 0.19183400E+00, 0.17194700E+00, 0.11348600E+01, 0.19254600E-01, 0.32257700E+00, 0.36122000E-02, 0.53542700E+00, -.10065000E+00, -.52203900E+00, -.52188100E-01, -.77830800E-01, -.16983700E+00, 0.33454400E+00, 0.21257200E+00, 0.47084500E-01, 0.55024100E+00, 0.76695900E-01, -.28498700E+00, -.93272700E+00, 0.18766100E+00, 0.78644000E+00, -.16698300E-01, 0.19429600E+01, -.69508600E+00, 0.68282900E+00, -.45956500E-01, 0.78864900E+00, -.39556200E-02, -.47556700E-01, 0.62279200E+00, 0.38672000E+00, -.84760800E+00, 0.48460900E+00, 0.13625200E+00, 0.29171300E-02, 0.38917100E-01, 0.23738700E+00, -.31125100E+00, -.29243900E+00, 0.10215100E+01, -.11348400E+00, 0.71393100E+00, -.27814700E+00, 0.10634300E+00, -.21005800E+01, -.31576400E+00, 0.66279600E+00, -.13769900E+00, 0.97376100E-02, 0.36785700E+00, -.98578400E-01, -.18020300E+00, -.76962400E+00, 0.38677700E+00, 0.15938800E+00, 0.47093000E+00, 0.38734200E+00, 0.25581900E+00, -.65444600E-01, -.43485600E-01, -.74701000E-01, -.48212900E+00, 0.29688900E+00, 0.26163200E+00, -.88584200E+00, -.36866000E+00, 0.14325000E+01, -.55624100E+00, 0.18618900E+00, -.46807100E-05, -.18527400E+00, 0.16648600E-01, 0.32471200E-01, 0.11667100E+02, -.27597500E+02, -.19222500E+02, -.19966100E+02, 0.15374400E+02, -.27180500E+02, -.13470900E+04, 0.70975200E+03, -.26126300E+03, 0.67206200E+03, 0.14355200E+03, 0.35404400E+03, 0.26964600E+03, 0.14983200E+02, 0.66257400E+03, 0.24998500E+03, 0.11225800E+04, -.56885700E+03, 0.28015800E+03, 0.74476300E+02, 0.28391700E+03, -.18678700E+03, -.31146400E+03, 0.26036700E+03, 0.25489400E+02, 0.23965900E+03, -.20962100E+03, 0.55683500E+03, -.27829700E+03, 0.13809800E+03, -.11446400E+02, 0.14060900E+03, -.15339300E+03, -.32054000E+03, 0.12428400E+03, -.17106600E+03, 0.21591400E+03, -.24070900E+03, 0.39749400E+03, 0.25435800E+03, -.12646400E+03, -.25889600E+03, -.11657500E+03, -.22772000E+03, 0.12069400E+03, 0.14148400E+03, 0.31669200E+03, -.67604100E+02, 0.10344200E+03, -.24199000E+02, 0.46960000E+03, -.25382600E+03, -.41204600E+03, -.23405100E+03, 0.48792500E+02, -.28547500E+03, -.44536800E+01, 0.19998900E+03, -.59162300E+02, -.24667700E+03, -.37456000E+03, -.12089100E+04, 0.60295500E+03, -.49650300E+02, 0.60345300E+03, 0.23600300E+03, -.24301200E+03, 0.36076800E+03, 0.31012000E+02, 0.32175700E+03, -.15913100E+03, 0.25683600E+03, 0.26520000E+03, -.13544900E+03, -.19429500E+03, -.13265100E+03, -.10400000E+03, -.82208100E+02, -.10252400E+03, 0.21694400E+03, 0.12337400E+03, -.96469500E+02, 0.16676000E+03, -.18753800E+04, 0.93872100E+03, 0.67960400E+03, 0.93724500E+03, 0.69081100E+02, 0.13583400E+03, 0.45215000E+03, -.24233300E+03, 0.54191500E+03, 0.14906400E+03, 0.11365100E+04, -.82092400E+03, 0.42218600E+03, -.39703400E+03, 0.40939300E+03, 0.14647900E+03, 0.22019600E+03, 0.13725200E+03, 0.25780200E+03, 0.46591400E+03, 0.15550500E+03, 0.74815800E+03, -.14986400E+04, 0.74937600E+03, 0.35721000E+03, 0.74778300E+03, -.80625000E+02, 0.24488400E+03, 0.62292100E+03, 0.11498200E+03, 0.58840400E+03, 0.23079400E+03, 0.12230900E+04, 0.17123000E+03, -.88836400E+02, 0.13105600E+03, -.87936800E+02, -.64850600E+02, -.13496000E+03, 0.11306100E+03, 0.11532000E+03, 0.19301800E+02, -.13303800E+03, 0.70282500E+01, 0.50869700E+03, -.25434000E+03, 0.83410100E+02, -.25510400E+03, -.68642600E+02, 0.10165400E+03, -.22849100E+03, -.17474700E+03, -.26502100E+03, 0.12836300E+03, -.33677200E+03, 0.18328700E+02, -.25450700E+02, 0.12214400E+01, -.17922900E+01, -.10456000E+02, -.18081400E+01, 0.25687600E+02, 0.49952500E+01, -.14044400E+02, -.81384300E+01, 0.35649400E+02, -.51179100E+01, 0.12185500E+02, -.71570800E+01, 0.88709300E+02, -.97874100E+01, 0.28254800E+02, -.14049200E+02, 0.10424700E+03, 0.34636300E+01, 0.27783900E+02, -.50211500E+02, -.16802200E+02, 0.11387500E+02, 0.65471500E+02, 0.29213400E+02 },
        { 0.49977700E+01, -.21670900E+01, -.79715600E+00, 0.11910200E+01, 0.73908600E+00, 0.61535000E+00, 0.26657800E+01, 0.19953700E+01, 0.11417700E+01, -.27795600E+01, -.64647600E-01, 0.51296400E-01, 0.30553800E+01, -.38025200E+01, 0.39909800E+01, 0.24047300E+01, -.68048300E-01, 0.57447100E-01, -.11711400E+01, -.77721800E+00, -.88010700E+00, 0.18843800E-01, -.65014400E-01, 0.66375700E-01, 0.11526800E+01, -.81973500E-01, 0.69732600E+00, 0.19186500E+00, -.70606100E+00, 0.17106700E-01, -.62191700E+00, -.11949000E+01, -.25258000E+00, -.32445600E+00, 0.52380800E+00, -.68163100E+00, 0.32258200E+00, -.70110200E+00, 0.70622100E+00, -.86480700E+00, -.12838500E+00, -.26594300E+00, 0.13300000E+01, -.26021300E+00, -.66852600E+00, -.64082500E-01, 0.70554000E+00, -.21948200E-02, -.14133600E-01, -.62232900E+00, -.86873600E+00, 0.57371600E+00, -.41796900E+00, 0.66505300E+00, -.99563900E+00, -.13111200E+01, -.17787500E+00, -.18052600E+00, -.14248300E-01, 0.39025100E+00, -.58903000E+00, -.10090500E+01, -.12190800E+00, -.14670900E+01, -.48458000E-01, -.25812000E+00, -.13263600E+01, -.84970800E+00, -.16305800E+00, -.91475200E-01, 0.12438800E+01, -.32514600E+00, -.38484300E+00, -.35277000E+00, -.35442500E+00, -.11473700E+01, 0.40752400E+00, -.12809100E+01, -.29034700E+00, -.65639200E+00, -.66001000E-02, 0.10883100E+00, 0.12204200E+01, -.37513500E+00, -.18933100E+01, -.16764800E-01, -.16349100E+01, 0.43034400E+00, -.32957900E+01, 0.32986000E+00, -.50554400E+01, -.40614100E-01, -.54916700E-01, -.53046800E+00, -.78554400E-01, 0.17829100E+01, -.40910500E+00, 0.38010400E+00, 0.38065100E+00, -.88829300E-02, -.30979900E+00, 0.12812400E+00, 0.75730300E+00, 0.71729000E+00, -.24938300E+00, 0.84750900E+00, 0.13906000E+00, 0.64052800E+00, 0.20692700E+01, 0.34966900E+00, -.45800900E+00, 0.14148900E+00, -.37257700E+00, -.42686000E+00, -.96705200E-01, 0.31130900E+00, -.17813000E+01, -.71384800E+00, -.33559700E+00, 0.30777700E+00, 0.29568500E+00, 0.13334200E+00, -.26194900E+00, -.93021800E+00, 0.82638600E-02, 0.35303900E+00, -.18776400E-01, 0.68853500E+00, -.11531900E+01, 0.40273200E+00, -.18430400E+01, -.97067300E+00, -.15467000E+01, -.17774000E-01, -.14153900E+00, 0.21060800E-02, 0.32271300E+01, -.13482000E+01, -.58664800E+02, -.42672700E+02, -.19430200E+02, 0.14943100E+02, -.50793900E+02, -.32955400E+04, 0.16362200E+04, 0.83045400E+03, 0.16428900E+04, 0.65634900E+03, 0.18729900E+04, -.71449800E+03, -.46594500E+03, 0.15302500E+04, 0.14439500E+04, 0.24055800E+04, -.10424600E+04, 0.51741600E+03, 0.98609600E+02, 0.52010700E+03, -.87385000E+03, -.87434100E+03, -.17561100E+03, 0.33339600E+03, 0.12800600E+04, -.10283600E+04, 0.10709500E+04, -.12631500E+04, 0.64917200E+03, -.73181700E+03, 0.63821800E+03, -.57189900E+03, -.10023900E+04, 0.89230600E+03, -.35959400E+03, 0.50083400E+03, -.80755400E+03, 0.12873100E+04, 0.98794200E+03, -.48896200E+03, -.27784800E+03, -.48448100E+03, -.10521500E+03, 0.36756900E+03, 0.49025100E+02, 0.59339400E+03, -.18316700E+03, 0.17169600E+03, -.48864700E+03, 0.11511000E+04, -.54707600E+03, -.17291400E+04, -.57263300E+03, 0.16679600E+03, -.63901200E+03, 0.10010200E+04, 0.64863000E+02, -.11146300E+04, -.35898400E+03, -.74530400E+03, -.16126800E+04, 0.80479900E+03, -.10467900E+04, 0.80523700E+03, 0.30004300E+03, -.27174000E+03, 0.11729600E+03, 0.35718900E+00, 0.75847700E+03, -.33934100E+03, 0.83465000E+03, 0.42395200E+03, -.22061200E+03, -.64171200E+02, -.21179200E+03, -.17764400E+03, -.27779800E+03, -.19680000E+03, 0.33212900E+03, 0.41045700E+03, -.30721700E+03, 0.60793700E+03, -.37816600E+04, 0.18937400E+04, 0.13516700E+04, 0.18899800E+04, 0.21186100E+03, 0.29569700E+03, 0.86702000E+03, -.24241100E+03, 0.10454900E+04, 0.41823800E+03, 0.19009000E+04, -.29558800E+04, 0.14647000E+04, 0.17295200E+03, 0.14685800E+04, 0.81318000E+03, 0.15728200E+04, -.46817200E+03, -.23091700E+03, 0.79501500E+03, 0.12955800E+04, 0.19164700E+04, -.37864900E+04, 0.18939300E+04, 0.58694600E+03, 0.18909700E+04, 0.27884700E+03, 0.55545800E+03, 0.13023400E+04, 0.64293900E+03, 0.14043000E+04, 0.57238500E+03, 0.17687900E+04, 0.25985000E+03, -.13382300E+03, -.21941000E+03, -.13363700E+03, -.16891600E+03, -.21737700E+03, 0.20972600E+03, 0.27951000E+03, 0.44495700E+02, -.23986900E+03, -.16520200E+03, 0.64072800E+03, -.32321200E+03, 0.57198400E+03, -.32166800E+03, -.33179000E+03, 0.53293000E+02, -.33519900E+03, -.18149500E+03, -.41514300E+03, 0.80328700E+02, -.45271400E+03, 0.71344200E+01, -.41542300E+02, 0.21025300E+02, -.17994600E+02, -.48228800E+02, 0.12756100E+02, 0.12285300E+02, -.36750300E+01, 0.10100800E+02, -.30998800E+02, 0.49375100E+02, 0.57124100E+02, 0.45820400E+02, -.20760700E+01, 0.21572900E+03, -.91658800E+02, -.61140000E+01, -.61324500E+02, 0.39452600E+02, -.67113500E+02, 0.84859400E+02, -.46502200E+02, -.13818400E+03, -.38293200E+02, 0.65918100E+02, 0.62919000E+02 },
        { 0.18678400E+00, -.27031200E+00, -.28300800E-01, -.96670500E-01, -.63685200E-01, -.11049900E+00, 0.59679500E+00, -.51577200E+00, 0.25519900E+00, -.68910900E-01, -.10775600E-03, 0.16983100E-01, -.35338200E-01, 0.86818100E-02, -.10030200E+00, 0.34272900E-01, 0.41352500E-01, -.20622800E+00, 0.79862900E-01, -.61422100E-01, -.17340400E-01, -.66112200E-02, 0.12503200E-01, -.13862900E-01, 0.17327700E+00, 0.52663000E-03, -.16307900E-01, -.62282500E-01, 0.27164200E-01, -.45364300E-01, 0.39203200E-01, 0.39789600E-01, 0.15906400E-03, -.47602800E-01, 0.57916800E-02, -.49898800E-02, -.18813000E-02, 0.25803600E-01, 0.71746100E-01, -.27253000E-01, 0.21497800E-02, 0.11748700E-02, 0.56806100E-01, 0.57588200E-02, -.50772400E-01, -.82428200E-02, 0.38157900E-01, -.50975300E-03, -.19468200E-02, -.99415300E-02, 0.85505500E-01, 0.61697900E-02, -.18152000E-01, -.32450300E-01, -.88176200E-02, 0.19447400E-01, -.53325000E-01, -.10186400E-01, -.17129400E-02, 0.26286500E-01, -.16673400E-01, -.64270600E-01, -.17527600E-01, -.21122000E-01, 0.22060100E-01, -.48003900E-02, 0.14474900E-01, -.24721200E-01, -.46605700E-02, -.31477400E-02, -.68094800E-01, 0.11337600E-01, -.56113800E-02, -.12741300E-01, -.10796600E-01, -.84022900E-02, -.10317500E-01, -.74181800E-01, -.21604700E-01, 0.51469400E-01, -.36419100E-02, -.23697500E-02, 0.30796000E-01, -.15839900E-01, 0.79741300E-01, 0.23084700E-01, 0.67471500E-01, -.35028400E-01, -.24277500E-01, 0.61722200E-01, -.11885000E-01, -.13316700E-02, -.14061500E-01, -.63129200E-01, 0.29844200E-01, 0.47042400E-01, -.21711400E-01, 0.43496500E-02, 0.62976000E-02, -.68529600E-02, -.13630400E-01, 0.47797900E-01, 0.19475900E-01, -.54497400E-01, 0.98215900E-02, 0.11334500E-01, 0.48647800E-01, 0.56126800E-01, 0.83240400E-02, 0.13969900E-01, -.15464500E-01, 0.37562300E-02, 0.80915400E-03, -.91439400E-03, 0.54125900E-01, -.31801800E-01, -.82041400E-01, 0.31494600E-01, -.46378400E-02, -.80945200E-02, 0.13284000E-01, 0.35792400E-01, 0.35776400E-02, -.20106000E-01, 0.15734900E-02, -.35745600E-01, 0.97062500E-03, 0.28359500E-01, -.21770400E-01, 0.32793100E-02, -.79637100E-01, 0.25834000E-01, -.76272400E-01, 0.54616400E-03, -.59325500E-02, 0.78710500E-03, 0.86159000E-01, -.26090900E-01, -.43236200E-01, -.24436700E+01, -.13186500E+01, 0.92430600E+00, -.30598300E+01, -.20837800E+03, 0.10155500E+03, 0.49234000E+02, 0.10396500E+03, 0.38323800E+02, 0.11230300E+03, -.41684800E+02, -.22722100E+02, 0.10601400E+03, 0.86241400E+02, 0.13918200E+03, -.45858500E+02, 0.22765500E+02, 0.10004300E+02, 0.22853800E+02, -.53023400E+02, -.40488700E+02, -.16019500E+02, 0.51667500E+01, 0.55012300E+02, -.47614500E+02, 0.88486900E+02, -.74540300E+02, 0.38377800E+02, -.59293700E+02, 0.37650500E+02, -.36764700E+02, -.59845800E+02, 0.50087900E+02, -.17058100E+02, 0.29814600E+02, -.47181900E+02, 0.89340300E+02, 0.29172400E+02, -.14383200E+02, -.95531600E+01, -.13457400E+02, -.17651100E+02, 0.18111200E+02, 0.16754700E+02, 0.46694300E+02, 0.32001100E+01, 0.65970200E+01, 0.81078000E+01, 0.72333500E+02, -.33330100E+02, -.11742400E+03, -.36042300E+02, 0.14108500E+02, -.39744600E+02, 0.52353600E+02, 0.13336900E+02, -.68672900E+02, -.23158800E+02, -.40305800E+02, -.12136700E+03, 0.60580800E+02, -.37409200E+02, 0.60549000E+02, 0.14269400E+02, -.19399400E+02, 0.21017000E+02, -.14448700E+01, 0.43131800E+02, -.21209100E+02, 0.54431000E+02, 0.12359500E+02, -.67027400E+01, 0.27041700E+01, -.61827400E+01, -.87827900E+01, -.11205600E+02, -.12696300E+02, 0.12565700E+02, 0.19990300E+02, -.12782100E+02, 0.49357300E+02, -.19936800E+03, 0.99816100E+02, 0.62529200E+02, 0.99619600E+02, 0.53766400E+01, 0.78304400E+01, 0.53946000E+02, -.75762600E+01, 0.65201200E+02, 0.15783900E+02, 0.11429800E+03, -.17968800E+03, 0.88219200E+02, 0.29145100E+01, 0.89594000E+02, 0.49556700E+02, 0.93555300E+02, -.29031400E+02, -.47508500E+01, 0.61209600E+02, 0.77008300E+02, 0.11143100E+03, -.20211700E+03, 0.10092900E+03, 0.16788000E+02, 0.10084500E+03, -.11476800E+01, 0.17047800E+02, 0.88433000E+02, 0.51278500E+02, 0.93000000E+02, 0.19425500E+02, 0.12665600E+03, 0.24131300E+02, -.12329400E+02, -.17047100E+02, -.12393000E+02, -.10280400E+02, -.10439000E+02, 0.90022300E+01, 0.18932700E+02, -.48215300E+00, -.12544200E+02, -.11525900E+02, 0.46351500E+02, -.23445600E+02, 0.28566000E+02, -.23283800E+02, -.26647800E+02, 0.37056500E+01, -.16169200E+02, -.89108100E+01, -.26225000E+02, 0.53660900E+01, -.28604800E+02, 0.39835000E+00, -.19006100E+01, 0.91259100E+00, -.10073900E+01, -.28933900E+01, 0.83514200E+00, 0.23820300E+01, 0.20895900E-01, 0.40514100E+00, -.20604600E+01, 0.36068600E+01, 0.44457600E+01, 0.21079600E+01, -.16739600E+00, 0.14062700E+02, -.33061300E+01, -.25505100E+01, -.44164200E+01, 0.24739800E+01, -.22174700E+01, 0.36602800E+01, -.68923300E+01, -.93625800E+01, -.61013700E+00, 0.34689300E+01, 0.37605200E+01 },
        { 0.21604200E+01, 0.76415900E+00, 0.24820300E-01, 0.68435300E+00, 0.14391700E+01, 0.82867200E+00, 0.11205500E+01, -.64756000E+00, 0.10496800E+01, -.12351200E+01, -.79829700E-01, 0.11842600E+00, -.54500900E+00, -.25957400E+00, -.84324100E+00, -.14250900E+01, 0.24613400E+00, -.14066800E+00, 0.65283900E+00, -.66070100E+00, -.20687100E+00, -.69540600E-02, -.15916800E+00, -.20573000E+00, 0.55978300E+00, -.63273900E-02, 0.31222400E+00, -.50176300E+00, 0.57261600E+00, -.11221000E+01, 0.37850700E+00, -.16510100E+00, 0.27689300E-01, 0.25992100E+00, -.99345500E-01, 0.34955700E+00, -.92429700E-01, 0.22684000E+00, -.13070400E+00, 0.34844000E+01, -.52034700E-01, 0.97867600E-01, -.38664100E+00, -.47259400E+00, 0.14582100E+00, -.68161400E-01, -.18052000E+00, 0.56419800E-02, -.27542600E-01, 0.43933800E+00, -.22060300E+00, -.24263500E+00, -.37102500E-01, -.42307600E+00, 0.56327300E+00, 0.40080500E+00, 0.23290000E+00, -.15767800E-02, 0.46229100E-01, 0.27792700E+00, -.30806100E+00, 0.19678400E+00, 0.45905000E-01, -.35179400E-01, 0.34668800E+00, -.11621300E+00, -.12442700E+00, -.48668300E-01, -.41663500E-01, -.28371300E-01, -.48729800E+00, -.84183900E-01, 0.54389900E+00, -.21858100E+00, -.12176100E+00, 0.52974600E+00, 0.39620200E-02, -.58252200E+00, -.23613400E+00, 0.19943500E+00, -.10771600E+00, -.15065000E+00, 0.65028400E+00, -.15618600E-01, 0.20604200E+00, 0.50909800E+00, 0.26811200E+00, -.16353800E-01, -.16427800E+01, -.44151100E+00, -.53129600E+00, -.32025000E-01, -.13577000E+00, -.42729800E-01, -.42941700E+00, 0.74421800E+00, -.22061200E+00, -.86623900E-01, -.58827300E+00, 0.96225500E-01, -.15904400E-02, 0.18977800E+00, -.19397200E+00, 0.89368000E-01, -.10644000E+00, 0.24232300E+00, 0.30166000E+00, 0.53695900E-01, 0.10158300E+01, 0.11048300E+00, -.91681000E+00, 0.19575400E+00, -.59234800E-01, -.37933500E+00, 0.37108100E+00, 0.66399700E+00, -.11838200E+01, -.29997400E+00, -.37682900E-01, 0.46923400E+00, 0.26499700E+00, -.31146200E+00, -.12397100E+00, -.33418000E+00, -.14030000E-02, 0.37020400E+00, -.93895200E-01, -.20445400E+00, -.28388000E+00, -.13911700E+00, -.32510100E+00, -.18729200E+01, -.45219800E+00, -.77782000E-02, -.26805900E-01, 0.93540300E-02, -.39550700E+00, 0.44640700E+00, 0.76452100E-01, 0.92028000E+00, 0.10918100E+02, -.31403400E+01, 0.15655600E+02, 0.45489100E+03, -.23919900E+03, -.59021900E+03, -.22715100E+03, -.11666400E+02, -.11236300E+03, -.18690000E+03, 0.77272800E+02, -.56142900E+02, -.66071800E+02, -.25189500E+03, 0.21502300E+03, -.10725500E+03, -.74420800E+02, -.10743100E+03, -.10934200E+03, 0.23694600E+03, -.21675500E+02, -.57748000E+01, -.25751100E+03, 0.19141300E+03, -.67976300E+02, 0.12678800E+03, -.62507500E+02, -.48033400E+02, -.63835600E+02, 0.61435600E+02, 0.15853200E+03, 0.24648100E+02, 0.15224200E+03, -.84598500E+02, 0.94658100E+02, -.13548700E+03, 0.14393200E+03, -.72020900E+02, -.93975500E+02, -.72454100E+02, 0.19122400E+03, 0.15339800E+03, -.17882800E+03, -.15578800E+03, -.24021400E+03, 0.17765700E+03, 0.13084200E+03, -.64425200E+02, 0.42771700E+02, 0.48356400E+03, 0.32045000E+02, -.17386900E+02, 0.70003900E+02, 0.81712700E+01, -.69278100E+02, -.76773800E+02, 0.35647900E+02, 0.11408600E+03, 0.22436300E+03, -.11205100E+03, 0.28627600E+03, -.11206600E+03, -.18585100E+03, 0.55542500E+02, -.97186800E+02, -.67968200E+02, -.15192400E+03, 0.32006700E+02, 0.54936500E+02, -.15225200E+03, 0.75778000E+02, 0.10465800E+03, 0.76119000E+02, -.39602000E+01, 0.12281900E+03, 0.50872300E+02, -.30073400E+02, 0.44906100E+02, 0.10294800E+03, 0.46235900E+02, -.40438300E+03, 0.20245100E+03, 0.27900100E+03, 0.20225800E+03, -.17863300E+02, 0.18956400E+03, -.54337900E+02, -.20975400E+03, -.53547000E+02, 0.20800200E+03, 0.76919500E+02, 0.36486400E+03, -.18692800E+03, -.27399700E+03, -.18199400E+03, -.89137600E+02, -.11967200E+03, -.79973100E+02, 0.23662200E+02, -.26850200E+02, -.95426800E+02, -.16972300E+03, -.54562200E+03, 0.27328900E+03, 0.38478300E+03, 0.27301100E+03, 0.24601500E+02, 0.28394500E+03, -.11178100E+03, -.32077600E+03, -.11348800E+03, 0.28905500E+03, 0.11197600E+03, -.17906300E+03, 0.89473500E+02, -.90306600E+02, 0.89849700E+02, 0.48039100E+01, 0.82697500E+02, 0.48272900E+02, -.66548100E+02, -.13526800E+03, 0.10748100E+03, 0.28819200E+02, -.33532900E+03, 0.16804000E+03, -.78956100E+01, 0.16777200E+03, 0.32366200E+02, -.66813200E+02, 0.11516600E+03, 0.66863400E+02, 0.10010700E+03, -.41270400E+02, 0.25692700E+03, -.40028100E+01, -.16009400E+02, 0.16015300E+02, -.92269000E+01, 0.16818000E+02, -.11453300E+02, 0.21378900E+02, -.48336600E+01, 0.38334900E+01, 0.44586100E+01, -.42052800E+01, -.17761300E+02, 0.15227900E+02, 0.56066900E+01, -.35579600E+02, 0.45087000E+02, -.13457100E+02, -.89225500E+01, 0.25202100E+02, 0.32340300E+02, -.13850000E+02, 0.77744000E+02, 0.25141500E+02, -.21382100E+02, -.19670500E+02, -.17387700E+02 },
        { -.81388300E+00, 0.73916200E+00, 0.84245300E-01, 0.85263800E-01, -.76891100E-01, 0.92625100E+00, -.17590400E+01, 0.10512100E+01, -.74615000E+00, 0.50251500E+00, 0.29200500E-01, -.13545500E+00, 0.41439000E+00, -.33657500E+00, 0.16177100E+00, -.11213400E+01, -.24024100E+00, 0.94149300E+00, -.22105600E+00, -.97421600E+00, -.55090200E-02, 0.12818700E+00, 0.14917400E-01, 0.35874300E-01, -.20528100E+00, 0.45109400E-02, 0.24508000E+00, 0.66422600E-01, 0.71400200E-01, 0.57404900E+00, -.33552700E+00, 0.10115400E+00, -.88316200E-01, -.26532000E+00, 0.10010800E+00, -.82928500E-01, 0.43854500E-01, -.40986400E+00, -.53246600E+00, -.83356900E+00, 0.26367500E-02, 0.10867000E-01, -.29247200E-01, 0.85996600E-01, 0.90524900E-01, -.12881800E-01, 0.49691900E-01, 0.22976200E-02, -.43277100E-01, -.14832500E+00, 0.43626700E+00, -.75912700E-01, -.72477900E-01, -.19417900E+00, -.55637200E+00, 0.30325700E+00, -.27749600E+00, 0.70284100E-01, -.45169100E-01, 0.14207900E+00, 0.12660900E+00, -.91326500E+00, -.65111000E+00, 0.53634900E+00, -.35994100E+00, 0.92535400E-01, -.53702100E-01, 0.59345300E-01, -.35623400E-01, 0.27125400E-01, 0.25443100E+00, 0.15932100E-02, 0.63701200E+00, 0.23104300E+00, 0.36218900E+00, -.50637500E+00, 0.19758100E+00, 0.16797600E+00, 0.17338900E+00, -.38197500E+00, 0.35757600E-01, -.19772700E-01, 0.35379600E-01, 0.50719900E-01, -.62460400E+00, -.24124400E+00, -.17208300E+00, -.75141600E+00, -.85966200E+00, 0.55801100E+00, 0.26852400E+00, 0.11042600E-02, 0.10944400E+00, -.47961900E-01, -.50290300E+00, 0.19755800E+00, -.80703800E-01, -.40987300E+00, -.17965000E+00, -.12394100E-01, 0.18511600E+00, -.23309300E+00, -.19896400E+00, 0.29187000E+00, -.43604500E-01, -.54281400E-01, 0.11508000E+00, -.23808700E+00, -.64974400E+00, -.92337600E-01, 0.13909000E+00, -.54390700E-02, 0.92854800E-01, 0.13252900E+00, 0.18983200E+00, -.29147500E+00, 0.53968200E-01, 0.62858900E+00, 0.22566300E-01, -.34026600E-01, -.55887300E-01, 0.18327800E+00, 0.57489800E-02, 0.13822700E+00, -.26951200E-02, -.33371200E-01, 0.83743700E-01, 0.92825300E-01, 0.32019000E+00, 0.20228600E+00, -.24186400E+00, -.15095000E+00, 0.19758700E+00, -.19926200E-02, -.18666600E-01, -.23446900E-02, -.50290100E+00, -.44269200E-01, 0.44247200E-01, 0.10614300E+01, 0.69679600E-01, -.16260400E+01, 0.13819000E+01, 0.49127600E+03, -.23553100E+03, 0.26228900E+03, -.24562900E+03, -.88052500E+02, -.43689900E+03, 0.28318700E+03, 0.21110500E+03, -.30531200E+03, -.37328700E+03, -.41611400E+03, -.86295600E+02, 0.43779300E+02, -.19084800E+02, 0.43258400E+02, 0.13902400E+03, 0.99249000E+02, 0.34007700E+02, -.42409200E+02, -.50006500E+01, 0.13464800E+03, -.87429800E+02, 0.29237500E+03, -.14556400E+03, 0.12896700E+03, -.14673900E+03, 0.72346900E+02, 0.15998800E+03, -.16030100E+03, 0.30661700E+02, -.89922100E+02, 0.15169400E+03, -.20731200E+03, 0.17894300E+03, -.89995600E+02, 0.11493300E+03, -.91504800E+02, 0.19458900E+02, 0.53159100E+02, -.54385000E+02, -.72711200E+02, -.11892300E+03, 0.73377600E+02, -.21604500E+03, -.28854000E+02, 0.88688200E+01, 0.20834500E+03, 0.14437000E+02, -.11922000E+03, 0.12861100E+03, -.14170200E+03, -.50142800E+02, 0.84039900E+02, 0.11544600E+03, -.21123100E+02, 0.26805000E+03, -.13413600E+03, 0.91815000E+02, -.13366800E+03, -.83876100E+02, 0.11722600E+02, 0.21837200E+01, 0.50847200E+02, -.52413300E+02, 0.21285900E+02, -.16506600E+03, 0.45869000E+02, -.22451000E+02, -.70027000E+02, -.22896500E+02, -.11642400E+02, 0.83239500E+01, 0.11133700E+02, 0.13624700E+02, -.13162800E+02, -.24038000E+01, -.56807300E+02, 0.38872700E+03, -.19431500E+03, -.49954700E+02, -.19425000E+03, 0.66462100E+02, -.34070600E+02, -.67425500E+02, 0.44985900E+02, -.15531000E+03, -.38301400E+02, -.25768700E+03, 0.48358500E+03, -.23584700E+03, 0.31000400E+03, -.24241300E+03, -.13533700E+03, -.28446100E+03, 0.15603100E+03, 0.89682500E+02, -.30875100E+03, -.23835800E+03, -.36883600E+03, 0.37188500E+03, -.18532000E+03, 0.99975900E+02, -.18546900E+03, 0.84020500E+02, -.52916700E+02, -.91031000E+02, -.62140100E+02, -.21273400E+03, -.41213700E+02, -.32000100E+03, -.44452200E+02, 0.22344000E+02, -.25571900E+02, 0.22921500E+02, 0.50817900E+02, 0.96693000E+01, -.13974300E+02, -.51759000E+01, 0.22671400E+02, 0.17344300E+02, 0.70305100E+02, -.12448500E+02, 0.61836700E+01, -.12005200E+03, 0.64406400E+01, 0.51046900E+02, 0.27329700E+02, -.61034400E+00, -.28361800E+02, -.84542200E+01, 0.32551500E+02, -.48835200E+02, -.28888400E+01, -.54692400E+01, -.75315100E+01, 0.26122700E+01, 0.53659200E+01, -.76600500E+01, -.10725700E+02, -.63730500E+01, 0.44980600E+01, 0.63104000E+01, -.76274400E+01, -.64763800E+02, -.16013300E+01, 0.35357100E+01, -.78018700E+02, 0.13352700E+02, -.13139400E+01, 0.98224800E+01, -.41924100E+02, 0.29868300E+01, -.10228400E+02, -.22696300E+02, 0.75358600E+02, 0.86280200E+01, 0.55544000E+01, -.13102900E+01 },
        { 0.11297800E+01, -.67965100E+00, -.82171000E-01, -.44108400E+00, 0.24304500E+00, 0.11565800E+01, 0.38304700E+00, 0.11655100E+01, 0.48270000E+00, -.76893400E+00, -.11836000E+00, 0.42107800E-01, -.16255800E+00, 0.93014100E+00, 0.19853500E+00, 0.32595100E+00, -.36116900E-01, -.26103300E-01, -.17589900E+00, 0.37910900E+00, -.85265700E-01, -.29890700E-01, -.18422900E-01, 0.13253100E+00, -.74635400E+00, -.24687700E-01, -.20489500E+00, -.15168900E+00, 0.35730900E+00, -.23429100E-01, -.44156200E-02, -.27808000E-01, -.27177500E+00, -.35123800E-01, 0.19007100E-01, 0.43353400E-01, 0.35705400E-02, 0.29838300E-01, 0.10118700E+00, 0.96167500E+00, -.53822000E-01, -.46453600E-01, -.52921400E-01, 0.17957000E+00, -.95125800E-01, -.12524400E-01, -.55178600E-01, -.10680900E-01, 0.51775300E-01, -.11353100E-01, 0.64543300E+00, 0.44144400E-03, -.88368700E-01, -.17492300E+00, -.19155500E+00, 0.17300500E+00, -.87742900E-01, 0.63387800E-01, -.31081800E-01, 0.90473100E-01, -.14913800E+00, -.97402400E-01, -.57920400E-01, 0.19279600E-01, 0.16107200E-01, 0.25426600E-01, -.31513900E-01, 0.15428000E-01, 0.52464400E-01, 0.19709500E-01, -.16097600E-01, -.27491000E-01, -.43288400E-01, -.17607200E-01, 0.16611600E+00, -.13406100E+00, 0.21049600E+00, -.86041100E-01, -.82480200E-01, 0.10433400E+00, 0.31372200E-01, -.11781600E+00, -.35082800E+00, -.58040900E-01, 0.44714600E+00, -.42861100E-01, 0.43296200E+00, -.28140300E+00, 0.41189400E+00, 0.10404000E-02, 0.46834800E-01, -.11997500E-01, 0.16224000E-01, 0.13256500E+00, 0.79983300E-01, -.39695800E+00, 0.15271000E+00, 0.19224400E+00, 0.36426300E-01, -.17523800E-01, -.13045900E-01, 0.14152900E-01, 0.65480100E-01, -.16201100E+00, 0.17779000E+00, -.60442000E-01, -.88656500E-01, 0.87010300E-01, 0.20731500E+00, 0.73396500E-01, -.14847600E+00, 0.52789600E-01, 0.22923100E-01, -.72215400E-01, -.16959100E+00, 0.17794400E+00, -.83368800E+00, 0.34480100E-01, 0.94491900E-01, 0.24119800E+00, 0.74604600E-01, 0.10803000E+00, -.21884700E-01, 0.14259100E+00, 0.35201200E-02, 0.53119900E-01, 0.38749800E-01, -.23424000E+00, 0.12864200E+00, 0.43696700E-01, 0.33334400E+00, -.20075400E+00, -.54807100E-02, 0.12649100E-02, 0.39649800E-01, 0.63111900E-03, 0.28480100E+00, 0.82498000E-01, -.37137200E-02, -.84505000E+00, -.14489400E+00, -.94654800E-01, 0.10318800E+02, -.31625500E+03, 0.15540300E+03, -.10815000E+03, 0.15802100E+03, 0.27883800E+01, 0.56488900E+02, 0.94586200E+01, -.15036900E+02, 0.20029000E+03, 0.45619500E+02, 0.31509700E+03, -.78762400E+02, 0.38554400E+02, 0.14934000E+02, 0.39357700E+02, 0.89402400E+01, -.21931700E+02, 0.28041600E+02, -.12555000E+02, 0.16941000E+02, -.14050800E+02, -.67540300E+02, -.65732700E+02, 0.31307200E+02, 0.67371900E+02, 0.32581700E+02, 0.15105900E+02, 0.29362800E+01, 0.29076200E+02, 0.31968200E+00, 0.17736700E+02, -.75549900E+00, -.60529000E+02, -.70800800E+02, 0.35435400E+02, 0.15916100E+03, 0.36093300E+02, 0.75372200E+02, 0.89959500E+01, 0.10628900E+02, -.17319800E+02, -.27989400E+02, 0.18120400E+02, -.21910500E+00, 0.23643600E+03, -.11819200E+03, -.13220300E+03, -.11815900E+03, 0.45402600E+02, 0.15916600E+02, -.78997700E+02, -.29386500E+02, -.92518500E+02, 0.86379200E+01, -.99075800E+02, -.12708700E+03, 0.63614300E+02, 0.31000200E+02, 0.63517100E+02, 0.26726900E+02, -.14055000E+02, 0.10904400E+02, -.38900000E+02, 0.34288300E+02, -.11099100E+02, -.32943200E+02, -.31428700E+02, 0.15884700E+02, 0.22003200E+02, 0.15717000E+02, 0.90019000E+01, -.33452100E+00, 0.76867400E+01, 0.14220900E+00, 0.25826100E+02, 0.19850700E+01, -.50253500E+02, -.32647100E+03, 0.16313100E+03, 0.18413900E+03, 0.16321700E+03, -.35734200E+02, 0.46354100E+02, 0.53490000E+02, -.81790600E+02, 0.38917500E+02, 0.51856100E+02, 0.21642800E+03, -.12628800E+03, 0.61860500E+02, -.20551000E+03, 0.62971800E+02, 0.10608200E+02, 0.16193200E+02, -.12107600E+02, -.61191200E+01, 0.17412300E+03, 0.67054300E+01, 0.19911900E+03, -.37780000E+03, 0.18841500E+03, 0.28644200E+03, 0.18884900E+03, -.18133800E+02, 0.59332000E+02, 0.70904200E+02, -.88860700E+02, 0.30766700E+02, 0.65860900E+02, 0.22876600E+03, -.17989200E+01, 0.72733100E+00, 0.29402700E+01, 0.81787300E+00, -.68965900E+01, -.12191400E+02, 0.40091300E+02, 0.20547800E+02, -.18060000E+02, -.24343000E+01, -.44042700E+02, -.49733600E+02, 0.25411800E+02, 0.59902500E+01, 0.24838700E+02, 0.11796800E+02, -.25245300E+02, 0.17528300E+02, 0.20823800E+02, 0.28620200E+02, -.12621600E+02, 0.46305900E+02, 0.14394500E+01, -.35862300E+01, 0.75889600E+01, 0.83368100E+00, 0.41040100E+01, -.64827200E+01, 0.12264500E+01, 0.14360500E+01, -.21565700E+01, 0.23982000E+01, 0.23159800E+01, 0.11990500E+02, 0.11477200E+01, 0.16827000E+00, 0.25733500E+02, -.51440600E+01, 0.97246800E+01, -.25811200E+01, 0.31500000E+02, -.18294800E+01, 0.28948000E+01, -.77344800E+01, -.13003500E+02, 0.31132100E+01, 0.18868200E+01, -.46605200E+01 },
        { -.55022200E+01, 0.26056600E+01, 0.35393200E+00, 0.20168800E+01, -.74294700E+00, -.57984200E+01, -.18879000E+01, -.61593500E+01, -.23930400E+01, 0.36595100E+01, 0.67535500E+00, -.15417700E+00, -.10277500E+01, -.24918600E+01, -.25688100E+01, -.13536900E+01, 0.12749400E+01, 0.29053500E+00, 0.15201500E+01, -.20838200E+01, 0.89741600E+00, 0.44773800E-01, -.15687300E+00, -.95540800E+00, 0.57181800E+01, 0.11186100E+00, 0.75979500E+00, 0.27743100E+00, -.19776300E+01, -.78083200E+00, 0.51632300E+00, -.12132100E+01, 0.16869600E+01, 0.68430000E+00, 0.65377700E-01, -.41648700E+00, -.72942500E-02, 0.69221000E+00, -.23358300E+00, -.46188900E+01, 0.36298800E+00, 0.17211900E+00, 0.53146800E+00, -.53972500E+00, 0.19070300E+00, 0.17627300E-02, -.61346700E-01, 0.50931900E-01, -.24157400E+00, 0.21893400E+00, -.26016400E+01, 0.19022400E+00, 0.39876500E+00, 0.55133700E+00, 0.96559600E+00, -.10817200E+01, 0.37368400E+00, -.22765000E+00, 0.20425900E+00, -.47117000E+00, 0.86376200E+00, 0.18574700E+01, 0.10205900E+01, 0.15795400E+00, -.31898600E+00, -.54846700E-01, -.44148700E+00, -.85758500E-01, -.41567100E+00, -.10788900E+00, -.12352700E+00, 0.17372400E+00, -.20755900E+00, -.11653600E+00, -.93678100E+00, 0.27539800E+00, -.90729400E+00, -.27818000E+00, 0.34018600E+00, -.11484600E+01, -.23679400E+00, 0.77477000E+00, 0.21047300E+01, 0.31851900E+00, -.16869200E+01, 0.72755300E+00, -.26905200E+01, 0.15268000E+01, -.26890000E+01, -.77521700E+00, -.16601100E+01, 0.79361400E-01, 0.77921000E+00, -.11393200E+01, -.35493700E+00, 0.16325200E+01, -.75621700E+00, 0.47281500E+00, -.30034500E-02, -.53611300E+00, -.22153200E-01, 0.31868400E+00, -.50420600E+00, 0.19330500E+00, -.12065700E+01, -.16696200E+00, 0.34120100E+00, -.11369100E+01, -.13184900E+01, -.26854900E+00, 0.22579200E+01, -.39157100E+00, 0.13264900E+00, 0.53062500E+00, -.26557400E+00, -.10309000E+01, -.47019000E+00, 0.10724100E+01, 0.14824700E+00, -.44551100E+00, -.47744100E+00, -.83718200E+00, 0.44851300E-01, 0.29736000E+00, 0.28728000E-01, -.28027800E+00, 0.40301500E-01, 0.16349700E+01, -.10774000E+00, 0.57839600E+00, 0.17187700E+00, 0.54366800E+00, 0.71985500E+00, -.46849800E-02, -.14297100E+00, -.73998400E-02, -.22635600E+01, -.42855900E+00, 0.27659900E+00, 0.28767800E+01, -.35612400E+00, 0.29369900E+01, 0.46450600E+01, 0.33925900E+04, -.16835700E+04, -.57022400E+03, -.16928900E+04, -.12272100E+03, -.78161800E+03, -.10151600E+03, 0.41674800E+03, -.14435700E+04, -.56019400E+03, -.33342800E+04, 0.73902000E+03, -.36340100E+03, -.18819000E+03, -.36905400E+03, -.22975700E+03, 0.28952000E+03, 0.37860500E-01, 0.35501500E+03, -.27753600E+03, 0.11043900E+03, 0.50791200E+03, 0.59019800E+03, -.28466800E+03, -.36557900E+03, -.29354000E+03, 0.15124700E+02, 0.26400900E+03, -.70480400E+02, 0.36901200E+03, -.15312000E+03, 0.12877500E+03, 0.25569800E+03, 0.17728500E+03, -.88679500E+02, -.11694300E+04, -.93004700E+02, -.57176700E+03, -.14491700E+03, -.15678300E+03, -.11567500E+02, 0.28563200E+03, -.18383900E+03, 0.49839000E+03, -.25696000E+04, 0.12930000E+04, 0.16544600E+04, 0.12827400E+04, -.20424100E+03, 0.59417400E+02, 0.63190900E+03, 0.13804600E+03, 0.93377100E+03, 0.87471400E+01, 0.14243900E+04, 0.11217300E+04, -.56132600E+03, -.39653000E+03, -.56113300E+03, -.23687600E+03, 0.16263600E+03, -.19227400E+03, 0.28460500E+03, -.51347900E+03, 0.11908500E+03, 0.60387600E+03, 0.26568900E+03, -.13340100E+03, -.16851800E+03, -.13308800E+03, -.14616600E+03, 0.12908400E+03, -.68007500E+02, 0.27643500E+02, -.35617500E+03, 0.11313800E+03, 0.28318400E+03, 0.23944900E+04, -.11966000E+04, -.14099100E+04, -.11969800E+04, 0.13659100E+03, -.19594700E+03, -.50465700E+03, 0.54524500E+03, -.22920300E+03, -.23256200E+03, -.19643700E+04, 0.17677100E+04, -.87171800E+03, 0.55271200E+03, -.87558900E+03, -.26507200E+03, -.50814900E+03, 0.15108700E+03, 0.43787600E+03, -.10045900E+04, -.34452800E+03, -.20470600E+04, 0.29729900E+04, -.14831500E+04, -.23498600E+04, -.14862900E+04, -.85385100E+02, -.25658200E+03, -.74831700E+03, 0.58993500E+03, -.20038100E+03, -.33700200E+03, -.22096300E+04, -.21381700E+03, 0.10766200E+03, 0.15357500E+03, 0.10748000E+03, 0.40690500E+02, 0.18423200E+03, -.13075000E+03, -.75075600E+02, 0.84574200E+02, 0.11941900E+03, 0.31911200E+03, -.12248500E+03, 0.58851900E+02, 0.20604600E+03, 0.61523500E+02, -.32601000E+02, 0.83760300E+02, -.41932000E+01, -.52557900E+02, 0.27142100E+02, -.58439900E+00, 0.39837500E+02, -.57092400E+01, -.88907800E+00, -.20598200E+02, -.16991300E+02, -.35580300E+01, 0.45049800E+02, 0.28315100E+02, 0.75014100E+01, 0.11041600E+02, -.16901400E+02, -.20050000E+02, -.78491800E+02, 0.26338700E+01, -.44273800E+01, -.22074900E+03, 0.41866700E+02, -.77651900E+02, -.97045400E+00, -.19197700E+03, 0.45911800E+02, -.53752600E+02, 0.21782300E+03, 0.10525300E+03, -.66729400E+02, -.35351600E+02, -.43830800E+01 },
        { -.66950600E+01, -.87028600E+01, -.99121900E+00, -.30988600E+01, -.73999200E+00, -.39590000E+01, -.79779900E+01, -.88349100E+00, -.43750600E+01, 0.59468400E+01, 0.16591900E+00, -.38598000E+00, -.33947100E+01, 0.80854400E+01, -.11846900E+01, 0.13387000E+01, 0.20563600E+01, 0.26877000E+01, -.10388900E+01, -.11281500E+01, -.13810900E+01, 0.42190100E+00, -.54207000E+00, -.71722600E-01, -.21971500E+01, 0.98910900E-01, 0.14319900E+00, 0.90461600E+00, -.11159900E+01, 0.21471800E+01, -.87497700E+00, 0.19810700E+00, 0.32090500E+00, -.62282400E+00, 0.10113000E+01, -.68766100E+00, 0.15742600E+00, -.64970500E+00, -.15362100E+01, -.18976700E+01, 0.55328900E-02, -.31149500E+00, -.53617800E-01, 0.23392300E+01, 0.14878000E+01, 0.41251100E-01, 0.58474300E+00, -.35219400E-01, 0.29908100E+00, -.13523200E-01, 0.33900000E+01, -.97493000E+00, -.98516000E+00, -.18346500E+01, -.14797600E+01, -.99689100E+00, -.23219200E+00, -.30099600E+00, -.77801400E-01, 0.10224200E+01, 0.78635100E+00, -.26304300E+01, -.11739300E+01, -.16740100E+01, 0.16917500E+01, -.85437300E-01, 0.80099500E+00, -.56701200E+00, 0.41433900E+00, 0.15369500E+00, 0.40172600E+00, -.11144200E+00, 0.39675100E+00, 0.12035800E+00, 0.78518700E-01, -.17286900E+01, 0.52922000E+00, -.89301500E+00, -.29971700E+00, 0.77115500E+00, 0.43567900E+00, 0.35542000E+00, -.43153300E-01, 0.19262100E+00, -.32528100E+01, -.82172000E+00, 0.35663200E+01, -.17484500E+00, -.24403300E+01, 0.19915600E+01, -.11159500E+01, 0.73912800E-01, -.12605700E+01, 0.78403900E+00, 0.19695600E+01, -.18624200E+01, 0.49089600E+00, 0.83487300E-01, 0.74864800E+00, -.18202900E+00, -.12565900E+01, -.58738900E+00, 0.76130500E+00, 0.18360600E+00, 0.10409700E+01, 0.11878600E+00, 0.14998000E+00, 0.22002300E+01, 0.22656400E+01, 0.65680400E+00, -.33672000E+01, 0.11751000E+01, -.20162700E+00, -.30098000E+00, 0.25934700E+00, 0.12319900E+01, -.86537800E+01, -.23884500E+00, 0.69844000E+00, 0.10219700E+00, -.36169600E+00, -.13494000E+01, 0.30163600E-01, -.17849900E-01, 0.84196700E-01, -.38917700E+00, 0.79497900E-01, 0.25415400E+01, -.57401600E+00, 0.16084200E+01, -.10638900E+01, 0.10911700E+01, -.11004400E+01, 0.51532800E-01, 0.28125600E+00, -.40821600E-02, -.15660900E+00, -.17689400E+01, 0.57217900E+00, -.30626800E+01, -.11891700E+01, 0.22545400E+01, -.95893900E+00, -.26183100E+00, -.26138300E+03, -.18504600E+04, 0.43367700E+01, -.34755000E+03, -.13007300E+03, 0.31499400E+03, 0.77555100E+03, 0.66806700E+03, -.13266200E+03, -.51549400E+03, 0.40192300E+03, -.18953400E+03, 0.79177900E+02, -.20099500E+03, -.70094000E+03, 0.17166700E+03, -.18610900E+03, -.38237700E+03, -.53010900E+03, 0.20114300E+03, 0.14636700E+04, 0.29226100E+03, -.15966900E+03, -.65579600E+03, -.14500400E+03, 0.62736600E+02, -.19281500E+01, 0.95916400E+02, 0.16035400E+03, -.23993800E+02, 0.43654300E+02, 0.45677000E+03, 0.43823800E+03, -.23010500E+03, -.12614200E+04, -.19906700E+03, -.18299800E+03, 0.50997500E+03, -.26357400E+03, 0.34234100E+03, 0.63850100E+02, 0.29868700E+03, 0.11956400E+04, -.55168900E+03, 0.34361300E+03, 0.28238900E+03, 0.27292800E+03, 0.58953400E+03, -.22115200E+02, -.12853400E+03, 0.64205400E+02, 0.30775500E+03, -.63587500E+02, 0.46938500E+03, -.91770700E+03, 0.47008600E+03, 0.11203500E+04, 0.45631900E+03, -.34463700E+03, -.23108100E+03, 0.11838600E+03, -.12883500E+03, 0.10793800E+02, -.18569800E+03, 0.42951700E+03, 0.23012800E+03, -.94830500E+02, 0.14925300E+03, -.11569300E+03, -.16959900E+03, 0.27061000E+03, -.12146600E+03, 0.49948100E+02, 0.46917200E+02, 0.20604000E+03, 0.69237200E+03, -.14943600E+04, 0.73862500E+03, 0.43052600E+03, 0.74689000E+03, -.30517800E+03, -.18077700E+02, 0.41016200E+03, 0.40646600E+02, 0.10770700E+04, 0.14305800E+02, 0.93687700E+03, -.38105800E+03, 0.96384100E+02, -.14849000E+04, 0.20599700E+03, -.13577200E+03, -.21995300E+03, 0.30351100E+03, 0.95402700E+03, 0.10467800E+04, -.25244800E+03, -.15812100E+03, -.13769300E+04, 0.66997900E+03, -.17269300E+02, 0.68589900E+03, -.58905600E+03, 0.24002600E+03, 0.55044600E+03, 0.51044200E+03, 0.15399100E+04, 0.13041300E+03, 0.14896400E+04, -.39873600E+03, 0.21182400E+03, 0.12979200E+03, 0.19605800E+03, -.21654300E+02, 0.12964100E+03, 0.10543200E+03, 0.22718700E+02, 0.85916500E+02, 0.10947000E+03, 0.35915600E+03, -.59397700E+03, 0.28453200E+03, 0.32275600E+02, 0.29611400E+03, 0.77144200E+02, 0.10466700E+03, 0.28776400E+01, -.11285300E+03, 0.44388300E+02, 0.11041200E+03, 0.23625100E+03, 0.95223100E+01, -.50133000E+02, 0.87727000E+01, 0.21086000E+02, 0.51693500E+01, -.89087500E+01, 0.41388600E+02, 0.10251400E+00, 0.87575600E+01, 0.18127800E+02, -.39084500E+01, 0.20997300E+03, 0.90957100E+01, 0.33863800E+01, 0.21914100E+03, 0.13379100E+03, -.59007300E+02, -.42142700E+02, 0.26649100E+03, 0.76763200E+02, -.31970500E+02, 0.94718100E+02, -.21653800E+03, -.95614800E+02, 0.17006300E+02, 0.20267300E+02 },
        { -.26356800E+01, -.16462300E+01, -.99163500E-01, -.13780400E+01, -.22114500E+01, -.12114100E+01, -.75029200E+00, 0.59552800E+00, -.11158500E+01, 0.22590300E+01, 0.77717000E-01, -.66582000E-01, -.96467500E+00, 0.11706300E+01, -.44399800E+00, 0.23937600E+01, 0.10202100E+00, -.32461000E+00, -.78671200E+00, -.39507700E-01, 0.10924200E+00, 0.61982900E-01, -.94409700E-01, 0.74485600E-01, -.56660400E+00, -.61401700E-01, -.69701200E+00, -.79146700E+00, 0.91455900E+00, -.20578000E+00, 0.24386400E+00, -.96365800E-01, 0.26000400E+00, 0.31032200E+00, -.18720100E+00, -.31833100E-01, -.19343500E+00, -.28489900E-01, 0.16451500E+01, -.16719600E+01, -.15610800E+00, -.19742100E+00, -.52313500E+00, 0.54159500E+00, -.39181000E+00, 0.17549900E+00, -.37085500E+00, -.78129300E-02, -.13371400E-01, -.17514900E+00, -.11474100E+01, 0.80216500E-02, 0.50351000E+00, 0.63779200E+00, 0.55207100E+00, -.12134400E+00, 0.15471000E+00, 0.18202900E+00, -.28314800E-01, -.87596900E+00, 0.33448500E-01, 0.23101800E+01, 0.83789600E+00, -.20071000E+00, -.29769100E+00, -.44224700E-01, -.11998000E+01, 0.52400300E+00, -.16238000E+00, 0.35022600E-02, 0.32463200E+00, 0.65561500E+00, -.20526500E+01, 0.24241500E+00, -.21989900E+00, -.75389200E+00, -.91893900E-01, 0.14817800E+00, -.11486600E+00, 0.18730600E+00, 0.84025800E-01, -.15806100E-01, -.22486200E+00, -.72119300E-01, 0.15525800E+00, -.38692700E-01, -.59766000E+00, -.92897500E-01, -.78677400E+00, -.28622200E+00, 0.68454500E+00, 0.27770400E-01, 0.16992800E+00, 0.97856200E+00, 0.15931300E+00, -.22837600E+00, 0.27699700E+00, -.24184800E+00, 0.58155700E+00, -.38497700E-01, 0.21780000E+00, -.37230800E+00, -.53170600E+00, -.22225200E+00, 0.29581800E+00, -.65037500E+00, -.96810400E+00, -.67263200E+00, 0.12709700E+01, 0.11951200E-01, 0.13832800E+00, 0.19547300E+00, -.22770700E+00, 0.96921000E-01, -.21049700E+00, 0.17548400E+01, -.18320100E+01, -.39047500E+00, -.49334800E-01, 0.61811100E+00, -.66065400E+00, -.50714900E-01, 0.17126600E+00, 0.31353400E-01, -.36314500E-01, -.14695800E+00, 0.19753200E+00, 0.86551400E-01, -.23903300E-01, 0.51901600E-01, -.70882400E-02, 0.72305100E+00, -.17817900E+00, -.39205400E-02, 0.19107100E+00, -.28662400E-02, -.42697500E+00, -.91604600E-01, -.41004000E-01, 0.91094000E+00, -.65593000E+00, 0.15671400E+01, 0.11399400E+01, -.50936700E-01, -.13541400E+00, -.11565400E+04, 0.13997300E+01, 0.38886300E+02, 0.56460000E+03, -.27635000E+03, -.10918900E+03, 0.28712200E+03, 0.51252500E+03, -.26788100E+02, 0.34003200E+03, -.17293400E+03, 0.40968700E+02, -.16998700E+03, -.17975300E+03, 0.87453100E+02, 0.60658700E+02, -.21226100E+02, -.30660400E+03, 0.73069000E+02, 0.11322500E+03, -.23637900E+03, 0.10587300E+03, -.14347200E+03, 0.11756400E+03, 0.11449600E+02, -.52282800E+02, 0.11703400E+03, 0.11917500E+03, 0.98499700E+02, -.72740800E+02, 0.11320500E+03, -.16729800E+03, 0.81582400E+02, -.59329600E+03, 0.88921600E+02, -.13263300E+03, -.19364800E+02, -.21460000E+02, 0.33429200E+01, 0.96663000E+02, -.33742700E+02, 0.50781900E+03, -.33829400E+03, 0.15252800E+03, 0.79948500E+02, 0.16820900E+03, 0.24196200E+03, -.16641500E+03, -.26057100E+02, 0.11140600E+03, 0.25461600E+03, -.20507200E+03, 0.34570200E+03, -.24512700E+03, 0.12398800E+03, 0.34064000E+03, 0.12187200E+03, 0.27968800E+02, -.84549700E+01, 0.51115600E+02, -.83153000E+02, -.12259600E+03, 0.56465700E+01, 0.20581300E+03, -.57714700E+02, 0.31343800E+02, 0.12278500E+03, 0.28674200E+02, 0.95317700E+01, 0.95818900E+02, -.91028600E+01, -.22763900E+02, -.49678200E+02, 0.10181300E+03, 0.62947000E+02, -.13247100E+03, 0.65343700E+02, -.19460100E+03, 0.66178400E+02, -.19046600E+03, 0.99007200E+01, 0.20451000E+01, -.20437000E+02, 0.24456600E+03, -.36069600E+01, 0.18674000E+03, -.22133400E+03, 0.10783700E+03, -.92263400E+03, 0.11546700E+03, 0.81204300E+02, 0.21885200E+03, -.86190600E+02, 0.12134800E+03, 0.66916200E+03, 0.17490600E+03, 0.10420500E+03, 0.30404800E+03, -.15390500E+03, -.57776600E+03, -.15268800E+03, -.34703400E+03, 0.35919100E+02, -.73102400E+02, 0.10023000E+03, 0.23580800E+03, -.52452800E+01, 0.24145800E+03, -.14727300E+03, 0.74275100E+02, 0.57743800E+02, 0.72799600E+02, -.36378100E+02, 0.82260600E+02, 0.24948000E+02, -.66749800E+02, -.10876400E+02, 0.78543200E+02, -.18068900E+02, -.45109900E+03, 0.22631700E+03, 0.22337200E+03, 0.22533900E+03, 0.15710000E+02, 0.23351100E+00, 0.10000400E+03, -.20441600E+02, 0.12919800E+03, 0.25762500E+01, 0.28401500E+03, 0.46081600E+01, -.27824000E+01, 0.14562100E+02, 0.53455300E+00, 0.16289800E+02, 0.13262000E+01, 0.29159700E+02, 0.41004000E+01, -.41106200E+01, 0.53136800E+01, -.36656600E+01, 0.15364400E+03, 0.65458100E+01, 0.16543700E+01, 0.12782100E+03, 0.37881900E+02, -.11863200E+02, -.45096800E+01, 0.12032400E+03, 0.31659400E+02, -.90988800E+01, 0.97008800E+02, -.15101400E+03, -.34467400E+02, -.24837000E+02, -.10251700E+02 },
        { -.95435100E+01, 0.26620700E+01, 0.55139400E+00, -.39458100E+01, -.64278800E+01, 0.97866600E+01, -.12523300E+02, 0.14117900E+02, -.60231400E+01, 0.78322100E+01, 0.86526200E-01, -.55938400E+00, 0.22009300E+00, 0.92056000E+01, -.10453400E+02, 0.13550500E+01, -.13409100E+01, -.46045100E+01, 0.34803800E+01, -.39009000E+01, 0.13093900E+01, 0.45435600E+00, 0.16679600E+00, 0.80686800E-02, -.24983900E+01, 0.33401500E+00, -.30213200E+01, -.58392800E+01, 0.51104200E+01, -.26909100E+01, 0.19978100E+01, 0.17689300E+01, 0.89292200E+00, 0.21437200E+01, 0.33023900E+00, 0.14855300E+01, -.97654700E+00, 0.21260500E+00, -.21141400E+01, -.55135900E+01, -.22150400E+00, -.99891200E+00, -.38208500E+01, -.41569200E+00, 0.71739900E+00, -.26766000E+00, -.16979200E+01, 0.84017500E-01, 0.68096200E+00, 0.14265100E+01, 0.78258900E+00, 0.62734500E+00, -.71943500E+00, 0.19512600E+01, 0.16837500E+01, -.38802900E-01, 0.10046800E+00, -.10815800E+00, 0.46077200E+00, -.15940400E+01, 0.74997300E-01, 0.44837500E+01, 0.25980200E+01, 0.22693400E+01, -.15476600E+01, 0.17933800E+00, -.77923900E-01, 0.11389300E+01, -.59018600E+00, 0.42707400E+00, -.15059100E+01, 0.67937200E+00, -.38657400E+01, 0.36561000E+00, -.75809000E+00, 0.73761400E-01, -.45335500E+00, 0.20714000E+01, 0.10702400E-01, 0.74187900E+00, 0.36847300E+00, -.14936100E-01, -.15089000E+01, 0.59642700E+00, 0.20694800E+01, 0.75737600E-01, 0.92235300E+00, -.25181400E+01, -.37464500E+01, 0.17381600E+01, -.21799200E+00, 0.33930700E+00, 0.42274900E+00, -.15214300E+01, -.10151000E+01, 0.90623900E+00, -.60661800E+00, -.95475800E+00, -.23951900E+00, -.21571100E-01, -.27593100E+00, 0.12389000E+01, -.15402200E+01, -.16337600E+01, -.55609700E+00, -.52105200E+00, 0.52536400E+00, -.71045300E+00, -.60648600E+00, 0.23931800E+00, 0.17977700E+01, -.36163100E+00, 0.20809800E+00, 0.61085600E+00, -.60617800E-01, 0.27806800E+01, 0.75212000E+00, -.19371000E+00, -.13240900E+00, -.64717500E+00, -.17753100E+01, -.16153500E-01, 0.17381000E+00, 0.80174900E+00, 0.32842000E+00, 0.10450300E+01, -.56735500E+00, -.20511300E+01, 0.33359700E+01, -.45891600E+00, -.57878300E-01, -.24873000E+00, 0.33068100E+01, 0.14740300E-01, 0.27413200E+00, -.82484700E-01, -.30238800E+01, -.88533400E+00, -.73252200E+00, 0.14265500E+01, -.19334200E+00, -.28099900E+01, 0.10006700E+01, 0.17342300E+00, -.21781600E+00, -.70298800E+00, 0.19368100E+02, -.14532900E+02, -.97870300E+03, 0.12715300E+04, 0.42913900E+03, -.19704500E+03, -.90947400E+03, -.63043100E+03, 0.12824300E+03, -.60423400E+02, -.17716100E+03, -.61758400E+02, 0.18637000E+03, 0.17520000E+03, 0.39533900E+03, 0.32784200E+02, -.28284700E+03, 0.22874900E+03, -.31570600E+03, 0.75989000E+03, -.38841600E+03, 0.41463900E+03, -.38070800E+03, 0.22269900E+03, 0.30715800E+03, -.59500400E+03, -.27278300E+02, -.31358100E+03, 0.26507700E+03, -.27764500E+03, 0.70070500E+03, -.35045200E+03, -.98372000E+03, -.37681000E+03, -.10044800E+03, 0.69430800E+02, -.20377600E+03, 0.18635700E+02, 0.20212900E+02, 0.47785800E+02, -.45032000E+03, 0.27699800E+03, -.17473900E+03, 0.76447500E+03, -.14395800E+03, -.34880200E+03, 0.60098400E+02, -.66350800E+03, 0.13046600E+03, 0.65431400E+03, -.49793000E+02, -.32925500E+03, 0.15498200E+04, -.77103200E+03, 0.37450500E+03, -.77194900E+03, -.33710000E+03, 0.11252400E+03, -.18472600E+03, 0.53664400E+02, -.51793900E+03, 0.10910300E+03, -.76295400E+03, -.68610300E+02, 0.44589600E+02, 0.23165100E+02, 0.34351900E+02, 0.11612500E+03, 0.11843200E+03, 0.78324300E+02, -.27618700E+02, 0.70725500E+02, 0.13614400E+03, -.40145800E+03, 0.19039400E+04, -.95525100E+03, -.10361500E+04, -.95019300E+03, 0.10348200E+03, -.19235900E+03, -.37402300E+03, 0.43959400E+03, -.25756400E+03, -.21858000E+03, -.10149800E+04, 0.10834000E+04, -.52947200E+03, 0.10404100E+03, -.52667200E+03, -.29856100E+03, -.92743500E+03, 0.85580700E+03, 0.50212600E+03, -.69455800E+01, -.89334500E+03, -.12042400E+04, 0.25312000E+04, -.12679400E+04, -.12283800E+04, -.12602100E+04, 0.95233600E+02, -.24281300E+03, -.60178200E+03, 0.38366400E+03, -.40483700E+03, -.23603500E+03, -.13866900E+04, -.35033600E+03, 0.18227600E+03, 0.72975500E+02, 0.18332800E+03, 0.12647600E+03, 0.11176900E+03, -.13416800E+03, -.23222300E+03, 0.18653600E+03, 0.84690200E+02, 0.37413800E+03, -.18521800E+03, 0.93482400E+02, -.22359800E+03, 0.95368900E+02, 0.22740000E+03, 0.26058100E+03, -.13130300E+03, -.24471100E+03, -.63990400E+02, 0.15478600E+03, 0.90321700E+02, -.20503200E+02, 0.92993500E+01, -.38066200E+02, 0.11268900E+02, 0.73347200E+01, -.24370100E+01, -.32935200E+02, -.16682100E+02, 0.18423200E+02, 0.20309700E+02, -.44224000E+02, -.27011400E+03, -.39894700E+00, 0.65929400E+01, -.19107000E+03, 0.24608200E+02, 0.49895100E+02, 0.23460400E+02, -.19690300E+01, 0.19311700E+02, 0.34106600E+01, 0.85407100E+02, 0.30588800E+03, -.44717500E+02, -.70485800E+01, 0.14832400E+02 },
        { -.59417400E+01, 0.47171600E+01, 0.11883600E+01, 0.43583000E+00, -.54885000E+00, -.34991200E+01, -.24857800E+01, -.47726400E+00, -.20755500E+01, 0.27957800E+01, 0.59316900E-01, -.15988700E+00, -.26995700E-01, -.37681300E+01, -.18310400E+00, -.27961900E+01, -.15465600E+01, -.69937300E-01, 0.53784800E+00, -.41292300E+00, -.65036000E+00, 0.34158400E+00, 0.24463700E+00, 0.33478500E+00, 0.71010700E-01, 0.14984200E+00, 0.18239200E+01, -.16340900E+00, 0.56500900E+00, 0.16972900E+01, -.14439300E+00, 0.50653000E+00, -.37913400E+00, -.52734600E-01, 0.13942000E+00, 0.76569500E+00, -.18099700E+00, -.23673600E+00, -.43937700E+00, -.13131700E+02, 0.47923900E+00, 0.41720300E+00, -.23250500E+01, 0.92546800E+00, 0.82827700E+00, -.21269900E+00, -.11672900E+01, -.80969100E-02, 0.20670600E+00, 0.87918300E+00, 0.47935800E-01, 0.38597900E+00, -.10707500E+00, -.48762500E+00, -.16691600E+00, 0.22892600E+01, 0.65062200E-01, 0.84949000E+00, 0.52666300E-01, -.43394900E+00, -.12968600E+01, 0.91920600E+00, 0.12412800E+01, -.40730000E+00, 0.71672500E+00, -.96461500E-02, -.22342600E+00, 0.28030500E+00, 0.13654500E+00, 0.14313800E+00, -.36401200E+00, -.75453600E-01, 0.11082900E+01, -.78261000E-01, 0.45443700E+00, 0.41154800E+00, 0.31089700E-02, -.69215300E+00, -.54899200E+00, 0.60004100E+00, 0.77302400E-01, 0.52401900E+00, -.25464500E+00, -.65242900E+00, 0.10145500E+01, 0.32234100E+00, 0.60762300E+00, 0.41119100E+00, -.16338500E+01, 0.20501300E+00, 0.31516500E+01, 0.67017900E-01, -.28581700E+00, -.48117200E-01, -.62558400E+00, 0.14540600E+01, -.82489800E-01, -.18886400E+00, 0.10147400E+01, -.19300300E+00, -.57392800E-01, 0.38636800E+00, 0.58875700E+00, -.11989700E+01, 0.33033200E+00, -.76577300E+00, -.11436600E+01, 0.19173000E+00, 0.15225300E+01, 0.84492900E-01, 0.65512200E+00, 0.21114300E-01, 0.11171600E-01, 0.21546200E+00, -.18822500E+00, -.55336000E+00, 0.47844000E+01, 0.24349900E+00, -.83422900E+00, -.12402100E+01, 0.19262400E+00, 0.20257700E+01, 0.21126700E+00, 0.34650900E+00, 0.73677800E-01, 0.37849700E+00, -.10742800E-01, -.85552400E+00, 0.34384700E+00, 0.12494000E+00, 0.80502300E+00, 0.57919300E+00, 0.26258000E+01, 0.26154200E-01, -.92855300E-01, -.54653600E-01, -.49580300E+01, -.47105300E+00, -.69465500E+00, 0.15757300E+00, -.25827600E+01, -.51779800E+01, -.14292600E+00, 0.27881400E+00, -.46969200E+00, 0.19872500E+01, -.22020000E+00, -.80042800E+03, -.32215400E+04, 0.24204300E+04, 0.14512900E+04, -.61892900E+03, -.30487100E+04, 0.18866700E+02, -.10979500E+04, 0.55594200E+03, -.38729000E+03, 0.55030400E+03, 0.20120900E+03, 0.19303200E+03, 0.48281400E+03, -.22249900E+03, 0.11134400E+03, 0.42341700E+03, 0.82192000E+02, 0.21369700E+04, -.10669700E+04, 0.11400900E+04, -.10690800E+04, 0.43972600E+03, 0.75995100E+03, -.12081600E+04, -.39721700E+03, -.10242100E+04, 0.78217300E+03, -.11731400E+04, 0.24483000E+04, -.12258800E+04, -.10465400E+04, -.12560200E+04, 0.64674300E+03, 0.73935500E+03, -.67271700E+03, -.72452800E+02, -.74906000E+03, 0.60467400E+03, -.17026400E+04, 0.86182300E+02, -.73062400E+02, 0.24441800E+04, -.41352100E+02, -.17181400E+03, 0.11539000E+04, -.96188300E+03, -.37577000E+03, 0.40211000E+03, 0.10256900E+04, -.73250300E+03, 0.29293800E+04, -.14635000E+04, 0.29837300E+03, -.14590300E+04, -.12101000E+04, 0.11123000E+02, -.45174500E+03, 0.41887100E+03, -.60989200E+03, 0.42900600E+02, -.10902100E+04, 0.67883200E+03, -.33113900E+03, -.59937700E+03, -.33857600E+03, -.39495400E+03, -.51806000E+02, 0.26765500E+03, 0.27947600E+03, 0.11400700E+03, -.11746800E+03, 0.32400700E+03, 0.12636200E+04, -.63408800E+03, 0.87115300E+02, -.63030700E+03, 0.52675100E+03, 0.14726800E+03, -.84365100E+02, 0.58700500E+03, -.66847100E+03, 0.22363200E+03, -.72293300E+03, 0.69140900E+03, -.33374100E+03, 0.10124400E+04, -.36210100E+03, -.85853300E+03, -.18117500E+04, 0.14335900E+04, 0.51931000E+03, -.12976300E+04, -.17562800E+04, -.58224000E+03, 0.88752800E+02, -.44482400E+02, 0.11865200E+04, -.37305200E+02, 0.10500900E+04, 0.46972300E+03, 0.17611400E+01, 0.24109100E+03, -.50253100E+03, 0.52723800E+03, -.55332400E+03, -.67360700E+03, 0.34116900E+03, 0.11225800E+03, 0.34688300E+03, 0.43669300E+03, 0.13031800E+03, -.16765200E+03, -.18454100E+03, 0.27446000E+03, 0.11012900E+03, 0.70473300E+03, 0.76116600E+03, -.38757900E+03, -.12247900E+04, -.37754500E+03, 0.54358600E+03, 0.39581200E+03, -.49691800E+03, -.37068200E+03, -.41333900E+03, 0.28405300E+03, -.88550400E+03, -.60706600E+02, -.45267400E+02, -.80440000E+02, 0.30399800E+02, -.25684600E+02, -.11071400E+02, -.10295200E+03, -.58907900E+02, 0.60473600E+02, 0.42367600E+02, -.73400500E+02, -.53699500E+03, -.11811000E+01, 0.25862800E+02, -.31357000E+03, 0.43055000E+02, 0.12547000E+03, 0.40656900E+02, 0.13910000E+03, 0.29741000E+02, -.71793700E+02, 0.42496900E+01, 0.54451300E+03, -.70400400E+02, 0.80991300E+02, 0.44531400E+02 },
        { -.60498200E+01, 0.20941500E+01, 0.90546300E+00, -.16612100E+01, -.12785400E+01, -.21137000E+01, -.20818900E+01, -.19318400E+01, -.15450600E+01, 0.38693200E+01, 0.26056800E-01, -.11536800E+00, -.19222300E+01, 0.13774400E+01, -.29543200E+01, -.31588600E+01, -.73311400E+00, 0.77454700E-01, 0.10483100E+01, 0.10533900E+01, 0.44567600E+00, 0.14887100E-01, 0.69017600E-01, 0.37590600E+00, -.68384400E+00, 0.67007200E-02, 0.80168900E+00, 0.24783200E+00, 0.27350000E+00, 0.11554600E+01, 0.40263100E-01, 0.88158900E+00, -.23738100E+00, 0.14774000E+01, 0.13864300E-01, 0.65248600E+00, -.32608900E-01, 0.76569700E+00, -.13585000E+00, -.55374600E+01, 0.26968700E+00, 0.74204900E+00, -.15944100E+01, -.28164400E+00, 0.82214700E+00, -.60037800E-01, -.21387300E+00, 0.18583100E-02, 0.31645200E-01, 0.30635500E+00, 0.74203700E+00, -.23781900E+00, -.35411600E+00, -.43319600E+00, -.93446100E+00, 0.86212600E+00, -.11170400E+01, 0.89554800E-01, -.11177300E-01, -.83605900E+00, 0.93598400E+00, 0.27522600E+01, 0.14510600E+01, 0.72099700E-01, 0.54679600E+00, 0.11518300E+00, 0.79864600E+00, 0.53949400E+00, 0.23102300E+00, 0.21245100E-01, 0.31936100E+00, -.36950100E+00, -.42346600E+00, -.24919800E+00, -.22772000E+00, 0.54214900E+00, -.38413900E+00, -.46132200E+00, 0.17777600E+00, 0.35938700E+00, 0.70821900E-01, -.32654200E+00, 0.22206200E+00, -.26917000E+00, 0.18456800E+01, 0.40442300E+00, -.16667400E+01, 0.12478800E+01, -.27605100E+01, 0.18465700E+00, 0.23174600E+01, 0.13179000E+00, -.41558000E+00, -.73762500E-02, -.23789700E-01, 0.25570900E+01, -.82590200E+00, -.15893700E+01, -.54513600E+00, -.20177100E+00, 0.24109800E+00, -.75346900E+00, -.46943400E+00, 0.57820700E+00, -.41216200E+00, -.11712700E+01, -.26573300E+00, -.10946800E+01, -.28588200E+01, -.64172200E+00, 0.10683500E+01, -.13805100E+00, 0.12534300E+00, 0.34831000E+00, -.10785900E-01, -.10192700E+01, 0.11258000E+00, 0.60915500E+00, -.31532100E+00, 0.30144000E-01, -.13775200E+01, 0.11715000E+01, 0.48983700E+00, 0.90789800E+00, 0.46174600E-02, -.19811400E+00, -.31054500E-01, 0.18387200E+00, 0.12987200E+01, 0.22207800E+00, 0.65950100E+00, 0.23383200E+01, 0.71630000E+00, 0.27677900E-01, -.77245900E-01, 0.42669200E-02, -.75216000E+00, 0.59926500E+00, -.85940800E+00, 0.15674500E+00, -.41960900E+00, 0.47216900E+00, -.37759800E-01, 0.43928600E+00, 0.15474300E+00, -.12673400E+01, 0.11378300E-01, 0.69589300E-01, 0.14813800E+04, -.14119900E+04, -.91510400E+03, 0.46008100E+03, 0.13044800E+04, 0.57799400E+03, 0.68988200E+03, -.35281900E+03, 0.22665500E+03, -.34551700E+03, -.12622800E+03, -.29665300E+03, -.35001900E+03, -.11276000E+03, -.12861700E+02, -.30839800E+03, -.76875600E+03, -.97569400E+03, 0.47438200E+03, -.45474600E+03, 0.48842300E+03, -.16547700E+03, -.22099000E+03, 0.41492100E+03, -.54227200E+02, 0.26185700E+03, -.13770000E+03, 0.22289200E+03, -.80508100E+03, 0.40222800E+03, 0.80012100E+02, 0.41513400E+03, -.41564400E+02, -.21783600E+03, 0.21846000E+03, 0.90335900E+02, 0.36851100E+03, -.28471900E+03, 0.41683500E+03, -.37485600E+03, 0.17747900E+03, -.12042800E+04, 0.18714500E+03, 0.41231800E+03, -.87720700E+02, 0.33303800E+03, 0.48894700E+02, -.15687400E+03, -.36259700E+02, 0.36805100E+03, -.70879500E+03, 0.35349000E+03, -.27753700E+02, 0.35234500E+03, 0.34043200E+03, 0.51699500E+02, -.11873500E+03, -.37250900E+03, 0.25522200E+03, -.11669200E+02, 0.34647200E+02, -.43153400E+03, 0.21218400E+03, 0.40825000E+03, 0.21550800E+03, 0.20334700E+03, -.11333100E+03, 0.36923600E+02, -.10538600E+03, 0.19495000E+03, -.39838600E+02, 0.71626500E+02, -.12112600E+04, 0.60574900E+03, 0.35440100E+03, 0.60502200E+03, -.35515500E+03, 0.38980900E+02, 0.23886300E+03, -.17298700E+03, 0.49577700E+03, 0.54262600E+02, 0.12024400E+04, -.12098200E+04, 0.58441400E+03, -.44641100E+03, 0.60940900E+03, 0.36835900E+03, 0.10270800E+04, -.80738200E+03, -.62119400E+03, 0.11053400E+04, 0.87261500E+03, 0.98266800E+03, -.79914500E+03, 0.39669900E+03, 0.18487600E+03, 0.39691400E+03, -.43184500E+03, 0.81591500E+01, 0.27486200E+03, 0.17272600E+03, 0.51214000E+03, -.25488800E+00, 0.11560400E+04, 0.20087900E+03, -.10409300E+03, 0.24527000E+03, -.10429200E+03, -.18885300E+03, -.89847500E+02, 0.43248700E+02, 0.11886100E+02, -.74935100E+02, -.31564400E+02, -.37897000E+03, -.42056800E+03, 0.21360300E+03, 0.42167400E+03, 0.20910000E+03, -.92821700E+02, -.79411700E+02, 0.12096500E+03, 0.72677900E+02, 0.14584000E+03, -.80863600E+02, 0.36438400E+03, 0.18473200E+00, 0.60160100E+02, 0.46888400E+02, -.84567000E+01, 0.30675900E+01, 0.17118900E+02, 0.12654200E+02, 0.10175100E+02, -.29157100E+02, -.15990400E+02, 0.31975000E+02, 0.38911600E+03, -.45625800E+01, -.74648100E+01, 0.26498400E+03, -.21696200E+02, -.99819100E+02, -.33509000E+02, 0.96553300E+01, -.25562300E+02, 0.65348900E+02, -.32336500E+02, -.39611800E+03, 0.14035400E+02, -.21363900E+02, -.97639700E+01 },
        { -.31981300E+01, 0.48287500E+00, 0.19621700E+00, -.65551500E+00, -.13477500E+01, -.19661800E+00, -.18674000E+01, 0.33585600E+01, -.14911400E+01, 0.19349500E+01, 0.10332900E+00, 0.36844300E-02, 0.73337400E-01, 0.25986600E+01, -.74206200E+00, 0.33520000E+01, -.12005200E+01, -.43823300E+00, 0.75050200E+00, 0.85186100E+00, 0.48734500E+00, -.15607700E+00, -.20928300E-01, -.61236700E-01, -.97672500E+00, 0.35499300E-01, -.62870400E+00, -.14403100E+01, 0.80288400E+00, -.84649500E+00, 0.96240300E+00, 0.24484600E+00, 0.15226800E+00, 0.45386400E+00, 0.42490300E-01, 0.15626800E+00, -.18904100E+00, 0.72572600E+00, -.16752800E+01, 0.79764400E+01, 0.12799000E+00, 0.11576200E+00, -.20312900E+00, 0.55063900E+00, -.15588200E+00, 0.42163600E-01, -.37403800E+00, -.53997200E-02, 0.19659800E+00, 0.48145900E+00, 0.40948000E+01, -.47407100E+00, -.77573100E+00, -.13148700E+01, 0.12275900E-01, -.81154000E-01, -.16474100E+00, 0.92730400E-01, 0.35587200E-01, -.19334300E-01, -.14836900E+00, 0.24973600E+01, 0.11221800E+01, -.85611300E+00, 0.35468100E+00, -.17301000E-01, -.32730600E+00, -.15670300E-01, 0.19121500E+00, 0.11885000E-01, -.14861400E+00, -.46952100E+00, 0.11161900E+01, -.12248000E+00, 0.12915900E+00, 0.74948100E+00, -.18794700E+00, 0.91841100E-01, 0.57789700E-02, -.33719900E-01, -.41256000E-01, -.30380900E+00, -.13233200E+00, 0.43345300E+00, 0.14038500E+01, 0.40698800E+00, 0.70101300E+00, 0.10231300E+00, 0.12871700E+01, -.60280000E+00, -.21126700E+00, 0.93077000E-02, 0.76115800E-01, -.10591700E+00, 0.41312000E+00, 0.26496100E+00, -.41053300E-01, -.10132300E+01, 0.34549300E+00, 0.33934100E+00, 0.21195300E+00, -.81787600E-01, -.97941700E+00, 0.53990600E+00, -.50867700E+00, 0.53654400E+00, -.49303800E+00, -.45843700E+00, -.11046600E+01, -.10237600E+00, 0.53686100E+00, -.85396900E-01, 0.14059300E+00, 0.17263600E+00, 0.16841800E-01, -.23730600E-01, 0.64721300E+00, 0.61024600E+00, 0.14506600E+00, -.74826000E+00, -.24732800E+00, 0.39266500E+00, 0.88008800E-01, 0.13285100E+00, 0.16496500E-01, -.22436100E-01, -.11413100E+00, -.82956000E+00, 0.53194600E+00, 0.94433400E-01, -.77700000E+00, -.27930100E+00, -.15652500E+00, -.28014900E-03, 0.36029000E-01, 0.60970300E-02, -.10711200E+01, 0.33347200E-01, -.18085800E+00, 0.24799400E+01, -.68317500E+00, 0.61895200E+00, 0.10517700E+01, -.43357500E-01, 0.52558200E-01, 0.66021300E+00, -.21081000E-01, -.15244900E+00, -.38524400E+00, -.47503600E+03, -.35153800E+03, 0.11062200E+03, -.19352200E+02, 0.67908700E+02, 0.46850200E+03, -.23285100E+03, -.68501600E+02, -.23425300E+03, -.10087300E+03, 0.10475800E+03, -.12394500E+03, -.10909900E+02, -.15988200E+03, 0.30596200E+02, -.71278000E+02, 0.40279300E+02, -.15707300E+02, -.17626000E+03, -.19941900E+02, -.60319200E+02, 0.18726300E+01, -.22428200E+02, -.27404900E+02, -.10442000E+03, -.19922400E+02, 0.10563800E+03, -.44362300E+03, 0.22425500E+03, -.15919800E+03, 0.21907600E+03, 0.50731600E+02, -.19617600E+03, 0.13121200E+03, -.10265800E+03, 0.23083100E+03, -.18649700E+03, 0.41810100E+03, -.22272100E+01, 0.12019900E+02, 0.19368800E+03, 0.14260300E+01, -.96163200E+01, 0.20969300E+03, 0.11469600E+03, 0.18365700E+03, -.90989900E+02, 0.18015100E+03, 0.40282400E+02, 0.58177800E+03, -.29202300E+03, 0.35111000E+02, -.29062900E+03, -.13004800E+03, 0.15428600E+03, -.14790300E+03, -.62511400E+02, -.26634600E+03, 0.11274600E+03, 0.47435200E+02, -.36004900E+03, 0.17602500E+03, 0.18110100E+03, 0.18010000E+03, 0.10771000E+03, 0.59107300E+02, 0.97780800E+02, -.90868600E+02, 0.68056200E+02, 0.72417300E+02, 0.19920500E+03, 0.14249300E+03, -.70410800E+02, -.17894300E+03, -.71221900E+02, 0.13131000E+02, 0.23315900E+02, -.37770300E+01, 0.86376600E+02, -.84576200E+02, 0.56128200E+02, 0.54799800E+02, -.30160500E+03, 0.14022500E+03, 0.21345700E+03, 0.14909200E+03, 0.86346200E+02, 0.24543500E+03, -.31710500E+03, -.25542100E+03, 0.87054100E+02, 0.19494400E+03, 0.11661400E+03, 0.11010200E+03, -.52988100E+02, -.11762600E+03, -.54792000E+02, 0.40900600E+02, -.30052500E+02, 0.31389800E+02, 0.96064700E+02, -.10172400E+03, 0.15573400E+02, 0.16075100E+03, 0.39844500E+01, -.24089700E+01, 0.29217800E+02, -.16761900E+01, -.37586200E+02, 0.53589400E+02, -.11415200E+03, -.12493900E+03, -.12845500E+02, 0.51259800E+02, -.41151000E+02, -.29713400E+02, 0.14688300E+02, 0.23248200E+02, 0.14935900E+02, -.29735300E+00, 0.40820800E+02, -.83701900E+00, -.20859900E+02, -.97876200E+01, -.13020400E+02, 0.10224200E+03, -.29377900E+02, 0.31546600E+02, -.79024700E+01, -.20353000E+02, -.27510300E+01, 0.19952900E+02, 0.19847000E+02, -.10080700E+02, 0.71122300E+00, -.11325200E+02, 0.19574200E+01, -.25587200E+02, -.35812500E+01, -.18573800E+00, -.26407600E+02, -.22094600E+01, -.18588800E+02, -.88186700E+01, -.36396200E+02, 0.24208100E+02, 0.10151000E+02, -.17412400E+02, 0.18738500E+02, 0.13165600E+02, -.23722600E+02, -.15286600E+01 },
        { 0.49080500E+01, 0.11747200E-01, -.19021700E+00, 0.97222500E+00, 0.24714100E+01, -.60406600E+00, 0.34428800E+01, -.55768200E+01, 0.25936400E+01, -.31664300E+01, -.77471100E-01, 0.13558900E+00, 0.17931400E+00, -.42972600E+01, -.10904400E+01, -.39921800E+01, 0.22424000E+01, -.15788400E+00, 0.35583400E+00, -.77948100E+00, -.16066300E+00, 0.55847500E-01, 0.15207100E+00, -.20864000E+00, 0.25522600E+01, 0.70963200E-02, 0.12073800E+01, 0.21444500E+01, -.13796100E+01, 0.78334800E+00, -.81808200E+00, -.81387400E+00, 0.44923100E+00, -.19477400E+00, -.71271400E+00, -.24731300E+00, 0.15020700E+00, -.40459800E+00, 0.19172600E+01, -.98970500E+01, -.59222500E-01, 0.13901900E+00, -.68994700E-01, -.38661500E+00, 0.41908000E+00, -.13481700E+00, 0.80678300E-01, 0.10435100E+00, -.98362600E-01, -.15480000E+00, -.91847600E+00, 0.11148200E-01, 0.30754200E+00, 0.40393800E+00, -.68381100E+00, 0.27135400E+00, 0.10710400E-01, -.20264700E+00, 0.22056800E+00, 0.58457000E+00, -.51312300E+00, -.27474000E+01, -.77603900E+00, 0.87038000E-01, 0.58248300E+00, 0.37648300E-01, 0.14184300E+01, -.18423200E+00, 0.17598700E+00, -.14163000E-01, -.12386400E+00, 0.61857700E-01, -.36961500E+00, -.25227300E+00, -.63795000E+00, 0.92567900E-01, 0.37406700E+00, -.39285900E-01, -.83519300E-01, 0.46442300E+00, -.55941100E-01, 0.36554200E+00, -.13407800E+00, 0.72503600E-01, -.16450700E+01, -.45769800E+00, 0.17192300E+01, 0.14683500E+01, 0.42854000E+00, -.48250200E+00, 0.18782000E+01, 0.11501900E-01, -.33553900E+00, 0.60625700E+00, 0.21164800E+00, -.97949800E+00, 0.15337200E+00, 0.12246500E+01, -.94838800E+00, -.44599800E+00, -.69646600E+00, -.13964400E+00, 0.10518200E+01, -.29683200E+00, 0.48806200E+00, -.71151600E+00, 0.12568000E+01, 0.11664100E+01, 0.14577600E+00, 0.32816800E+00, -.91003600E+00, -.12889100E+00, -.55942200E-01, -.82744300E-01, -.36786700E+00, -.14700600E+01, -.10445600E+01, -.77119600E+00, 0.11848500E+00, 0.28786100E+00, 0.85369000E+00, -.11369100E+01, -.25936600E+00, -.49788600E+00, 0.77065900E-02, -.42861300E-02, 0.10837400E+00, 0.13715700E+01, -.10615900E+01, 0.29762700E-02, 0.15240000E+01, -.58537600E+00, -.97179100E+00, 0.54506100E-02, 0.21250900E+00, 0.16833500E-01, 0.18572000E+01, 0.38523800E+00, 0.81466400E-01, -.13107900E+01, 0.21854600E+00, 0.77865500E+00, 0.27120000E+01, 0.15324100E+00, 0.27504600E-01, -.30975600E-01, 0.19387500E+00, -.49968000E-01, 0.26595800E+00, -.63413800E-01, 0.49171700E+03, -.30075800E+03, 0.75874900E+02, -.22879200E+03, -.53275600E+03, 0.26304500E+03, 0.12914000E+03, 0.26627600E+03, -.18663000E+02, -.66034500E+02, -.26626000E+02, -.17678200E+03, 0.25264600E+03, 0.22327400E+02, 0.43248500E+03, 0.15270400E+03, -.76901900E+02, -.21421600E+02, -.76188100E+02, 0.17262800E+02, 0.67090400E+02, 0.12344100E+03, 0.23794800E+03, 0.17543700E+03, 0.65472900E+02, -.26147900E+03, 0.34453800E+03, -.17428700E+03, 0.56963300E+03, -.16464000E+03, -.21635700E+03, 0.15256500E+03, -.12463600E+03, -.13307800E+03, -.31102100E+03, 0.14550300E+03, 0.38605300E+01, -.78666900E+03, 0.40429500E+03, -.17392200E+03, 0.39219200E+03, 0.24971200E+03, 0.26314600E+03, 0.44713300E+02, -.23633700E+03, 0.14065300E+03, 0.22591300E+03, 0.56736500E+03, -.10113200E+04, 0.50467000E+03, -.82686700E+01, 0.50438400E+03, 0.59754700E+01, -.24353400E+03, 0.36247700E+03, 0.10933800E+03, 0.47403000E+03, -.18404400E+03, 0.43897600E+03, -.66922300E+02, 0.32349800E+02, -.84494800E+02, 0.33140100E+02, -.11074900E+03, -.88420200E+02, -.29323200E+02, 0.83744700E+02, 0.16585400E+03, -.12574100E+03, 0.79755300E+02, -.32970500E+03, 0.16542800E+03, 0.36249600E+03, 0.16466700E+03, -.63111300E+02, 0.27904400E+02, 0.90820700E+02, -.14069100E+03, 0.11978700E+03, 0.25222600E+02, -.27799000E+03, -.82526100E+03, 0.41944400E+03, 0.18954800E+03, 0.41923400E+03, 0.16918100E+03, 0.31198800E+03, -.15870500E+03, 0.15443600E+03, -.29788900E+03, 0.35001400E+03, 0.46941000E+03, -.29908000E+03, 0.14809400E+03, 0.38575300E+03, 0.14817000E+03, -.21488100E+03, 0.63026900E+02, 0.11833300E+03, -.26443300E+03, 0.12532700E+03, 0.29218700E+02, -.30295400E+03, 0.32367700E+02, -.19831800E+02, -.36748800E+02, -.17945500E+02, 0.11684600E+02, -.47757000E+02, 0.16582300E+03, 0.21751300E+03, 0.58646200E+01, -.43116400E+02, -.73948100E+02, 0.21990600E+03, -.10995000E+03, 0.90394300E+01, -.11043300E+03, -.67041100E+02, -.79310000E+02, 0.10282400E+02, 0.60288500E+02, -.10372600E+03, 0.54310600E+00, -.14247300E+03, 0.18801600E+02, -.22884300E+02, 0.26134900E+02, -.92437800E+01, 0.57650500E+01, -.11457100E+02, 0.37069300E+01, 0.17485500E+02, -.90225200E+01, -.33981900E+01, 0.18666600E+01, -.30021800E+01, -.82564200E+01, -.65643200E+01, 0.93711500E+01, 0.28692000E+02, -.50534500E+02, -.17026400E+01, -.44030200E+02, -.40172500E+01, 0.12926100E+02, 0.19382100E+02, -.33868600E+02, 0.18933300E+01, 0.24939200E+02, -.69123900E+01 },
        { -.42984900E+01, 0.24872100E+01, 0.33131500E+00, 0.59088100E+00, -.11560700E+01, -.31563400E+01, -.10660500E+01, -.38049100E+01, -.15329000E+01, 0.30006000E+01, 0.40804500E+00, -.12571000E+00, -.20307100E+01, -.16774100E+01, -.21993300E+01, -.54571800E+00, 0.71646000E+00, -.48468600E+00, 0.13650100E+01, -.18369000E+01, 0.16034800E+00, -.14391300E+00, -.36386200E-01, -.55622700E+00, 0.26422800E+01, 0.95156600E-01, 0.97320800E+00, -.77057700E+00, -.27083800E+00, -.27707300E+00, 0.13359500E+00, 0.41598100E+00, -.95763800E-01, -.51154700E+00, -.33489000E+00, -.24516700E+00, -.22407300E+00, 0.86525900E-01, 0.65907100E+00, 0.22180500E+01, -.37144900E-01, 0.44108200E+00, 0.64031600E+00, 0.96506300E+00, -.14147400E+00, 0.36699900E-01, 0.27903100E+00, 0.75323400E-01, -.23254000E+00, -.63452000E-01, 0.16455700E+00, -.24127500E+00, -.14967900E+00, -.64709000E+00, -.19283900E-01, 0.10955300E+01, -.96130900E+00, 0.51342600E+00, 0.12999100E+00, -.84688100E+00, 0.12589400E+01, 0.12975700E+01, -.16163600E+00, -.45882600E+00, -.61214400E+00, 0.20431700E+00, 0.81393900E+00, 0.34339200E+00, 0.18224800E+00, -.52077800E-03, 0.64179400E+00, 0.33488100E+00, -.11196200E+01, 0.13306600E+00, -.63232200E+00, -.41943100E+00, 0.16973700E+00, 0.45998200E+00, -.63755300E-01, -.52060200E+00, -.28492100E-01, 0.55002900E+00, -.10762100E+00, 0.70947600E+00, -.17557200E+01, 0.55931500E-01, 0.72767900E+00, 0.22583900E+01, 0.15212400E+01, -.19121000E+01, 0.68603300E+00, 0.33984400E-01, -.61858100E-01, 0.11863700E+01, 0.66485900E+00, -.87419900E+00, 0.64192000E+00, 0.12729000E+01, 0.19669700E+00, -.49160800E+00, -.72495200E-01, -.52178700E+00, -.57137900E+00, 0.92265900E+00, -.32569400E+00, 0.40681600E+00, -.18785700E+00, 0.21775100E+00, -.17251100E+01, -.32286300E+00, 0.98803500E+00, -.40464700E+00, 0.10152100E+00, 0.30487300E+00, 0.64124100E-01, -.44865000E+00, 0.35836900E+01, 0.25642200E+00, 0.11701700E-02, -.49857000E+00, 0.92712400E+00, 0.41464400E+00, -.17455000E-02, -.67923800E+00, -.88079900E-01, -.48986500E-01, 0.77415400E-01, -.13176500E+00, -.92750100E+00, -.33287500E+00, 0.45148400E+00, -.31685900E+01, 0.12868100E+01, -.16181300E-01, 0.14706300E+00, 0.97890500E-02, 0.18101100E+01, -.67532500E-01, 0.68886100E+00, -.41388400E+00, -.41049800E+00, -.55038100E+00, 0.15527700E+01, 0.36977300E+00, 0.15562300E+00, -.89737500E+00, 0.52109100E-01, -.21883500E-01, 0.31372200E-01, -.90162800E+00, 0.40215700E-01, 0.78451300E+03, -.79974300E+02, 0.39434400E+03, 0.13824600E+03, -.69215200E+02, -.17610600E+03, -.68925800E+02, -.34390100E+02, 0.35834600E+03, 0.48478600E+02, -.27796600E+03, -.39536300E+03, 0.28310200E+03, -.41014000E+03, -.97254300E+02, 0.46516000E+02, 0.11764300E+03, 0.46159800E+02, 0.28418400E+02, 0.69445100E+02, -.13850700E+03, 0.23116600E+02, -.18003300E+03, -.21066200E+01, -.34658300E+03, -.81243200E+03, 0.40828200E+03, -.10928300E+02, 0.40279600E+03, 0.35753400E+03, -.21390800E+03, 0.63039500E+02, -.26085400E+03, 0.13492000E+03, -.15347700E+03, 0.64686900E+03, 0.26700400E+04, -.13370800E+04, -.91542800E+02, -.13350100E+04, -.48910700E+03, -.16704400E+03, -.80746700E+03, 0.12263300E+03, -.94256300E+03, -.15406100E+03, -.10284700E+04, 0.12275300E+04, -.61387300E+03, 0.57200200E+03, -.61312900E+03, -.49947400E+03, 0.15769700E+03, -.26900300E+03, -.19920000E+03, -.65926900E+03, 0.13055900E+03, -.55738300E+03, -.52986600E+03, 0.26291300E+03, 0.31873600E+03, 0.26499100E+03, 0.18640900E+03, 0.17477700E+03, 0.18184400E+03, -.22075600E+03, -.57129400E+02, 0.23410900E+03, -.33124900E+02, 0.10202500E+04, -.50973500E+03, -.50302000E+03, -.50992100E+03, -.12244400E+03, 0.40655800E+02, -.32051900E+03, -.50950300E-02, -.49590000E+03, 0.46067600E+02, -.20146500E+03, 0.11240900E+04, -.57862200E+03, -.34779800E+03, -.56311800E+03, -.24077100E+03, -.21003900E+03, -.59613800E+02, 0.26629000E+02, 0.74095500E+03, -.25837400E+03, -.25329000E+03, 0.89209500E+03, -.44363700E+03, -.23179100E+03, -.44520300E+03, -.60978500E+02, -.53958300E+02, -.41411300E+03, -.21622800E+03, -.66129000E+03, 0.20202900E+02, 0.72714000E+02, -.26089200E+03, 0.13155700E+03, -.10781700E+03, 0.13170200E+03, 0.80221200E+02, 0.13101900E+03, -.32064300E+02, -.14472800E+03, -.25357600E+02, 0.14679700E+03, -.12033500E+03, -.80365000E+03, 0.40751900E+03, -.36992300E+02, 0.40221700E+03, 0.10384100E+03, -.64708700E+02, 0.28930800E+03, 0.10768100E+03, 0.36132400E+03, -.96763400E+02, 0.54048600E+03, -.34938800E+02, 0.15170500E+02, 0.52953700E+01, 0.21373700E+01, 0.23863600E+02, -.15830200E+01, 0.20357500E+02, -.13553600E+02, 0.92729700E+01, 0.15174600E+02, -.19038600E+02, 0.14477000E+02, 0.44298300E+01, 0.12451800E+02, -.61119800E+02, 0.26165400E+02, 0.30934500E+02, 0.16727400E+02, 0.91930400E+02, 0.63051900E+02, -.46642400E+02, 0.45589400E+02, 0.41195500E+02, 0.25254800E+01, -.42059000E+02, -.30762800E+02 },
        { 0.11485300E+01, -.65197600E+00, -.20307800E+00, 0.18422100E+00, 0.17333700E+00, 0.28669700E+00, 0.62820300E+00, 0.19182400E+00, 0.37553200E+00, -.68438400E+00, -.20456400E-01, 0.30714300E-01, 0.20769400E+00, 0.21031000E+00, 0.32190200E+00, 0.57780600E+00, 0.63276100E-01, -.38119800E-01, -.15754200E+00, 0.11638900E+00, 0.15373100E-02, -.29715600E-01, -.89354400E-02, -.12981600E-01, 0.19662800E+00, -.14420800E-01, -.11169100E+00, -.25108800E-01, 0.12834200E-01, -.16973400E+00, 0.63065400E-01, -.10192400E+00, 0.54413800E-01, -.13437900E+00, 0.25453700E-01, -.97477700E-01, 0.21200600E-01, 0.42442700E-01, -.77147200E-01, 0.16779100E+01, -.19499100E-01, -.86017700E-01, 0.20103300E+00, 0.33823800E-01, -.93023300E-01, 0.13216400E-01, -.11154000E-01, -.27393700E-02, 0.10469200E-01, -.46761400E-01, 0.19001600E+00, -.13968000E-01, 0.23449700E-01, -.35876400E-01, 0.56737600E-01, -.95340700E-01, 0.13045400E+00, -.13146200E-01, -.86712900E-02, 0.19418000E+00, -.14617800E+00, -.26483900E+00, -.13947900E+00, -.44254800E-01, -.33739700E-01, -.34179700E-01, -.19783200E+00, -.57747700E-01, -.31285600E-01, -.57750000E-02, -.13092800E+00, 0.26267200E-01, 0.23055100E+00, 0.50878300E-01, 0.10622800E+00, -.54974400E-01, 0.15517300E-01, -.10046400E-01, -.29299100E-02, -.58406100E-01, -.21452300E-01, -.17382700E-01, -.30062500E-01, -.57748600E-01, 0.95157300E-01, -.92057800E-02, 0.14084900E+00, -.20751000E+00, 0.10561400E+00, 0.66983500E-01, -.10175600E+00, -.18131200E-01, 0.29948800E-01, -.29382600E-01, -.48966500E-03, -.17113000E+00, 0.46913900E-01, 0.19358500E+00, -.14344800E-01, -.22673500E-02, -.46488900E-01, 0.96770400E-01, 0.14299200E+00, -.13371700E+00, 0.99869800E-01, 0.30823100E-01, 0.35767400E-01, 0.12051900E+00, 0.30407800E+00, 0.74936100E-01, -.16215700E+00, 0.21529900E-01, -.25041100E-01, -.63993800E-01, -.21206000E-01, 0.10447900E+00, -.21431000E+00, -.13395200E+00, 0.49889700E-01, 0.51463200E-01, 0.10124300E+00, -.11149100E+00, -.42947500E-01, -.58836300E-01, 0.15454000E-02, 0.81296100E-02, 0.18641600E-02, -.75175300E-01, -.63962600E-01, 0.12140600E-02, 0.71381600E-03, -.18212100E+00, -.11144200E+00, -.29563900E-03, -.73155700E-01, 0.26796700E-02, -.11669900E-01, -.63775100E-01, 0.81768400E-01, 0.26139400E+00, 0.33542000E-01, 0.24556400E-01, -.14742600E+00, -.59583600E-01, -.35975100E-01, 0.71208000E-01, 0.92065700E-02, 0.61259200E-01, 0.51483100E-01, 0.29735000E-01, 0.21082100E-01, -.43433200E-02, 0.39640300E+02, -.55239900E+02, 0.60435600E+02, -.30110500E+02, 0.30411700E+02, -.30301100E+02, 0.73475800E+02, 0.42928800E+02, -.44296500E+01, 0.28345100E+02, -.53163000E+02, 0.21054100E+02, 0.17009100E+03, 0.16844100E+02, -.85225600E+01, -.17193200E+02, -.82740100E+01, 0.44499600E+01, 0.22740900E+02, 0.32536700E+02, 0.65024400E+02, 0.40507800E+02, -.10362300E+02, 0.62798800E+02, -.11377400E+03, 0.56788200E+02, 0.48551300E+02, 0.59580500E+02, -.73524900E+02, -.41585000E+01, 0.32096500E+02, 0.22350300E+02, 0.39493200E+00, 0.17705000E+02, 0.19132200E+03, -.20904500E+03, 0.10643500E+03, -.14417000E+03, 0.10437300E+03, 0.55081400E+02, 0.18407500E+02, 0.51550200E+02, 0.40432200E+02, 0.62095600E+02, -.86761100E+01, 0.15220500E+03, -.34609000E+03, 0.17303900E+03, 0.81181800E+01, 0.17265500E+03, 0.14359000E+03, 0.90379400E+01, 0.91040900E+02, 0.13293700E+02, 0.55309800E+02, 0.13424200E+02, 0.15779800E+03, 0.69503900E+02, -.34783900E+02, -.68977900E+02, -.34815800E+02, 0.16310400E+00, 0.14471000E+02, -.34256700E+02, 0.29562400E+02, -.31188200E+02, 0.49996500E+01, -.36083100E+02, -.11703900E+03, 0.58532600E+02, 0.87887500E+01, 0.58421700E+02, -.11730900E+02, 0.48591400E+01, 0.10047000E+02, -.57165100E+02, 0.51785300E+02, -.33850900E+01, 0.21091500E+02, -.32194600E+02, 0.18055700E+02, -.74881200E+02, 0.17354300E+02, 0.22932700E+02, -.30817500E+01, 0.47581800E+01, 0.49773300E+02, 0.26141000E+01, 0.27482200E+02, 0.15607000E+02, -.26819500E+02, 0.13301800E+02, -.91870800E+02, 0.12930800E+02, -.71429200E+02, -.29940900E+01, 0.45634800E+01, -.39754000E+02, 0.37549200E+02, -.12272100E+02, 0.68122700E+02, 0.57890500E+02, -.29159800E+02, -.16900100E+01, -.29619400E+02, -.24018800E+02, 0.41357600E+01, -.31045400E+01, 0.63839700E+01, -.46134800E+02, -.16568700E+01, -.15569000E+02, 0.42205900E+02, -.21636800E+02, 0.69013700E+02, -.21303800E+02, -.26982000E+02, -.10911800E+02, 0.41118700E+01, 0.46741200E+01, -.26587100E+02, 0.28576300E+01, 0.84487400E+01, 0.59182600E+01, -.12638300E+01, 0.23142900E+01, -.27372800E+01, 0.28863200E+01, -.28454300E+01, 0.12498700E+02, 0.49768300E+01, -.27458200E+01, -.16818200E+01, 0.56407900E+01, 0.10398000E+02, 0.11114800E+01, -.17054400E+01, 0.68404000E+01, -.19666700E+02, 0.52105100E+01, -.48078200E+01, -.24158100E+02, 0.98073300E+00, 0.77694700E+01, 0.76201100E+01, -.13005400E+02, 0.32753500E+01, -.46245600E+01, -.18798100E+01 },
        { -.38614700E+01, -.48142900E+01, -.61967000E+00, -.28645800E+01, 0.16301800E+00, 0.26776100E+01, -.72545700E+01, -.39703200E+00, -.28498400E+01, 0.33648200E+01, 0.24522200E+00, -.36407600E+00, -.45898700E+01, 0.74044700E+01, -.45022000E+01, -.28355700E+01, 0.15489000E+01, 0.11814900E+01, 0.18942900E+01, -.30011500E+01, 0.34998100E+00, 0.17152600E+00, -.93260100E+00, 0.18881100E+00, -.91152700E+00, 0.32724500E-01, 0.20990300E+00, -.14410200E+01, 0.63777800E+00, -.16300900E+00, -.35645300E+00, -.80434800E+00, -.94973700E+00, 0.73378400E-01, 0.40658300E+00, -.72618500E-01, 0.36641700E-01, -.59091900E+00, -.17973600E+00, -.33454600E+01, -.14794600E+00, -.14027200E+00, 0.83398500E+00, 0.66543800E+00, -.41523200E+00, 0.28928300E-01, 0.14632900E+00, -.83250300E-02, 0.87111400E-02, 0.52725600E-01, -.93295700E+00, 0.33542400E+00, 0.14623300E+00, 0.65196400E+00, 0.11385800E+01, -.27950200E+00, -.10769500E+00, 0.31086200E-01, 0.46366000E-01, -.45298500E+00, 0.10782400E+00, 0.13251700E+01, 0.96747700E+00, -.79611000E+00, -.75702600E-01, 0.37965100E-01, -.39668400E+00, -.27833700E-01, -.68041600E-01, -.15298200E-01, 0.83406000E+00, -.45399600E-01, -.85183500E+00, -.21483300E-01, -.69776900E+00, -.37098200E+00, 0.20345100E+00, 0.26125500E+00, -.27698600E+00, -.17060900E+00, 0.14635100E+00, 0.82057600E+00, 0.13737100E+00, 0.38152100E+00, -.26450400E+01, -.17694900E+00, 0.86760900E-01, 0.16804200E+01, -.89555000E+00, -.57161600E+00, -.59313500E+00, 0.44669900E-01, 0.81699100E-01, 0.31620900E+00, -.11517000E+00, 0.31682500E-02, -.99810600E-01, 0.20368300E+00, 0.28633800E+00, -.23230700E+00, -.60201900E+00, -.11310300E+00, -.10462800E+00, 0.28946200E+00, -.36157600E+00, 0.21848700E+00, 0.56898500E+00, 0.78309900E+00, 0.15112900E+00, -.32518000E-01, 0.18693500E+00, 0.29917000E+00, 0.71843100E-01, 0.29750600E+00, 0.34785200E+00, 0.12389000E+01, -.27372300E+01, 0.72019700E+00, 0.27472000E-01, 0.76747800E+00, -.96463100E+00, 0.13542400E+01, 0.14730200E+00, 0.10485200E+01, 0.34362400E-01, 0.17332700E+00, 0.11102200E+00, -.42297700E+00, 0.96351000E+00, 0.73246100E+00, -.10237500E+01, 0.15895200E+01, -.41519600E+00, -.20626300E-01, -.44279500E+00, -.29375100E-02, -.91619400E+00, -.74847000E+00, 0.24361400E+00, -.20877100E-01, -.18633700E+00, 0.47824300E+00, -.76227600E+00, -.40432000E-01, -.31731200E+00, 0.87289300E+00, 0.41522600E-02, 0.32211900E+00, 0.25961100E+00, -.28806600E+00, 0.55338500E+00, 0.62406700E+00, 0.39577300E+00, -.37339000E+03, 0.44062800E+03, -.21425500E+03, 0.10866300E+02, -.22078900E+03, -.21383600E+03, -.15836800E+03, -.14434000E+03, 0.22700800E+03, -.54420200E+02, -.19831100E+03, 0.69227300E+03, 0.17812600E+02, 0.71689200E+01, -.52198700E+03, -.62352400E+01, -.86569400E+02, -.13936900E+03, 0.12111400E+03, -.16377200E+03, -.66385800E+01, -.78743600E+02, 0.74127000E+03, 0.34829400E+03, -.16724500E+03, -.52507600E+03, -.16478300E+03, -.89521000E+02, 0.24113300E+03, -.46074900E+02, 0.41936000E+03, 0.11872200E+03, 0.14552000E+03, 0.21942300E+02, -.12883200E+04, 0.66193900E+03, -.28370700E+02, 0.64430000E+03, 0.20752200E+03, -.12531400E+03, 0.60737200E+03, 0.10671900E+03, 0.44699100E+03, -.11196400E+03, 0.41525900E+03, -.84482700E+03, 0.42228700E+03, -.13355600E+03, 0.42102700E+03, 0.25988900E+03, -.27858400E+02, 0.46240200E+02, 0.51294200E+02, 0.26411100E+03, -.48736800E+02, 0.47614700E+03, 0.59864500E+03, -.30164600E+03, -.19965500E+03, -.29945800E+03, -.15930200E+03, -.13098600E+02, -.12893100E+03, 0.14218100E+03, -.81854200E+02, -.55626900E+02, 0.24022200E+03, -.12876400E+04, 0.64429200E+03, 0.39930900E+03, 0.64334900E+03, 0.66592200E+02, -.27080300E+02, 0.26511700E+03, -.32368500E+02, 0.67484900E+03, -.35106200E+02, 0.78710600E+03, -.31655400E+03, 0.16275900E+03, -.30332900E+00, 0.16008500E+03, 0.61501200E+02, -.33972000E+02, 0.16969600E+03, 0.28646800E+03, -.36004300E+01, -.46222500E+02, -.24653900E+03, -.14637400E+04, 0.73453500E+03, 0.64987100E+02, 0.72998000E+03, 0.80973400E+02, 0.11915400E+03, 0.39199000E+03, 0.34136900E+03, 0.10041500E+04, 0.33269400E+02, 0.93637500E+03, 0.15207900E+03, -.74870300E+02, 0.64805100E+02, -.78831700E+02, -.86082300E+02, -.40806400E+02, -.45576600E+02, -.14548200E+02, -.34905300E+02, -.68925300E+02, 0.21638500E+03, 0.31859000E+03, -.16655400E+03, 0.12779300E+03, -.16017100E+03, -.57115800E+02, 0.10194200E+03, -.21469500E+03, -.95552700E+02, -.19513000E+03, 0.80873300E+02, -.26771600E+03, 0.17117300E+02, -.11541700E+02, -.24547100E+02, 0.68708200E+01, -.25957900E+02, 0.11665100E+01, 0.44493200E+01, -.69364300E+00, 0.42055000E+01, -.60122100E+01, 0.19690900E+02, 0.99076500E+01, 0.42055100E+01, -.51991900E+01, 0.48598000E+02, -.77591800E+01, -.21548000E+02, -.35303100E+02, -.42893400E+02, -.23338500E+02, 0.13333100E+02, -.23826800E+02, -.28905400E+02, -.28704700E+02, 0.17375800E+02, 0.32793700E+02 },
        { -.84512700E+01, 0.58160800E+01, 0.14865800E+01, 0.52936900E+00, -.18701200E+00, -.48536700E+01, -.54066700E+01, 0.55480100E+00, -.39397300E+01, 0.50681400E+01, 0.76470300E-01, -.36686300E+00, -.17177300E+01, -.16130800E+01, -.65779700E+00, -.28746200E+01, 0.18766200E+01, 0.50230000E+00, 0.20181100E+01, -.16495400E+01, -.19144300E+01, 0.31694000E+00, -.24148400E+00, -.34403900E+00, 0.36525600E+00, 0.20977400E+00, 0.24448100E+01, 0.14778400E+01, -.10969400E+01, 0.85527400E+00, -.76201700E+00, -.74227700E+00, -.69894500E+00, 0.57380200E-01, -.41271800E+00, 0.14693300E+00, -.52614600E+00, -.96035000E+00, 0.51710600E+00, -.98940800E+01, -.11904600E+00, 0.58294400E+00, -.81238400E+00, 0.82179600E+00, 0.17053700E+01, 0.24763100E+00, 0.13570100E+01, 0.29462300E-01, 0.19555100E+00, 0.11896700E+00, 0.17222800E+01, -.14256500E+01, -.17365400E+01, -.98631900E+00, -.26923700E+01, 0.39666400E+00, -.29508700E+01, -.11214700E+00, -.51733400E-02, -.76541800E+00, 0.31401000E+00, 0.28341300E+01, 0.24351700E+01, -.22714400E+01, 0.42669000E+00, 0.70975800E-01, 0.14183500E+01, 0.47111500E+00, 0.46203800E+00, 0.11788600E+00, 0.14899400E+01, -.19900200E+00, -.25367800E+01, -.34946000E-01, -.10484600E+01, -.14954300E+01, -.25748300E-01, -.64800300E+00, -.10890100E+00, -.14390200E+00, 0.49096100E+00, 0.10367800E+01, -.16164400E+01, 0.54224900E+00, -.34600300E+01, -.23674600E+00, 0.10982600E+01, 0.25916700E+01, 0.10805900E+01, -.17271900E+01, 0.65211900E+01, 0.22029100E+00, 0.32197000E+00, 0.31534300E+01, 0.29093500E+01, -.26530100E+01, 0.99164900E+00, -.63948200E+00, 0.17237100E+01, -.10166500E+00, -.84573900E+00, 0.10002400E+01, -.13849000E+01, -.44462300E+00, -.13395900E+01, 0.19130100E+01, 0.16416000E+01, 0.23532700E+01, -.35859100E+01, -.18427700E+00, 0.16259400E+01, -.53095100E+00, 0.28487300E+00, 0.69065600E+00, 0.89914800E+00, -.22700400E+01, -.16066500E+01, 0.18754500E+01, -.43855200E-01, -.64786600E+00, 0.48407900E+00, 0.87761400E+00, -.38284200E-01, -.11195400E+01, -.78791400E-01, -.80872400E+00, 0.70490400E+00, -.37491900E+00, -.96575400E+00, -.78172400E+00, 0.11289400E+01, -.96581300E+00, 0.61375800E+00, -.15677200E-01, -.48927200E+00, 0.18954500E-03, -.59019100E+01, 0.19040900E+00, -.49232500E-01, 0.53187700E+01, 0.24638300E+00, 0.49531900E+01, -.17215200E+01, -.52405300E+00, -.61570600E+00, 0.82951400E+00, 0.11498400E+00, 0.66291000E-01, 0.11520500E+00, 0.10242000E+01, 0.78367800E+00, 0.32326500E+00, 0.84895600E+00, -.93924800E+00, 0.23271600E+04, -.11604800E+04, -.28277700E+02, -.11643800E+04, 0.16353900E+03, 0.53460900E+02, -.51635500E+03, 0.51142700E+03, -.12642800E+04, -.85284000E+02, 0.93156900E+03, -.65772600E+01, 0.55664800E+00, -.92276500E+03, 0.97206900E+01, -.12992600E+03, -.21970900E+03, 0.21967400E+03, -.30886800E+03, -.13186200E+03, -.10783600E+03, 0.15038300E+04, -.18557800E+03, 0.98190600E+02, -.16911100E+04, 0.11668400E+03, -.81877400E+03, 0.27798300E+03, 0.89072400E+02, 0.95000800E+03, 0.85262600E+03, 0.36528900E+02, 0.89276700E+03, -.31595900E+04, 0.15618700E+04, -.23114800E+03, 0.15795500E+04, 0.40151500E+03, -.27059200E+03, 0.11636700E+04, 0.32695900E+03, 0.12517100E+04, -.20423900E+03, 0.95922400E+03, -.11128400E+04, 0.56012400E+03, 0.27737300E+02, 0.55364700E+03, 0.90478400E+03, 0.18016700E+03, -.17454200E+03, 0.75207600E+02, -.19888600E+03, 0.14158500E+03, 0.49336900E+03, 0.14512200E+04, -.72015100E+03, -.50166200E+03, -.72597600E+03, -.48819400E+03, -.39227000E+02, -.42432300E+03, 0.35633100E+03, -.36338800E+03, -.23364700E+02, 0.53254100E+03, -.17490000E+04, 0.87245100E+03, -.30351000E+02, 0.87366600E+03, -.17029800E+03, -.18892200E+03, 0.38955800E+03, 0.85612000E+02, 0.16930800E+04, -.24339400E+03, 0.88111900E+03, -.33012000E+03, 0.18561800E+03, -.15160200E+03, 0.17089900E+03, 0.86844400E+02, -.15342700E+03, 0.22047400E+03, 0.78859600E+03, 0.60321400E+02, -.13653500E+03, -.13150800E+01, -.97164900E+03, 0.48272000E+03, -.14038100E+04, 0.48219900E+03, -.56480600E+03, 0.18680200E+02, 0.38087400E+03, 0.96440600E+03, 0.23588800E+04, -.24127700E+03, 0.10905800E+04, -.36530300E+01, 0.46899600E+01, 0.25861800E+03, -.33971100E+01, -.14347700E+03, 0.35232200E+02, -.31430500E+02, -.13524900E+03, 0.12064800E+03, -.63865300E+02, 0.61559800E+03, -.45233400E+01, -.13042400E+02, 0.74217600E+03, 0.65828900E+00, -.99271500E+01, 0.27139900E+03, -.34575900E+03, -.26043900E+03, -.14110900E+03, 0.13739900E+03, -.16671900E+03, 0.54374000E+02, -.63367700E+02, -.62491100E+02, 0.41264100E+02, -.45162700E+02, 0.40006000E+01, 0.45625500E+02, 0.49369200E+01, 0.23158600E+01, 0.98772300E+01, 0.15839000E+02, -.30058600E+02, 0.19032400E+02, -.63570100E+01, 0.79147300E+02, -.82279200E+02, -.17693600E+02, -.74363200E+02, -.10984300E+03, 0.64162200E+01, -.66014900E+00, 0.15187000E+03, -.13574800E+02, -.12427100E+03, 0.51225000E+01, 0.66546500E+02 },
        { -.94451000E+01, -.12585900E+02, -.13344500E+01, -.60272200E+01, -.21184100E+01, -.19578300E+00, -.11623500E+02, -.75429200E+00, -.56846100E+01, 0.88689800E+01, 0.37432900E+00, -.51323100E+00, -.28658000E+01, 0.11380500E+02, -.45961400E+01, -.10242500E+01, 0.81890200E+00, 0.24816100E+01, 0.70106600E+00, -.31164200E+01, 0.67958200E+00, 0.37452700E+00, -.48568000E+00, -.42734500E-01, -.47856800E+00, 0.82342700E-01, -.63481200E+00, 0.98340700E+00, -.16572400E+01, 0.29069400E+01, -.88545500E+00, 0.16690100E+01, 0.92143100E+00, -.82565800E+00, 0.12577400E+01, -.46051100E+00, 0.44655900E+00, -.93597200E+00, -.85573400E+00, -.24258400E+01, 0.48086500E-01, -.97988300E-01, 0.78297200E+00, 0.84018200E+00, -.19326800E+00, -.59384700E-01, 0.14434700E+01, -.52784200E-01, -.10383200E+00, -.26085800E+00, -.19597900E-01, 0.50009900E+00, -.12121400E+00, 0.53796900E-01, 0.92687600E+00, -.11757900E+01, 0.78840800E+00, -.46721500E+00, -.10691500E+00, 0.14394600E+00, 0.10278100E+01, -.53995800E+01, -.28783700E+01, -.17656900E+01, 0.84356000E+00, -.91841000E-01, 0.20121800E+01, -.98345200E+00, -.47301000E-01, -.62415100E-01, -.21018100E+00, 0.46880600E+00, 0.91657700E+00, 0.34227500E+00, -.10438800E+01, -.74122400E+00, 0.34317200E+00, -.98571100E+00, -.48908300E+00, 0.92360000E+00, 0.21119100E+00, 0.65297200E-01, -.15031500E+01, 0.42579400E+00, 0.11161800E+00, 0.17312600E+00, 0.46370700E+01, -.25535000E+00, 0.18766100E+01, 0.67843500E+00, -.36300800E+01, -.88909600E-01, -.67072800E+00, -.79849000E+00, 0.15574300E+01, 0.10211300E+00, 0.37704500E+00, -.31831300E+00, 0.15169200E+01, 0.70352900E+00, 0.83294400E-01, -.86960600E+00, 0.68635500E+00, 0.17789400E+01, 0.11632900E+00, 0.14592500E+01, -.32721400E+00, 0.10963600E+01, 0.58474400E+00, 0.12451400E+00, -.22712400E+01, 0.73354300E+00, -.27969900E-01, -.30207300E+00, 0.14211200E+00, -.25614600E+00, -.17605200E+01, -.26479700E+00, 0.74355800E-01, 0.19612700E+00, -.14808400E+00, -.83452900E+00, 0.99643000E-01, -.40422100E+00, -.51104700E-01, -.37536900E+00, -.42749900E-01, 0.71197000E+00, -.58581600E+00, -.56024300E+00, 0.59314700E-01, -.27702900E+00, -.20916100E+00, 0.10991000E+00, -.27696300E+00, 0.20215000E-01, 0.71460800E+00, 0.43266000E+00, -.37302700E-01, -.50824800E+00, 0.28530700E-01, -.75532700E+00, -.10759400E+01, -.72324400E-01, 0.46748100E+00, -.15963100E+01, -.39894500E-01, -.25113500E+00, 0.43815300E-01, 0.48644800E+00, -.34699700E+00, -.36042000E+00, 0.72283600E-01, -.13694400E+01, 0.26115700E+00, 0.12733100E+02, -.63447400E+02, -.24993200E+00, -.11031400E+02, -.44250100E+02, 0.13578800E+03, 0.12976200E+03, 0.39064200E+02, -.44655700E+02, 0.11490600E+03, 0.26552600E+03, -.11592100E+03, -.79768600E+02, -.13262100E+03, 0.53458400E+02, 0.11037400E+03, -.67447500E+02, -.29807600E+02, -.85990600E+02, 0.77704500E+02, -.19721000E+02, 0.48423800E+03, -.23415800E+03, -.39687700E+03, -.23919700E+03, 0.16555000E+03, 0.23389600E+03, -.13829300E+03, 0.12801900E+03, -.20634000E+03, 0.21925800E+03, -.23927300E+03, -.42690900E+03, 0.22835100E+03, 0.12513700E+03, 0.21383800E+03, 0.38434700E+02, 0.39346400E+02, 0.13971700E+03, 0.12875400E+02, 0.15854100E+03, -.65054500E+01, 0.16806400E+03, -.38309500E+03, 0.19254200E+03, 0.71883900E+02, 0.19107500E+03, 0.79153300E+02, -.20190600E+02, 0.11124100E+03, 0.37947500E+02, 0.12717800E+03, -.15598900E+02, 0.20667600E+03, 0.14004300E+03, -.72433700E+02, -.62441500E+02, -.70019900E+02, -.28732200E+02, 0.22743500E+02, 0.48973900E+02, 0.66599100E+02, -.44649800E+00, -.10707300E+02, 0.60893100E+01, -.89600300E+03, 0.44948200E+03, 0.37471100E+03, 0.44777800E+03, 0.88059000E+02, 0.94227700E+02, 0.11734500E+03, -.13671400E+03, 0.25662700E+03, 0.87282800E+02, 0.58861800E+03, -.18379800E+03, 0.86418300E+02, 0.67822600E+02, 0.91228300E+02, -.16110400E+02, -.34001500E+02, 0.10754800E+03, 0.78903000E+02, 0.75745500E+02, -.55121000E+02, 0.41492400E+02, -.10657200E+04, 0.54038300E+03, 0.35321600E+03, 0.53212200E+03, 0.18570700E+03, 0.21877400E+03, 0.16350400E+03, -.27830300E+02, 0.34341500E+03, 0.18016400E+03, 0.64870900E+03, 0.12347100E+03, -.58787700E+02, -.56911100E+02, -.62891600E+02, -.40470400E+02, -.21018000E+02, -.11188400E+02, -.10814700E+02, -.10127400E+03, -.18902300E+02, -.21769500E+02, 0.28561100E+03, -.15274800E+03, -.39264100E+01, -.14318600E+03, -.51023900E+01, -.16541800E+02, -.44962000E+02, 0.31267600E+02, -.11871400E+03, 0.18456500E+02, -.16389000E+03, -.49497200E+00, 0.47636100E+01, -.78499700E+01, 0.80115100E+00, -.55957500E+01, -.13758300E+02, -.11035200E+01, -.69825500E+01, 0.80688500E+01, 0.59527300E+01, 0.21906000E+01, -.11442500E+02, 0.47060300E+01, 0.31657900E+01, -.20081200E+01, -.26933900E+01, 0.55748000E+01, -.11523000E+02, -.18496200E+02, -.99667700E+01, 0.90643200E+01, 0.47482200E+01, 0.94305300E+01, -.20039800E+02, -.45462400E+01, -.10512000E+01 },
        { -.15834200E+01, 0.99510200E+00, -.14721900E-01, 0.46497600E+00, -.49712700E+00, 0.32753200E+00, -.22792900E+01, -.62909800E+00, -.10629700E+01, 0.10734300E+01, -.89627700E-01, -.23979500E+00, -.14490300E+01, 0.16176100E+01, -.47359100E+00, -.63525000E+00, 0.53621900E-01, 0.67043000E+00, -.27120200E+00, -.44894400E+00, -.45389200E+00, 0.51966500E-01, -.15834000E+00, -.24418000E+00, -.96557500E-01, 0.75939000E-01, 0.29973000E+00, 0.43275400E+00, -.44470900E+00, 0.67456400E-01, 0.63862100E-01, 0.24135600E+00, 0.31264700E+00, 0.27248800E+00, 0.40184300E+00, -.14823000E-01, -.83811900E-01, -.30451400E-01, 0.41860900E+00, 0.24905400E+01, -.48101200E-01, 0.52833300E-01, -.12709800E+00, -.21504400E+00, 0.60552100E-03, -.16079500E-01, -.21494800E-01, 0.12042200E-01, -.70124400E-01, -.10494000E+00, -.83415200E+00, -.37829200E+00, 0.38920100E+00, 0.66337500E+00, 0.75774900E+00, -.33273600E+00, 0.20043200E+00, -.15615400E+00, -.11274500E-01, -.80647000E-01, 0.10934200E+01, 0.27533100E-01, -.18875400E+00, 0.45519900E+00, -.42762900E+00, 0.19495400E-01, -.18574600E-01, 0.15617100E+00, -.10269100E+00, 0.27077200E-01, 0.17763600E+00, 0.15913600E+00, 0.37782600E+00, -.24071700E+00, -.35261700E+00, 0.56887300E+00, -.29377800E+00, -.14288300E+00, -.41310500E-01, 0.32488000E+00, -.10047000E-01, -.50539800E-01, -.39033200E+00, 0.92140000E-02, 0.52057000E+00, 0.17433900E+00, 0.17337100E-01, 0.27266000E+00, 0.14333000E+01, -.69572700E+00, -.12023700E+01, 0.49802200E-02, -.40563500E-01, -.16908200E+00, 0.10370700E+00, -.46552600E+00, -.79945400E-01, -.10487300E+00, -.16124500E+00, 0.14976200E+00, -.46953900E-01, 0.22411900E+00, 0.13911100E+00, -.48703900E+00, 0.32330200E-01, 0.58970900E-01, -.16944900E+00, 0.88121100E-01, 0.27086600E+00, 0.22024900E-01, 0.21512600E+00, -.88535900E-01, -.10549100E+00, -.96371000E-01, -.35623500E+00, -.50061700E+00, 0.16643100E+01, -.50149800E+00, -.24120800E+00, -.11602700E+00, 0.29642900E+00, -.38031700E+00, -.81187200E-01, -.38150000E+00, 0.74036500E-03, 0.18203800E-01, -.16811500E-01, 0.90319200E-01, -.22589200E+00, 0.59219400E-01, -.49773100E+00, 0.41894100E+00, -.82331800E+00, 0.20370900E-02, -.18587300E-01, 0.52061600E-02, 0.13634000E+00, -.75725600E-01, -.12406900E+00, -.57593700E+00, -.23571300E+00, -.74630500E+00, -.22914700E+00, -.18613900E+00, 0.94380300E-02, 0.16672000E+00, -.21235400E-01, -.35883700E-01, -.94026400E-01, 0.39423900E+00, 0.17788900E+00, -.29263200E+00, 0.20680500E+00, 0.11567900E+00, 0.98670100E-03, -.62184000E-01, -.43739300E+02, 0.23015400E-01, -.73157100E+02, 0.95747600E+02, 0.39034000E+02, -.44421900E+02, -.28761800E+02, 0.91622800E+02, -.56617300E+02, -.21559800E+01, 0.18898600E+01, -.44168800E+02, 0.87001000E+00, -.78589200E+01, 0.24962500E+01, -.20568000E+02, 0.35820600E+02, 0.39985400E+02, -.12637100E+02, -.11246100E+03, 0.39353500E+02, -.19404500E+02, -.18855900E+03, -.22100700E+02, 0.60080900E+01, -.19225400E+02, -.46025900E+02, -.75788200E+02, -.71558600E+02, 0.46630300E+01, 0.60699600E+02, 0.38179100E+03, -.18885400E+03, 0.79011000E+02, -.19060600E+03, -.55516400E+02, 0.12202800E+02, -.11331600E+03, 0.21198100E+02, -.16927100E+03, 0.80954100E+01, -.85294800E+02, 0.24921600E+03, -.12471800E+03, 0.15311200E+03, -.12429100E+03, -.17123300E+03, -.60262900E+01, -.25606300E+01, 0.33695700E+02, -.93015700E+02, -.57033800E+01, 0.17640500E+02, -.14317200E+03, 0.70844300E+02, 0.52183100E+02, 0.71663000E+02, 0.35079600E+02, 0.38268800E+02, 0.58679100E+02, -.20363500E+02, 0.46683500E+02, 0.34211300E+02, 0.12051100E+03, 0.34801600E+03, -.17353200E+03, -.18828200E+03, -.17396100E+03, 0.13122200E+02, 0.29562000E+02, -.10658500E+03, 0.10423100E+02, -.18297900E+03, 0.40563500E+02, -.20643800E+03, 0.11102800E+03, -.57342800E+02, 0.47787400E+02, -.57196000E+02, -.22064000E+02, 0.36808900E+01, -.69330900E+01, -.41037400E+02, -.43689800E+02, 0.38062500E+01, -.33922700E+02, 0.40004900E+03, -.19894100E+03, -.27155200E+03, -.19968400E+03, 0.81371900E+01, 0.19270100E+02, -.13588800E+03, -.16864500E+02, -.24819500E+03, 0.44020000E+02, -.22173800E+03, -.10675600E+03, 0.53235200E+02, -.85279400E+02, 0.53820600E+02, 0.80709100E+01, 0.36430100E+02, -.79917100E+01, -.50634400E+02, 0.12949200E+02, 0.37586300E+02, -.12294400E+02, -.13197100E+03, 0.66692800E+02, 0.98378400E+00, 0.66106100E+02, 0.17435600E+02, 0.18238200E+02, 0.32460100E+02, -.13453500E+02, 0.11799400E+02, 0.16084400E+02, 0.55127300E+02, -.90963500E+01, 0.66350300E+01, 0.85170400E-01, -.13112700E+01, 0.26555000E+01, -.12085600E+01, 0.13645800E+01, -.20442300E+01, 0.38597400E+01, 0.40067000E+01, -.51117000E+01, 0.10106800E+02, -.12631400E+00, 0.29221600E+01, -.52634300E+01, 0.30517000E+02, -.62319000E+01, 0.93438300E+01, 0.18179600E+02, 0.17260800E+02, 0.32400300E+01, 0.36849400E+02, -.42837100E+01, -.61762900E+01, -.14093100E+02, 0.71772900E+00 },
        { -.62399000E+01, 0.41535000E+01, 0.56885000E+00, -.98543100E+00, -.38713600E+01, 0.41728800E+01, -.62316400E+01, 0.43821400E+01, -.32973900E+01, 0.37434100E+01, 0.49102200E-02, -.59399200E+00, 0.74035200E+00, 0.36860400E+01, -.21172000E+01, 0.22405700E+01, -.12724800E+01, -.31196600E+00, 0.81317200E+00, -.75051900E+00, 0.11801200E+01, 0.63555900E-01, -.10429900E+00, -.36091200E+00, 0.24039600E+01, 0.22959400E+00, -.66300200E+00, -.64163300E+00, -.39383300E+00, -.13615600E+01, 0.72193200E+00, -.44306300E+00, 0.88853500E+00, -.18124800E-01, 0.29846700E+00, -.14095800E+00, -.45263800E+00, 0.44336400E+00, -.17219300E+01, 0.66962600E+01, -.13616600E-01, -.24270500E+00, 0.82191700E+00, 0.30346900E+00, 0.35298800E-02, 0.41801000E+00, -.67538000E-01, -.40497700E-02, 0.32710500E-01, -.73143500E-02, -.17831500E+01, 0.19874900E+00, 0.26991800E-01, 0.75339700E+00, 0.82457000E+00, -.13065800E+01, 0.34290000E+00, 0.13115800E-01, 0.68625300E-01, -.77632400E+00, 0.52940200E+00, 0.96414800E+00, 0.52411600E+00, -.22860100E+00, -.11991400E+01, -.46517400E-01, 0.25281200E+00, 0.33990400E+00, -.41504600E+00, 0.45682800E-01, -.11806300E+01, 0.10366500E+01, -.13600600E+01, 0.44243400E+00, -.42649500E+00, -.63888400E+00, 0.32616300E+00, 0.42536900E+00, 0.34024000E-01, -.60850400E+00, -.81558000E-03, 0.17234800E+00, 0.36872700E+00, 0.23698800E+00, -.11639100E+01, -.48989300E+00, 0.11398100E+01, 0.79977700E+00, -.24249800E+00, 0.38142200E+00, 0.26181000E+01, 0.14747300E-01, -.13501300E+00, 0.83083500E-01, -.10715100E+00, 0.12117900E+01, 0.11431300E-01, 0.87073000E-01, 0.10323600E+00, -.15713900E-01, -.26612300E+00, 0.20305900E+00, -.36423600E-01, 0.32868200E+00, -.24375400E+00, 0.40765500E+00, 0.10313600E+01, 0.44014500E+00, -.58029600E+00, 0.95107600E-01, 0.12522300E+00, -.12723500E+00, -.17477000E-01, 0.16395600E+00, 0.17895000E+00, 0.67792400E+00, -.13224900E+01, -.10437500E+00, 0.26120000E+00, 0.17632300E+00, 0.16220300E+00, -.84607900E-02, -.20025200E+00, -.19229900E+00, 0.43438900E-01, 0.19225800E+00, 0.47253800E-01, -.61621500E+00, 0.73611800E+00, -.42541200E+00, 0.13488700E+01, -.21195000E+01, 0.13729700E+01, 0.55479600E-02, 0.15057400E+00, -.86275100E-02, 0.14031300E+00, 0.15958500E+00, 0.24735200E+00, -.29583800E+01, 0.43678600E+00, 0.55048700E+00, 0.84439700E+00, 0.51085000E-01, 0.51946900E-01, -.62433400E+00, 0.20894600E+00, -.20060500E+00, 0.74760500E-01, -.35307900E+00, -.14486600E+00, -.74895800E-01, 0.30831600E+00, -.37707200E+00, -.42348400E-02, 0.49441500E-01, -.80426800E+00, 0.89851500E+01, -.12528300E+03, -.82936200E+02, -.48550200E+02, -.83884200E+02, -.53180000E+02, -.77748300E+02, -.11587000E+03, 0.14341500E+03, -.70102300E+02, -.64948000E+02, -.70232500E+02, 0.38702900E+02, 0.93841800E+02, -.66478700E+02, -.69839300E+02, -.98048100E+02, 0.80840800E+02, -.11533500E+03, 0.64754600E+02, -.30752500E+02, 0.36297000E+02, -.31450400E+02, 0.12480500E+03, 0.56835000E+02, -.82531900E+02, -.25939400E+02, 0.18863100E+02, 0.13474600E+01, -.37650600E+02, -.16437200E+02, 0.11198100E+02, 0.12295500E+01, 0.75796900E+01, 0.19780400E+02, 0.10976700E+03, -.11976100E+03, -.13938000E+03, 0.16722100E+02, 0.90363700E+02, 0.26081800E+02, 0.27714300E+03, -.13883300E+03, -.72186700E+02, -.13829800E+03, -.16998500E+03, -.40209500E+02, -.16563800E+03, -.57330800E+02, -.31064800E+02, -.62850200E+02, -.16151200E+03, -.11682700E+03, 0.58233700E+02, 0.87229500E+02, 0.58362800E+02, -.23374400E+01, -.44474200E+02, 0.43426500E+02, -.75061000E+01, 0.10328400E+03, -.10404300E+02, 0.91677800E+02, 0.51801400E+02, -.26264400E+02, 0.29128800E+02, -.25696900E+02, -.58804200E+02, -.13424200E+02, 0.16767300E+02, 0.13782700E+03, 0.67880500E+02, -.68433300E+01, 0.80686100E+02, -.26244800E+03, 0.13145900E+03, -.13361100E+02, 0.13323500E+03, 0.28991300E+02, 0.51060700E+02, -.20835900E+02, -.67882100E+02, 0.17021900E+03, 0.32845800E+02, 0.11652900E+03, -.13914800E+03, 0.69157500E+02, 0.16485600E+03, 0.70117700E+02, 0.27541700E+01, 0.24646200E+02, 0.26769300E+02, 0.14842800E+03, 0.17022500E+03, 0.15558700E+02, 0.11968600E+03, -.80810900E+02, 0.40312900E+02, 0.82443000E+02, 0.41308100E+02, -.15032700E+02, -.49016500E+02, 0.10671400E+03, 0.63489500E+02, 0.58718600E+02, -.27070300E+02, 0.21135900E+02, -.18000100E+03, 0.90100200E+02, -.86287900E+02, 0.90316200E+02, 0.72889000E+02, -.12525300E+02, 0.26666500E+02, 0.42553500E+02, 0.11659700E+03, -.38150700E+02, 0.90678000E+02, -.79356000E+01, 0.10239400E+02, 0.52529400E+01, 0.59613800E+01, 0.17691600E+00, -.23552300E+01, -.10607600E+02, -.26264000E+01, 0.28876000E+01, 0.64029000E+01, -.38775500E+01, -.18744300E+02, 0.15361500E+01, -.10750000E+01, -.12989200E+02, 0.25486800E+01, -.19162800E+02, -.39522700E+01, -.59880400E+01, -.81241900E+00, 0.47519900E+01, 0.34637200E+01, 0.16368900E+02, -.16259800E+02, 0.15827600E+02, -.54313400E+01 },
        { 0.30639300E+01, -.48924200E+00, -.17416300E+00, -.64696000E+00, 0.11094300E+01, 0.21904000E+01, 0.12843600E+01, 0.21767800E+00, 0.14547100E+01, -.17542900E+01, 0.36772400E-02, 0.19980600E+00, 0.78314300E+00, -.86565000E+00, 0.23391400E+01, 0.62972600E+00, -.13703700E+00, 0.33296700E+00, -.81842600E+00, 0.10916900E+01, -.49592600E+00, 0.82496900E-02, 0.92471400E-01, 0.37769300E+00, -.15491400E+01, -.35364700E-01, -.38054400E-02, 0.38175500E+00, 0.30455500E+00, 0.70513600E+00, -.48473800E+00, -.31368100E+00, -.74937700E+00, -.85994400E-02, 0.26003500E-01, -.10211100E+00, 0.69823300E-01, -.67694900E+00, 0.14258300E+01, -.19171100E+01, -.18925300E+00, -.15478800E+00, 0.65392100E+00, -.29805600E+00, -.20553400E+00, 0.47271000E-01, 0.43984200E+00, 0.65238100E-02, -.10877300E+00, -.28755100E+00, -.56265700E+00, -.19110400E+00, -.78691200E-01, 0.17386400E+00, -.27133800E+00, -.66890700E+00, -.37183800E+00, -.17268600E+00, -.21555300E-01, -.20777300E-02, 0.99480300E+00, 0.69918700E+00, 0.56845300E-01, -.15273500E+00, -.80183200E+00, -.83856400E-01, 0.17990300E+00, -.22035100E+00, -.15488800E+00, -.68634500E-01, 0.38122300E+00, 0.59993500E-01, -.11370000E+01, -.10429600E+00, -.37628600E+00, -.10226800E+01, 0.45479100E+00, -.41482000E+00, 0.15063300E-01, -.53899700E+00, 0.35407400E-02, -.23613300E+00, 0.15661100E+01, 0.61045100E-01, -.14424800E+01, -.24645500E+00, -.10169800E+01, 0.16162800E+00, -.67982900E+00, 0.85547900E+00, 0.14003600E+00, -.11586800E-01, -.51174700E+00, 0.29471900E+00, 0.44968900E+00, -.32308200E+00, 0.13322300E+00, -.14978700E+00, 0.27088100E-01, 0.10771000E+00, 0.87902900E-02, -.67431400E+00, 0.16023300E+00, 0.45278600E+00, 0.45796800E+00, -.19003000E+00, -.68895300E-01, -.73892600E-01, -.15124500E+00, 0.13046400E+00, -.19694600E+00, 0.89365300E-02, -.13920000E+00, -.16075300E+00, -.88097300E-01, -.17658800E+00, -.16511300E+01, -.43677300E+00, 0.33282600E+00, -.51898800E-01, 0.62267900E+00, -.11803900E+01, -.10130800E+00, -.37287300E+00, -.81618500E-02, -.30114300E+00, -.19433700E+00, 0.69962500E+00, -.13334900E+01, -.27954800E+00, 0.89545600E+00, -.36115000E+00, -.35493000E+00, 0.92681000E-02, -.98836700E-01, 0.19375200E-01, 0.16579000E+01, 0.42321200E+00, 0.84033500E-01, -.20486200E+01, 0.69319000E+00, -.18323700E-01, -.60030800E+00, -.26920800E+00, 0.14861700E+00, -.84473200E+00, 0.70385200E-01, -.30540400E+00, -.17903600E-01, -.43842600E-01, -.58498000E-01, -.12938800E+00, 0.78445600E+00, 0.61121100E-01, 0.25482300E-01, -.13229800E+00, 0.13211000E+01, 0.89399300E-02, 0.16897400E+03, -.12097200E+03, -.37580700E+02, 0.12528000E+02, 0.76270300E+02, -.14512600E+03, -.16182400E+03, 0.14639000E+03, -.76936900E+02, 0.20053700E+03, -.72671300E+02, 0.56204500E+02, 0.98511000E+02, -.21868500E+02, 0.82131800E+01, -.97717900E+02, 0.76784500E+02, -.12965100E+03, 0.63129200E+02, -.31675400E+02, 0.40447600E+02, -.30347600E+02, 0.10929300E+03, 0.12275200E+03, 0.18590600E+02, 0.81727000E+02, 0.22702500E+01, 0.79370100E+02, -.13055800E+03, -.40297300E+03, 0.19442800E+03, 0.14935400E+02, 0.20121800E+03, 0.48049700E+02, 0.77918500E+02, 0.58406900E+02, -.78816800E+02, 0.10090100E+03, 0.76808200E+02, 0.13825000E+03, 0.43884700E+02, -.21921100E+02, -.17301700E+03, -.21918400E+02, 0.14392400E+03, 0.40416800E+02, -.77775700E+02, -.74374200E+02, 0.28557500E+02, 0.24682800E+02, -.12321200E+03, 0.66673500E+02, -.32794700E+02, 0.32868100E+02, -.33374500E+02, -.65978600E+01, -.22901100E+02, -.20289700E+02, 0.33101600E+02, 0.18093900E+02, -.27082700E+02, -.19035100E+03, -.80125100E+03, 0.39969800E+03, 0.43043200E+03, 0.40068500E+03, 0.16534700E+02, 0.59623700E+02, 0.19996300E+03, -.48459100E+02, 0.26678500E+03, 0.44958100E+02, 0.31688400E+03, -.27721600E+03, 0.13386700E+03, 0.38102800E+02, 0.13960200E+03, 0.49830700E+02, 0.86122100E+02, -.21892300E+02, -.53085700E+02, 0.45887800E+02, 0.73925000E+02, 0.15169100E+03, -.90729800E+03, 0.45178200E+03, 0.61300800E+03, 0.45375800E+03, 0.56807200E+02, 0.11907600E+03, 0.23526200E+03, -.73375900E+01, 0.33845100E+03, 0.72458200E+02, 0.29824600E+03, 0.73536100E+02, -.36559000E+02, 0.10653100E+03, -.36553400E+02, 0.40523200E+02, -.10230700E+02, 0.61512400E+01, 0.76816400E+02, -.53085200E+02, 0.52144500E+01, -.12929000E+02, 0.29329600E+03, -.14842900E+03, -.10200800E+03, -.14656600E+03, -.80055400E+00, -.73861200E+02, 0.77488100E+01, 0.12757600E+03, -.18301800E+02, -.56556100E+02, -.11339000E+03, 0.34017300E+01, -.68537400E+01, 0.81217700E+01, 0.63073400E+00, -.58954400E+01, -.73721500E+01, -.89680700E+01, -.30633400E+01, -.92426200E-01, 0.50026000E+01, -.80438500E+00, -.25376600E+02, 0.14063000E+01, 0.18690400E+01, -.13213600E+02, -.61089900E+02, 0.16418800E+02, -.18907800E+02, -.20916400E+02, -.21320000E+02, 0.50238800E-01, -.11173700E+02, 0.18574700E+02, -.86691300E+01, 0.16112200E+02, -.14720500E+02 },
        { -.19580300E+01, -.99916500E+00, -.50627200E-01, 0.29726300E+00, -.10987200E+01, -.52316100E+00, -.15069400E+01, -.34510300E+00, -.11348200E+01, 0.16788300E+01, 0.27333900E-01, -.17175400E+00, -.14252200E+01, 0.30128800E+01, -.35264700E+01, 0.36337100E-01, 0.61961300E+00, -.72748600E+00, 0.12538500E+01, -.11720400E+01, 0.75189900E+00, 0.30266300E-01, 0.48160200E-02, -.38766000E+00, 0.17722500E+01, -.34170800E-01, -.54399700E+00, -.98403900E+00, 0.14952300E+00, -.54509000E+00, 0.59273100E+00, 0.86225500E+00, 0.96818300E+00, 0.51082800E-01, 0.10067600E+00, -.58650400E-01, 0.52994100E-01, 0.66514700E+00, -.83406700E+00, 0.48537700E+01, 0.12367600E+00, 0.22773700E+00, -.38240300E+00, 0.10247800E+00, 0.18316200E+00, 0.10762200E+00, -.51275800E-01, 0.15031400E-01, -.91702800E-02, 0.17195400E+00, 0.71996100E+00, -.25021800E+00, -.16456600E+00, -.59707700E+00, -.75579700E-01, 0.76290800E-01, -.22736900E+00, 0.55253100E-01, 0.48709800E-01, -.29188400E+00, 0.68457600E+00, 0.17548100E+01, 0.65207600E+00, -.45514000E+00, 0.20593600E+00, -.19260400E-02, 0.97362700E-01, 0.83932700E-01, 0.29273600E-01, -.99914100E-02, -.54536000E-01, -.17803400E-01, -.23853900E+00, 0.20490300E-01, 0.43507800E-01, -.17396900E+00, 0.21777600E-01, -.19451800E+00, 0.69569300E-01, -.40762000E+00, -.50719100E-01, -.52383400E-01, 0.46735200E+00, 0.90003100E-01, -.16833600E+00, 0.16822500E+00, -.36583200E+00, -.71049900E-02, -.90268100E+00, -.17572800E+00, 0.45139200E+00, 0.10595300E-01, 0.51371700E-01, 0.25934400E+00, -.24469500E+00, 0.69172200E+00, -.11969200E+00, -.80727600E+00, 0.14044300E+00, 0.11520400E-01, 0.11947600E+00, -.39302700E+00, -.35198400E+00, 0.36591700E-01, 0.17814400E+00, -.42317800E+00, -.60597000E+00, -.39924000E+00, -.41140300E-01, -.22783000E-01, 0.90928500E-01, 0.37126100E-01, -.60527400E-01, 0.86775100E-01, -.35172800E+00, 0.52397700E+00, -.19892900E+00, -.62653400E-01, -.14014100E-01, 0.68063200E-01, -.19276200E+00, 0.14176000E+00, 0.11225300E+00, 0.13286900E+00, -.51503700E-02, 0.38214700E-01, 0.17205600E-01, -.12806200E+00, 0.36125400E+00, 0.28579100E+00, 0.76162900E-01, -.33906500E+00, 0.19163000E+00, 0.57813500E-02, 0.38542500E-01, 0.75124700E-02, -.59041200E+00, -.17839600E-01, -.84160700E-01, -.32142100E+00, -.47535600E+00, 0.80124600E+00, 0.19972600E+00, -.37293700E-01, 0.79899800E-01, 0.27404400E+00, 0.30031200E-01, 0.35962900E-02, 0.12496900E+00, 0.41073900E+00, 0.12428200E+00, 0.82797000E-01, 0.93344000E+00, -.38409700E+00, 0.32253400E-01, 0.11507300E+00, 0.61175700E+00, -.23517300E-01, -.18367800E+00, -.25909600E+03, -.64242800E+02, 0.17850800E+03, 0.16183200E+03, -.26329500E+03, 0.37823100E+02, -.84810200E+02, 0.48039300E+02, -.34328300E+02, 0.43805400E+02, -.27589700E+02, -.81288200E+02, 0.99414800E+02, -.13366200E+03, -.17579500E+02, -.37240400E+02, 0.26348300E+03, 0.12360300E+03, -.59372900E+02, 0.23337600E+03, -.57090900E+02, 0.11066100E+03, 0.11753400E+03, 0.32713100E+02, 0.21297100E+03, 0.26839400E+02, 0.80760700E+02, -.31170900E+03, -.77748500E+03, 0.39682600E+03, -.11807600E+02, 0.38854900E+03, 0.12095500E+03, -.74985600E+02, 0.37049200E+03, -.12984900E+03, 0.19400800E+03, -.37578500E+02, 0.15585500E+03, -.51025200E+03, 0.25401600E+03, -.34433800E+03, 0.25436300E+03, 0.24618100E+03, -.41050200E+02, -.23383700E+02, -.17532700E+02, 0.27170600E+03, -.53470000E+02, 0.99444200E+02, 0.32369700E+03, -.16360900E+03, -.90359500E+02, -.16193400E+03, -.10658200E+03, -.92904600E+02, -.73539300E+02, 0.90066800E+02, 0.89141000E+01, -.10643200E+03, -.29776900E+02, -.11213600E+04, 0.56086000E+03, 0.57996500E+03, 0.56046100E+03, 0.25415700E+02, 0.30292900E+02, 0.24312100E+03, -.86040600E+02, 0.34857300E+03, 0.28433300E+02, 0.60498900E+03, -.16173600E+03, 0.82209600E+02, -.92866900E+02, 0.82832800E+02, 0.24575800E+02, -.33068600E+02, 0.69570800E+02, 0.34211300E+02, -.28900100E+02, -.34320800E+02, 0.40150500E+02, -.14505000E+04, 0.72504600E+03, 0.74033300E+03, 0.72428400E+03, 0.11749900E+03, 0.11246800E+03, 0.35132100E+03, 0.50220800E+02, 0.52738900E+03, 0.76714700E+02, 0.63023700E+03, 0.15435600E+03, -.78215900E+02, 0.80770800E+02, -.78599600E+02, -.11525900E+01, -.82614500E+02, 0.51807700E+02, 0.97817700E+02, -.41568900E+02, -.74428800E+02, 0.62910500E+02, 0.30598200E+03, -.15420500E+03, -.47215200E+02, -.15342700E+03, -.24367000E+02, -.16564200E+02, -.12108700E+03, 0.21122000E+02, -.81202200E+02, -.58319400E+01, -.20854700E+03, 0.18129400E+02, -.19293600E+02, 0.10855200E+01, 0.74717200E+01, -.13737700E+02, -.81600600E+01, -.14224600E+02, 0.19705200E+01, -.16266800E+01, -.21400000E+01, 0.15452600E+02, -.71053400E+01, 0.35527800E+01, -.37774600E+01, 0.23495600E+02, -.42173600E+02, 0.10910300E+02, -.20674000E+02, -.13935100E+02, -.41557300E+02, 0.10156900E+02, -.60966100E+02, -.28469400E+01, 0.15894900E+01, 0.33618000E+02, 0.96251100E+01 },
        { 0.87381400E+01, 0.17761000E+00, -.11418600E+00, 0.47132100E+01, 0.53625200E+01, -.63256300E+01, 0.10550300E+02, -.10103000E+02, 0.49012000E+01, -.74847600E+01, -.52693200E-02, 0.44255900E+00, -.38210500E+01, -.17809600E+01, 0.62839500E+00, -.19801800E+01, 0.26119300E+01, 0.11398800E+00, 0.42561200E+00, 0.13392200E+01, -.84161400E+00, -.31326900E+00, -.17871400E+00, 0.12541600E+00, 0.38678200E+00, -.39926500E+00, 0.20294300E+01, 0.14048900E+01, -.16581300E+00, 0.76203200E+00, -.54537300E+00, 0.56510600E+00, -.38658800E+00, -.13392000E+01, -.56105900E+00, -.43310200E+00, 0.65627100E+00, 0.86039600E-01, -.10000500E+01, 0.10708100E+02, 0.22588000E+00, 0.82039200E+00, 0.87917500E+00, 0.56870100E+00, -.98192500E-01, 0.11220100E+00, 0.58151800E+00, -.28852800E-01, -.27859300E+00, -.31224300E+00, 0.12276900E+01, -.81425000E+00, 0.23713400E+00, -.91383800E+00, 0.30762000E+00, -.31269200E+00, 0.16610900E+00, -.20299700E+00, -.19164500E+00, 0.70569800E+00, -.21501100E+00, 0.15358000E+01, 0.10345800E+01, -.17547700E+01, 0.14942600E+01, -.22864500E+00, -.26922900E+00, -.44504800E+00, 0.14053300E+00, -.30536100E+00, -.10214000E+01, 0.10849600E+00, -.32646000E+00, -.23029100E+00, 0.74823400E+00, -.82537800E+00, 0.95397300E-01, -.11880900E+01, -.16021100E+00, -.30855300E+00, -.28486100E+00, 0.15376000E+00, 0.26349000E+01, -.51451000E+00, -.38602100E+01, -.16009400E+00, -.35689700E+01, 0.19188700E+01, 0.12782000E+01, -.52864600E+00, 0.19554900E+00, -.23565000E+00, -.58554900E+00, 0.16169300E+01, 0.76695800E+00, -.19747100E+01, 0.62145000E+00, 0.82608300E+00, -.23941100E+00, -.53651000E+00, -.70226800E-01, -.12096200E+01, 0.30503900E+01, -.69740400E+00, 0.22199800E+01, -.91452000E-01, -.58943800E-01, 0.23974900E+01, 0.32892900E+01, 0.24216600E+00, -.30863000E+01, 0.97373200E+00, -.47875800E+00, -.84207300E-01, 0.52126100E+00, -.15432100E+01, -.44785900E+01, -.74607800E+00, -.97577100E-01, 0.16525100E+01, 0.13869400E+01, 0.40082700E+00, 0.16334400E+00, -.58964100E+00, -.71151500E+00, -.19929000E+01, 0.60934100E+00, 0.35736500E+01, -.51542300E+01, 0.59058800E+00, -.21617800E+00, 0.48607800E+01, -.49419700E+01, 0.14031100E-01, -.45245100E+00, 0.90630500E-01, 0.25497000E+01, 0.94183200E+00, -.94486100E-01, -.41690100E-01, 0.21961300E+00, 0.90321700E+00, -.35120000E+01, -.44258000E+00, 0.29961400E+00, 0.13687000E+01, 0.74308700E+00, 0.14953600E+00, 0.14141800E+01, 0.16253900E+01, 0.12290600E+01, -.62184000E+00, -.16897300E+01, -.35519100E+00, -.39553700E+00, 0.81126200E+00, -.20162400E+01, 0.13743100E+00, -.21193400E+01, -.96414800E+00, -.62338900E+03, 0.59692100E+03, 0.58882300E+00, -.28543000E+03, 0.18385500E+04, -.66278300E+03, 0.35999800E+03, -.36058700E+03, 0.33858200E+03, -.33407300E+03, -.67480500E+03, 0.67418200E+03, -.29838000E+03, 0.13770100E+03, -.58724900E+03, 0.16225800E+04, -.10826400E+03, 0.55509100E+02, 0.39513600E+02, 0.10004600E+03, 0.78045200E+02, 0.59384900E+03, 0.24365200E+03, 0.98161000E+03, -.12892800E+02, 0.57724700E+03, 0.84013000E+02, -.87947500E+03, 0.48962200E+03, 0.32966700E+03, 0.43803200E+03, -.16101400E+02, -.11644900E+04, 0.17092800E+04, 0.13327000E+03, -.64065500E+03, -.78420000E+03, -.82376300E+02, -.19844200E+04, 0.98542700E+03, -.83341300E+03, 0.99796600E+03, 0.90531000E+03, -.16382900E+02, 0.69905700E+02, 0.31502400E+03, 0.35488600E+03, -.15059400E+02, 0.96373400E+03, 0.20742900E+04, -.10488400E+04, -.87305100E+03, -.10292500E+04, -.76923600E+03, -.41903700E+02, -.55631000E+03, 0.35976800E+03, -.85682900E+03, -.18631700E+03, 0.62026100E+03, -.40161000E+04, 0.20111800E+04, 0.18988100E+04, 0.20039000E+04, 0.43003400E+03, 0.26173400E+03, 0.81435900E+03, -.66868900E+03, 0.86298000E+03, 0.22778300E+03, 0.16185900E+04, 0.67864500E+03, -.33629100E+03, 0.40945000E+02, -.35484000E+03, -.18339800E+03, -.35863900E+03, 0.25688100E+03, 0.23266200E+03, -.14678600E+04, -.19855300E+03, -.13692700E+03, -.58889000E+04, 0.29453700E+04, 0.17493900E+04, 0.29399400E+04, 0.54847200E+03, 0.62319000E+03, 0.12649900E+04, -.30503200E+03, 0.16364400E+04, 0.45966700E+03, 0.25198800E+04, 0.49650500E+03, -.25590300E+03, -.45506400E+03, -.25482400E+03, 0.52223200E+02, -.24554300E+02, -.44650600E+02, 0.28947000E+03, -.37817300E+03, -.85860100E+02, 0.37967900E+03, 0.13254900E+04, -.67355900E+03, -.39318300E+02, -.67372400E+03, -.40202000E+03, -.31298100E+03, -.72250400E+02, 0.43404900E+03, -.14676500E+03, -.16396800E+03, -.10236200E+04, 0.82926700E+02, -.14205300E+03, -.51729000E+02, 0.53735000E+02, -.77115800E+02, -.36842800E+02, 0.23195900E+02, 0.48394100E+01, 0.22019700E+02, 0.11549500E+02, 0.57089400E+02, 0.10207100E+03, 0.34038600E+02, 0.91925000E+01, 0.13809400E+03, -.13636300E+03, 0.13666600E+03, -.55395100E+02, 0.71242700E+02, -.59628800E+02, -.13525500E+03, -.90943000E+02, -.13082200E+03, -.16824900E+02, 0.59385000E+02, 0.27580900E+02 },
        { -.17572300E+01, -.15221900E+01, -.95486900E-01, 0.13580800E+01, 0.10903300E+00, -.34567100E+01, -.15047800E+01, -.64225000E+00, -.14432100E+01, 0.14984200E+01, 0.19431700E-01, -.15602000E+00, -.18954300E+01, 0.17962100E+01, -.24791200E+01, 0.31824300E+00, 0.16651600E+01, -.24366100E+00, -.14310800E+00, -.17255000E+01, -.71139700E+00, 0.23706000E+00, -.11012100E+00, 0.50444600E-01, -.21790800E+00, 0.66656000E-01, -.29095000E-01, -.35961900E+00, 0.35183100E+00, 0.18481000E-01, -.20847200E+00, -.13442000E+00, 0.66980600E-01, -.47667600E+00, 0.79401500E-01, -.24703700E+00, -.20968700E+00, -.91498400E+00, 0.14959100E+01, -.10911400E+01, -.31544400E+00, -.50742900E+00, 0.42276500E+00, 0.62499500E+00, -.57600200E-01, 0.11950900E-01, 0.18451800E+00, 0.13252200E-01, -.11285000E+00, -.76942700E-01, -.21301600E+01, 0.21547900E+00, 0.33172600E+00, 0.74496500E+00, 0.62686400E+00, -.42970800E-01, 0.23167000E+00, -.30999600E-01, 0.36283100E-01, -.44475300E+00, 0.50982500E+00, -.45954300E+00, -.46546600E+00, 0.44023400E-01, -.33764100E+00, -.41648000E-01, 0.31645700E+00, -.74213400E-01, -.71169100E-01, -.81150800E-02, 0.40199000E+00, 0.85872400E-01, -.51147700E+00, -.82375600E-01, -.46134200E+00, 0.31627900E+00, -.18250600E-01, -.24621800E-01, -.12672900E+00, 0.11078500E+00, -.16292500E-01, 0.61989000E-01, 0.52561300E+00, 0.87462300E-01, -.83256100E+00, -.37710900E-01, 0.71601300E-01, 0.10348600E+01, 0.23826900E+00, -.51461500E+00, 0.94846300E+00, 0.10238200E-01, 0.74115500E-01, 0.36196800E-01, -.16450800E+00, 0.15530900E+00, -.20701000E+00, 0.56264900E+00, -.90519500E+00, -.12945900E+00, -.89600600E-01, 0.43753700E+00, 0.78336900E-01, -.53493600E+00, -.17979900E+00, -.36802100E+00, -.21315200E+00, -.63570300E+00, 0.67117800E+00, 0.96449200E-01, -.12817900E+00, -.36271500E-01, 0.51254500E-01, -.33399100E+00, -.61129100E+00, -.42427000E+00, -.82486600E+00, -.65468400E-01, 0.85973400E-01, -.53603400E-01, 0.10108500E+00, -.23532700E+00, -.54830000E-01, 0.28708400E+00, 0.56872100E-01, 0.28646600E+00, -.20415500E+00, -.14126200E+00, 0.74990500E-01, -.19926400E-01, 0.17807500E+00, 0.10969800E+01, -.63694700E+00, 0.16560600E-02, -.11588300E+00, -.53448000E-02, -.19047000E+01, 0.49634700E+00, -.27768300E+00, -.27665900E+01, 0.33101400E+00, -.13225300E+01, 0.45337500E+00, 0.36708500E+00, -.16454400E+00, -.13215300E+00, -.72755500E-01, 0.14262200E+00, 0.26561800E+00, -.31534800E+00, 0.41118400E-02, -.52220400E+00, -.59666300E+00, 0.18731600E+00, -.23121700E+00, -.10383300E+00, -.18829500E+00, -.90298800E-02, 0.44949400E+00, -.70152200E+00, 0.88804200E-01, -.17041800E+03, -.13769700E+03, -.65268600E+01, 0.66583800E+03, 0.18859900E+02, -.13447500E+02, -.60919500E+02, -.95450800E+01, -.72391200E+02, -.29438500E+02, 0.45064400E+02, -.72811900E+02, 0.15838000E+02, -.29452400E+02, 0.25941300E+03, -.23886400E+03, 0.12246000E+03, 0.25411900E+03, 0.12263200E+03, 0.14117000E+02, 0.12675300E+02, -.27761500E+02, -.20211300E+03, -.17524200E+01, 0.42742000E+02, 0.60539300E+03, -.38020100E+03, 0.18358100E+03, -.20125300E+03, 0.19051900E+03, 0.30106100E+02, -.58819200E+02, 0.16567900E+03, 0.16084500E+03, 0.33830700E+03, -.90915900E+02, 0.24720500E+03, -.80002300E+03, 0.40176800E+03, 0.35796700E+03, 0.39893300E+03, 0.10097600E+03, -.69569300E+02, 0.20687000E+03, 0.22826900E+02, 0.14616900E+03, -.48388700E+02, 0.29262200E+03, -.17155100E+03, 0.86941500E+02, 0.76114000E+02, 0.85047900E+02, -.15121600E+01, 0.59945300E+02, 0.55319800E+00, -.46762800E+01, 0.12062500E+03, 0.47795100E+02, 0.39462100E+03, -.46556400E+03, 0.23267000E+03, 0.16042200E+03, 0.23291800E+03, -.11147100E+02, -.70991000E+00, 0.67168300E+02, -.88260500E+02, 0.14087000E+03, 0.21746800E+02, 0.39776100E+03, 0.85558900E+02, -.41529300E+02, -.17310200E+03, -.41422700E+02, -.19593100E+02, -.95403100E+02, 0.67021500E+02, 0.26641900E+03, 0.14196400E+03, -.11031900E+03, -.16733100E+02, -.46828200E+03, 0.23481700E+03, 0.20825200E+03, 0.23370800E+03, -.51590300E+02, -.37544200E+01, 0.78458700E+02, -.16795200E+03, 0.14939500E+03, 0.17036300E+02, 0.60566100E+03, -.73241500E+02, 0.38292900E+02, -.11252000E+02, 0.35934700E+02, -.33819000E+02, -.46673500E+01, 0.61016300E+02, -.54843900E+02, 0.11006200E+03, -.28006500E+02, 0.13899800E+03, -.25157000E+03, 0.12357700E+03, 0.94871700E+02, 0.12635100E+03, 0.35266200E+02, 0.84845500E+02, -.46507100E+02, -.11611400E+03, -.28878700E+01, 0.68585500E+02, 0.12575800E+03, -.35681200E+01, 0.83672300E+00, -.13095100E+02, 0.51962400E+01, 0.13205500E+02, -.15176500E+02, 0.16288300E+02, -.13529000E+00, 0.38398400E+01, 0.80320600E+01, -.37157000E+00, -.99237200E+01, 0.14533300E+01, -.46370700E+00, 0.12889800E+02, -.24387400E+02, -.63035900E+01, 0.81903700E+01, -.43665800E+02, 0.11336800E+02, 0.22567300E+02, -.42211400E+02, 0.64411600E+01, 0.83391800E+01, 0.20956000E+00, 0.80298700E+01 },
        { -.93608300E+00, 0.10338600E+01, 0.99981100E-01, 0.36791500E+00, 0.46692000E+00, 0.39769600E+00, -.30719600E+01, 0.25751400E+01, -.13034800E+01, 0.33595200E+00, 0.54101900E-02, -.59700600E-01, -.78824000E+00, 0.58555200E+00, -.26630400E+00, -.20965800E+00, 0.41467300E+00, 0.10728900E+01, -.29559600E+00, 0.10070400E+00, 0.85489900E-01, 0.33671900E-01, -.17978700E+00, 0.16357400E-01, -.62777000E+00, -.15369000E-01, 0.26422100E-01, 0.15720000E+00, -.19434500E+00, -.22345600E+00, -.14863100E+00, -.79752500E+00, -.43968600E-01, 0.21623000E+00, -.90781300E-01, 0.12848800E-01, 0.65501200E-02, 0.30604600E-01, -.48077500E+00, 0.81856600E+00, -.15538300E-01, -.73460100E-02, -.39118800E+00, -.30121000E+00, 0.22766100E+00, 0.61123100E-01, -.39492900E+00, 0.47507000E-02, 0.48814300E-01, 0.16946000E+00, -.65612400E+00, 0.24646400E-01, 0.17302400E+00, 0.19134100E+00, 0.34860800E+00, -.13200200E+00, 0.64211000E+00, -.37986200E-01, 0.44490300E-01, -.13860100E+00, 0.57215100E-01, 0.28241600E+00, -.14473600E-01, 0.13706600E-01, -.15750700E-01, -.19832100E-02, -.22110900E+00, 0.14556300E+00, -.62340800E-01, 0.32130000E-01, 0.12584600E+00, 0.71732400E-01, -.39573200E+00, 0.44103300E-01, 0.70985300E-02, -.99519600E-01, 0.20132300E+00, -.18258500E+00, -.60237900E-01, -.40972000E+00, -.18533500E-01, 0.23674600E-01, 0.50889700E+00, -.70172800E-01, -.36158700E+00, 0.17054000E+00, -.10380400E+01, -.11379700E+00, -.12686800E+01, -.98540500E-01, -.11353600E+01, 0.78065100E-02, 0.36009700E+00, 0.10148400E+00, -.54904100E+00, -.37638600E+00, -.32611600E-01, 0.36394300E+00, -.58475800E+00, -.15959300E+00, 0.14613000E+00, -.26912900E+00, 0.97341100E-01, -.10632500E+00, 0.10823700E+00, -.60744500E+00, -.60412500E+00, -.70307700E+00, 0.46165100E+00, 0.13237300E-01, 0.35577300E-01, 0.12926400E+00, 0.20250200E-02, -.10959600E+00, -.47143800E+00, 0.37784100E-01, -.16069500E+01, 0.81915400E-01, 0.13922500E+00, 0.36319500E+00, 0.33667900E-01, -.36268000E+00, -.34331000E-01, 0.37625800E+00, 0.28586800E-01, -.13351300E-01, 0.34759200E-01, 0.92045500E-01, -.17856800E+00, 0.47642500E+00, 0.70701600E+00, -.10126700E+01, 0.80790800E+00, 0.41707400E-02, 0.47135900E-01, -.65147600E-02, -.39370200E+00, -.22204800E+00, 0.20217900E-01, -.11967200E+01, -.50856600E+00, -.57814000E+00, -.15840600E+00, 0.10256900E-01, -.90422300E-01, 0.35172100E+00, -.30615400E-01, 0.16984900E+00, 0.80936600E-01, -.27063700E-01, 0.11633800E+00, 0.25771000E+00, 0.46704700E+00, 0.15711000E-01, -.55057400E-01, -.12354900E+00, -.32796700E+00, -.16026200E-01, -.89205400E-01, 0.28725200E+00, 0.11891900E+00, 0.34306900E+00, 0.11098900E+03, 0.66084800E+01, -.18542600E+03, 0.30813000E+01, -.63815400E+01, 0.20250400E+02, -.13546800E+01, 0.17494200E+02, -.29394100E+01, -.27450500E+02, 0.63421500E+02, 0.78918900E+02, -.98887400E+01, -.24323500E+02, 0.15849200E+03, -.79730200E+02, -.24208600E+03, -.86093800E+02, -.99347600E+02, -.17676800E+02, -.41844400E+02, 0.71974200E+01, -.42265300E+02, -.22257700E+02, -.12766500E+03, 0.12491600E+03, -.73578900E+02, 0.45546400E+02, -.62081600E+02, 0.15407100E+01, 0.61068100E+02, -.68574000E+02, 0.28549300E+02, -.16393800E+02, 0.56751400E+02, -.81261500E+02, 0.18841700E+03, -.93015400E+02, 0.93271800E+02, -.94505500E+02, -.57169800E+01, 0.31514200E+02, -.31611800E+02, -.75199400E+02, -.47203600E+02, 0.33526400E+02, -.67737300E+02, -.11270300E+03, 0.59179500E+02, 0.52747500E+02, 0.55711900E+02, 0.71971700E+02, 0.10420200E+02, 0.28229400E+02, -.30510400E+02, 0.74633300E+02, 0.13173200E+02, -.15507900E+03, -.64012100E+02, 0.31325200E+02, -.82199200E+01, 0.32397100E+02, -.27209100E+02, 0.66916200E+02, -.43155200E+02, -.60691900E+02, 0.68509100E+02, 0.61374200E+02, -.26404100E+02, 0.18915100E+02, -.69448200E+01, 0.58011400E+02, -.93416500E+01, 0.25040100E+02, 0.22103400E+02, -.79405900E+01, -.10254600E+02, 0.52537300E+02, 0.25772700E+02, -.78625500E+02, 0.33973600E+03, -.17044600E+03, -.16935500E+03, -.16925000E+03, -.91908400E+02, 0.92028900E+02, -.14150500E+03, -.91879000E+01, -.59414200E+02, 0.73967800E+02, -.25424800E+03, -.26500400E+02, 0.14461600E+02, -.16960300E+02, 0.14103400E+02, -.17237900E+02, 0.25736400E+02, -.42149000E+02, -.44132100E+02, 0.92167300E+01, 0.28985000E+02, -.40284300E+02, -.11496000E+03, 0.57250500E+02, 0.10250700E+03, 0.58522100E+02, 0.21888800E+02, 0.10564400E+02, 0.79521600E+01, -.49554500E+02, -.37999300E+02, 0.22343600E+02, 0.10539300E+03, -.72763300E+01, 0.43815700E+01, 0.65115100E+01, -.92770200E+01, -.38633000E+00, 0.58708000E+01, 0.30557900E+01, 0.11201500E+01, -.40535500E+01, -.39857200E+01, -.22754300E+01, 0.11485100E+02, -.44046700E+01, -.48867400E+00, 0.38874200E+01, 0.15973300E+02, 0.60428300E+01, -.27764900E+01, 0.17845900E+02, 0.74750900E+01, 0.13146900E+02, 0.63533100E+02, -.74870100E+01, -.16225000E+02, -.11851900E+02, 0.75674700E+01 },
        { -.70999400E+01, 0.48096800E+01, 0.68819500E+00, 0.28762800E+01, -.13940400E+01, -.77261900E+01, -.18104700E+01, -.83157000E+01, -.27643400E+01, 0.48672200E+01, 0.81650900E+00, -.19359100E+00, 0.85784500E+00, -.51506200E+01, -.22108100E+01, -.23089900E+01, 0.65023100E+00, -.87236700E-01, 0.19108100E+01, -.40426800E+01, 0.34146300E+00, 0.15297200E+00, 0.18513400E+00, -.99803400E+00, 0.68047400E+01, 0.18513000E+00, 0.18315000E+01, 0.10915900E+01, -.21182800E+01, 0.11222900E+01, 0.46869600E-01, 0.11332900E+01, 0.19172600E+01, -.26920600E+00, 0.12098900E+00, -.42322100E+00, -.36406300E-01, -.31832600E+00, 0.37144000E+00, -.59344800E+01, 0.41129900E+00, 0.16234900E+00, 0.50251600E+00, -.73622900E+00, 0.49735000E+00, 0.23462400E+00, 0.74101900E+00, 0.71145100E-01, -.49284100E+00, -.64149000E-01, -.39801600E+01, -.15181400E+00, 0.59056400E+00, 0.10289500E+01, 0.21343800E+01, -.87050900E+00, 0.61283900E+00, -.43320500E+00, 0.15472400E+00, -.37125600E+00, 0.83696200E+00, -.46766100E+00, -.75326400E-01, -.12752200E+01, -.65617400E+00, 0.86823300E-01, -.54624800E+00, -.35418800E+00, -.56182300E+00, -.15665900E+00, 0.92711400E-01, 0.41179900E+00, 0.25793100E+01, 0.46394500E+00, -.14806500E+01, 0.92817600E+00, -.14972800E+01, 0.95444500E-01, 0.30338300E+00, -.41140500E+00, -.19638500E+00, 0.10805200E+01, -.31374300E+00, 0.41591900E+00, -.10958900E+01, 0.51132300E+00, -.66451500E-01, 0.21577100E+01, 0.14960400E+01, -.12684100E+01, -.40115700E+00, 0.24363500E-01, 0.20548000E+00, -.14135400E+01, -.10806200E+01, 0.25441700E+01, -.11430200E+01, -.14402800E+01, 0.78833300E-01, 0.58859400E-01, -.30502800E+00, -.10161500E-01, 0.58431900E+00, 0.20604900E+00, -.46958100E+00, -.70124000E-01, -.17342800E+00, -.16602100E+00, -.15831600E+01, -.45274200E+00, 0.14794700E+01, -.41418600E+00, -.23333800E+00, 0.61063800E+00, 0.15005800E+00, -.23907500E+01, 0.86413800E+01, -.54761400E+00, -.11743800E+01, -.16305800E+01, -.35295300E+00, -.41354600E+00, 0.24470300E+00, -.94986400E+00, -.54958800E-01, -.31694800E+00, -.16671700E-01, 0.51876900E+00, 0.34370100E+00, 0.38125600E+00, -.14973100E+01, -.32555800E+01, 0.19469200E+01, 0.68495400E-02, 0.19745200E-01, 0.21184000E-01, 0.12464600E+01, -.12651900E+01, 0.11314600E+00, 0.63263800E+01, -.10109500E+01, -.15611900E+01, 0.16903100E+01, 0.69900600E+00, 0.12658000E+00, -.47994500E+00, 0.72568600E-01, -.19799300E-01, 0.97138500E-02, -.40290300E+00, 0.23812800E+00, 0.69065900E+00, -.38018700E+01, 0.11322400E+01, -.13238700E+00, -.72047000E+00, -.37027800E+00, -.50130700E-01, 0.15313800E+01, -.27489200E+01, 0.18838700E+00, 0.18280100E-01, -.12227900E+01, 0.18041400E+03, -.18024700E+02, 0.21727600E+02, -.21259300E+02, -.41733700E+03, -.11681300E+02, -.55823400E+02, -.21121900E+03, -.26390500E+03, -.20254000E+03, 0.72324000E+02, -.10958300E+03, 0.67616100E+03, 0.51306200E+03, -.25266200E+03, -.41803400E+03, -.24543400E+03, -.52405500E+02, -.34380700E+02, 0.11784200E+02, 0.56216000E+03, -.68414400E+02, 0.20929000E+02, -.67278200E+03, -.12669700E+04, 0.62495100E+03, 0.17987900E+03, 0.63343700E+03, 0.38267300E+03, 0.29398700E+03, 0.97404500E+02, -.17808300E+03, 0.44123400E+03, 0.26782500E+03, 0.19900000E+03, -.69598900E+03, 0.34894900E+03, 0.39521200E+03, 0.34246000E+03, -.73041800E+01, -.14177500E+03, 0.27450800E+03, -.50326500E+02, 0.35041700E+03, -.67612600E+02, 0.27651500E+03, -.89273400E+02, 0.46258800E+02, -.49969500E+02, 0.41835600E+02, 0.84664600E+02, -.11423400E+03, 0.12837500E+03, 0.28636000E+02, 0.44361700E+03, -.12950900E+03, 0.77397900E+02, 0.41224800E+03, -.20588700E+03, -.33195200E+03, -.20604100E+03, -.18321700E+03, 0.61444200E+02, -.25047100E+03, 0.67004400E+02, 0.12399200E+03, 0.46843600E+02, 0.84232900E+03, -.45648200E+03, 0.23312200E+03, -.16974100E+03, 0.24134700E+03, 0.22870300E+03, 0.18556400E+03, 0.85454500E+02, -.18880000E+03, 0.33582000E+03, 0.16343100E+03, -.19285900E+03, 0.10247000E+04, -.50946100E+03, -.67058200E+03, -.51598800E+03, -.25125700E+03, 0.15779900E+03, -.35305100E+03, 0.50598200E+03, 0.26707900E+02, 0.11558300E+03, 0.76544100E+03, 0.39653100E+03, -.19738500E+03, -.27332600E+03, -.20354800E+03, -.58754900E+02, -.28861100E+02, -.16196900E+03, -.12760100E+03, -.11005800E+03, -.48135300E+02, -.85507100E+02, 0.18124500E+03, -.93220600E+02, -.43231300E+02, -.89604000E+02, 0.12355000E+02, 0.22122800E+03, -.29320800E+03, -.41330800E+03, -.51672600E+03, 0.25635200E+03, -.95776500E+02, -.17824500E+02, 0.22630100E+02, -.14834500E+02, -.13008800E+02, -.76976900E+01, 0.69039000E+01, 0.10758500E+02, 0.15573700E+01, -.76892300E+01, -.24207200E+02, 0.39869400E+02, -.24685200E+01, -.10188300E+02, -.76399700E+01, 0.35311600E+02, 0.75165200E+02, 0.29607900E+02, -.28698900E+02, 0.21719700E+02, 0.16571700E+02, 0.98325600E+02, 0.54697100E+02, -.24575200E+00, -.12183200E+02, -.46084200E+01, 0.73870800E+02 },
        { 0.17735000E+01, -.20765100E+01, -.22945700E+00, -.50843800E+00, 0.52666200E-01, -.15658500E+01, 0.38260800E+01, -.18138800E+01, 0.17315800E+01, -.12169800E+01, 0.98731200E-02, 0.21420200E+00, 0.58063500E+00, -.15590500E+01, 0.11099400E+01, 0.66948200E+00, -.54858000E+00, -.10111200E+01, -.99096500E+00, 0.19453600E+01, 0.63762900E+00, -.14890700E+00, 0.12688400E+00, 0.19470700E+00, -.17155600E+00, -.30503600E-01, -.26156400E+00, -.35178200E+00, 0.58950300E-01, -.28798700E+00, -.12940500E+00, -.76006000E+00, -.65341600E+00, -.48442900E+00, -.14653900E+00, -.54129000E-01, 0.80321700E-01, 0.30365800E+00, -.82284700E+00, -.17921100E+01, 0.18713100E+00, -.38921200E-01, 0.22841200E+00, 0.69452700E+00, -.54318600E+00, -.62594300E-01, 0.25642700E-02, -.29486000E-01, 0.12386200E+00, -.27633600E+00, 0.31307000E+01, 0.23041600E-01, -.65664900E+00, -.84153400E+00, -.18563700E+01, 0.13550900E+00, -.82054400E+00, 0.21332000E+00, -.12982500E+00, 0.51365700E+00, 0.42296700E+00, -.69139200E+00, -.11098900E+01, -.32754700E+00, -.25001300E+00, -.21653200E-01, 0.28620300E+00, -.20417100E+00, 0.10362000E+00, -.16747300E-01, 0.76498700E-02, -.13181500E+00, -.52780100E-01, -.35601300E+00, -.25631200E+00, -.68710800E-01, 0.10873600E-01, -.44293800E+00, 0.37950200E-01, 0.22259500E+00, 0.37882700E-01, -.22162100E+00, -.11359900E+00, -.48332000E-01, 0.32483400E+00, 0.25778300E-01, 0.16469300E+00, -.71738300E-01, -.59558200E+00, 0.30256600E+00, -.19272500E+01, 0.15799600E-02, -.27962700E+00, -.19510000E-01, 0.57203500E+00, 0.39627800E-01, -.24822300E-01, -.41555200E+00, 0.15899300E+00, 0.58759400E-01, -.19060200E+00, 0.11064700E-01, -.92864000E-01, 0.14033900E+00, 0.22033800E+00, 0.45716900E+00, -.11502300E-01, 0.70662500E+00, -.40311800E+00, 0.11987000E+00, -.51500600E+00, 0.36459500E-01, -.41343400E-01, -.88941200E-01, -.10539400E+00, 0.12611500E+00, -.18269100E+01, -.16684600E+00, 0.81723300E-01, 0.27107500E+00, -.23559500E+00, 0.25607000E+00, 0.22862800E-01, -.10619500E+00, 0.37036800E-02, 0.64809800E-01, 0.21490500E-01, -.25764100E+00, -.16765000E+00, 0.15205300E+00, 0.24937900E+00, -.12273800E-01, -.11288900E+01, 0.39047200E-02, 0.74764700E-02, 0.17287100E-01, -.33621900E+00, 0.41137100E+00, -.90878700E-01, 0.44459600E+00, 0.11120700E+00, 0.50270800E+00, -.10476100E+00, 0.20621500E-01, -.68321800E-02, -.14446800E+00, 0.58721900E-01, -.52580300E-01, 0.19902100E+00, 0.22180000E+00, 0.41660100E+00, 0.16862200E+00, -.21173400E+00, -.19325100E-01, 0.34446300E-01, -.16977500E+00, 0.47235600E-01, -.19276600E-01, 0.64377700E+00, -.32040700E+00, -.45666700E-01, -.40736700E+00, -.10638700E+01, 0.64457500E-01, 0.72206700E+03, -.64662500E+02, 0.28007600E+02, -.11095500E+03, 0.32824200E+02, -.66568600E+02, -.10092400E+03, 0.75116400E+02, -.49385400E+02, 0.15999800E+03, -.93378800E+02, 0.51697500E+03, -.10528200E+02, 0.68626000E+01, 0.21815400E+02, 0.77501800E+01, -.64813100E+02, 0.74193000E+02, 0.19581200E+02, 0.42524600E+02, -.10134500E+03, 0.13040300E+03, 0.33188300E+03, -.30429800E+03, 0.14461200E+03, -.13963300E+03, 0.15280700E+03, 0.44103800E+02, -.17861000E+03, 0.32413300E+03, 0.16356600E+03, 0.21616200E+03, -.16431600E+03, 0.38760200E+02, -.13735900E+04, 0.68859700E+03, 0.42791900E+03, 0.68590700E+03, 0.28541900E+03, -.78300200E+02, 0.42178800E+03, 0.38273000E+02, 0.35468400E+03, -.33993300E+02, 0.41981900E+03, 0.52994900E+02, -.24068900E+02, -.24607500E+02, -.26993800E+02, -.32962900E+01, 0.57064800E+02, -.35989500E+02, 0.45480100E+02, 0.12428900E+03, 0.10837400E+02, 0.15711900E+03, -.10331500E+04, 0.51652400E+03, 0.39561000E+03, 0.51657800E+03, -.40540600E+02, 0.54564200E+02, 0.17310900E+03, -.20780300E+03, 0.32968900E+03, 0.59321200E+02, 0.69098500E+03, 0.33059200E+03, -.15710300E+03, -.18358400E+03, -.16547700E+03, -.41290000E+02, -.21054000E+03, 0.13280400E+03, 0.27648300E+03, 0.10172100E+02, -.18662000E+03, -.24476800E+03, -.81406600E+03, 0.40735000E+03, 0.25182000E+03, 0.40648700E+03, -.14627900E+03, 0.97039100E+02, 0.21135100E+03, -.75008900E+02, 0.29940300E+03, 0.87427200E+02, 0.79969900E+03, 0.59444400E+02, -.28809600E+02, -.97142500E+02, -.30629500E+02, -.77917700E+02, 0.16457700E+01, -.16350300E+02, -.55282200E+02, 0.11161700E+02, -.22725800E+02, 0.12741900E+03, -.88720800E+02, 0.40840300E+02, 0.15881400E+03, 0.44634200E+02, -.21629900E+02, 0.69691700E+02, -.86149800E+02, -.13746900E+03, -.11895800E+03, 0.99704400E+02, 0.29360800E+02, 0.80308000E+01, -.11462900E+02, -.77043100E+01, 0.27073700E+01, 0.40771700E+01, -.19111000E+02, 0.24165600E+02, 0.40674100E+01, -.89479400E+00, 0.37100400E+01, 0.17356600E+02, 0.28900700E+02, 0.14658900E+01, -.27190600E+01, 0.46378400E+02, -.38092300E+01, 0.23925700E+02, -.38297500E+01, -.26255100E+01, -.50759200E+00, 0.38754700E+02, -.26393400E+02, -.26923200E+02, 0.69942900E+01, -.30749300E+01, 0.23113100E+02 },
        { -.84857100E+01, -.12086900E+02, -.12932000E+01, -.58658700E+01, -.14018900E+01, 0.56156700E-01, -.10373800E+02, -.21876300E+00, -.50304700E+01, 0.76384200E+01, 0.38343100E+00, -.43087100E+00, -.26966100E+01, 0.88077200E+01, -.36224400E+01, -.10289600E+01, 0.13220100E+00, 0.30068100E+01, -.14004900E+00, -.18248800E+01, 0.10822200E+01, 0.17024600E+00, -.56388700E+00, 0.25488200E-01, -.22313600E+01, 0.10384100E+00, -.34913300E+00, 0.41242200E+00, -.16335100E+01, 0.24557300E+01, -.11477300E+01, 0.51307200E+00, -.14093800E+00, -.76283700E+00, 0.75011600E+00, -.46241800E+00, 0.32151600E+00, -.99331300E+00, -.24545400E+01, -.45017000E+01, -.26630400E-01, 0.30782600E+00, 0.72455400E+00, 0.78767100E+00, 0.31680300E+00, -.25216600E+00, 0.10751800E+01, -.22913100E-01, 0.99596100E-01, -.52506300E+00, 0.93850900E+00, 0.50370200E+00, -.54547700E+00, 0.10567800E+00, -.87215700E+00, -.10352500E+01, 0.19725800E+00, -.43482400E+00, -.64123900E-01, 0.67880400E+00, 0.27214100E+00, -.68519400E+01, -.36785600E+01, -.32700900E+00, 0.88507300E+00, 0.11944000E+00, 0.16673400E+01, -.57907600E+00, -.10216400E-01, 0.10290700E+00, 0.95725600E-01, 0.33161500E+00, 0.11640900E+01, 0.19604700E+00, -.61336900E+00, -.73460200E+00, 0.73481700E+00, -.98514700E+00, -.38667300E+00, 0.64908800E+00, 0.29002500E+00, -.22828500E+00, -.11164400E+01, 0.11599900E+00, -.29859200E+00, -.13913200E+00, 0.18454900E+01, 0.30175700E+00, 0.27880500E+00, 0.68025000E+00, -.47083900E+01, -.93426800E-02, -.92619000E+00, -.43253900E+00, 0.18662200E+01, -.21911900E+00, 0.43561000E+00, 0.12987500E+01, 0.55503400E+00, 0.10669700E+00, -.84879500E+00, -.20697000E+00, 0.10676400E+01, 0.12718600E+01, -.71789700E-01, 0.13611100E+01, 0.54266100E+00, 0.17759600E+01, -.32829500E+00, 0.30169500E+00, -.88928800E+00, 0.77863800E+00, 0.18437600E+00, -.62424700E-01, -.11973600E+00, -.19531800E+01, -.79936100E+01, 0.16392200E+01, 0.57444400E+00, 0.66909700E+00, 0.23961700E+00, -.37714500E+00, -.53159400E-01, 0.31885700E+00, 0.82153400E-01, -.66303800E+00, 0.68852400E-01, 0.27718500E+01, -.11495000E+01, 0.35905400E+00, 0.22738100E+00, 0.27676400E+01, -.14872500E+01, 0.43827400E-01, -.29177900E+00, -.43158900E-02, 0.35038500E+01, -.35378100E+00, 0.36710800E+00, -.36817000E+01, -.44425500E+00, 0.18574200E+01, 0.36155200E+00, 0.48852000E-03, 0.21006400E+00, -.11482900E+01, 0.92260700E-01, -.19842700E+00, 0.44156300E+00, 0.43875000E+00, 0.57109400E+00, 0.10146400E+00, 0.34862700E+00, 0.55198400E+00, -.51626400E-02, -.81894500E+00, 0.23897600E+01, 0.34539200E-01, -.51340900E+00, 0.12129000E+01, -.95163700E-01, -.14929600E+01, -.95492400E+00, -.22143900E+00, 0.96540400E+00, 0.55681600E+03, -.28798500E+03, -.96470400E+02, -.27871100E+03, 0.10481300E+03, 0.21660000E+03, -.96816300E+02, 0.67354800E+02, -.28465300E+03, 0.18647500E+03, -.40302800E+03, 0.84788600E+03, -.41711200E+03, -.61931400E+03, -.43146100E+03, 0.10369400E+03, 0.33529900E+03, -.41028900E+03, -.16360100E+03, -.25911500E+03, 0.25160900E+03, -.55512000E+02, -.66912000E+03, 0.30937000E+03, 0.35829600E+02, 0.33484400E+03, 0.11079700E+03, 0.29079300E+03, -.39982700E+01, 0.25193500E+02, 0.36658600E+03, 0.21595100E+03, 0.37304100E+03, 0.23768400E+03, -.11401600E+03, 0.22393000E+03, -.11865500E+03, 0.13572300E+02, -.45561600E+02, -.14107200E+03, -.30552400E+02, -.12194000E+03, -.31140800E+02, -.20993800E+03, -.28695500E+02, 0.22689600E+02, 0.37936700E+00, 0.13464000E+02, -.67479200E+01, 0.77474400E+02, -.27870300E+02, 0.20707600E+02, -.62842900E+02, 0.74018900E+02, -.53779600E+02, -.97695400E+03, 0.49091100E+03, 0.50137200E+03, 0.48927100E+03, 0.14604800E+03, 0.19601100E+03, 0.85302300E+02, -.22148700E+03, 0.37055500E+03, 0.19137800E+03, 0.46822700E+03, -.55030600E+03, 0.27559300E+03, 0.18146200E+03, 0.27534900E+03, 0.50596300E+02, 0.11532200E+03, 0.17195800E+02, 0.12409400E+03, 0.37035600E+03, 0.68780400E+02, 0.24310100E+03, -.87505200E+03, 0.44583500E+03, 0.41113800E+03, 0.43926700E+03, 0.21465400E+03, 0.40864700E+03, -.47525300E+02, -.32944300E+03, 0.41303500E+03, 0.32612300E+03, 0.37097200E+03, -.19425000E+03, 0.10321300E+03, -.57705600E+02, 0.99680500E+02, -.42637400E+02, -.64679800E+01, 0.48019700E+02, -.48602800E+02, 0.11115500E+03, -.24662800E+02, 0.90859100E+02, 0.11804900E+03, -.68914300E+02, -.97032400E+02, -.57123600E+02, 0.44326600E+02, -.55969000E+02, 0.22169200E+02, 0.53031800E+02, 0.67317000E+01, -.25642800E+02, 0.64079600E+02, -.13171200E+02, 0.61447600E-01, -.21146300E+02, 0.61766300E+01, 0.57317500E+01, 0.99353700E+00, -.15921100E+02, -.91997300E+01, 0.12002100E+02, 0.65665700E+01, -.27808800E+02, -.34011100E+02, 0.62014900E+01, 0.70749200E+01, -.21978700E+02, 0.29561200E+01, -.39286800E+02, 0.74537800E+01, -.49902300E+02, 0.51818000E+01, -.23568600E+02, 0.92399400E+02, 0.26937100E+02, -.61315100E+02, -.10414600E+02, -.13856000E+02 },
        { -.43876300E+01, -.73258800E+00, 0.60635300E-01, -.83300400E+00, -.14792000E+01, -.15944500E+01, -.26932500E+01, 0.26080900E+01, -.21227300E+01, 0.29139400E+01, 0.25333800E-01, -.13789800E+00, 0.16093400E+01, 0.17690500E+00, 0.18477700E+01, 0.13400900E+01, -.18515800E+01, 0.78564800E+00, -.10748000E+00, 0.18707900E+01, 0.49061000E+00, -.10723900E+00, 0.64774200E-01, -.19060900E+00, -.80827900E+00, 0.14848200E+00, 0.45747100E-01, 0.78536600E+00, -.18893300E+01, 0.76923200E+00, 0.50701400E-01, -.58116900E+00, 0.42219200E+00, 0.75178300E+00, 0.40029400E+00, -.22958100E+00, -.73708200E-01, 0.44186300E+00, -.85972700E+00, -.14882800E+01, 0.18263100E+00, 0.74936900E-01, 0.86985500E+00, 0.35326100E+00, -.11798700E+00, -.11359900E+00, 0.38682700E+00, -.35467400E-01, 0.10659100E+00, -.43885100E+00, 0.17290000E+01, 0.22102800E+00, -.48614100E+00, 0.18582100E-01, -.58973800E+00, -.79385300E+00, -.68502700E+00, -.97291600E-01, -.93920700E-01, -.11072500E+00, 0.68294800E+00, -.51844200E-01, -.16577200E+00, 0.23598800E+00, -.78703700E+00, 0.14203600E+00, 0.19478200E+00, -.14106200E+00, -.10597600E+00, 0.53836000E-01, 0.80769500E-01, 0.40101900E-01, -.58837500E+00, -.25199800E+00, 0.19707200E-02, -.66722300E+00, 0.29570400E+00, -.64309200E+00, -.90389200E-01, 0.75684700E-01, 0.10499900E+00, -.22151800E+00, -.38160400E+00, 0.90587700E-01, 0.26815100E+00, -.50456800E+00, -.10093700E+01, -.13842400E+01, 0.70949000E+00, 0.10564100E+01, -.21128500E+01, 0.29865800E-01, -.86243500E-01, -.34065000E+00, 0.75988600E+00, -.13370700E+01, 0.29930000E+00, 0.42880100E+00, 0.25673300E+00, 0.23507000E+00, 0.14717100E+00, -.27938200E+00, -.86570900E-01, 0.50786300E+00, -.40464800E-01, 0.19106800E+00, -.53006600E+00, -.55198700E+00, 0.77763900E+00, 0.32647000E-01, -.64076100E+00, 0.11863100E+00, 0.89989100E-01, -.32598300E+00, -.32274100E+00, 0.15585600E+01, -.21698200E+00, -.17538800E+00, 0.54217400E+00, -.93026500E+00, -.32060700E+00, -.92142500E+00, 0.19148900E-01, -.52941600E-01, 0.60235200E-01, 0.16711400E+00, -.21974400E+00, 0.16509800E+00, 0.87706600E+00, 0.32673800E-01, -.91016600E+00, -.14816000E+01, 0.69270900E+00, -.13690100E-01, 0.11636500E+00, -.12312400E-01, 0.11973300E+01, -.88898800E+00, 0.51094600E+00, 0.90704000E+00, -.40012800E+00, 0.97430300E+00, 0.75549700E+00, -.25433000E+00, -.28097500E-01, 0.17069300E+00, 0.93429800E-01, 0.73099100E-01, -.55283000E-01, 0.50709400E+00, 0.19668300E+00, 0.15010900E+00, 0.24232400E+01, -.37584400E-01, 0.10419200E+00, 0.58237700E-01, 0.12956600E+01, 0.34507800E-01, 0.31750600E+00, 0.82658700E+00, -.18259400E+00, -.12175700E+01, -.15884300E+01, -.90538800E-01, 0.41118800E+00, -.25349400E+00, -.11871100E+02, -.98709500E+02, 0.81163000E+00, -.21636500E+02, -.44628600E+01, 0.69248200E+02, 0.72190500E+02, 0.30162400E+02, -.13433100E+01, -.62014000E+02, 0.48986900E+02, -.23041700E+02, 0.91573400E+02, -.31614200E+02, -.15292700E+03, -.42410300E+02, -.19794900E+03, -.25827100E+03, -.13743200E+02, -.46525000E+02, 0.19995200E+03, -.24215000E+03, 0.91646200E+02, -.15614800E+03, 0.12131100E+03, 0.81401900E+02, 0.18321800E+03, -.91357000E+01, 0.50868200E+02, 0.22125400E+03, 0.16317300E+03, 0.20278700E+03, -.69133900E+02, 0.39800400E+02, 0.12624100E+03, 0.34817800E+02, 0.64457900E+02, -.48458800E+02, -.71997900E+01, -.83383100E+01, -.48623200E+02, -.13808800E+02, 0.22609100E+02, -.17100600E+03, 0.93836700E+02, 0.44792900E+02, 0.84818000E+02, 0.12962900E+02, 0.46050300E+02, 0.21112800E+01, -.72417600E+02, -.20393400E+02, 0.67067300E+02, -.83923500E+01, 0.14464700E+02, -.75832200E+01, 0.14236400E+02, -.65766800E+01, -.16179700E+02, 0.66908100E+02, -.14804900E+03, -.95939100E+02, 0.19198500E+03, 0.32471500E+02, -.10132400E+03, -.65538400E+02, 0.40066000E+02, -.44142100E+02, 0.32725600E+02, 0.50069500E+02, 0.53250900E+02, -.93294100E+01, 0.12407600E+03, 0.22928200E+03, 0.45161200E+02, 0.91408100E+00, 0.51736600E+03, -.25618900E+03, -.19065800E+03, -.25718200E+03, -.12342000E+03, 0.12653600E+03, -.37940700E+03, -.20775400E+03, 0.64815800E+02, 0.47908700E+02, -.32314300E+03, -.14258300E+03, 0.77384000E+02, -.11800000E+02, 0.73500700E+02, -.35890500E+02, 0.23241400E+02, 0.25399400E+02, -.38884900E+02, 0.14436200E+03, -.69516600E+01, -.13551900E+02, -.36080100E+03, 0.17741300E+03, 0.26085100E+03, 0.18195500E+03, 0.35986200E+02, -.49905700E+02, 0.60593700E+02, -.35267100E+02, 0.80618300E+02, -.19303100E+02, 0.24163800E+03, -.77440500E+01, -.65086900E+01, -.69698200E+01, -.54980700E+00, 0.99688900E+01, 0.46826300E+01, 0.72554700E+01, 0.42375800E+01, -.21110400E+01, -.13426300E+01, -.10702900E+02, 0.81376400E+01, -.74725100E+00, 0.16016400E+01, 0.12025400E+02, 0.10630500E+02, -.22959000E+02, 0.13167500E+02, -.16733400E+02, 0.17372700E+02, -.11957900E+02, 0.10207000E+03, -.80545700E+01, -.33586900E+02, -.18382200E+02, 0.33727000E-01 },
        { -.11608000E+01, -.51343700E+00, -.13311600E-01, -.76937900E+00, -.10296100E+01, -.26108800E+00, -.58800200E+00, 0.13109300E+01, -.59258600E+00, 0.58809900E+00, 0.49260800E-01, -.38397100E-01, 0.10056700E+01, -.86234500E+00, 0.35825700E+00, 0.17673100E+01, -.48249400E+00, -.16285700E+00, -.67809500E+00, -.32395100E-01, 0.15529300E+00, 0.69290100E-01, 0.38172200E-01, -.20555600E-01, -.46961500E+00, -.21929600E-01, -.38263800E+00, -.82985400E-01, 0.49756000E+00, 0.11413900E+00, 0.31037100E+00, -.11637600E+00, 0.58209700E+00, 0.71089900E+00, 0.10304200E+00, 0.32714800E-01, -.94384800E-02, 0.36457200E+00, -.25988300E+00, -.51361700E-01, 0.60422900E-01, 0.50017900E-01, -.54819200E+00, 0.82605900E-01, 0.14414900E+00, -.22430200E+00, -.31617200E+00, 0.10432600E-01, 0.10056200E+00, -.57596900E-01, 0.11607100E+01, 0.10570700E+00, -.62969400E-01, 0.87943000E+00, -.59145200E-01, -.37579000E+00, 0.14373600E+00, -.95619800E-01, -.33577900E-02, 0.16852300E+00, -.83307200E-01, -.30933100E+00, -.70707500E-02, 0.30145900E-01, 0.20905300E+00, -.29685300E-02, -.28546700E+00, -.34808800E-01, -.15126900E-01, 0.44668500E-02, 0.13902000E-01, -.65852500E-02, 0.18139000E+00, 0.97691300E-01, 0.23234100E+00, -.12109500E-01, -.30348900E-01, 0.13588900E+00, 0.15162400E+00, -.14172800E+00, -.12133600E-01, 0.20906400E-01, 0.61686100E+00, -.54569800E-01, -.94191200E+00, -.15558400E+00, -.78961500E+00, -.67674400E+00, -.87595900E+00, 0.72299200E+00, 0.25614000E+00, -.63247500E-02, 0.27771500E-01, -.12624100E-01, -.43679300E+00, 0.41834500E+00, -.17083000E+00, -.40970000E+00, -.18398600E+00, 0.86264400E-01, 0.61874100E-01, 0.30828900E-01, 0.12894500E+00, -.60244600E-02, 0.25279300E-01, 0.34719600E-01, -.33713000E-01, 0.13787000E-01, 0.60687700E-01, -.64352500E-01, -.27620300E+00, -.21203300E-01, -.29651400E-02, 0.93481600E-02, 0.74009000E-01, 0.12219500E+00, 0.16719900E+01, -.28202800E+00, -.10253200E+00, 0.43598100E+00, 0.70788700E-01, 0.21824700E+00, -.92860000E-02, 0.12864300E+00, 0.29445900E-02, -.31469300E-01, -.14732600E-01, 0.67472400E-01, -.10568600E+00, -.10007700E-01, 0.87377100E-01, -.16429700E+00, 0.77975800E-01, -.20956700E-02, -.78299600E-01, 0.11688900E-02, 0.25972600E+00, 0.97118600E-01, 0.51802000E-01, -.12609000E+00, 0.19513100E+00, -.53565000E+00, -.60952600E+00, 0.81778300E-03, -.12867800E-01, -.18887000E+00, 0.54938900E-02, 0.79350700E-01, 0.52154000E-01, -.17296100E+00, 0.33378400E-02, 0.16722700E+00, -.12227000E+00, 0.18316500E-01, 0.14465500E-01, 0.13932300E-01, -.74133600E+00, -.45957100E-02, 0.11312000E+00, -.18779200E+00, -.59416500E-01, -.39508600E+00, -.14956600E+00, -.10560700E+00, 0.44204000E+00, -.12806700E+00, -.12294900E+00, -.99825300E+02, 0.54338200E+00, -.36422000E+02, -.22841900E+02, 0.24368500E+02, -.18118800E+02, 0.11321800E+02, -.19514400E+02, -.78746400E+01, 0.59574500E+02, -.27622400E+02, 0.69195000E+01, -.28553200E+02, 0.17038700E+02, 0.18636300E+02, -.73500600E+02, -.33757300E+02, -.50227800E+02, 0.30667600E+02, 0.39660800E+01, -.29458400E+03, 0.14667400E+03, -.10667700E+03, 0.14727100E+03, 0.84532000E+02, 0.80595600E+02, 0.45181600E+02, -.16797000E+02, 0.50381500E+02, 0.72491600E+02, 0.18525800E+03, -.32622100E+02, 0.17137000E+02, -.13893200E+02, 0.15854200E+02, 0.20381800E+02, -.19562600E+02, -.36004900E+02, 0.24308300E+02, -.85828000E+00, -.14464900E+02, 0.10608700E+03, -.15315700E+02, 0.82453800E+01, -.24112800E+02, 0.74737300E+01, -.14351100E+02, 0.18335200E+00, 0.71534000E+01, -.57156900E+00, -.61747200E+01, -.75861700E+00, 0.13022200E+03, -.10138700E+03, 0.51560000E+02, 0.47963900E+02, 0.50665400E+02, 0.43994800E+02, 0.69787000E+02, -.63789200E+02, -.88705300E+02, -.12310600E+02, 0.71167700E+02, 0.87344800E+02, -.49845400E+02, 0.25234500E+02, -.73691600E+02, 0.25981800E+02, 0.17969200E+02, 0.13064600E+02, 0.15286600E+02, 0.32363400E+02, -.33242500E+01, 0.93152800E+01, 0.34337400E+02, -.12301500E+03, 0.64050400E+02, -.15300600E+02, 0.61140400E+02, 0.71003700E+02, 0.10984900E+03, -.10786500E+03, -.10816100E+03, -.16557300E+02, 0.97048900E+02, 0.70641500E+02, -.10445900E+02, 0.64830200E+01, -.62287800E+02, 0.46782000E+01, -.97975300E+01, -.24741400E+01, 0.13549800E+02, -.23392000E+02, 0.11694300E+02, -.93364900E+01, -.15712100E+02, 0.21344500E+02, -.12442400E+02, 0.41710700E+02, -.10672100E+02, -.44251300E+01, -.73810400E+01, -.64613600E+01, -.12492700E+02, -.38653400E+02, 0.88512100E+01, -.67573900E+01, -.43629200E+01, 0.18943600E+01, -.75222200E+01, 0.70572900E+00, -.51499200E+00, -.12071600E+01, -.66684600E+00, 0.37137000E+00, 0.26542900E+01, -.46314500E+00, 0.87275500E+00, -.11980200E+02, 0.62507500E+00, 0.14894400E+01, 0.43671000E+00, -.26323300E+01, -.11726900E+02, 0.23731700E+01, -.20549900E+02, 0.42208200E+01, 0.15449300E+01, 0.30157100E+02, 0.79978300E+01, -.93152300E+01, -.68643500E+01, 0.41068000E+01 },
        { -.33032800E+01, 0.41983200E+01, 0.40745200E+00, 0.11040300E+01, -.16077200E+01, 0.93191300E+00, -.32827700E+01, 0.18527200E+01, -.21420200E+01, 0.18709500E+01, -.12400800E+00, -.48817400E+00, 0.34480600E+00, 0.10762300E+00, -.66786300E+00, 0.29347000E-01, -.17577900E+00, -.38481600E+00, 0.31055300E+00, -.38688500E+00, 0.16229000E+00, 0.21116000E-01, 0.27802800E-01, -.56056000E-01, 0.13375900E+00, 0.68643500E-01, -.18756300E+00, -.39750800E+00, 0.35316100E+00, -.23509200E+00, 0.20319500E+00, 0.95481700E-01, 0.77278700E-01, 0.16358400E+00, -.25848800E-01, 0.93743100E-01, -.16437100E+00, -.86057200E-01, -.20225800E+00, -.96023500E+00, -.29885800E-01, -.78438000E-01, -.14780200E+00, -.36031100E-01, 0.27035400E-01, -.72686900E-01, -.82938900E-01, 0.17024200E-01, 0.43129600E-01, 0.74304500E-01, 0.11098500E+00, 0.69234900E-01, -.70680800E-01, 0.22222600E+00, 0.89681500E-01, -.31381400E-01, -.13563000E-01, -.37350600E-01, 0.55819900E-01, -.23408700E-01, 0.44037800E-01, -.12497500E+00, -.79297400E-01, 0.28894200E+00, -.23460300E+00, 0.30766500E-01, 0.22754900E-01, 0.65819900E-01, -.73318100E-01, 0.38724900E-01, -.81243900E-01, 0.65895600E-01, -.26906200E-01, 0.14412800E-01, -.14415900E+00, 0.61987400E-01, -.22810100E-01, 0.14180800E+00, -.54655700E-02, 0.80496500E-01, 0.17528400E-01, 0.40709100E-01, -.19178600E+00, 0.71797100E-01, 0.89081500E-01, -.17612500E-01, 0.80433100E-01, 0.61541900E-01, 0.16561800E+00, -.13961000E-02, 0.17204200E-01, 0.30091200E-01, -.14837700E-03, -.12467500E+00, 0.33429400E-01, 0.35213500E-01, -.35695500E-01, 0.15943000E+00, -.50674900E-01, -.48039600E-01, -.88547600E-01, 0.14237400E+00, 0.34323700E-01, -.82641500E-01, -.46373300E-01, 0.20048400E-01, 0.22621700E+00, 0.16965400E+00, -.24478400E+00, 0.45838100E-01, 0.11040400E+00, -.36305200E-01, 0.19356800E-01, 0.94053500E-01, 0.92589200E-02, -.24469800E+00, 0.15006700E+00, 0.85866300E-01, 0.14234400E-01, -.10968700E+00, 0.29140500E-01, -.55165000E-01, -.16074000E-02, 0.22444300E-02, 0.28675700E-01, 0.13058400E-01, -.45193800E-01, -.15934500E-01, 0.10560900E+00, -.76903500E-01, 0.13147300E+00, 0.22171800E+00, 0.13646300E+00, 0.33664500E-02, 0.19505200E-01, -.54039500E-02, 0.13130100E-01, -.17034000E-01, -.80515900E-01, -.16240300E+00, 0.14976800E-01, -.30011700E+00, 0.10008700E+00, 0.47536900E-01, -.12936500E-03, -.13966100E+00, 0.53157000E-01, -.54170300E-02, 0.49748800E-01, -.62327200E-01, -.53639200E-01, -.88289100E-01, 0.82251700E-01, -.68552300E-01, -.62752700E-02, 0.10074800E-02, 0.63784900E-01, 0.79648500E-02, -.12269600E+00, 0.40867200E-01, 0.26065000E-01, 0.27392500E+00, 0.26704000E+00, 0.26168800E-01, -.22482400E+00, 0.56951000E-01, -.21515100E+00, 0.57405800E-02, 0.10276900E+02, 0.64800500E+01, 0.14196500E+02, 0.85398900E+01, 0.26055900E+02, 0.10466000E+02, 0.12056700E+02, -.19730800E+02, -.33644300E+02, 0.16498700E+02, 0.55312300E+02, 0.16397100E+02, -.18192900E+02, -.18395500E+01, -.77655300E+00, -.21062500E+02, 0.66695300E+01, -.29838400E+01, 0.45541600E+02, 0.64259600E+02, -.35292100E+02, -.25731300E+02, -.32413200E+02, -.53447300E+01, 0.14242700E+02, -.21691000E+02, 0.10211500E+02, -.68462400E+01, 0.15946000E+02, -.21927600E+02, -.68930600E+02, 0.35055700E+02, 0.27272200E+02, 0.34708000E+02, 0.12640500E+02, -.10540600E+02, 0.37262100E+02, -.14026700E+01, 0.16787000E+02, -.34623400E+01, -.14859000E+02, -.25062000E+02, 0.13468000E+02, 0.20136000E+02, 0.12538500E+02, 0.84723900E+01, 0.91044600E+01, -.14355300E+01, -.13151700E+02, -.17711900E+01, 0.11486400E+02, -.48335800E+02, -.36476400E+02, 0.18003000E+02, 0.28515000E+02, 0.18356700E+02, -.19087000E+02, -.99467200E+01, 0.12159800E+02, -.86040900E+00, 0.55064100E+02, -.20780900E+02, -.18563000E+02, 0.19367500E+02, -.89036800E+01, -.41298700E+00, -.90130700E+01, 0.24946700E+01, 0.55283300E+01, -.10864600E+02, 0.54160500E+01, 0.17722400E+02, 0.71324800E+01, -.77142600E+01, 0.21567100E+02, -.11019100E+02, 0.34831000E+02, -.10397100E+02, -.45881900E+02, -.12246600E+02, 0.75174100E+00, -.58768800E+01, 0.44913500E+02, -.26702300E+02, -.29859600E+02, -.63767900E+01, 0.37767800E+01, 0.74285100E+01, 0.37881000E+01, -.27200900E+01, 0.41519600E+01, -.12172200E+01, 0.11197600E+02, 0.56536300E+01, 0.30170400E+01, -.68889600E+01, -.35356400E+02, 0.17499000E+02, 0.28769900E+02, 0.17868900E+02, -.34886800E+01, -.20712100E+02, 0.22831500E+02, 0.18435500E+02, 0.22653800E+02, -.12821900E+02, 0.24385400E+02, 0.10310500E+01, -.22271200E+01, 0.18281200E+01, 0.14749900E+00, 0.10676800E+01, -.12658600E+01, 0.15328000E+01, 0.64898200E+00, -.96112300E+00, 0.88775700E+00, -.32916900E+00, 0.40186800E+01, -.34138700E+00, 0.16153600E+00, 0.13399600E+01, 0.34043200E+01, -.29531100E+01, -.56352700E-01, 0.19854100E+01, 0.15885000E+00, -.23508200E+01, 0.28708400E+01, -.30398600E+01, -.61065200E+00, -.71857300E+00, -.26368300E+01 },
        { 0.78708800E+01, -.22570000E+01, -.23529500E+00, 0.69129700E+00, 0.58754500E+00, -.47507800E+01, 0.12095700E+02, -.30598700E+00, 0.53495900E+01, -.54836900E+01, -.21644700E+00, 0.92483000E+00, 0.68526600E+00, -.14551500E+01, 0.16375400E+01, 0.54052300E+01, 0.43909200E+00, -.22190700E+01, -.13822900E+01, 0.52284500E+01, 0.52460100E+00, -.52539000E+00, 0.10792700E+01, 0.97517000E-01, -.21389900E+00, -.72914700E-01, -.18056300E+01, -.30111900E+00, 0.71486500E+00, 0.53608000E-02, 0.88322800E+00, 0.18000500E+01, 0.69260700E+00, -.72991100E+00, -.75006300E+00, 0.11488400E+00, -.27885000E-01, -.44493100E+00, -.59764800E-01, -.35658800E+01, 0.15546200E+00, -.95665800E-01, -.36359700E+00, -.12257300E+01, 0.75755800E-01, -.46165500E+00, -.26784600E+00, 0.13537300E+00, 0.11364400E+00, -.23423000E+00, -.17473800E+00, -.32121600E+00, 0.34823200E+00, -.28717000E+00, -.75149300E+00, -.25892200E+00, 0.20562100E+00, -.42312000E+00, -.10789400E+00, 0.76986900E+00, 0.12172700E+01, 0.71586500E+00, 0.11241900E+00, 0.14049600E+01, 0.44938700E-02, -.13509500E+00, 0.33039300E+00, -.39626800E+00, -.13417200E+00, 0.20084900E+00, -.19705200E+01, -.39142900E+00, 0.21473700E+01, -.89539800E+00, 0.98945400E+00, 0.15423300E+01, -.57832700E+00, -.83508200E+00, -.14071500E+00, 0.16161700E+01, -.25600200E+00, -.85141800E+00, 0.19630000E-01, -.38494100E+00, 0.30739500E+01, 0.57519900E-01, -.76450200E+00, -.33563400E+01, 0.41956300E+01, 0.99613100E+00, 0.48745000E+00, 0.38821700E+00, -.37602500E+00, -.77765000E+00, 0.21370400E+01, -.25689800E+00, 0.32452100E+00, -.13496000E+01, 0.16464600E+01, 0.11302100E+01, 0.43459500E+00, 0.16060500E+01, -.34767700E+00, -.22828600E+01, 0.90729300E+00, 0.47254200E+00, 0.70078000E+00, 0.95783700E+00, 0.19441600E+01, 0.70865300E+00, -.24207500E+01, 0.99470200E+00, 0.31884100E+00, -.97805000E-01, 0.78649100E+00, -.26206900E+01, -.33444100E+01, 0.19509000E+01, 0.39089000E+00, 0.17420900E+00, 0.14594100E+01, 0.37652400E+00, -.88719700E-01, 0.12024300E+01, 0.20223500E+00, -.83662000E+00, -.27361300E+00, -.46707500E+00, 0.83345600E+00, -.10353300E+01, 0.18459500E+01, 0.45999600E+01, 0.10430900E+01, 0.43652500E-01, -.62386100E+00, -.40576100E-01, 0.77988100E+00, -.41952800E+00, -.41833300E+00, -.50028800E+01, -.92297100E+00, -.44395400E+01, -.19398000E+01, 0.10439300E+00, -.24494400E+00, -.69918800E-01, -.47837400E-01, 0.75501200E+00, 0.66287800E+00, -.10032500E+01, -.38298300E+00, -.94227400E+00, 0.27260900E+01, 0.24497900E+00, -.18909500E+00, 0.12407500E-01, -.58903300E+00, 0.32774100E-01, -.15210100E+01, -.10092200E+01, 0.37873400E+00, 0.30531400E+01, 0.33533400E+01, 0.57312000E-01, -.23988100E+01, -.11459300E+00, -.52071200E+00, -.23729200E+00, -.31928600E+00, 0.15254000E+03, 0.14294500E+03, 0.76863000E+02, 0.23375900E+03, 0.80769800E+02, 0.11514200E+03, -.11472200E+03, -.53241000E+03, 0.26680100E+03, 0.59045200E+03, 0.26342500E+03, 0.18619600E+03, 0.96853400E+02, 0.30476800E+03, 0.30402500E+03, 0.20690300E+03, 0.72033400E+02, 0.50126100E+03, 0.13859100E+04, -.67979200E+03, -.18752200E+03, -.69395900E+03, -.13174600E+03, -.80475200E+02, -.35753100E+03, -.53499100E+02, -.59473600E+03, 0.10619900E+02, -.62891600E+03, -.11468800E+04, 0.57218200E+03, 0.39999000E+03, 0.57390300E+03, 0.22985500E+03, -.12101200E+03, 0.43626200E+03, -.13385500E+03, 0.38660600E+03, -.64854100E+02, -.23114300E+03, -.17681100E+03, 0.86274800E+02, 0.40248300E+03, 0.88198000E+02, 0.18996200E+03, 0.16290600E+03, -.10194600E+03, -.28197700E+02, 0.18290000E+03, 0.12589800E+03, -.59776800E+03, -.16632400E+04, 0.83238600E+03, 0.90174000E+03, 0.83206900E+03, -.22927200E+03, -.26409300E+02, 0.54357400E+03, -.94228900E+02, 0.69338200E+03, -.77572800E+02, 0.89387100E+03, 0.58805800E+03, -.30337100E+03, -.19752800E+02, -.29072700E+03, -.79362200E+02, -.83611300E+02, -.16344200E+03, -.99628800E+02, -.19883400E+03, -.25070000E+02, -.20647600E+03, -.16401400E+04, 0.82109500E+03, 0.13239700E+04, 0.82122200E+03, -.35923500E+03, -.43246600E+02, 0.79108100E+03, 0.27075400E+03, 0.91599300E+03, -.14355700E+03, 0.11161100E+04, 0.21243100E+03, -.10824100E+03, 0.72684800E+02, -.10439000E+03, 0.29113800E+01, -.24059900E+02, 0.56466800E+02, 0.28781400E+03, -.88728200E+02, 0.13141500E+02, -.86025700E+02, 0.21833700E+03, -.11207600E+03, -.12316800E+03, -.10836600E+03, -.11960600E+03, -.23542900E+03, 0.24516000E+03, 0.29322000E+03, 0.38046400E+02, -.13436600E+03, 0.11419500E+03, 0.24601500E+02, -.45467500E+02, 0.34904700E+02, 0.13005100E+02, 0.25593100E+01, -.30600900E+02, 0.42248200E+01, 0.40880400E+01, -.10811200E+02, 0.11808800E+02, 0.23681400E+02, 0.96701600E+02, 0.34447900E+01, 0.17915900E+01, 0.48464800E+02, 0.25255800E+02, 0.21789900E+02, -.42199000E+02, 0.11375500E+03, -.25546000E+02, 0.32298600E+02, -.10655100E+03, -.78345000E+02, 0.22093700E+02, 0.26774000E+02, -.29946800E+02 },
        { -.81740700E+01, 0.35795900E+01, 0.12204100E+01, -.38696700E+01, -.30729900E+01, 0.41310000E+01, -.71523800E+01, 0.69808300E+01, -.34997400E+01, 0.54788000E+01, 0.16517300E+00, -.69159800E-01, -.34882700E+01, 0.17921600E+01, -.49042500E+01, 0.19985100E+00, 0.35323400E+00, -.27133000E+01, 0.29419000E+01, -.17788800E+01, -.93535000E+00, 0.43712300E+00, 0.19028200E+00, 0.50063600E+00, -.38815600E+01, -.23115600E+00, -.60425100E+00, -.42135500E+01, 0.23927300E+01, -.17580200E+01, 0.13349300E+00, 0.49219400E+00, -.69987000E-01, 0.57304000E+00, -.26892800E-01, 0.37149200E+00, -.46266300E-01, -.33031100E+00, 0.37115800E+00, 0.36439500E+01, -.33008300E+00, -.63430000E+00, 0.84262000E-01, 0.12923600E+00, -.90704400E-01, -.60951200E+00, -.83442100E+00, -.99674000E-01, 0.53369000E+00, 0.13501200E+01, 0.16035300E+01, -.27789300E-01, -.76192700E+00, -.49053700E+00, 0.72242000E+00, 0.16733300E+01, 0.14218800E+00, 0.72889700E+00, -.10436300E+00, -.10582900E+01, -.20613900E+01, 0.50254200E+01, 0.29054400E+01, -.74288100E+00, 0.12362600E+01, 0.39816600E-01, 0.61556400E+00, 0.70769400E+00, 0.59135700E+00, 0.12896200E+00, -.13984600E+01, 0.42490400E+00, -.65729200E+01, 0.45341100E+00, 0.72021000E+00, -.88454400E+00, 0.43577700E+00, 0.15229400E+01, 0.23825600E+00, -.21313600E+00, 0.30663100E+00, -.74998400E+00, 0.43537500E-01, 0.43214400E+00, 0.11971000E+01, -.13670700E-01, 0.31260600E+01, -.19574600E+01, 0.64715800E+00, -.16286100E-01, 0.15168700E+01, 0.36744300E-01, 0.41974100E-02, 0.14723200E+01, -.50548100E+00, -.49454800E+01, 0.15261100E+01, -.16764900E+00, -.11189700E+01, -.33626500E+00, 0.22854300E+00, -.30750800E+00, -.21793100E+01, -.32003100E+01, 0.10325300E+01, -.11949800E+01, -.13489200E+01, -.12038800E+01, 0.51700300E-01, -.89191500E-01, 0.22007500E+01, 0.37728700E-01, 0.12963300E+01, 0.26293800E+00, 0.72079000E+00, 0.41936100E+00, -.53595500E+01, 0.14953000E+01, -.98798700E-03, 0.25616900E+00, 0.47585800E+00, -.56326500E+00, 0.70717600E-01, 0.19055300E+00, -.17309600E-01, -.69553700E+00, -.19677600E+00, 0.14178500E+00, -.50960500E+00, -.21762700E+00, 0.10052100E+01, 0.11393300E+01, 0.96428900E+00, 0.25345500E-01, 0.15939400E+00, 0.28733600E-02, -.15036400E+01, 0.40314500E+00, -.61139800E+00, -.74828300E+00, -.88996000E+00, -.15003700E+01, 0.25931600E+00, 0.67233800E+00, 0.19935600E+00, -.25345500E+01, -.49736400E-01, -.43931000E-01, 0.51696400E+00, -.10250600E+01, 0.38615500E+00, 0.99788100E+00, -.23341100E+01, 0.75383800E+00, 0.12235700E+00, -.65722200E+00, 0.19345700E+01, -.91828200E-02, 0.18362100E+01, -.20252700E+01, -.24256800E+00, -.19641500E+01, -.50889100E+01, 0.25570800E+00, 0.26976400E+01, -.32412900E+00, 0.18117400E+01, -.43095100E+01, -.58671200E-01, -.28818700E+00, -.21750400E+03, 0.73187000E+02, 0.21142200E+02, 0.36647500E+02, -.21092700E+03, 0.28013900E+03, 0.41043200E+03, -.19700600E+03, -.95693800E+03, -.20434000E+03, 0.10613500E+02, 0.13019800E+03, -.42216300E+02, 0.14211900E+02, -.21236800E+03, 0.15131400E+03, -.11016200E+03, -.60616600E+03, 0.31333600E+03, 0.71082300E+03, 0.30336300E+03, -.29850400E+01, -.39649500E+03, 0.36789300E+03, 0.43326100E+03, 0.33720300E+03, -.42655000E+03, 0.18886900E+03, 0.60027800E+03, -.30201400E+03, 0.27618200E+03, -.30233500E+03, 0.25414100E+03, 0.12406300E+03, -.42577900E+03, -.31529600E+03, -.48897700E+03, 0.15110100E+03, 0.71230500E+02, -.36126800E+03, 0.17704900E+03, 0.20019300E+03, 0.17998600E+03, 0.15754300E+02, 0.21298400E+03, -.10459100E+03, -.14343600E+03, -.22041000E+02, 0.15671600E+03, 0.22896400E+03, -.29203400E+04, 0.14630700E+04, 0.10592600E+04, 0.14598600E+04, 0.28962500E+03, 0.48326700E+03, 0.43939400E+03, -.71969400E+03, 0.42975700E+03, 0.58025400E+03, 0.15306800E+04, 0.35188200E+03, -.19263900E+03, 0.80807800E+03, -.17273500E+03, -.19569400E+03, -.39367600E+03, 0.21010100E+03, 0.56991400E+03, -.21482700E+03, -.37452700E+03, -.30182500E+03, -.29110300E+04, 0.14629000E+04, 0.93716700E+03, 0.14534900E+04, 0.41817500E+03, 0.72893300E+03, 0.37773000E+03, -.83133900E+03, 0.35234400E+03, 0.76625600E+03, 0.13131900E+04, 0.13733300E+03, -.68663300E+02, -.42337400E+03, -.71907000E+02, 0.25234900E+02, 0.29835100E+02, -.39253900E+02, -.15935200E+03, -.19916200E+03, 0.56668200E+02, -.10731800E+02, 0.43414000E+03, -.22457800E+03, -.11639600E+03, -.21739300E+03, 0.25493600E+02, -.42955800E+02, -.15731600E+02, -.46570300E+02, -.23144700E+03, 0.39005000E+02, 0.50391100E+02, -.13359500E+02, -.16455100E+02, -.23747500E+02, -.28416900E+02, 0.50122500E+00, 0.50308700E+00, 0.28209100E+02, -.10617800E+02, 0.45742400E+01, -.26534500E+01, -.13786700E+02, 0.62445700E+02, 0.73394400E+01, 0.68844600E+01, 0.62947200E+02, -.93094800E+01, 0.59412900E+02, -.66242400E+01, 0.67092800E+02, 0.46637700E+02, -.33840600E+02, 0.55268400E+02, -.58335100E+02, -.35004900E+02, -.96962800E+01, 0.70624700E+01 },
        { -.13447000E+01, -.81250000E+00, -.15484700E-01, -.80360900E+00, -.13840300E+01, -.75403900E+00, -.15739500E-01, -.77836300E-01, -.37660100E+00, 0.12999500E+01, 0.12705900E-01, -.70203200E-01, 0.29932600E+00, 0.51291000E+00, 0.69211700E-01, -.25258100E+00, -.54476000E+00, -.10973200E+00, 0.23841000E+00, -.29016700E+00, -.74314100E-01, 0.81320000E-01, 0.39578300E-01, -.53337100E-01, 0.49148400E+00, 0.42357200E-01, 0.44688400E+00, 0.31162800E+00, 0.14220600E+00, 0.49034600E+00, 0.12817800E+00, 0.47264600E+00, 0.13513300E+00, 0.65151600E-02, 0.13556400E+00, 0.22248200E-01, -.11581700E+00, -.12660700E+00, 0.23304500E+00, -.37082400E-01, -.57904500E-02, 0.16205200E+00, -.20658300E+00, -.67986500E-02, 0.83052400E-01, -.59662300E-01, 0.63428200E-01, 0.71851500E-02, -.69304600E-01, -.30376500E+00, -.78428700E+00, -.45832400E-01, 0.29914300E+00, 0.89872800E+00, -.19864500E-01, -.11953600E+00, -.21769600E+00, 0.37752700E-01, -.49899900E-01, -.16685900E-02, 0.88861500E+00, -.29534300E+00, -.16159500E+00, 0.12151300E+00, -.27738000E+00, 0.27120600E-01, 0.23714900E+00, -.26940600E-02, 0.27963100E-01, -.10793600E-01, 0.67303200E-01, -.81223600E-01, -.27342500E+00, -.21990200E+00, -.17217600E+00, 0.16365600E+00, -.39673100E-01, -.20429400E+00, -.52046300E-01, 0.11233000E+00, -.41574900E-02, -.66170100E-01, -.18451400E+00, -.65234000E-01, 0.51808700E+00, 0.81229500E-01, -.30743100E+00, 0.38060900E+00, 0.91643900E+00, -.35925000E+00, -.51277900E+00, 0.22961900E-02, -.27136400E-01, -.24110300E+00, -.42880100E-01, -.18403000E+00, -.53173500E-01, -.16681300E-01, -.24760600E+00, 0.10318400E+00, 0.78977600E-01, 0.21441700E-01, 0.13331000E+00, 0.35064400E-01, -.50355500E-01, 0.39571900E-01, 0.10889100E+00, -.14336100E+00, -.44810100E-01, -.35128000E-01, 0.73405600E-01, -.79823000E-02, -.84536400E-02, -.12820500E+00, -.13745400E+00, -.31653300E+00, -.22775300E+00, -.31311600E+00, -.67275400E-01, 0.31944700E+00, 0.35492200E-01, -.32534000E+00, -.43421300E-01, -.50518600E-02, -.31126600E-02, 0.43180800E-02, 0.21465600E-01, 0.68491600E-02, -.28106600E+00, -.28774200E+00, 0.63157000E+00, 0.48439700E+00, -.20621100E+00, 0.32984200E-02, -.13135800E+00, 0.50705900E-03, 0.31116800E+00, 0.24300200E+00, -.51158300E-01, -.75575700E+00, 0.15216500E+00, 0.31619700E-01, -.33948200E+00, -.11695900E+00, -.18562400E-01, -.13703800E+00, -.33352500E-02, 0.36536600E-01, 0.10223700E+00, 0.10732800E+00, 0.25358900E-02, -.20501700E-01, 0.72961100E+00, 0.10801800E+00, 0.14253900E-01, -.17388000E-01, -.28046700E+00, 0.12076400E-01, -.10651000E+00, 0.67745400E-01, -.13521300E-01, 0.40432900E-02, 0.36240000E+00, 0.51052100E-01, -.26535300E+00, -.43414100E-01, -.10868900E+00, -.41605200E+00, 0.56308400E-01, -.49806900E-01, -.16514900E+00, 0.76666100E+02, 0.23623000E+02, 0.92360300E+01, -.31069400E+00, -.54140700E+02, 0.14681900E+03, -.71294600E+02, -.99156500E+02, -.75426100E+02, 0.62117000E+01, 0.81652500E+02, -.88990300E+02, -.98626000E+02, -.12351400E+03, 0.88436700E+02, 0.72915800E+02, -.14280000E+03, 0.71562900E+02, 0.56618200E+02, 0.71607100E+02, 0.16581000E+02, -.46663500E+02, 0.12747500E+03, 0.82290200E+02, 0.18279200E+02, -.40026600E+02, 0.14503400E+03, -.14916300E+03, 0.75099000E+02, 0.14960800E+03, 0.74836700E+02, 0.11537300E+03, -.20526600E+02, -.22468900E+02, -.11267000E+02, -.38482600E+02, 0.21436200E+01, 0.12204900E+03, -.60363000E+02, 0.30550000E+02, 0.54044600E+02, 0.30311900E+02, -.17516200E+02, 0.82278000E+02, -.54873500E+02, -.19641200E+02, -.57810200E+02, 0.57671200E+02, 0.13247700E+03, -.94205000E+03, 0.47224900E+03, 0.42253500E+03, 0.47102000E+03, 0.78344600E+02, 0.15105200E+03, 0.12248200E+03, -.24903600E+03, 0.15051700E+03, 0.17020200E+03, 0.38733200E+03, 0.15845800E+03, -.80319100E+02, 0.12137000E+03, -.80601500E+02, -.61062400E+02, -.11067100E+03, 0.45424000E+02, 0.16732200E+03, -.74660000E+02, -.98980700E+02, -.25651300E+02, -.95355200E+03, 0.47951900E+03, 0.40576300E+03, 0.47698200E+03, 0.87955300E+02, 0.23127400E+03, 0.10699800E+03, -.29445700E+03, 0.14470500E+03, 0.22065200E+03, 0.32351400E+03, -.37819700E+02, 0.19436500E+02, -.14789700E+03, 0.19120600E+02, -.11464100E+02, -.43895800E-01, 0.53522200E+02, -.60344500E+01, -.11503600E+02, 0.37305400E+01, 0.21470000E+01, 0.54747800E+02, -.30644300E+02, 0.21967000E+02, -.27374500E+02, -.15767200E+02, -.57391800E+02, 0.32439300E+02, 0.35395400E+02, -.98859300E+00, -.13718400E+02, 0.21256300E+02, -.45852700E-02, -.12117300E+02, -.46971600E+01, 0.77138900E+00, 0.40647300E+01, -.73613600E+01, 0.41760800E+01, -.24820000E+00, 0.26511800E+01, 0.46452400E+01, -.50019600E+01, 0.19160400E+02, 0.37073400E+01, 0.34368400E+01, 0.18997700E+02, 0.56282200E+01, -.62658400E+01, 0.51538200E+01, 0.80335100E+01, 0.93325100E+01, -.15613700E+02, 0.26174500E+02, -.18069700E+02, -.14668900E+02, -.58844800E+01, -.48307200E+01 },
        { -.73404500E+01, -.88453800E+01, -.96194000E+00, -.40199300E+01, -.14500600E+01, -.19777200E+00, -.91700600E+01, -.10559200E+00, -.46524400E+01, 0.65770800E+01, 0.28271300E+00, -.45427900E+00, 0.23050600E-01, 0.54363300E+01, -.69313400E+00, -.76944500E+00, -.46734700E-01, 0.35231600E+01, -.14367300E+01, -.93034400E+00, 0.56015100E+00, 0.27720300E+00, -.45019800E+00, -.30467900E-02, -.16610800E+01, 0.24041100E-01, -.67484700E+00, 0.13863200E+01, -.19716500E+01, 0.14916200E+01, -.86740600E+00, -.89863000E+00, 0.66718100E+00, 0.19678900E+00, 0.96978100E+00, -.50948300E+00, 0.47729400E+00, 0.36698700E+00, -.24304400E+01, 0.18819100E+01, 0.67551700E-01, 0.62322500E-01, 0.47389200E+00, 0.34049500E+00, 0.18757400E+00, -.96597100E-01, 0.63453700E+00, -.31703300E-01, 0.69688600E-01, -.33110800E+00, 0.24467900E+01, 0.65450400E+00, -.59916200E+00, -.28997900E+00, -.87223000E+00, -.69693700E+00, 0.30950200E+00, -.33291200E+00, -.87805300E-01, 0.77593300E+00, -.32682200E+00, -.63379600E+01, -.36849700E+01, 0.19626300E+00, 0.46490000E+00, -.13789500E-01, 0.99799700E+00, -.47445700E+00, -.11835900E+00, 0.19346500E-01, 0.31912600E+00, 0.18708400E+00, 0.48972600E+00, 0.23209300E-01, -.62148800E+00, -.11160100E+01, 0.79002900E+00, -.20047300E+01, -.68492400E+00, 0.52631900E+00, 0.16769900E+00, -.22391000E+00, -.11764700E+01, -.19847300E+00, 0.13561900E+01, 0.27404100E+00, 0.17840400E+01, -.94079500E+00, -.34213700E+01, 0.70119700E+00, -.57303900E+01, -.16961900E-01, -.28089600E+00, -.12675800E+01, 0.47223000E+00, 0.85167600E+00, -.13023900E+00, 0.92878100E+00, 0.25916100E+00, -.51741700E-01, -.30817100E+00, -.21968600E+00, 0.36424800E+00, 0.94967900E+00, -.39493700E+00, 0.63876000E+00, 0.24174400E+00, 0.49938300E+00, -.73963400E+00, 0.17700100E+00, 0.68466200E+00, 0.90151300E+00, 0.24510100E+00, 0.40240700E+00, -.32275400E+00, -.20041800E+01, -.10428900E+02, 0.33269700E+01, 0.50709700E+00, 0.12706900E+01, -.56931000E+00, 0.54758000E+00, -.29042100E-01, 0.97248200E+00, 0.90879300E-01, -.39669800E+00, 0.43792400E+00, 0.20111000E+00, 0.80656100E+00, 0.14934300E+01, -.62280500E+00, 0.16312400E+01, -.15384800E+01, -.44060700E-02, -.69618800E+00, 0.10202100E-01, 0.44863800E+00, -.17517200E+00, 0.38074800E+00, 0.56231000E+00, -.66632700E+00, 0.23691700E+01, 0.10886500E+01, 0.12628600E+00, -.53687300E+00, 0.80034600E+00, 0.11458200E+00, 0.17057700E+00, 0.58801900E+00, 0.11131700E+01, 0.12924700E+01, 0.59869400E+00, 0.59427700E+00, 0.66760800E+00, 0.60487000E-01, -.13859400E+00, 0.49079700E+00, 0.39106400E-02, 0.11641900E+00, 0.30976600E+00, 0.16891600E+00, 0.55288400E-01, 0.11931700E+01, -.77203400E-01, 0.78021100E-01, 0.17780200E+00, 0.95296900E+00, -.24771900E-01, -.71093300E-01, 0.28712000E+00, 0.19082400E+00, -.43750300E+00, -.22723500E+03, -.87962800E+02, 0.12574400E+02, 0.19793900E+02, 0.14201300E+03, -.83044100E+02, 0.27212200E+03, -.62488600E+02, 0.36118500E+03, 0.65413600E+02, 0.52312900E+02, 0.17211100E+03, 0.20113600E+02, 0.54199700E+02, -.40019400E+03, -.29217000E+03, 0.16316300E+03, -.12328300E+03, 0.14601200E+03, 0.14071700E+02, -.16589500E+03, 0.13366100E+03, -.25107100E+03, 0.59740000E+02, -.16490800E+03, 0.39000400E+02, 0.18624500E+03, -.93020500E+02, -.28469100E+03, -.93531200E+02, -.20091300E+03, -.66488800E+02, -.72953500E+02, 0.16290500E+03, 0.13775400E+03, -.10560200E+03, -.11906900E+03, 0.33086800E+03, -.16641100E+03, -.18562800E+03, -.16503100E+03, -.50337200E+02, -.28993300E+02, -.22619900E+02, 0.12446000E+03, -.65408700E+02, -.56445600E+02, 0.22790100E+03, 0.66432800E+03, -.33721000E+03, -.19356900E+03, -.33266900E+03, 0.11729900E+03, -.24830300E+03, 0.28095900E+02, 0.25054100E+03, -.40208500E+03, -.18773800E+03, -.13393900E+03, -.17040800E+01, 0.28828600E+02, -.40053900E+03, 0.10874200E+01, -.58225700E+02, -.18364200E+03, 0.86543100E+02, -.79149800E+02, 0.35422300E+02, -.18658200E+03, 0.41322200E+02, -.30891400E+03, 0.14119200E+03, 0.14708200E+03, 0.15315100E+03, 0.41104700E+03, -.36321400E+03, 0.35888700E+03, 0.31180700E+03, -.11570000E+03, -.22500600E+03, 0.94294400E+02, 0.74024300E+02, -.44857700E+02, -.48781400E+02, -.38922800E+02, -.26121900E+02, -.11405900E+03, 0.91082300E+02, 0.65506500E+02, 0.14406000E+02, -.10359500E+03, 0.76044500E+02, 0.32213200E+03, -.16154600E+03, -.43197900E+03, -.16221200E+03, -.39262000E+02, 0.11785300E+03, -.15334700E+03, -.69189200E+01, -.13810800E+02, 0.44375400E+02, -.31731300E+03, 0.13333900E+02, 0.11002200E+02, -.35483600E+01, 0.24066100E+02, -.71289400E+01, -.64258500E+01, -.36594900E+02, -.27554700E+01, 0.10784200E+02, 0.63339400E+00, 0.11343100E+02, -.45573300E+02, 0.61880000E+01, -.13611100E+01, -.18397700E+02, -.15608300E+02, 0.31919300E+01, 0.71340000E+01, -.45685300E+02, -.30001100E+02, 0.11343100E+02, -.21308100E+03, 0.42017200E+02, 0.58015700E+02, 0.18076100E+02, 0.42754400E+01 },
        { -.60924600E+01, -.99821300E+01, -.11834300E+01, -.58650400E+01, -.20344600E+01, 0.25326000E+01, -.85255500E+01, 0.52564900E+00, -.36691400E+01, 0.50527700E+01, 0.33021900E+00, -.39093300E+00, -.17327100E+01, 0.11447300E+02, -.18420700E+01, 0.17114300E+01, -.19471700E-01, 0.32694200E+01, -.96298100E+00, -.14490700E+00, 0.11442100E+01, 0.69491200E-01, -.66224500E+00, -.16584400E+00, 0.10754600E+00, 0.98548700E-01, -.59025100E+00, 0.16435100E+01, -.23613200E+01, 0.84157800E+00, -.63178400E+00, -.69817000E+00, 0.57192900E+00, -.77940000E+00, 0.31776900E+00, -.70826400E+00, 0.53191100E-01, -.31891800E+00, -.94862800E+00, 0.28124100E+01, -.15044300E+00, -.83173400E-01, 0.10463600E+01, 0.99459400E-01, 0.19576100E+00, 0.29940600E+00, 0.29664600E+00, -.13805300E-01, -.39864700E-01, -.43560300E+00, -.13523500E+01, -.25674300E+00, 0.39211900E+00, 0.10077100E+01, 0.73681800E+00, -.22292600E+01, 0.12362900E+01, -.53426200E+00, -.52402100E-01, 0.83950900E+00, 0.13655700E+01, -.48411000E+01, -.28750600E+01, -.20224300E+00, -.53542200E+00, -.12140900E+00, -.36046000E+00, -.15197700E+00, -.61472500E+00, 0.50119600E-01, -.10850800E+01, 0.12374400E+01, 0.26053100E+01, 0.78149800E+00, -.63437600E+00, -.50512500E+00, 0.59420600E+00, -.84944100E+00, -.72671300E+00, 0.10196100E+01, 0.97380400E-01, 0.35649300E+00, -.81108100E+00, -.11990700E-01, 0.27769000E-01, -.20981400E+00, 0.25805100E+01, 0.35214600E+00, -.62314900E-01, 0.11349800E+01, -.16045500E+01, -.55688400E-01, -.79115600E+00, -.35296200E+00, 0.19350300E+01, -.41962200E+00, 0.45674000E+00, 0.22661200E+01, 0.78800100E+00, -.19890000E+00, -.57089000E+00, 0.63080500E+00, 0.55465300E+00, 0.53147800E+00, -.16874800E+00, 0.13923000E+01, 0.18908900E+01, 0.24777100E+01, -.86594800E+00, 0.32851500E+00, -.88223100E+00, 0.14078300E+00, 0.17598500E+00, -.80830300E-01, 0.11818800E+01, -.64783900E+00, -.37341500E+01, 0.92011800E+00, 0.68731800E+00, -.41734200E+00, 0.43387900E+00, -.51068100E+00, -.14936000E+00, -.44047200E+00, -.15538100E-01, -.30830800E+00, 0.73414900E-01, 0.10054500E+01, -.67450700E+00, -.47072900E+00, 0.58990600E+00, -.17372200E+01, 0.80101500E+00, -.42330400E-02, -.12118100E+00, -.69567300E-03, 0.30366800E+01, -.52931700E+00, 0.88796800E+00, 0.42886900E+00, 0.44854100E+00, 0.17293800E+01, 0.77379700E+00, 0.20623000E+00, -.85660200E-01, -.76170500E+00, 0.10905000E+00, -.84076600E-01, 0.27043500E+00, -.68453100E+00, -.14761300E+00, 0.27509100E+00, -.31645900E+00, 0.11731100E+00, 0.36015600E-01, 0.32174500E-01, -.17253700E+01, 0.27036900E-01, -.17289500E+00, -.66705700E+00, -.72743200E-02, -.38215700E+00, -.66689900E+00, -.19848300E+00, -.26400200E+00, 0.68079900E+00, 0.12725500E+01, -.33541500E-01, 0.86541800E-02, 0.94324500E-03, -.92133900E-01, -.20194000E+01, 0.25636300E+00, 0.15033300E+03, -.21297000E+02, 0.24141800E+03, 0.11482700E+03, -.55815400E+02, -.40929300E+03, -.50871100E+02, 0.14645600E+03, 0.27667000E+03, 0.15978300E+03, 0.42994800E+03, -.22352200E+03, 0.32173400E+03, -.10369300E+03, -.11658200E+03, 0.81563700E+02, 0.37321600E+03, 0.58622700E+02, -.34585900E+02, -.36347400E+03, 0.35010300E+03, 0.18345800E+03, -.28132000E+03, -.29611200E+03, -.17990100E+02, -.85801600E+03, 0.42242800E+03, 0.37269900E+03, 0.42728000E+03, 0.30941400E+03, 0.32977300E+02, 0.10559100E+03, -.18211800E+03, 0.11414700E+03, 0.44176600E+02, 0.39838200E+03, -.30333000E+02, 0.52567600E+01, 0.14751400E+03, 0.15412800E+02, 0.12458800E+02, 0.97305000E+02, -.64869500E+02, 0.35263700E+00, 0.10854600E+03, 0.22793400E+02, 0.17539500E+03, -.24634300E+04, 0.12326600E+04, 0.99317500E+03, 0.12308300E+04, -.14733700E+02, 0.33030000E+03, 0.46616000E+03, -.51696600E+03, 0.34948300E+03, 0.40806700E+03, 0.14138300E+04, 0.36138400E+03, -.19602600E+03, 0.35390800E+03, -.17988800E+03, -.14467400E+03, -.30931400E+03, 0.17792800E+03, 0.20264800E+03, -.45554100E+03, -.25462100E+03, -.16639400E+03, -.28243100E+04, 0.14096900E+04, 0.10962100E+04, 0.14093000E+04, -.84061900E+01, 0.49100200E+03, 0.71522500E+03, -.18072700E+03, 0.48786500E+03, 0.52705400E+03, 0.16011500E+04, 0.24326600E+03, -.12893300E+03, -.28517800E+03, -.12609800E+03, 0.11888600E+02, 0.31541800E+02, -.29024000E+01, 0.16449000E+01, -.33119700E+03, 0.97441900E+02, -.30504600E+02, 0.40141600E+03, -.20068000E+03, -.82314900E+02, -.20244400E+03, -.64124400E+02, -.82126100E+02, 0.16932700E+02, 0.69095300E+02, -.20181000E+03, 0.22042900E+02, -.14520000E+03, 0.61486800E+01, -.16514700E+02, 0.65775000E+01, -.71734600E+01, -.92739000E+01, -.36233600E+02, 0.25887100E+02, -.32849900E+01, 0.23707600E+01, 0.13555600E+02, 0.20628800E+02, 0.47707000E+02, 0.70507700E+01, 0.43910100E+01, 0.49372600E+02, 0.28321300E+01, 0.35963600E+02, -.44602100E+02, 0.69978400E+02, 0.16810000E+01, 0.17224400E+02, -.16267600E+01, -.44657500E+02, -.11030600E+02, 0.40581600E+01, 0.98792200E+01 },
        { -.14725400E+01, -.12998400E+01, -.76094800E-01, -.11864500E+01, -.17205900E+01, -.19440600E+00, -.85325200E-01, -.56671000E+00, -.25092300E+00, 0.15093000E+01, 0.21856600E-01, -.60116100E-01, 0.17152900E+01, -.19874100E+01, 0.10429800E+01, -.46940200E-01, -.79854700E+00, 0.14994600E+00, -.62285000E-01, -.39672500E+00, 0.55608700E+00, -.11298100E-01, 0.93557600E-01, 0.31967700E-01, 0.23117400E+00, -.13734400E-01, -.31443100E+00, -.11489100E+00, -.46429300E+00, 0.15246000E+00, -.47686800E-01, 0.90685700E-01, 0.60244400E+00, 0.10858400E+00, 0.65242800E-02, -.19819100E+00, 0.54070600E-01, 0.33930500E+00, 0.35912900E-01, 0.36559200E+01, -.75309600E-01, -.82013900E-01, 0.40877400E+00, -.20180900E+00, 0.13848100E+00, 0.50548300E-01, -.78243500E-01, 0.80000000E-02, -.54835100E-01, -.16896000E-01, -.73530500E+00, 0.37757000E+00, 0.13719800E+00, 0.17375500E+00, -.13534000E+00, 0.91016200E-01, 0.87462500E-01, -.39027900E-01, 0.35681300E-01, -.43557200E+00, -.22764100E+00, -.27824300E+00, -.17266600E+00, 0.47650400E+00, 0.37061500E+00, 0.35422000E-01, 0.37437600E+00, 0.56790100E-01, 0.11406100E+00, -.15506500E-01, 0.43161700E+00, -.34385800E-01, -.99398700E+00, -.32160100E+00, -.17990700E+00, 0.20994100E+00, 0.81686300E-01, -.29104200E+00, -.23206200E+00, 0.85665700E+00, -.53690400E-04, -.14329700E+00, -.26011300E-01, 0.14929700E-01, 0.37804000E+00, -.83962000E-01, -.65998200E+00, -.29828100E+00, 0.95810300E+00, 0.12349400E+00, -.69090900E+00, -.15232000E-03, -.54183700E-02, 0.42147400E-01, 0.14530400E+00, -.43780400E+00, 0.71072100E-01, -.13569100E+00, -.84895300E-01, 0.12582300E+00, 0.22482000E+00, -.25400100E+00, -.31808900E-01, 0.11598400E+00, 0.73888900E-01, -.18417000E+00, -.35543300E+00, -.36695300E+00, 0.59178200E+00, -.16770200E-01, -.12248100E+00, 0.10491500E+00, -.98318900E-01, 0.42170000E-01, -.43002400E-01, 0.54824100E+00, 0.48928500E+00, -.73335300E-01, 0.11959500E-01, -.24768600E+00, 0.15916100E+00, -.50898500E+00, -.49094900E-01, -.17698300E+00, 0.33826200E-02, 0.17527700E+00, -.33729600E-01, -.25848600E+00, 0.11206400E+00, 0.10999700E+00, -.39501400E+00, -.80421900E+00, 0.25467600E+00, -.16690700E-02, 0.28258500E-01, -.21891000E-02, -.69237200E+00, -.38064300E-01, -.15054800E-01, 0.87544200E+00, 0.78786400E-01, 0.76943000E-01, 0.13770400E+00, -.11281500E+00, -.17525700E-01, 0.39945700E+00, 0.10255400E-02, -.19794600E-01, -.19597800E+00, 0.25841700E+00, 0.39504900E-01, -.98745200E-01, -.12133200E+00, 0.41031400E-01, -.33843700E-02, 0.42780500E-01, -.10547300E+00, 0.73184100E-02, -.15884100E+00, -.65893000E-01, 0.30772500E-01, -.13579700E+00, 0.60691400E+00, -.11424100E+00, -.10086300E+00, 0.73685500E-03, 0.51384400E-01, 0.64407300E+00, -.60583300E-01, 0.19880800E-01, -.11143500E-01, -.42642700E+00, 0.18827300E+00, -.13218500E+00, 0.11947400E+02, 0.22295700E+02, -.59286100E+02, 0.32924800E+02, -.13286400E+02, 0.30721200E+02, 0.46684900E+02, 0.28900200E+02, 0.32404800E+02, 0.37996700E+02, 0.21449800E+00, 0.44365900E+02, 0.84901900E+02, -.10964800E+03, 0.58122100E+02, 0.82456000E+02, 0.54852300E+02, 0.31428300E+02, 0.83289900E+01, 0.39846100E+02, 0.19790600E+02, 0.37975600E+02, 0.12160000E+02, 0.56591900E+02, -.32480300E+03, 0.16081600E+03, 0.20070200E+03, 0.16190500E+03, 0.92397400E+02, -.77457200E+01, 0.70970700E+02, -.44239200E+02, 0.75189500E+02, -.48556100E+00, 0.93752900E+02, -.90951200E+02, 0.42970500E+02, 0.89009200E+02, 0.45329000E+02, 0.79465700E+01, 0.19409600E+02, 0.14936700E+02, 0.28062700E+01, 0.11027800E+03, 0.11033500E+01, 0.80550200E+02, -.55029900E+03, 0.27638000E+03, 0.23651500E+03, 0.27508100E+03, -.47901700E+02, 0.75387600E+02, 0.89711300E+02, -.11378800E+03, 0.11960300E+03, 0.87127100E+02, 0.39947200E+03, 0.34190400E+02, -.26518000E+02, 0.11952200E+03, -.16249400E+02, -.16401400E+01, -.84161500E+00, 0.14482400E+02, 0.44808900E+02, -.75628700E+01, -.69317000E+01, -.26033000E+02, -.54763200E+03, 0.27613000E+03, 0.30351000E+03, 0.27336000E+03, -.60217800E+02, 0.11496300E+03, 0.11410100E+03, -.60995400E+02, 0.14855400E+03, 0.11189600E+03, 0.46250700E+03, 0.51176900E+01, -.29231900E+01, -.46294400E+02, -.32821200E+01, 0.10144300E+02, 0.16397600E+02, 0.12785300E+02, -.96942100E+01, -.19466600E+02, 0.24817300E+02, 0.97863200E+01, 0.23935800E+02, -.12000500E+02, -.58591100E+01, -.12042500E+02, 0.51906200E+01, -.18497400E+01, -.13837400E+02, -.14856800E+02, -.63938800E+02, 0.19941500E+02, 0.50780500E+01, -.16029900E+01, -.63860700E+01, -.12349700E+01, -.24380600E+00, 0.18709100E+01, -.82648700E+01, 0.33876300E+01, -.16677100E+01, 0.10339200E+00, 0.33134500E+01, 0.32292300E+01, 0.18475400E+02, 0.13347800E+01, 0.12370400E+01, 0.17931200E+02, 0.10735900E+01, 0.32275600E+01, -.98303800E+01, 0.19881300E+02, -.14684500E+01, 0.15799500E+02, 0.39486200E+01, -.16683100E+02, -.51290900E+01, 0.21399300E+00, 0.33074900E+01 },
        { 0.48469200E+00, -.95216800E-01, 0.10571600E-01, 0.20640600E+00, 0.25356200E+00, -.61243500E+00, 0.89965000E+00, -.80231100E-01, 0.22545900E+00, -.43203000E+00, 0.22340500E-01, 0.30919800E-01, 0.22521700E+00, 0.84005700E-01, 0.22637100E-01, 0.95762900E-01, 0.23884900E+00, -.20529900E+00, 0.80475300E-01, -.12973500E+00, -.12784400E-01, -.18727900E-01, 0.25103300E-01, -.16072800E-01, 0.65361900E+00, -.12130400E-01, 0.40048500E-01, 0.79735200E-01, 0.47650800E-01, -.15168900E-01, 0.34181900E-01, 0.45493500E-01, 0.40980700E-01, -.13632600E+00, 0.42854400E-01, -.48951400E-01, 0.40086500E-01, -.25268100E-01, 0.59944500E-01, 0.55324900E+00, -.16547200E-01, -.58919200E-01, 0.87818300E-01, -.25753600E-02, -.56800400E-01, 0.20329600E-01, 0.94568700E-01, 0.46673600E-03, -.12900300E-01, -.48269700E-01, -.99835400E-02, 0.73674900E-01, -.27365800E-01, -.47662500E-01, -.10848100E-02, 0.24601600E-01, 0.13861600E-01, -.58243400E-02, 0.72698600E-03, 0.35360700E-01, -.13193100E+00, -.29433900E+00, -.12678800E+00, -.15106400E+00, 0.49458300E-01, -.33997100E-01, -.23657800E-01, -.88282400E-01, 0.13362200E-02, -.11145400E-01, -.78733000E-02, 0.65145800E-02, -.12623400E-01, 0.53127800E-01, 0.26593300E-01, -.99562000E-01, 0.13521000E-01, -.31762100E-02, -.97476700E-02, 0.88683200E-02, -.54508400E-02, 0.15115700E-01, -.45997100E-01, -.21088100E-01, -.63474600E-01, -.56094900E-01, 0.23157500E+00, -.62734500E-02, 0.47304900E-01, 0.31660300E-01, 0.13850700E+00, -.83043200E-02, 0.10584200E-01, -.23770600E-01, -.92627000E-02, 0.69569400E-01, 0.10515700E-01, 0.69017800E-04, 0.73269000E-01, 0.76502300E-02, -.30747700E-01, 0.10393900E-01, 0.84050200E-01, -.60416500E-02, 0.45381200E-01, 0.19299400E-01, -.12301600E-01, 0.65648500E-01, 0.58969800E-01, 0.27068100E-01, -.44927100E-01, 0.10863800E-01, -.73401200E-02, 0.25939400E-02, 0.26010700E-02, 0.94128200E-04, -.11987600E+00, -.41999700E-01, 0.23631100E-02, 0.58002700E-02, 0.48944700E-02, -.14044500E-01, -.53264200E-03, -.32013400E-01, -.17143100E-02, -.30510400E-01, 0.86406200E-02, 0.20718200E-01, -.37514300E-01, -.35568700E-01, 0.36248900E-01, 0.84142700E-02, -.39085400E-01, 0.10917100E-03, -.58230000E-02, 0.12002700E-02, 0.15236200E+00, -.81725700E-02, 0.88863900E-02, 0.12331700E+00, 0.15464500E+00, -.25260700E+00, -.21156500E+00, -.10350800E-01, -.21642500E-01, -.76146200E-01, 0.15330300E-01, 0.32071500E-01, 0.44508200E-01, -.12113200E+00, -.44558700E-02, 0.40774300E-01, 0.20200500E+00, 0.10821500E+00, -.95236100E-02, -.54711400E-01, -.22350000E+00, 0.58445000E-03, 0.95214500E-01, -.17767800E+00, -.21989000E-01, -.45277400E-01, 0.73395900E-02, 0.37892300E-01, 0.49040200E-01, -.38098900E-01, -.60910600E-01, 0.54170100E-01, 0.84668700E-03, -.16462300E-01, -.15559200E-01, 0.20466800E+00, -.26489700E-01, -.25453900E-02, 0.27502300E+00, -.31941400E+02, -.93431800E+02, 0.45353000E+02, 0.98588500E+02, 0.47837300E+02, -.18571200E+02, -.41790700E+02, 0.34821300E+02, -.19545300E+02, 0.52786900E+02, -.44234800E+02, 0.14136800E+02, 0.83441600E+02, -.42421400E+02, -.37879300E+02, -.41851100E+02, -.19557800E+02, -.25696200E+01, -.34100000E+02, -.14098700E+02, -.21079200E+02, 0.21577100E+01, -.35947300E+02, 0.11863200E+03, -.58851900E+02, -.78637400E+02, -.59043100E+02, -.38680500E+02, -.83163300E+01, -.10019100E+02, 0.25111800E+02, -.32067100E+02, -.75443000E+01, -.67643100E+02, 0.25848400E+02, -.12262500E+02, -.22463300E+02, -.12722400E+02, -.89350400E+01, -.11498100E+02, -.61443200E+01, -.57962900E+01, -.52283900E+02, -.21442500E+01, -.10730700E+02, 0.27813300E+03, -.13950500E+03, -.11423400E+03, -.13912100E+03, 0.46702900E+01, -.73009600E+02, -.11224500E+02, 0.80638800E+02, -.48195800E+02, -.77349300E+02, -.18094900E+03, -.19167900E+02, 0.12350600E+02, -.47259900E+02, 0.93375900E+01, 0.37919900E+01, 0.17521200E+02, -.22541300E+02, -.22999000E+02, 0.75049200E+01, 0.18356300E+02, 0.27823000E+02, 0.23212000E+03, -.11701900E+03, -.82150400E+02, -.11600200E+03, 0.15623600E+01, -.11469500E+03, 0.81711800E+01, 0.54040800E+02, -.34797100E+02, -.10713700E+03, -.17276600E+03, -.73173000E+01, 0.35677700E+01, 0.29503000E+02, 0.37833000E+01, 0.24026500E+01, -.11637100E+02, 0.68460500E+01, 0.26056800E+02, 0.37108200E+02, -.14203900E+02, 0.35765800E+01, -.25183500E+02, 0.12550500E+02, -.10986400E+02, 0.12394500E+02, -.15688400E+01, -.19848400E+01, 0.16755900E+02, 0.18103400E+02, 0.52119500E+02, -.13159000E+02, -.12433200E+02, 0.17520100E+01, 0.30643600E+00, -.41264700E+00, 0.29468300E+01, -.32029200E+00, 0.13246500E+01, -.29300200E+01, -.72649900E-01, 0.25854600E+00, 0.72310800E+00, -.13725500E+01, -.50443500E+01, -.16551600E+01, -.15807700E+00, -.59970300E+01, 0.78348500E+00, -.30506500E+01, 0.55100900E+01, -.51368600E+01, -.97929800E+00, -.10557700E+02, -.26352400E+02, 0.41242800E+01, 0.93767200E+01, 0.31235200E+01, -.34793100E+01 },
        { -.99712500E+01, -.12133500E+02, -.13135800E+01, -.83735100E+01, -.41119600E+01, 0.57687900E+01, -.14743500E+02, 0.83982300E+01, -.67268300E+01, 0.96104100E+01, 0.40418100E+00, -.43840300E+00, 0.62497100E+01, 0.96933300E+01, 0.30474600E+01, 0.42455300E+00, -.33476800E+01, 0.39882200E+01, -.48946100E+01, 0.21841100E+01, -.25306400E+00, 0.36242300E+00, -.10259600E+00, 0.18910200E+01, -.13943600E+02, -.30803400E+00, -.33292000E+01, 0.47395900E+00, 0.19850300E+01, 0.22314300E+01, -.17168100E+01, 0.12714200E+01, -.13256700E+01, 0.14103000E-02, 0.89980400E+00, 0.11287900E+01, 0.10483100E+01, -.25607300E+00, -.25968700E+01, 0.90593100E+01, -.52391600E+00, -.84159000E+00, -.24755300E+01, -.90164700E+00, 0.11450300E+01, 0.17652600E+01, 0.36206000E+00, -.12683700E+00, 0.56891600E-01, -.49042900E+00, -.12774600E+00, 0.42299100E+00, -.25305400E-03, -.45442500E-01, -.45862300E+00, 0.42708900E+00, 0.16484800E+00, 0.12704100E+00, -.38088200E+00, 0.17648800E+00, -.16426300E+01, -.39715900E+01, -.25007700E+01, 0.16993800E+01, -.60283800E+00, -.46393500E-01, 0.24276400E+00, 0.21313100E+00, -.20505000E+00, 0.56542600E-01, 0.58244700E-01, 0.53944600E+00, -.14084200E+01, 0.62856800E+00, 0.64753600E+00, -.18336900E+01, 0.42267800E+00, 0.33785700E-01, 0.84821900E-01, -.28082200E+00, 0.33431200E+00, -.74542100E+00, -.10112400E+01, -.63152400E+00, 0.11270300E+01, -.57031900E+00, 0.46158600E+00, -.17779500E+01, -.29532500E+01, 0.18912400E+01, -.56123500E+00, -.27401400E-01, -.42194900E+00, -.74496900E-01, -.15111600E+00, 0.12478700E+01, 0.29468700E-01, 0.12096200E+00, -.18468000E-01, -.14823500E+00, -.16922400E+00, -.23072000E+00, 0.33286000E+00, -.54283000E+00, 0.74707600E+00, -.69207400E+00, -.10390700E+01, -.25938600E+00, 0.12567800E+01, 0.29430100E+00, 0.41561900E+00, -.98505200E+00, -.34439900E+00, -.15768400E+01, -.18648300E+01, 0.38202600E+01, 0.40639200E+01, -.28197700E+01, -.92949700E-01, -.17272700E+01, -.13355900E+01, -.10946600E+01, 0.62990200E+00, -.73019300E+00, 0.61670300E-02, 0.83483800E+00, -.14381500E+00, 0.19852300E+00, 0.10084000E+01, -.41456200E+00, -.58149200E+00, -.23081900E+01, 0.56592100E+00, -.31777800E-01, 0.13161500E+00, -.18409200E-01, 0.11613700E+01, -.52523100E+00, 0.46662400E+00, 0.53876100E+01, 0.49048100E+00, 0.19762000E+01, 0.35670300E+01, -.44329600E-01, -.20609100E+00, 0.72292800E+00, -.32427600E-01, -.13966000E+00, -.53700800E+00, -.16638600E+00, -.41549100E+00, -.81790700E+00, 0.14361900E+01, 0.94682500E-01, 0.27791500E+00, 0.18935500E+00, 0.43043800E+01, 0.91140800E-01, 0.17272300E+01, -.24249500E+00, -.42600900E+00, -.16238300E+01, -.37590100E+01, -.46824900E-01, -.11658100E+00, 0.41714600E+00, -.17797200E+00, 0.64787600E-01, 0.10600900E+00, -.32528700E+00, -.19191300E+00, -.55908500E+00, -.62232500E+00, -.22102500E+00, -.12022800E-01, -.10407200E+02, -.13860100E+04, 0.67507400E+03, 0.16389800E+04, 0.69315500E+03, -.12813700E+03, -.51460400E+03, 0.52897900E+03, -.11520700E+03, 0.64745800E+03, -.51502500E+03, 0.25308900E+03, 0.10179100E+04, -.50340200E+03, -.11203400E+03, -.50950700E+03, -.40920400E+03, -.36931400E+03, -.20206200E+03, 0.57638600E+02, -.22365300E+03, -.30226500E+03, -.60190300E+03, 0.52582100E+03, -.25677100E+03, -.51104500E+03, -.26007900E+03, -.12709600E+03, -.22087700E+02, -.50553800E+02, -.55423500E+02, -.30082000E+03, 0.11438900E+02, -.61642800E+03, 0.18998200E+03, -.85214500E+02, -.12970000E+03, -.92742700E+02, -.78609600E+02, -.47102400E+02, -.12839900E+03, -.24727400E+03, -.69461100E+03, 0.48129400E+02, -.30117000E+03, 0.17402100E+04, -.87853000E+03, -.55845300E+03, -.87080200E+03, -.15399400E+03, -.66030300E+03, 0.26042900E+02, 0.40013500E+03, -.18473200E+03, -.66850900E+03, -.10091800E+04, -.56929200E+03, 0.36043900E+03, -.17333200E+03, 0.27873700E+03, -.38523200E+02, -.34572500E+02, -.28597800E+02, -.87516000E+02, 0.12838100E+03, -.66103000E+01, 0.30056600E+03, 0.11256800E+04, -.58158900E+03, 0.22722800E+03, -.56236700E+03, -.23038200E+03, -.10623900E+04, 0.32200500E+03, 0.16087700E+03, -.54245600E+01, -.96768200E+03, -.77095200E+03, 0.16765800E+03, -.89276900E+02, 0.25862300E+03, -.83049100E+02, -.10861600E+02, -.10621800E+03, 0.73417500E+02, 0.25428300E+03, 0.23238500E+03, -.10552800E+03, -.59754100E+02, -.71308900E+03, 0.35922100E+03, 0.16288300E+03, 0.35435600E+03, -.22202200E+02, -.98396700E+02, 0.24620200E+03, 0.88456100E+02, 0.63344400E+03, -.15084400E+03, 0.20123400E+03, 0.21632800E+02, -.15902100E+02, 0.23327800E+01, 0.17113000E+02, 0.91999600E+01, 0.13005800E+02, 0.90723600E+01, 0.29461300E+01, -.51421400E+01, -.68489800E+01, -.18285800E+01, -.39867700E+02, -.19626800E+02, -.68362100E+01, -.45713800E+02, 0.24660100E+02, -.12530700E+02, 0.34737700E+02, -.15177800E+02, -.10823400E+01, -.15602900E+03, -.32869600E+03, 0.26760800E+02, 0.11857500E+03, 0.26243100E+02, -.24892900E+02 },
        { -.25108700E+01, 0.12080500E+01, 0.89438200E-01, -.12051100E+01, -.11074400E+01, 0.39450100E+01, -.43943200E+01, 0.39501200E+00, -.81367900E+00, 0.20187500E+01, -.11879300E+00, -.10297200E+00, -.14633200E+01, -.11880400E+01, -.69869900E+00, -.68803200E+00, -.15830700E+01, 0.67711700E+00, -.15199800E+00, 0.12383700E+01, 0.43230700E+00, 0.28974000E-01, -.18905100E-01, 0.11296100E+00, -.39556100E+01, 0.60869200E-01, -.15459900E+00, -.77141000E+00, 0.11110500E+00, 0.26049600E+00, -.10429100E+00, -.48142000E+00, -.68073800E+00, 0.54800400E+00, -.58044400E+00, 0.27032500E+00, -.28888800E+00, 0.23067100E+00, -.12848100E+01, -.33613300E+01, 0.77950500E-01, 0.62273800E+00, -.42387700E+00, 0.20011400E+00, 0.57724100E+00, -.19333300E+00, -.49574800E+00, 0.79521100E-02, 0.13947900E+00, 0.17751000E+00, 0.10953600E+01, -.33416900E+00, -.51725300E-01, 0.81820900E-01, -.46003200E+00, 0.16082200E+00, -.33257800E+00, -.86942900E-01, 0.11158600E-01, -.14132000E+00, 0.28308900E+00, 0.11100900E+01, 0.54345800E+00, 0.12434500E+01, -.19857800E+00, 0.28771800E+00, 0.36282700E+00, 0.64674500E+00, -.83365600E-01, 0.10777600E+00, -.62775100E+00, 0.76611400E-01, 0.94887300E-01, -.50293500E+00, -.57473900E-01, 0.38114800E+00, 0.12838700E+00, -.58182700E+00, -.11779700E+00, 0.22682300E+00, 0.38535700E-01, -.23175900E+00, 0.14998200E+00, -.39375500E-01, 0.73950500E+00, 0.12024100E+00, -.22755700E+01, 0.56314200E+00, 0.67243100E+00, -.24071500E+00, -.44344800E+00, 0.66608600E-01, -.33925100E+00, 0.26292200E+00, 0.10052700E+01, -.38461700E+00, 0.23177000E+00, 0.64496800E+00, 0.76741600E-01, -.16206400E+00, 0.93978700E-01, 0.27077500E+00, -.48409400E+00, -.17496600E+00, -.26486300E+00, 0.24753900E+00, 0.72850800E+00, 0.27498800E-01, -.11713600E+01, -.14125700E+00, 0.87200500E+00, -.21400400E+00, 0.18205300E+00, 0.11221300E+00, 0.60073900E-01, -.12722600E+01, -.91233300E+00, 0.85819100E+00, 0.18614500E+00, 0.16620500E+00, 0.50081200E+00, 0.24951700E+00, -.45474400E-01, 0.15664500E+00, 0.12561200E-01, -.26456200E+00, 0.15971600E+00, 0.26722400E+00, -.32027600E+00, 0.14910600E+00, 0.14810000E+00, 0.87423100E+00, -.82527600E+00, -.21561300E-03, -.94362700E-01, 0.30078700E-02, 0.11392900E+00, 0.33315400E+00, -.24710000E-01, -.25008400E+00, 0.98083300E+00, 0.66390800E+00, -.13179300E+01, -.18125600E+00, 0.38527500E-01, -.15577100E+00, 0.28488800E-01, -.24355000E+00, -.52674800E-01, 0.10863100E+00, -.10890600E+00, -.35841200E+00, -.66799300E+00, -.24390100E+00, 0.83306500E-01, 0.23696500E+00, -.68434400E+00, 0.24848600E-01, -.19717000E+00, -.21568800E+00, 0.10066100E+00, 0.65173100E+00, 0.11190700E+01, -.51692900E-01, -.57026500E+00, 0.28233300E+00, -.60178500E+00, 0.42603900E-01, -.18037500E-01, -.36143000E-01, -.14897000E+00, -.35396600E+00, 0.18425000E+00, 0.16587800E-01, -.61316900E+00, 0.13280700E+01, 0.12867200E+00, 0.84393300E+01, -.96564000E+02, -.72444900E+01, 0.96446600E+02, 0.20456400E+02, -.11487800E+02, -.29876800E+02, -.88575100E+02, 0.69965800E+02, 0.23754400E+03, -.40528100E+03, 0.20327600E+03, 0.17881500E+03, 0.20296100E+03, 0.15232200E+03, 0.99462100E+02, 0.11347200E+03, 0.37628300E+02, 0.16399500E+03, 0.78310400E+02, 0.30841000E+03, -.51937700E+03, 0.25725100E+03, 0.32980700E+03, 0.25898700E+03, 0.17820300E+03, -.48221100E+01, 0.87714900E+02, -.62527700E+02, 0.14789800E+03, 0.68113600E+01, 0.38615500E+03, -.25157500E+03, 0.12191800E+03, 0.17316000E+03, 0.12490600E+03, 0.27584900E+02, 0.66343300E+02, 0.42169200E+02, 0.11628100E+02, 0.25662100E+03, 0.13987200E+02, 0.30747500E+03, -.94429400E+03, 0.47583100E+03, 0.41470900E+03, 0.47261200E+03, -.44024700E+02, 0.27653400E+03, 0.64394500E+02, -.23905800E+03, 0.81957300E+02, 0.29242400E+03, 0.74423300E+03, 0.18993900E+03, -.12121200E+03, 0.28901600E+03, -.93721900E+02, -.10497800E+02, -.58216400E+02, 0.67864100E+02, 0.13721000E+03, 0.98437700E+01, -.62956500E+02, -.10279100E+03, -.85578400E+03, 0.43641300E+03, 0.45875800E+03, 0.42842100E+03, -.36825700E+02, 0.39785400E+03, 0.29207700E+02, -.19859300E+03, 0.53440800E+02, 0.37693400E+03, 0.85745900E+03, 0.25242000E+02, -.10179600E+02, -.11742900E+03, -.11998000E+02, 0.76255300E+01, 0.44024300E+02, -.37649100E+01, -.61417300E+02, -.11319300E+03, 0.54857500E+02, -.69835700E+02, 0.14786800E+03, -.73097900E+02, -.57133700E+02, -.72653100E+02, 0.21647200E+02, -.23331000E+02, -.43816200E+02, -.50699800E+02, -.19289900E+03, 0.38354000E+02, -.24204300E+02, -.11686700E+02, -.11783100E+01, -.23114400E+01, -.11112300E+02, 0.56184800E+01, -.52756200E+01, 0.12437500E+02, -.16454600E+01, -.20102800E+01, -.21298300E+01, 0.71032400E+01, 0.50908700E+02, 0.60320800E+01, 0.25427400E+01, 0.51613400E+02, -.26910100E+01, 0.10251900E+02, -.13594800E+02, 0.42373900E+02, 0.79587000E+01, 0.46590000E+02, 0.71217700E+02, -.43249600E+02, -.20182700E+02, -.92001600E+01, 0.76510900E+01 },
        { 0.50865100E+01, -.15626600E+01, -.39266600E+00, -.18917600E+01, 0.51686000E+00, 0.57713700E+01, 0.11407100E+01, -.12998000E+01, 0.24017600E+01, -.27751200E+01, -.79525400E-02, 0.25055200E+00, 0.12112100E+00, 0.66881800E+00, -.27529000E+00, -.10525800E+01, 0.37665400E+00, -.24023200E+00, -.16729000E+00, 0.70577600E+00, 0.24629300E+00, -.19863900E+00, 0.57191800E-02, 0.13864700E+00, -.58617900E+00, -.14230900E+00, -.49197700E+00, 0.52963200E+00, 0.69098200E+00, -.75444600E+00, -.91722500E-01, -.41322100E+00, -.81151000E+00, -.38142900E+00, -.72400200E+00, 0.30142100E+00, 0.17483500E+00, 0.43517200E+00, -.17253800E+01, 0.54821700E+00, 0.44068500E-01, 0.27654200E+00, -.18294600E+00, -.12950800E+00, -.53792100E-01, -.11781100E+00, -.45491300E+00, -.16101200E-01, 0.14102300E+00, 0.11717600E+00, 0.24708800E+00, 0.33497400E+00, 0.65155600E+00, 0.10917600E+00, 0.10186900E+01, 0.68106500E+00, 0.11541200E+01, 0.21267500E+00, 0.13154100E-02, 0.86615700E+00, -.21764300E+01, -.26430100E+01, -.10574700E+01, 0.12714400E+01, 0.47809000E+00, 0.25542200E+00, -.25983000E-01, 0.38487000E+00, 0.93765900E-01, 0.82505400E-01, -.10542700E+01, 0.37017200E+00, -.85810000E-01, 0.48140900E+00, 0.10006800E+01, 0.39445300E-01, 0.18177700E+00, 0.10317500E+01, 0.25499600E+00, 0.16321700E+00, -.12156700E-01, -.12256000E+00, -.91911300E+00, -.13006800E+00, 0.38090500E+00, -.59788000E+00, 0.11115100E+01, -.30496000E+00, -.72182400E+00, 0.19832900E+00, -.63538800E+00, -.29471200E-01, -.81856900E-01, -.37174500E+00, -.13519900E+01, -.16273700E+01, 0.20254600E+00, 0.71634300E+00, -.18423500E+01, -.50482900E+00, -.19408900E+00, -.73046100E+00, 0.24190000E+00, -.11840900E+00, 0.46127900E+00, -.86130000E+00, 0.12448800E+01, 0.62479000E+00, -.17468400E+01, -.18867200E+00, 0.43426200E+00, -.68262600E-01, 0.11107200E+00, 0.13249100E+00, 0.11958100E+01, -.71302100E+00, -.16214300E+01, 0.91199900E+00, 0.30034200E+00, -.59897700E-03, 0.35028200E+00, -.14192200E+00, -.33346000E-01, 0.13540600E+00, 0.15823200E-01, -.29172100E+00, 0.15755300E+00, 0.50216900E+00, 0.37487900E-01, 0.26587300E+00, -.19165500E+00, 0.56725400E+00, -.37517400E+00, -.23447100E-02, -.62046800E-01, 0.20786700E-03, 0.43708200E+00, 0.24219500E+00, -.45576800E-01, 0.12207900E+01, 0.92580100E+00, 0.11626500E+01, 0.56537600E+00, -.20664900E+00, 0.58422900E-01, -.11796900E+00, 0.63772200E-01, -.15427700E+00, 0.51212800E-01, -.65683700E-01, -.88146100E-01, -.56781900E+00, -.97172200E+00, 0.10643400E+01, -.23615000E+00, -.98331700E-01, 0.19471400E+00, 0.56557500E-01, 0.72075300E+00, -.15565200E+01, 0.87728400E-01, -.20692500E+00, -.31551700E+00, 0.24718900E+00, -.70445800E+00, -.27692300E+00, 0.28211900E+00, -.21178100E+00, 0.67631800E-01, -.53087500E-01, -.15210500E+00, 0.14441900E+01, -.21158700E-01, -.11895600E+00, 0.34058200E+00, 0.13735700E+01, -.40485200E+00, -.71964800E+00, 0.47259900E+03, -.12825700E+02, 0.20390500E+02, -.19214700E+02, 0.40182400E+02, -.26200900E+01, -.30792400E+02, 0.16246600E+02, 0.69617900E+02, 0.11480500E+01, 0.50670100E+01, 0.83586600E+01, -.40370000E+00, -.59537800E+02, -.16128900E+03, 0.71223600E+02, 0.61823700E+02, 0.13171000E+03, -.15803900E+03, -.75623000E+02, -.46117400E+03, 0.23037700E+03, 0.11426800E+03, 0.22987200E+03, 0.70923100E+02, -.52813700E+02, 0.16083100E+03, -.41634900E+02, 0.19684700E+03, -.51714200E+02, -.12596300E+03, -.12980600E+03, 0.65302100E+02, 0.41430300E+02, 0.63843700E+02, 0.23091100E+02, -.32875300E+02, 0.30444200E+02, -.70447400E+01, 0.12102800E+03, -.24403300E+02, -.11457200E+03, 0.46079200E+03, -.23101000E+03, -.58638000E+02, -.22977900E+03, -.10318500E+03, -.11546200E+03, -.35192800E+02, 0.49048700E+02, -.83844700E+02, -.96355600E+02, -.14791100E+03, -.98752600E+02, 0.64055200E+02, 0.72708900E+01, 0.51502200E+02, -.32680000E+02, -.13021700E+03, 0.78443300E+02, 0.67469700E+02, 0.18097900E+03, -.12986400E+03, 0.14774000E+02, 0.45765000E+03, -.23050000E+03, 0.13849400E+03, -.22801600E+03, -.14181800E+03, -.18133800E+03, 0.31798800E+02, 0.89546600E+01, -.87068300E+02, -.12029300E+03, -.23777900E+02, -.12279800E+02, 0.43274800E+01, 0.54594800E+02, 0.72134300E+01, -.25384300E+01, -.14406900E+02, 0.34127700E+02, 0.92516700E+01, 0.31114500E+02, -.13289100E+02, 0.35078800E+02, -.19088700E+03, 0.99947400E+02, -.46353800E+02, 0.97055800E+02, 0.13593500E+02, 0.49456200E+02, -.45197300E+02, -.10091100E+03, 0.45536000E+01, 0.40097500E+02, 0.10733600E+03, 0.77910600E+01, -.38224400E+00, 0.28726500E+01, 0.49276400E+01, 0.10938600E+02, -.74639900E+01, -.31326700E+00, 0.46399600E+01, -.40777900E+01, -.18500100E+01, 0.13337100E+01, 0.40133900E+01, -.12625700E+00, -.34233100E+01, 0.12441200E+02, 0.73444400E+01, -.46270900E+01, 0.44952800E+01, 0.60124000E+01, -.16619700E+02, 0.19271000E+02, -.70478900E+02, -.21079200E+01, 0.26394700E+02, 0.58992500E+01, 0.71541800E+01 },
        { -.17702600E+01, -.16095000E+01, -.91392300E-01, 0.28753500E+00, -.81582400E+00, -.11768000E+01, -.15738700E+01, -.16018300E+00, -.11377900E+01, 0.14786900E+01, 0.47730800E-01, -.12698200E+00, -.23818900E+00, 0.12557500E+01, -.19110900E+01, -.79178500E+00, 0.70197300E-01, -.29086600E+00, 0.97396200E+00, -.89527100E+00, 0.55377000E+00, -.24084400E-01, -.21051900E-01, -.35205500E+00, 0.17550000E+01, 0.72999800E-01, -.47441300E-02, -.42483000E+00, -.14341800E+00, -.40021800E+00, 0.42125700E+00, 0.78348000E+00, 0.55554800E+00, 0.68558100E-01, 0.16859100E+00, 0.12738600E+00, -.10408200E+00, 0.16367000E+00, -.76524500E+00, 0.21650500E+01, 0.78970600E-01, 0.21145800E+00, -.13255900E+00, -.24740600E-01, 0.97397600E-01, -.10756500E+00, 0.21646800E+00, 0.17618600E-02, -.44519200E-01, 0.36208400E-01, 0.23137700E+00, 0.75698400E-02, -.29425400E+00, -.80920400E-01, -.29178700E+00, 0.64028200E-01, -.38660800E+00, 0.83224700E-01, -.98646700E-02, -.23579300E-01, 0.31686200E+00, -.37132400E+00, -.36658800E+00, 0.14768100E-02, 0.17293600E-02, 0.70465300E-01, 0.28377800E+00, -.86863900E-01, 0.98949600E-01, -.81030500E-02, 0.71510600E+00, -.33291500E+00, 0.38161200E+00, 0.67293800E-01, -.50596000E-01, -.49445500E-02, 0.34811600E-01, 0.19504400E+00, 0.22943400E+00, -.53114400E+00, 0.27467200E-01, -.22890200E+00, 0.17232800E+00, 0.67702100E-01, 0.25548200E+00, 0.16281700E+00, -.70096700E+00, 0.21901200E+00, -.88316000E+00, 0.74644300E-01, -.13095100E+01, 0.15940100E-01, -.15772700E+00, -.40755900E+00, -.13946300E+00, 0.15684700E+01, -.42127300E+00, -.38889600E+00, 0.14632000E-01, 0.77743100E-01, 0.52259800E-01, -.16515800E+00, -.60253100E-01, 0.69501400E+00, -.28241300E+00, 0.75632900E-01, -.53559300E+00, -.56623600E+00, -.29131200E+00, -.10253700E+00, 0.11331400E+00, -.33186300E-01, 0.32833800E-02, -.72853300E-01, -.47537800E+00, -.11633400E+00, 0.46558100E+00, 0.10860900E-01, -.71097100E-01, -.23931700E-01, -.36347000E+00, 0.23866700E+00, 0.61136200E-01, 0.48134300E-01, 0.16595700E-01, 0.36946000E+00, -.53977100E-01, -.16791800E+00, 0.23760700E+00, 0.20559500E+00, -.76540000E-01, -.59065400E+00, -.63702400E-01, -.70869400E-03, -.11849900E-01, -.15572900E-03, -.45519400E+00, -.77362900E-01, 0.12666800E+00, -.12939900E+01, -.55640200E+00, 0.66722200E+00, 0.48868900E+00, -.11214200E-01, 0.80619700E-02, 0.14423300E+00, 0.19285500E-01, 0.15975400E-01, 0.53506500E-01, 0.39662300E+00, 0.34331500E+00, 0.23551100E+00, 0.68962100E+00, -.36611300E-01, -.71418900E-01, 0.35463000E-01, 0.51308100E-01, -.53570000E-02, -.40030300E+00, 0.96379600E+00, -.68007500E-01, -.32533600E+00, -.45003000E+00, -.41295600E-01, 0.45188000E+00, 0.13957800E+00, 0.35929500E+00, -.89265700E+00, 0.14468300E+00, -.24320000E+00, -.11462600E-02, 0.35548500E+00, 0.19951700E-01, 0.20642200E+00, -.24663000E+00, 0.21442900E+01, -.19882600E+00, -.17686400E+00, -.24899300E+00, -.58968200E+01, 0.36315000E+02, 0.25214500E+02, -.48708400E+01, 0.67851700E+02, 0.14566800E+02, 0.14306100E+02, 0.10283800E+03, 0.17899500E+03, -.85955200E+02, 0.34041800E+02, -.89548800E+02, -.86778700E+01, 0.59375200E+02, -.10775300E+03, -.59473900E+02, -.12895200E+03, 0.71093600E+02, -.57585700E+02, -.32987900E+03, 0.16459100E+03, 0.10079700E+03, 0.16515300E+03, 0.10107300E+03, 0.31678800E+01, 0.48562500E+02, -.65027400E+02, 0.10969200E+03, 0.11866200E+02, 0.86402500E+02, 0.38939600E+02, -.19900400E+02, 0.27072300E+02, -.19644500E+02, 0.17754400E+02, -.27179700E+02, 0.22153100E+02, 0.57261500E+02, 0.10929100E+03, -.31777900E+02, -.95840000E+02, -.44346900E+03, 0.22122800E+03, 0.25525400E+03, 0.22198700E+03, -.90256200E+02, 0.10046900E+03, 0.43871200E+02, -.95527200E+02, 0.19360400E+03, 0.85133900E+02, 0.29879600E+03, -.15856700E+03, 0.83675700E+02, 0.99556800E+02, 0.79361400E+02, 0.32993000E+02, 0.70747900E+02, -.25190500E+02, -.82225700E+02, 0.17527600E+01, 0.71939800E+02, 0.58113100E+02, -.29099800E+03, 0.14462700E+03, 0.27590100E+03, 0.14616600E+03, -.12305100E+03, 0.15913900E+03, 0.37597100E+02, 0.44077300E+02, 0.22898300E+03, 0.10705200E+03, 0.33678600E+03, 0.26434400E+02, -.13792900E+02, 0.95897300E+02, -.12266500E+02, 0.24574400E+01, 0.13863200E+02, 0.28456900E+01, 0.12357800E+02, -.26681000E+02, 0.20707500E+02, -.40305100E+02, -.62999300E+02, 0.33158900E+02, 0.77501200E+02, 0.32057200E+02, 0.20429300E+02, -.68543100E+01, -.46097800E+01, -.44924500E+02, -.63407100E+02, 0.15734400E+02, 0.84362100E+02, 0.91577200E+00, -.51153800E+01, 0.68906200E+01, -.10975700E+01, 0.15511400E+01, 0.15540800E+01, 0.48561700E+01, 0.16051500E+01, -.38175300E+01, -.31113700E+01, 0.86550400E+01, 0.18260100E+02, 0.39682700E+00, -.12477500E+01, 0.13371800E+02, 0.36540100E+01, 0.51406100E+01, -.13735600E+02, 0.36508900E+02, -.27509400E+01, 0.28849400E+02, 0.41580900E+02, -.18834300E+02, -.13543800E+02, 0.53810600E+00, 0.67042200E+01 },
        { -.70178000E+00, 0.66880100E+00, 0.29818100E-01, -.61692600E+00, -.24511300E+00, 0.21003800E+00, -.40579000E+00, 0.57361200E+00, -.28348400E+00, 0.41303600E+00, 0.27934400E-02, -.24633500E-01, -.17477100E+00, 0.52134400E+00, -.24354000E+00, 0.12052900E+00, -.21360700E-01, -.20987600E+00, 0.12895100E+00, 0.32233000E-01, -.36104400E-01, -.29447200E-02, 0.13572800E-02, 0.57874400E-01, -.30263100E+00, -.46106400E-02, -.99482400E-01, -.26097000E+00, 0.31713800E+00, -.10237700E+00, 0.62845200E-01, 0.10095300E+00, -.13061400E+00, 0.16655800E-01, 0.31433400E-02, 0.90745100E-01, -.22900100E-01, -.45292300E-01, 0.34988600E-01, -.29819100E+00, -.15361600E-01, -.29821200E-01, -.15837200E+00, -.96125900E-02, -.26823400E-01, -.11177200E-01, -.58070100E-01, -.43343000E-02, 0.26214100E-01, 0.64353700E-01, -.14535300E-01, 0.42106800E-02, -.29977100E-01, -.18061500E-01, 0.59338000E-01, 0.84093900E-01, -.13175800E-01, 0.21539800E-01, -.11170400E-02, -.10568800E+00, 0.37477700E-01, 0.31877200E+00, 0.14216400E+00, 0.48924400E-01, -.54628200E-01, 0.26545100E-02, 0.45273500E-01, 0.52878000E-01, 0.70700400E-03, 0.15937900E-01, -.61186100E-01, 0.32337100E-01, -.23867400E+00, 0.37722300E-01, 0.54054500E-01, -.10241400E+00, 0.49733800E-01, 0.22614000E-01, -.48157700E-01, 0.66070700E-01, 0.24576700E-01, -.30295500E-01, -.34434400E-01, 0.92033800E-02, 0.17959600E+00, -.78146800E-02, 0.87021400E-01, -.17481400E+00, -.25475000E+00, 0.17644600E+00, -.79329400E-01, 0.75194100E-02, 0.88695600E-02, -.25285500E-02, 0.11515200E+00, -.13788000E+00, 0.41552000E-01, 0.20754800E-02, 0.68207700E-01, 0.36387600E-02, 0.36051400E-01, -.27419000E-01, -.14066800E+00, -.64915700E-02, -.13061700E-01, -.35630100E-01, -.51547400E-02, -.96048000E-01, 0.32809000E-01, 0.13001900E-01, 0.57745000E-01, 0.52607900E-01, 0.22493100E-02, 0.40776100E-01, 0.93665500E-01, 0.80235700E-01, -.64567200E+00, 0.19423600E+00, 0.28148500E-01, -.69489500E-01, -.47935700E-01, -.13302200E-01, 0.49726000E-02, 0.15372700E-01, 0.48085500E-02, -.74526900E-02, -.78324300E-02, -.12761300E+00, 0.87044000E-01, -.12256100E-01, -.72302000E-01, -.73153300E-01, 0.15403800E+00, 0.84587500E-03, 0.54342500E-02, -.20463500E-02, -.27952300E+00, -.64588500E-01, -.14812600E-01, 0.21662300E+00, -.85793400E-01, 0.93672000E-01, -.17509900E-01, -.17942500E-01, -.10142200E-01, 0.88871300E-01, 0.49538900E-02, 0.10029300E-02, -.32912200E-01, 0.60426100E-01, 0.65895500E-02, 0.22873300E-01, -.14492700E+00, 0.60496000E-01, -.49553400E-02, -.30999200E-01, -.86452200E-01, 0.95607000E-03, 0.99058700E-01, -.14496000E+00, 0.31604000E-02, -.88193800E-01, -.11334600E+00, 0.74908300E-05, 0.99659600E-01, -.46141000E-01, 0.69927700E-01, -.29687600E-01, 0.61007800E-02, 0.22478900E-02, 0.33115900E-01, -.36435600E-01, 0.40056700E-01, 0.31636300E-01, 0.18556800E-01, 0.23463300E+00, -.17293600E-01, 0.87625400E-01, 0.26272200E-01, -.31004000E-03, -.29006200E+02, -.10222500E+02, -.14912200E+02, -.95742600E+01, 0.15064100E+02, -.15771100E+02, -.53362900E+00, 0.29266100E+02, -.16421800E+02, -.36170300E+02, -.14672400E+02, -.12466700E+02, 0.44806900E+01, -.16765800E+02, -.77400700E+01, 0.83432500E+01, 0.41091500E+01, -.12269800E+02, 0.49041500E+02, -.24061400E+02, -.15132200E+02, -.24493700E+02, -.13049900E+02, -.36200800E+00, -.14695200E+02, 0.13091600E+01, -.15027200E+02, -.19186000E+01, -.43165100E+02, 0.10613200E+02, -.45150000E+01, -.13686100E+02, -.53253000E+01, 0.33252200E+01, -.78316400E+01, -.65994100E+00, 0.29769000E+00, -.87320700E+01, -.80664900E-01, -.31698600E+02, 0.13267600E+03, -.66440100E+02, -.65163500E+02, -.66311500E+02, -.13074300E+01, -.20249000E+02, -.33422600E+02, 0.20722100E+02, -.34015800E+01, -.23638200E+02, -.83459200E+02, -.23077100E+02, 0.13698000E+02, -.57251500E+02, 0.11690600E+02, 0.86983300E+01, 0.12397700E+02, -.89930700E+01, -.10939100E+02, 0.30195100E+02, 0.10903300E+02, 0.17248700E+02, 0.19230500E+03, -.96147400E+02, -.10317500E+03, -.96088300E+02, -.15570000E+02, -.28331100E+02, -.57287200E+02, 0.14684100E+02, -.17414600E+02, -.31058100E+02, -.11494300E+03, -.12996900E+02, 0.68301500E+01, 0.18446200E+02, 0.66103600E+01, -.74072600E+01, -.52158200E+01, 0.45424800E+01, 0.21708500E+01, 0.28047100E+02, -.88918000E+01, 0.83773900E+01, -.57422300E+02, 0.28516400E+02, 0.30853800E+02, 0.28761100E+02, 0.59724700E+01, 0.93483700E+01, -.20697500E+00, -.10663100E+02, 0.16405900E+02, 0.20982200E+01, 0.32108200E+02, 0.52429300E+00, 0.90963000E+00, -.97694900E-01, 0.12807000E+01, 0.45605600E+00, 0.13549400E+01, -.11404600E+01, 0.88362200E+00, -.32161800E+00, -.24579600E+00, -.14229500E+01, -.51576300E+01, -.54479100E+00, -.48448500E+00, -.37958300E+01, 0.84602500E+00, -.14113500E+01, 0.19348000E+01, -.57929200E+01, 0.25375900E+00, -.42030700E+00, 0.54866500E+01, 0.44912300E+01, -.19390300E+01, -.83461900E+00, 0.79179300E+00 },
        { -.18880100E+01, 0.17881600E+01, 0.23145500E+00, 0.24743700E+00, -.62320400E-02, 0.13390200E+01, -.42687100E+01, 0.21861500E+01, -.18227000E+01, 0.98204300E+00, -.17991700E-01, -.22678800E+00, -.35176700E+00, 0.16768300E+01, 0.30173000E+00, -.12402000E+01, 0.30350800E+00, 0.21977100E+01, 0.94016700E+00, -.14823200E+00, -.35123300E+00, 0.30939000E-01, -.23822600E+00, -.40206500E+00, 0.64525700E+00, 0.87607500E-01, 0.66769300E+00, 0.14233000E+01, -.71638900E+00, -.51776500E-01, 0.27073800E+00, 0.31402300E-01, 0.80709000E+00, 0.69861600E+00, -.14065400E+00, 0.14578800E+00, -.29105100E+00, 0.43927500E+00, -.12645300E+01, 0.56088700E+01, 0.61954700E-01, 0.38331400E+00, -.75024600E+00, 0.11289900E+00, 0.10442900E+01, -.14266900E-01, -.29712800E+00, 0.10095500E-01, -.14794400E-02, 0.26361900E+00, 0.17586000E+00, -.26442900E+00, 0.74921500E-01, 0.25846700E+00, 0.44642200E+00, -.13967500E+00, 0.29806900E+00, -.79747200E-01, 0.22387600E-01, -.98071800E-01, 0.20513300E+00, 0.12460100E+00, 0.43323100E-01, 0.37805300E+00, 0.14347300E+00, 0.13851300E+00, 0.25076800E-01, 0.25275600E+00, -.20131600E-01, 0.26585400E-01, 0.49833700E-01, 0.10720700E+00, -.44170500E+00, 0.36399300E-02, -.86706400E-01, -.21629900E+00, 0.11784700E+00, -.19372800E+00, -.24370000E-01, -.16391200E+00, 0.29395100E-01, -.26305400E-02, 0.41971400E+00, 0.10373800E-01, -.55180000E+00, 0.50185200E-01, -.32466200E+00, 0.58295300E+00, 0.37601800E+00, -.25470400E+00, -.47019200E+00, 0.98716200E-02, -.16423600E-01, 0.10393800E+00, 0.70298200E+00, -.36816000E+00, -.49041800E-01, 0.77291500E-01, -.96568400E-01, -.87845300E-01, -.20631300E-01, -.14077000E+00, 0.85331100E-01, 0.99347800E-01, -.92099500E-01, 0.28214100E+00, 0.50484600E+00, 0.48725100E+00, -.10303800E+01, -.14936600E+00, 0.30470400E+00, -.14270800E-01, -.76138100E-02, 0.62093100E-01, 0.41404400E+00, -.56504100E+00, -.72573300E+00, 0.24495000E+00, 0.61360300E-02, 0.36990200E+00, 0.38954200E+00, 0.20949000E+00, -.69080300E-01, -.31805500E-01, -.21386100E-01, -.24144900E+00, 0.17401200E+00, -.94901300E-02, -.23557100E+00, -.16632600E+00, 0.89791000E+00, 0.25896500E+00, 0.17981200E+00, 0.10775800E-02, -.17469900E+00, 0.28029600E-02, 0.63437200E-01, 0.45582400E+00, -.11881900E+00, -.10848200E+01, 0.39787300E+00, 0.87427500E-02, -.75647700E+00, -.26046300E+00, -.75483000E-01, 0.20854900E-01, -.10934500E-02, -.57142800E-01, 0.46017400E-01, 0.30369700E+00, -.65155200E-01, -.31338700E+00, 0.48860800E+00, -.16081600E+00, 0.10425400E-02, 0.16215900E+00, -.57239200E-01, 0.98951900E-02, -.40764900E+00, 0.35584400E+00, 0.32667300E-01, 0.21511000E+00, 0.55199700E+00, -.96752900E-01, -.32526000E+00, 0.63633700E-01, 0.24844900E+00, -.50481500E+00, 0.38753300E-01, -.12982300E+00, -.95529400E-01, -.62856800E-01, 0.88775400E-02, -.30941800E-01, 0.11347800E+00, -.75340900E+00, -.40804400E-01, -.10424200E+00, 0.11585400E+00, -.48966100E+00, -.11051300E+01, 0.82888600E+02, 0.53397400E+02, 0.15764900E+03, 0.30634100E+02, 0.52267700E+02, 0.31230700E+02, 0.12279800E+03, -.56633300E+02, 0.61159800E+02, -.61767100E+02, -.66895900E+01, 0.21734200E+02, -.68152400E+02, -.68395600E+02, -.22420100E+03, 0.51960300E+02, -.36961700E+02, -.15849300E+02, 0.77465500E+01, -.26688200E+01, 0.79218900E+01, 0.34104000E+02, -.10417200E+02, -.22904900E+02, -.16891300E+02, -.26127200E+02, -.44094600E+01, -.32490900E+02, 0.11129200E+03, -.55652800E+02, -.90999600E+01, -.55528200E+02, -.90386200E+01, -.28122300E+02, -.50686000E+02, 0.28162600E+02, -.48237100E+02, -.24488900E+02, -.69842800E+01, -.36261400E+03, 0.18074300E+03, 0.21747500E+03, 0.18124200E+03, -.12711300E+02, 0.64958700E+02, 0.29730700E+02, -.64631000E+02, 0.14363500E+03, 0.41539400E+02, 0.18225100E+03, -.52896000E+02, 0.30917700E+02, 0.48326500E+02, 0.27547100E+02, 0.64073000E+01, 0.36971800E+02, -.45176100E+02, -.87988700E+02, -.10920900E+03, 0.50898100E+02, 0.72568800E+02, -.43213300E+03, 0.21530500E+03, 0.26761100E+03, 0.21591100E+03, -.41562400E+02, 0.10719400E+03, 0.65912800E+02, 0.61156900E+02, 0.23979100E+03, 0.47716600E+02, 0.24329500E+03, 0.64252200E+02, -.32757300E+02, -.21697100E+02, -.32321700E+02, -.36259600E+00, -.24501300E+02, 0.43345400E+02, 0.72128600E+02, -.11766300E+02, -.18929100E+02, -.23986100E+02, 0.14221100E+03, -.72336400E+02, -.45952900E+02, -.71330100E+02, -.43112800E+02, -.53819200E+02, 0.52657700E+02, 0.70799900E+02, 0.26315800E+01, -.30224100E+02, -.39442400E+02, 0.42739900E+01, -.65537000E+01, 0.22388700E+01, 0.75771800E+01, -.67062600E+01, -.29601500E+01, -.45304700E+01, 0.56794500E+00, 0.16425000E+01, 0.29417600E+01, 0.57226700E+01, 0.56246100E+01, 0.25641400E+00, 0.12166500E+01, 0.17019700E+01, 0.41941600E+01, 0.43278400E+01, -.95658800E+01, 0.24946700E+02, -.36212200E+01, -.63557600E+01, 0.25742700E+02, -.77847400E+01, -.12638300E+02, 0.54673400E+01, -.10421400E+01 },
        { -.14877100E+01, 0.60111500E+00, 0.53071500E-01, -.13196000E+00, 0.41789600E-01, 0.18373400E+01, -.35177500E+01, 0.10209300E+01, -.15371400E+01, 0.11658700E+01, 0.82244000E-01, -.23916000E+00, 0.28438200E+00, 0.47477600E+00, -.37498700E+00, -.16289900E+01, -.43820800E+00, 0.10085000E+01, 0.75617500E+00, -.16687600E+01, 0.28566000E-01, 0.14066200E+00, -.28228600E+00, -.13909600E+00, 0.30679200E+00, 0.50335600E-01, 0.59075500E+00, 0.45581000E+00, -.53909800E+00, -.38342200E+00, -.27300900E+00, -.12044000E+00, -.20378000E-02, -.36118100E+00, -.63431200E-01, 0.17033600E+00, -.54221300E-01, -.53371200E+00, 0.20448000E+00, 0.22113000E+01, -.11162900E+00, 0.21180800E+00, -.53114100E+00, -.41050700E+00, 0.36607600E+00, 0.19022800E+00, -.33480100E-01, 0.30348600E-01, -.11504400E+00, 0.14715600E+00, -.82698000E+00, -.79408600E+00, -.12982900E-01, 0.42046900E+00, 0.52986200E+00, -.70952400E-01, -.14953100E+00, -.18330300E-01, 0.85119500E-02, 0.43493400E-01, -.16280800E+00, -.12175500E+00, 0.21445500E+00, -.66132700E-01, -.22868500E+00, 0.62091200E-01, -.25297300E+00, 0.14770900E+00, -.59106300E-01, 0.15390900E-01, 0.55596800E+00, 0.63339400E-01, 0.20046200E+00, 0.23188900E+00, -.21926000E+00, -.30457200E+00, 0.12807400E+00, 0.26003000E+00, 0.20496500E-01, -.29889800E+00, 0.92122700E-01, 0.35290200E+00, -.26734700E+00, 0.11544500E+00, -.11884400E+01, -.16523800E+00, -.14570300E+00, 0.10318600E+01, -.22895600E+00, -.36818300E+00, -.27778100E+00, 0.25120200E-01, 0.90881500E-01, 0.70243900E-01, -.50946300E+00, -.50459100E+00, -.15446500E+00, 0.16820600E+00, -.72308000E+00, -.28065100E+00, -.18251200E+00, -.24744700E+00, 0.85489300E-01, 0.13727500E-01, -.10136200E+00, -.32509300E+00, 0.47678500E-01, -.18516300E-01, -.22881500E+00, -.13084500E+00, 0.32148600E+00, -.64538100E-01, -.35821900E-01, 0.35435500E-01, 0.61931700E-01, 0.22189200E+00, 0.47940800E+00, 0.38437200E-02, -.11262200E+00, -.21414100E-01, -.14073400E+00, 0.21499000E-01, 0.38846100E-01, -.52818300E-01, -.87532900E-02, 0.14735300E+00, -.74961400E-02, 0.16695700E+00, -.86035100E-01, 0.47898000E+00, -.87744800E+00, -.14108500E+00, -.71496500E+00, -.10274900E-01, 0.12694700E-01, 0.87249600E-02, -.41820300E+00, -.91950500E-01, 0.79087300E-01, 0.15716200E+01, 0.37922700E+00, 0.76076200E+00, 0.34609700E+00, 0.73410000E-01, -.46592300E-02, 0.84281900E-01, 0.49161400E-02, -.76485700E-01, 0.51572500E-01, -.27759500E-01, 0.11388900E+00, 0.87327400E-01, -.99245500E+00, 0.34551600E+00, -.37604200E-01, -.88686000E-01, -.70596000E-01, -.25476500E-02, 0.49224800E+00, -.46750400E+00, -.44174900E-01, -.46290700E+00, -.96669700E+00, 0.30060800E-01, 0.54222000E+00, 0.29739600E-01, 0.17420100E+00, 0.13165200E+00, -.58950500E-01, -.18168500E+00, 0.32679600E-01, -.21213700E+00, -.14994200E+00, -.23027700E-01, -.22804800E+00, 0.88682600E+00, -.52396300E-01, -.12117300E+00, 0.12369600E-01, 0.30479400E+00, -.13968800E+01, 0.11402200E+00, 0.46834900E+02, 0.19247600E+02, -.12958800E+02, 0.19987200E+02, -.13739100E+02, -.11280100E+03, 0.60810300E+02, 0.58939700E+01, 0.56501000E+02, -.17055300E+02, -.11869400E+03, 0.13085400E+03, 0.62880900E+02, 0.95634700E+02, -.12052500E+03, 0.65051700E+02, -.67622800E+02, 0.33061200E+02, 0.35631600E+02, 0.33322700E+02, 0.17184900E+02, -.71267700E+01, 0.32347300E+02, 0.10024500E+02, 0.10316100E+02, -.56483400E+01, 0.54880100E+02, -.47618800E+02, 0.22358000E+02, 0.20907800E+02, 0.23594200E+02, 0.83827300E+01, 0.28365500E+02, 0.19017000E+01, -.17455100E+01, 0.13786900E+02, 0.14229900E+02, 0.52386800E+02, 0.81606500E+01, -.37905900E+01, -.60127400E+02, -.40974400E+01, 0.29168800E+02, -.28151200E+02, 0.96980400E+01, -.10959400E+02, -.80954100E+02, -.79624000E+01, -.19896100E+02, 0.13874700E+03, -.70212600E+02, -.56004900E+02, -.68643700E+02, -.44449400E+02, -.11172700E+03, 0.59044400E+02, 0.83165200E+02, 0.15651900E+02, -.10975100E+03, -.20789900E+02, -.89793000E+02, 0.44938000E+02, -.35342300E+02, 0.44550700E+02, 0.37754600E+02, -.58117900E+02, 0.61277500E+02, -.30272000E+02, -.79180500E+02, -.16226000E+02, -.45128100E+01, 0.22240300E+02, -.12524400E+02, -.76535900E+02, -.11680000E+02, -.38726800E+01, -.69317700E+01, 0.13003500E+02, -.20176100E+01, -.18732500E+02, -.41638100E+01, 0.80664500E+01, 0.11578600E+03, -.58198300E+02, -.75385300E+02, -.57833800E+02, -.20694800E+02, 0.24681400E+02, -.43002100E+02, -.55106200E+01, -.37517900E+02, 0.18165300E+02, -.63119200E+02, 0.27389100E+01, 0.64256900E+00, -.16730600E+01, -.44295900E+00, 0.10436300E+01, -.63859000E+01, 0.15403300E+00, 0.62635100E+00, 0.60456300E+00, 0.14898400E+01, -.11735400E+01, -.11405900E+01, 0.16952500E+01, 0.15351700E+00, 0.48912800E+01, 0.80566500E-01, -.24336200E+01, 0.15219800E+01, -.12949500E+02, -.10756200E+01, 0.42812100E+01, -.28532500E+02, 0.36401500E+01, 0.10327300E+02, -.84578800E+00, 0.14563900E+00 },
        { 0.45847400E+01, -.34270200E+00, -.21665400E+00, -.42446900E+00, 0.12069000E+01, 0.27475100E+01, 0.18973000E+01, -.47134100E+00, 0.21608900E+01, -.27654700E+01, -.46273200E-01, 0.25148100E+00, -.43612700E+00, -.10262800E+01, 0.89403400E+00, 0.12959700E+00, 0.44258800E+00, -.37091100E+00, -.35030200E+00, 0.82061900E-02, -.40641000E+00, -.32720400E-01, 0.84139100E-01, 0.23248100E+00, -.33377500E-01, -.65249700E-01, 0.30745800E+00, -.15465200E+00, 0.77037000E+00, 0.26399400E+00, -.30935600E+00, -.17793500E+00, -.76937300E+00, -.63754000E+00, -.73381900E-01, -.50346400E-01, 0.99799200E-01, -.38997900E+00, 0.90948300E+00, -.12917700E+01, -.69280000E-01, -.23828600E+00, -.13441600E+00, 0.36469900E+00, -.43526500E+00, 0.29299100E-01, -.16045200E+00, 0.88136100E-02, -.41072700E-01, -.16601700E+00, -.56438000E+00, 0.22654800E+00, 0.52514000E+00, 0.29519500E+00, 0.60880000E+00, 0.58087600E+00, 0.36512000E+00, 0.24698000E+00, 0.37615600E-02, -.15838400E+00, -.63827500E-01, 0.79251700E+00, 0.39012600E+00, -.41695900E+00, -.49846400E+00, -.31911900E-02, -.34518900E+00, 0.45854900E-01, -.23319800E-01, -.24113000E-01, -.63570500E-01, 0.24049600E+00, -.54980400E+00, -.13886900E+00, -.22529600E+00, -.29640300E-01, -.50919200E-01, 0.42864200E-01, -.26958700E+00, 0.68748200E+00, -.14635500E-01, 0.23577900E+00, -.17819100E+01, 0.10953400E+00, 0.53596100E+00, -.25037800E+00, 0.17670500E+01, 0.15037500E+00, 0.38327400E+01, -.12493400E+01, -.41579100E+00, -.42874200E-01, 0.34899500E+00, 0.43233900E+00, 0.29919700E+00, -.23354200E+01, 0.63167100E+00, 0.75913600E+00, 0.22494300E+00, -.45167500E-01, -.12657700E+00, 0.78354700E-01, 0.29149000E+00, -.10310100E+01, 0.54813900E+00, -.23211800E+00, -.57671400E+00, 0.26667000E+00, 0.98191900E+00, 0.18209400E+00, 0.84611200E-01, -.65156700E-01, -.83834600E-01, -.27706100E-01, -.78622200E+00, 0.10871200E+00, 0.66045600E+00, -.70711700E+00, -.58506000E-02, 0.12739100E+00, 0.29439400E+00, -.10074900E+01, -.75065100E-01, -.26664200E+00, -.35095900E-01, 0.10303400E+00, 0.11626600E+00, -.76082100E+00, 0.43805700E+00, -.80824900E-01, 0.31166400E+00, 0.58814700E+00, -.49340300E+00, 0.11765700E-01, 0.16397600E+00, 0.81124200E-02, 0.52311400E-01, 0.47203300E+00, -.43313700E+00, -.11806100E+01, 0.24179800E+00, -.10996800E+01, -.97284400E+00, -.36582500E+00, 0.11969200E+00, 0.10159200E+00, -.17549800E-01, -.14067900E+00, -.37179700E+00, 0.28129500E+00, -.15121300E+00, -.22259800E+00, -.40945400E+00, -.28865300E+00, 0.71968100E-01, -.46920700E-01, -.10418300E+00, -.23629300E-01, -.27987200E+00, 0.22145900E+00, -.27116700E-01, -.15698200E+00, 0.50644000E+00, -.12221400E+00, -.89463400E-01, 0.60804700E-01, -.25045400E+00, 0.84583700E+00, -.19589400E+00, 0.89377700E-01, -.62129100E-01, -.39058800E+00, -.44475800E-01, -.11431200E+00, 0.51497200E+00, -.13485600E+01, 0.23395900E+00, 0.33583300E+00, -.44934700E+00, -.75918400E+00, -.18379100E+01, -.38680000E+00, 0.86030300E+00, 0.14443400E+03, 0.89159800E+02, -.36671400E+02, 0.70758300E+02, 0.10724100E+03, -.48443100E+02, -.39687600E+02, -.53974900E+02, 0.17304900E+02, 0.98454800E+02, -.12339000E+03, -.14376700E+03, -.14008100E+03, 0.12763100E+03, -.66132100E+02, -.35605200E+01, 0.23134100E+01, -.29676400E+02, 0.13864100E+01, -.34710500E+02, -.22935800E+02, -.13946400E+02, -.54871600E+01, 0.62096100E+02, -.33404700E+02, -.99400300E+02, 0.41528900E+02, -.20181000E+02, 0.23149800E+02, -.20972800E+02, 0.36216300E+01, -.75815300E+02, 0.23256400E+02, 0.88343700E+02, 0.17338000E+03, -.55948700E+02, 0.31190100E+02, 0.38446900E+03, -.19375000E+03, -.12578300E+03, -.19220100E+03, -.13257600E+03, -.49869900E+02, -.62414400E+02, 0.15538300E+03, 0.10797600E+03, -.68957900E+02, -.15108700E+03, -.21629400E+03, 0.12050300E+03, -.92479500E+02, 0.11035500E+03, 0.73030400E+02, 0.12048700E+03, -.67307400E+02, -.16400500E+03, 0.53379800E+02, 0.12081000E+03, 0.10280900E+03, 0.59254600E+03, -.29902600E+03, -.19911500E+03, -.29651600E+03, -.16964000E+03, -.46006500E+02, -.79690400E+02, 0.33036000E+03, 0.17410900E+03, -.88465900E+02, -.16737700E+03, -.79949500E+02, 0.38727500E+02, 0.16394300E+03, 0.39704200E+02, -.84169700E+01, -.12722500E+02, 0.55577000E+02, 0.46043600E+02, 0.10342000E+03, -.14903500E+02, 0.38834000E+02, -.25795500E+03, 0.12983300E+03, 0.85061500E+02, 0.12904200E+03, 0.40327000E+02, 0.41941000E+02, 0.70845400E+01, -.61196100E+02, 0.29826600E+01, 0.24616100E+02, 0.13499900E+03, 0.21295900E+01, 0.30129300E+00, 0.91926300E+01, 0.10104400E+02, -.12163200E+01, 0.12841100E+01, -.84556900E+01, 0.52952500E+01, -.40985100E+01, 0.67418200E+00, 0.60662500E+01, -.14825300E+01, -.12486500E+01, -.36174600E+01, 0.13239100E+01, 0.15262800E+01, -.25797700E+00, -.91966200E+01, 0.20333700E+02, -.64471500E+01, 0.43120300E+02, 0.34268000E+02, -.19967700E+01, -.15585600E+02, 0.75098400E+01, 0.11054400E+02 },
        { 0.25044300E+01, -.10409200E+01, -.57988600E-01, 0.84827500E+00, 0.11761700E+01, -.25957400E+01, 0.34488300E+01, -.57298800E-01, 0.87430600E+00, -.19488300E+01, 0.10078800E+00, 0.11117600E+00, 0.13032200E+01, 0.76913400E+00, 0.37390400E+00, 0.57354900E+00, 0.90186300E+00, -.14362700E-02, -.33033000E+00, 0.11892300E+00, 0.23281700E+00, -.65324600E-01, 0.33575200E-01, -.12887200E-01, 0.17693700E+01, -.68326400E-01, -.80076000E-01, 0.41118000E+00, 0.24204300E+00, -.11192200E+00, -.26758200E-01, -.13053100E-02, 0.10935700E+00, -.45154600E+00, 0.42152000E-01, -.17616300E+00, 0.17521700E+00, -.18083700E-01, -.15826600E-01, 0.29712500E+01, -.87590300E-01, -.13517600E+00, 0.41068800E+00, -.18584200E+00, -.95564300E-01, 0.14181100E+00, 0.36287900E+00, 0.72964400E-02, -.10385500E+00, -.33755900E+00, -.68167000E+00, 0.28845500E+00, 0.23264100E+00, 0.57733400E+00, 0.52644200E+00, -.52530900E+00, 0.49708800E+00, -.18250200E+00, -.31031700E-02, 0.52623400E+00, -.11820100E+00, -.14372700E+01, -.74681600E+00, -.79229600E+00, 0.48919800E-01, -.12906900E+00, -.29205900E+00, -.32864800E+00, -.55577700E-01, -.11890600E+00, 0.92720400E+00, -.56791600E-01, -.15484800E+00, 0.17174300E+00, -.50054900E+00, -.51423500E+00, 0.86355300E-01, -.17991900E+00, 0.53217400E-01, -.58751200E+00, -.31161100E-01, 0.23621400E+00, -.23748300E+00, -.19215300E-01, -.11850500E+01, -.70165100E-01, 0.13317500E+01, 0.53481100E+00, 0.59422400E+00, -.84029800E+00, -.32853300E+00, -.59921200E-01, 0.49361800E+00, -.81425600E-01, -.10036700E+01, -.11832100E+00, -.88495600E-01, -.13785500E+00, -.54273600E+00, 0.85187900E-02, -.16207000E+00, -.79933100E-01, 0.67786100E+00, -.19215000E+00, 0.14900800E+00, -.38625900E-01, -.44370100E+00, -.74792400E-01, 0.81638800E+00, 0.17330000E+00, 0.35687600E-01, 0.38548800E-01, -.11009100E+00, -.22648100E+00, -.65376000E+00, -.78651400E-01, -.14216400E+00, -.42965800E+00, -.13760700E+00, 0.69958600E-01, 0.17185400E+00, -.68950700E+00, -.55551500E-01, -.20741700E+00, 0.44557900E-03, 0.21025500E+00, -.10242900E+00, -.13899400E+00, 0.11100100E+00, 0.18813700E+00, 0.35838000E+00, -.69954900E+00, -.43663800E-01, 0.10354800E-01, -.15202400E-01, 0.11614900E-01, -.84080100E+00, 0.31795100E-01, -.41095700E-01, -.66196900E+00, -.38298400E+00, -.41568200E+00, 0.59113400E+00, 0.55615900E-01, -.14154900E-01, 0.16737400E+00, -.96860200E-02, 0.12067100E+00, 0.45088600E-01, 0.22587300E+00, 0.15598000E+00, -.25366800E-01, 0.82353600E+00, -.22466900E+00, 0.59368100E-02, -.23029200E+00, 0.72946000E+00, -.46220400E-01, -.10078500E+00, 0.67734400E+00, -.39920100E-01, 0.11827400E+00, -.21587100E+00, -.76175800E-01, 0.10411200E+00, 0.26323800E-01, 0.51090700E+00, -.17877600E+00, -.17263100E+00, 0.94073900E-01, 0.10254400E+00, -.82036800E+00, 0.59088600E-01, 0.26289300E+00, 0.29927500E+00, 0.90297800E+00, -.29626300E-01, 0.16191400E+00, -.14252600E+00, -.10326100E+01, 0.17364400E+01, 0.14583700E+00, -.46521000E+00, 0.24636300E+00, -.65066300E+02, 0.28985600E+02, 0.58144500E+02, 0.10010700E+03, -.41263600E+02, -.41941300E+01, -.49927500E+02, -.12933000E+02, -.30451500E+02, 0.21320000E+02, 0.25585100E+02, -.48385600E+02, -.36928500E+02, -.10891100E+02, -.52777800E+03, 0.26314500E+03, 0.18622200E+03, 0.26373800E+03, 0.14782100E+03, 0.13481000E+02, 0.13708600E+03, -.40953700E+02, 0.17356000E+03, 0.25768900E+02, 0.23493000E+03, -.12007700E+03, 0.58013700E+02, 0.57876200E+02, 0.60172300E+02, 0.90698500E+01, -.17408800E+02, 0.57441600E+02, 0.19557000E+02, 0.19380800E+03, -.41414200E+02, -.55766800E+02, -.39063000E+03, 0.19544700E+03, 0.16409900E+03, 0.19513800E+03, -.66432600E+02, 0.74128200E+02, 0.31666400E+02, -.14205700E+03, 0.84310900E+02, 0.71978500E+02, 0.19553800E+03, 0.51418200E+02, -.22148400E+02, 0.76221400E+02, -.26193800E+02, -.27921400E+02, -.53463300E+02, 0.44420600E+02, 0.23219900E+02, -.31806600E+02, -.50050300E+02, -.32385500E+02, -.21616500E+03, 0.10791100E+03, 0.13958500E+03, 0.10764200E+03, -.10142900E+03, 0.97986300E+02, 0.22485300E+02, -.73302100E+02, 0.47622600E+02, 0.88017400E+02, 0.18457100E+03, 0.42742600E+02, -.23495300E+02, -.34051800E+02, -.22066400E+02, -.96192700E+01, 0.26223800E+02, -.22370900E+02, -.31714700E+02, -.80969300E+02, 0.30632800E+02, -.44096200E+02, 0.54272500E+02, -.27465800E+02, 0.82842700E+02, -.27505200E+02, -.48965400E+01, 0.46196500E+01, -.44280200E+02, -.38605300E+02, -.11656600E+03, 0.29716000E+02, 0.18690600E+02, 0.15576500E+01, -.26817700E+01, 0.41457900E+01, -.65241300E+01, 0.30148900E+01, -.62830900E+01, 0.96720900E+01, 0.20100500E+01, -.36130400E+01, -.38010200E+00, 0.65436300E+01, 0.14474500E+02, 0.52757400E+00, -.21127900E+01, 0.10041500E+02, 0.32552800E+01, 0.16050600E+01, -.82415800E+01, 0.12060100E+02, -.20199600E+01, 0.34229200E+02, 0.26397600E+02, -.10961700E+02, -.22038000E+01, -.72861700E+01, 0.49224100E+01 },
        { 0.66766500E+01, -.10335100E+01, -.15458200E+00, -.76831900E-01, 0.18148600E+01, 0.60103100E+01, 0.28921700E+01, 0.50736700E+01, 0.26156200E+01, -.51883500E+01, -.68907600E+00, 0.73908800E-01, -.26520900E+01, 0.51601400E+01, -.24261500E+01, 0.11333300E+01, 0.30099400E+00, -.17510700E+01, 0.13211400E+01, 0.94004900E+00, -.21074400E+00, -.23029700E-01, -.67146100E-01, 0.66768900E+00, -.43651700E+01, -.20486800E+00, -.88596800E+00, -.23765600E+01, 0.34087400E+01, -.93358700E+00, 0.64801300E+00, 0.14142600E+01, -.14402000E+01, -.10727100E+01, -.86689800E+00, 0.74012300E+00, -.12938600E+00, 0.12192700E-01, -.20368000E-01, 0.12878700E+02, -.34655700E+00, 0.33029100E+00, -.15421200E+01, -.96984200E+00, 0.25262600E+00, 0.26130300E+00, -.58086100E+00, 0.21689100E-01, 0.42697100E+00, 0.99196700E+00, 0.29041200E+01, -.15276300E+01, -.67471600E+00, -.25699000E+01, 0.46384500E+00, 0.95801500E+00, 0.35263500E+00, -.17233800E+00, 0.17335000E+00, 0.98996400E+00, -.11535500E+01, 0.26966400E+01, 0.10969400E+01, -.81123900E+00, 0.14169500E+01, -.54062500E+00, -.44196300E+00, 0.44539900E+00, 0.37139500E-01, 0.13037500E+00, -.23412200E+01, 0.40527300E+00, -.24861500E+00, -.54896400E-01, 0.10595300E+01, -.83454200E+00, 0.50240000E+00, -.10283600E+01, -.68268800E+00, 0.52111600E+00, -.62612600E-01, -.73187800E+00, 0.33193700E+00, -.23177100E+00, -.16677700E+01, -.54820000E+00, 0.20442200E+00, 0.11106900E+01, 0.20076400E+01, -.13173100E+01, 0.18014200E+01, -.89385600E-01, -.88527400E+00, 0.13749100E+01, -.14295000E+00, -.13260500E+01, 0.20563100E+00, -.27735400E+01, -.11586200E+01, 0.57961600E+00, 0.14247600E+00, -.13313300E+01, 0.18304400E+00, -.97957600E+00, 0.16841500E+01, -.48467100E+00, 0.12051800E+01, 0.11368000E+01, -.11504500E+01, -.21130600E+00, -.13630600E+01, 0.45938100E-01, -.13787000E+00, -.43030600E+00, 0.18309300E+01, -.15638700E+01, 0.20967200E+01, -.69821800E+00, -.11036600E+00, -.53582500E+00, 0.15615700E+01, -.16456500E+01, -.13435700E+00, -.11274600E+01, -.68965900E-01, -.50764800E-01, -.33599400E+00, 0.11293300E+01, -.12652000E+01, -.81620200E+00, -.90609100E+00, 0.10788500E+01, -.25567100E+01, 0.42483900E-02, -.20071100E+00, 0.44159300E-01, 0.21481300E+01, 0.54212800E+00, -.28569900E+00, 0.29098100E+01, 0.24410000E+01, 0.53889500E+01, -.14854200E+01, -.11244100E+01, 0.27748700E+00, 0.90927600E+00, 0.35916500E-01, -.62941100E+00, 0.80128400E-01, 0.21953000E+01, -.41938600E+00, -.17420800E+01, 0.10517100E+01, 0.26656400E+00, -.10208800E+00, 0.10634600E-01, 0.23837100E+01, 0.13173700E-01, 0.16072200E+00, 0.50510400E+00, 0.73371600E-01, -.17235800E+01, -.19638500E+01, -.20543000E+00, -.46339600E+00, -.31711700E+00, 0.16336800E+01, -.84668200E+00, -.11306300E+00, -.29763700E+00, -.37508500E+00, -.78673900E+00, 0.97395000E-01, 0.12006700E+00, -.24759200E+00, -.33294000E+01, -.66282800E-01, 0.95139700E+00, 0.28228000E+00, -.19083900E+01, -.35006800E+01, 0.26097100E+01, -.26789100E+01, 0.25391000E+00, 0.29193800E+00, 0.69975300E+02, 0.12392000E+03, -.24992000E+03, 0.12310600E+03, -.15552300E+03, 0.12586600E+03, -.14881900E+03, -.40341900E+03, 0.28129600E+03, 0.24373700E+03, 0.53220500E+03, -.42586800E+03, 0.35361600E+02, -.34076500E+03, 0.17279700E+03, 0.33575500E+03, 0.16617900E+03, -.47669600E+02, -.80130600E+02, 0.11076300E+03, -.77479200E+02, 0.14174700E+03, -.11578700E+03, -.45185000E+03, -.13100300E+03, 0.67675700E+02, -.96590000E+01, 0.62523100E+02, 0.12231400E+03, 0.78204400E+02, 0.31034200E+02, 0.11837200E+02, 0.86834400E+02, 0.85188100E+02, -.23892900E+03, 0.34351200E+03, -.17219000E+03, -.39538700E+03, -.17105400E+03, -.39050100E+02, -.26842700E+03, 0.51580500E+02, -.19191400E+02, -.29905200E+03, -.15235400E+03, 0.43326100E+03, 0.84833200E+02, -.23232400E+02, -.41940000E+03, -.34330000E+02, -.73349200E+02, -.26155800E+03, 0.15351100E+03, 0.25140000E+03, 0.34360000E+03, -.28305700E+03, 0.22656900E+02, 0.10333400E+03, -.54116200E+02, -.26571400E+03, -.53071800E+02, -.31762200E+02, -.42444100E+03, 0.16737200E+03, -.24787400E+03, -.36537600E+03, -.16924600E+03, 0.70959500E+03, -.35169600E+02, 0.12450900E+02, -.10243100E+03, 0.15453500E+02, -.63735900E+02, -.63034800E+02, 0.66751400E+02, 0.19431500E+01, 0.14756500E+03, -.67221700E+02, 0.17805400E+03, -.17384200E+03, 0.81597800E+02, -.10278100E+03, 0.89391300E+02, 0.25284400E+02, 0.25256500E+03, -.21080800E+03, -.20176000E+03, -.78168300E+02, 0.15776400E+03, 0.15666500E+03, 0.78742700E+01, 0.12987500E+02, -.10170600E+02, 0.14305500E+02, 0.20508500E+02, -.26762900E+02, -.14850300E+02, 0.34264300E+01, 0.25399400E+01, 0.77665000E+01, -.14806200E+02, -.39688300E+02, 0.81955900E+00, -.11729500E+01, -.64914400E+01, 0.50315900E+01, -.13778100E+02, 0.14750300E+02, -.71201500E+02, -.20855800E+02, 0.25040100E+02, -.20540800E+03, 0.40861000E+02, 0.56128100E+02, -.18176400E+01, 0.75461000E+01 },
        { 0.86874600E+01, 0.78339700E+01, 0.83336600E+00, 0.49485300E+01, 0.27468300E+01, 0.85244000E-01, 0.10216600E+02, -.24124900E+01, 0.49466300E+01, -.77860200E+01, -.14883200E+00, 0.40789500E+00, 0.43990000E+01, -.94725900E+01, 0.29637500E+01, -.11362900E+01, -.12819900E+01, -.20806900E+01, 0.39275300E+00, 0.50059800E+00, -.64545700E+00, -.13464600E+00, 0.40765900E+00, 0.35051500E+00, -.14630700E+01, -.12353800E+00, 0.83649600E+00, -.72259400E+00, 0.25699300E+01, -.38582400E+00, 0.34386000E+00, 0.87145300E+00, -.51021900E+00, -.15283100E+00, -.10025100E+01, 0.40441200E+00, -.15746900E+00, 0.99061500E-01, -.11152800E+01, 0.77499300E+01, -.23848100E-01, 0.28017600E+00, -.85508500E+00, -.96865700E-01, 0.21324200E+00, 0.16065100E+00, -.28928900E+00, 0.65887100E-01, -.12596600E+00, 0.18200500E+00, 0.19755300E+01, -.37120800E+00, -.32217900E+00, -.66524800E-01, -.40291700E+00, 0.13507000E+01, -.45745600E+00, 0.24927200E+00, 0.39581300E-01, 0.71929000E-02, -.20833700E+01, 0.88692500E+00, 0.43546400E+00, 0.99246700E+00, -.70306600E+00, 0.18149700E-01, 0.15070500E-01, 0.67497400E+00, -.76630800E-01, -.10717600E+00, -.90516200E+00, 0.40559700E+00, -.18673300E+01, 0.27218400E+00, 0.50700400E+00, -.60323800E+00, -.20238900E+00, 0.33503200E+00, 0.41939900E+00, -.11291400E+01, -.26996100E+00, -.36114500E+00, 0.86175900E+00, -.87976900E+00, 0.47001400E+00, 0.35555300E+00, -.45662300E+01, 0.22509800E+01, 0.11927600E+01, -.16804100E+01, 0.29596400E+01, -.56672800E-01, 0.10217200E+00, 0.21850400E+00, -.12202300E+01, -.10983500E+00, -.41179900E-01, 0.82449800E+00, -.14893400E+01, -.71955700E+00, -.80025300E+00, 0.69395600E+00, 0.11415200E+01, -.23645900E+01, 0.67214100E+00, -.10652700E+01, 0.48404800E+00, 0.25960900E+00, -.14492200E+01, 0.12277300E-01, 0.41262500E+01, -.35531300E+00, -.17278000E+00, 0.10208200E+01, -.33839300E+00, -.35240400E+01, -.12296800E+01, 0.20554000E+01, -.52282100E+00, 0.56541800E+00, 0.10762300E+01, -.18399700E+00, -.10932700E+00, -.26472500E+00, 0.53130600E-02, -.42393200E+00, 0.53306500E+00, -.53361200E+00, 0.67837000E+00, 0.50123600E+00, 0.11768900E+01, 0.33599800E+01, -.59443500E+00, 0.12690100E-01, -.34905900E+00, 0.46654700E-02, -.77063100E+00, 0.12461400E+01, -.60412000E+00, -.23508300E+01, 0.10546700E+00, -.14691500E+00, 0.46573500E+00, 0.16351300E+00, 0.18321500E+00, -.27874300E+00, 0.23997400E-01, -.11448700E+00, 0.18697700E+00, -.14374800E+00, 0.15049600E+00, -.20794800E+00, -.17774100E+01, 0.54959700E+00, -.31131900E+00, -.13709800E+00, -.47532100E+00, 0.13674500E-01, -.71830400E+00, -.22396400E+00, 0.24457200E+00, 0.15497400E+01, 0.18960100E+01, 0.30982400E+00, -.14204200E+01, -.55658000E-01, 0.13763800E+01, -.26913400E+01, -.54621100E-01, -.15226500E+00, -.91665400E-01, 0.47862700E+00, 0.53676000E+00, 0.21556400E-01, -.11144000E+01, 0.26854200E+01, -.20205600E+00, 0.16112600E+01, -.28746400E+00, -.20208800E+01, -.76048600E+01, 0.11178800E+01, -.51740700E+00, 0.11003700E+01, 0.29931600E+00, 0.12775900E-01, -.34118000E+03, 0.94516000E+03, -.45178800E+03, -.47412100E+03, -.47307600E+03, -.31837700E+03, -.25896200E+03, -.25037000E+03, -.16474100E+01, -.21900400E+03, -.26475100E+03, -.58214600E+03, -.13896200E+03, 0.69860600E+02, -.10744400E+03, 0.70651100E+02, -.44516800E+02, 0.46551600E+02, 0.88610700E+02, -.22510200E+02, 0.79252700E+02, 0.36217200E+02, -.39025500E+03, 0.28995900E+03, -.14507500E+03, -.20205700E+03, -.14403000E+03, 0.10267300E+02, -.13205300E+03, 0.51451300E+02, 0.66122500E+02, -.12922200E+03, -.75695700E+02, -.79844000E+03, 0.15726200E+03, -.77008000E+02, -.10412400E+03, -.78913800E+02, -.27453300E+02, -.17126600E+03, 0.58053900E+02, -.10174300E+03, -.43048100E+02, -.17411700E+03, -.27353500E+03, -.25832300E+03, 0.16373900E+03, -.50173700E+03, 0.12766200E+03, -.31029700E+02, -.80984300E+01, -.45186700E+02, -.14606100E+03, -.18141000E+00, -.18878700E+02, 0.13982200E+03, 0.10758500E+03, -.50529000E+02, -.14922900E+03, -.53601200E+02, -.13227200E+02, -.27986200E+03, 0.10347300E+03, -.15710900E+03, -.90098600E+02, -.22398400E+03, -.37570900E+03, -.61873900E+02, 0.27567100E+02, 0.18040600E+03, 0.31281600E+02, 0.75332100E+01, -.14048700E+02, -.27054100E+02, 0.36677500E+01, 0.81329500E+02, -.61051800E+01, 0.12243900E+03, -.15403700E+03, 0.76625800E+02, 0.15429100E+03, 0.76078600E+02, 0.89294500E+01, 0.94238300E+02, -.33665700E+02, -.19664600E+02, 0.81707800E+02, 0.22209300E+02, 0.11957700E+03, 0.16931500E+02, -.16748800E+01, 0.73666200E+01, 0.32994100E+01, 0.27140500E+01, -.24574400E+01, -.75607200E+01, 0.27290500E+00, -.39545400E+00, 0.17159300E+01, -.98923100E+00, -.76978900E+02, -.90579500E+01, -.60918700E+01, -.69715600E+02, 0.79221000E+00, -.13896200E+02, 0.65721800E+01, -.64599400E+02, -.23223800E+02, -.13907900E+02, -.75690900E+02, 0.66742800E+02, 0.33412700E+02, 0.77809100E+01, -.83888500E+01 },
        { -.12653100E+01, 0.17881400E+01, 0.20929900E+00, 0.43661000E+00, 0.13435600E-01, 0.16809500E+01, -.38809300E+01, 0.36323500E+01, -.15259500E+01, 0.66784700E+00, -.20672800E-01, -.10272700E+00, -.20720600E+01, 0.42886800E+01, -.20050700E+01, -.24692300E+01, 0.11565600E+01, 0.65144200E+00, 0.12935900E+01, 0.44965100E+00, -.14776500E+00, 0.88597500E-02, -.36700600E-01, 0.13420200E+00, -.10161000E+01, -.15947000E-01, -.14610700E-01, 0.14407900E+00, 0.15567500E+00, 0.21485700E+00, -.76772200E-01, -.24722800E+00, -.17201600E+00, 0.16581500E+00, 0.81338900E-02, -.17734500E-01, 0.86149500E-02, -.75342600E-01, -.38493000E+00, -.98798700E+00, 0.31662300E-01, -.62610900E-01, -.79083400E-01, 0.16860400E+00, -.36746100E-01, -.30286400E-01, -.19518900E+00, -.11464500E-01, 0.10285300E+00, 0.10909300E-01, 0.64424700E+00, -.22757500E-01, 0.48990500E-01, -.12395100E+00, -.20906500E-01, -.67333500E-01, 0.25936100E+00, 0.10477400E-01, -.13588400E-01, 0.12342900E+00, -.10123500E+00, 0.20966000E+00, 0.11360900E+00, 0.16345100E-01, 0.27346400E+00, 0.18061000E-01, -.32375500E-02, 0.62308200E-02, 0.54192000E-01, 0.34013600E-01, 0.17604200E-01, -.10566900E+00, 0.43579400E+00, 0.66016500E-01, 0.28225300E+00, 0.21186100E+00, 0.12409100E+00, 0.15457800E+00, 0.91977000E-01, -.21387500E+00, 0.16715000E-01, -.11516000E+00, 0.23122200E+00, -.11372600E-01, -.48816200E-01, -.98784200E-01, -.12355000E+00, 0.28493300E+00, 0.16511100E+00, 0.53487700E-01, 0.60559600E+00, 0.16889800E-02, -.53363300E-01, 0.24131400E+00, 0.42643400E+00, -.82328300E-01, 0.85174900E-01, -.11932700E+00, 0.37691300E-01, 0.22117600E-01, 0.10446200E+00, -.19926500E+00, -.13699900E+00, 0.17108700E+00, -.16984900E-01, -.52016900E-01, -.17707800E+00, -.27475100E+00, -.13056000E+00, -.44378400E-01, 0.15036700E+00, -.96857000E-02, 0.31042900E-01, 0.73729400E-02, -.18569100E+00, 0.25545500E+00, -.65248300E+00, -.74861000E-01, 0.81052200E-01, 0.90430500E-01, -.14020400E+00, 0.17458900E+00, 0.37749200E-01, 0.17016400E+00, -.62600300E-02, -.90699300E-01, 0.11856300E-01, 0.12209700E+00, -.16240000E+00, -.26415000E-02, -.61921500E-01, 0.64216900E+00, -.36584000E+00, -.15054100E-02, 0.26879300E-01, 0.15342600E-02, 0.46414500E+00, 0.23310400E+00, -.11483800E+00, 0.77188300E+00, 0.32098500E+00, -.49644900E-02, -.33715200E-01, -.37557200E-01, -.19965900E-01, 0.22388400E-01, 0.17852000E-02, -.41397400E-01, 0.45638000E-01, -.13996200E+00, -.57399900E-01, -.48704900E-01, -.15334300E+00, 0.24649300E+00, -.46570100E-01, 0.29095900E-01, -.40465200E-01, 0.18080000E-01, -.38477000E-01, -.40372800E+00, 0.10963400E+00, 0.29041000E+00, 0.72762700E+00, 0.65008200E-01, -.57334500E+00, -.78120200E-01, 0.10695700E+00, -.95910100E-01, -.62859200E-01, -.54037300E-01, -.45050000E-01, 0.19425700E+00, -.14937200E-02, -.10667600E+00, 0.29577800E+00, 0.66310400E+00, 0.45456400E-01, 0.73100400E-01, 0.13408000E+00, -.66645800E-02, -.29401500E+01, -.15735800E+00, 0.50205500E-01, -.18851600E-01, -.51923400E+00, 0.11723300E+00, 0.10470000E-01, 0.26654500E+03, -.13129500E+03, -.14203500E+03, -.13341700E+03, -.38419000E+02, -.54874000E+01, -.64181900E+02, -.55182300E+02, -.12530200E+03, -.35260600E+01, -.11663100E+03, -.18047100E+03, 0.90423900E+02, 0.42712300E+02, 0.90314900E+02, 0.46834600E+02, 0.10868600E+02, 0.71576500E+02, 0.16076900E+02, 0.85667200E+02, 0.18902900E+02, 0.38779200E+02, -.87392200E+02, 0.44288200E+02, 0.60485900E+02, 0.43765100E+02, 0.45063100E+02, -.14499600E+02, 0.10954900E+02, 0.97027100E+01, 0.12242900E+03, -.18222000E+02, -.12956600E+03, -.15021300E+03, 0.74990500E+02, 0.80565900E+02, 0.75091500E+02, -.41520900E+01, 0.26947600E+02, 0.23997800E+01, -.48748200E+02, 0.68410900E+02, 0.99951000E+01, -.10419500E+03, -.79091300E+01, 0.82000700E+01, -.11633100E+03, 0.42607900E+01, -.11967700E+02, -.50704800E+02, 0.44066600E+02, -.32439500E+02, 0.18446400E+02, -.41270800E+02, -.91392300E+01, -.35698900E+02, 0.17787600E+02, 0.48235400E+02, 0.17861600E+02, -.13564300E+02, 0.24583900E+02, -.45210900E+01, 0.24827200E+02, 0.62910700E+02, -.50169700E+01, -.21009700E+03, -.48316200E+01, 0.27573100E+01, 0.11850100E+02, 0.24558600E+01, -.20135100E+02, -.20226000E+00, -.39389000E+01, -.80380800E+01, -.16875000E+01, -.41150400E+00, -.61573800E+01, 0.67190200E+02, -.34717500E+02, 0.15702300E+02, -.33670100E+02, -.22143000E+02, -.12372100E+02, 0.49208800E+01, 0.22581000E+02, -.37022700E+02, -.10350300E+02, 0.33330100E+02, 0.18346700E+01, 0.12416400E+01, 0.63991600E+01, -.14080100E+01, -.19879200E+01, -.83322100E+00, -.25177400E+01, 0.22459400E+01, -.20978400E+01, -.54283600E+00, 0.52348800E+01, -.74026400E+01, -.34015600E+00, -.27907500E+01, -.75373400E+01, 0.14272500E+01, -.22531900E+01, -.36530300E+01, -.53894000E+01, -.57839900E+01, 0.26762500E+02, 0.23495100E+02, 0.91996900E+01, -.24378600E+01, -.32856900E+01, 0.45631100E+00 },
        { 0.73860200E+01, -.36811600E+01, -.42460400E+00, 0.20658600E+00, 0.25528200E+01, -.10954000E+01, 0.75917200E+01, -.15436900E+01, 0.39834300E+01, -.53229500E+01, -.21802200E-01, 0.76032700E+00, -.18483700E+01, 0.32534300E+01, -.22022300E+01, 0.22261500E+01, 0.10529200E+01, -.16108200E+01, 0.16405700E+01, 0.21461600E+01, 0.42025000E+00, -.34402400E+00, -.11748300E+00, -.52899300E+00, 0.17229600E+01, 0.34204000E+00, -.10667700E+01, -.61778600E-01, 0.81925800E+00, -.26072900E+01, 0.20625000E+01, -.20002500E-01, 0.12094900E+01, 0.11921400E+01, -.46449500E+00, 0.38635200E+00, -.33615900E+00, 0.17940500E+01, -.10374500E+00, 0.89564600E+01, 0.29816500E+00, 0.41357800E+00, -.11110600E+01, -.22489500E+00, 0.16788200E+00, -.22481200E+00, -.97590300E+00, 0.62782400E-02, 0.20417100E+00, 0.90374400E+00, 0.25617500E+01, -.13298700E+01, -.30571900E+00, 0.24021800E-01, 0.21530000E+01, -.13683700E+01, 0.34716400E+00, -.25138800E+00, 0.10000100E+00, 0.72041600E+00, 0.74013400E+00, 0.51864600E+01, 0.30794800E+01, -.56513000E+00, 0.32878600E+00, -.23466900E+00, -.17674200E+01, -.19674300E-01, -.33383000E+00, -.18484500E-01, -.17011900E+01, 0.49563200E-01, 0.60150900E+00, -.59373500E+00, -.37490900E+00, 0.92581500E+00, -.71834400E+00, -.29243300E+00, -.26072700E+00, 0.31875000E+00, -.10984400E+00, 0.26950300E+00, 0.99200700E+00, 0.70379200E-01, -.27904800E+00, 0.42236600E+00, -.25241100E+01, 0.15717400E+01, 0.22144700E+01, -.12823700E+01, -.15674100E+01, 0.21217500E-01, -.10750600E+00, 0.13114300E+00, 0.13060100E+01, -.21436100E+01, 0.23438100E+00, 0.52571400E+00, 0.40686300E+00, -.51856900E-01, -.31701700E+00, 0.32112500E+00, -.26835900E+00, -.16313600E+01, 0.29751900E+00, -.52155400E+00, 0.59260500E+00, 0.43448300E+00, 0.20567400E+01, 0.28955000E+00, -.91224300E+00, 0.24494400E+00, -.11616500E+00, -.44515100E+00, 0.67674100E+00, 0.49431100E+00, -.17498900E+01, -.89099600E+00, 0.19495700E+00, -.14528400E+00, 0.24202800E+00, -.15252000E+01, 0.50021000E-01, -.28883800E-01, 0.11409500E-01, 0.58329800E-01, -.46173400E+00, 0.44189400E+00, -.77033800E-01, -.47525700E+00, 0.29047900E+00, 0.20504200E+01, 0.64477500E+00, 0.27160100E-01, -.18312700E+00, -.53800700E-02, 0.49585800E+00, -.90390300E+00, -.81710200E-01, -.40692300E+01, 0.11806800E-01, -.20954600E+01, -.33064100E+01, -.15498000E+00, 0.83649900E-01, -.34566400E+00, -.10190900E+00, 0.31475900E+00, 0.36586600E+00, -.80095500E+00, -.47321500E+00, 0.13692700E+00, 0.14221600E+01, -.23521000E-01, 0.25245400E-01, -.43651300E+00, 0.10358500E-01, -.56634900E-01, -.51652500E+00, 0.72687400E+00, -.95876200E-01, -.88547800E+00, -.84673600E+00, -.26565500E+00, 0.97221900E+00, 0.15661800E+00, 0.28418600E+00, -.46117300E-01, -.30884700E+00, -.18998200E-01, -.43543900E-01, -.11656900E+01, -.13412700E+00, 0.22040800E+00, 0.46742000E+00, -.11765400E+01, -.19562400E+00, -.31608000E+00, -.79243900E-01, -.72554200E+00, 0.61214900E+00, 0.12244900E+01, -.62832900E+00, -.65472900E+00, 0.20580000E+00, 0.17968700E-01, -.66435000E+00, 0.15644800E+01, 0.32007800E+02, 0.12732800E+03, -.27121400E-01, -.18007800E+03, -.24138500E+03, 0.98559700E+02, 0.26712100E+03, 0.16827800E+03, -.22938300E+03, -.81101000E+02, 0.14575400E+03, -.72784500E+02, -.12143200E+03, -.73324400E+02, -.18723000E+02, 0.11185900E+02, -.81965800E+02, -.99486100E+02, -.95694000E+02, -.10310500E+02, -.30486300E+03, 0.23182700E+03, -.12071900E+03, -.12814500E+03, -.11583900E+03, -.73698400E+02, -.26575100E+02, 0.36356100E+02, 0.38619300E+02, -.19938600E+03, 0.36833400E+01, -.16378300E+03, -.18932300E+03, 0.95142300E+02, 0.21069800E+02, 0.94421500E+02, 0.30071700E+02, -.14299000E+03, 0.19193300E+03, -.44092400E+02, 0.42763100E+02, -.79228100E+02, 0.23621500E+03, -.34139300E+03, 0.19657100E+03, 0.65777200E+02, 0.17132700E+03, 0.94899800E+01, 0.10274200E+03, -.48638800E+02, 0.85654700E+02, -.17283300E+02, 0.72382200E+02, 0.23194200E+03, -.38551000E+03, 0.19239700E+03, 0.12496300E+03, 0.19197100E+03, 0.57495100E+02, -.19166800E+03, 0.28550400E+03, -.18967200E+03, 0.53005000E+02, -.73567500E+02, 0.38920700E+03, 0.23781300E+02, -.19277800E+02, 0.12466700E+03, -.13061400E+02, 0.24921200E+02, -.26801900E+02, 0.12549700E+02, 0.24865700E+02, 0.26918700E+02, -.75536500E+01, 0.86659500E+02, -.38586300E+03, 0.19344400E+03, 0.21949000E+03, 0.19242900E+03, 0.81358200E+02, 0.10287800E+03, -.32835800E+02, -.13416000E+03, 0.72944100E+02, 0.66740000E+02, 0.15051200E+03, 0.60497200E+01, -.22530300E+01, -.11075400E+02, 0.29313200E+01, 0.88185900E+01, -.44339500E+01, 0.56486500E+01, -.35602900E+01, 0.43456700E+00, 0.15259400E+01, -.13336500E+02, -.24288900E+02, -.53968900E+01, 0.12600700E+01, -.13858100E+02, 0.59987800E+01, -.52765900E+01, 0.78340500E+01, -.15067600E+02, -.45239600E+01, -.34064500E+02, -.12715600E+03, 0.10098400E+02, 0.28205000E+02, 0.12177200E+02, 0.20081600E+01 },
        { -.45354600E+01, 0.22858300E+01, 0.72647200E+00, -.16191600E+01, -.12655300E+01, 0.52589200E+00, -.25609700E+01, 0.81414600E+00, -.14039400E+01, 0.30350600E+01, 0.43358600E-01, -.94328000E-01, -.30569500E+01, 0.65385800E+01, -.36260800E+01, 0.48982100E+00, 0.60244400E-01, -.48713000E+00, 0.77617900E+00, 0.21006300E+00, 0.49225800E+00, 0.31970300E-02, -.81673600E-01, 0.10867500E+00, -.55541200E+00, 0.13995100E-02, -.87710700E+00, -.11033200E+01, 0.13110400E+01, -.18760300E+00, 0.75666700E+00, 0.87772800E+00, 0.20670400E+00, 0.55999900E+00, 0.19331500E+00, 0.17418200E+00, -.17119000E+00, 0.72514300E+00, -.76647500E+00, 0.30589400E+01, 0.16052700E+00, 0.57192000E-01, -.62172900E+00, 0.10439600E+01, -.70213600E-01, 0.18481100E+00, -.40013600E+00, -.22897600E-01, 0.26112100E-01, 0.20458400E+00, 0.82354000E+00, -.19519800E+00, 0.35532700E+00, -.11181200E+01, 0.46224200E+00, 0.84021000E+00, -.20934600E+00, 0.43838900E+00, -.12884700E-01, -.13897400E+01, 0.12435900E+01, 0.51215500E+01, 0.21471500E+01, -.62483400E+00, 0.50992800E+00, 0.16653700E-01, 0.22623700E+00, 0.47333100E+00, 0.32342700E+00, 0.11703500E-01, -.45794200E+00, -.19321800E+00, -.52827200E+00, 0.30575800E+00, 0.96169600E+00, 0.54122900E+00, -.41168400E+00, 0.10804200E+01, 0.50076600E+00, -.50041200E+00, -.84316500E-01, -.20811600E+00, 0.15399000E+01, 0.25251300E+00, -.18391100E+00, 0.54241600E-01, -.34964500E+00, -.74757900E+00, -.17352700E+01, 0.64981200E+00, 0.43531800E+01, 0.29914500E-01, 0.15708900E-01, 0.70970100E+00, -.87228400E+00, 0.76077100E+00, -.31612100E+00, -.26920500E+01, -.32478900E+00, 0.47070500E+00, 0.68553500E+00, -.87115800E+00, -.13166200E+01, -.16623800E+00, 0.14068900E+00, -.12583500E+01, -.11127900E+01, -.20873700E+01, -.38083000E+00, -.51520000E+00, -.18495800E-01, -.29907600E-01, 0.13420900E+00, 0.12949800E+00, 0.32079100E+00, 0.66275300E+00, 0.29391600E+01, 0.11279000E+00, -.19577400E+00, -.19032900E+00, -.45541000E+00, 0.30129900E+00, 0.27625700E+00, 0.52412800E+00, -.21790900E-01, -.18295600E-01, -.19037700E+00, -.78567300E+00, 0.55299000E+00, -.31032200E+00, 0.69768000E+00, -.68805700E+00, 0.15239500E+01, 0.23687000E-02, -.36717500E-01, 0.30843600E-02, -.39812200E+01, 0.70598500E+00, -.53313300E+00, 0.44885300E+00, 0.35975100E+00, 0.79125000E+00, -.16649200E+01, -.10724000E+00, -.73639200E-01, -.50427000E+00, 0.30502200E-02, 0.99816000E-01, 0.35456100E+00, -.14990900E+00, 0.51485000E-01, 0.22343800E+00, 0.14096000E+01, -.20967700E+00, 0.27930900E+00, -.33146200E-01, 0.97755100E+00, -.40540000E-02, -.46138200E+00, 0.62566800E+00, -.81944600E-01, -.10408800E+00, 0.37037400E+00, -.13942300E+00, 0.24524400E+00, 0.23242100E+00, -.17493400E-01, 0.45343500E+00, -.10235300E+00, 0.12055600E+00, -.95552900E-03, -.68119400E+00, 0.25519300E+00, -.14228300E-01, -.10084600E+01, -.13263500E+01, 0.28782100E+00, 0.92358500E+00, -.18008400E+00, -.19730000E+01, -.20239100E+01, 0.77521500E+00, -.33211900E+00, 0.18221200E+00, 0.11476400E+01, 0.14369500E+00, -.45041800E-01, 0.13701000E+01, -.37112500E+00, 0.18358100E+03, -.44732200E+00, -.54870500E+02, 0.44464600E+02, -.72336700E+02, 0.15442300E+03, 0.12185900E+03, 0.46277900E+02, -.14868700E+02, 0.10754500E+03, -.55634800E+02, -.99258700E+02, -.52658600E+02, 0.27666900E+02, 0.77797000E+01, -.91824200E+02, -.11723400E+03, -.13017300E+03, 0.72648200E+01, -.16146700E+03, 0.36214000E+03, -.18549600E+03, -.10836900E+03, -.18039900E+03, -.41012100E+02, 0.94540900E+01, -.23008500E+02, 0.67918500E+02, -.26539200E+03, 0.36186500E+02, -.28872500E+03, -.42064800E+03, 0.21116600E+03, 0.19450400E+03, 0.21025000E+03, 0.24193300E+02, 0.39370600E+01, 0.18113800E+03, -.11212100E+02, 0.16842900E+03, 0.23091600E+02, 0.43678500E+03, -.36234600E+03, 0.16881500E+03, 0.20981000E+03, 0.17999300E+03, 0.10815500E+03, 0.35728600E+03, -.20598100E+03, -.39001000E+02, -.29422100E+02, 0.32129000E+03, 0.23741900E+03, -.34921100E+03, 0.17540700E+03, 0.23426800E+03, 0.17518200E+03, -.13654600E+02, 0.37168100E+02, 0.17689600E+03, -.79544100E+02, 0.12829700E+03, 0.58405400E+02, 0.55930300E+03, 0.40894300E+02, -.22005000E+02, 0.15903200E+03, -.19536100E+02, 0.61155500E+02, 0.16113600E+02, -.38389400E+02, 0.21794300E+02, 0.44864600E+01, 0.30380900E+02, 0.21437900E+02, -.30074900E+03, 0.15731700E+03, 0.12170000E+03, 0.14994300E+03, 0.11330100E+03, 0.74991300E+02, -.54911900E+02, -.14959600E+03, 0.41965200E+02, 0.66545600E+02, 0.96858300E+02, 0.15593800E+01, -.10294800E+02, -.65974600E+01, -.53856700E+01, 0.90521700E+01, 0.40239100E+01, 0.17020000E+02, -.57893700E+01, -.18651000E+01, -.20378600E+01, -.70894500E+01, 0.75986000E+01, -.45813900E+01, 0.31080700E+01, 0.11231400E+01, 0.36770600E+01, 0.33622500E+01, -.32950200E+01, 0.22118800E+02, 0.79899000E+01, -.37949600E+02, -.47583700E+02, -.19996500E+02, 0.41483400E+01, 0.12226100E+02, 0.54965700E+01 },
        { 0.64361400E+01, -.25473500E+01, -.52831800E+00, 0.25685900E+01, 0.36204700E+01, -.50829500E+01, 0.76225600E+01, -.79074800E+01, 0.36204800E+01, -.50431400E+01, -.15454400E+00, 0.26988600E+00, -.99990300E+00, -.27235200E+01, 0.58519700E+01, -.23562200E+01, 0.94518800E+00, 0.25434600E+01, -.19405900E+01, 0.25337200E+01, -.81239600E+00, -.31861700E+00, -.20273100E+00, 0.31471000E-01, 0.14084500E+01, -.21172200E+00, 0.12853200E+01, 0.33316500E+01, -.22150000E+01, 0.12145200E+01, -.81105400E+00, -.41141100E+00, -.93351000E+00, -.11617000E+01, 0.22949900E+00, -.38585000E+00, 0.59543800E+00, -.19561700E-01, 0.23194300E+01, 0.41509600E+01, -.17193700E-02, 0.48832100E+00, 0.17491100E+01, -.48969300E-02, -.55023500E+00, 0.10193200E+00, 0.11476300E+01, -.91073700E-01, -.46694200E+00, -.10562500E+01, -.22469600E+01, -.16151400E+00, 0.56835000E+00, -.11435000E+00, -.64193200E+00, -.27496800E+00, -.26116300E+00, 0.36489900E-01, -.41123900E+00, 0.92303900E+00, 0.10556100E+00, -.38936300E+01, -.22818000E+01, 0.33380200E+00, -.18308300E+00, 0.46499900E-01, -.53628700E+00, -.48556900E+00, -.72825400E-02, -.19275300E+00, 0.10656900E+01, -.29382200E-01, 0.17350000E+01, -.21601000E-01, 0.72150100E+00, -.11738700E+01, 0.32292600E+00, -.10746500E+01, -.36753100E-01, -.32738200E+00, -.39677200E-01, -.21581600E-01, 0.66530500E+00, -.64459100E+00, -.15851000E+01, -.46355800E+00, -.19181200E+01, 0.45847400E+00, 0.12351900E+01, 0.26336500E+00, -.68554800E+00, -.17548600E+00, -.41284900E+00, 0.68622400E+00, 0.10989300E+01, -.23464700E+00, 0.24777400E+00, 0.76310100E+00, 0.53967000E+00, -.71625900E-01, 0.29622400E+00, -.48516900E+00, 0.93176300E+00, 0.32766900E+00, 0.49994200E+00, 0.61048300E-01, -.36848600E+00, 0.30848000E+00, 0.16458900E+01, -.24144900E-01, -.11329100E+01, 0.39906000E+00, -.21016900E+00, -.41107400E+00, 0.75066300E-01, -.71003400E+00, -.35100100E-01, 0.31741700E+00, -.62024900E-01, 0.44118700E+00, 0.62509200E+00, -.21640000E+00, 0.49113000E-01, -.35971000E+00, -.17494400E+00, -.45852400E+00, 0.12264600E+00, 0.14125200E+01, -.18553400E+01, 0.16152200E+00, -.62082800E+00, 0.72352200E+00, -.18049800E+01, -.15504100E-01, -.15385400E+00, 0.36970700E-01, 0.18110700E+01, 0.22754000E+00, 0.37521400E+00, 0.56644600E+00, 0.68907600E+00, 0.10388400E+01, -.68164100E+00, -.18252600E-03, 0.10599700E+00, -.76464800E-01, -.34099000E+00, -.61176100E-01, -.40544700E-01, -.16796600E+00, -.13758700E+00, -.20791500E+00, -.26777800E+00, -.22406600E+00, 0.60099300E-01, 0.20450600E+00, 0.26054100E+00, -.52420500E-01, 0.27294300E+00, -.21806500E+00, -.85794200E-01, -.38474700E+00, -.92085900E+00, -.75332600E-01, 0.35394000E+00, -.12657500E-01, -.29443600E+00, 0.61599800E+00, 0.27113700E-02, -.33001400E-01, 0.28629500E-01, -.27224000E+00, -.38016700E-01, -.12082200E+00, 0.24442900E+00, -.19058800E+01, 0.12212100E+00, -.15690700E+00, -.12640800E+00, 0.16781900E+00, 0.11236700E+01, 0.33782100E+00, -.48952000E-01, -.27819500E+00, 0.27755400E+00, -.55742100E-01, -.43945800E-01, -.99394500E+00, -.81759600E-01, -.69665100E-01, 0.10377300E+02, -.52885300E+02, -.72330800E+02, 0.10659900E+02, 0.18771700E+02, 0.34171000E+01, -.65444800E+02, -.35234200E+02, -.13318200E+02, 0.73966700E+01, -.17677800E+02, 0.62055200E+01, 0.18170500E+01, 0.93274900E+01, 0.16189300E+02, -.88066500E+01, 0.18447400E+02, 0.68506400E+01, -.92302200E+02, -.24171700E+02, 0.13172600E+02, 0.21562600E+02, 0.11742400E+02, -.66747300E+01, -.11210300E+02, 0.19700200E+02, -.92130700E+01, 0.19903900E+02, -.28208300E+01, -.83695700E+02, -.26216200E+02, 0.13171300E+02, 0.30425600E+02, 0.13062000E+02, 0.83944100E+01, -.19967700E+02, 0.30594600E+02, -.19595700E+02, 0.39797500E+02, -.18591200E+02, -.86808500E+02, -.50422000E+02, 0.30554900E+02, -.58894500E+02, 0.20499500E+02, -.23078100E+02, -.71095100E+02, 0.56637700E+02, 0.52642200E+02, 0.46984000E+02, -.69451600E+02, 0.90669500E+01, -.14651400E+02, 0.76468000E+01, 0.26977500E+02, 0.70275800E+01, 0.16207100E+02, -.27170900E+02, 0.42509800E+02, -.17125400E+02, 0.46214500E+02, -.21634500E+02, -.11057000E+03, -.97140600E+01, 0.55448500E+01, 0.54632300E+02, 0.42479600E+01, 0.40580800E+01, 0.36058300E+01, -.75302000E+01, 0.13426000E+01, 0.61617000E+01, 0.97162100E+01, 0.19512700E+02, -.79711700E+02, 0.39767200E+02, 0.50382900E+02, 0.40126200E+02, 0.14830500E+01, -.11592900E+02, 0.37280500E+02, 0.79406100E+01, 0.26808500E+02, -.10574500E+02, 0.62088100E+02, 0.14872500E+01, 0.12550400E-01, 0.10551200E+01, 0.54852400E+00, -.15107900E+01, -.15912000E+00, -.20025000E-01, 0.24716100E+00, -.78673900E+00, 0.54826700E+00, -.50959900E+00, -.10183900E+02, -.70932600E+00, -.56155100E+00, -.46581300E+01, 0.18291100E+01, -.27204900E+01, 0.10397100E+01, -.50394300E+01, -.35203100E+01, 0.15264900E+01, -.89460800E+01, 0.90998500E+01, 0.30067500E+01, 0.15497700E+01, -.21000200E+00 },
        { 0.37659700E+01, -.60018300E-01, -.14353000E+00, -.53602500E+00, 0.10139700E+01, 0.24687200E+01, 0.13196600E+01, -.32008600E+00, 0.16948300E+01, -.21634800E+01, -.28229800E-01, 0.19892400E+00, 0.13974800E+00, -.92097700E+00, 0.82973600E+00, -.61934200E-01, 0.55636500E+00, -.69474300E-01, -.57002800E+00, 0.32187000E+00, -.38942600E+00, -.63502500E-01, -.29554200E-02, 0.29055400E+00, -.80831300E+00, -.66674000E-01, 0.46359900E-01, 0.33208900E+00, 0.48788300E+00, -.56708400E-01, -.44321400E+00, -.13700500E+00, -.80453500E+00, -.52025200E+00, -.42540900E+00, 0.13401900E+00, 0.35110900E-01, -.30908600E+00, 0.23302900E+00, 0.93939900E-01, -.15220200E+00, -.54402700E-01, -.56150100E+00, -.51093300E+00, 0.30096300E+00, 0.14629100E+00, -.23596800E+00, 0.16744100E-01, -.65820500E-02, 0.29829100E+00, -.12946400E+01, -.23978100E+00, 0.35024200E+00, -.30215800E+00, 0.75630300E+00, 0.71546100E+00, 0.71180300E+00, -.35484000E-01, 0.67242600E-01, 0.38005300E+00, -.50638200E+00, -.84460000E+00, -.41985000E+00, 0.21320400E+00, 0.41281700E+00, -.45189100E-01, 0.67906900E-02, 0.35281100E+00, 0.86195300E-02, 0.34467700E-01, -.60904600E+00, 0.50845800E+00, -.90436100E-01, 0.79965100E+00, 0.55814100E+00, -.58834300E+00, 0.25003500E+00, 0.11799200E+01, 0.10413900E+00, 0.32021800E-01, 0.39130200E-01, 0.20447900E+00, -.26179900E+00, -.49022500E-02, -.18217500E+01, -.55489500E+00, 0.10316900E+01, 0.40716800E-01, 0.73791900E+00, 0.30886000E-01, 0.26290000E+01, -.46234000E-01, -.46884500E-01, 0.58740700E+00, -.41118400E+00, -.65153900E+00, 0.24156100E+00, 0.56282100E+00, -.43262100E+00, -.16026600E+00, -.13478600E-01, 0.97849900E-01, 0.39818400E+00, -.82173900E+00, 0.47893800E+00, -.49130400E+00, -.36889600E-01, 0.13768400E+00, 0.23222800E+00, 0.21667700E-01, 0.82996800E-01, -.60215900E-01, -.42726400E-01, 0.96687700E-01, 0.74556400E-01, -.52103200E+00, 0.19206700E+01, -.27265500E+00, -.70254000E-01, -.30634200E+00, 0.72622700E+00, -.60535000E+00, -.82861700E-01, -.24060500E+00, -.36583600E-01, -.66890200E-01, -.13189800E+00, 0.33751000E+00, -.80303600E-01, -.36828800E+00, 0.26549800E+00, 0.82503100E+00, 0.52281300E+00, 0.12376800E-01, 0.12072000E+00, -.81652600E-03, 0.79986200E+00, 0.78319600E-01, -.35331800E+00, -.24788300E+01, 0.36913600E+00, -.17189200E+01, -.12497100E+01, -.24603600E+00, 0.12073700E+00, -.14064800E+00, -.64264600E-01, -.11574900E+00, -.21793200E+00, -.26498600E+00, -.40026600E+00, -.57828500E+00, -.14526800E+01, 0.26848000E+00, -.17452400E+00, -.11955700E+00, -.82354200E+00, -.10140900E-01, -.88598900E+00, -.78858900E+00, 0.23616200E+00, 0.11294600E+01, 0.14235200E+01, 0.52085400E-01, -.10798000E+01, 0.35656300E+00, -.62748300E+00, -.28006500E+00, -.11292300E-01, -.38477500E-01, -.33401400E+00, 0.25443800E+00, -.44054200E+00, 0.17081600E+00, -.10619400E+01, -.14090600E+01, 0.15209100E+00, 0.14624400E+00, -.56044900E-01, -.13895500E+01, -.38656100E+01, 0.17436200E+00, -.24871500E+00, 0.70406300E+00, 0.51474000E-01, 0.44508000E+00, -.21787300E+00, 0.56656700E+00, 0.26512900E+00, -.84766800E-01, -.61508100E-01, 0.80417400E+02, 0.17619900E+03, -.15172400E+03, -.18935800E+03, -.59412100E+02, 0.17193200E+03, 0.71063500E+01, -.23019600E+03, 0.11327900E+03, 0.15781200E+02, 0.11559300E+03, 0.70971200E+02, -.11388100E+02, 0.71253100E+02, 0.87939600E+01, 0.13450000E+03, 0.92785200E+01, 0.13702900E+03, -.59616200E+02, 0.27708100E+02, 0.75470100E+02, 0.30001900E+02, 0.20196500E+02, -.66798900E+02, 0.58020000E+02, 0.82463600E+02, 0.23392800E+03, -.73899900E+02, -.13540000E+03, -.53603900E+03, 0.26807200E+03, 0.34255100E+03, 0.26812000E+03, -.12024300E+02, 0.15079800E+03, 0.31512000E+02, -.66761100E+02, 0.24149100E+03, 0.10096100E+03, 0.18741000E+02, -.51809400E+02, 0.15238600E+02, 0.40416500E+02, 0.26723500E+02, 0.58910100E+02, 0.11473900E+03, -.85516400E+02, -.14177900E+03, 0.54406100E+02, 0.10371300E+03, 0.77162600E+01, -.21012000E+03, 0.10597800E+03, 0.25057900E+03, 0.10558100E+03, -.58067000E+02, 0.22115200E+03, -.45151200E+02, 0.80501900E+02, 0.23051800E+03, 0.11783200E+03, -.15333500E+03, 0.10049400E+02, -.39219400E+01, 0.90218800E+02, -.42402600E+01, 0.32445100E+02, 0.19063400E+02, 0.70349400E+01, 0.20652900E+02, -.38347400E+02, 0.28726300E+02, -.41693000E+02, 0.13056500E+03, -.61537900E+02, -.22901000E+02, -.65219000E+02, 0.14690900E+02, -.48135400E+02, -.35589600E+01, 0.18700700E+02, -.94686600E+02, -.55539600E+01, -.24626100E+02, 0.50357800E+00, -.55670800E+01, 0.14315300E+02, -.49520300E+01, -.38984300E+01, 0.23100900E+01, 0.13067200E+01, 0.79784000E+00, -.39111000E+01, -.12966300E+01, 0.11421000E+02, 0.16299700E+02, 0.94968900E+00, -.14209100E+01, 0.11394000E+02, -.23001000E+01, 0.38270700E+01, -.11855900E+02, 0.31831300E+02, -.15725100E+01, 0.49121200E+02, 0.87403200E+02, -.13714200E+02, -.23664000E+02, 0.68051200E+01, 0.40597400E+01 },
        { 0.52357500E+01, -.55918000E+01, -.14710000E+01, 0.76712700E+00, -.51614400E+00, 0.77857200E+00, 0.32654800E+01, 0.13882000E+01, 0.12858800E+01, -.33416700E+01, -.41062900E-02, -.61688300E-01, 0.42637800E+01, -.22809100E+01, 0.54150800E+01, 0.55015100E+01, -.15094200E+01, 0.12654300E+01, -.28806800E+01, 0.48287400E+00, 0.10290600E+01, -.21013100E+00, -.10479600E+00, -.47044900E+00, 0.48064200E+01, -.97593600E-01, -.15505800E+00, 0.14150400E+01, -.27049700E+01, -.57835800E+00, -.14566000E+00, -.17334500E+01, 0.18816000E+01, -.89816200E+00, 0.99958700E+00, -.13499000E+01, 0.52620700E+00, 0.17982900E+01, -.19479100E+01, 0.19957200E+02, 0.18888400E+00, -.33440900E+00, 0.12477500E+01, 0.23470800E+00, -.29052300E+00, 0.23626400E+00, -.77794000E+00, -.15319500E-01, 0.60029600E-01, -.14695400E+00, 0.21959200E+01, 0.46527500E+00, -.33872200E+00, -.85519500E+00, -.60824400E+00, -.88748900E+00, 0.11865600E+01, -.76557000E-01, -.10833200E-01, 0.12131000E+01, -.60014300E+00, -.38560000E+01, -.22635100E+01, -.16251100E+01, 0.14942600E+01, -.55271800E+00, -.10910300E+01, -.96295600E+00, 0.79313800E-01, -.10527100E+00, 0.41568000E+00, -.12844800E+00, 0.15486000E+01, -.97824600E-01, 0.27105600E-02, -.32899100E-02, 0.22887200E+00, -.13772300E+01, -.44762900E+00, 0.14563700E+00, -.16943600E+00, -.29198300E-01, 0.10741300E+01, -.15921300E+00, -.11694500E+01, 0.18030700E+00, 0.80583600E+00, -.12596300E+01, -.24256200E+01, 0.42569500E+00, -.56210500E+01, -.14078900E+00, 0.25200500E+00, -.59398000E+00, -.79402600E+00, -.11625800E+01, 0.91421800E-01, -.37697400E-01, -.55015400E+00, 0.60213400E+00, 0.83287600E-01, -.73566300E+00, 0.82803700E+00, 0.15281900E+01, 0.58522100E-02, 0.71440900E+00, -.15276400E+01, -.88074400E+00, 0.30839500E+01, 0.20752700E+00, -.11801200E+01, 0.30986900E+00, -.51116500E+00, -.81035000E+00, -.47055500E+00, 0.24545500E+01, 0.17302500E+00, -.23422900E+01, 0.83839800E-02, -.27565500E+00, 0.34442600E+00, -.20072700E+01, -.20272800E+00, -.12802800E+01, -.54418700E-01, 0.23829200E+00, -.25413100E+00, 0.18995800E+00, -.21607700E+01, -.81843200E-01, -.18067600E+00, -.47965500E+01, -.15569300E+00, -.19930600E-01, -.99752600E-01, 0.28878700E-01, 0.18617600E+01, 0.56761400E-01, 0.62636800E+00, 0.25423100E+01, 0.79876100E+00, -.68805100E+00, -.18994600E+01, -.79263000E+00, -.11094700E+00, 0.69275100E+00, 0.15500000E-01, -.14077200E+00, -.58976800E+00, 0.11799600E+01, 0.28237600E+00, 0.42735000E+00, 0.19717400E+01, -.20456200E+00, 0.19396900E+00, -.15934500E+00, 0.22739200E+01, -.13568900E-01, 0.15249700E+01, 0.10847600E+01, -.12865800E+00, -.13156700E+01, 0.13049200E+00, 0.15459000E+00, 0.10184000E+01, 0.21554700E+00, -.20563500E+00, -.11862200E+00, 0.12267600E+00, -.27855700E+00, -.40959200E+00, 0.12917900E+01, 0.12220300E+00, -.50879100E+00, 0.93545700E+00, -.47085900E+01, 0.41759800E+00, -.97268900E-01, 0.57506700E-01, -.18399400E+01, -.52504800E+01, 0.94782200E+00, -.20911400E+01, 0.86442700E+00, -.59337700E+00, 0.54685000E+00, 0.37279400E+00, -.82759000E+00, -.55384200E-01, 0.59638500E+00, -.20543500E-01, 0.11369600E+01, -.23222100E+03, 0.29533800E+03, 0.15864600E+03, -.79081500E+02, -.24228400E+03, 0.15681500E+03, -.25752400E+03, 0.12816400E+03, 0.25221900E+03, 0.12902300E+03, 0.16997700E+03, 0.61071000E+02, -.21238000E+02, 0.43992200E+01, 0.15072000E+02, 0.81385900E+02, 0.59341500E+03, -.19217500E+03, 0.95110100E+02, 0.46828700E+02, 0.96936200E+02, -.46842400E+01, 0.10662600E+03, -.32429200E+02, -.13804500E+03, 0.15656500E+02, 0.28577400E+02, 0.49715700E+03, 0.63651300E+02, -.31123600E+02, -.15313500E+03, -.32455000E+02, 0.71780900E+02, -.38546000E+02, -.11368600E+03, -.13805200E+03, -.15545600E+03, -.14788900E+02, -.32165800E+03, 0.66523100E+03, -.35082600E+03, 0.10917400E+03, -.33593000E+03, -.20894300E+03, -.48489500E+03, 0.32195900E+03, 0.30682700E+03, -.22050400E+03, -.43167900E+03, -.30230600E+03, -.32686300E+03, 0.16430100E+03, -.47407000E+02, 0.16240000E+03, 0.16477000E+03, -.56737600E+02, 0.36533400E+01, -.98601900E+02, -.18426700E+02, -.30920000E+02, -.34356300E+03, 0.15513900E+03, -.74490400E+02, -.27041400E+03, -.79220600E+02, -.91011300E+02, 0.14599500E+02, -.79675900E+02, -.11894300E+03, -.18641100E+03, -.11369300E+01, -.14859300E+03, 0.31644500E+03, -.16334200E+03, 0.39794600E+02, -.15965400E+03, -.14268100E+03, -.89147600E+02, 0.27756400E+02, 0.74510500E+02, -.96531900E+02, -.42553400E+02, -.18377600E+03, 0.39006700E+01, 0.79788400E+01, -.10334600E+02, -.65119100E+01, -.92445100E+01, 0.99494800E+00, 0.38186600E+01, 0.19276400E+00, 0.18096900E+01, -.65556900E+01, 0.13295300E+01, 0.39291100E+02, 0.93601000E+01, 0.12493600E+01, 0.35043200E+02, 0.74610000E+01, 0.11700500E+01, -.29746700E+01, -.14327500E+01, 0.13188800E+02, -.55639100E+01, -.71271100E+01, -.24024900E+02, 0.77610000E+01, -.34270200E+02, 0.47102000E+01 },
        { -.32140700E+01, 0.61276500E+00, 0.11583700E+00, 0.99238400E+00, -.58096700E+00, -.21622800E+01, -.13020200E+01, 0.70879100E+00, -.13265500E+01, 0.20693900E+01, -.10994400E+00, -.16182500E+00, -.15702800E+01, -.44674500E+00, -.22794300E+01, 0.65051300E+00, -.25077900E+00, -.10932300E+01, 0.10769100E+01, -.10419000E+00, 0.52093100E+00, 0.14878500E+00, 0.14900900E+00, 0.40579100E-01, -.18697900E+01, 0.59282900E-01, -.56203400E+00, -.19927400E+01, 0.46426600E+00, 0.28529000E+00, 0.14071500E+00, 0.32924500E+00, -.22078800E-01, 0.87825400E-01, -.49672700E+00, -.13456400E+00, -.35929300E+00, -.46467600E+00, -.14087700E+00, -.29697100E+01, -.76133100E-01, -.19147300E-02, 0.70691200E+00, 0.69995900E+00, -.21689400E+00, -.11735000E+00, 0.31399100E+00, -.41557000E-02, 0.45886700E-02, 0.26846900E-02, 0.17047100E+01, 0.76125900E-01, -.24726600E+00, -.41095700E-02, 0.15406200E-01, 0.22184700E+00, -.54155100E+00, -.33484600E-01, -.26921600E-01, -.56360300E+00, 0.59205200E+00, 0.16555800E+01, 0.60977400E+00, 0.17880700E+00, -.57442800E+00, 0.21105900E+00, -.45968200E-01, 0.22684200E+00, -.11990600E+00, -.10338300E-02, 0.19723600E+00, -.99303900E-01, -.55007100E+00, -.30878100E+00, -.15531500E+00, 0.79166000E-01, -.20081100E+00, -.48197600E-01, 0.36260100E+00, -.54334500E+00, -.16886000E-01, -.37258500E+00, 0.18843500E+00, 0.26516700E-01, 0.33294300E+00, 0.84717400E-01, -.32183400E+01, 0.40233200E-01, 0.14608100E+00, -.28214700E+00, -.25832800E+01, 0.35421100E-01, 0.23806500E-02, -.19509100E+00, -.10278300E+00, 0.88856700E+00, -.38237400E+00, -.78440300E+00, -.15283800E+00, 0.31665000E-01, 0.14142100E+00, -.10299500E+00, -.45020600E+00, 0.38616600E-01, 0.59312900E-01, -.43699500E-01, 0.25158700E+00, -.30571700E+00, -.96425300E+00, -.14942400E+00, -.97689900E-01, -.58592500E-01, 0.54310100E-01, -.12812100E+00, -.14131400E+00, -.80446400E-01, -.72567700E+00, 0.38861900E-01, 0.38429700E-01, 0.58185800E+00, -.29747800E+00, 0.50040600E+00, -.33533400E-01, 0.43556700E+00, 0.28091000E-01, 0.30746800E+00, -.31905200E-01, -.85408900E+00, -.87265000E-02, 0.46256800E+00, 0.14641900E+00, -.14198800E+01, -.76196200E+00, -.43809900E-02, -.10502100E-01, 0.16416500E-01, -.10779300E+00, -.24684500E-01, 0.24832200E+00, -.33654400E+00, 0.30574100E+00, 0.81992100E+00, 0.88942300E-01, 0.17371700E-01, -.37197700E-01, 0.27967200E-01, 0.60172800E-01, -.12993300E+00, 0.66877400E-01, -.39333200E-01, 0.21740200E+00, 0.35198200E+00, 0.52269900E+00, 0.93344400E-01, -.12050900E+00, -.22641200E-01, -.61652300E+00, -.20964000E-01, 0.38214700E+00, 0.19459800E+00, 0.60658300E-01, 0.29137300E+00, 0.39001900E+00, 0.37053100E-01, 0.35227100E+00, 0.56443800E-01, 0.46301800E-01, 0.17270700E+00, -.19161900E-01, -.10336000E+00, 0.12352500E-01, -.58485200E+00, 0.11279400E+00, 0.10968000E+00, 0.69522500E-01, 0.28659300E+01, -.20389400E+00, -.65848800E-01, 0.39384000E-01, 0.68939200E+00, -.15388000E+01, -.97534600E-01, -.43731000E+00, -.10550300E+00, -.45227200E+00, 0.20694000E+00, 0.25132200E-01, -.16425200E+00, 0.79887300E-01, 0.96957800E-02, -.23983300E-02, 0.40418500E+00, 0.14307200E+00, 0.46296400E+02, 0.56982100E+02, -.11358200E+01, -.49108500E+01, 0.97655100E+02, 0.23518100E+02, -.11153100E+02, -.40083000E+02, -.10901000E+02, 0.29174500E+02, 0.26657900E+02, -.17603800E+02, 0.72526200E+02, -.50313900E+02, 0.34031200E+02, 0.26401800E+03, 0.19418000E+02, -.79461100E+01, 0.14079300E+02, -.90260500E+01, -.86477400E+00, 0.49037000E+02, -.57972600E+02, -.60050700E+01, -.62758500E+02, 0.33169100E+02, 0.13484100E+03, -.13351500E+02, 0.70800900E+01, -.21219500E+02, 0.64435000E+01, 0.27030100E+02, 0.99796900E+02, -.56234200E+02, -.49081900E+02, -.91366800E+02, 0.10201900E+03, 0.15933100E+01, -.55598800E+01, 0.10247700E+02, 0.69058000E+02, -.11048200E+00, -.13813600E+02, -.42183400E+02, 0.40978300E+02, 0.35046700E+02, -.12796200E+02, -.34297000E+02, 0.37032600E+02, -.61481000E+01, 0.40784800E+01, -.65070900E+02, 0.32083300E+01, 0.20005600E+02, 0.10831600E+03, -.56230800E+02, -.14092300E+02, -.96222100E+02, 0.90434100E+02, -.24004500E+02, 0.21346500E+02, -.10366300E+02, -.62198800E+02, -.10513500E+02, -.12960200E+02, 0.12008800E+02, 0.64804700E+01, -.16660400E+02, -.25723300E+02, 0.76857700E+01, -.64084600E+02, 0.14081400E+03, -.71989900E+02, -.15099700E+02, -.71057100E+02, -.18787500E+02, -.17737500E+02, 0.10286200E+01, 0.15161800E+02, -.39007800E+02, -.17358400E+02, -.77914400E+02, -.71328300E+01, 0.11285400E+00, -.23514300E+01, -.56967400E+01, -.12859100E+01, 0.37747000E+01, 0.22351900E+01, 0.10175900E+01, -.32537100E+00, -.32324000E+01, -.12287600E+00, 0.94987100E+01, -.93752000E+00, 0.95550300E-01, 0.10580200E+02, 0.25176700E+00, 0.57770200E+00, -.65088100E+01, 0.23805600E+01, 0.68742500E+01, -.69466900E+01, 0.48854900E+02, -.94290400E+01, -.98505400E+01, -.85632500E+01, -.24130400E+01 },
        { -.86829600E+00, 0.11066100E+01, 0.51480000E-01, 0.15228800E+00, 0.13326100E-02, 0.33522700E+01, -.24589200E+01, 0.12701600E+01, -.93240600E+00, 0.79083400E+00, 0.42671800E-01, -.23049100E+00, 0.82805900E+00, -.66161300E+00, -.89022000E+00, -.42633400E+00, -.15304100E+01, -.55817300E+00, 0.27958600E+00, -.91888300E+00, 0.60675100E+00, 0.88975300E-01, 0.65718400E-02, 0.54922500E-01, -.45229900E+00, 0.29830500E-01, 0.25916100E+00, 0.68239100E+00, -.43955100E-01, 0.83754200E+00, -.11275500E+00, 0.85643200E+00, 0.29154900E+00, 0.16610500E+00, -.12380700E+00, -.13251000E+00, -.17666500E+00, 0.15191500E+00, -.13547000E-01, 0.95325600E+00, 0.33249000E-01, 0.22904700E+00, -.54652000E+00, 0.20631800E+00, 0.40247700E+00, 0.75253200E-01, -.95900000E-02, 0.28904000E-01, 0.57346200E-02, 0.19952100E-01, 0.46370600E+00, -.43283700E+00, 0.43133300E-01, -.20998100E+00, -.11015200E+00, 0.91139700E-01, -.27428300E-01, -.61624200E-01, 0.44544100E-01, 0.93910400E-01, -.68825000E-01, -.90969800E-01, 0.13136100E+00, -.37927500E+00, 0.57659500E+00, 0.99423500E-02, 0.72644600E-01, 0.99458400E-01, 0.11257600E+00, 0.23025600E-01, -.13851700E+00, 0.38016700E-01, 0.22640300E+00, 0.20294800E+00, 0.14241400E+00, -.12519100E+00, -.18603700E+00, 0.26560700E+00, 0.25814000E-02, 0.20844700E+00, 0.41750500E-01, 0.17588600E+00, -.67732800E+00, -.98263400E-01, 0.30482100E+00, 0.61923400E-01, 0.20326500E+00, 0.25528000E+00, 0.42806100E+00, -.12437900E+00, 0.81142500E+00, 0.17291100E-01, -.28407900E-01, 0.17015400E+00, 0.54769500E+00, -.77596600E+00, 0.25396000E+00, 0.29874300E+00, 0.33672200E+00, 0.28946000E-02, -.23297400E-01, 0.78303300E-01, 0.10911600E+00, -.24482700E+00, 0.11667200E+00, -.12095400E+00, -.25265100E+00, -.83704700E-01, 0.55994800E-01, 0.52772300E-02, 0.23031400E+00, -.55304100E-01, -.12951100E-01, 0.48938100E-01, -.13474600E+00, -.44498100E+00, 0.54956800E+00, -.58327000E-01, -.58714000E-01, -.13329400E+00, -.21058700E+00, -.29157300E+00, 0.66877100E-01, 0.11919200E+00, 0.67403900E-03, 0.17127400E-01, 0.90620500E-02, 0.20141500E+00, 0.43458800E+00, -.45977500E-01, -.81027600E-01, 0.14592400E+01, 0.15992300E+00, 0.37723600E-02, 0.37964900E-01, -.10161800E-01, 0.58587700E+00, -.11902800E+00, -.14402700E+00, -.11171000E+01, -.31552900E+00, -.96285100E+00, -.11958500E+00, 0.12447100E+00, 0.29302900E-01, -.17341900E+00, -.30267900E-01, 0.99635300E-01, 0.64816400E-01, -.24962300E+00, -.16109500E+00, -.22261700E+00, -.25004900E+00, -.50495700E-01, -.86046400E-01, 0.46349200E-01, 0.46907600E-01, -.33399900E-02, -.36250500E+00, -.98665900E-01, 0.21074800E-01, 0.17716600E+00, 0.10129900E+00, -.15484000E-01, -.10638000E+00, 0.47365800E-01, -.61496800E-02, -.96376600E-01, -.81037800E-02, 0.10667500E+00, 0.30440700E-01, -.39290500E-01, 0.64905000E-01, -.42494400E-01, 0.55607200E+00, -.35000800E+00, -.46593000E-01, -.18438500E+00, -.83601900E-01, -.35994200E-02, 0.13727100E+01, 0.15532000E+00, 0.23685400E-01, -.10668100E+00, -.40826000E+00, -.11678200E+00, -.82084900E-01, 0.35601600E+00, 0.15318100E+00, -.41727900E-01, 0.79472300E-02, -.16961300E+00, 0.22745000E-02, -.23405800E+00, 0.43159200E+02, 0.83329700E+02, -.20388100E+02, 0.20012100E+02, -.13593200E+03, 0.67724300E+02, 0.24938700E+02, 0.67726800E+02, 0.24653600E+02, -.30444200E+01, 0.45448500E+02, 0.48501200E+01, 0.64488100E+02, -.11706300E+01, 0.11651100E+03, -.13964000E+02, 0.62318400E+01, 0.49348300E+00, 0.68654400E+01, 0.20052000E+01, -.17961200E+02, 0.33944600E+02, 0.35161700E+02, 0.91656200E+02, -.25026900E+02, -.34986900E+02, 0.42299900E+02, -.21305300E+02, -.42448100E+02, -.21148600E+02, -.25385500E+02, 0.20949700E+02, -.38569700E+02, -.13037200E+02, -.16954300E+02, 0.15127400E+02, 0.44979000E+02, -.28546900E+02, 0.13649700E+02, 0.55824700E+02, 0.14783800E+02, -.14019800E+01, -.59210200E+01, 0.11426100E+02, 0.27829500E+02, 0.67311300E+02, -.13474100E+02, -.22634700E+01, 0.87217900E+02, -.43887100E+02, -.54514500E+02, -.43766800E+02, -.41480200E+02, 0.28095700E+02, -.42947700E+02, 0.64499800E+01, -.20834900E+02, 0.21608300E+02, 0.88470800E+02, 0.15686700E+02, -.80933000E+01, -.41522100E+01, -.80819900E+01, -.96281100E-02, 0.13123500E+02, -.14783400E+02, -.23540600E+02, -.18384600E+02, 0.12059000E+02, -.32515300E+02, -.24190600E+01, 0.36063400E+01, 0.27845400E+02, 0.12510600E+01, 0.15319900E+02, 0.35668300E+02, -.57139900E+02, -.51236600E+02, -.59086400E+02, 0.31501800E+02, -.57540000E+01, -.85563300E+00, 0.15488000E+01, 0.84251600E+00, -.47081000E+01, 0.12265400E+01, -.20943000E+00, 0.93458400E+00, 0.40633100E+00, -.16597200E+01, -.10528700E+01, 0.25235000E+00, 0.43758400E+01, -.62639800E+00, -.11178000E+01, 0.37611600E+01, 0.99428800E+00, -.34174100E+00, -.64278800E+01, -.51932000E+00, -.22234900E+01, 0.19968000E+02, 0.17990300E+02, -.28911700E+01, -.37889300E+01, -.45520100E+01, 0.52318900E+01 },
        { -.29968400E+01, 0.92614600E+00, 0.14990200E+00, 0.25501300E+00, -.10420000E+01, -.40694300E+00, -.27182600E+01, 0.34368600E+00, -.17015800E+01, 0.22186800E+01, -.50383400E-02, -.26535700E+00, -.35057200E+00, 0.16502400E+00, -.78972000E+00, -.13819300E+00, -.66648500E-01, 0.22699100E-01, 0.26285500E+00, -.59243700E+00, 0.96136700E-01, 0.75436600E-01, -.22339700E-01, -.68190900E-01, 0.21145700E+00, 0.21618600E-01, 0.98765700E-01, -.98705900E-01, -.29025900E+00, 0.12895900E+00, -.59478000E-01, 0.14478600E+00, 0.26352000E+00, 0.84899400E-01, 0.75553600E-01, -.20916000E-01, -.70997500E-02, 0.64708400E-02, -.72983800E-01, -.76673700E+00, 0.37225500E-01, 0.73988000E-01, 0.29576400E-01, 0.11838100E+00, 0.10745400E+00, 0.77040500E-01, 0.10918100E+00, -.17140500E-02, -.38593500E-01, 0.41183500E-01, -.56883500E+00, 0.22889000E-01, 0.16092900E-01, -.25845100E-01, 0.58663600E-01, -.76847500E-01, -.94751300E-01, 0.47243700E-01, 0.98639300E-02, -.34261200E+00, 0.19297600E+00, 0.61360500E+00, 0.32672800E+00, -.22522100E+00, 0.14133800E+00, 0.36519600E-01, 0.37101600E+00, 0.46336000E-01, 0.61393800E-01, -.15105100E-01, 0.91743600E-01, 0.18383500E-01, -.76123000E+00, -.69087900E-03, -.15153200E+00, -.30462400E-01, -.38789900E-01, 0.10331700E+00, 0.99740200E-01, -.22416000E+00, 0.63126400E-02, -.27624000E-01, 0.23971500E+00, 0.13173700E+00, -.32886200E+00, 0.60505300E-01, -.19696700E+00, 0.17261200E+00, -.30401000E+00, -.17640800E+00, -.25472800E+00, 0.86863400E-02, -.22161500E-01, 0.73061500E-01, -.11661600E+00, 0.30921700E+00, -.49512500E-01, -.49570800E+00, 0.13810800E-01, 0.15070400E+00, 0.17807500E+00, -.29882900E+00, -.27475800E+00, 0.42970100E+00, -.16420700E+00, 0.63409600E-01, -.25787900E+00, -.49088600E+00, -.13688200E+00, -.13647600E+00, 0.10070000E+00, -.42899300E-01, -.12639800E-01, -.70051100E-01, -.13142000E+00, 0.41786500E+00, 0.37127500E+00, -.27658800E+00, -.44197900E-01, 0.87476600E-01, -.25473400E+00, -.93910700E-01, -.11775800E-01, 0.36186100E-01, -.69402700E-02, 0.18074000E+00, -.18578800E-01, 0.91294800E-04, 0.26261200E+00, 0.85664100E-01, -.23399100E+00, -.38574000E+00, 0.15390300E+00, 0.94307900E+00, -.32343300E-01, 0.39437700E+00, -.73798300E-01, -.16720100E+00, 0.81113500E-01, -.53080000E+00, 0.28930100E+00, 0.62229500E-01, -.51590700E+00, -.89104600E-01, 0.22065100E-01, -.54457900E+00, 0.30210000E-01, 0.12026700E-01, 0.26192900E+00, -.14662600E+00, 0.52881900E-01, -.43652900E-01, 0.69459200E+00, 0.18805500E+00, 0.63420400E-01, 0.58396200E-01, 0.13943400E+01, 0.22567300E-01, 0.55928100E+00, 0.32444400E-01, -.55678900E-01, -.52125000E+00, -.48251300E+00, 0.13967200E-01, 0.36782700E+00, 0.18168700E-01, -.23308900E-01, 0.77328100E-01, 0.36055300E-01, -.10526500E+00, 0.23985300E+00, 0.13126200E+00, -.25751800E-01, -.16370100E+00, 0.62142800E+00, 0.22429100E+01, 0.27784300E-01, -.25981300E+00, 0.12341800E+00, 0.84301400E+00, 0.90609700E+00, -.48673900E+00, 0.33490800E+00, -.98080900E-01, 0.34616700E+00, 0.13961500E-01, -.56350000E-01, 0.37023100E-01, -.14794200E+00, -.21361200E+00, -.28317000E-01, 0.19825700E+00, -.78234300E-01, 0.57105900E+00, 0.17163200E+01, -.15829800E+03, 0.47940200E+02, -.84196100E+02, 0.38609600E+03, -.19370900E+03, -.84709400E+02, -.19281800E+03, -.11064400E+03, -.38151300E+01, -.11517200E+03, -.28871100E+02, -.17760900E+03, -.26389000E+02, -.42667800E+03, 0.18648600E+03, -.94424000E+02, -.91048000E+02, -.93305600E+02, -.85899300E+01, 0.47721300E+02, -.10632500E+03, -.76541800E+02, -.33186800E+03, 0.74139400E+02, 0.16841100E+02, 0.17900100E+03, -.88667600E+02, -.58216400E+02, -.89353900E+02, 0.82068100E+02, -.12499600E+03, 0.68733700E+02, 0.92999200E+02, -.43679600E+02, -.10189100E+03, -.86281000E+02, 0.65600400E+02, -.44270300E+02, -.13864000E+03, -.32286600E+02, 0.35196000E+02, 0.13516600E+03, -.10983900E+03, -.48634700E+02, -.22694000E+03, 0.14330100E+03, 0.21260300E+02, -.65901700E+02, 0.33853900E+02, -.51215900E+01, 0.33365300E+02, 0.12626500E+03, -.15941400E+03, 0.93546100E+02, -.49320400E+02, -.28743600E+02, -.10519400E+03, -.32310300E+02, -.19041600E+02, 0.10264600E+02, 0.22863900E+01, 0.10219500E+02, 0.31202600E+01, -.53910000E+02, 0.24230200E+02, 0.55834200E+02, 0.56190500E+02, -.52716500E+02, 0.11364200E+03, -.21237900E+03, 0.10569200E+03, -.22105500E+02, 0.10645500E+03, -.22513000E+02, -.42020700E+02, 0.12725500E+03, 0.62529700E+02, 0.20791400E+03, -.48027200E+02, 0.72327000E+02, 0.11624700E+02, 0.14446100E+01, -.90561300E+01, 0.12319000E+02, -.34057900E+00, 0.14291200E+01, -.27527700E+01, -.22778900E+00, 0.41805700E+01, 0.28089500E+01, -.72665200E+01, -.18984600E+02, 0.27066600E+01, 0.45543000E+01, -.19258700E+02, -.28519900E+00, -.42748500E+01, 0.19910000E+02, -.90640000E+01, 0.74665500E+00, -.62084700E+02, -.82790700E+02, 0.11256100E+02, 0.17086200E+02, 0.13501000E+02, -.73889100E+01 },
        { -.17954300E+01, -.13935800E+01, -.12503100E+00, 0.80119800E+00, -.29347100E+00, -.21055000E+01, -.16501900E+01, -.34599400E+00, -.13456700E+01, 0.13495600E+01, 0.37482200E-01, -.14536800E+00, -.76963200E+00, 0.12227800E+01, -.27086100E+01, 0.41226200E+00, 0.54963800E+00, -.58004200E+00, 0.41073600E+00, -.16514000E+01, 0.40771200E+00, 0.10158200E+00, -.79200200E-01, -.28386000E+00, 0.12825700E+01, 0.32938600E-01, -.71581400E-01, -.75076300E+00, -.20159000E+00, -.25424000E+00, 0.14395300E+00, 0.29987300E+00, 0.74330900E+00, -.26579900E+00, 0.10410100E+00, -.12381200E+00, -.25819400E-01, -.36350100E+00, 0.31356400E+00, -.83617300E+00, -.53000800E-01, -.27461200E+00, 0.98622700E-01, 0.74001200E+00, -.23883200E+00, -.59125700E-01, 0.48714600E-01, -.15626000E-02, 0.54188000E-01, -.10354100E+00, 0.52588000E+00, -.17660500E-01, -.17806800E+00, -.23461700E+00, -.40845800E+00, -.18737600E+00, -.13162300E+00, 0.72650800E-01, -.12282400E-02, 0.15354700E+00, -.20417300E+00, -.32386500E+00, -.16859900E+00, -.15749700E+00, 0.19592000E+00, -.11722000E-01, -.43815700E+00, -.69704200E-01, 0.99361400E-01, 0.32266200E-01, 0.29962500E+00, -.15561700E+00, 0.55973900E+00, 0.11823600E-01, 0.39168700E+00, -.13542700E+00, 0.83843600E-02, 0.40765300E-01, 0.84536200E-01, 0.11472000E+00, 0.10738800E-01, -.15471400E+00, 0.17500100E+00, -.15123500E+00, -.11493500E+00, -.25517500E-01, 0.23926000E-01, -.97712800E+00, -.17924100E+01, 0.70307100E+00, -.52961000E+00, -.16142600E-02, -.10839200E+00, -.19257400E-01, -.18817000E+00, 0.10191700E+01, -.25565100E+00, -.29152500E+00, 0.55704800E-01, 0.27488600E-01, 0.55555400E-02, 0.80734600E-01, 0.17039900E+00, 0.22601900E+00, 0.92456700E-01, 0.88734400E-01, -.17717800E+00, 0.46436000E-01, 0.41744300E+00, 0.48689900E-01, -.39097400E+00, 0.99838700E-01, -.91989300E-01, 0.78016200E-01, -.27256500E-01, -.16414400E+00, 0.18337100E+00, -.40725000E-01, -.20052700E+00, 0.17544600E+00, -.13540400E+00, 0.67795400E+00, 0.11419600E+00, -.20372500E+00, -.15276800E-01, -.97241900E-01, 0.67915700E-01, -.17787400E-01, -.88227900E+00, -.74584000E-02, -.64236300E+00, 0.48136000E+00, -.99231400E+00, -.90294700E-02, -.55057300E-01, 0.39301300E-02, 0.32354900E+00, 0.14852900E+00, -.19746800E-01, 0.19512100E+01, 0.46245200E-01, -.13138900E+00, -.35092800E+00, 0.99610800E-02, -.12373400E-01, 0.52231500E-01, -.27469800E-02, 0.81860500E-01, 0.38077800E-01, 0.42403100E+00, 0.58948000E-01, 0.13451000E+00, 0.74025400E+00, -.26237300E+00, 0.38336600E-01, 0.15806500E+00, -.90497300E+00, -.23083500E-02, -.58221100E+00, 0.22192000E+00, -.30220300E-02, -.31341400E+00, 0.38906900E+00, -.65288800E-02, 0.22013500E+00, -.30123400E-01, -.30620100E+00, 0.52892400E+00, 0.24197600E-01, -.19419400E-01, -.82229500E-01, 0.46227300E+00, -.93125600E-02, -.21883200E+00, 0.66363800E+00, 0.21020200E+00, 0.21367900E-01, -.22435100E+00, -.11837200E+00, 0.60972600E+00, -.16386500E+01, -.24679900E-01, -.18996300E+00, -.34039900E+00, -.61193500E+00, 0.47964200E-01, 0.98669500E-02, -.16522200E+00, 0.77269200E-01, -.25244500E+00, -.11338800E-01, 0.17170000E-01, -.50306000E-02, 0.45160800E+00, -.56010600E+00, -.45852500E+00, 0.13803000E+02, -.61383100E+02, -.65218500E+02, 0.31552700E+02, 0.46119600E+02, 0.32162700E+02, -.63991700E+01, -.11322200E+02, 0.23083400E+02, -.48769400E+02, 0.33351100E+02, -.18846700E+02, -.15776000E+03, 0.13910900E+01, -.34444500E+01, -.56310000E+01, -.10758500E+01, -.68561800E+01, -.25081200E+02, 0.25846100E+02, -.12366500E+02, 0.66580000E+01, -.17416400E+02, -.46340800E+02, 0.96404100E+02, -.48347900E+02, -.42451700E+02, -.48053100E+02, -.13139100E+02, -.10497800E+03, 0.27027000E+02, 0.31676200E+02, 0.26503300E+02, -.10277600E+03, -.67109900E+02, 0.34751200E+02, -.27807100E+02, -.78996300E+02, -.15217100E+02, 0.24093300E+02, 0.76335100E+02, -.56366500E+02, -.13459200E+02, -.35561100E+02, 0.71680700E+02, -.41303300E+01, 0.93620500E+00, -.15217700E+01, -.29183900E+01, -.50251600E+00, 0.24405400E+01, -.12179900E+03, 0.47531700E+02, -.24789700E+02, 0.60257200E+02, -.96016300E+02, -.71444800E+01, -.89112400E+01, 0.41788000E+01, 0.19625100E+02, 0.44697000E+01, 0.17084200E+00, -.87385600E+01, -.10654700E+02, 0.35603500E+01, 0.17477500E+02, -.79586700E+01, 0.55251600E+02, -.14706500E+03, 0.76834300E+02, 0.64659300E+02, 0.73903000E+02, -.34070300E+02, -.87230900E+01, 0.39060900E+02, 0.10096200E+02, 0.61078400E+02, -.53504700E+01, 0.62574200E+02, 0.84294800E+01, 0.21264000E+01, -.39436100E+00, 0.37058600E+01, -.35567200E+01, -.23520900E+01, -.48834400E+00, -.39516800E+00, -.24008000E+00, 0.26482100E+01, -.28794700E+01, -.31354700E+01, 0.12792000E+01, 0.92942100E+00, -.45353900E+01, 0.39728700E+01, -.42618500E+01, 0.49815900E+01, -.12436800E+01, -.55912600E+01, -.61865100E+00, -.45871200E+02, 0.14644800E+01, 0.95773200E+01, 0.20982500E+01, 0.36831400E+01 },
        { -.64510000E+01, 0.49207300E+01, 0.69799900E+00, 0.26849700E+01, -.91907600E+00, -.66576000E+01, -.13204100E+01, -.68134200E+01, -.23903800E+01, 0.40379200E+01, 0.72842400E+00, -.17041700E+00, 0.10469600E+01, -.68187300E+01, -.13618900E+01, -.23781200E+01, -.78258800E-01, 0.35274300E+00, 0.12457300E+01, -.28348100E+01, 0.47791900E+00, 0.71190700E-01, 0.14150600E+00, -.80519900E+00, 0.42909800E+01, 0.18776900E+00, 0.18793900E+01, 0.62028300E+00, -.18876100E+01, 0.92888700E+00, -.19521300E+00, -.44581300E-02, 0.10215600E+01, 0.61161200E-01, -.81141500E-01, -.47382200E+00, -.98054800E-01, -.35989700E+00, -.17948400E+01, -.87673600E+01, 0.41938100E+00, 0.40748900E+00, 0.62494400E+00, -.33968000E+00, 0.43010000E+00, -.65430200E-01, 0.42224900E+00, 0.63121400E-01, -.22908900E+00, -.35943500E+00, -.20428000E+01, 0.34873200E+00, 0.22454000E+00, 0.10923400E+01, 0.59428000E+00, -.66948800E+00, 0.12244900E+00, -.30991100E+00, 0.13587700E+00, -.44056500E+00, 0.55805700E+00, -.68699700E+00, -.36823500E+00, -.85094300E-01, -.46020800E+00, 0.18178900E-01, 0.20201800E+00, -.46660900E-01, -.39959500E+00, -.62628000E-01, 0.16069300E+00, 0.30260100E+00, 0.45507100E+00, 0.12848200E-01, -.11904600E+01, 0.33202600E+00, -.69450600E+00, -.16255300E+00, 0.24742300E+00, -.67775200E+00, -.92836200E-01, 0.61611400E+00, 0.13826300E+01, 0.25363800E+00, -.19442900E+01, 0.24100700E+00, -.24733500E+01, 0.18659100E+01, -.15049100E+01, -.35944400E+00, -.66406500E+00, 0.84157100E-01, -.94505700E-01, -.55180400E+00, 0.15183500E+00, 0.20532800E+01, -.61970500E+00, 0.20335000E-01, -.18558200E+00, -.22933300E+00, -.11156700E-01, 0.15154800E+00, -.27913300E+00, 0.88194000E+00, -.10044500E+01, 0.39528100E+00, 0.44919900E+00, -.64506300E+00, -.11202700E+01, -.36872300E+00, 0.12079600E+01, -.27413200E+00, -.47931700E-01, 0.24713900E+00, 0.66318100E+00, -.11064300E+01, 0.16726300E+01, 0.25205100E-01, -.36623900E+00, -.26606800E+00, -.94551900E-01, -.51475100E+00, 0.42277200E-01, -.58120500E+00, -.18031100E-01, -.56323300E+00, -.87333500E-01, 0.21023800E+01, -.95165700E+00, -.44841700E+00, -.93659500E+00, 0.27573300E+01, -.81120700E+00, -.58439100E-02, -.82527700E-01, -.50074400E-02, 0.44806700E+00, 0.30201200E+00, -.12790900E+00, 0.13927800E+01, 0.11777800E+01, 0.57743100E+00, 0.90421800E+00, 0.58129200E+00, 0.28992900E+00, -.15985200E+01, -.33019900E-01, -.34140100E+00, 0.91172900E-01, -.36360800E+00, -.56228100E+00, -.64505700E+00, -.19701700E+01, -.65472400E-01, 0.36700800E-01, 0.20655000E+00, 0.54833400E+00, 0.49757700E-01, -.55040500E+00, -.65395600E+00, 0.27819200E-01, 0.63301400E+00, 0.10675000E+00, 0.18565200E+00, -.54434600E+00, 0.23360800E+00, -.66566900E+00, -.11650200E+01, 0.40754700E-01, -.10303100E+00, -.53072000E-01, 0.67528700E+00, -.37735000E+00, -.19848000E+00, -.91401300E+00, 0.13861700E+01, -.94959100E-02, -.94949700E-01, 0.77996000E-01, 0.68645900E+00, -.39069600E+01, 0.28896700E+00, -.68503600E+00, -.10294500E+01, 0.82129500E+00, 0.27782800E-01, -.52354500E+00, 0.14907600E+01, 0.29667600E+00, -.10917000E+01, -.10996900E+00, -.97269000E+00, -.67657000E+00, -.19962300E+01, 0.20528600E+01, 0.76782500E+00, 0.33664100E+00, 0.23354900E+03, 0.19650600E+03, -.99809000E+02, -.10834000E+03, -.94252400E+02, 0.10022800E+03, 0.56684800E+02, -.14768400E+03, 0.12033100E+03, -.18827700E+03, 0.95981500E+02, 0.52140000E+03, 0.30320000E+03, -.15165500E+03, -.75602500E+02, -.14856900E+03, -.46535300E+02, 0.77562900E+02, -.11625100E+03, 0.80577500E+02, -.24783300E+03, 0.48922200E+02, 0.20175300E+03, -.16188200E+03, 0.82501300E+02, 0.62761600E+02, 0.80122400E+02, 0.62297100E+02, 0.17747400E+03, -.49377000E+02, -.40058600E+02, -.59758400E+02, 0.15689900E+03, -.42025600E+02, 0.54502100E+02, -.28085400E+02, 0.37708200E+02, -.35693300E+02, 0.19112600E+01, 0.10630600E+02, -.41996700E+02, -.32665800E+02, -.71626200E+02, 0.12199300E+02, 0.14803800E+03, -.87415500E+02, 0.47353100E+02, -.34644100E+02, 0.44797700E+02, 0.36170800E+02, 0.21546100E+03, -.75896200E+02, 0.49307500E+02, -.71732100E+02, 0.13639900E+03, -.10444300E+03, 0.26315300E+02, -.11944200E+02, 0.32233800E+01, -.11630300E+02, 0.41372300E+02, 0.47890300E+02, -.97196000E+01, -.19138100E+02, -.50186800E+02, 0.48515700E+02, -.11514100E+03, 0.27766500E+03, -.13716600E+03, -.11956800E+03, -.14148700E+03, 0.31465200E+02, -.24528400E+02, -.30760300E+02, -.42748700E+01, -.85789800E+02, -.79569500E+01, -.20220100E+03, -.12321700E+02, -.14282400E+02, -.27820200E+01, -.74628600E+01, 0.83625100E-01, 0.11789400E+02, 0.46455600E+01, -.16221500E+01, 0.18343200E+00, -.64609900E+01, 0.19311700E+01, 0.34378500E+02, 0.91897200E+00, 0.25757400E+01, 0.40295600E+02, -.50605900E+01, 0.83194200E+01, -.73382000E+01, 0.29167300E+02, 0.24519200E+02, -.25595000E+02, 0.94726200E+02, -.36761500E+02, -.21644400E+02, -.30744400E+01, -.28834600E+01 },
        { 0.49733700E+01, -.34067200E+01, -.55704900E+00, -.17102800E+00, 0.16698700E+01, 0.21573100E+01, 0.24423900E+01, 0.11159400E+01, 0.19771600E+01, -.33869100E+01, -.69160900E+00, -.65191200E-01, -.13410400E+01, 0.23956600E+01, 0.87309000E+00, -.96121200E+00, 0.39290000E+00, 0.56285700E+00, -.40282400E+00, 0.78078300E+00, -.31756000E+00, -.26015600E+00, -.21794000E+00, 0.13374600E+00, -.52211500E+00, -.60807900E-02, 0.58242200E-01, 0.42305300E+00, 0.40735700E+00, -.20547500E-01, 0.15646300E-01, 0.17491300E+00, -.97759100E+00, -.28329900E+00, 0.38921900E+00, 0.33627700E+00, 0.63332900E-01, -.29398200E-01, 0.84416000E+00, 0.30482400E+01, -.16206000E+00, -.50145100E-01, -.19180300E+00, -.65166400E+00, -.10269500E+00, 0.13314300E+00, 0.23307300E+00, -.31644800E-01, -.92571900E-02, -.26202000E+00, -.14141100E+01, -.46906600E-01, 0.22136200E+00, 0.15101200E+00, 0.68740300E+00, -.37177400E+00, 0.56289100E+00, -.21768200E+00, -.78119300E-01, 0.72528200E+00, -.60346200E+00, -.25870800E+01, -.17777000E+01, 0.97050000E+00, -.54987300E+00, -.15644700E-01, -.13675400E+01, 0.17871500E-01, -.47280000E+00, 0.72582900E-01, -.10634300E+00, 0.49148400E+00, 0.13973800E+01, 0.49094000E+00, 0.71989000E+00, -.12944700E+01, 0.23759700E+00, -.95602200E+00, -.38274900E+00, 0.14519700E+00, 0.53652300E-01, -.20896600E+00, -.61292900E+00, -.52716700E+00, -.58734200E-01, -.63191200E+00, -.41012800E+00, -.44202100E+00, -.21813300E+00, 0.74155000E+00, -.46904100E+00, -.43849100E-01, -.61649600E-01, -.31773700E+00, -.19858500E+00, -.30803200E+00, -.12596600E+00, -.51356600E+00, -.21800100E+00, 0.78107000E-01, -.24294600E-01, -.58893400E+00, 0.85201000E+00, 0.76489000E-01, 0.38476800E+00, -.35892700E+00, 0.15032800E+00, -.34282800E+00, 0.16087400E+01, 0.18356400E+00, -.10034200E+01, 0.20859600E+00, -.25079400E+00, -.46762900E+00, -.13097800E+00, 0.49462200E+00, -.91632800E+00, -.83319300E+00, -.34193500E-01, 0.26643500E+00, -.46752300E+00, -.28974200E+00, 0.55957600E-01, -.13535300E+00, 0.99013900E-02, 0.54410400E-01, 0.43032900E-01, 0.38028700E+00, -.60670300E+00, 0.49687900E+00, -.19590300E+01, 0.24426400E+00, -.22989400E+01, -.21462000E-01, 0.86166900E-02, 0.11516500E-01, 0.19468700E+01, -.26504300E+00, 0.70673400E-01, 0.55026800E+01, 0.10711400E+01, 0.17897900E+01, 0.82335000E+00, -.41265000E+00, -.62450800E-01, 0.12078800E+01, -.12546300E-01, -.29666300E+00, -.35304300E+00, 0.96947900E+00, -.17328100E+00, -.96449800E+00, -.41037200E+00, 0.41725300E+00, -.97748600E-01, 0.16662200E+00, 0.33873300E+00, 0.41164900E-01, 0.13062300E+01, -.14805500E+01, 0.45789000E-01, -.49801800E+00, -.50195400E+00, 0.91519000E-01, -.51252300E+00, -.33920600E+00, -.19673300E+00, 0.14000100E+01, 0.83151500E-01, -.16229700E+00, -.28101000E+00, 0.21638800E+00, 0.95026600E-01, -.37237500E+00, 0.28806100E+00, -.34472900E+01, 0.29619800E+00, 0.75178900E+00, 0.90362200E-01, -.11448500E+00, 0.96854900E+00, 0.60650300E+00, 0.56046100E+00, 0.12069100E+00, -.70552000E+00, 0.13835700E+00, 0.32542600E+00, -.13356600E+01, -.32547200E+00, 0.35506200E+00, 0.58229200E-01, -.71652400E+00, 0.11734400E+00, -.73005200E+00, -.22281100E+01, -.82233600E+00, -.82000400E+00, 0.25100700E+00, -.47362900E+03, 0.23616700E+03, 0.10663500E+03, 0.23529900E+03, 0.77110300E+02, -.13514100E+02, 0.21009700E+03, -.26306900E+01, 0.23487500E+03, -.97871800E+01, -.91027500E+01, -.27283800E+03, 0.13412900E+03, 0.13435700E+03, 0.13513300E+03, 0.43409000E+02, -.64177000E+02, 0.79483100E+02, -.16991500E+02, 0.32900400E+03, -.70332600E+02, -.16768000E+03, -.28479400E+03, 0.14160200E+03, 0.16085900E+03, 0.14284100E+03, 0.77311400E+01, -.53683900E+01, 0.32875100E+02, -.82620300E+02, 0.20092400E+03, -.31909600E+02, -.21904000E+03, 0.78913000E+02, -.49809500E+02, 0.36295400E+02, -.35089200E+02, -.91620500E+01, -.16648300E+02, 0.15238000E+02, 0.50183200E+02, 0.43055200E+02, -.18962700E+02, -.28502100E+02, -.17815600E+03, 0.87284900E+02, 0.13817200E+03, 0.88909400E+02, -.49070500E+01, 0.20470100E+00, 0.60188600E+02, -.40108600E+01, 0.26250400E+03, -.31109100E+02, -.34569300E+03, 0.71065300E+02, -.34871300E+02, -.85899800E+01, -.35701100E+02, -.27979700E+02, -.17867500E+02, -.88554200E+01, 0.10471800E+02, -.28828600E+02, -.13634100E+02, -.63298700E+01, -.84910900E+02, 0.46979500E+02, 0.15834000E+03, 0.43725700E+02, -.77097000E+02, -.64912100E+02, 0.77169400E+02, 0.34810500E+02, -.80680700E+01, -.29256100E+02, 0.10799000E+03, 0.15245500E+02, 0.91678500E+01, 0.88759800E+01, -.33867600E+01, -.10660000E+02, -.39279700E+01, -.89215700E-01, 0.46241200E+01, -.51504500E+01, 0.16969000E+01, 0.44092200E+01, 0.11294500E+01, 0.23817300E+00, -.24352800E+01, -.35701400E+01, 0.11847500E+02, -.10822000E+02, -.81742400E+01, 0.15600500E+01, -.17110600E+02, 0.55800100E+02, 0.17597100E+02, 0.31973900E+01, -.34773600E+01, -.54131500E+01, 0.10691300E+02 },
        { 0.78594300E+01, 0.11764400E+02, 0.15399000E+01, 0.49224200E+01, 0.10761100E+01, -.92782700E+00, 0.12498900E+02, -.21519900E-01, 0.56208100E+01, -.83915100E+01, -.19231100E+00, 0.50554600E+00, 0.13444600E+01, -.80694700E+01, 0.27125500E+01, -.84215300E-01, -.15000600E+01, -.26037900E+01, 0.84355400E+00, 0.22542200E+01, 0.77804000E+00, -.50858800E+00, 0.53930200E+00, -.10085900E+01, 0.89683300E+01, 0.22246300E-01, 0.19400100E+01, 0.11952100E+01, -.88544900E+00, -.29472300E+01, 0.13852900E+01, -.93485500E+00, 0.63739300E+00, -.14080600E+00, -.37485700E+00, 0.45101000E+00, -.30592200E+00, 0.19900100E+01, -.56020100E-02, 0.95828700E+01, 0.56186300E+00, 0.61658500E+00, -.20039700E+01, -.83091700E+00, 0.26685500E+00, 0.17819500E+00, -.14898600E+01, 0.17249800E-01, -.75159400E-01, 0.48414900E+00, -.89891300E+00, -.11237200E+01, -.14106800E+00, -.25706100E+00, -.69341700E+00, 0.12165000E+00, -.73077900E+00, 0.49467900E+00, -.92641800E-02, -.99516700E+00, 0.24555900E+01, 0.73340100E+01, 0.36661700E+01, -.15694300E+01, -.82777900E+00, -.19439200E+00, -.12211500E+01, 0.11227100E+00, 0.46068300E-01, -.44608800E-01, -.47581100E+00, -.12137500E+00, 0.85151300E+00, -.70103100E+00, -.18253800E+00, 0.16140100E+01, -.63688800E+00, 0.36745700E+00, 0.39204800E-01, 0.51154200E+00, -.18834900E+00, 0.47226300E+00, 0.13491700E+01, 0.46456400E+00, -.17082600E+01, -.27524400E+00, -.41301900E-02, 0.69101600E+00, -.74208500E+00, -.10989400E+00, 0.23647800E+01, 0.23823900E-01, 0.25155100E+00, 0.94775800E+00, -.34232800E-01, -.54894100E+00, -.18236000E+00, -.15139900E+01, 0.21113100E-01, -.21843500E-01, -.51034100E+00, 0.66813700E-01, -.10942500E+01, -.24644400E+00, -.15609200E+00, -.31019700E+00, -.52893100E+00, -.58005700E+00, -.11250500E+00, -.16452800E+00, -.34711700E+00, -.70556100E+00, -.13853300E+00, -.34302500E+00, -.86037200E-01, 0.26028600E+01, 0.26720700E+01, -.24454900E+01, 0.51725500E-01, -.11849900E+00, -.55920900E+00, 0.72644600E-01, -.90817600E-02, -.29024400E+00, -.65881700E-01, 0.51122900E+00, -.21852000E+00, -.36111600E+00, -.49175600E+00, -.57730200E+00, 0.17628300E+01, -.33228700E+01, 0.10294000E+01, -.80005500E-02, 0.59500900E+00, 0.13766900E-01, -.20171100E+01, 0.73065100E+00, -.32578900E+00, -.46366500E+00, 0.58132700E+00, -.10633100E+00, -.40413800E+00, 0.11410200E+00, -.10346300E+00, -.21793400E+00, 0.44821600E-01, 0.66283500E-02, 0.30866800E+00, -.56067900E+00, -.10129600E+00, 0.20808900E+00, -.60576000E-01, -.14392900E+00, -.10201700E-02, -.44389700E+00, -.75271200E+00, -.41452400E-01, 0.77508500E+00, -.15828600E+00, -.13395100E+00, -.86246800E-01, -.14430800E+01, 0.11200300E+00, 0.83896200E+00, 0.64792500E-01, -.54521200E+00, 0.18290000E+00, 0.81522600E-01, -.10309300E+00, -.17975500E+00, -.12800000E+00, -.37103400E+00, 0.52228800E+00, 0.19207600E+00, 0.56083400E+00, -.19247200E+00, -.69810200E+00, 0.55391800E+00, -.18230300E+00, 0.33904000E+01, 0.81704800E-01, -.15978000E+01, -.78122300E+00, 0.56837900E+00, 0.72462000E-01, -.55160400E+00, 0.35615800E+00, 0.11674500E+00, -.14465400E+00, -.36132100E-01, -.34621500E+00, -.13139000E+00, -.73972500E+00, -.26149400E+00, -.90064700E-01, 0.46822500E+00, 0.48578900E+00, 0.52337200E+00, 0.89858500E+01, -.53481400E+01, 0.12871800E+01, -.13359500E+02, 0.12125100E+02, -.86971600E+02, -.16796100E+02, -.30318900E+02, 0.17977600E+01, 0.69210000E+02, 0.17445500E+03, -.81000500E+02, -.80664100E+02, -.86363400E+02, -.27874900E+02, 0.17912900E+02, -.29779500E+02, 0.51742400E+02, -.10626700E+03, 0.12769500E+02, 0.17200400E+02, -.68594500E+01, 0.39629300E+01, -.10667800E+02, 0.32219400E+01, -.34133400E+02, 0.65896000E+02, -.19119700E+02, -.17924300E+02, -.84043300E+02, 0.76949900E+02, 0.19161900E+03, -.11634900E+03, 0.83511400E+02, 0.22076000E+02, 0.54500700E+02, 0.41802000E+01, -.17100300E+02, 0.30843100E+02, -.12800200E+02, 0.23099400E+02, -.10888300E+02, 0.22386800E+02, -.46378800E+02, 0.27444100E+02, -.76807600E+01, 0.23658300E+02, -.32662600E+02, 0.89529100E+02, -.26152000E+02, -.16196100E+02, -.10230300E+03, 0.94178000E+02, 0.25228600E+03, -.23346500E+02, 0.14298000E+02, 0.58938900E+01, 0.12342100E+02, -.45287900E+01, -.19307700E+01, 0.41793700E+02, 0.76435100E+01, 0.36493700E+01, 0.13682300E+01, -.58870900E+01, -.34267100E+01, -.32830900E+01, -.49891800E+02, 0.10445000E+01, 0.61565900E+02, 0.51090600E+02, -.66711500E+02, -.57566300E+02, -.11112000E+02, 0.33716400E+02, -.85202900E+01, -.32974700E+01, -.44496000E+01, -.24770300E+01, -.18968700E+00, 0.84326500E+01, 0.20990100E+01, 0.20504500E+01, 0.83604500E+00, 0.11916800E+00, -.25636700E+01, 0.12755800E+01, 0.20097900E+01, 0.74119400E+00, -.17043500E+00, 0.42123500E+01, -.41084900E+01, 0.39435800E+01, -.34067700E+00, 0.33057700E+01, 0.61425700E+01, -.11867700E+02, 0.21693000E+02, -.38216000E+01, -.52873100E+01, 0.21222900E+01, -.24195100E+01 },
        { -.23035400E+01, -.14093700E+01, -.88477600E-01, -.60584700E+00, -.15189000E+01, 0.80695500E+00, -.26930800E+01, 0.24745000E+01, -.16256500E+01, 0.18829400E+01, 0.39197700E-01, -.16533300E+00, 0.70775500E+00, 0.15629200E+01, 0.27724600E+01, 0.17619000E+01, -.72147100E+00, 0.12568200E+01, -.17034600E+01, 0.11133900E+01, -.37838900E+00, 0.53023400E-01, -.13689700E+00, 0.41263500E+00, -.25119500E+01, -.34578300E-01, -.52399800E+00, 0.74223300E+00, -.23554000E+00, 0.83858500E+00, -.49185400E+00, -.41810000E+00, -.30009100E+00, -.62544100E-01, 0.17406900E+00, -.21224900E+00, 0.33776800E-01, -.21502200E+00, 0.28813400E+00, -.25488800E+00, -.12064600E+00, -.27572600E+00, 0.25316700E+00, 0.29784500E+00, -.20611800E+00, 0.27857800E+00, 0.98772700E-01, -.48608300E-01, 0.58026700E-01, -.31630100E+00, -.24464700E+00, 0.11061500E+00, 0.32013500E+00, 0.12270500E+00, 0.49197200E+00, -.59923600E+00, 0.58668900E+00, -.65934500E-01, -.10701200E+00, 0.48091800E-01, -.43417500E+00, -.43672500E+00, -.31379900E+00, -.31829600E+00, 0.38070600E+00, -.13445600E+00, -.82116300E+00, -.47776600E-01, -.11145900E+00, 0.22407900E-02, 0.22693600E-01, 0.32799400E+00, -.42659100E+00, 0.33644200E+00, 0.33305200E+00, -.57474000E+00, -.25618300E-03, 0.63281100E-01, 0.88621900E-01, -.98490000E-01, 0.77989200E-01, -.13797700E+00, 0.30814500E+00, -.16583800E+00, -.99048400E+00, -.39323100E+00, -.14134000E+00, -.88354200E+00, -.72730800E+00, 0.84071500E+00, 0.45059000E+00, -.34575700E-01, -.51951500E-01, 0.51566600E+00, -.27622000E+00, 0.10803400E+00, 0.13238000E+00, -.34649300E+00, 0.10361900E+00, 0.70538700E-01, 0.51990700E-01, -.31509500E+00, 0.28597700E+00, -.96575200E-01, 0.53493200E+00, -.23766100E+00, -.70561900E+00, 0.45749700E-01, 0.12797900E+01, 0.79618100E-01, -.92022700E+00, 0.17117600E-01, -.20392300E+00, -.38188800E+00, -.29698600E+00, 0.15297900E+01, 0.13173400E+01, -.12377700E+01, -.94567900E-01, 0.20607400E+00, -.25096900E+00, -.62769400E-01, 0.16497200E+00, -.20984400E+00, -.28209100E-01, -.46866500E-01, 0.31095600E-01, 0.27010100E+00, -.33701900E+00, -.10829400E+00, -.35217100E+00, -.31028700E+00, -.10882300E-01, -.78834900E-02, 0.24247300E-01, -.19239300E-02, 0.72788300E+00, -.30732300E+00, 0.23896200E+00, 0.49494500E+00, -.13546600E+00, 0.45340900E+00, -.12321600E+00, -.87112400E-01, -.31030500E-01, 0.28454200E+00, -.53476500E-01, -.66012600E-01, -.26019200E+00, -.50712400E-01, -.10237500E+00, 0.35149500E-01, 0.45136900E-01, -.11815400E+00, 0.81943400E-01, 0.31397400E-01, -.22524000E+00, 0.27981100E-02, -.14525800E+00, 0.24639400E+00, -.87266100E-01, 0.30423600E-01, 0.18797600E+00, -.15932800E-01, -.97205300E-01, 0.12030300E+00, -.46559400E+00, 0.36489400E+00, 0.11722100E+00, -.41790500E-01, -.99846000E-01, 0.10650800E+00, -.16368100E-01, 0.55137500E-02, 0.38370000E+00, -.12048800E+00, 0.33871500E-02, -.22404800E+00, -.16786200E+00, 0.67113800E+00, 0.81020300E+00, 0.49976500E-01, 0.19538900E+00, -.18883800E+00, 0.27155800E+00, -.97858700E-01, -.42868200E-01, -.63992300E+00, -.17269200E+00, -.78229300E-01, 0.22288700E-01, -.32827500E+00, 0.76682500E-01, -.53907000E+00, 0.71699900E+00, 0.68876500E-01, 0.73713800E+00, 0.13711900E+00, -.33648700E+00, 0.21163000E+00, -.69245500E+02, 0.27939000E+00, -.74305500E+01, 0.16987000E+01, 0.73720700E+02, 0.57337500E+02, 0.43510400E+02, 0.55782500E+01, -.57592000E+02, -.14382600E+03, 0.73903200E+02, 0.77892600E+02, 0.71875500E+02, 0.12226100E+02, -.11589100E+02, 0.19045400E+02, -.29543500E+02, 0.89984600E+02, -.44601500E+01, -.75023200E+02, -.22883300E+03, 0.11429100E+03, 0.16650800E+03, 0.11453100E+03, 0.43580800E+02, 0.81980500E+02, 0.41698100E+02, -.28495500E+02, 0.99656800E+02, 0.70965900E+02, -.62545000E+02, -.26177500E+02, 0.22570800E+02, 0.79492100E+02, 0.11599100E+02, -.13859600E+02, -.64076700E+02, 0.58735700E+02, 0.30018300E+02, 0.48194600E+02, -.59497200E+02, -.17980000E+02, -.10359800E+03, 0.51986400E+02, 0.12149400E+03, 0.52237100E+02, 0.31703200E+02, 0.10201100E+03, 0.27618300E+02, 0.29378900E+02, 0.81924300E+02, 0.67498300E+02, -.19086000E+03, -.94212000E+01, 0.46916500E+01, 0.50403200E+02, 0.53325100E+01, 0.18713500E+01, 0.48569400E+01, -.83666000E+01, 0.14384100E+02, 0.52400800E+01, 0.87081000E+01, -.13302500E+02, 0.49621600E+02, -.26257300E+02, 0.16777400E+02, -.24522700E+02, -.68688900E+01, -.57973700E+02, 0.64234100E+02, 0.55261100E+02, 0.29150100E+01, -.41038100E+02, 0.20957200E+02, -.37185600E+01, 0.46421600E+01, 0.39313600E+01, -.17688400E+01, -.44138100E+01, 0.86543100E+00, -.11787800E+01, 0.12010300E+01, -.18621900E+01, 0.88935400E-01, 0.36957400E+01, 0.83210700E+01, -.25410200E+01, -.53472600E+00, 0.90202500E+01, -.14356300E+01, 0.19477400E+00, -.38790900E+01, 0.93900500E+01, -.54184200E+01, 0.10066800E+02, 0.34910100E+02, -.63871700E+01, -.84842500E+01, 0.15977400E+01, -.37655000E+01 },
        { 0.79821600E+01, -.40871200E+01, -.42282700E+00, 0.19796300E+01, 0.48429200E+01, -.87281100E+01, 0.11683800E+02, -.10371600E+02, 0.53954100E+01, -.73386700E+01, 0.12781600E+00, 0.63177000E+00, 0.12905700E+00, -.39278400E+01, 0.66460100E+00, -.35074100E+01, 0.79768300E+00, 0.13361800E+01, -.91769900E+00, 0.11911300E+01, 0.12595100E+01, -.43720400E+00, 0.41861300E-01, -.72535500E+00, 0.66233300E+01, -.35280600E+00, 0.23265100E+01, 0.31921100E+01, -.27500800E+01, -.63141300E+00, -.34493400E+00, -.31741400E+00, 0.99166300E+00, -.11687800E+01, 0.52847900E+00, 0.22692600E+00, 0.12186800E+01, 0.21584600E+01, -.18422000E+01, 0.19919900E+02, 0.45249100E+00, 0.66831400E+00, -.19267300E+01, -.70333500E+00, 0.10200700E+01, 0.12343600E+00, -.47344000E+00, -.39892900E-01, -.16370300E+00, 0.47041800E-01, 0.33984800E+01, -.85919800E+00, -.12917300E+01, -.10961200E+01, -.25017400E+01, 0.28155500E-01, -.40728200E+00, 0.23872800E+00, -.33722300E+00, 0.13244800E+01, 0.23753200E+00, -.38800000E+01, -.23079600E+01, -.81152700E+00, 0.18478600E+00, -.26633700E+00, 0.24708200E+00, -.57118300E+00, 0.18347200E+00, -.15170700E+00, -.35350800E+00, 0.22978600E+00, 0.24895300E+01, 0.94499300E-02, -.11893000E+00, -.52724500E-01, 0.25298400E+00, -.59676800E+00, -.44765000E+00, 0.16146400E+01, 0.38995900E-01, 0.23691400E+00, -.10564200E+01, -.40460800E-01, -.10139100E+01, -.78760000E+00, 0.31778300E+01, 0.68684300E+00, 0.28322800E+00, 0.94725400E+00, -.86416800E-01, -.13774400E+00, -.95794900E+00, 0.36243300E+00, 0.12667600E+01, -.11155300E+01, 0.32686000E+00, 0.89033200E+00, -.94133800E-01, -.37950900E+00, -.10020100E+01, -.11765500E+00, 0.55767300E+00, 0.10707200E+00, 0.57004400E+00, 0.36507400E+00, 0.10134200E+01, 0.24885000E+01, -.13642900E+01, 0.34631100E+00, -.11966700E+01, 0.18831900E+00, -.46110000E-01, -.26603600E+00, 0.75438900E+00, -.18485500E+01, -.26294300E+01, 0.47594100E+00, 0.25419400E-01, -.36033000E+00, 0.52640000E+00, -.30552800E+00, -.82565400E-01, -.76367000E+00, -.13428400E+00, 0.81246300E-02, -.10870800E+00, -.25743500E+00, -.53399800E+00, -.66071500E+00, 0.17734300E+01, -.21299500E+00, 0.13832600E+00, 0.19389200E-01, -.68768800E-01, 0.34168400E-01, -.18922200E+01, 0.10180800E+01, -.47972300E+00, -.15310300E+01, 0.10818600E+01, -.15735400E+01, -.22164600E+01, 0.28446500E+00, -.19960000E+00, -.15760500E+01, -.57176600E-01, 0.14232900E+00, 0.82162900E+00, -.76182000E+00, -.27275800E+00, -.45212100E+00, 0.80018300E+00, -.77399900E+00, 0.16150500E+00, -.48826100E+00, 0.52641200E+00, -.99077800E-01, 0.31568600E+00, -.21518200E-01, -.91885500E-01, 0.12772700E+01, 0.46151300E-01, -.40093800E-01, 0.37121300E+00, 0.56633200E+00, -.19933800E+00, 0.17078700E+00, -.24636600E+00, 0.45083000E+00, -.10165100E+00, -.17519600E+01, 0.14620400E+00, 0.50430800E+00, -.40352500E+00, -.16584200E+00, -.12720100E+00, 0.32184700E-01, 0.99297500E-01, -.27302300E+01, -.86946700E+00, 0.12942300E+01, -.28413700E+01, 0.24035700E+00, 0.12984000E+01, 0.31201300E+00, -.25472700E+00, 0.19213300E+00, 0.57071400E-01, 0.64258200E+00, 0.23017600E-01, -.51710000E+00, 0.98744000E-01, -.77885000E+00, -.61342700E+00, -.86827500E+00, 0.15576400E+00, 0.42375300E+00, 0.45885800E+00, 0.12486300E+00, -.16355700E+00, 0.98935000E+01, -.31071200E+01, 0.30359500E+02, -.59020800E+02, -.24574300E+02, -.48428600E+02, 0.25011900E+02, 0.20349700E+02, 0.10094200E+03, -.48569000E+02, -.62089300E+02, -.49020300E+02, 0.14071800E+02, 0.46205700E+02, -.29621600E+02, -.28539100E+02, -.16224900E+03, 0.42581700E+02, -.87775100E+01, -.12387700E+03, 0.62306200E+02, 0.56937500E+02, 0.61231900E+02, 0.98925900E+01, 0.31502000E+02, -.35701500E+02, -.75506200E+02, 0.25497900E+02, 0.11610700E+02, -.96344000E+01, 0.10695200E+02, -.16147900E+01, 0.18630600E+01, -.10213200E+02, -.48939900E+01, -.48488000E+02, 0.50905700E+02, 0.28073300E+02, 0.20192900E+02, -.42629800E+02, -.33620700E+02, -.21437500E+03, 0.10927900E+03, 0.77256900E+02, 0.10665700E+03, 0.15361900E+02, 0.55299400E+02, -.51802200E+02, -.11875000E+03, 0.25862300E+02, 0.32022800E+02, 0.12159000E+02, 0.50326200E+02, -.22011800E+02, -.29669400E+02, -.26194700E+02, -.41462500E+01, -.16720900E+02, 0.25891600E+02, 0.20651900E+02, -.50049100E+02, -.12529200E+02, -.38389500E+02, 0.37802100E+02, -.20825200E+02, -.19555000E+02, -.20678900E+02, 0.16776400E+01, -.28815700E+02, 0.90664800E+01, 0.17253400E+02, 0.12221600E+02, -.12723500E+02, -.39704800E+02, 0.76063700E+01, 0.21902500E+01, -.97951500E+00, -.31175500E+01, 0.13630400E+01, 0.49907500E+01, 0.63436000E+01, 0.19526200E+01, -.18165800E+00, -.54528400E+01, 0.20833300E+01, 0.10554500E+00, 0.30554900E+01, 0.17509800E+01, 0.27736800E+01, 0.16366600E+01, -.16473800E+01, 0.19786600E+01, 0.13000600E+01, 0.70380500E+01, -.21645400E+02, 0.20119800E+02, 0.98472200E+00, -.21035400E+01, -.40115000E+00, -.27716000E+01 },
        { -.47072500E+01, 0.49569600E+01, 0.11363000E+01, -.12573900E+01, -.14550500E+01, 0.36390600E+00, -.16680800E+01, -.89865100E+00, -.92962600E+00, 0.14771200E+01, 0.29461300E-01, -.20213900E+00, -.85757200E+00, -.14447500E+01, 0.36153000E+00, -.24390800E+01, -.54553900E+00, 0.61861900E+00, 0.39203400E+00, 0.34563800E+00, -.10427900E+00, 0.59309200E-01, 0.38102700E-01, -.56181900E-01, -.66030600E+00, 0.99874600E-01, 0.40062800E+00, 0.86360100E+00, -.34324500E+00, 0.81715900E+00, -.76932200E-01, 0.57161800E+00, -.50806100E-01, 0.97293600E+00, -.93172400E-01, 0.48258900E+00, -.21519300E+00, 0.38033100E+00, 0.50375400E+00, -.45564100E+01, 0.67825500E-01, 0.49483000E+00, -.12753400E+01, -.60712400E+00, 0.71439500E+00, -.35483800E-01, -.15787100E+00, 0.21201300E-01, -.85276700E-01, 0.18172700E+00, -.12851700E+01, -.17276300E+00, 0.18804300E+00, 0.71550500E+00, -.62370200E-01, -.10513200E+00, -.28963700E+00, -.11999900E+00, 0.33918100E-01, -.70222400E+00, 0.13034400E+01, 0.47112500E+00, 0.86748100E-01, 0.11463100E+01, 0.65847900E-01, 0.20987900E+00, 0.87053300E+00, 0.40710700E+00, 0.16626900E-01, 0.49275400E-01, 0.20621600E+00, 0.20537100E+00, -.98361000E+00, -.25811500E+00, -.58429600E+00, 0.43339200E+00, -.27566800E-01, -.24286500E-01, -.19858800E+00, 0.98012000E+00, 0.10884600E+00, 0.11656700E+00, -.13910200E+00, 0.21876000E+00, 0.15187100E+00, 0.12105900E+00, -.21077300E+00, 0.18512400E+00, -.36202000E+00, 0.49695500E-01, 0.75738600E+00, 0.76046600E-01, -.43381400E-01, 0.13868300E+00, 0.28790800E+00, 0.43653100E+00, -.49926000E-01, -.11429300E+00, 0.35214600E+00, -.15138500E+00, 0.21518400E+00, 0.22676600E-01, -.68152100E+00, 0.19924600E+00, -.39534400E+00, -.80606200E-01, -.18904300E-01, -.36378900E+00, -.13747900E+01, -.27767900E+00, 0.81713600E+00, -.15232000E+00, 0.21536600E+00, 0.36750600E+00, 0.23139700E+00, -.34864200E+00, 0.11181300E+01, 0.77036100E+00, -.10562800E+00, -.10315100E+00, -.49286700E+00, 0.56259200E+00, 0.20298700E+00, 0.42516600E+00, -.15291200E-01, -.16626300E+00, -.36730100E-02, 0.41856900E+00, 0.70289800E+00, -.18356200E+00, -.16859900E+00, 0.18007800E+01, 0.50783900E+00, 0.43917000E-02, 0.12617600E+00, -.11238900E-01, -.41539300E-01, 0.11507500E+00, -.30287100E+00, -.68516900E+00, -.30040900E+00, 0.40731500E-01, 0.20028600E+00, 0.29491100E+00, 0.12539400E+00, -.75552800E+00, -.33216800E-01, -.80765400E-02, 0.25668300E+00, -.41453300E+00, -.23274500E+00, -.57412400E-01, -.18082100E+01, -.42696600E-01, 0.30175600E-01, 0.10167100E+00, -.15809000E+01, 0.12098100E-01, -.62970700E+00, -.10593800E+01, -.33330800E-01, -.56910500E+00, -.88229000E+00, -.28621700E+00, 0.41705900E+00, 0.59116000E-01, -.90333200E-01, 0.74553100E+00, 0.12259200E-01, 0.73795400E-02, 0.16452600E+00, -.60441400E+00, -.43770000E-01, 0.16881700E+00, 0.11954400E+00, -.19478800E+01, 0.20664100E+00, 0.21188100E+00, -.13357500E+00, -.25084100E-01, 0.18686000E+01, -.37042000E+00, 0.61334600E+00, 0.10388500E+00, 0.90008700E-01, -.86589400E-01, -.14701600E+00, 0.27265900E+00, -.91114300E-01, 0.14344800E+00, 0.25774100E-02, -.86823400E-01, -.19248400E+00, 0.86537600E+00, -.21434800E+01, -.10487800E+01, 0.11007300E+01, -.41047600E+00, -.69416000E+00, -.63650900E-01, -.18838800E-01, -.77067800E-01, -.10111700E+03, -.40909800E+02, 0.87113700E+02, 0.70954400E+02, 0.80943300E+02, -.42206700E+02, -.86681000E+02, -.10606700E+02, 0.35995800E+01, -.25630500E+02, 0.44607800E+01, 0.21530300E+02, -.26653200E+02, 0.32335300E+02, 0.30916900E+02, 0.10795300E+03, -.27478800E+02, -.11084100E+03, 0.20092600E+03, -.10047800E+03, -.82646900E+02, -.10002600E+03, 0.35486900E+02, -.51091000E+02, -.44841100E+02, 0.10531100E+03, 0.48132700E+02, -.88226000E+02, -.26306400E+03, 0.10942300E+03, -.66862800E+02, -.10150600E+03, -.51390700E+02, 0.13823800E+02, 0.69254800E+02, -.49466700E+02, -.24932700E+02, -.18753700E+02, 0.56022100E+02, -.70292000E+01, 0.15987000E+03, -.78848900E+02, -.81045700E+02, -.79558500E+02, 0.26035100E+02, -.63622100E+02, -.35187900E+02, 0.10702300E+03, 0.73088900E+02, -.94272300E+02, -.25756500E+03, 0.35264000E+02, -.15428600E+02, -.50814500E+02, -.16970300E+02, 0.19967500E+02, -.29802300E+02, 0.12464300E+01, 0.40842400E+02, 0.48559400E+01, -.33551200E+02, 0.22130900E+02, -.93395700E+02, 0.51343000E+02, -.42824200E+02, 0.47776500E+02, 0.90091600E+01, 0.91613300E+01, -.59480600E+01, -.47186400E+01, 0.28080200E+02, 0.10987800E+02, 0.16110100E+02, 0.11813300E+02, 0.35704000E+01, 0.27197700E+01, 0.43134100E+01, -.24618600E+01, -.41505000E+01, -.10544900E+02, 0.36037100E+01, 0.43100000E+00, 0.42329000E+01, -.50478800E-02, -.11810400E+02, 0.19529100E+01, 0.10097800E+01, -.14754400E+02, 0.13592900E+01, -.40891100E+01, 0.41024000E+01, -.12487700E+02, -.85792900E+01, 0.21396400E+02, 0.56079100E+01, 0.13436400E+02, -.21048700E+01, 0.77691000E+01, 0.63997300E+01 },
        { -.76099400E+01, 0.75577200E+01, 0.91624500E+00, 0.30730600E+01, 0.27599600E+00, 0.29184100E+01, -.98823400E+01, 0.17167100E+01, -.53221900E+01, 0.47424500E+01, 0.15854600E+00, -.10047400E+01, 0.46580600E+00, -.13299200E+01, -.26627800E+01, -.48325900E+01, -.13368100E+01, 0.49483800E+00, 0.34362900E+01, -.34728000E+01, 0.17543300E+01, 0.12745100E+00, -.76070100E+00, -.10681800E+01, 0.59661800E+01, 0.70047000E-01, 0.23146400E+01, 0.32018300E+01, -.22295400E+01, -.10321500E+01, 0.66493900E+00, -.15879600E+00, 0.20699400E+01, 0.10414800E+01, -.30812400E+00, 0.17870000E+00, -.40162600E+00, 0.25258800E+01, 0.10077300E+01, 0.13549800E+02, 0.35539200E+00, 0.64937300E+00, -.17023000E+01, -.57309900E-01, 0.86010400E+00, 0.51872200E+00, -.33958100E+00, 0.31998200E-01, -.28859600E+00, 0.46017200E+00, 0.10859700E+01, -.57525700E+00, -.53876500E+00, -.13141200E+01, -.12152700E+01, 0.10291500E+01, -.96856600E+00, 0.58183400E+00, -.79122100E-02, -.69861300E+00, -.45514000E+00, 0.29310900E+01, 0.19066700E+01, -.50804800E+00, 0.24305100E+00, 0.14239300E+00, 0.40515100E+00, 0.47652900E+00, 0.48050000E+00, -.15983400E+00, 0.33737600E+00, -.20109800E+00, -.16913100E+01, 0.39232600E-01, 0.61748700E-01, -.29760900E+00, -.25680900E+00, 0.70954500E+00, 0.86052700E-01, -.58175000E-01, -.83903800E-01, 0.10865600E+00, -.92051400E+00, 0.53690200E-01, 0.15295200E+01, 0.54190400E+00, 0.71035400E+00, -.23374100E+00, -.25789800E+01, -.58162900E+00, -.59182500E+00, -.35580100E-01, 0.51170000E+00, -.58701700E+00, -.97256400E+00, 0.11477000E+01, -.44720400E+00, -.13462100E+01, 0.42487000E+00, 0.14002300E+00, 0.21175900E+00, 0.18541500E+00, -.14076100E+01, 0.75891000E-01, -.97681200E+00, -.75732000E-01, -.12082000E+01, -.18243700E+01, -.76443800E+00, -.46324700E+00, 0.22329400E+01, -.60037300E+00, 0.14139800E+00, 0.31203800E+00, -.10341000E+01, 0.24720800E+01, 0.27973800E+01, -.38258400E+00, -.18582200E+00, 0.10270900E+00, -.18300900E+01, 0.62176000E+00, 0.94784100E-01, 0.64297200E+00, -.72093100E-01, 0.11199300E+01, 0.14333000E+00, -.17447900E+01, 0.23685500E+01, 0.47640500E+00, -.44167500E+00, -.27589200E+01, 0.14930000E+01, -.22487200E-01, 0.23475200E+00, -.28131300E-03, -.25545300E+01, -.29217000E-01, 0.72854500E-01, 0.15573500E+01, -.57128500E+00, 0.11011300E+01, 0.22750500E+01, -.11488000E-01, -.16413600E+00, 0.72110400E+00, 0.10639900E-01, -.39333500E-01, -.66216700E+00, 0.26041200E+00, 0.45942800E+00, 0.94950500E+00, -.51444000E+00, 0.33815400E+00, 0.13592800E+00, 0.37599300E-01, 0.58350300E+00, -.17728200E-01, 0.73106100E+00, 0.84049000E+00, -.32576000E+00, -.17822900E+01, -.12972300E+01, -.10566200E+00, 0.11869800E+01, -.15484500E+00, 0.46683000E+00, 0.13916200E+00, 0.21017000E+00, -.40815800E+00, 0.25803500E+00, 0.19269500E+00, 0.16007300E+00, -.27347300E+00, 0.59445400E+00, 0.29522900E+00, 0.31248300E-01, 0.27385200E+00, 0.89270400E-01, -.26111000E+01, -.23440600E+01, -.18101700E+00, -.13408300E+01, 0.14227100E+01, -.43426000E+00, 0.19131700E+00, -.35117100E+00, 0.39692300E+01, 0.18387100E+00, 0.16818100E+01, 0.95232600E-01, 0.65166400E+00, 0.82753100E+00, -.12653800E+01, -.17953700E+01, -.37819200E+00, -.97096000E+00, 0.11323900E+00, 0.34994400E+00, 0.12542300E+00, 0.10692800E+01, -.36172600E-01, 0.13267200E+01, 0.43568700E+02, -.16266600E+03, -.88642000E+02, -.15663900E+03, 0.90525200E+01, 0.28071600E+03, 0.41160200E+03, -.20203000E+03, -.27342200E+03, -.20475800E+03, -.93197500E+02, 0.41098500E+02, -.97492300E+02, 0.94273600E+01, -.48260500E+03, 0.40847600E+02, 0.36153600E+03, 0.10047500E+04, -.50285500E+03, -.57778100E+03, -.50303800E+03, -.26273000E+03, 0.40876900E+02, -.29945800E+03, -.85517800E+02, -.73063900E+03, 0.12181000E+03, 0.67377200E+03, -.17333600E+03, 0.12253400E+03, -.18697300E+02, 0.81157000E+02, 0.14725400E+02, 0.28635800E+02, -.95674900E+02, -.12797300E+03, -.28773500E+02, 0.38920100E+02, 0.35740600E+02, 0.70424900E+03, -.35625500E+03, -.57723100E+03, -.35295700E+03, -.27678100E+03, 0.40383200E+01, -.31508900E+03, -.24939000E+03, -.77695000E+03, 0.13411600E+03, 0.11772300E+04, -.99656200E+02, 0.42730800E+02, -.33854100E+02, 0.48346400E+02, -.69166300E+01, 0.40326600E+02, 0.84305100E+02, -.44397400E+02, 0.38657500E+02, 0.24706800E+02, -.31491300E+02, 0.10340800E+03, -.53338300E+02, -.28389700E+02, -.53200900E+02, -.50116800E+02, 0.88089400E+02, -.93935600E+02, -.35239600E+02, 0.27637100E+02, 0.13945200E+02, -.12473000E+03, -.18126000E+02, -.13441500E+02, -.11737500E+02, -.25679600E+00, 0.15144900E+02, 0.92629700E+01, 0.12913600E+02, -.11861300E+01, 0.43032100E+01, -.76459500E+01, -.93800400E+01, 0.33126100E+00, 0.39476500E+00, 0.93163300E+00, 0.17482800E+01, -.85430900E+01, 0.85003300E+01, 0.21404400E+01, 0.16901700E+01, 0.11524700E+02, -.80132700E+02, 0.42105900E+01, -.66743400E+01, 0.66297600E+01, -.13903800E+02, -.19155900E+02 },
        { -.19239300E+01, -.80073300E+00, 0.34672700E-01, -.51946600E+00, -.16798900E+01, -.14449100E+01, -.14631100E+00, 0.69584000E-01, -.70968000E+00, 0.93486300E+00, 0.64389000E-01, -.82422900E-01, 0.53174200E+00, 0.95234500E+00, 0.20439400E+00, -.25731500E+00, 0.63750500E-02, 0.31913800E+00, 0.43848200E+00, -.29201300E+00, 0.16348300E+00, -.32230800E-01, -.63898000E-01, -.35786100E+00, 0.25463600E+01, 0.71647900E-01, 0.17361200E+00, 0.61411200E+00, -.68360600E+00, -.11202600E+00, 0.42756200E+00, 0.38103700E+00, 0.91988500E+00, 0.39958500E+00, 0.38806000E+00, -.52905400E-01, -.81016500E-01, 0.76346700E+00, -.68447800E+00, 0.39337000E+01, 0.16938200E+00, 0.13578600E+00, -.15097900E+00, -.25926500E+00, 0.14284100E+00, -.24255800E-01, 0.27300500E-01, -.63100900E-02, -.33310000E-01, 0.14154300E-01, 0.27950400E+00, 0.21173200E-01, -.15070500E+00, 0.94979400E-01, -.15726900E+00, -.38748400E+00, -.18366400E-01, -.17871400E-01, -.24723800E-01, 0.80876000E-01, 0.43271400E+00, -.68588600E+00, -.39891500E+00, 0.70306900E-01, 0.32205600E+00, -.71178600E-02, 0.86013900E-01, -.13880500E+00, 0.83818100E-01, -.17214000E-01, 0.44863000E+00, -.77680900E-01, -.13365400E+00, 0.89953300E-01, -.72952600E-01, -.13778800E+00, 0.15318400E-01, 0.24014700E+00, 0.11923500E+00, -.11092000E+00, 0.48903800E-01, -.47912500E-01, 0.73914200E+00, 0.68897500E-01, -.66099400E+00, -.16968200E-01, 0.27645600E+00, 0.17924400E+00, -.16053400E+01, 0.49746300E+00, 0.39386800E+00, 0.13355200E-01, -.68790100E-01, 0.23557100E+00, 0.34224400E+00, 0.42742800E+00, -.48458800E-01, -.67350400E-01, 0.26798300E+00, 0.63604000E-02, -.11069800E+00, -.12990400E+00, -.10754300E+00, 0.44243800E+00, 0.36929600E-01, -.23493900E-01, -.39432900E+00, -.28019700E+00, -.73597500E-01, 0.39965500E-01, -.14582600E+00, -.40256500E-01, -.41827400E-02, -.11451100E+00, -.11418100E+00, 0.57315400E+00, -.94624900E+00, -.29834300E+00, 0.15131100E+00, -.71334900E-01, -.68461600E+00, -.17846100E+00, 0.15189000E+00, 0.62064100E-01, -.41064700E-03, -.38687700E-01, -.43931300E-01, 0.41201900E+00, 0.32761000E+00, 0.99776400E-01, -.10016900E+01, 0.16303700E+01, -.92821500E+00, -.28902800E-02, 0.88175800E-01, 0.45051900E-03, 0.41724800E+00, 0.90374000E-01, -.12095200E+00, 0.42143800E+00, 0.65900700E-01, 0.19089000E+00, 0.32745800E+00, 0.14708500E+00, 0.11635500E+00, -.23813000E+00, -.20877300E-01, -.64049400E-01, 0.47925400E-01, 0.87509900E-01, -.14985000E+00, -.24705600E+00, -.47895900E+00, -.25030000E+00, -.35814200E-01, 0.16382700E+00, 0.36230800E-01, -.20750900E-02, -.51131400E+00, -.27836800E-01, 0.16907900E-01, -.80712200E-01, -.27900000E+00, -.18820600E+00, 0.23609400E+00, -.10756500E-01, 0.16060400E+00, 0.16322200E+00, -.27666800E-01, -.81897000E-03, -.39773300E-01, -.51159000E+00, -.13519100E+00, -.83020700E-01, 0.71632100E-01, -.21288200E+01, 0.15309300E+00, 0.11279500E+00, -.28333300E+00, -.52831300E+00, -.22209000E+01, 0.28815300E+00, 0.32373400E+00, 0.35596300E+00, -.24126400E+00, 0.15449700E+00, 0.66203700E-02, 0.40225600E+00, -.81465200E-02, 0.63149600E-02, -.24266000E-01, 0.10663400E+00, -.89819100E-01, -.73316800E+00, 0.10783900E+01, 0.28714500E+00, -.73336300E+00, 0.59695700E-01, -.14825400E+00, 0.60185400E-02, -.60297400E+00, -.89327500E-02, -.23106400E+00, 0.16067600E+00, 0.92017600E+02, 0.46960400E+02, 0.61333700E+02, 0.15062100E+02, -.11040300E+03, -.29872600E+03, 0.14883500E+03, 0.13903300E+03, 0.14876700E+03, 0.39105000E+02, -.32173700E+01, 0.54177100E+02, -.71262000E+02, 0.20126500E+03, -.45369400E+01, -.12566700E+03, -.39771400E+03, 0.19851800E+03, 0.24315700E+03, 0.19921200E+03, 0.12317800E+03, 0.11150900E+01, 0.98855400E+02, -.55992500E+01, 0.27215100E+03, -.35340500E+02, -.30421600E+03, 0.10708600E+03, -.61440100E+02, 0.27296400E+02, -.51702000E+02, -.18546100E+02, -.37296400E+02, 0.38946300E+02, 0.57998600E+02, 0.63703900E+01, -.38766500E+02, -.44108200E+02, -.30165700E+03, 0.15111900E+03, 0.21806500E+03, 0.15128800E+03, 0.13776500E+03, 0.11340700E+02, 0.99087100E+02, 0.39534100E+02, 0.29958600E+03, -.45579500E+02, -.51374100E+03, 0.68419400E+02, -.32137000E+02, -.39190500E+02, -.33444800E+02, -.58336900E-01, -.79951500E+01, -.49179500E+02, 0.27297700E+02, -.28999300E+02, -.72877300E+01, -.15734000E+02, 0.56554800E+02, -.27708000E+02, -.27161800E+01, -.27411600E+02, -.50023500E+02, -.98075600E+02, 0.10704500E+03, 0.10515400E+03, 0.14873700E+02, -.61631100E+02, 0.35062300E+02, 0.55197500E+01, 0.80074400E+01, 0.48609600E+01, -.64759700E+00, -.13035900E+02, -.25823400E+01, -.34617200E+01, 0.79507700E+00, -.15100700E+01, 0.34298100E+01, 0.31119400E+01, 0.53835900E+01, -.99836900E+00, 0.10524800E+01, 0.21087700E+01, 0.43265000E+01, -.37605900E+01, -.11036700E+01, 0.26596200E+01, -.47507800E+01, 0.23073900E+02, 0.66900200E+01, -.16919300E+01, -.29920600E+01, -.45777200E+00, 0.20290300E+01 },
        { 0.34993500E+00, 0.11101500E+00, -.47226800E-02, 0.71396000E-01, 0.28598500E+00, 0.24476100E+00, 0.37673600E-01, 0.52165600E-01, 0.12761600E+00, -.18482800E+00, -.10585900E-01, 0.18640500E-01, -.23834100E-01, -.15851600E+00, 0.38903200E-01, -.25225300E-01, -.57559600E-01, -.82744700E-02, -.58750000E-01, 0.78697600E-01, -.18078100E-01, 0.20791800E-02, 0.31466300E-02, 0.50429300E-01, -.30509100E+00, -.71788000E-02, 0.12929900E-02, -.85600300E-01, 0.91840300E-01, -.10738100E-01, -.44266600E-01, -.49652400E-01, -.11167200E+00, -.20533600E-01, -.33230900E-01, 0.28801800E-01, 0.82294600E-02, -.71485100E-01, 0.50381700E-01, -.60226900E+00, -.25480500E-02, -.13823400E-01, -.19049400E-01, 0.13752000E-01, -.21001700E-01, -.36349700E-02, -.32568700E-01, -.12112800E-02, 0.78098300E-02, 0.17823000E-01, -.36113600E-02, -.11346800E-01, 0.48423400E-02, -.52919700E-01, -.14332900E-01, 0.84430200E-01, -.21626600E-01, 0.28462100E-01, -.10229500E-02, 0.15169600E-02, -.41399400E-01, 0.17950800E+00, 0.89222600E-01, -.65251000E-02, -.26460900E-01, -.29458100E-02, 0.94887700E-03, 0.17707500E-01, 0.11313200E-01, 0.85734200E-03, -.16148200E-01, -.19976900E-01, -.19965600E-01, -.76329500E-02, 0.33324900E-01, 0.18467400E-01, 0.99678500E-02, 0.31785000E-01, 0.12973700E-01, -.38846200E-01, -.41229600E-02, -.19033800E-01, -.66010400E-02, 0.48592800E-02, 0.30463700E-01, 0.27443600E-02, -.92208600E-02, -.37012800E-01, 0.10680300E+00, -.46246100E-01, 0.37104100E-01, -.21295800E-02, 0.84337300E-02, 0.31942600E-01, -.36372800E-01, -.43962300E-01, 0.82995700E-02, -.30045600E-01, -.32615900E-01, 0.18623300E-01, 0.19446200E-01, -.16871500E-01, -.79063400E-02, -.33406900E-01, 0.18689300E-01, -.30394000E-01, -.47509300E-01, -.40799200E-01, 0.10260800E+00, 0.14181300E-02, -.28731700E-01, 0.71618000E-02, -.11673200E-01, -.15199500E-01, -.39928100E-01, 0.66579800E-01, 0.78809100E-01, -.59276000E-01, -.54115100E-03, -.19967700E-02, 0.62290500E-01, -.58371000E-01, -.15587300E-01, -.23249300E-01, -.24459300E-03, 0.37645700E-01, -.12116300E-01, -.70699400E-01, -.29234200E-01, -.17803000E-01, 0.94026000E-01, -.13169200E+00, 0.36418700E-01, 0.74178900E-03, 0.59414900E-02, 0.26722200E-03, -.13332500E+00, 0.64544200E-01, -.27100600E-01, -.96274400E-01, 0.56632200E-01, -.14552400E+00, -.54353500E-01, -.25449400E-01, -.48407000E-02, 0.23884200E-01, -.14749200E-02, -.26455300E-02, -.26805000E-01, 0.96572500E-02, -.12030000E-01, -.23029600E-01, 0.37397000E-01, -.15281500E-01, 0.14129200E-02, -.42204800E-02, -.76496300E-01, 0.19918700E-03, -.71736700E-02, -.22683300E-01, 0.93098600E-02, 0.55115000E-01, 0.15489100E+00, 0.15505700E-01, -.75542500E-01, 0.14262200E-01, -.75142300E-01, 0.18691200E-01, -.36188000E-03, 0.36979600E-02, -.28224100E-01, 0.11738600E+00, 0.42051400E-02, 0.37481000E-02, 0.79023500E-01, 0.22843200E+00, -.85569500E-02, 0.30457300E-02, 0.21453200E-01, 0.13113200E-01, -.56698500E-01, -.57480500E-01, -.11393300E+00, -.35436100E-01, -.49805100E-01, 0.61275900E-03, 0.26600700E-02, -.11854300E-01, 0.24991100E-01, -.23209300E-01, -.29172700E-03, 0.96338700E-02, 0.41784800E-02, 0.73014200E-01, -.21832700E+00, -.11386200E+00, 0.13645900E+00, -.37406700E-03, -.29072200E-01, -.14250200E-03, 0.44286300E-01, -.90079500E-02, 0.31181400E-01, 0.28805900E-01, -.10449500E-01, -.38309200E+01, 0.38137700E+01, -.66925400E+00, -.99958700E+01, -.32204100E+00, -.54016900E-01, 0.48297900E+01, 0.10633500E+00, 0.52181200E+01, -.24303500E+01, 0.20441700E+01, 0.52995000E+01, 0.17714700E+02, -.19777500E+01, -.16840900E+02, -.17535300E+02, 0.86692300E+01, 0.98479000E+01, 0.87827300E+01, 0.47915000E+01, -.36590700E+01, 0.21264300E+01, 0.56388500E+01, 0.23995600E+02, -.66962100E+01, -.24104800E+02, 0.22704900E+01, -.25830000E+01, -.21746200E+01, -.83413200E+00, 0.20905700E+01, 0.44881500E+01, -.28664400E+00, 0.15217500E+01, 0.10417000E+01, 0.36333600E+01, 0.12518800E+01, -.63564200E+00, 0.24843300E+00, 0.98888900E+01, 0.29138000E+00, 0.38642900E+01, -.22104200E+01, -.81950700E+00, 0.10136600E+02, 0.23092900E+02, -.61142600E+01, -.39370600E+02, 0.14760600E+01, -.49892100E+00, 0.71024000E+01, -.76853300E+00, -.88847800E+00, -.29863400E+01, 0.43150500E+00, 0.20330500E+00, 0.28963100E+00, -.19320300E+01, 0.29665200E+01, -.30451200E+02, 0.15517800E+02, 0.79035000E+01, 0.15267500E+02, 0.80941100E+01, 0.40275500E+01, -.12554300E+01, -.10216400E+02, 0.49387400E+00, 0.50999100E+01, 0.15020800E+02, 0.15265400E+01, 0.58640800E+00, 0.55436900E+00, -.18388000E+00, 0.41773000E+00, -.53245200E+00, -.69208300E-01, 0.18584800E+00, -.39184600E+00, 0.21771000E+00, 0.21588300E+00, -.12206800E+01, 0.39105000E+00, -.89086100E-01, -.10055800E+01, 0.62415600E+00, -.80460200E+00, -.25991800E+00, -.82497800E+00, -.34015400E+00, 0.42947200E+01, 0.63945300E+00, 0.12668800E+01, -.51977800E+00, 0.57447400E+00, 0.14412400E+01 },
        { 0.13417300E+01, 0.11570200E+01, 0.53962900E-01, 0.62374600E+00, 0.12643500E+01, 0.10349300E+01, -.34426300E-02, 0.10493500E+01, 0.28677900E+00, -.69789300E+00, -.28906100E-01, 0.88678900E-01, 0.37738600E+00, -.72274600E+00, 0.95792000E-01, 0.38073500E+00, 0.16199600E+00, -.48236200E+00, -.35181300E+00, -.87731300E+00, -.63251100E+00, 0.74838200E-01, -.47257200E-01, 0.26178500E+00, -.99414700E+00, -.57446000E-01, -.10446900E+00, -.66681200E+00, 0.61270300E+00, -.16519400E+00, -.20895800E+00, -.27634100E+00, -.43678400E+00, 0.36211600E-01, 0.19288200E+00, -.17972300E-01, 0.15021400E+00, -.44787100E+00, 0.77697900E+00, -.34782600E+01, -.55352000E-01, -.30452400E+00, 0.37681200E+00, 0.64023600E-01, -.38061000E+00, -.90998700E-02, 0.11187300E+00, -.12241600E-01, 0.37653100E-01, 0.11894300E+00, -.10604300E+00, 0.21080600E+00, -.12176700E+00, -.52001600E+00, 0.29768500E-01, 0.22729300E+00, -.62120300E-01, 0.62773900E-02, 0.27788100E-01, -.65761100E-01, -.76744100E+00, 0.58569800E+00, 0.57934200E+00, -.63275100E+00, 0.40203500E+00, -.81907300E-01, -.11948600E+00, -.22286800E+00, 0.91113600E-01, -.24709500E-01, -.14132400E+00, -.24967200E+00, -.29299600E-01, -.13090200E+00, 0.22029300E+00, 0.76113900E-01, 0.94668900E-01, -.41860100E+00, -.13362900E+00, -.14645400E+00, -.73605900E-01, -.43620200E-01, 0.74813700E+00, -.27610100E-01, 0.77961900E-01, 0.20029200E+00, -.16238800E+00, -.31166000E+00, -.68965800E+00, 0.21648700E+00, 0.21767100E+00, -.18615000E-01, -.19191100E-01, -.42372000E-01, -.17111400E+00, 0.63708100E+00, -.97303600E-01, -.21372000E+00, 0.58346400E-01, 0.86521800E-01, 0.49571700E-01, 0.67296800E-01, -.68571900E-01, -.11773700E-01, -.12751000E+00, 0.49187800E-01, 0.30232000E+00, 0.78040600E-01, 0.54647300E+00, 0.74067500E-01, -.19132800E+00, 0.11324600E+00, -.23141000E-01, -.50372300E-02, 0.21424200E+00, -.23331000E-01, -.68127900E+00, 0.25651200E+00, -.45637200E-01, 0.16807600E+00, 0.35397800E+00, 0.40802900E+00, -.71188900E-01, -.39597100E-01, 0.49032600E-02, -.55565900E-01, -.27242500E-01, -.62949500E-01, -.25887600E+00, -.27707500E+00, 0.84713400E+00, -.75640700E+00, 0.45060600E+00, 0.28105000E-02, -.30066400E-01, 0.85062900E-03, -.43132500E-01, 0.34177300E+00, -.27336300E-02, -.10148100E+01, 0.95194200E-01, -.17284600E+00, 0.44796100E+00, 0.32662100E-01, -.13186400E-01, -.21841600E+00, 0.16428400E-01, 0.36013100E-01, 0.10063800E+00, -.47754100E-01, -.49123100E-01, -.30195700E-01, 0.86004200E+00, -.10017900E+00, -.18794800E-01, 0.96031700E-02, -.18067400E+00, 0.58401800E-02, -.21007300E+00, 0.32395200E+00, -.16522800E-01, 0.40330800E+00, 0.43883100E+00, 0.54148200E-01, -.45750800E+00, -.11649700E-01, -.25542000E-01, -.29212400E+00, 0.49662900E-01, 0.78647200E-01, -.77339900E-01, 0.48393900E+00, 0.51994100E-01, 0.10892000E+00, -.22166200E+00, 0.32844600E+00, -.10702700E+00, -.10233100E+00, 0.11302100E+00, -.13710100E+00, 0.37387600E+00, 0.26416400E-01, -.60133600E+00, -.16955500E+00, 0.12639200E+00, -.31135700E-01, 0.20318700E-01, -.13150400E+00, 0.23972400E-01, 0.15969300E-01, 0.88732800E-04, -.46503000E-01, -.69154000E-02, -.58518000E-02, -.46736100E+00, -.25930500E+00, 0.26020300E+00, 0.87470200E-01, 0.19912000E-01, 0.54700800E-01, -.20545200E+00, 0.14015300E-01, 0.10140100E+00, -.11743700E+00, 0.24528600E-01, 0.17472200E+01, -.33526100E+02, -.46399500E-01, 0.25285400E+02, 0.31118700E+02, -.13627600E+02, -.28263000E+02, -.15203300E+02, -.24158700E+02, 0.13545400E+02, -.13529200E+02, -.17288600E+02, -.97917700E+02, 0.21906200E+02, 0.71806400E+02, 0.12351800E+03, -.61922800E+02, -.70746400E+02, -.61911600E+02, -.51181300E+02, 0.30442700E+02, -.44184200E+02, -.27866200E+02, -.10235900E+03, 0.41879700E+02, 0.16205100E+03, -.54598300E+02, 0.39424300E+02, 0.24671000E+02, 0.25099100E+02, -.56684600E+01, -.34677100E+02, 0.17771300E+02, 0.83076300E-01, 0.26223500E+02, -.27176900E+02, -.75407600E+01, 0.92090600E+02, -.46918000E+02, -.68819400E+02, -.46049000E+02, -.58163200E+02, 0.31934900E+02, -.55440200E+02, -.56936200E+02, -.11875200E+03, 0.46646700E+02, 0.23451100E+03, -.21211700E+02, 0.93122500E+01, -.16890900E+02, 0.10539900E+02, -.77817900E+01, 0.65155400E+01, 0.24887900E+02, 0.53530400E+01, 0.16387000E+02, 0.39061500E+01, -.21318700E+02, 0.26403300E+02, -.14973000E+02, 0.57614100E+01, -.13567600E+02, -.11560000E+02, -.40980200E+01, 0.60706500E+01, 0.15847500E+02, 0.13312700E+02, -.12407000E+02, -.16403200E+02, -.52369000E+01, -.23340000E+01, -.26644700E+01, 0.47276100E-01, 0.22232000E+01, 0.10593900E+01, 0.31093600E+01, 0.67113200E+00, 0.78324100E+00, -.95666300E+00, -.11146600E+01, 0.29072400E+01, -.10501100E+01, 0.15579300E+00, 0.37744300E+01, -.11802800E+01, 0.19870200E+01, 0.22574800E+00, 0.27405500E+01, 0.25502400E+01, -.19612500E+02, 0.10495900E+02, -.33451200E+01, -.13890000E+01, -.40787500E+01, -.59125400E+01 },
        { 0.80317200E+00, 0.72116500E+00, 0.47809800E-01, -.64325300E-01, 0.10448100E+01, 0.22220000E+01, -.92359300E-01, -.35720700E+00, 0.35091900E+00, -.39522500E+00, 0.20358300E-01, 0.10731700E-01, 0.52224300E+00, -.46634800E+00, -.32007600E+00, -.95574000E+00, -.57799200E+00, 0.21265700E+00, -.15289200E-01, -.12257100E+01, -.46587700E-01, -.13480200E-01, -.21870600E-01, 0.46835000E-01, -.43601400E+00, -.30867700E-01, -.17327800E+00, -.88691200E-01, 0.11829200E+00, 0.32523800E-01, -.47262100E-01, 0.11204000E+00, -.56704300E-01, 0.18221800E+00, 0.19193600E+00, 0.63067700E-01, 0.15637900E+00, 0.27780200E+00, 0.19914300E+00, 0.13456400E+01, -.34715400E-01, 0.11747000E-01, 0.51238400E-01, -.39612500E+00, 0.70533300E-01, -.27716900E-01, -.16693500E+00, 0.73366200E-02, -.58273900E-01, -.41720100E-01, -.96444500E+00, 0.14344400E+00, 0.36896100E+00, 0.49481600E+00, 0.68906600E+00, -.29819500E+00, 0.49913900E+00, -.90948000E-01, 0.28561600E-01, 0.32007000E+00, -.11265300E+00, -.12339500E+01, -.73138500E+00, 0.64972500E+00, 0.25390700E+00, -.36194900E-01, -.29917000E+00, -.75894100E-01, -.98231700E-01, -.10517400E-01, 0.10426900E+00, -.37356000E-01, 0.23144800E+00, -.45808900E-01, -.13332300E+00, 0.24076200E+00, -.15682300E-01, -.70843000E-01, -.51173400E-01, -.26072300E-01, -.31877000E-01, -.83689300E-02, 0.40711100E+00, 0.25325700E-01, 0.39724900E-01, 0.10152400E+00, 0.16122700E+00, 0.28781400E+00, 0.18523000E+00, -.11909000E+00, 0.87992400E+00, 0.74499400E-03, 0.56297500E-01, -.43282100E-02, 0.31612900E-01, -.22843900E-01, -.99905300E-02, 0.19011700E+00, -.90957100E-01, -.42721500E-01, -.63015400E-01, 0.48241300E-01, 0.88893900E-01, 0.50235600E-01, -.38490400E-01, 0.62003200E-01, 0.23646800E+00, 0.86143200E-01, -.38430000E+00, -.47611600E-02, 0.11231800E+00, -.49811400E-01, 0.51618500E-01, -.25765300E-01, -.70204300E-01, -.31903800E+00, -.55808900E+00, 0.86790600E-01, 0.72764000E-01, 0.98842000E-01, -.20930900E-01, 0.36535300E-01, 0.13298100E-01, 0.12983800E+00, 0.13853600E-02, -.47791700E-01, -.29663600E-01, 0.97786500E-01, -.15511800E+00, -.59116300E-01, 0.40128700E+00, 0.26918500E+00, -.77603200E-01, 0.17613700E-02, -.46826100E-01, 0.32135100E-02, 0.44568700E-01, 0.13712500E+00, -.17857500E-01, -.47647700E+00, -.15340500E-01, 0.10047500E+00, 0.29420800E+00, 0.99449100E-01, -.37499900E-02, -.19409100E+00, 0.42850900E-03, 0.70835500E-03, 0.80548600E-01, -.95129800E-01, 0.20508300E-01, 0.92951900E-01, 0.24618900E+00, -.18374600E-01, -.10194400E-01, -.19300700E-01, -.59734700E-03, -.72393200E-02, 0.12060300E+00, 0.11106900E+00, 0.46225200E-02, 0.23065800E+00, 0.15190600E-01, 0.66940200E-01, -.31930100E-01, 0.14181600E-01, -.19883100E-01, -.33123000E+00, 0.25336300E-01, -.21988400E-01, -.38332000E-03, 0.22294600E+00, -.73314600E-01, 0.57367900E-01, -.51143200E+00, 0.28410500E+00, -.51965200E-02, 0.16465700E-01, -.17375300E-01, 0.85435400E-02, -.66135600E+00, -.35544900E-01, -.56317900E-01, -.30577500E-02, 0.80574300E-01, 0.11728200E-02, 0.32810800E-01, -.18526500E-01, -.10073600E-01, -.56586500E-02, -.16213200E-02, 0.30145100E-01, -.23300600E-01, 0.99092400E-01, -.26754200E+00, -.69568100E-01, -.94440600E-01, -.11973100E-02, 0.19571700E-01, -.30563400E-01, -.31144500E+00, 0.10022800E-02, -.45117700E-01, -.46084300E-01, 0.15153200E+00, 0.15331700E+01, 0.63316900E+00, 0.42696800E+01, -.10834700E+02, 0.36298300E+02, -.18618900E+02, -.20536400E+02, -.18207300E+02, -.24180500E+01, -.11378400E+02, 0.50139900E+01, 0.16607400E+02, -.27334500E+01, -.13157800E+02, -.23511000E+02, -.67768600E+01, 0.36302200E+01, 0.13034800E+02, 0.34079400E+01, 0.76668500E+01, -.10092800E+00, 0.53259400E+00, -.80457600E+01, -.80853500E+01, -.46655100E+00, 0.68898900E+01, 0.19728700E+02, -.11892400E+02, -.15302500E+02, -.95293000E+01, 0.25399400E+01, 0.15143900E+02, -.12656100E+02, -.84983900E+01, -.13546000E+02, 0.12185500E+02, 0.49290200E+01, -.21910500E+02, 0.11448200E+02, 0.15378300E+02, 0.10938300E+02, 0.74955600E+01, -.10436300E+01, 0.74126400E+01, 0.65158500E+00, -.49460800E+00, -.99492600E+00, 0.12990400E+02, 0.26173400E+01, -.12698400E+01, 0.86516100E+01, -.13328000E+01, 0.32494500E+01, -.85247800E+00, -.74982700E+01, -.23712900E+01, 0.17275200E+01, -.24709600E+01, 0.73467400E+01, 0.35620300E+01, -.88849100E+00, -.28163700E+01, -.17280600E+01, 0.45769100E+00, 0.90110800E+01, -.10456700E+02, -.90717600E+01, -.24720200E+01, 0.73962400E+01, -.17561200E+01, 0.30983600E+00, -.33114700E+00, 0.82623900E-01, 0.35911300E+00, -.32752000E-01, 0.65426900E+00, -.21641300E+00, -.14477400E+00, 0.94479000E-01, -.46565000E-01, 0.66029300E+00, 0.11440900E+01, 0.11200800E-01, 0.16861000E-01, 0.10055700E+01, -.11551000E+01, 0.73867300E+00, 0.45904500E+00, 0.98812600E+00, 0.46643100E+00, 0.13645100E+01, -.36932800E+01, -.12507800E+01, 0.10791100E+01, 0.11565500E+01, 0.10277400E+01 },
        { -.52822100E+01, 0.30859900E+01, 0.93351500E+00, 0.15758000E+00, 0.33517400E+00, -.44437800E+01, -.25997500E+01, -.15676600E+01, -.20805900E+01, 0.27958000E+01, 0.54437900E-01, -.13710200E+00, -.10094600E+01, -.12530700E+01, 0.49782700E+00, -.15791100E+01, 0.37478900E+00, 0.10426200E+01, 0.36057300E+00, 0.92732300E+00, -.18023500E+01, 0.32418300E+00, 0.82817400E-02, 0.37224700E+00, -.90718200E+00, 0.12918200E+00, 0.20950900E+01, 0.16256200E+01, -.55904500E+00, 0.15702700E+01, -.70520900E+00, -.33946100E+00, -.62339900E+00, 0.26918100E+00, -.13832500E+00, 0.24098200E+00, -.31242900E+00, -.10754300E+00, -.13365300E+00, -.73531000E+01, 0.15808400E+00, 0.27123600E+00, -.19448800E+01, 0.18178000E+01, 0.19518400E+01, 0.15228300E+00, 0.38874000E+00, -.27528000E-02, 0.24306300E+00, 0.45558200E+00, 0.33493600E+01, -.11562400E+01, -.17706500E+01, -.24087200E+01, -.32567400E+01, 0.12115500E+01, -.23169500E+01, 0.11866200E+00, -.49496000E-01, -.93309800E+00, -.34330800E+00, 0.27492700E+01, 0.22811400E+01, -.16913700E+01, 0.96530600E+00, 0.12299100E+00, 0.18679300E+01, 0.27299700E+00, 0.64893000E+00, 0.13943400E+00, -.74290800E-01, -.22140700E+00, -.13374900E+01, -.45981300E+00, -.18950800E+00, -.83805300E+00, 0.16834200E+00, -.79484600E+00, -.56605900E+00, 0.18736000E+01, 0.42783000E+00, 0.36532700E+00, -.20179400E+01, -.30185200E+00, 0.40668300E+00, -.31508200E+00, 0.13713800E+01, 0.20039500E+01, 0.61612500E-01, 0.18293600E+00, -.11675000E+01, 0.13096300E+00, -.89358300E+00, -.74387400E+00, 0.16104100E+01, -.14494100E+00, -.10217300E+00, -.93434700E+00, 0.11603000E+01, -.34142200E-01, -.24291700E-01, 0.22016100E+00, -.35190500E+00, -.38152700E+00, -.45875000E+00, 0.83079000E+00, 0.74641200E+00, 0.14459500E+01, -.17992900E+01, -.41307700E+00, 0.67118800E+00, -.10218000E-01, 0.24906200E+00, 0.57936400E+00, 0.14468200E+01, -.18276700E+01, 0.25663000E+01, 0.19967900E+01, -.76580100E+00, -.80424500E+00, 0.85155300E-01, 0.18725800E+01, 0.14038300E+00, -.25033800E+00, -.35165600E-03, 0.42998700E-02, 0.38467700E+00, -.11144300E+01, 0.13147800E+01, -.29259300E+00, -.11725800E+01, 0.14781700E+01, 0.10709800E+01, -.68360800E-02, -.24440100E+00, -.38863400E-01, -.46231500E+01, -.61530000E+00, -.37003900E+00, 0.48394300E+01, -.32467300E+00, 0.98489800E-01, -.21735800E+01, 0.16289300E+00, -.36861800E+00, 0.67674700E+00, -.89186100E-01, 0.54824000E+00, 0.32229900E+00, -.23631200E-01, 0.26848400E+00, 0.68132600E-01, -.22491500E+01, -.40361700E+00, 0.56452500E+00, 0.20563200E+00, -.37070900E+00, 0.14876700E-01, -.34274600E+00, -.98883100E+00, 0.72968600E-01, -.44232600E+00, 0.46944700E+00, -.23226000E+00, 0.39739400E+00, -.20780400E+00, -.27232700E+00, 0.13876100E+01, -.31033500E+00, 0.29916800E+00, 0.43600400E+00, -.12739700E+01, 0.33652600E+00, -.39686000E+00, 0.61062800E+00, 0.22634900E+01, 0.82224600E-01, 0.84985300E+00, 0.26504400E+00, -.28079200E+00, 0.14685100E+01, -.38168800E+00, 0.12063400E+00, -.23807200E+00, 0.10786900E+01, -.30717000E+00, -.24118500E+00, 0.10029700E+01, -.10924700E+00, -.42090700E+00, 0.36675600E-02, -.14659000E+01, -.84968100E+00, 0.19401500E+00, 0.10053300E+00, 0.19643200E+00, -.41148600E+00, 0.15043300E+00, 0.20907500E+00, -.38097900E+00, -.90500100E+00, 0.15252700E-01, -.17282600E+00, 0.67754100E+00, 0.63263900E+00, -.17938200E+01, -.19178800E+01, 0.37552400E+00, -.16434300E+03, 0.14103200E+03, -.71152400E+02, -.39965100E+02, -.70413400E+02, 0.51356400E+02, 0.11727100E+02, 0.13641000E+02, 0.58571700E+02, -.45946100E+00, 0.17652100E+02, -.27030200E+03, -.83065900E+02, 0.42397100E+02, 0.94438100E+02, 0.41655200E+02, 0.62945800E+02, -.12877000E+02, 0.28684300E+02, 0.55126700E+02, 0.85480300E+02, -.24404600E+02, -.21564000E+03, 0.79977600E+01, -.12952900E+02, 0.59183500E+01, -.46314100E+01, 0.86669700E+01, -.11590100E+02, 0.53002300E+02, 0.25091000E+02, 0.50858700E+02, -.10241300E+02, -.21901100E+02, -.14824500E+03, 0.77322400E+02, 0.17874200E+03, 0.74704200E+02, 0.51543500E+02, 0.29528400E+01, 0.59947300E+02, 0.81890100E+02, 0.10772900E+03, -.33787700E+01, -.22552100E+03, 0.57011200E+02, -.25071900E+02, 0.11501500E+03, -.27646100E+02, 0.76027600E+00, -.26259600E+02, 0.67607200E+01, 0.35495600E+02, -.14036400E+02, -.20404500E+02, -.29910300E+01, -.56649300E+02, 0.30069100E+02, 0.26067000E+02, 0.28529200E+02, 0.78301400E+02, 0.50423200E+02, -.98990600E+02, -.99072800E+02, -.54784700E+02, 0.60102100E+02, 0.14967900E+02, 0.10257600E+02, 0.14430300E+01, 0.47517400E+01, -.30289500E+01, 0.36473600E+01, 0.15619500E+01, 0.19878600E+01, 0.24161300E+01, -.23403200E+01, -.18766200E+01, 0.50540200E+01, 0.79972100E+01, 0.22991000E+01, -.11096400E+01, 0.82141300E+01, -.30770700E+01, 0.12086400E+01, -.15948500E+01, 0.83491600E+01, 0.37397400E-01, 0.18186400E+02, -.80327500E+01, -.50414500E+01, 0.91848600E+00, 0.11098100E+02, 0.11317000E+02 },
        { -.17073100E+01, -.35214700E+00, -.96071300E-02, -.67177400E+00, -.19821200E-01, 0.61589000E+00, -.41552000E+01, 0.21959400E+01, -.16206300E+01, 0.11601800E+01, -.22774400E-01, -.12880500E+00, -.12152200E+01, 0.25014400E+01, 0.79702200E-01, -.17501600E+01, 0.98371400E+00, 0.34484300E+01, 0.28310400E+00, -.22358400E+00, -.14011400E+00, 0.24798000E-01, -.19722300E+00, -.13492500E+00, -.59583100E-01, 0.27401900E-01, 0.64773700E-01, 0.27329400E+00, -.37510800E+00, -.46276100E+00, 0.72203200E-01, -.79871200E+00, 0.19034700E+00, 0.35983600E+00, 0.52680400E-01, 0.86802600E-01, -.23405200E-01, -.93521000E-01, -.42493200E+00, 0.20200600E+01, -.90024600E-01, 0.39789400E-01, -.42819700E+00, -.16413000E+00, 0.27384900E+00, -.38841700E-01, -.53626300E+00, 0.12893700E-01, -.54577100E-02, 0.31229100E+00, -.32585000E+00, 0.91606300E-01, 0.33385600E+00, 0.54088000E+00, 0.10365800E+01, 0.26932900E+00, 0.58728000E+00, -.40012400E-02, 0.54671200E-01, 0.13129500E-01, 0.45157700E+00, -.24364700E+00, -.48938000E+00, 0.36211700E+00, -.14280600E+00, -.10799500E-01, -.72358000E+00, 0.19043200E+00, -.19829000E+00, 0.21267700E-01, 0.62829300E+00, 0.43641500E-01, 0.10049700E+01, 0.27671800E+00, -.14860700E+00, -.37064900E-01, 0.20903700E+00, 0.17053600E+00, -.72964500E-01, -.43187100E+00, 0.18316300E-01, 0.28209800E+00, 0.13618700E+01, 0.23068800E+00, -.21271900E+01, -.12893000E+00, 0.30267600E+00, 0.91542500E+00, -.20392400E+01, 0.49760200E-01, 0.25682500E+01, 0.28919300E-01, -.87711600E-01, 0.59331800E+00, -.52437700E+00, 0.36720400E+00, -.10980100E+00, 0.25666000E+00, -.58577500E+00, -.25269600E+00, -.76038500E-01, -.15551400E+00, -.25416900E+00, 0.46433000E+00, -.32589000E+00, -.71930600E-01, 0.30174400E+00, -.10456600E+00, -.87849300E+00, -.15630000E+00, 0.43942600E+00, -.10386500E+00, 0.44495300E-01, 0.13153000E+00, 0.51780800E+00, 0.58525000E-01, 0.14521700E+00, 0.35582800E+00, 0.74384900E-01, -.38975800E-01, 0.24994400E-01, 0.38880800E+00, 0.32113800E-01, 0.14225100E+00, -.97873300E-02, -.18129800E-01, -.14770200E-01, 0.33229500E+00, 0.10614500E+00, 0.18737500E+00, -.69910500E+00, 0.47865800E+00, -.30353800E+00, -.11977600E-01, 0.16577500E-01, 0.24253000E-02, 0.57859000E+00, -.20032600E-01, 0.45045200E-01, 0.34702600E+00, 0.44625100E+00, -.74396500E+00, 0.95790000E+00, 0.22853500E+00, 0.41607300E-02, -.29323700E+00, -.94118800E-03, -.82818300E-01, 0.17697900E-01, -.42834100E+00, -.18080200E+00, -.27318200E+00, -.13884600E+01, 0.56059400E+00, -.19728900E+00, 0.56900700E-01, -.75520400E+00, 0.20255800E-01, 0.42992500E-01, -.12711700E+01, 0.45772600E-02, 0.81216800E-01, -.73590700E+00, 0.71353800E-01, -.14722600E+00, 0.55307600E-01, 0.12930100E+00, -.18846600E+00, 0.20393200E-01, -.13998600E+00, -.56129600E-01, 0.15390400E+00, -.18633000E+00, 0.76818600E-01, 0.15932300E+00, 0.83262200E+00, -.17491800E+00, -.52359900E+00, 0.37694900E+00, 0.65965500E-02, -.18760900E+01, 0.34529900E+00, 0.32892800E+00, -.19184400E+00, -.61222900E+00, -.73825900E-01, -.15947800E+00, 0.70482200E+00, 0.13259300E+00, -.13419700E+00, -.13861000E-02, -.41169600E+00, -.94099200E-01, -.24514300E+00, -.39216300E+00, -.69859200E+00, 0.62253500E+00, 0.25918300E+00, 0.22657200E+00, 0.40899800E-01, -.15247900E+00, -.13901300E-01, 0.27163700E+00, -.19901200E-01, -.18961300E+00, 0.67424900E+01, 0.12772800E+01, 0.12662400E+01, 0.12856700E+00, -.13131900E+03, 0.66245600E+02, 0.22694900E+02, 0.65594800E+02, 0.94042200E+01, 0.24058200E+02, -.56000300E+01, -.69224800E+02, -.22454400E+02, 0.17741600E+02, 0.30976400E+02, -.21852300E+03, 0.10995900E+03, 0.10908600E+03, 0.10934200E+03, 0.57408200E+02, 0.46997600E+02, 0.48995200E+02, -.36554200E+02, 0.89907400E+01, 0.60786600E+02, 0.11094600E+03, 0.43780000E+02, -.20363400E+02, 0.49499300E+01, -.21930100E+02, -.11766100E+02, -.53316300E+01, -.10353000E+02, -.30158400E+01, -.33809100E+02, -.67490800E+01, -.10333200E+01, -.37395700E+03, 0.18852000E+03, 0.14889600E+03, 0.18718500E+03, 0.88735900E+02, 0.60626200E+02, 0.11895500E+03, -.47439100E+01, 0.53178300E+02, 0.63004600E+02, 0.97930300E+02, 0.44937600E+02, -.23055800E+02, -.35154400E+02, -.22172800E+02, -.14968900E+01, 0.35083100E+00, -.25343600E+02, 0.17039900E+02, -.16769500E+02, -.25288900E+00, -.12214700E+02, 0.17753400E+03, -.91789900E+02, -.57088700E+02, -.88583100E+02, -.52775200E+02, -.60909000E+02, 0.52355700E+02, 0.83098500E+02, 0.86938000E+01, -.46044000E+02, -.45016800E+02, -.48326100E+01, 0.18959300E+01, -.73414000E-01, 0.16590200E+01, -.54874000E+01, 0.19564900E+01, -.21090200E+00, -.10528000E+01, 0.10535400E+01, -.15820100E+01, 0.28928600E+01, 0.76687900E+01, -.22943400E+01, 0.80805000E+00, 0.54909300E+01, -.13790700E+01, 0.30869300E+01, 0.78818100E+00, 0.51790100E+01, -.69624300E+00, -.14306600E+02, -.90687200E+01, -.74340200E+01, 0.24473700E+01, -.37588700E+00, -.64970800E+01 },
        { 0.37091900E+01, -.12403200E+01, 0.41617100E-01, 0.66214900E+00, 0.17851500E+01, -.41843700E+01, 0.67582900E+01, -.15001200E+01, 0.23652100E+01, -.35577700E+01, 0.92763900E-01, 0.29189100E+00, 0.10609100E+01, -.98692000E+00, 0.15970300E+01, 0.23879500E+00, 0.24305100E+00, -.39912800E+00, -.21516300E+00, 0.35007300E+01, 0.96825100E+00, -.25373000E+00, 0.36352600E+00, 0.25648000E+00, 0.15222000E+01, -.35709100E-01, 0.41802400E+00, 0.19021800E+01, -.33625300E+00, -.99417400E-02, -.35540500E+00, -.54422400E+00, -.68407300E+00, -.15584900E+01, -.10879300E+01, 0.74393800E-02, -.12595000E+00, -.30392600E+00, -.10892800E+01, 0.35621700E+01, -.76448700E-01, -.81150900E-01, -.28207700E+00, 0.49900200E+00, 0.95757100E-01, 0.78814500E-01, -.64020200E-01, -.98185700E-02, -.28978700E-01, 0.50971900E-01, 0.16622500E+01, 0.28887600E-01, -.61877200E+00, 0.12185600E+00, -.51557700E+00, 0.99701500E+00, -.52825100E+00, 0.11723800E+00, -.12348900E+00, -.64400200E+00, -.13702800E+00, -.12381600E+01, -.89916600E+00, -.28706900E-01, -.12430100E+01, 0.71140200E-01, 0.44288400E+00, 0.25603700E+00, -.19436200E+00, 0.27782800E-01, -.47544300E+00, 0.67040000E+00, 0.29126200E+00, 0.11563100E+00, -.46454900E+00, 0.17365100E+00, -.27557500E-01, 0.25693600E+00, -.15391200E+00, 0.12528800E+01, 0.11516300E+00, 0.14643900E+00, -.21958300E+01, -.26030800E+00, 0.86591400E+00, -.33356500E+00, 0.11778000E+01, 0.26272000E+00, 0.77825800E-01, -.47102100E-01, -.14276700E+01, -.87148800E-02, -.26901000E+00, -.14860000E+00, -.74839400E-01, 0.59519100E+00, -.22045700E+00, 0.58798100E+00, -.56625400E+00, -.53449100E+00, -.40105200E+00, 0.48201700E+00, 0.29757100E+00, -.11222900E+01, 0.66675700E+00, -.64912600E+00, -.60199800E+00, 0.76594800E+00, 0.92254000E-01, 0.16939500E+00, -.56768600E+00, 0.15926400E+00, 0.16649900E-01, -.89292600E-01, 0.36550800E-01, 0.11073400E+00, -.99491200E+00, -.36627300E-01, -.11018200E+00, 0.10516800E+00, -.46200600E+00, 0.67492900E+00, 0.11250800E+00, 0.26179100E+00, 0.35161700E-01, 0.19932800E+00, -.19315700E+00, -.41950100E+00, 0.27490900E+00, -.20948800E+00, 0.58137800E+00, 0.73099300E+00, -.19678500E+00, 0.15385700E-01, -.15408800E+00, 0.40125000E-02, -.82952100E+00, 0.15247400E+00, -.33060000E+00, -.64429900E+00, -.12837600E+00, -.17060700E+01, -.17524500E+01, 0.92630500E-01, -.18598300E+00, -.54452500E+00, 0.25779600E-01, 0.31241700E+00, 0.67976500E+00, -.33601600E+00, 0.25257300E+00, 0.11233200E+00, 0.67862700E+00, 0.19596900E+00, 0.62514800E-01, -.28885000E+00, 0.34989500E+00, -.15291100E-01, 0.81840400E+00, -.55277400E+00, -.59259600E-01, -.96125900E-01, -.57725700E+00, 0.41808600E-01, 0.76300500E+00, -.85179200E-01, -.71937700E-01, 0.46165700E+00, -.16245300E+00, 0.17807800E+00, 0.51212800E-01, -.17452000E+00, 0.39002800E-01, -.18766500E-01, 0.81694400E+00, 0.13555700E+01, -.94617400E-01, -.52770200E+00, 0.32310800E+00, -.63971400E+00, 0.38544200E+00, 0.22336700E+00, -.93007100E+00, -.24992700E+00, 0.10046800E+01, 0.10804700E+00, -.26014300E+00, 0.53372600E-01, -.31953800E-01, 0.59643400E-01, -.27183200E-01, -.24560100E+00, -.55030200E-01, 0.65911500E+00, -.67768100E+00, -.31462400E+00, 0.95354000E+00, 0.29576100E-01, 0.61057900E-02, -.48237300E-01, 0.63039500E+00, 0.49430800E-01, 0.69764500E-01, 0.50616300E-01, -.10371100E+01, 0.85132700E+00, -.28556600E+01, 0.15329400E+00, -.51399900E-01, 0.12397700E-01, 0.47495200E+01, -.33736400E+02, 0.64550100E+00, -.43905000E+02, 0.37296200E+02, -.16764800E+02, -.67673100E+02, -.15766200E+03, 0.52868400E+02, 0.10231700E+03, 0.15454300E+02, -.70281600E+01, 0.79896100E+01, -.77301400E+01, -.47390900E+02, 0.10353600E+03, -.45306500E+02, -.10272000E+03, -.10189900E+03, 0.10769100E+03, 0.21280600E+03, -.62048800E+02, 0.52707200E+02, 0.58431300E+02, 0.27038500E+02, -.27264200E+02, -.11336700E+03, 0.82830800E+02, 0.53746500E+02, 0.65383100E+02, -.96401500E+02, -.47187600E+02, -.20321500E+02, 0.11453800E+02, 0.49187100E+01, 0.11108500E+02, -.50178200E+02, 0.13322900E+03, -.75666000E+02, -.15439700E+03, -.13125800E+03, 0.12927700E+03, 0.27978000E+03, -.24366500E+02, 0.12309900E+02, -.45473900E+02, 0.13530800E+02, -.21876900E+01, 0.17259200E+02, 0.12597000E+02, 0.14787800E+02, -.69098800E+00, 0.15309500E+02, -.49025300E+02, 0.83068300E+02, -.44627000E+02, -.24915400E+02, -.41698500E+02, -.19109400E+02, -.55120100E+02, 0.49936900E+02, 0.66906300E+02, 0.28134200E+02, -.49285800E+02, -.35626400E+02, -.62156200E+01, -.30659700E+01, -.57224300E+01, -.62231000E+00, 0.99143500E+00, 0.45965400E+01, 0.33987000E+01, 0.12504900E+01, 0.11210400E+01, -.35541600E+01, -.16924100E+00, 0.11641300E+02, 0.14422400E-01, 0.16973400E+01, 0.13066100E+02, -.15545300E+01, 0.44325500E+01, 0.13423800E+01, 0.10625000E+02, 0.32800300E+01, -.35380300E+02, 0.40846000E+02, -.10754700E+02, -.66372200E+01, -.74226200E+01, -.11645800E+02 },
        { -.72136100E+01, 0.43646800E+01, 0.11731100E+01, -.48124800E+00, -.14246800E+01, -.15857900E+01, -.40354600E+01, -.13663900E+00, -.25642000E+01, 0.43093300E+01, 0.82484900E-01, -.27546700E+00, -.11339500E+01, 0.32835400E-01, -.22060500E+01, -.28577000E+01, -.64632900E+00, 0.28697200E+00, 0.62335500E+00, -.11121900E+01, 0.46016000E+00, 0.10003600E+00, 0.76378600E-01, -.87402200E-01, -.12842900E+01, 0.90420000E-01, -.80469400E-01, -.57661700E+00, 0.53140300E+00, 0.11894900E+01, 0.55078500E-01, 0.16517900E+01, -.48426800E-01, 0.38437800E+00, -.68996300E-01, 0.64436100E+00, -.13091000E+00, -.17026800E+00, 0.22647000E+00, -.63485100E+01, 0.11457100E+00, 0.47037200E+00, -.14931100E+01, -.16434200E+00, 0.72242800E+00, 0.34158600E-01, 0.42014300E-01, 0.20967900E-01, -.11003700E+00, 0.19715100E+00, -.93444400E+00, -.48674900E+00, 0.17977500E-01, -.25190100E+00, -.37672900E+00, 0.60041000E+00, -.67870900E+00, 0.76834000E-01, 0.15219200E-01, -.58157800E+00, 0.89083000E+00, 0.40521300E+00, -.14421400E+00, 0.10150200E+01, 0.14003300E+00, 0.43721700E+00, 0.15396900E+01, 0.47879000E+00, 0.33986500E+00, 0.70194200E-01, 0.16758900E+00, -.55574400E-01, -.37246400E+00, 0.31942000E-01, -.85768300E-01, 0.77270200E+00, -.21424600E+00, 0.68409900E+00, 0.16127900E+00, 0.23351400E+00, 0.60277200E-01, 0.26462900E-01, -.86942000E+00, 0.45831600E+00, 0.13545600E+01, 0.39935300E+00, 0.30593900E+00, 0.43588600E+00, 0.28121500E+01, -.11701000E+01, 0.25433500E+01, 0.74376300E-01, 0.30494300E+00, 0.72858700E+00, 0.18769800E+00, -.57795700E+00, 0.37216200E+00, -.48253700E+00, 0.71119000E+00, -.61815400E-01, 0.33510500E+00, -.55837700E+00, -.67635900E+00, -.89790100E-01, 0.14447100E+00, -.84892200E+00, -.16318400E+01, -.12011900E+01, -.90301200E+00, -.32109700E+00, 0.69186200E+00, -.18372800E+00, 0.31327800E+00, 0.28662800E+00, -.11110300E+01, -.40156300E-01, 0.23745800E+01, 0.88467500E-01, -.34581700E-01, 0.97633000E-01, -.86885900E+00, -.56357900E-01, 0.22479100E+00, 0.10619000E+01, 0.51160000E-03, 0.33552500E+00, -.11534100E+00, 0.31370500E+00, 0.13465800E+01, -.12164900E+00, 0.16863000E+01, 0.24235000E+01, 0.90225600E+00, 0.18623600E-01, 0.17049600E+00, -.11223300E-01, -.21375600E+01, 0.77409600E+00, -.74655300E+00, -.41620700E+01, -.15054200E+01, -.33515900E+00, 0.13802100E+01, 0.31151700E+00, 0.55209000E-01, -.34676800E+00, -.44827800E-01, 0.27614300E+00, 0.31072600E+00, -.93146300E-01, 0.38338600E+00, 0.29986700E+00, 0.95668100E+00, 0.55638200E-01, 0.13062500E-01, -.12562300E+00, 0.21319100E+01, -.17945900E-01, 0.53797200E+00, 0.83124700E+00, -.25254900E+00, -.15221200E+01, -.26840800E+01, -.10131300E+00, 0.17183900E+01, -.23889100E-01, 0.43416700E+00, -.76368800E+00, 0.53559600E-01, -.93512600E-02, 0.24843900E+00, 0.68811900E+00, -.18791300E+00, -.13939800E+00, -.96769100E-02, -.16311600E+01, 0.29841600E+00, -.23342000E+00, -.88402200E+00, 0.10317100E+01, 0.45534500E+01, -.56761400E+00, 0.21276200E+01, 0.20523600E+00, 0.12073100E+01, -.34303200E+00, -.22615500E+00, -.23364700E+00, -.21276700E+00, -.41671200E+00, -.14264400E-01, -.81089100E+00, -.45945200E+00, -.12353300E+01, 0.27218000E+01, 0.12644900E+01, -.82374800E+00, 0.23069600E+00, -.10387200E-01, -.14387700E+00, 0.68533800E+00, -.83238200E-01, -.13067300E+00, 0.46660300E+00, -.28076700E+00, -.73538800E+01, -.39838300E+01, -.22889300E+01, 0.14919700E+00, 0.10480500E+01, 0.95784400E-01, 0.10185200E+03, -.11283800E+00, -.14795900E+02, -.66038000E+02, 0.16454300E+02, 0.73662400E+02, 0.11004200E+03, -.34450300E+02, -.12036200E+01, 0.12422500E+02, -.68876900E+01, 0.58517100E+01, -.63796100E+01, -.47900200E+02, 0.58342600E+02, -.62315200E+02, -.64984300E+02, 0.12608900E+02, 0.50242500E+02, -.31848700E+02, -.10978000E+03, 0.54167900E+02, 0.29732400E+02, 0.55246900E+02, -.23673900E+01, -.72100500E+02, 0.93895500E+02, 0.70312900E+02, 0.94080100E+02, -.62613900E+02, 0.26845200E+01, 0.20269600E+03, -.10289600E+03, -.26974700E+02, -.10208200E+03, -.54748000E+02, 0.77262600E+02, -.16137300E+03, -.87427700E+02, -.31368200E+02, 0.65424800E+02, -.84482000E+02, -.74660500E+02, 0.39492800E+02, 0.42374300E+02, 0.36225400E+02, -.22571500E+02, -.53652300E+01, 0.65881000E+02, -.33153200E+02, 0.26146600E+02, 0.33864800E+01, 0.10434500E+02, -.28008500E+03, 0.14425700E+03, 0.14892900E+03, 0.13977500E+03, 0.52882000E+02, 0.56358700E+02, -.11085400E+02, -.10213200E+03, -.21096800E+02, 0.44021500E+02, 0.14793100E+03, -.63400000E+00, 0.41230600E+01, 0.15146700E+01, -.57773900E+01, 0.48092000E+01, -.20652900E+01, 0.13424500E+01, 0.23443400E+01, -.30363700E+01, 0.21435000E+00, -.21618100E+01, -.10925700E+02, -.11315300E+00, -.28813800E+01, -.27595200E+01, 0.45408300E+01, -.64190000E+01, -.67623300E+01, -.37812500E+01, 0.16141800E+01, 0.29966000E+02, 0.50369900E+02, 0.10569200E+02, -.13204400E+02, -.54584600E+01, 0.10720800E+02 },
        { 0.64430200E+01, -.13820900E+01, -.24724700E+00, 0.32928800E+01, 0.43347100E+01, -.75052900E+01, 0.77464700E+01, -.70736200E+01, 0.33212400E+01, -.50061900E+01, 0.56102300E-02, 0.37571600E+00, -.52325200E+00, -.20059300E+01, -.18777100E+01, -.12953200E+01, 0.27087700E+01, -.21556700E+00, -.27274000E+00, -.18516300E+01, -.25586600E+00, -.29685900E-01, -.10181000E+00, -.38157700E+00, 0.43312900E+01, -.45625200E+00, 0.14413900E+01, 0.25701100E+00, -.41320600E+00, -.22585700E+00, -.77762600E-01, 0.98519300E-01, 0.11031400E+01, 0.18825300E+00, 0.95574400E+00, -.13370600E+00, 0.13259100E+01, 0.14471400E+01, 0.13959400E+01, 0.10654100E+02, 0.14304900E+00, 0.17375200E-01, -.60001700E+00, -.57543300E+00, 0.11462800E+00, 0.25121900E+00, 0.11683400E+00, -.15922200E-02, -.22275100E+00, -.14813400E+00, 0.64709300E+00, -.11729600E+00, -.71705400E+00, -.29749400E+00, -.12797200E+01, -.74354800E+00, -.63636500E+00, 0.65767500E-01, -.97786500E-01, 0.32585500E+00, -.68372700E+00, 0.90100000E-01, 0.40337300E+00, -.67944800E+00, 0.19956200E+00, -.71304300E-01, -.10188400E+01, -.54341500E+00, 0.19834300E+00, -.18650300E+00, 0.11597200E+01, -.58308900E+00, -.43646500E+00, -.32421200E+00, 0.19785000E-01, -.53476800E+00, 0.36876100E-02, -.41950600E+00, -.86334500E-01, -.43045700E+00, -.10119000E+00, 0.39172400E+00, 0.13706600E+01, -.51056800E-02, -.17983700E+01, 0.12670300E+00, 0.55481600E-01, 0.19377900E-01, -.31953900E+01, 0.19838600E+00, 0.44237300E+00, -.47711800E-01, 0.44938800E+00, 0.24790500E-01, -.10439700E+01, 0.27682600E+00, -.38142100E+00, -.11431700E+01, -.24176800E+00, -.12557300E+00, -.16610800E+00, -.34391400E+00, -.39298100E+00, 0.14896600E+00, -.15240300E+00, -.21025300E+00, 0.22305900E+00, -.49798600E-01, -.37215200E+00, 0.91140700E-01, 0.35963700E+00, -.41052700E-01, 0.10589200E+00, -.10683500E+00, 0.17806800E-02, -.62916400E-01, -.49765900E+00, 0.48124500E+00, -.19293500E+00, -.14119200E+00, -.71343900E+00, 0.63347500E+00, 0.98395100E-01, 0.59385600E+00, -.37948700E-01, 0.56003100E+00, -.30237400E+00, -.25713300E+00, 0.92078300E+00, 0.32972900E+00, 0.37351400E+00, -.24672400E+00, 0.73370900E+00, 0.32573600E-03, 0.15841000E+00, 0.10355200E-01, -.14395300E+01, 0.14109900E+00, -.26138600E+00, -.92467300E+00, -.51923500E+00, -.16213000E+01, 0.24181100E+01, 0.70870400E+00, -.10156800E+00, -.83611200E+00, -.58019600E-01, 0.28307600E+00, 0.34209600E+00, -.71860100E+00, -.17038900E+00, 0.11555400E+00, 0.10282600E+01, 0.84492500E-01, -.56630600E-01, -.40734100E+00, 0.14686600E+01, -.67559800E-01, 0.33978800E+00, 0.42645800E+00, -.22766300E+00, -.12684300E-01, -.93348500E+00, -.24009900E-01, 0.30509200E+00, -.20102400E-01, 0.62437000E+00, -.27269400E+00, -.17590900E+00, 0.15775800E+00, 0.50085700E-01, -.30752500E+00, 0.54860500E-01, 0.14784300E+00, 0.67626700E+00, -.11097500E+01, 0.16679300E-01, -.30189900E+00, -.49431100E-01, -.17390600E+01, -.60779900E+00, 0.58772200E+00, -.13967100E+01, -.15513700E+00, 0.74559200E+00, 0.14788400E+00, -.12323200E+00, 0.78187100E+00, 0.16647800E-01, -.64383900E-01, -.36100400E-01, -.40331700E+00, -.24277300E+00, -.46036400E+00, 0.14262300E+01, 0.64683400E-01, -.95261700E-01, 0.31185900E+00, 0.42153300E-01, 0.18660700E-01, -.28986900E+00, 0.26640100E-01, -.23454000E+00, 0.37200400E+00, 0.70861000E+00, 0.73489700E+01, 0.13370700E+00, 0.11871000E+01, -.18721900E+00, 0.15164100E+01, -.13209700E+00, 0.32498500E+00, 0.10204600E+02, -.90915600E+01, 0.10849300E+02, 0.22012600E+02, 0.29336800E+01, -.19226800E+02, 0.16477500E+02, 0.26772700E+02, 0.74675400E+02, -.36817700E+02, -.44239000E+02, -.38094300E+02, -.60355200E+02, -.37689500E+02, 0.16114900E+02, 0.25657200E+02, 0.35015700E+02, -.51324800E+02, -.14978700E+03, 0.14665200E-01, -.34563900E+01, 0.11705900E+02, -.31601100E+01, 0.23675600E+01, -.19666900E+02, 0.38082000E+02, 0.26864700E+02, 0.17096500E+02, -.15770000E+02, -.25704500E+02, 0.17985000E+03, -.88369000E+02, -.57510100E+02, -.90690900E+02, -.82101800E+02, -.41095800E+02, -.28510800E+02, -.75275400E+01, -.76505200E+01, -.45451300E+02, -.15631000E+03, -.30434700E+02, 0.17617800E+02, 0.42077900E+02, 0.14010600E+02, 0.87127900E+01, 0.60348500E+01, 0.52845200E+01, -.10771400E+02, -.28607500E+02, 0.91415700E+01, 0.22407500E+01, -.84155300E+01, 0.45656100E+01, 0.42542000E+02, 0.22255500E+01, 0.54140100E+02, 0.31141200E+02, -.77542000E+02, -.47161400E+02, -.55579600E+02, 0.31659800E+02, -.34914300E+02, 0.57497700E+01, -.67674600E+00, -.11288800E+01, -.22339000E+01, 0.40109500E+01, 0.70358100E+00, 0.28447200E+01, 0.17287900E+01, -.68052100E+00, -.21448400E+01, 0.21229100E-02, 0.16535000E+01, 0.20763000E+01, -.63391700E+00, 0.28757300E+01, -.14567600E+01, 0.11229000E+01, 0.40795000E+00, 0.17797900E+01, 0.30301700E+01, 0.23284300E+01, 0.82445400E+01, -.59251400E+00, 0.71177800E+00, 0.21491600E+01, 0.26169200E+01 },
        { 0.71101200E+01, -.33273300E+01, -.31485400E+00, -.95559900E+00, 0.13270800E+01, -.30409300E+01, 0.10150100E+02, -.89530600E-01, 0.48023300E+01, -.60848700E+01, 0.64334200E-01, 0.75000500E+00, 0.35387500E+01, -.47285800E+01, 0.63907500E+01, 0.44729200E+00, -.25889000E+01, 0.13658800E+01, -.22134800E+01, 0.40669400E+01, 0.11293600E+01, -.41216000E+00, 0.36839800E+00, 0.58740500E-01, -.62582200E+00, 0.53455500E-01, 0.47324800E+00, 0.17800100E+01, -.12849600E+01, 0.91257000E+00, -.67074000E+00, -.48310900E+00, -.10117300E+01, -.11188200E+01, -.31304900E+00, -.29412600E+00, -.58080300E-02, 0.62705600E-01, -.25141200E+01, 0.51045700E+01, 0.91319200E-01, 0.11385000E+00, -.15797700E+01, 0.23817900E+00, 0.29146800E+00, -.19477900E+00, -.79781700E+00, 0.35873700E-01, 0.15087200E+00, -.72571100E+00, 0.33346800E+01, -.78423200E-01, -.37589200E+00, 0.10319100E+01, -.17342500E+01, 0.10822700E+01, -.59879500E+00, 0.19356300E+00, 0.21306700E+00, -.49972200E+00, 0.12859900E+01, -.13232800E+01, -.16429800E+01, 0.85759400E-01, -.19254200E+01, 0.16840500E+00, -.10227900E+01, 0.72614400E+00, 0.10947500E-02, 0.17269900E+00, 0.15682800E+01, 0.94555100E-01, 0.41315500E+01, 0.97315800E+00, 0.88894700E+00, 0.47894500E+00, -.52159100E+00, 0.19559800E+01, 0.46661000E+00, 0.37853100E+00, 0.18210300E+00, 0.57529500E+00, -.37030200E+01, 0.87695400E-01, -.87159700E-01, -.12200100E+01, 0.38884500E-02, 0.11181000E+01, 0.45089900E+01, -.74730200E+00, 0.95812400E+00, 0.52084400E-01, 0.26573500E+00, -.48367000E-01, -.57846400E-01, -.11377800E+01, -.45597900E+00, 0.42834600E+00, -.87743700E+00, -.93122200E+00, -.55507600E+00, 0.20497000E+00, 0.38979700E+00, -.17681600E+01, 0.85980100E+00, -.21448400E+01, -.33895500E+00, 0.17822400E+00, 0.18248300E+00, -.85496900E-01, -.16289600E+01, -.17189400E+00, -.17156200E+00, -.31030300E+00, 0.23921400E-01, -.11626100E+01, 0.66818000E+01, -.12763000E+01, -.54899400E+00, -.60273400E+00, 0.39111500E+00, -.43013300E+00, 0.35380200E-02, -.76702800E+00, -.54395300E-01, 0.42878400E+00, -.79170900E-01, -.96777600E+00, -.10730500E+01, -.73935000E-01, 0.41072000E+00, -.25635100E+01, 0.35011100E+00, -.17398600E-01, 0.68942200E+00, -.18220600E-02, -.83309900E+00, -.18470300E+00, 0.60890600E-01, 0.24358900E+01, 0.13869900E+01, -.77535700E+00, -.12250300E+01, 0.47878400E+00, -.14992200E-01, -.38039000E+00, -.62738800E-01, -.33858800E-01, 0.29378200E+00, -.15142500E+01, -.10477500E+01, -.37535000E+00, -.19935500E+01, -.10841400E+01, -.23391400E+00, 0.27386100E-02, -.35235700E+01, -.60505600E-01, -.81798100E+00, -.10820200E+01, 0.21912700E+00, 0.17994300E+01, 0.13395300E+01, -.23170900E+00, 0.35605700E+00, 0.41575900E+00, -.77203100E+00, 0.16448500E+01, -.31596800E+00, 0.16895300E+00, 0.22827900E+00, -.37178700E+01, -.17835500E+00, 0.43760100E+00, 0.30347600E+00, 0.32680400E+01, -.51232500E+00, -.11466700E+00, 0.12009400E+00, 0.89658600E+00, 0.35971300E+01, 0.44202500E+00, 0.85408200E+00, 0.20352900E+00, -.13835700E+01, 0.56030300E-01, -.74941800E-01, -.16571400E+00, 0.27599800E+00, 0.14663900E+01, 0.90275700E-01, 0.45984900E+00, 0.99815600E+00, -.35355200E+00, -.76393400E+00, -.61154300E+00, -.14265100E+01, -.29382800E+00, -.15622900E+00, 0.62629900E+00, 0.42597000E+00, -.18014900E-01, 0.61147100E+00, 0.36792600E+00, 0.15790800E+01, -.12894300E+02, 0.17198300E+00, -.11606100E+01, -.43296300E+00, -.21087000E+01, -.43296300E+00, 0.83252200E-01, 0.22243900E-01, 0.12610000E+03, 0.13465000E+03, -.14189000E+03, -.62827700E+02, -.87211800E+02, 0.98996400E+02, -.14276600E+03, -.40591900E+03, 0.20216200E+03, 0.16025600E+03, 0.20299100E+03, 0.15036700E+03, -.29760400E+02, 0.90625600E+02, 0.58645600E+02, 0.12160500E+03, -.51673500E+02, 0.69933300E+02, 0.11560700E+02, -.11608000E+02, -.64053900E+02, -.47945800E+01, 0.16500100E+02, 0.33518800E+02, -.34667600E+02, -.24456800E+02, 0.24965500E+02, 0.32551600E+02, 0.54784000E+02, -.68667800E+03, 0.34360600E+03, 0.30911900E+03, 0.34361600E+03, 0.17465000E+03, -.42699800E+02, 0.23523300E+03, 0.12718400E+03, 0.21837900E+03, -.70417100E+02, 0.49396200E+02, 0.22555500E+03, -.11069500E+03, -.10017600E+03, -.11234000E+03, -.20823900E+02, -.64766700E+02, 0.23232700E+01, 0.10874700E+03, -.68463000E+02, -.58272100E+02, -.62221600E+02, 0.36237400E+03, -.18586800E+03, -.17388100E+03, -.18125800E+03, -.83737600E+02, -.72735000E+02, 0.20738900E+02, 0.10289400E+03, -.16410600E+02, -.37727600E+02, -.14117300E+03, 0.11421700E+02, 0.81789600E+00, 0.60609800E+01, 0.37759100E+00, -.41734400E+01, -.13317200E+01, -.85859000E+00, 0.16108500E+01, -.10494200E+01, -.21226900E+01, 0.77164400E+01, -.81836500E+01, 0.18512700E+01, 0.57559900E+00, -.78449200E+01, 0.75515300E+01, -.38033000E+01, 0.60459900E+00, -.58593700E+01, -.23342500E+00, -.82894800E+01, -.58077900E+02, 0.87667900E+01, 0.14727100E+02, 0.85308500E+01, -.62232300E+01 },
        { -.44538400E+01, 0.36889600E+01, 0.49262400E+00, 0.23145400E+01, -.13235500E+01, -.53235500E+01, -.86787700E+00, -.54099400E+01, -.15203000E+01, 0.27209100E+01, 0.39598000E+00, -.14937200E+00, -.15420600E+00, -.38965000E+01, -.19226500E+01, -.11411800E+01, 0.40843600E+00, -.45622100E+00, 0.89517100E+00, -.35115800E+01, -.12189500E+00, 0.14041300E+00, 0.90043900E-01, -.72710800E+00, 0.46441100E+01, 0.13254500E+00, 0.16523700E+01, 0.40135300E+00, -.77326100E+00, 0.13614600E+01, 0.18588500E+00, 0.39378400E+00, 0.18864400E+01, 0.97983000E-01, 0.41281700E+00, -.42910700E+00, -.67087700E-01, 0.42555500E+00, -.16460500E+01, -.72966600E+01, 0.73306800E+00, 0.69217900E-01, -.19398900E+00, -.79327200E-01, -.14158700E+00, 0.79294600E-01, -.83438600E-01, 0.19536200E-01, -.13068700E+00, -.23510400E-01, -.13638800E+01, 0.51894400E+00, 0.53866100E+00, 0.84004100E+00, 0.23368400E+01, -.46381400E+00, 0.11221400E+01, -.29366500E+00, 0.10878800E+00, -.62117600E+00, -.24613100E+00, 0.11899200E+01, 0.69417800E+00, -.33385400E+00, -.77784700E+00, 0.10419800E+00, -.23573800E+01, -.18872700E+00, -.77512000E+00, -.50643700E-02, -.27377800E+00, 0.20871000E+00, 0.19656500E+01, 0.93968200E-01, 0.10140600E+00, -.28485800E+00, -.51243000E+00, -.86001100E+00, -.31186900E+00, 0.34037100E+00, -.10146900E+00, 0.64549500E+00, -.10390200E+01, -.51574800E-01, -.49111600E+00, -.27064900E+00, -.11304300E+01, -.64226800E+00, 0.17972800E+01, 0.63813400E-01, -.15132600E+01, -.12816300E-01, 0.97789200E-01, -.61314900E+00, -.28190000E+00, -.12160700E+01, -.51266100E-01, -.88622600E+00, 0.30024500E+00, 0.82014800E-01, 0.98626200E-01, -.24679400E+00, 0.16506600E+00, -.29747000E+00, 0.29485900E+00, 0.16859400E+00, 0.71429300E+00, 0.80820400E+00, 0.70348700E+00, -.40351400E-02, -.10288300E+01, 0.30446600E+00, -.17028800E-01, 0.29215000E+00, 0.11325800E+01, -.64413400E-01, 0.46229000E+01, 0.13829100E+00, -.44931200E+00, -.82283900E+00, -.13662600E+00, 0.28749300E+00, 0.13266400E+00, -.10495300E+00, -.20660400E-01, 0.10943300E-01, -.76934100E-01, -.89384100E+00, 0.15151100E+01, 0.66764400E-01, -.14989600E+01, -.13793700E+01, 0.97369800E+00, -.74098300E-02, -.26474600E-01, 0.11257300E-01, 0.12762200E+01, -.40861800E+00, -.22600500E-01, 0.43662700E+01, 0.59499700E+00, -.34744200E+00, 0.18523000E+00, 0.65582200E-01, 0.38320300E-01, 0.15948400E+00, 0.26836600E-01, -.12219300E+00, -.14669000E+00, -.12184600E-01, -.24807500E+00, -.12720100E-01, -.24101000E+01, 0.75209700E+00, -.13333500E+00, -.34944100E+00, -.88329800E+00, -.10323700E-01, 0.91500600E+00, -.17712000E+01, 0.10950300E-01, -.73130200E+00, -.13692400E+01, 0.38761200E+00, 0.92935200E-03, -.20330900E+00, 0.25820700E+00, 0.59365100E+00, -.68896100E-02, -.10261900E+00, -.42105300E-01, -.19269800E+00, 0.10048600E+00, 0.69255500E-01, 0.99257400E+00, -.22099600E+01, 0.24075900E+00, 0.26748300E+00, -.15399500E-01, -.96602400E-01, 0.29845000E+01, 0.10546100E+00, 0.10594800E+01, -.41048800E+00, -.61812200E+00, -.29828200E+00, -.17798500E+00, 0.10670300E+01, 0.45430500E-01, -.41872900E-01, 0.25453900E-01, -.17438600E+00, 0.77111800E-01, -.11653600E+01, 0.10634500E+01, 0.43290600E+00, 0.85184300E+00, 0.21470000E+00, -.56942900E-01, 0.43905400E+00, 0.84650300E+00, -.11623800E+00, 0.30028500E+00, 0.15336900E-01, -.64916200E-01, -.72633700E+01, -.41980800E+00, -.13508600E+01, -.19564600E+00, 0.54565300E+00, 0.79267200E-01, 0.99968800E-01, -.66643300E-01, 0.41142100E+00, -.66985500E+02, 0.58239700E+02, 0.94539400E+02, 0.14987600E+03, -.48828500E+02, 0.35581700E+02, 0.45736500E+03, -.22903100E+03, -.23038300E+03, -.22875600E+03, -.13915000E+03, -.72696000E+02, -.57637500E+02, 0.85532100E+02, -.59908600E+02, -.64230700E+02, -.10394600E+03, -.12076800E+03, 0.64517200E+02, 0.56767600E+02, 0.61880400E+02, 0.27002800E+02, 0.50939500E+02, -.36055900E+01, -.40285200E+02, 0.58688000E+01, 0.43579300E+02, 0.59053300E+02, 0.70913900E+03, -.35575400E+03, -.28337600E+03, -.35566400E+03, -.18228700E+03, -.10688200E+03, -.11999500E+03, 0.87869600E+02, -.13573000E+03, -.77681300E+02, -.10791100E+03, -.14363700E+03, 0.70064700E+02, 0.98007600E+02, 0.70207500E+02, -.18790800E+02, 0.97549400E+01, 0.16683000E+02, -.64096800E+02, 0.80860000E+02, 0.16684400E+01, 0.56512400E+02, -.31239500E+03, 0.15442000E+03, 0.98013000E+02, 0.15631900E+03, 0.11147700E+03, 0.15725600E+03, -.13558800E+03, -.19669800E+03, -.61113400E+02, 0.10161100E+03, 0.23137300E+03, -.19247900E+01, 0.49903400E+01, 0.13369100E+01, 0.12187400E+01, 0.14145800E+02, -.32260300E+01, -.14746500E+01, 0.98136900E+00, -.17532100E+01, 0.22029300E+01, -.94129500E+00, -.90373000E+01, -.82802800E-01, -.34897000E+01, -.51289000E+01, -.21724600E+01, -.17337700E+01, -.10353100E+01, -.37261900E+01, -.55074500E+00, 0.37471700E+02, 0.22740900E+01, 0.69458200E+01, 0.23882300E+01, -.28365700E+01, 0.12987800E+02 },
        { -.16717900E+01, -.46269300E+00, -.26563300E-01, 0.25796200E+00, -.60050300E+00, -.19696500E+01, -.76663000E+00, 0.30063400E-02, -.10033800E+01, 0.12031700E+01, 0.47377900E-01, -.11000600E+00, -.15443900E+00, 0.21301700E+00, -.33835400E+00, 0.82647200E+00, 0.38551400E+00, -.25739200E+00, -.29877200E+00, -.48780900E+00, -.22303600E+00, 0.11082400E+00, 0.23011500E-01, 0.26095700E+00, -.94644000E+00, -.23803200E-01, -.81373200E-01, -.25984000E+00, 0.23242100E+00, 0.48013700E+00, -.31922600E+00, -.90530500E-01, -.14486400E+00, -.48805200E+00, 0.87561400E-01, -.24002900E+00, 0.10656800E+00, -.79840500E+00, -.19921100E-01, -.33304900E+01, -.40973400E-01, -.50102900E+00, 0.47615000E-01, 0.84037100E+00, -.35854600E-02, 0.90685600E-01, -.55229700E-02, -.10889600E-01, 0.80774100E-01, 0.19897900E+00, 0.11083300E+01, -.28052800E+00, -.30345400E+00, -.91518600E+00, -.45331100E+00, 0.29684100E+00, -.21976900E+00, 0.52919600E-01, -.91543700E-02, -.17211800E-01, 0.17567200E+00, 0.30097900E+00, -.11641300E-01, -.55286200E+00, 0.48394800E+00, -.21065400E-01, 0.24177700E+00, -.54611600E-01, 0.16750900E+00, 0.36975700E-01, -.81632600E-01, -.51717900E-01, -.19851100E+00, 0.77767400E-01, 0.17894700E+00, -.27581800E+00, 0.35556100E-01, -.67393200E-01, 0.94783600E-02, -.11451400E+00, 0.55473000E-01, 0.70863100E-01, 0.33724100E+00, 0.10046700E+00, -.10183600E+01, -.14772300E+00, 0.58862900E+00, -.10198600E+00, -.40058000E+00, 0.79986800E-01, 0.58092100E+00, 0.17247100E-01, -.21037600E+00, 0.46331800E+00, 0.78171100E-01, -.66546900E+00, 0.16067100E+00, -.65653500E+00, 0.13255000E+00, 0.14551800E+00, 0.35914300E-01, -.44703100E+00, -.13957200E+00, 0.87309300E-01, 0.30496000E+00, 0.82390300E-01, -.19930800E-01, 0.22971900E+00, 0.24796500E+00, -.30546100E-01, -.80904400E+00, 0.99399100E-01, -.52134500E-01, -.22541400E+00, 0.46189600E+00, 0.70001100E+00, 0.32921700E+00, -.53670400E+00, 0.15252800E-01, -.83420400E-01, 0.13207100E+00, -.47899800E+00, -.83724800E-01, -.31224100E+00, -.56421400E-02, 0.21851100E+00, -.69475900E-01, -.33490700E+00, -.19593500E+00, -.64333100E-01, 0.76186100E-01, -.14458900E+01, 0.47103700E-03, -.17634700E-02, 0.19980800E-01, 0.62200000E-02, -.83472600E+00, 0.17507400E+00, 0.20598100E-01, 0.53715100E+00, 0.27856400E+00, 0.19382100E-01, -.44212700E+00, -.24981300E+00, -.69375000E-01, 0.39615300E+00, 0.12052900E-01, -.46655200E-02, -.18734500E+00, 0.34214400E+00, 0.14705700E+00, 0.77347500E-01, 0.67770200E+00, -.10644100E+00, 0.10575000E+00, -.67177500E-01, 0.35813700E+00, -.57969800E-02, 0.43027800E+00, 0.22585500E+00, -.44499900E-01, -.29072800E+00, -.79850700E-01, -.39165700E-01, 0.26030000E+00, 0.24388900E-01, -.98224600E-01, 0.27630100E+00, 0.18034500E-01, 0.80092200E-03, -.13354600E-01, -.28759100E-01, 0.48299500E-01, -.36511700E-01, 0.15562800E-01, -.68662700E+00, 0.15046600E+00, 0.28008900E+00, -.83119900E-01, -.40648800E+00, 0.65537400E+00, 0.89080100E-01, -.17264900E+00, 0.15685400E+00, -.93896000E-01, -.18364900E-01, -.47913400E-02, 0.11526400E+00, 0.16579400E-01, 0.19065900E+00, 0.24785200E-01, 0.78888600E-01, 0.17352600E+00, 0.10688800E+00, -.93770300E+00, -.41522300E+00, 0.37892400E+00, -.79772500E-01, -.30079300E-01, -.22334200E-01, 0.68307400E+00, -.36255400E-01, 0.20765900E+00, 0.71818100E-01, -.58382800E+00, 0.45276100E+00, -.23529300E+00, 0.45241800E+00, -.75347800E-01, 0.45218000E+00, -.22577600E+00, 0.11139800E+00, -.82222400E-03, 0.12420600E+00, -.13577300E+00, 0.29790700E+02, 0.10079200E+02, 0.13837000E+02, 0.11790600E+02, 0.11294800E+02, 0.23027700E+03, -.11493000E+03, -.11249700E+03, -.11509100E+03, -.46401600E+02, -.53423900E+02, -.27270300E+02, 0.26142800E+02, -.23176800E+02, -.54163100E+02, -.14579800E+03, -.16423000E+02, 0.76287600E+01, 0.22190400E+02, 0.81826500E+01, 0.16857900E+01, -.38118600E+01, 0.16537600E+02, 0.10720700E+02, 0.10674600E+02, -.25477800E+01, -.18737900E+02, 0.30874400E+03, -.15408400E+03, -.13934900E+03, -.15434100E+03, -.62610000E+02, -.70649700E+02, -.63066500E+02, -.20356600E+02, -.54066700E+02, -.55277700E+02, -.11585100E+03, -.34233800E+02, 0.17553100E+02, 0.15690600E+02, 0.17179200E+02, 0.16177400E+01, 0.10869900E+02, -.50316100E+01, -.21290500E+02, 0.11005200E+02, 0.77649200E+01, -.10455900E+01, -.14438900E+03, 0.73250900E+02, 0.35060200E+02, 0.72337300E+02, 0.36872500E+02, 0.45029500E+02, -.36543700E+02, -.65253300E+02, -.14739300E+02, 0.28834200E+02, 0.58096700E+02, 0.42774400E+01, 0.16557100E+01, -.49037000E+00, -.16391700E+01, 0.37271800E+01, 0.12721700E+01, 0.15114300E+01, 0.11298400E+01, -.35355700E+00, -.70713400E+00, -.21096700E+01, -.20540700E+01, 0.15261300E+01, 0.82001700E-01, -.26692300E+01, 0.98612200E+00, -.28341400E+01, -.34554300E+00, -.21718000E+01, 0.15336900E+01, 0.73800700E+01, -.33248700E+01, 0.24925700E+01, 0.31470000E+01, -.40667300E+01, 0.57865600E+01 },
        { -.59783800E+01, 0.22535200E+01, 0.85505100E+00, -.96416900E+00, -.94425500E+00, -.16059900E+01, -.36809600E+01, -.79176000E+00, -.22211300E+01, 0.37087800E+01, 0.10032600E+00, -.20352400E+00, -.31519900E+01, 0.22668600E+01, -.31973300E+01, -.39241800E+01, 0.79234800E+00, 0.39696400E+00, 0.12557000E+01, -.64266100E+00, 0.27775000E+00, 0.91696900E-01, -.11391000E+00, -.12768700E+00, -.10787200E+01, 0.55668500E-01, -.17159400E-01, -.56216200E+00, 0.59142500E+00, 0.64360000E+00, 0.23633300E+00, 0.11669700E-01, -.45358800E+00, 0.13108900E+01, 0.19953700E+00, 0.51741800E+00, -.21645200E-01, 0.12622200E+00, -.13578400E+01, -.11176800E+02, 0.30033100E+00, 0.45853500E+00, -.13940900E+01, -.58722800E-01, 0.42249900E+00, -.21075400E+00, -.29852200E+00, -.66675900E-02, 0.15140000E+00, 0.83684200E-01, 0.12544400E+01, 0.83151800E-01, 0.11599900E+00, 0.34368500E-01, -.45724300E+00, 0.29529000E+00, -.29884000E+00, 0.81702800E-01, -.17288600E-02, -.38813600E+00, 0.15592100E+01, 0.20049100E+01, 0.43792900E+00, 0.56453200E+00, 0.62787000E-01, 0.13757800E+00, 0.20788400E+00, 0.36450700E+00, -.90605500E-02, 0.74242700E-01, 0.36313300E+00, -.30190100E+00, -.39519000E+00, -.30553600E+00, -.79645600E-01, 0.25354300E+00, -.11500400E+00, -.12022800E+01, 0.79803100E-01, -.21417600E+00, 0.94337300E-02, -.26867000E+00, 0.72511500E+00, -.17475900E+00, 0.14690000E+01, 0.48272900E+00, -.21250000E+01, -.79476000E+00, -.28216400E+01, 0.26843000E+00, 0.19571900E+00, 0.12522500E+00, 0.23885500E+00, -.38754300E+00, -.14576600E+01, 0.20332600E+01, -.81110100E+00, -.17211600E+01, -.36094800E+00, -.20272600E+00, 0.40735600E+00, -.73070500E+00, -.39064200E+00, -.17339000E+00, 0.13531700E+00, -.17121800E+01, -.16658100E+01, -.19611100E+01, 0.17984200E-02, -.35671400E+00, -.37928900E+00, 0.26127000E-01, 0.13659500E+00, -.33213700E+00, -.11234600E+01, 0.10015900E+01, -.81468100E+00, -.86450100E+00, -.51070900E-01, 0.87225600E+00, -.94567300E+00, 0.13155200E+01, 0.31709400E+00, 0.15439000E+01, 0.80789800E-01, 0.20631000E+00, -.30735000E+00, 0.61208800E+00, -.64334500E-01, 0.11265700E+01, -.86567700E-01, 0.23873000E+01, -.10165900E+01, 0.20961100E-01, 0.34763500E+00, -.34965300E-02, 0.12715900E+00, 0.14186100E+00, -.51497800E+00, -.36688800E+01, -.58587700E+00, -.20656500E+01, 0.43361800E+00, 0.48469300E+00, 0.24502200E+00, -.46971600E+00, -.95707000E-01, -.76110700E-01, 0.24133000E+00, -.89057200E+00, -.37932400E-01, 0.13406500E+00, -.45574100E+01, 0.59891700E+00, -.23278500E+00, -.23806500E+00, 0.17992100E-02, -.17503200E-01, 0.18239500E+01, -.22907200E+01, 0.65089100E-01, -.11565000E+01, -.23477700E+01, -.75723100E-01, 0.18423300E+01, -.36923000E-01, -.55295200E+00, 0.18117100E+01, -.28548300E-01, -.10827900E+00, 0.47388300E+00, -.67314100E+00, -.10290900E+00, -.14682700E+00, 0.59954700E+00, -.48029100E+01, 0.58923800E+00, 0.51062300E-01, 0.17432100E+00, 0.91543900E+00, 0.69635000E+01, -.11450400E+01, 0.23605500E+01, -.30987200E+00, -.40744200E+00, -.35507600E+00, -.29803500E+00, 0.12796800E+00, -.10223000E+00, -.26374400E+00, 0.20224900E-03, 0.80864300E-01, -.18593800E+00, 0.66196600E+00, 0.21869300E-01, 0.47996500E+00, 0.32110200E+00, -.51590900E+00, -.14763000E+00, -.15842300E+00, 0.12141700E+01, -.24110400E-01, 0.41385400E+00, 0.19785600E+00, -.11051200E+01, -.10022700E+02, -.36173400E+01, 0.28076400E+01, -.58278900E+00, 0.39382900E+00, 0.23718200E+00, 0.72342600E+00, 0.21256900E-01, 0.29605000E+00, -.59299300E+00, 0.20928400E+01, 0.73671000E+02, 0.13807600E+03, -.93423700E+01, -.16439000E+03, -.24937000E+03, 0.12319400E+03, 0.88565200E+02, 0.12469600E+03, -.77341700E+02, 0.32472700E+00, 0.15125300E+03, 0.22853300E+03, 0.26375500E+03, -.19549300E+02, 0.10761000E+03, -.12573300E+03, 0.65800000E+02, 0.17024100E+02, 0.62300600E+02, 0.38318600E+02, 0.93583500E+02, -.37941600E+02, -.67198900E+02, -.21873700E+02, 0.88522000E+02, 0.82274800E+02, -.46395800E+02, 0.20776800E+02, 0.12994000E+03, 0.23258600E+02, -.11030300E+03, 0.18017600E+02, 0.17344100E+03, 0.37982600E+03, 0.23184700E+03, -.34914800E+02, -.41370300E+02, -.65989200E+02, 0.30559800E+02, 0.13128000E+03, 0.33173200E+02, 0.37514800E+01, 0.12912700E+02, 0.17772200E+02, 0.37695500E+02, 0.28791600E+02, 0.21654200E+02, 0.37532300E+02, -.76126600E+01, -.28040700E+01, -.46649500E+02, 0.38269800E+01, 0.10759600E+03, 0.55353500E+02, -.82240000E+02, -.58133700E+02, -.33777100E+02, 0.45008800E+02, 0.67585900E+02, -.58856400E+01, -.80180400E+01, 0.61142000E+01, 0.32987100E+01, 0.87845300E+01, -.10997300E+02, -.62956500E+00, 0.63823000E+00, -.38587300E+01, 0.60901000E+01, 0.83248700E+01, 0.39218000E+01, -.19746300E+01, -.37188100E+01, 0.50749000E+01, -.58414500E+01, 0.70590600E+01, -.49359400E+01, 0.62237900E+01, 0.77202200E+00, 0.20978300E+02, 0.10513400E+02, -.72812500E+01, -.72330000E+01, 0.15013200E+02, -.14416400E+01 },
        { 0.15200600E+02, -.76916400E+01, -.11730700E+01, -.38456400E+01, 0.53084500E+01, 0.72382100E+01, 0.11723700E+02, -.31832000E+01, 0.84353300E+01, -.99343800E+01, 0.17823500E+00, 0.12345200E+01, 0.36889100E+00, 0.25905000E+01, 0.95173800E+00, -.77468800E+00, 0.15510500E+01, 0.69603300E+00, 0.24672400E+00, 0.46482500E+01, 0.89971700E+00, -.80768000E+00, -.20564800E+00, 0.38987400E+00, -.12179800E+01, -.20472100E+00, -.11164400E+01, 0.24653500E+01, -.67930100E+00, -.23555900E+01, -.29806200E+00, -.17202100E+01, -.14878100E+01, 0.22768200E+01, -.10028100E+01, -.59482800E-01, 0.62090400E-01, -.12583700E+00, 0.14398300E+01, 0.59406300E+01, -.82452300E+00, -.48460500E-01, 0.18691500E+01, -.35372600E+01, -.48338200E-01, -.44784000E+00, 0.33581800E+00, -.33480800E+00, -.22455200E-01, -.51107300E+00, -.52028800E+00, 0.83604100E-01, 0.35293500E+00, 0.25852700E+01, 0.97584800E+00, -.17127800E+01, 0.54959400E+00, -.13491800E+01, -.63504400E-01, 0.86665200E+00, 0.18691500E+01, -.22032700E+01, -.18073200E+01, 0.21654200E+01, -.19243300E+01, -.27426400E+00, -.13520400E+01, -.14383700E+00, -.10679400E+01, -.28432600E+00, 0.11378500E+01, -.11411600E+00, 0.13453400E+01, -.39154700E+00, -.20038100E+01, 0.20429800E+00, 0.67538600E+00, -.59722400E+00, 0.13309500E+00, -.10051700E+01, -.13609400E+00, -.59157200E+00, 0.26637800E+01, 0.50864000E+00, -.10237600E+01, -.32174800E+00, -.56935600E+01, 0.26644900E+01, -.16808700E+01, 0.10490600E+01, -.22069900E+01, -.79315600E-02, -.83095700E+00, -.77637900E-01, 0.20869300E+01, 0.16864100E+01, -.57437700E+00, 0.26741900E+01, -.15413200E+01, -.76225100E+00, 0.38155200E-02, 0.86380500E-01, -.12713200E+01, 0.19851400E+01, -.12629300E+01, -.13114700E+00, 0.16756200E+01, -.11950900E+01, -.26357600E+01, 0.42059200E-01, 0.78410500E+00, -.70729000E+00, -.35891000E+00, -.54060500E+00, 0.40912200E+00, 0.77938800E+00, -.69853500E+01, -.16413700E+01, 0.14361100E+01, -.49628900E+00, 0.12138500E+01, -.30810400E+01, -.27561100E+00, -.13045200E+01, -.12702000E+00, -.12431000E+01, -.48236900E+00, 0.42925300E+01, -.31192800E+01, -.70599100E+00, 0.21264200E+01, -.44462400E+01, 0.80961900E+00, 0.39920800E-01, 0.59021100E+00, 0.68625100E-01, 0.98671900E+01, -.14124000E+01, 0.15485900E+01, -.24507200E+01, 0.13231500E+01, 0.56523400E+01, 0.12551500E+01, 0.47781500E+00, 0.92554800E+00, -.29495400E+01, 0.22504900E+00, -.14540800E+01, 0.49515300E+00, -.75610300E+00, -.10347600E+01, -.33075400E+00, -.38991100E+01, -.83961500E+00, -.12565100E+00, 0.38680400E+00, -.51084700E+01, -.32038900E-01, -.75621600E+00, -.17713400E+01, 0.59458700E+00, 0.49620600E+01, 0.39216500E+01, 0.95314300E+00, -.40948300E+01, 0.85071000E+00, -.32141700E+01, -.10769900E+01, 0.26297200E+00, 0.30214100E+00, -.11340000E+01, 0.24607300E+01, -.47611900E+00, 0.16462900E+01, -.39189800E+01, 0.20996300E+01, -.60078400E+00, -.10136600E+00, 0.11598900E+01, 0.53911400E+00, 0.11245600E+02, -.73966900E+00, -.11132900E+00, -.24241300E+01, -.99215200E+00, -.52020000E+00, -.71727200E+00, -.22681300E+00, 0.10947800E+01, -.74238800E+00, -.47832400E-01, 0.56080000E+00, -.18323500E+00, -.34617100E+01, 0.10669300E-01, -.15342400E+00, -.71860100E+00, 0.43935300E+00, 0.86271700E+00, 0.69186200E+00, -.13650400E+01, 0.23412000E+00, -.56468500E+00, -.15329200E+01, -.16221400E+00, -.17032800E+02, 0.53060300E+01, 0.36966700E+01, -.30987900E+00, -.22034100E+01, 0.79021600E+00, -.57249900E+00, -.12438600E+00, 0.10998100E+01, 0.17055400E+01, -.22160500E+01, -.80168100E+00, 0.19749100E+03, 0.29991200E+01, -.40590900E+03, -.61009300E+03, 0.30087800E+03, 0.37087600E+03, 0.30542600E+03, 0.73277500E+01, 0.77252000E+02, 0.13798500E+03, 0.24573300E+03, 0.64854100E+03, 0.19677100E+02, -.23793100E+03, -.24515400E+03, 0.12614400E+03, 0.17103900E+03, 0.12272900E+03, 0.46957600E+02, 0.84400500E+02, 0.27670900E+02, -.52054900E+02, 0.14662400E+02, 0.85054200E+02, 0.38171800E+02, -.17430100E+03, 0.80898900E+02, 0.32430900E+03, 0.87959400E+02, -.27265300E+02, 0.17232700E+03, 0.46468400E+02, 0.37636600E+03, 0.57953000E+03, 0.31045600E+02, -.54576900E+03, -.11547300E+03, 0.58467500E+02, 0.16117000E+03, 0.59226000E+02, 0.22559100E+01, 0.66698800E+02, -.77443600E+02, -.51714000E+02, 0.14871600E+02, 0.76446200E+02, 0.30444400E+02, -.67498100E+03, 0.34875400E+03, 0.24790600E+01, 0.33832900E+03, 0.12044400E+03, -.50829300E+02, 0.79594900E+02, -.92391400E+02, 0.23170300E+03, -.18841800E+02, 0.25565200E+03, 0.98367700E+01, -.43938700E-01, 0.12002200E+02, -.27007400E+01, -.58688100E+00, 0.88479500E-01, 0.13190600E+01, 0.38786500E+01, -.60725000E+01, 0.53968500E+01, 0.48477800E+01, 0.77688200E+00, 0.31016100E+01, -.46186900E+00, -.14143300E+01, 0.72375900E+01, -.83504800E+01, -.11035400E+02, 0.43556900E+01, -.15614200E+01, 0.18286600E+02, 0.83985800E+02, -.35818400E+01, -.34493300E+02, 0.11015100E+01, 0.21392700E+02 },
        { -.55931500E+01, -.70846400E+01, -.78143400E+00, -.43106800E+01, -.15189800E+01, 0.85941200E+00, -.63287100E+01, 0.29510400E+00, -.30987000E+01, 0.52200300E+01, 0.13144100E+00, -.30418500E+00, 0.18954900E+01, 0.24785000E+01, 0.20130800E+01, -.64302500E-02, -.15302800E+01, 0.26109900E+01, -.20825700E+01, 0.20351400E-01, -.19543300E+00, 0.21124300E+00, -.12652800E+00, 0.45000900E+00, -.46184700E+01, -.34128700E-02, -.85093700E+00, 0.11283500E+01, -.75771100E+00, 0.15456600E+01, -.11373200E+01, 0.70758100E+00, -.21986700E+00, -.56071500E+00, 0.29558800E+00, -.43869800E-01, 0.27803500E+00, -.45117500E+00, -.98926100E+00, 0.35048000E+01, -.17795400E+00, 0.71316500E-01, -.38877900E+00, 0.46992800E+00, 0.40116100E+00, 0.13989800E+00, 0.53769100E+00, -.83673500E-02, -.76397500E-01, -.21556400E+00, 0.16190800E+01, -.38208500E-01, -.30528500E+00, -.80117300E+00, -.93109000E+00, 0.83103100E+00, -.21690900E+00, 0.19557800E+00, -.11629500E+00, 0.29441200E+00, -.80319300E-01, -.39638700E+01, -.27045100E+01, 0.28618200E+00, 0.38244300E+00, -.71214400E-02, 0.15003400E+01, -.20468100E+00, 0.23798200E+00, 0.11330000E-01, 0.30688300E+00, 0.98009100E-02, 0.30275500E+00, 0.45875000E+00, 0.77325700E-01, -.79028900E+00, 0.45891700E+00, 0.10974400E+00, -.29858700E+00, 0.73985000E+00, 0.21008800E+00, -.24567700E+00, -.18081700E+01, 0.14107300E-01, 0.12767600E+01, 0.59476600E-02, 0.19656300E+01, -.66338800E+00, -.39970700E+00, 0.81762400E+00, -.28719100E+01, -.45104100E-01, -.88201700E+00, -.32673800E+00, 0.11785500E+01, -.23982500E+00, 0.45730200E+00, 0.13605100E+01, 0.64857400E+00, 0.38648300E-01, -.31361400E+00, 0.13038600E+00, 0.14725000E+00, 0.27177300E-01, 0.24444400E+00, 0.49307800E+00, 0.20997500E+00, 0.14303500E+01, -.45354600E+00, 0.23110900E+00, 0.15956000E+00, -.16793800E+00, 0.20128600E-01, -.16085500E+00, -.19457500E-01, -.57255800E+00, 0.16176200E+01, 0.80035200E+00, 0.11704100E+00, -.13641200E+01, 0.61902900E-02, -.91494900E+00, -.89366800E-03, -.72328600E+00, 0.14273500E-01, 0.46366100E+00, 0.53872200E-01, -.29836500E+00, 0.94048500E+00, -.16274900E+00, -.99746700E+00, -.16095200E+01, 0.75152100E+00, -.13633200E-01, -.37789000E+00, -.15377800E-01, 0.14038000E+01, -.89240900E+00, 0.10099600E+01, 0.75218900E+00, 0.79545000E-01, 0.16268300E+01, 0.72320100E+00, -.16125200E-02, -.35482100E-01, -.74483500E+00, 0.60241000E-01, -.10271500E+00, -.23383200E+00, -.36901900E+00, 0.78495800E-01, 0.20151100E+00, 0.50287200E+00, -.30603100E+00, 0.30337800E+00, -.48840800E-01, 0.15547800E+01, 0.37950500E-01, 0.79690000E+00, 0.39208100E+00, -.39030800E+00, -.14914800E+01, -.17454200E+01, -.36247700E+00, 0.14236000E+01, 0.56803100E+00, -.26839900E-01, 0.17872600E+01, 0.81242600E-01, 0.15067300E+00, 0.16150100E+00, -.15759800E+01, 0.36237500E+00, -.28610600E+00, 0.19192500E-01, -.49552400E+01, 0.27342800E+00, -.40077300E-02, -.69162000E+00, 0.61897100E+00, 0.38315300E+01, 0.21947600E+00, 0.16528000E+01, 0.38722100E+00, 0.72255500E+00, -.42609800E+00, 0.10813400E+00, -.13489900E+01, -.10594600E+00, 0.81887800E+00, 0.51371400E-01, 0.93804500E-01, 0.36366200E+00, 0.69799800E+00, -.52075900E+00, -.30714000E+00, 0.31376600E+00, -.62452800E+00, -.61965400E+00, -.33949400E+00, 0.75835000E+00, 0.85802200E-01, 0.59689500E+00, 0.63057300E+00, 0.40585400E+00, -.95754700E+01, -.21745200E+01, -.80440500E+00, 0.54509200E+00, -.25503600E+00, -.28259900E+00, 0.11011000E+00, 0.10340300E+00, -.29796400E+00, -.24098400E+00, -.23181100E+01, 0.30355300E+00, -.42000100E-01, 0.43832000E+02, 0.43980900E+02, 0.64448400E+03, -.32190900E+03, -.31547100E+03, -.32242600E+03, -.11172400E+03, -.11436100E+03, -.11903200E+03, 0.41980400E+02, -.49876300E+02, -.13227600E+03, -.34383400E+03, -.16396600E+03, 0.61677500E+02, 0.16846600E+03, 0.80609200E+02, 0.56562600E+01, -.62975100E+02, 0.12950600E+03, 0.79523800E+02, 0.90542100E+02, -.50283200E+02, -.25477100E+02, 0.82675900E+03, -.41238000E+03, -.37572200E+03, -.41336200E+03, -.15348800E+03, -.14333700E+03, -.21100500E+03, -.75316200E+02, -.11876100E+03, -.13544400E+03, -.27394100E+03, -.11794500E+03, 0.59636100E+02, -.10091600E+02, 0.59050100E+02, 0.16949800E+01, 0.25632900E+02, -.35566200E+01, -.53749900E+02, 0.82829400E+02, 0.22626600E+02, -.97160200E+01, -.50664000E+03, 0.25359000E+03, 0.50850900E+02, 0.25277100E+03, 0.97115400E+02, 0.72982600E+02, 0.26229800E+02, -.14284200E+03, 0.50587200E+02, 0.38354600E+02, 0.23953600E+03, 0.11470900E+02, 0.42855700E+01, -.23319600E+01, -.29523000E+01, 0.11023700E+02, 0.35744900E+01, 0.12036900E+01, 0.33216000E+01, -.13133200E+01, -.11319100E+01, -.73097100E+01, -.16774900E+02, 0.23992000E+01, 0.76210300E+00, -.11528000E+02, 0.11120700E+02, -.12617500E+02, 0.96440100E+00, -.11896400E+02, 0.24601300E+01, 0.59977200E+01, 0.13338900E+02, 0.17196200E+02, 0.21739400E+01, -.14797300E+02, 0.11914800E+02 },
        { 0.13659600E+02, -.45090000E+01, -.73632900E+00, -.30930900E+01, 0.32019300E+01, 0.93584400E+01, 0.11269900E+02, -.26479600E+00, 0.80674700E+01, -.96301800E+01, 0.19437300E+00, 0.11456500E+01, 0.25838600E+01, -.15032900E+01, -.64987800E+00, -.28040300E+01, -.23290000E+01, -.15798800E+01, 0.92548800E+00, 0.21763400E+01, 0.35818400E+01, -.84347600E+00, 0.25741500E+00, 0.14211600E+00, 0.19449200E+01, -.15726100E+00, -.13559700E+01, 0.37584300E-01, 0.56217700E+00, -.21280700E+01, 0.72240900E+00, -.28810100E+00, -.82129800E+00, 0.37512100E+00, -.10181700E+01, 0.66848400E+00, 0.16914100E+00, 0.49601200E+00, 0.41072600E+00, 0.46270800E+01, -.14617900E+00, 0.60728500E+00, 0.95503500E+00, -.42332500E+01, -.30748000E+01, -.75723500E+00, -.14725600E+00, 0.42956000E+00, -.54829300E+00, -.56746400E+00, -.42607800E+01, 0.26085100E+01, 0.15518600E+01, 0.44422300E+01, 0.33538500E+01, -.18232600E+00, 0.16851800E+01, -.47573800E+00, 0.46178600E-01, -.29676700E+00, -.66766700E+00, -.39224400E+01, -.24022100E+01, 0.30732400E+01, -.24605000E+01, 0.35288800E-02, -.16967300E+01, 0.16517400E+00, -.11870700E+01, -.30655600E+00, -.63815800E+00, 0.64576000E+00, 0.32523200E+01, 0.22568200E+00, -.71721800E+00, 0.22950300E+01, -.20275600E+00, 0.60935200E+00, -.33192000E-01, -.51603000E+00, -.63285500E+00, -.40572300E+00, -.40052000E+00, 0.13323500E+00, 0.38248000E+01, 0.79414600E+00, -.24903700E+01, 0.26022300E+00, 0.14418200E+01, -.11137200E+01, -.35591500E+01, -.23593200E+00, 0.13696900E+01, -.21058600E+01, -.18752000E+01, 0.60366700E+01, -.13526100E+01, 0.30525600E+01, -.12767000E+01, -.64743500E+00, -.14984800E+01, 0.17460200E+01, 0.12926100E+01, -.52026100E+00, -.12766100E+01, -.11440900E+01, 0.34619400E+00, -.75892300E+00, 0.18694600E+00, 0.70676600E+00, 0.28998500E+01, 0.99230800E-01, 0.21549300E+00, 0.57025400E+00, -.25533500E+01, -.32438300E+01, -.97665700E+01, 0.25323000E+01, 0.49350500E+00, 0.14893800E+01, -.30497600E+00, 0.85034800E+00, 0.22136000E+00, 0.21613100E+01, 0.12026900E+00, -.11514500E+01, 0.21699900E-01, 0.34728400E+01, 0.19323800E+00, 0.16027800E+01, 0.30001100E+01, 0.34004100E+01, 0.21886600E+00, 0.78570400E-01, 0.38995600E-01, 0.19109800E-01, 0.49403900E+01, -.10871300E+01, 0.22954000E+00, -.83913700E+01, -.30767600E+01, 0.76134600E+00, 0.56652000E+01, 0.15274200E+01, 0.11159800E+01, -.24103800E+01, -.58645100E-02, -.13149100E+00, 0.11202100E+01, -.19645500E+01, -.98854500E+00, 0.50801200E+00, 0.13202400E+01, 0.28048500E+00, -.77513100E+00, -.32675300E+00, -.31155400E+01, -.57896700E-01, -.10277200E+01, 0.98384300E+00, -.43405300E-01, 0.32955400E+01, 0.12243300E+01, 0.98184000E+00, -.22678900E+01, 0.29303700E+00, -.60171600E-01, -.40172700E+01, 0.12887000E+00, -.49380000E+00, -.80706500E+00, 0.35422200E+01, -.97941000E+00, 0.10067100E+01, -.11984000E+01, 0.70935800E+01, -.11910000E+01, -.27362400E+01, 0.96786700E-01, 0.19523600E+01, -.97060900E+01, -.54337400E+00, -.23058000E-01, -.94971400E+00, 0.66166400E+00, -.53105700E+00, 0.58168000E-01, -.13910500E+01, 0.36826900E+00, -.15132600E+01, -.12857100E+00, -.25865200E+01, -.75987400E+00, -.38194300E+01, 0.13151600E+01, -.58425700E+00, 0.31308500E+00, 0.20841500E+01, 0.11904800E+01, 0.64834600E+00, -.83497700E+00, 0.72172900E-01, -.12590300E+01, -.12972500E+01, -.11663800E+00, 0.15121900E+02, 0.38799200E+01, -.98723000E+00, -.55275900E+00, -.29846800E+01, 0.13978100E+01, -.17954600E+01, -.13036300E+00, -.28967200E+00, 0.15766900E+01, -.66257300E+01, -.60788600E+00, -.34310200E+00, 0.51121800E+00, -.45584600E+03, -.18713100E+04, 0.93509700E+03, 0.10347000E+04, 0.93635300E+03, 0.29996300E+03, 0.41026100E+03, 0.26254800E+03, -.21267300E+03, 0.48907700E+03, 0.41501200E+03, 0.52852900E+03, 0.92239000E+01, -.10173000E+02, -.43657100E+02, -.65003600E+00, 0.46299500E+01, 0.21638100E+02, 0.22445100E+02, 0.18337000E+02, -.62956800E+02, 0.29691700E+02, -.10979700E+02, -.18971900E+04, 0.94905200E+03, 0.10740000E+04, 0.94936500E+03, 0.38953600E+03, 0.58033700E+03, 0.18257100E+03, -.19851900E+03, 0.48455500E+03, 0.48717500E+03, 0.32385600E+03, 0.30080800E+03, -.14421700E+03, -.94916500E+02, -.14907100E+03, -.12093600E+02, -.19379000E+02, -.36062700E+02, 0.81496000E+02, -.21825800E+03, 0.24758100E+01, -.14475900E+03, 0.19866300E+03, -.94179800E+02, -.99608100E+02, -.97612200E+02, -.98030500E+02, -.17233900E+03, 0.11481500E+03, 0.10110000E+03, 0.48274300E+02, -.91614600E+02, -.27759000E+00, 0.73187400E+01, 0.63840200E+01, 0.65027200E+01, -.14917300E+02, -.15559400E+02, 0.18763900E+02, 0.77052300E+01, 0.57290600E+01, -.25460900E+01, -.11614800E+02, 0.95897600E+01, 0.13942700E+02, 0.28337800E+01, 0.38636800E+01, 0.11553400E+02, 0.22301600E+01, -.81837300E+00, -.17683000E+02, 0.14378600E+02, 0.22316600E+01, 0.44113600E+00, 0.70417300E+02, -.15199200E+02, -.30266000E+02, -.29244500E+01, 0.55215700E+01 },
        { -.73542300E+00, 0.70055900E-01, 0.31895700E-01, 0.10712400E+00, -.22645900E+00, -.47046900E+00, -.24761200E+00, 0.10351700E+00, -.32104200E+00, 0.42310300E+00, 0.19965400E-02, -.38024100E-01, 0.41927700E-01, 0.33911800E-01, -.15070900E+00, -.98232700E-02, -.11159100E+00, -.99879900E-02, 0.12969200E+00, -.12479500E+00, 0.42138300E-01, 0.82764200E-02, -.30082300E-03, -.59456100E-01, 0.15822000E+00, 0.15780800E-01, 0.28587400E-01, -.22848400E-02, -.13602100E+00, 0.42747600E-01, 0.58844100E-01, 0.65018300E-01, 0.14118600E+00, 0.68461400E-01, 0.48274000E-01, -.26452000E-01, -.22092400E-01, 0.87799300E-01, -.14578600E+00, 0.40066300E+00, 0.25136900E-01, 0.40799300E-01, 0.52723600E-01, 0.41239000E-01, 0.20600300E-01, -.14232400E-01, 0.46410700E-01, -.12373900E-02, -.17879300E-02, -.57169300E-02, 0.23819700E+00, 0.15639200E-01, -.78722300E-01, 0.10030800E-01, -.46803700E-01, -.97482800E-01, -.50190100E-01, -.25430600E-01, -.50678200E-02, -.26964200E-01, 0.75422900E-01, -.62574700E-01, -.39808500E-01, -.46488000E-01, 0.12502200E-01, 0.74594000E-02, -.85283000E-02, -.35738700E-01, -.17524200E-01, -.32825800E-02, 0.19054300E-01, -.16474200E-01, 0.67404400E-01, -.32892800E-01, -.54453800E-01, 0.10067300E-01, -.25001800E-01, -.11209900E+00, 0.16344000E-02, -.31031000E-01, -.64893000E-03, -.14154100E-01, 0.10749700E+00, -.13215800E-02, 0.13738000E-01, 0.52190600E-01, -.18512000E+00, 0.30546300E-01, -.25785800E+00, 0.59089000E-01, -.27618000E+00, 0.37436300E-02, -.43473600E-01, -.92585900E-01, 0.80424900E-02, 0.25385600E+00, -.69827700E-01, -.74092100E-01, 0.29376500E-01, 0.37087500E-02, -.18065500E-01, 0.26351200E-02, -.13284800E-01, 0.10712100E+00, -.42461000E-01, 0.71116300E-01, 0.24746800E-01, 0.17689200E-01, -.10788100E+00, -.58561000E-02, -.15716000E-02, -.26868100E-02, 0.99960700E-03, -.19322600E-01, 0.19116300E-01, 0.98979900E-02, -.85166400E-01, -.91286700E-02, -.16675300E-01, 0.14494900E-01, -.93247500E-01, 0.92988800E-01, 0.15193500E-01, 0.90219200E-02, 0.25166400E-02, 0.10511900E-02, -.38150200E-02, 0.48582700E-01, 0.69488700E-02, 0.38004200E-01, -.11461200E+00, -.52309900E-02, -.85344200E-01, -.84853600E-03, -.11186400E-01, 0.66968300E-03, 0.93194000E-01, -.58478700E-01, 0.30991500E-01, -.23881600E+00, -.75387600E-01, -.29041800E-01, -.12035400E-01, 0.78145600E-02, 0.60963400E-02, -.50391400E-01, 0.14839800E-02, -.32166200E-02, 0.15243800E-01, 0.37262800E-01, 0.46633700E-01, 0.51402300E-01, 0.50085000E-01, 0.21768900E-01, 0.19530500E-02, -.46158700E-02, 0.47731000E-01, -.69173300E-03, -.14682300E-01, 0.61029900E-01, -.83897700E-02, -.66935600E-01, -.50939300E-01, -.57128300E-02, 0.68935600E-01, 0.20515900E-01, 0.12178100E-01, -.21367200E-02, 0.13265600E-01, -.21971500E-01, -.24248800E-01, 0.44514800E-01, -.64010600E-02, -.10069600E-01, 0.16852700E-01, -.47584200E+00, 0.16940100E-01, -.83759900E-01, -.29175900E-02, -.78523200E-01, -.49318400E+00, 0.81593600E-01, 0.58218200E-01, -.10314000E-01, -.24304200E-01, 0.16321500E-02, -.31939800E-01, 0.13473400E+00, -.14232900E-01, 0.10577200E-01, -.25726500E-02, -.14215700E-01, -.43116700E-01, -.55908600E-01, 0.14367300E+00, 0.16249900E-01, 0.27336800E-01, 0.48667500E-01, -.12606400E-01, 0.12756900E-01, -.14074000E+00, -.34679600E-02, -.11490900E-01, 0.47952900E-01, 0.15243600E+00, 0.14439700E+01, -.24868700E-01, -.24252200E+00, 0.29680600E-01, 0.39312800E-01, 0.71031900E-01, -.68363700E-01, -.18092300E-02, -.62719500E-01, 0.36708100E-01, -.20338000E+00, 0.41275600E-01, -.23560200E-01, 0.15587400E-01, -.29607900E-01, -.80123100E+02, 0.40234000E+02, 0.42481800E+02, 0.40087800E+02, 0.12327100E+02, 0.12874300E+02, 0.20554000E+02, -.15815600E+02, 0.37582200E+01, 0.19326900E+02, 0.47750800E+02, -.46814400E+01, 0.22239300E+01, 0.97502500E+01, 0.23073300E+01, -.30501800E+01, -.11960900E+02, 0.11878300E+02, 0.58123500E+01, 0.27480100E+01, -.10174300E+02, -.67257700E+01, -.82745400E+02, 0.41713500E+02, 0.45361300E+02, 0.41398500E+02, 0.17120400E+02, 0.14649500E+02, 0.23733900E+02, -.14676800E+02, 0.41208400E+01, 0.21105100E+02, 0.48937900E+02, 0.15469900E+02, -.73257700E+01, -.20583500E+00, -.76998900E+01, -.27472400E+01, -.14978900E+01, -.23673600E+01, 0.15869400E+01, -.10736500E+02, -.31665300E+00, -.91391600E+01, 0.20025800E+01, -.60712300E+00, 0.60049300E+01, -.92207500E+00, -.61713100E+01, -.15427500E+01, 0.21331300E+01, -.45044000E+01, -.33303300E+01, 0.11624500E+00, -.49531600E+01, 0.57691700E-01, 0.49322900E+00, 0.37592300E+00, -.10854800E+01, -.14974800E+00, 0.14598900E+01, 0.93785600E+00, -.34354100E+00, 0.15771800E+00, -.11026100E+01, 0.69438800E+00, 0.11824700E+01, 0.67534800E+00, 0.40182600E+00, 0.12450500E+01, -.43890200E-01, -.39340200E-01, -.12794900E+01, 0.12806700E+01, 0.72219700E+00, -.13136800E+00, -.54896300E+01, -.99211900E+00, 0.13669900E+01, -.36976100E+00, 0.57983700E+00 },
        { -.34360200E+01, -.32975400E+01, -.26849200E+00, -.87485800E+00, 0.19124700E+00, -.39254200E+01, -.29387000E+01, -.18320200E+01, -.19109900E+01, 0.30165600E+01, 0.94751900E-01, -.10137200E+00, -.12073900E+01, 0.24061600E+01, 0.26971800E+00, 0.37753400E-01, 0.10120500E+01, 0.20457600E+01, -.13486400E+01, 0.15302900E+01, -.83950600E-01, -.20077800E-01, 0.46220100E-01, -.29820200E-01, 0.64676500E+00, 0.99445600E-02, 0.28554900E+00, 0.18057400E+01, -.19723500E+01, 0.15725400E+01, -.50964200E+00, -.66807200E+00, 0.28355700E+00, 0.39687100E+00, 0.63883800E+00, -.62432000E+00, 0.26562800E+00, 0.85457000E+00, -.11409800E+01, -.60086700E+00, 0.17398700E+00, 0.97882300E-01, 0.13219500E+01, 0.75861700E+00, -.38599300E-01, 0.15936400E-01, 0.10089400E+01, -.59886500E-01, 0.80663700E-01, -.34484100E+00, 0.30149900E+01, 0.56163400E-01, -.70507800E+00, -.13974000E+01, -.89658900E+00, -.50641300E+00, 0.97224100E-01, -.34931100E+00, -.16764900E+00, 0.64499900E+00, -.40663400E+00, -.43594500E+01, -.21856300E+01, -.12075200E+01, 0.11724900E+01, -.12246900E+00, 0.96997800E+00, -.63591200E+00, 0.10448000E+00, -.37913200E-02, -.69451000E+00, 0.37798100E+00, 0.11050900E+01, -.11736400E-01, -.16881700E+00, -.37552200E+00, 0.13891600E+00, -.96795600E+00, -.82652900E-01, 0.11416300E+01, 0.14057200E+00, -.24401200E+00, -.14992700E+01, -.16594600E+00, 0.10262700E+01, -.38845800E+00, 0.33262300E+01, -.87472600E+00, -.65319900E+00, 0.89608900E+00, -.20762800E+01, -.34876400E-01, -.47360800E+00, -.48783100E+00, 0.96840300E+00, 0.29968100E+00, 0.74147800E-01, 0.13130400E+00, 0.26485100E+00, 0.65305000E-01, -.15579400E-01, -.15532500E+00, 0.25808400E+00, 0.80231600E+00, 0.98925200E-01, 0.63144600E+00, 0.24569900E+00, 0.38189200E+00, -.36550800E-01, 0.82567000E-02, -.94784700E+00, 0.31489000E+00, -.21263500E-01, -.17102400E+00, 0.44833800E+00, -.18536400E+00, -.17679600E+01, 0.44726700E+00, -.38891400E-01, 0.20102700E+00, -.23460000E+00, 0.18188700E+00, 0.38235800E-01, -.18979400E+00, -.19834700E-01, -.65145000E-01, 0.21918700E-01, 0.48446300E+00, 0.26924900E+00, -.66730900E-01, -.10031700E+01, 0.15099200E+00, -.46159700E+00, -.34526100E-02, -.18066700E+00, 0.62637400E-02, 0.10941900E+01, -.37892400E+00, 0.37731400E+00, 0.37116400E+00, 0.20083300E+00, 0.52659400E+00, -.94542000E+00, 0.16379000E+00, 0.11571500E+00, -.65174200E+00, -.14937800E-01, 0.13682200E+00, 0.41163000E+00, -.25539200E-01, -.57425600E-01, -.40225900E-01, 0.13412600E+01, -.71525100E+00, 0.18609300E+00, 0.31519700E+00, 0.11004500E+01, -.14441200E-01, -.38715600E+00, 0.10346200E+01, -.12110500E+00, 0.18772200E+00, -.42800900E+00, -.30430100E-01, 0.13582700E+00, -.46856500E-01, -.44539900E-01, -.41820300E+00, -.19174600E-02, 0.22357900E+00, 0.17544400E+00, -.20008600E+00, 0.12327500E+00, -.67980200E-01, -.67127800E+00, -.72519800E-01, 0.47781100E-01, 0.23535500E+00, -.15041100E+00, -.25097300E+00, 0.83030700E+00, 0.15906400E+00, -.28621900E+00, 0.49224900E-01, 0.57638800E+00, -.22601400E+00, 0.19270400E-03, -.17986200E-01, -.20144600E+00, 0.36751900E-02, 0.14249400E-01, -.96714300E+00, -.29662200E+00, -.37957800E+00, 0.13089300E+01, 0.82347000E-01, -.25901700E+00, 0.22530500E+00, 0.53367300E-01, -.14897100E+00, -.75080900E+00, 0.23637400E-01, -.29444900E+00, 0.33380100E-02, 0.46366200E+00, 0.23218300E+01, 0.69841600E+00, 0.39448300E+00, 0.44710800E+00, -.14195500E+00, -.54523900E-01, -.46199800E+00, -.12214900E-01, -.18636700E+00, 0.10392400E+00, -.11140200E+01, -.30304700E+00, -.13217500E-01, 0.17127400E+00, 0.16977800E+00, 0.24248500E+01, 0.35942000E+01, -.81628300E+02, -.11887900E+00, -.52923000E+02, -.58969500E+02, -.30636800E+02, 0.34190700E+02, 0.77966100E+02, -.94442000E+02, -.84003300E+02, 0.57330600E+01, -.34282700E+01, -.16828900E+02, -.31687300E+01, 0.64030500E+01, 0.19598900E+02, -.15761200E+02, -.12668800E+02, 0.15930700E+01, 0.17757100E+02, 0.18722200E+02, 0.23587200E+02, -.11965300E+02, -.47342300E+02, -.12049200E+02, -.65550600E+02, -.64084700E+02, -.57168300E+02, 0.15086200E+02, 0.55881500E+02, -.96314500E+02, -.11503700E+03, -.43278900E+02, 0.21145500E+02, -.42526800E+01, 0.21254500E+02, -.75082300E+01, -.84180500E+01, 0.30552600E+02, 0.48042100E+01, 0.19525300E+02, -.80962500E+01, 0.19231900E+02, 0.89342300E+01, -.73877400E+01, 0.89574200E+01, -.47382000E+01, 0.23875200E+02, 0.59906700E+01, -.20696800E+02, 0.13152200E+02, -.24572500E+01, 0.58727100E+01, 0.15923400E+02, 0.19100700E-01, -.53231600E+00, 0.12367100E+01, 0.26792600E+01, 0.13930600E+01, -.82608000E+01, -.39594900E+01, 0.67150000E+00, -.10372200E+01, 0.35054000E+01, -.80611200E+00, -.45297900E+01, -.21531300E+01, -.20948000E+01, -.46906100E+01, 0.18574200E+01, -.10676900E+01, 0.46822500E+01, -.51913000E+01, -.25109100E+01, 0.23789500E+00, 0.10089700E+02, 0.45403600E+01, -.17685400E+01, 0.21692100E+01, -.19779400E+01 },
        { 0.69674000E+01, -.34178000E+00, -.32414500E+00, -.11851800E+01, 0.18369600E+00, 0.84472600E+01, 0.42986500E+01, 0.30386700E+01, 0.35895000E+01, -.53484000E+01, -.14250800E-01, 0.32877700E+00, 0.32715200E+01, -.19059800E+01, 0.51334100E+00, 0.16269500E+00, -.24296300E+01, -.21653800E+01, 0.11623000E+01, -.28627900E+01, 0.10647800E+00, 0.12230600E+00, -.18696600E+00, -.49269100E+00, -.26663300E+00, 0.49218400E-01, -.35182700E+00, -.52648000E+00, 0.14457100E+01, -.18963800E+01, 0.52852900E+00, 0.13678800E+01, 0.32754300E+00, -.10314000E+01, -.49127000E+00, 0.72955200E+00, -.29673100E+00, -.10765800E+01, 0.26155500E+00, 0.94155500E+01, -.26354300E+00, 0.11437500E+00, -.26744500E+01, -.10748900E+01, 0.36554400E+00, -.34259500E+00, -.12635800E+01, 0.10287400E+00, -.69076800E-01, 0.42199400E+00, -.30248500E+01, 0.57540700E-01, 0.64612200E+00, 0.26302200E+01, 0.14021800E+01, -.49213900E+00, 0.35880400E+00, 0.26274000E-01, 0.28033200E+00, -.22668200E+00, 0.14664400E+01, 0.25089200E+01, 0.12986000E+01, 0.17392400E+01, -.13915700E+01, 0.14643500E+00, -.17343300E+01, 0.58912500E+00, -.26798200E+00, 0.54301800E-01, 0.16930000E+01, -.53214600E+00, 0.17133900E+00, 0.34041600E+00, 0.40781300E-02, -.53220700E+00, 0.38794400E+00, 0.11214300E+01, -.44770600E+00, -.10506300E+01, 0.69777800E-02, 0.77437600E+00, 0.20105800E+01, 0.59790600E+00, -.37635200E+01, 0.16620000E+00, -.24612400E+01, 0.11019200E+01, -.24904100E+01, 0.37639700E+00, -.41005700E-01, 0.44349500E-01, 0.27697600E-01, 0.89951100E-01, -.19365700E+00, 0.10393400E+01, -.35829300E+00, 0.89805800E+00, 0.69784200E+00, -.35258300E+00, -.87464300E+00, 0.27666300E+00, 0.34405300E-01, 0.22316700E+00, -.70725800E+00, -.41429400E-01, -.22815100E+00, 0.64350400E+00, 0.16729500E+00, 0.29428300E+00, 0.83585600E+00, -.26875500E+00, -.58996500E-01, 0.28950300E+00, -.11900800E+01, 0.36482700E+00, -.15315100E+00, -.83793100E+00, 0.22622400E+00, -.67075300E+00, -.36523700E+00, -.30977700E+00, 0.11224300E+00, 0.75777100E-01, 0.23094800E-02, -.20116300E+00, 0.23139300E-01, 0.88850600E+00, -.13417100E+01, 0.40354800E+00, 0.19068900E+01, 0.32616800E-01, 0.11320700E+01, 0.92914400E-02, 0.22163000E+00, -.93754000E-02, -.11183500E+01, -.23116900E+00, -.87797600E-01, -.79560600E+00, -.92307000E+00, -.99276700E+00, 0.13126100E+01, 0.29285700E+00, -.11859100E+00, 0.16499600E+00, 0.10347000E-01, -.84573200E-01, -.25762400E+00, -.92935100E+00, -.15372600E+00, 0.35918700E+00, -.30348900E+01, 0.54651600E+00, -.14568200E+00, -.52237300E+00, -.28678900E+01, -.15366700E-01, 0.81526800E+00, -.23584200E+01, 0.13056500E+00, 0.81848700E+00, -.30412200E+00, 0.32649500E+00, -.15031600E+00, 0.55702600E+00, -.11682200E+01, 0.81923400E+00, 0.19521000E+00, -.10004700E+00, -.36426000E+00, 0.55336600E+00, -.39074700E+00, 0.50345800E+00, -.22807700E+00, -.33088900E+01, -.20175300E+00, -.13105100E+01, 0.99850300E-01, 0.16079100E+01, 0.44437000E+01, -.13059900E+01, 0.14755300E+01, -.26799600E+00, -.18616300E+01, -.25191000E+00, -.16352900E+00, -.79052600E+00, 0.56268200E+00, 0.77928700E+00, 0.24697100E-01, 0.12995400E+01, 0.86313200E+00, -.53925900E+00, -.28654200E+01, -.97794800E+00, -.93636700E+00, -.66380800E+00, 0.31054200E+00, 0.32704500E+00, 0.30216600E+00, 0.50624500E-01, 0.52295500E+00, -.59530300E+00, -.45111100E+00, -.13397200E+02, 0.57372000E+00, 0.79409700E-01, -.58229700E+00, -.15149300E+01, 0.13775700E+00, -.60314700E-01, 0.14306900E-02, 0.14504000E-01, 0.28178100E+00, -.17132100E+01, 0.24659800E+00, 0.58238100E-01, 0.40374600E+00, -.80340400E-01, 0.43611900E+00, 0.80860000E+00, 0.19750800E+03, 0.37007100E+01, 0.37601900E+02, 0.50827800E+02, 0.21791900E+02, -.45155600E+02, 0.10390300E+02, 0.66785700E+02, 0.20634300E+03, 0.57509500E+02, -.15568400E+02, -.85489000E+02, -.26462300E+02, -.47122900E+01, -.35195800E+01, -.32776600E+02, 0.17113100E+02, -.34722500E+01, -.90903100E+01, -.16849200E+02, -.72163100E+02, 0.35514900E+02, 0.17823700E+03, 0.36434500E+02, 0.51916800E+02, 0.55613700E+02, 0.65666300E+02, -.16414000E+02, 0.95208100E+02, 0.59864500E+02, 0.26731600E+03, 0.89956500E+02, -.44428100E+02, -.32785500E+02, -.44394600E+02, 0.23572500E+01, -.76386900E+01, -.12470700E+02, 0.36630600E+02, -.12846900E+02, -.59757900E+01, -.46001000E+02, -.45449600E+02, 0.26088600E+02, -.27885000E+01, 0.23286100E+02, -.60036700E+02, -.38200000E+02, 0.70825200E+02, 0.29507300E+02, 0.46733600E+02, -.25280100E+02, -.53882600E+00, 0.68160500E+01, 0.23358400E+01, -.18883400E+01, 0.73560000E+00, -.22667600E+01, 0.85455200E+01, 0.45029800E+01, 0.20944200E+01, -.10398100E+00, -.14955100E+01, 0.34114400E+01, 0.50096600E+01, 0.36173800E+01, 0.37813800E+01, 0.74652100E+01, 0.45325800E+01, -.37728700E+01, -.32094900E+01, 0.65647500E+01, 0.34220000E+01, 0.19281700E+01, -.24505800E+02, -.61670200E+01, 0.37462600E+01, -.34358000E+01, -.12644900E+01 },
        { -.34183300E+01, 0.20929400E+00, 0.16334500E+00, -.31192500E+01, -.25945000E+01, 0.43803700E+01, -.46009900E+01, 0.72207600E+01, -.20437000E+01, 0.32655600E+01, 0.58611200E-01, -.38526900E-01, 0.20364300E+01, 0.21000400E+01, 0.32346200E+01, 0.24055700E+01, -.16287100E+01, 0.93443600E+00, -.14201500E+01, 0.27735900E+01, -.70729300E-01, -.46081700E-01, 0.16124100E+00, 0.80180500E+00, -.37731300E+01, 0.38889300E+00, -.15787800E+01, -.61423800E+00, 0.10255600E+01, 0.83860900E+00, 0.66430100E-01, -.11555300E+01, -.13948200E+01, 0.87914000E+00, -.10950200E+00, -.21945800E+00, -.10226500E+01, -.10777300E+01, -.61760200E+00, -.15162500E+02, -.16128400E+00, -.58318900E+00, 0.19087100E+01, 0.34496200E+00, -.78833100E+00, -.18090200E+00, 0.51906600E+00, -.28141200E-01, 0.29378000E+00, -.38224100E+00, 0.70365200E+00, 0.43370400E+00, -.47107800E-02, -.75296000E-01, 0.44742900E-01, -.66537300E-01, 0.18213200E+00, -.32758100E+00, 0.25845200E-02, 0.14117900E+00, -.44570400E+00, -.22478200E+01, -.13836700E+01, 0.96339700E-01, -.23465300E+00, -.95499200E-01, 0.29853500E+00, -.22677400E+00, -.25553600E+00, 0.16950800E+00, -.73634000E+00, 0.29188100E+00, 0.10601700E+01, -.16757800E+00, -.17957800E+00, 0.62670000E+00, -.20443200E+00, -.50342900E+00, 0.15358200E+00, 0.65225100E+00, 0.93994200E-01, -.38265200E+00, -.12458700E+01, -.37236500E+00, 0.22500000E+01, -.21388600E+00, 0.72724200E+00, -.45693500E+00, 0.16960400E+01, 0.83551600E-01, 0.44871900E-01, 0.85737500E-01, -.82181600E-01, -.33773200E+00, 0.43574800E+00, -.12960400E+00, 0.33970400E-01, 0.25758100E+00, -.41988400E+00, 0.95233800E-02, 0.15628200E+00, 0.48054600E+00, 0.52582200E+00, -.61212700E+00, 0.51044800E+00, 0.25972400E-01, 0.48558700E+00, 0.36206400E+00, 0.26703800E+00, 0.46482300E-01, -.75754300E+00, 0.19434000E+00, -.10848100E-01, 0.12881000E-01, 0.79905200E+00, -.76292200E+00, 0.67146000E-01, 0.55864100E+00, -.17165200E-01, 0.39675300E-01, 0.59378300E+00, 0.30032700E+00, 0.19974700E-01, -.21190800E+00, 0.12278000E+00, -.34012700E+00, -.51541700E-01, 0.14342800E-02, -.16484200E+00, -.41513200E+00, -.88396000E+00, 0.10005800E+01, -.73585400E+00, 0.10463000E-02, -.17418100E+00, -.19357900E-01, 0.20411600E+01, -.28836400E+00, 0.19070500E+00, 0.14496800E+01, 0.42416200E+00, -.25468000E-01, -.70656200E+00, 0.13214700E+00, 0.11817300E+00, -.46275000E+00, 0.88569700E-01, 0.86296900E-01, 0.46998800E+00, -.93975100E-01, -.10050000E+00, -.21748500E+00, 0.68268800E+00, -.25873000E+00, -.43880700E-01, 0.31171600E+00, 0.22601900E+00, 0.65068600E-01, -.48854700E+00, 0.55380000E-02, 0.13311100E+00, 0.22009800E+00, 0.24766900E+00, 0.26547400E-01, -.20622900E+00, -.32132600E+00, 0.29510100E+00, -.35975300E+00, -.13567900E+00, 0.15725600E+00, 0.13640100E+00, -.12056600E+00, -.54053600E-01, -.16111700E+00, 0.18666700E+00, 0.25580700E+01, -.12386700E+00, 0.36855400E-01, 0.22453600E+00, 0.54264800E+00, -.12177100E+01, 0.25767700E+00, 0.12017200E+00, -.54162700E+00, 0.22180500E+00, -.38754400E-01, 0.12930100E+00, -.33074900E+00, -.10245900E+00, -.68454800E+00, -.53794200E-01, -.58329100E+00, -.46866200E+00, 0.47554300E+00, 0.15256800E+01, 0.51157700E+00, 0.23138300E+00, 0.18839000E+00, -.13411000E+00, -.11600700E+00, -.66980300E+00, 0.52562500E-01, -.53211500E+00, -.10806800E+00, 0.21636100E+00, 0.57738600E+01, -.23243100E-01, -.30930400E+00, 0.12584800E+00, 0.56128700E-01, 0.14343900E+00, -.22688600E+00, -.74169400E-01, 0.50600400E-01, 0.44519500E-01, -.16812800E+00, -.80487800E-01, 0.92206300E-02, -.36043700E-01, 0.46473100E-01, -.11642900E+00, -.47431200E-01, -.23927800E+00, 0.10258000E+02, 0.11764500E+02, 0.16128900E+02, -.22555000E+01, -.37220400E+02, -.89606100E+02, 0.32600900E+02, 0.35640700E+02, -.26100600E+01, 0.41101200E+01, -.33533100E+01, 0.21268800E+01, -.29677800E+01, -.41974600E+01, -.17342000E+01, -.79094200E+01, -.40271200E+01, -.14889200E+01, -.33176100E+01, -.34224100E+02, 0.15733500E+02, 0.66373100E+00, 0.18764000E+02, 0.17871700E+02, 0.10051200E+02, 0.30242100E+01, -.52067100E+02, -.93573700E+02, 0.36072100E+02, 0.87782900E+02, 0.14522300E+02, -.80655700E+01, 0.13343900E+02, -.47371800E+01, 0.56866100E+01, 0.12528000E+02, -.26943600E+02, -.20003600E+02, -.16663100E+02, 0.92396600E+01, -.58149100E+01, 0.52223400E+02, -.24331100E+02, 0.54789600E+01, -.24535800E+02, -.18416100E+02, 0.12974900E+02, -.23996100E+02, -.15697500E+02, -.32040900E+02, 0.62225400E+01, -.28259200E+02, -.19182600E+01, -.35968900E+00, 0.25046700E+00, -.27506100E+01, -.24471600E+01, 0.36129300E+01, 0.90611100E+00, -.42802200E+00, 0.21641800E+00, -.22598700E+01, -.81535700E+00, 0.40958400E+01, -.40583000E+00, -.27673200E+00, 0.27211900E+01, -.23864800E+01, 0.19574800E+01, -.24896400E+01, 0.35463700E+01, 0.13471800E+00, 0.90252500E+00, -.79096200E+01, -.39833400E+01, 0.35357200E+01, -.22346100E+01, 0.32536600E+01 },
        { -.10066800E+02, -.15279000E+02, -.16722600E+01, -.63799800E+01, -.31841700E+00, -.29641200E+01, -.13770800E+02, 0.54695900E+00, -.71545300E+01, 0.93655800E+01, 0.46054300E+00, -.57128400E+00, -.36194600E+01, 0.14791400E+02, -.24440100E+01, -.37299500E+00, 0.28219000E+01, 0.51060000E+01, -.11512800E+01, -.13189500E+01, -.86738700E+00, 0.39015200E+00, -.10732900E+01, -.21729200E+00, -.15832600E+01, 0.19759100E+00, -.68371200E-01, 0.27067200E+01, -.19268900E+01, 0.27321100E+01, -.76644100E+00, -.85963100E-01, 0.11780100E+01, 0.73476200E+00, 0.17760300E+01, -.83368500E+00, 0.16872000E+00, 0.29085700E-01, -.29869400E+01, 0.42798700E+01, -.15750800E+00, -.21437900E+00, 0.68820900E+00, 0.16902000E+01, 0.10325500E+01, -.29295800E+00, 0.13867600E+01, -.38748600E-01, 0.22825100E+00, -.18837200E+00, 0.38750600E+01, 0.13440600E+00, -.13208400E+01, -.96733800E+00, -.94285600E+00, -.17776300E+01, -.79938700E-01, -.10013900E+01, -.40809200E-01, 0.10647800E+01, 0.83988300E+00, -.79686800E+01, -.38242000E+01, -.64428600E+00, 0.21459600E+01, -.10709300E+00, 0.13194000E+01, -.60599700E+00, 0.15836700E+00, 0.13933500E+00, 0.82711400E+00, 0.32968700E+00, 0.59077800E+00, 0.67721000E+00, -.45834600E+00, -.24767000E+01, 0.95053800E+00, -.14313200E+01, -.34914900E+00, 0.47819500E+00, 0.49504000E+00, -.57448800E-02, 0.80966100E+00, 0.18497800E+00, -.40354300E+01, -.68044800E+00, 0.44561700E+01, -.50035700E+00, -.32594800E+01, 0.23332900E+01, -.16108800E+01, 0.39417600E-01, -.10836700E+01, 0.69590200E+00, 0.43610400E+01, -.23525200E+00, 0.46032900E-01, 0.19584900E+00, 0.12272600E+01, 0.34307900E+00, -.55383800E-01, -.14588500E+00, 0.26671000E+00, 0.20902400E+01, -.47869700E+00, 0.24452800E+01, 0.30900400E+00, 0.10734200E+01, -.79617300E+00, -.18682500E-01, -.11156300E+01, 0.21362400E+00, -.22388000E+00, -.36626100E+00, 0.77014500E+00, -.15751100E+01, -.48096800E+00, 0.34354900E+00, -.20723900E+00, -.11790900E+01, 0.85841500E+00, -.10541800E+01, -.81678300E-01, -.22557700E+01, -.12551100E+00, -.59372100E+00, 0.11991000E+00, 0.13734100E+01, -.21105800E+01, -.89527500E+00, -.91598300E+00, -.18618000E+01, -.20027100E-01, -.43798900E-01, -.44450500E+00, 0.12672900E-01, -.72704500E+00, 0.53079300E+00, 0.38097000E+00, 0.27064300E+01, 0.81146900E+00, -.77096300E+00, -.25965400E+01, 0.12856100E+00, -.33330500E+00, -.10783800E+01, -.71905900E-01, 0.13100800E+00, 0.34475300E+00, 0.51525400E+00, 0.11231100E+00, -.47138500E+00, -.15370800E+00, -.18036600E+01, 0.62757700E+00, 0.21525700E+00, 0.21951800E+01, -.33484900E-01, 0.39190400E+00, -.13245000E+00, -.71640600E-01, -.22571900E+00, -.18733800E+01, -.23593400E+00, 0.12090800E+01, 0.51543700E+00, -.20645700E+00, 0.63043600E+00, 0.10375600E+00, 0.45534300E+00, 0.21572800E+00, -.15111900E+01, 0.52761400E+00, 0.29326400E-02, -.37030600E+00, -.83538800E+01, 0.62801800E+00, 0.15006300E+01, -.24419400E+00, -.21193000E+01, 0.10055000E+02, 0.95997800E+00, -.26204800E+00, 0.32018100E+00, -.89980300E+00, -.49311700E+00, 0.64158400E+00, -.10747500E+01, -.17558500E+00, 0.14535100E+01, 0.14609700E+00, 0.76633400E+00, 0.87157200E+00, 0.38090900E+00, 0.19239700E-02, -.69695300E+00, -.52351500E+00, -.11009300E+01, -.72804500E+00, 0.62326900E-01, 0.89223000E+00, -.18380600E+00, 0.48544600E+00, -.95202500E-01, 0.38197100E-01, -.62506800E+01, 0.47596000E-01, 0.14888800E+01, -.17327700E+00, -.44149400E+00, -.11012500E+01, -.81872800E+00, -.47627100E-03, -.34979400E+00, -.64239400E+00, 0.61911700E+00, 0.11209200E+00, -.67310000E-01, 0.64830100E+00, -.20025600E+00, 0.92687000E+01, -.21471500E+01, -.92893000E+00, 0.28535600E+00, -.18553600E+03, -.13153000E+03, -.15834600E+03, 0.12446000E+03, 0.44071300E+03, -.29213400E+03, -.30031500E+02, 0.84935200E+02, -.15490700E+02, -.28859100E+03, -.38815800E+02, 0.24090700E+02, 0.75109200E+02, -.11193600E+03, -.22913100E+02, 0.44058800E+02, 0.60001500E+02, 0.84721000E+02, -.11006400E+03, 0.36759900E+02, 0.20747000E+03, 0.52919900E+02, -.19220900E+03, -.11255800E+03, -.19599900E+03, 0.99030800E+02, 0.51937500E+03, -.29667400E+03, -.96084900E+02, 0.33490800E+01, -.31798200E+01, -.11719200E+03, -.47937400E+01, -.66678600E+02, -.79463400E+02, 0.15099500E+03, 0.11262300E+03, 0.40675000E+02, -.75682900E+02, -.14838400E+02, 0.48661200E+02, -.31428600E+02, 0.35094900E+02, -.25232500E+02, -.17827300E+02, -.69945000E+02, 0.16255900E+02, 0.16562400E+03, 0.79689100E+02, -.32687200E+02, 0.67177900E+02, 0.10290800E+02, 0.64071900E+01, 0.17813400E+01, 0.15260000E+02, -.21292500E+01, -.27515400E+02, -.11831500E+02, 0.11515400E+02, -.65101800E+01, 0.15889900E+02, 0.37418600E+01, -.18524200E+02, -.53810800E+01, -.63927400E+01, -.13382200E+02, 0.17325300E+02, -.12149500E+02, 0.17602400E+02, -.18373600E+02, -.71342800E+01, 0.10131900E+02, 0.39871100E+02, 0.16553600E+02, -.12574700E+02, 0.23725200E+01, -.11526700E+02 },
        { 0.63912000E+01, 0.74421900E+01, 0.84449800E+00, 0.35834500E+01, 0.13394700E+01, -.34730300E-01, 0.72919800E+01, 0.18153500E+01, 0.33547200E+01, -.53744600E+01, -.15179500E+00, 0.35422100E+00, 0.10459300E+01, -.34461200E+01, 0.15697400E+01, 0.19024600E+01, 0.40175900E+00, -.20339600E+01, -.30048300E-01, -.14829600E+00, -.77014400E+00, -.87686400E-01, 0.17039700E+00, -.37916900E+00, 0.43956100E+01, -.61005600E-01, 0.75587800E+00, -.32673800E+00, 0.58037000E+00, -.12909300E+01, 0.86575200E+00, -.65012300E+00, 0.42935100E+00, 0.74685500E+00, 0.41353500E+00, -.16922100E+00, -.46825500E-01, 0.61367000E+00, 0.19965700E+01, 0.11963600E+01, 0.13933000E+00, -.12865500E+00, 0.17197700E+00, -.46651800E+00, -.70166600E+00, 0.10888400E+00, -.19483100E+00, 0.64381100E-02, -.80714200E-01, -.15144400E+00, -.21560900E+01, -.89998300E-01, 0.17589300E+00, 0.48487700E+00, 0.26143300E+00, -.13541400E+01, -.21101100E+00, -.55903300E-01, 0.64777800E-01, -.77557500E+00, 0.94237000E+00, 0.51363600E+01, 0.29340200E+01, -.14800300E+01, -.10685900E+00, -.13769400E+00, -.21124400E+01, -.50785200E+00, -.29335600E-01, -.79797900E-01, 0.92027300E+00, -.65585800E+00, -.47338400E+00, -.73955500E+00, 0.13150600E+00, 0.45821700E+00, -.32735200E+00, -.43597800E+00, 0.20974500E+00, -.11716800E+01, -.23838600E+00, 0.33859900E+00, 0.36927800E+01, 0.21973200E+00, -.31741800E+01, 0.19171300E+00, -.19206400E+01, -.24601100E+00, -.35175600E+01, -.11459300E-01, 0.21087800E+01, 0.29292100E-01, 0.94611400E+00, 0.63673900E+00, -.14435300E+01, 0.20833800E+00, -.42335100E+00, -.23081800E+01, -.20532500E+00, 0.21729500E+00, 0.13883700E+00, -.46776200E+00, -.85413400E+00, 0.52955700E+00, -.44261000E+00, -.13123500E+00, -.42174700E+00, -.16478200E+01, 0.21781600E+00, -.20174300E+00, 0.83019600E+00, -.50990200E+00, -.52292800E-01, -.20328100E+00, -.36356000E-01, 0.10539300E+01, 0.28399500E+01, -.80849600E+00, -.34165900E+00, -.15299800E+00, -.33786900E+00, 0.63275800E+00, 0.59526400E-01, 0.13433000E+00, -.21954900E-01, 0.32294500E+00, -.29768200E+00, -.27360100E-02, -.11964100E+00, -.11980200E+00, 0.46213900E+00, -.12183800E+01, 0.59586500E+00, -.18338600E-01, 0.20782700E+00, 0.58801000E-02, -.10579500E+01, 0.51382200E+00, -.19109200E+00, 0.23079400E+00, -.32372800E+00, -.14529900E+01, 0.19877700E+01, 0.56914000E+00, -.10720800E+00, -.32762300E+00, -.65289300E-01, 0.24834700E+00, 0.24073400E+00, -.37968800E+00, -.20360000E+00, -.12203200E-01, 0.81257500E+00, -.19425300E+00, -.39827000E-01, -.23284600E+00, 0.11598500E+01, -.34852300E-01, 0.67388300E+00, 0.10025100E+00, -.21836300E+00, -.34521300E+00, -.23793500E+01, 0.11662800E+00, 0.51951300E+00, -.36033200E+00, 0.52522000E+00, -.70561200E+00, 0.26417400E-01, 0.20647700E-01, 0.24932100E-01, 0.50904300E+00, -.98714200E-01, 0.22735500E+00, 0.68180300E-01, -.26095400E+01, 0.12832700E+00, 0.14163200E+00, 0.34622600E-01, -.12639600E+01, 0.37913600E+01, 0.41553100E+00, -.71474400E+00, -.38110800E+00, 0.75975300E+00, -.33171700E+00, 0.64856200E-01, 0.20230800E+00, -.30163200E+00, -.67536700E-01, 0.16178600E-01, -.13439600E+01, -.42496500E+00, -.11706400E+01, 0.77248700E+00, -.25069900E+00, 0.68488800E-01, 0.29674500E+00, 0.16909800E+00, 0.30821800E+00, 0.25145400E+00, -.54702100E-01, -.32514500E+00, -.84186400E-01, -.12711200E+00, 0.21867500E+01, -.16427600E+00, 0.11496700E+01, -.24587900E+00, 0.10879100E+01, 0.74633200E+00, 0.17568800E+00, -.58377800E-01, 0.27422100E+00, 0.10425400E+01, 0.11342600E+01, -.36110800E+00, 0.17836500E+00, -.76338600E+00, 0.13401900E+00, -.39168100E+00, -.13058300E+00, -.37073800E+00, 0.10353700E+00, -.22322400E+00, -.16923500E+03, 0.80740900E-03, 0.58358000E+02, 0.24736700E+03, -.23709900E+03, -.20796900E+03, 0.16819500E+03, -.11224200E+03, -.11795700E+03, -.82434800E+02, 0.69305400E+01, 0.33729800E+02, -.31169500E+02, 0.50412800E+02, -.21046000E+02, 0.25430500E+02, -.30414900E+02, -.12170300E+03, 0.56590100E+02, 0.83119700E+02, 0.60274600E+02, 0.13840400E+02, -.19205900E+03, 0.26625400E+02, 0.25276400E+02, 0.34346200E+03, -.25110400E+03, -.21077200E+03, 0.97548900E+02, -.46694900E+02, -.74995700E+02, -.49588200E+02, 0.96295000E+00, -.50263500E+02, 0.53932500E+02, 0.74528900E+02, -.28198600E+02, -.35226800E+02, -.30846100E+02, -.40632300E+02, 0.20602100E+02, 0.50181800E+02, 0.19155500E+02, -.19138800E+02, -.51509700E+02, 0.71095500E+02, 0.76467200E+02, 0.35545800E+02, -.13493700E+02, -.58767900E+02, 0.20616300E+02, 0.13419700E+01, 0.59941000E+00, 0.37345100E+01, -.45305600E+01, -.10405800E+02, -.28753100E+01, 0.42579000E+01, -.20519800E+01, 0.57655400E+01, -.11798700E+01, -.11165000E+02, 0.14731200E+01, 0.10490800E+01, -.97668800E+01, 0.14644000E+02, -.11547700E+02, 0.70469000E+01, -.13594100E+02, -.11867700E+00, 0.51918900E+01, -.40516200E+02, 0.12072300E+02, 0.75565100E+01, 0.49551300E+01, -.18197400E+01 },
        { 0.12521100E+02, -.82827000E+01, -.11368900E+01, -.25194000E+00, 0.62440300E+01, -.31907200E+01, 0.10996300E+02, -.35317300E+01, 0.64476100E+01, -.71350000E+01, 0.20506200E-01, 0.12632100E+01, 0.71429200E+00, -.66859400E+01, 0.21375900E+01, -.38510200E+01, 0.12279100E+01, -.10233300E+01, -.49151600E+00, 0.14811300E+00, -.16817000E+01, -.35204800E-01, 0.33925200E+00, 0.59909700E+00, -.50390300E+01, -.14022400E+00, 0.19422200E+00, -.64002400E+00, 0.26582900E+01, 0.17314500E+01, -.53659500E+00, 0.12207200E+01, -.16975100E+01, 0.79958300E+00, -.76437800E+00, 0.71325200E+00, 0.59881000E-01, -.14438000E+01, 0.26030200E+01, -.19129700E+02, -.15076900E+00, 0.67782300E-01, -.23201700E+01, -.83904300E+00, 0.18354800E-01, -.11774800E+01, -.29984100E+00, 0.68403900E-01, 0.17303300E+00, 0.32618700E+00, 0.38909200E+01, -.31207500E-01, -.32050800E+00, -.35036400E+00, -.12450800E+01, 0.25560800E+01, -.78640400E+00, -.20006200E+00, 0.84633800E-01, 0.13585400E+01, -.87154400E+00, -.23465300E+01, -.13269400E+01, 0.19332500E+01, 0.11599500E+01, 0.22974500E+00, -.52804300E+00, -.32261400E+00, 0.46179600E+00, 0.10815000E+00, 0.21263800E+01, -.18366900E+01, 0.26554800E+01, -.83942100E+00, 0.17722700E+00, 0.15909100E+01, -.76578000E+00, -.18180600E+00, -.10893200E+00, 0.15577400E+01, 0.13837800E+00, -.17612300E+00, -.17111300E+01, -.21363300E+00, 0.30669600E+01, 0.95295000E+00, -.19681400E+01, -.13690500E+01, 0.81305200E+00, -.70467100E+00, -.51703800E+01, 0.12566600E+00, 0.29195000E+00, -.86309100E+00, 0.34826400E+00, -.19147500E+01, -.27703000E+00, 0.50682300E+00, -.33341400E+00, -.18135000E+00, 0.11952900E+00, 0.44255400E+00, 0.10482800E+00, -.11005000E+01, 0.15068100E+00, -.67575300E+00, -.11770000E+01, -.24103700E+00, 0.45805300E-01, -.20840800E-01, 0.52792000E+00, 0.32525400E-02, 0.12699300E+00, 0.17864700E-01, -.34845100E+00, -.20564600E+01, 0.35650600E+01, 0.50244300E+00, -.47849800E+00, -.91365300E+00, -.37250400E+00, -.15107200E-01, 0.42902600E+00, 0.45774100E+00, 0.62556900E-01, -.26360400E+00, -.28751100E+00, 0.98258600E+00, -.82714400E+00, 0.46373800E+00, -.21103800E+01, 0.49595100E+01, -.17570800E+01, 0.11013800E-02, -.21008000E+00, -.17459400E-01, -.84872400E-01, -.53617500E+00, -.75900500E+00, 0.57757400E+01, -.89096300E+00, -.25629400E+01, -.97650500E+00, 0.22428800E+00, -.11170100E+00, 0.49702300E+00, -.21323800E+00, 0.39316900E+00, 0.20236200E-01, 0.11761500E+00, -.23216400E-01, -.14819800E-01, -.71676300E+00, 0.54882900E+00, -.18781700E-01, 0.15908900E+00, 0.10167400E+01, 0.38984800E+00, 0.12181100E+01, -.18111200E+01, 0.63346300E-02, -.16588200E+01, -.96496400E-01, 0.92157700E-01, 0.23380500E+01, -.85376500E+00, -.93235800E-01, 0.96132900E+00, -.50874000E+00, -.36945600E+00, 0.24180100E-01, 0.19243700E+01, -.61311000E+00, -.19385100E+01, 0.29004700E+01, -.26095400E+01, 0.47522500E-01, -.19093200E+01, -.27648600E+00, 0.10153700E+01, -.16097800E+02, 0.16631100E+01, 0.16555000E+01, 0.68812300E+00, -.28371900E+00, 0.43262800E+00, 0.46886400E+00, -.15896600E+01, -.22257900E+00, -.36874800E+00, -.52908900E-01, -.12737600E+01, -.13446600E-01, 0.65251400E+00, -.69488900E+00, -.51147600E+00, 0.80681100E+00, 0.12046600E+00, -.48875300E+00, -.85129800E+00, 0.33190200E+01, -.79290800E-01, -.11985800E+01, -.10279100E+00, -.30478500E+01, 0.16453700E+02, -.54224800E+01, 0.27116800E+01, -.10031000E+01, 0.17512600E+01, -.49922700E+00, -.55807400E+00, 0.87227900E-01, -.21558800E+00, -.20219600E+01, 0.26960800E+01, 0.12456200E+01, -.32395600E+00, 0.64753500E+00, 0.19512800E-01, -.39694300E+00, 0.68627100E-01, 0.25305200E+00, -.77348100E-01, -.57158800E+00, -.76966500E+00, -.31711800E+03, -.18253500E+03, 0.77363800E+02, -.14111800E+03, -.14444600E+03, 0.16069400E+03, -.82498800E+02, -.27671500E+03, -.75489200E+02, 0.11531400E+02, 0.39967200E+01, -.37544600E+02, 0.40194100E+02, 0.74421400E+02, 0.59763300E+01, -.22961600E+01, -.17563200E+03, 0.71232000E+02, 0.72221000E+02, 0.85815100E+02, 0.14468500E+02, 0.21294100E+02, -.47821300E+03, -.40085700E+03, 0.14303400E+03, -.96216600E+02, -.89780400E+01, 0.28917400E+03, -.13935600E+03, -.32140400E+03, -.14764900E+03, -.53988900E+02, -.11969200E+03, 0.14072200E+03, 0.10019000E+03, -.19109800E+03, -.11841400E+03, -.14635600E+03, 0.23401700E+03, -.10351600E+03, 0.88568000E+02, -.11788500E+03, -.13927100E+03, -.83018100E+02, -.68953500E+02, 0.13513600E+03, -.65218500E+02, -.27141500E+02, -.27712000E+02, 0.30900200E+02, 0.54925700E+01, -.32292600E+01, -.35339500E+01, -.13822600E+02, -.12569000E+02, -.31831500E+01, 0.16632100E+02, -.48851800E+01, 0.46993700E+01, -.72015200E+01, -.23161900E+02, 0.49236500E+01, -.20522000E+01, -.20069600E+02, 0.18496300E+02, -.12137400E+02, 0.79888100E+01, -.20788800E+02, -.30366100E+01, 0.22296400E+02, 0.74772500E+02, 0.26387100E+02, -.17696200E+02, -.11126100E+02, 0.82374600E+01 },
        { -.12930300E+02, 0.50606000E+01, 0.10555100E+01, -.21950800E+01, -.52574500E+01, 0.33396000E+01, -.13305700E+02, 0.88922900E+01, -.70491800E+01, 0.96242000E+01, 0.26976600E+00, -.63906100E+00, -.89860900E+00, 0.45391500E+01, -.30930300E+01, 0.50742400E+01, -.68469000E+00, -.73503000E+00, 0.97250400E-01, -.27122600E+00, -.23349800E+00, 0.39993800E+00, 0.10693500E+00, 0.73411500E+00, -.54500700E+01, -.10277900E+00, -.95928600E+00, -.21768100E+01, 0.80953800E+00, 0.17544500E+00, -.56907800E+00, -.47735600E+00, 0.62174700E+00, 0.54878400E+00, -.30151900E+00, -.27722200E+00, -.38032200E-01, -.11137800E+00, -.30186900E+01, -.27390500E+01, 0.21096600E+00, -.35131700E+00, -.89927700E+00, 0.55453500E+00, 0.48324600E+00, 0.35780500E+00, -.10760800E+01, -.27235400E-01, 0.54862100E+00, 0.10584200E+01, 0.29286900E+01, -.22517400E+00, -.14055900E+00, -.18081800E+01, 0.88551400E+00, 0.23151300E+00, 0.12399300E+01, 0.41536200E-01, 0.17628000E+00, -.10536300E+01, -.47260000E+00, 0.73491400E+01, 0.43028300E+01, -.39048000E+01, 0.32012900E+01, -.51871900E+00, 0.83257000E+00, -.14481200E+00, 0.63779600E+00, -.10764300E-01, -.16101200E+01, -.48845700E+00, -.24629300E+01, -.13400000E+00, 0.15391000E+00, 0.17262900E+01, -.20183000E+00, 0.60442400E-01, 0.10661500E+00, -.21582000E+00, -.11572600E+00, -.47112200E+00, 0.15672600E+01, 0.53540500E+00, 0.77814200E+00, 0.75326800E+00, 0.26898800E+01, -.14300700E+01, -.23754900E+01, -.23029100E+00, 0.16153200E+01, -.18696400E-02, 0.47106100E+00, 0.58878700E+00, -.19834000E+01, -.10754800E+01, 0.32197800E+00, -.25475100E+01, -.85772700E+00, 0.62986800E+00, 0.33529900E+00, -.10599200E+01, -.13807600E+01, 0.42831400E+00, 0.20584400E+00, -.30493000E+00, -.91711400E+00, -.13470300E+01, -.23749800E+00, -.17310400E+00, -.54070200E+00, 0.46874800E-01, 0.12324800E+00, -.45599800E+00, 0.43501500E+00, 0.23180100E+01, -.37065800E+01, -.12995400E+01, 0.74153300E-01, 0.38242900E+00, -.31968400E+00, 0.41330700E+00, -.19923600E+00, 0.27118700E+00, 0.29982400E-01, 0.11734900E+00, 0.14937900E+00, -.14870000E+01, 0.11214400E+01, 0.26587500E+00, 0.12206800E+00, -.21292000E+01, 0.95253900E+00, 0.10100700E-01, -.49115900E-01, -.44855000E-03, -.25924300E+01, -.12493600E-01, -.43534000E-01, -.12420400E+01, -.10682000E+01, 0.62082600E+00, -.14796300E+01, -.67430600E+00, -.11252600E+00, 0.13490600E+01, 0.74574300E-01, 0.18385900E+00, -.94148500E-01, 0.11938500E+01, 0.62312700E+00, 0.58363600E+00, 0.59832800E+00, 0.88818300E+00, -.10078900E+00, -.46318300E+00, -.89587900E+00, -.53964800E-03, 0.19144800E+00, 0.27896400E-01, 0.60091200E-01, -.10743500E+01, -.25028700E-01, -.15768900E+00, 0.88179400E+00, -.36271200E+00, 0.11167000E+01, 0.18286400E-01, 0.75349700E-01, -.37517300E-01, 0.17722900E+00, 0.63959900E-01, 0.38657400E+00, 0.25672500E+00, -.55981000E+00, 0.27156000E+01, -.84355000E-01, 0.10448800E+01, 0.12043500E+00, -.89989000E+00, 0.26186200E+01, -.37597600E+00, 0.21579900E+00, 0.96809800E+00, 0.85875700E-01, 0.50539200E-01, 0.66841600E-01, 0.22605700E+01, -.86322700E-01, 0.75486000E+00, 0.38569100E+00, 0.15493700E+01, 0.75629200E+00, 0.12148600E+01, 0.93384200E+00, -.16932800E+00, 0.32707500E+01, -.10609200E+00, -.21559000E+01, 0.38862600E+00, 0.11425700E+01, -.49354400E+00, 0.17534200E+01, 0.59046300E-01, -.27976300E+00, 0.16849300E+02, 0.44396600E+01, -.39919500E+01, 0.16922500E+01, 0.37030300E+01, -.71806800E+00, -.15850700E+00, -.21151900E+00, -.64918400E+00, 0.45030300E+00, -.49348000E+01, -.19329700E+00, -.14911600E+00, 0.89362200E+00, -.41971200E+00, 0.28373700E+00, -.62511600E+00, -.50789300E+00, 0.24423900E+00, 0.62435900E+00, 0.63954400E+00, -.73715000E+00, -.24875800E+03, -.27931300E+03, 0.40461500E+02, -.15826700E+02, 0.68207100E+02, -.13871600E+02, 0.63405200E+01, -.22582900E+02, -.19522200E+02, 0.29036200E+02, -.97730700E+02, -.33207900E+02, -.64406600E+02, 0.44224100E+02, -.66170000E+02, 0.48404500E+03, -.24796100E+03, -.32588300E+03, -.24383500E+03, -.38332200E+02, -.93533900E+02, -.32352600E+03, -.61710600E+03, -.48672200E+03, 0.22668500E+02, 0.78072500E+02, 0.17610500E+03, -.84831100E+02, -.34683900E+03, -.90673000E+02, -.18189600E+02, -.21812000E+02, 0.10728200E+02, -.46605700E+02, -.20382300E+03, -.49489300E+02, -.65267900E+02, 0.99700600E+02, -.28449200E+02, -.36603900E+02, -.47105700E+02, -.16534300E+03, 0.69136300E+02, -.16036900E+03, -.55562000E+02, -.69648700E+02, 0.11107700E+02, -.52549100E+02, 0.23305200E+02, 0.16450100E+01, -.83316000E+01, -.17266600E+02, -.56253000E+01, 0.19036400E+02, 0.89335600E+01, 0.64143700E+01, 0.42797200E+01, -.93783100E+01, -.18700500E+02, -.27689300E+02, 0.10574400E+02, 0.25998900E+01, -.46424800E+02, 0.40877800E+01, -.12230400E+02, -.70845100E+01, -.33310900E+02, 0.43307600E+01, 0.96903900E+01, -.23638700E+02, 0.30218300E+02, 0.14759500E+02, -.26759000E+02, 0.16839400E+02 },
        { -.10173500E+02, 0.49396400E+01, 0.82856300E+00, -.49969000E+01, -.67342400E+01, 0.12302100E+02, -.14175800E+02, 0.19332400E+02, -.70074500E+01, 0.84148900E+01, 0.74540400E-01, -.67192800E+00, 0.55021200E+01, 0.51612900E+01, 0.29745400E+01, 0.40468900E+01, -.33503800E+01, -.11768900E+00, 0.12610400E+00, -.14404600E+00, -.10500300E+01, 0.41986400E+00, -.21486900E+00, 0.61363600E+00, -.53758800E+01, 0.88275900E+00, -.26073200E+01, -.25890500E+01, 0.40928900E+01, -.38755700E+00, 0.14270000E+01, -.63024800E+00, -.71661000E+00, 0.25341200E+01, 0.32877800E-01, 0.37849200E+00, -.24218200E+01, -.18858200E+01, -.91072700E+00, -.17658600E+02, -.57161700E+00, -.12287300E+01, -.56314800E-01, 0.60783800E+00, 0.16040300E+00, -.34626200E+00, -.41453900E+00, 0.79126000E-01, 0.52629600E+00, 0.45908200E+00, -.79751300E+00, 0.47567600E+00, -.27544300E+00, 0.12043800E+01, 0.40823700E+00, 0.23511800E+00, -.13370000E+01, -.39457200E+00, 0.43964200E+00, -.12878200E+01, 0.99772200E+00, 0.27218100E+01, 0.17133200E+01, 0.21675600E+01, -.13762300E+01, 0.19080400E+00, 0.91826700E-01, 0.11226900E+01, -.26244400E+00, 0.43141600E+00, 0.11480400E+01, -.21058700E+00, -.20547600E+01, 0.15217400E+00, -.92916600E+00, -.34915400E+00, -.30043800E+00, 0.10192400E+01, 0.22023500E+00, -.64321600E+00, 0.42628600E+00, 0.27613100E+00, 0.23961600E+00, 0.26073600E+00, -.54075200E+00, 0.16015400E+00, -.46981200E+00, 0.83681800E+00, -.10889800E+01, -.23398700E+00, 0.27210200E+01, 0.81458700E+00, 0.43580600E+00, -.12877100E+00, 0.25200200E+01, 0.18324600E+01, -.11395300E+01, -.17605100E+01, 0.88275200E+00, 0.36442800E+00, 0.22786800E+00, 0.23534600E+01, 0.30596900E+00, -.22459100E+01, -.13973800E+00, 0.83584600E+00, -.10814100E+01, -.24016000E+00, 0.24918000E+01, -.23149600E-01, -.52959700E+00, 0.22889400E-01, -.13922700E+00, 0.44636600E+00, -.36732800E+00, 0.14316300E+01, 0.34034300E+01, -.62026500E+00, -.17212700E+00, -.49982100E+00, 0.20108900E-01, 0.12099300E+01, 0.21307700E+00, -.38788400E+00, -.13121400E+00, -.53035100E+00, 0.29057200E+00, -.52885400E+00, -.85671600E+00, 0.31811100E-01, -.12191700E+01, -.38183900E+00, -.20643400E-01, -.41227100E-02, -.10291100E+00, -.67144700E-01, -.20809600E+01, -.76485000E+00, 0.18753500E+00, 0.51387200E+01, -.12134000E+01, -.16995900E+01, 0.22952900E+00, 0.13740900E+00, -.20302300E+00, 0.17599800E+01, 0.93079100E+00, 0.55713600E+00, 0.69350000E+00, 0.42638100E+00, 0.14004000E+01, 0.47740000E+00, -.21876400E+01, -.75335000E-01, -.14189600E+00, 0.83448800E+00, -.13823500E+01, 0.41836200E+00, -.43101200E+00, -.23078000E+01, 0.77222900E+00, -.65498500E+00, -.11777300E+01, 0.18005900E+00, 0.89464300E+00, -.73108300E+00, 0.45695400E+00, 0.18376400E+00, 0.16844800E+00, -.43220300E-01, 0.51625400E+00, 0.56412900E-01, -.25394600E+00, -.62899200E+00, 0.20558500E+01, 0.16362900E+01, -.12102600E+00, -.11284300E+01, 0.82925700E+00, 0.50611400E+01, 0.56826400E+01, -.15401800E+01, 0.27882700E+01, -.21493400E+01, -.27969000E+01, -.37386400E+00, 0.57481900E+00, -.15171100E+01, 0.44706100E+00, -.10082700E+01, -.27509200E+00, 0.28355600E+01, 0.57186600E+00, 0.28502200E+01, 0.28996600E+01, 0.24356800E+01, -.60802000E+00, -.98342400E+00, -.11342600E+01, 0.10716600E+00, -.52413000E+00, 0.89222400E+00, 0.47428200E+00, -.13561600E+01, -.74325900E+00, 0.60830000E+01, 0.36108700E+00, -.69287000E+01, -.11410800E+01, -.91566800E+00, -.19579200E+00, -.67248000E+00, 0.10632800E+00, -.36811100E+00, -.90684800E-02, -.13991800E+01, 0.11744500E+01, -.36944600E+00, 0.22141100E+00, -.42206000E+00, -.54179500E+01, -.21091500E+00, 0.10980800E+01, -.33039800E+00, -.36119100E+00, -.45991300E+00, 0.18808200E+00, 0.33243000E+00, -.37094800E+03, 0.80930200E+02, 0.54333600E+03, -.15650600E+03, 0.82907100E+02, -.25227300E+02, 0.82870900E+02, -.15587800E+02, -.39526100E+02, 0.32092300E+02, -.43236000E+02, 0.63192900E+02, -.24568900E+02, 0.39705800E+02, -.57046600E+03, 0.27418100E+03, 0.32400700E+03, 0.28620300E+03, 0.90048300E+02, -.31023000E+02, 0.20705100E+03, 0.24774300E+02, -.25847900E+03, 0.85725800E+02, 0.87939400E+03, 0.78969700E+01, -.12245400E+02, 0.15597100E+03, 0.10389700E+02, -.35780700E+02, 0.54962800E+02, -.89303200E+02, -.39421700E+02, 0.87674900E+02, 0.38725300E+02, -.31659500E+02, 0.25656800E+03, -.12614800E+03, 0.31830700E+01, -.12352700E+03, -.13273200E+03, 0.55758700E+02, -.56786800E+02, 0.39592300E+01, -.47532700E+02, 0.12725200E+02, -.11998500E+03, -.32470000E+02, 0.11998800E+01, 0.89690300E+01, -.22648000E+01, -.13710200E+02, 0.34442700E+01, -.32897700E+01, -.44123000E+01, -.15150000E+01, -.34003600E+00, 0.30195700E+01, 0.30804300E+02, -.11405600E+02, -.62441700E+01, 0.26679500E+02, -.10347700E+02, 0.91310300E+01, -.79291500E+01, 0.25963700E+02, -.45904800E+01, -.21366800E+01, -.10756500E+03, -.31500900E+02, 0.28397800E+02, -.93266500E+01, 0.50277800E+01 },
        { -.10589800E+01, 0.38372700E+00, 0.99599900E-01, 0.45102500E+00, -.12872500E+00, -.17087300E+01, -.18740800E+00, -.60213300E+00, -.51304000E+00, 0.74748500E+00, 0.32136400E-01, -.42814900E-01, -.13266200E+00, -.45476500E+00, -.68001200E-01, 0.31129700E+00, 0.28608900E+00, -.19899600E+00, -.26752300E+00, 0.40591100E+00, -.22873200E-01, 0.14028400E-02, 0.90299000E-01, 0.14874400E+00, -.19331300E+00, -.22035100E-01, 0.55389700E-01, 0.30944500E+00, -.16910400E+00, 0.62208600E+00, -.20989000E+00, 0.52704200E-01, -.43495900E-01, 0.12137900E+00, -.27568600E-01, -.17385700E+00, 0.37779300E-01, -.18099800E-01, -.77601700E-02, -.28241500E+01, 0.51915000E-01, -.56251600E-02, 0.31015100E+00, 0.22357000E+00, 0.96851700E-01, 0.42508100E-01, 0.11195700E+00, -.10620200E-01, 0.22314000E-01, -.15031700E-01, 0.79423100E+00, -.24892000E-01, -.15899800E+00, -.29543900E+00, -.31396200E+00, 0.65952400E-01, -.51699100E-01, 0.54797000E-02, -.38445200E-01, 0.11389300E+00, -.78572200E-01, -.42498000E+00, -.17956400E+00, -.29219000E+00, 0.24569200E+00, -.12924800E-01, 0.19193000E-01, -.57429200E-01, 0.50315700E-01, -.47627100E-02, 0.21170300E+00, -.58504500E-02, -.56171600E-01, 0.14822500E-01, -.68035500E-01, -.16652500E+00, -.51581600E-01, -.11652600E-01, 0.17179500E+00, -.44936400E-01, 0.49994600E-01, 0.29721100E-01, -.14464100E+00, -.33629500E-01, -.28712800E+00, -.92021600E-01, 0.32002700E+00, -.81209500E-01, -.74336100E+00, 0.14784400E-01, 0.52237800E+00, 0.20611900E-01, 0.46723300E-01, 0.24269500E+00, -.23797400E+00, -.31922600E+00, 0.89702000E-01, -.12056300E+00, -.13370600E+00, -.69068300E-01, 0.17646000E-01, -.10461100E+00, -.97438900E-01, 0.11986800E+00, -.45558000E-01, -.99842600E-01, -.23258400E+00, -.26995800E+00, -.24991700E+00, -.82623300E-01, 0.26442000E+00, -.48706500E-01, -.26378800E-01, 0.50442200E-01, -.46210700E-01, 0.24526700E+00, -.40976200E-01, -.91050600E-01, 0.30266700E-01, -.61911900E-02, -.11252100E+00, -.89229800E-01, 0.18262000E-01, -.28498400E-01, -.97950400E-02, -.17739300E-01, 0.17782600E-01, 0.34244000E-01, -.96363200E-01, 0.27417400E-01, 0.47325300E-01, 0.30408200E+00, -.16377300E+00, -.35879400E-02, -.11304900E-01, 0.18609100E-02, -.63207000E-01, 0.12214800E+00, 0.48898200E-02, 0.16325300E+00, 0.16833900E+00, -.21794000E-01, 0.20497900E+00, 0.41969500E-01, -.27054500E-01, -.68888000E-01, 0.27035000E-02, -.61816100E-02, 0.13385600E-02, -.96054900E-02, 0.42801200E-01, 0.66869100E-01, -.15410400E-01, 0.14881500E-02, 0.87196200E-02, 0.97985500E-02, -.20013100E+00, -.85182000E-04, -.11727800E-01, -.17943600E-01, -.11951700E-01, -.38445000E-01, -.58370300E-01, -.19364500E-01, 0.10353400E+00, 0.11100600E-01, 0.31225400E-01, 0.57944800E-01, 0.69170000E-02, -.47338200E-01, -.89907400E-02, 0.12919400E-02, -.59186900E-01, -.24973800E-01, -.12776200E+00, 0.64211500E-02, 0.18324400E-01, -.22114500E-01, -.11698700E+00, 0.13517000E+00, -.12696700E+01, -.18669000E-01, 0.23669300E+00, 0.75333700E-01, -.70747200E-01, 0.27109000E-01, 0.12135300E-01, -.17963000E-01, -.10888900E-01, -.42778400E-01, -.58456300E-02, -.30565100E-01, -.60240700E-01, 0.14048700E+00, -.30233300E+00, -.12654000E+00, 0.36630000E-01, -.19420700E-01, 0.95311900E-02, -.47733100E-01, -.13891600E+00, 0.14000800E-01, -.88282900E-02, 0.14607300E-01, 0.54745000E-01, 0.65084800E+00, -.49467400E-01, 0.12016400E+00, 0.15287600E-01, -.13164800E-01, 0.39384100E-01, -.17723300E-01, 0.12662800E-01, -.55276400E-01, -.43796500E-01, -.18672200E+00, 0.31289000E-01, -.12522100E-01, 0.67022200E-01, 0.22452400E-01, -.53589000E+00, 0.34175000E-01, 0.21794600E-01, -.91321900E-02, -.78674100E-03, -.85894200E-02, -.26176000E-01, 0.23057600E-01, 0.10160400E-01, -.41256400E+01, -.12237200E+02, 0.76139200E+01, -.34467000E+01, -.23202100E+01, -.41869800E+01, -.62540200E+00, -.37221800E+01, 0.16869500E+01, 0.30010900E+01, 0.16712500E+01, -.36397300E+01, -.27950500E+01, -.18562400E+02, 0.92787400E+01, 0.11979500E+02, 0.92515800E+01, 0.62426500E+00, -.10602800E+01, 0.91724300E+01, 0.75490700E+00, 0.78196800E+01, -.26488700E+01, 0.25794900E+01, 0.75163300E+01, -.34268400E+01, 0.43391500E+01, -.39474600E+01, 0.16116400E+01, -.14390600E+01, 0.93606500E+00, 0.32821100E+01, -.69273000E+01, -.57235600E+00, -.34633400E+01, -.21612700E+01, 0.15111400E+01, 0.77891300E+01, 0.91070800E+00, 0.14070300E+01, -.18456500E+01, -.25073700E+01, -.37609900E+01, -.46147800E+01, 0.17699800E+01, -.23478500E+01, 0.10254400E+01, -.24916600E+00, 0.32136900E+00, -.19322100E+00, 0.11599800E+00, 0.29287900E+00, 0.19940200E+00, 0.20054600E-01, -.10538200E+00, -.50021300E+00, 0.50640300E+00, 0.79356500E+00, 0.33991700E+00, 0.14278200E+00, 0.10627500E+01, 0.49547000E+00, -.16383300E+00, -.99025000E-01, 0.94625700E+00, 0.23621000E+00, 0.13112100E+00, -.21179800E+00, -.60888400E+00, 0.95014200E+00, 0.57405800E+00, 0.64532000E+00 },
        { -.18534300E+01, 0.82735900E+00, 0.44576300E-01, -.87376500E+00, -.13125100E+01, 0.21464000E+01, -.28905600E+01, 0.10456700E+00, -.48459200E+00, 0.15816300E+01, -.10327500E+00, -.46697900E-01, -.10752700E+00, -.10877000E+01, 0.15507500E+01, 0.68685500E+00, -.13716600E+01, 0.41181000E+00, -.78817800E+00, 0.13881400E+01, -.28113500E+00, 0.13011500E+00, 0.14892200E+00, 0.21718800E+00, -.25639200E+01, 0.52902200E-01, 0.27236400E-01, 0.26111100E+00, -.19622200E+00, 0.13861600E+01, -.22715500E+00, -.18809000E+00, -.28761100E+00, -.29308200E+00, -.36282400E+00, -.23148100E-01, -.24008600E+00, 0.20963400E+00, 0.32801100E+00, -.35890700E+01, 0.19435200E+00, 0.54977900E+00, 0.29410800E+00, 0.53531700E+00, -.45944800E+00, 0.36886000E-01, 0.11931800E+00, -.14026100E-01, 0.27832500E-02, -.45325700E-01, 0.11728800E+01, 0.31728000E-01, -.48299600E+00, -.57825400E+00, -.63314900E+00, 0.22747000E-01, -.45649300E+00, 0.58429800E-01, -.45167400E-01, -.41692900E+00, -.18202900E-01, -.10042100E+00, -.26601500E+00, -.35662300E+00, 0.19136000E-02, -.39002600E-01, -.34413500E+00, -.28864600E+00, -.35967600E-01, 0.26962000E-01, -.14859600E+00, -.46572000E-01, 0.71645100E+00, -.14336500E+00, 0.41782200E+00, -.98448800E-01, 0.98665100E-01, -.74478500E+00, -.11515100E+00, -.25801500E+00, -.64022400E-01, 0.59546800E-01, 0.85045000E+00, -.81584300E-01, -.26084200E-01, 0.30761400E+00, -.13049800E+01, -.54002100E+00, 0.15788700E-01, 0.57458800E+00, -.11365700E+01, -.18678000E-01, 0.19571500E+00, -.33531500E-01, -.22714700E-01, -.13561500E+01, 0.28800000E+00, -.13677000E+00, 0.28440600E+00, 0.45685000E-03, 0.16969500E-01, -.68884700E+00, 0.42215400E+00, 0.57021000E+00, 0.34654900E+00, 0.94957800E-01, 0.43011900E+00, 0.68867800E+00, 0.35320200E+00, 0.88279600E-01, -.73180900E+00, 0.25212100E+00, -.49148000E-02, 0.19414300E+00, 0.50666200E+00, 0.73467000E-02, 0.85381000E+00, 0.28893300E+00, 0.58420500E-02, -.24847000E+00, 0.14175700E+00, 0.34510500E+00, 0.44724200E-01, 0.87234300E-01, -.61887600E-02, -.43424700E-01, -.74595400E-01, -.13705100E+00, -.26847200E+00, -.26154000E+00, 0.37069000E+00, -.16164300E+00, 0.84883900E+00, -.12558100E-01, -.93623200E-01, -.58911000E-02, 0.10928600E+01, -.18317600E+00, 0.24008500E+00, -.12917700E+00, -.18307800E+00, 0.84304500E-02, 0.39619000E+00, 0.15152200E+00, -.52156300E-01, -.12830400E+00, 0.48104200E-02, 0.55066800E-01, 0.10223000E+00, -.23042600E+00, -.39663000E-01, 0.26386400E+00, -.39503500E-02, 0.13703800E+00, -.51990200E-02, -.20853000E-03, 0.34906700E+00, 0.12276800E-01, 0.20264100E+00, 0.17745100E+00, -.99285600E-01, -.67376300E+00, -.76201800E+00, -.13675200E+00, 0.47108000E+00, -.32952700E-01, 0.33616400E+00, 0.35149600E-01, 0.45439300E-01, -.35737100E-01, 0.66911500E-01, -.28928400E+00, 0.10570400E+00, 0.10744500E+00, -.69020400E-01, -.10838000E+01, 0.92914300E-01, 0.11892400E+00, 0.55991600E-01, -.44176600E+00, 0.14005200E+01, 0.41359700E+00, 0.90271800E-01, -.25794500E+00, 0.21605100E+00, -.12361000E+00, -.57192100E-01, 0.23206900E+00, -.10755000E+00, 0.51452800E-01, 0.90881200E-03, -.23736000E+00, -.18517400E+00, 0.78523800E-01, 0.23030600E+00, 0.13081900E+00, -.67291700E-01, -.88105700E-01, 0.17000600E+00, 0.12402500E-01, -.42487400E-02, 0.29688600E-01, -.11042100E+00, 0.34005200E-01, -.17204500E+00, -.20803900E+01, -.65781400E+00, 0.87155900E+00, 0.88896400E-01, -.19026800E+00, 0.10101600E+00, -.27430900E+00, -.38222300E-02, -.14171800E+00, 0.91105900E-01, -.11731300E+00, 0.74783200E-01, -.64527300E-02, 0.35867900E-01, 0.67167600E-01, -.36210400E+00, 0.12744600E-01, -.13751700E+00, 0.48839500E-01, -.58351000E-01, 0.18612400E+00, 0.11821400E-02, 0.11989100E-01, -.47905500E-01, -.59402900E+00, 0.60074600E+02, -.37137900E+02, 0.26171900E+02, -.10763700E+02, 0.18495100E+02, -.21628400E+01, -.24079000E+02, 0.23789000E+02, 0.12667600E+02, 0.38608400E+02, -.21081300E+02, 0.80236900E+01, -.80460100E+02, 0.40032700E+02, 0.45820600E+02, 0.40306700E+02, 0.15624500E+02, -.28486400E+01, 0.42637200E+02, 0.20011800E+02, 0.30272500E+02, -.51265900E+00, 0.91291500E+02, 0.46789600E+01, -.17785800E+01, 0.36502500E+01, -.16979400E+01, -.16706400E+02, -.40604700E+01, -.20154300E+01, -.53027200E+01, 0.20101800E-01, -.37485300E+01, -.73542600E+01, -.15610900E+02, 0.58862500E+01, 0.12085200E+02, 0.80146400E+01, -.15533300E+02, -.99065600E-01, -.58903900E+01, 0.45261400E+01, 0.44303800E+02, -.24331000E+01, 0.35486100E+01, -.60757600E-01, 0.24668600E+01, 0.14379000E+01, 0.20887900E+00, 0.99467200E+00, 0.23730800E+00, 0.78863900E+00, 0.10711800E+01, -.10826900E+01, -.33758100E+00, 0.20415300E+01, 0.11697500E+01, 0.47570600E+00, -.82631600E+00, 0.29385700E+01, 0.97758300E+00, -.80170100E+00, 0.62013400E-01, 0.17386400E+01, 0.87258900E+00, 0.87188600E+00, -.10256100E+02, -.13711300E+01, 0.39898400E+01, -.19452900E+01, -.16530200E+01 },
        { 0.15583600E+01, 0.74500600E+00, 0.34635100E-01, 0.73122300E+00, 0.12295100E+01, 0.13044000E+01, 0.32270800E+00, -.44010900E+00, 0.62948600E+00, -.13442900E+01, -.62489500E-01, -.27296600E-01, 0.13378300E+01, -.16115800E+01, 0.15481400E+01, -.25261800E+01, -.49264400E+00, 0.72438600E+00, -.18618900E+00, -.47493700E+00, -.19096700E+00, 0.73780800E-01, 0.91390000E-01, -.31370500E-01, -.50503000E+00, 0.15219800E-01, 0.97008800E-01, 0.45106000E+00, -.50570600E+00, 0.36441400E+00, -.47029700E+00, 0.65212400E+00, -.24178000E+00, -.41743200E+00, 0.16164500E+00, 0.20399800E+00, 0.19360500E+00, -.43986800E+00, -.42401800E+00, -.99559100E+00, 0.59915800E-02, 0.12229500E+00, -.97495100E-01, -.95865900E+00, 0.38353300E+00, -.17340000E-01, 0.41665700E+00, -.30587100E-02, -.13801800E+00, -.66654800E-01, -.17009800E+01, -.15078600E+00, 0.97450800E-01, 0.27452000E+00, -.15825900E+00, 0.97045900E-01, -.12839400E+00, -.16093600E+00, -.55171500E-01, 0.38217600E+00, 0.47054400E+00, -.20782100E+01, -.12550800E+01, 0.98453100E+00, -.52437600E+00, 0.79895600E-01, 0.90747600E+00, -.19908500E+00, -.86259200E-01, -.43221700E-03, -.89637400E-01, -.83813200E-01, 0.66349400E+00, -.44855700E-01, -.14083300E-02, 0.12405500E+00, 0.18485300E-01, -.57594100E-01, -.17694400E-01, 0.27827200E-01, 0.48475700E-02, 0.76781900E-01, -.15864300E+00, 0.24960300E-01, -.52706600E-01, -.37019400E-01, 0.29923100E-01, -.65287900E+00, 0.23194800E+00, 0.44993900E+00, -.51690300E+00, -.12878100E-01, -.30261400E-01, -.21742300E+00, 0.78620100E-01, 0.85058400E-01, 0.37382600E-01, 0.24560600E+00, 0.33402800E+00, 0.10766900E+00, -.45018600E-01, 0.26946900E+00, 0.16405600E+00, 0.32398600E-01, -.20227600E-01, 0.38121000E+00, 0.64007100E-01, 0.27838900E+00, 0.17020200E+00, 0.94387900E-01, -.16868600E+00, 0.46574000E-03, 0.17622000E-01, -.27938300E-01, -.10485900E+00, -.18569600E+00, 0.67119400E+00, 0.68443900E-02, 0.72257200E-01, -.19332700E+00, 0.80719900E-01, -.20883800E+00, -.62598600E-01, -.90693800E-01, 0.12549700E-01, 0.13769900E+00, -.90788600E-01, -.82827800E-01, 0.67731800E-02, 0.68147300E-01, -.45364800E+00, -.36001600E+00, -.16434500E+00, -.33470000E-02, -.61261100E-02, 0.34761200E-03, 0.48047400E+00, -.13761500E+00, 0.48904000E-01, 0.48954700E+00, 0.37805000E+00, -.43320600E+00, -.61243200E+00, -.16388500E+00, -.13972000E-02, 0.54201700E-01, 0.27577000E-02, -.12244900E+00, -.27349400E+00, 0.11365500E+00, -.73118500E-01, -.15741300E+00, -.86931400E-01, 0.94154600E-02, 0.33041800E-01, 0.33870900E-01, 0.39930200E+00, 0.92314500E-02, 0.15658200E+00, -.74105200E-02, 0.19183400E-01, 0.29953200E+00, 0.45797900E+00, 0.26552400E-01, -.34496800E+00, 0.11664500E+00, -.26209000E+00, 0.78792800E-01, 0.25217700E-01, -.36804600E-01, -.47986800E-01, -.22968200E+00, 0.17741200E-01, -.10638700E+00, 0.64125900E-01, -.59879300E+00, 0.96479300E-01, 0.79383200E-01, -.40955900E-01, -.58943700E-01, -.10189600E+01, 0.72623200E-01, -.54856500E-01, 0.10037800E+00, 0.26932700E-02, 0.17260000E-02, -.26169700E-01, 0.11476500E+00, -.61948300E-01, 0.10404800E+00, 0.40241900E-03, -.21854200E+00, 0.28089600E-01, -.42021900E-01, -.36918900E+00, -.27531500E+00, -.34748800E+00, -.16220500E+00, -.47722800E-01, -.11214800E+00, 0.22276300E+00, 0.70950700E-01, -.88319100E-01, -.67054900E-01, -.26096700E+00, 0.14488600E+00, -.46621500E-01, 0.47806200E+00, 0.19610600E+00, -.25392400E-01, -.18143900E+00, -.17154900E+00, 0.32617600E-01, -.22961100E+00, -.40457900E+00, -.41836800E+00, 0.11936600E+00, -.76075100E-01, 0.29421900E+00, -.11372700E-01, -.52235300E-01, -.18096700E-01, -.11790800E-01, 0.15301400E-01, -.39321600E-02, 0.20438500E-01, 0.20766600E-01, -.27915300E-01, 0.21605600E-02, -.61858000E+00, -.13172900E+00, 0.46052500E+02, -.14759900E+02, -.46600200E+02, -.21983300E+02, 0.63827400E+01, 0.35906900E+02, -.55176900E+02, -.19046200E+02, -.28747500E+02, 0.29185500E+02, 0.13629800E+02, 0.12616300E+02, -.63125000E+01, -.13348300E+02, -.62213200E+01, 0.38302300E+01, -.80606200E+01, -.77278700E+01, -.12362800E+02, 0.14019400E+01, -.30611900E+01, 0.46162400E+01, 0.12345600E+02, -.53013500E+01, -.29673400E+00, -.60302100E+01, -.60304000E+01, -.38915900E+01, 0.15935600E+01, 0.67699200E-01, -.10926100E+02, -.58039200E+01, -.51222000E+00, -.52593600E+02, 0.28802100E+02, 0.25350900E+02, 0.26554700E+02, -.28655500E+02, -.43291700E+01, 0.48603500E+01, -.83226400E+01, 0.16387600E+02, -.34723100E+01, 0.46075700E+02, 0.37795400E+01, 0.20150500E+01, 0.53019700E+00, 0.13146700E+00, -.45620200E+00, 0.12680800E+01, 0.35405600E+00, 0.91114800E+00, -.38595400E+00, -.52995600E+00, 0.25015300E-01, 0.33249600E+01, 0.21955700E+01, 0.98984700E+00, 0.33366900E+01, 0.17460200E+01, -.18941500E+01, -.46362800E+00, 0.43485700E+01, -.51590900E-01, 0.21261000E+01, -.24541800E+01, -.45865300E+01, 0.13571100E+01, -.21843300E+01, 0.27908900E+01 },
        { -.24890300E+01, -.10058100E+01, -.64916300E-02, -.55556000E+00, -.20056000E+01, -.12178400E+01, -.42153700E+00, -.62123000E+00, -.96443700E+00, 0.14704800E+01, 0.81841800E-01, -.18640100E+00, -.17147700E-02, 0.11856600E+01, -.84650100E+00, 0.11692500E+00, 0.23012200E+00, 0.25303700E-01, 0.81907000E+00, -.11777800E+01, 0.32268300E+00, 0.16203200E-01, -.31986600E-01, -.39142900E+00, 0.32197800E+01, 0.59522000E-01, 0.19201800E+00, 0.30553300E+00, -.85118900E+00, 0.67152700E-01, 0.25314400E+00, 0.42879800E+00, 0.83704500E+00, 0.18956900E+00, 0.45115800E+00, -.22775700E+00, -.11771500E-01, 0.44175900E+00, -.21686300E+00, 0.53574600E+01, 0.76475300E-03, 0.16005800E+00, 0.10398100E+00, -.15813400E+00, 0.34573600E+00, 0.79498600E-01, 0.29129900E+00, 0.14230900E-01, -.77821400E-01, -.93562000E-01, -.19910900E+00, -.11182400E+00, -.18714200E+00, 0.20950400E-01, -.26181400E+00, -.32139800E+00, -.32944400E+00, -.15498200E+00, 0.15053600E-01, -.66617600E-01, 0.43020100E+00, -.58363700E+00, -.12997300E+00, -.30915700E+00, 0.28983700E+00, 0.25165900E-01, 0.41388700E+00, -.14306700E+00, 0.35391100E-01, -.15294400E-01, 0.19801500E+00, 0.26332600E-02, -.65176700E-01, 0.55240300E-01, -.27369100E+00, -.15460600E+00, 0.21774500E-02, -.13913100E+00, -.77308000E-01, 0.12945800E+00, 0.48801300E-01, 0.65621400E-01, -.38438100E+00, 0.55449600E-01, 0.65654600E-01, -.23859500E-01, -.84424700E-01, 0.51630900E+00, 0.61041500E+00, -.89966500E-01, -.45631300E+00, 0.10938000E-01, -.68006000E-01, -.28579400E+00, 0.61738300E+00, 0.38251000E+00, 0.50775400E-01, -.33878600E-01, 0.70678600E+00, 0.15672800E+00, 0.61278700E-01, 0.12708600E+00, -.13776300E+00, 0.42573300E+00, -.36165500E+00, 0.49652700E+00, 0.15678300E+00, -.70664000E-01, -.63778300E+00, -.47856500E-01, 0.34969000E+00, -.59615800E-01, 0.93252500E-01, 0.48433900E-01, 0.51253100E-02, -.68970900E+00, -.28482300E+00, 0.43833300E+00, 0.92225800E-02, 0.98554900E-01, -.10543000E+00, 0.20622700E+00, 0.24901000E-01, 0.15640600E+00, -.12581200E-02, -.23518800E+00, 0.16465500E+00, 0.82977200E-01, 0.42551900E+00, 0.17825800E-01, 0.59355800E+00, -.74060100E+00, 0.79002100E+00, 0.17990400E-02, -.29396100E-01, -.68505200E-03, -.19672800E+00, -.12494500E+00, 0.15345900E+00, -.89936900E+00, -.79893900E+00, -.23859200E+00, 0.57440900E+00, 0.28781700E+00, -.72062200E-01, -.13772600E+00, 0.17538000E-01, 0.24069200E+00, 0.33215400E+00, -.16371500E+00, 0.22760000E+00, 0.37101500E+00, 0.12397900E+01, -.17460500E+00, 0.33866500E-01, -.33074900E-01, 0.33092300E+00, -.15544800E-01, -.14038500E+00, 0.82362300E+00, -.10962800E+00, 0.17344200E+00, -.34681000E+00, -.44142100E-01, 0.17850200E+00, 0.55488200E-02, 0.40365100E+00, -.54286000E+00, -.89816100E-02, 0.10560900E+00, 0.17096700E+00, -.70558500E+00, 0.23931200E+00, 0.24851800E+00, -.44900900E+00, 0.80457500E+00, -.83315000E-01, 0.23207200E+00, 0.14337800E+00, -.84907300E+00, 0.25036100E+01, 0.46422800E+00, -.11891400E+01, -.32718200E+00, 0.84581600E+00, -.11794400E+00, 0.65411400E-01, -.10365600E+00, -.87998700E-01, 0.16222700E+00, 0.13720300E-01, -.90964100E-01, -.15582800E-01, 0.15481900E+00, -.18655400E-01, -.91136800E-01, 0.44721400E+00, 0.20816000E+00, -.32564400E-01, 0.12205600E+00, -.65663900E+00, -.44272800E-01, 0.18487400E+00, -.43770000E-01, 0.44018700E+00, 0.45126100E+01, 0.14833300E+01, -.96122700E+00, 0.22195300E+00, 0.65447500E-01, 0.13495700E+00, 0.34774200E-01, -.41068600E-01, -.43529700E-01, 0.52584000E-02, -.76306100E-01, -.14289600E-01, -.66502800E-01, -.25877800E+00, -.10891100E+00, 0.29276500E+01, -.27652600E-01, -.56185200E-01, 0.20471800E-01, 0.14913800E+00, -.14339900E+00, -.69158800E-01, 0.86728500E-01, -.13161000E+00, -.76918400E+00, 0.11117100E+01, 0.26998400E+00, -.24381100E+02, 0.48871200E+02, 0.90178700E-01, 0.17634200E+01, 0.12409500E+02, 0.18422900E+02, 0.78708900E+01, -.25162800E+02, 0.10272100E+02, -.13599500E+02, 0.27509100E+02, -.13783700E+02, -.16789600E+02, -.13806600E+02, -.15709900E+02, 0.13589800E+02, -.15414300E+02, -.22096500E+01, -.19836900E+02, 0.40462000E+01, -.46682800E+01, -.41248200E+02, 0.18260600E+02, 0.27717200E+02, 0.21544200E+02, 0.28699900E+02, 0.17509500E+02, -.16477000E+02, -.90059200E+01, 0.40459000E+02, 0.19563400E+02, 0.13476800E+02, -.31845200E+02, 0.16636900E+02, -.15272800E+02, 0.15860100E+02, 0.44448900E+02, -.39735000E+01, 0.34568300E+02, -.19930600E+01, -.27026000E+02, -.56029700E+00, 0.13906100E+02, -.49174800E+01, -.29060400E+01, -.92044000E+00, 0.65446500E+00, -.30956600E+01, -.46897300E+00, -.33860600E+01, -.15392800E+01, 0.22467900E+00, 0.10047000E+01, -.26927500E+01, 0.59549400E+00, -.47105700E+01, -.33895800E+00, 0.19808000E-01, -.11602800E+01, 0.14884000E+01, 0.80983500E+00, -.12758100E-01, -.29474100E+01, -.12556500E+01, 0.76540500E+01, -.13013400E+00, -.45046400E+01, 0.32763600E+01, 0.25497500E+01 },
        { -.27113500E+01, 0.10726000E+01, 0.53992700E-01, -.78949400E+00, -.12093900E+01, 0.32847900E+01, -.52313400E+01, 0.10346000E-01, -.10703200E+01, 0.22858700E+01, -.16579000E+00, -.12537100E+00, -.14846000E+01, 0.10276600E+01, -.19614100E+01, -.20802600E+01, -.72257000E+00, 0.93346600E+00, 0.38002200E-01, 0.13257100E+01, 0.15206300E+00, 0.11851100E+00, 0.17632500E-01, 0.33257500E+00, -.51980200E+01, 0.71642300E-01, -.51871600E+00, 0.52405500E-01, -.35564400E+00, -.33204400E-01, -.46988100E+00, 0.40555600E+00, 0.45965900E-01, 0.81252000E+00, -.24128000E+00, 0.81469800E+00, 0.69318500E-01, 0.59610200E+00, -.12382200E+01, -.92835500E-01, 0.18278500E+00, 0.34211700E+00, -.10325100E+01, -.15025400E+00, 0.62616500E+00, -.21281900E+00, -.39473000E+00, 0.13056900E-01, 0.20180400E+00, 0.46213000E+00, 0.33058400E+01, -.27248900E+00, -.64517900E+00, -.51125600E+00, -.28711800E+00, -.14547300E+00, 0.11887400E+00, -.12524100E+00, 0.58063400E-01, 0.84656100E+00, -.47516800E+00, -.56651000E+00, 0.16526200E+00, -.22041800E+00, 0.88695400E+00, -.51635100E-01, 0.48451800E+00, -.34116600E+00, 0.95975400E-01, 0.16611800E-01, -.72857000E+00, -.28389400E+00, 0.89220600E+00, -.32581300E+00, -.12968200E+00, 0.50705900E+00, 0.84380300E-01, -.80953400E-01, 0.37896000E-01, 0.47581300E+00, 0.27562100E-01, -.14574800E+00, -.25627400E+00, 0.26678000E+00, -.18950700E+00, -.36164000E-01, 0.12982300E+01, -.11813500E+01, -.27591400E+00, 0.77544600E+00, -.86829400E+00, -.11279400E-01, -.24365300E+00, -.10074500E+00, -.35014400E+00, -.70443500E+00, 0.25888000E-01, -.65975700E-02, -.81889800E+00, -.17980300E+00, -.24567100E+00, -.18978200E+00, 0.10090000E+00, -.13449300E+00, 0.47060600E+00, -.11284200E+00, 0.85833800E+00, 0.14504400E+01, -.68253000E+00, 0.30169400E+00, -.10367000E+01, 0.20067900E+00, 0.13328700E-02, 0.14397300E+00, 0.41838800E+00, -.85835700E+00, -.15757600E+00, 0.70058500E+00, -.17499100E+00, 0.61091600E-02, 0.19887900E+00, -.15124000E+00, -.46743500E-01, -.68742100E-01, 0.25018600E-01, -.15230800E-01, -.58104500E-01, 0.11821000E-01, 0.23739900E+00, -.20316200E+00, 0.64696400E-01, 0.20977800E+00, 0.40854900E+00, 0.55962100E-02, -.12107500E+00, -.63014400E-02, 0.29020600E+00, -.20721700E+00, -.32193700E-01, -.76176900E-01, -.32408100E+00, -.57936200E+00, -.44301500E-01, 0.88784100E-01, 0.13637100E+00, -.57938500E+00, 0.42545300E-02, -.60802500E-02, -.20188900E+00, 0.45350800E+00, -.53659400E-01, -.64617100E-01, 0.25771400E+00, -.36402800E+00, 0.52059600E-01, 0.56380000E-01, -.70414900E+00, -.97336600E-02, -.49370500E+00, 0.41137000E+00, -.14807400E+00, -.24858900E+00, -.30278600E-01, -.60399800E-01, 0.37483400E+00, -.13244000E+00, -.28530300E+00, 0.22061500E+00, 0.81152900E-01, 0.13671600E+00, -.94035200E-01, 0.78396200E+00, 0.75518300E-01, -.58730300E-01, 0.17355300E+00, -.39793700E+00, -.22457800E+00, -.36442700E+00, -.17141900E+00, 0.50821700E-01, 0.16085300E+01, 0.30276200E+00, -.70107700E+00, 0.62548600E-02, 0.57267000E+00, -.48553000E-01, 0.71910800E-01, -.17024700E+01, -.57315000E-01, -.34457800E+00, -.36536600E-01, -.60530700E+00, -.27115700E+00, 0.39777800E+00, -.43255900E+00, -.56378800E+00, 0.41332900E+00, -.35321800E-01, -.18018300E+00, -.21584300E+00, -.18915700E-01, 0.10785700E+00, -.41508300E+00, 0.14190500E+00, 0.25387600E+00, 0.44327700E+01, -.69341800E+00, 0.19256800E+01, -.24556200E-01, 0.14816600E+00, 0.50195100E-02, -.18826300E+00, 0.86630000E-01, -.25610300E+00, -.22025200E+00, -.18988600E+00, -.47796000E-01, 0.17966200E-02, 0.26423800E+00, 0.17845500E+00, -.52095600E+00, -.39203600E-01, -.19550500E+00, 0.54581600E-01, 0.13165200E-01, 0.42341700E-01, -.75137000E-02, -.23070900E-01, -.39084900E-01, 0.73137900E+00, 0.34912800E+00, 0.49224900E+00, -.66325200E-02, 0.96512900E+02, -.10414900E+01, -.73788000E+01, -.18832300E+02, 0.36106600E+02, -.12472800E+02, -.71524400E+02, -.10908300E+02, -.15508200E+02, -.25169200E+02, 0.12387800E+02, 0.17024300E+02, 0.12865600E+02, -.68238300E+01, 0.11795200E+02, -.29210100E+01, -.39601400E+00, 0.17721200E+01, 0.70078600E+01, 0.11032400E+02, -.42764800E+01, 0.21303000E+01, 0.47980100E+01, 0.29885800E+01, 0.10588000E+02, -.14719100E+01, 0.49236900E+01, 0.48398800E+01, -.29088100E+01, 0.15225200E+01, -.17616400E+01, 0.71902000E+02, -.35747100E+02, 0.78375200E+00, -.36289000E+02, 0.23325800E+02, 0.32633300E+01, -.24702000E+02, 0.32461800E+01, -.52616800E+02, 0.65691600E+01, -.32501300E+02, -.16712200E+01, -.15191000E+01, -.73911400E+00, -.28271500E+00, -.91964900E+00, -.17382600E+01, -.36917100E+00, -.62603200E+00, 0.59387500E+00, 0.52345200E+00, -.25868500E+00, 0.59403700E+00, -.13756800E+01, -.20381300E+00, -.16194400E+01, -.25127200E+01, 0.26475200E+01, -.37454900E-01, -.13089200E+01, 0.71118400E-01, -.69677600E+00, 0.40963500E+01, 0.31139100E+00, -.28382900E+01, 0.38861200E+01, 0.24294900E-01 },
        { -.10122100E+02, 0.25403400E+01, 0.50531000E+00, -.36758100E+01, -.62821000E+01, 0.83680200E+01, -.12641100E+02, 0.13319000E+02, -.63725700E+01, 0.83306100E+01, 0.75245300E-01, -.61668800E+00, -.22922700E+01, 0.12192300E+02, -.14958500E+02, 0.22699900E+00, 0.35213000E-01, -.59667500E+01, 0.49861000E+01, -.44076200E+01, 0.18410300E+01, 0.35188000E+00, 0.24410100E+00, -.30073000E-01, -.19575200E+01, 0.21605300E+00, -.33199100E+01, -.76719800E+01, 0.66273100E+01, -.40576300E+01, 0.26721500E+01, 0.26964300E+01, 0.89896700E+00, 0.22644300E+01, 0.90254300E+00, 0.21339400E+01, -.25802100E+00, 0.99110200E+00, -.33429900E+01, 0.41541200E+01, -.12331900E+00, -.80137100E+00, -.33945800E+01, -.75720900E+00, 0.54330400E+00, -.52049100E+00, -.11821200E+01, 0.12202900E+00, 0.55381900E+00, 0.13953000E+01, 0.10156400E+01, 0.13091600E+01, -.14689200E+01, 0.23240900E+01, 0.86471400E+00, 0.24843000E+00, -.26162300E+00, 0.52442500E-01, 0.51076600E+00, -.20677000E+01, -.88894400E+00, 0.24305000E+01, 0.15514300E+01, 0.23691000E+01, -.19942100E+01, 0.29028400E+00, 0.82994800E+00, 0.15741000E+01, -.31785100E+00, 0.35242700E+00, -.10385500E+01, 0.13374700E+01, -.66215800E+01, 0.98858400E+00, -.42560800E-01, -.18589300E+01, 0.10757100E+00, 0.19135100E+01, -.27937600E-01, 0.63904500E+00, 0.21891300E+00, -.11463200E+00, -.10249100E+01, -.48804100E-01, 0.20277800E+01, -.29343700E+00, -.14008000E+00, -.22574300E+01, -.56164800E+01, 0.24468900E+01, 0.55200700E+00, 0.27937200E+00, 0.45033500E+00, -.14603800E+01, -.10742900E+01, 0.71785400E+00, -.58101100E+00, -.52571500E+00, -.57721700E+00, -.35010100E+00, -.36681700E+00, 0.68618200E+00, -.73627300E+00, -.20386100E+01, -.12058600E+00, -.15205400E+01, 0.39740300E+00, -.16581400E+01, 0.98787300E+00, 0.21559100E+00, 0.14946800E+01, 0.34034900E+00, 0.32115300E+00, 0.12752300E+01, -.57408000E-01, 0.10958900E+01, -.49275600E+01, 0.91880700E+00, -.10892300E+00, 0.46127100E+00, -.11490700E+01, 0.99498400E-01, 0.23895200E+00, 0.81653200E+00, 0.26025700E+00, 0.35565100E+00, -.36932000E+00, -.10941900E+01, 0.17723600E+01, 0.90388900E-01, 0.66725600E-01, 0.20502900E+01, 0.52466400E+00, 0.21302300E-01, 0.29254400E+00, -.30152700E-01, -.20423500E+01, 0.14487100E+00, -.10248100E+01, 0.12701200E+01, 0.31316100E+00, -.17238100E+01, 0.11708100E+01, 0.30412300E+00, -.56687700E-01, -.62037500E+00, 0.68377400E+00, -.20349600E-01, 0.62937100E+00, 0.10756600E+00, 0.17161700E+00, -.45597900E+00, -.31207500E+00, 0.10697000E+00, -.14812900E+00, 0.13025100E+00, 0.15294700E+01, 0.61208000E-01, 0.54182700E-01, -.71594500E+00, 0.33302000E+00, 0.56062700E+00, -.19334100E+00, 0.12247400E+00, -.57572300E+00, -.89316800E-01, 0.93128500E+00, -.16557900E+01, -.24582500E+00, -.16907400E-01, 0.26890800E+00, -.84234800E+00, 0.81203000E-02, -.47170100E-01, -.29545600E+00, -.49927800E+00, 0.30519600E+00, 0.81120100E+00, 0.39885600E+00, -.17793400E+01, -.34688400E+01, 0.22417000E+00, -.79595400E+00, 0.25069000E+00, -.66905600E+00, 0.35856500E+00, -.16646200E-01, 0.26488000E+01, 0.19240200E+00, 0.28947500E+00, -.32559600E+00, -.66284100E-01, -.17517200E+00, -.31020100E+00, -.10744700E+01, -.14890700E+00, -.14485100E+01, 0.78930900E-01, 0.77946200E+00, -.24097800E+00, -.84077900E+00, -.16618200E+00, -.21924400E+00, 0.37958600E+00, 0.39255000E+00, -.63852400E+01, -.15008300E+01, 0.53278300E+00, -.28229200E+00, -.80996100E+00, 0.71757900E-01, 0.27296600E+00, -.98255100E-01, 0.45954800E+00, -.25421100E+00, 0.25648700E+01, 0.49663400E-01, 0.21012500E-01, -.48551800E+00, -.88366600E-02, 0.28314100E+01, 0.15140400E+00, 0.26629400E-01, 0.89598900E-02, -.12856200E+00, -.29461400E+00, 0.28865000E+00, -.40452600E+00, -.20506800E+00, -.12025300E+01, 0.17482400E+00, -.34944800E+00, 0.36930600E+00, -.68329300E+00, 0.26476100E+02, -.19437800E+02, -.17565900E+02, -.33263400E+02, -.42020700E+02, -.47869900E+02, -.95474100E+01, 0.41748700E+01, 0.29029500E+02, -.15487300E+02, -.11291400E+02, -.15264900E+02, 0.80249200E+01, -.72286900E+01, -.27626000E+02, -.35874700E+02, -.14718300E+02, -.21740300E+01, 0.37717000E+01, 0.22623200E+02, -.10309400E+02, -.38685100E+02, -.97538100E+01, -.10224700E+02, -.64477400E+01, 0.34567200E+01, -.66889600E+00, -.22301700E+02, -.10980600E+02, -.81644500E+01, 0.31224300E+02, -.13052800E+02, -.59182000E+01, -.14064700E+02, -.28490300E+02, 0.44968200E+01, -.20412900E+02, 0.23035100E+01, -.78453600E+01, 0.13585500E+01, -.21018600E+02, 0.25793700E+01, 0.21295100E+01, -.86194000E+00, -.11074800E+01, -.15193000E+01, 0.15370800E+01, 0.53750900E+00, 0.15733600E+01, 0.49829400E+00, -.70847700E+00, -.74340900E+00, -.54315300E+01, 0.91185100E+00, -.38760000E-01, -.88641700E+01, 0.19213000E+00, -.21175700E+01, -.93157000E+00, -.68875200E+01, 0.40561000E+00, 0.25326800E+01, -.26476900E+01, 0.50040600E+01, 0.17708200E+01, -.37534000E+01, 0.18597500E+01 },
        { 0.19193800E+02, -.52614100E+01, -.11007100E+01, 0.25647300E+01, 0.92646400E+01, -.72125800E+01, 0.21536500E+02, -.15703800E+02, 0.11700700E+02, -.14829700E+02, -.10231000E+00, 0.12983600E+01, 0.48036800E+01, -.16767200E+02, 0.25046400E+01, -.39407400E+01, 0.75786200E+00, 0.28341900E+00, 0.98992900E+00, -.23300300E+01, 0.12084600E+01, -.42330200E+00, 0.26742300E+00, -.17651300E+01, 0.11181300E+02, 0.26584900E+00, 0.30874300E+01, 0.25244900E+01, -.30744000E+01, 0.67659900E-01, 0.43050100E+00, -.73314000E+00, 0.10236300E+01, -.70551000E+00, -.89848000E+00, -.83104900E+00, -.12630900E+00, 0.29027000E+00, 0.10614600E+01, 0.18415100E+01, 0.74697000E-01, 0.82084900E+00, 0.20381500E+01, -.28525200E+00, -.13062800E-01, -.52459800E+00, 0.86251600E+00, 0.23908000E+00, -.61220400E+00, -.62485600E+00, 0.18260000E+01, -.21687200E+00, -.70932300E+00, 0.31912000E-01, -.28212100E+01, 0.91900000E+00, -.18544100E+01, 0.80556400E-01, 0.31315500E+00, 0.14730500E+01, 0.26668100E+00, -.76793800E+01, -.43735400E+01, 0.20099100E+01, -.25956900E+01, 0.53192200E+00, 0.79449700E+00, 0.49447000E-01, -.13210800E-01, -.80218400E-01, 0.19790400E+01, -.27304300E+00, 0.52150600E+01, -.38834900E+00, -.17836900E+01, 0.10266100E+01, 0.88505800E-03, 0.16956100E+00, -.82110100E-01, 0.25367800E+00, -.29969900E+00, 0.10756100E+01, -.29674600E+01, 0.34922100E+00, 0.92937700E+00, 0.29138200E+00, 0.72601200E+00, 0.60164400E+01, 0.67978100E+01, -.40955300E+01, -.26881400E-01, 0.38851700E-01, -.92707700E-01, -.10229100E+01, 0.14781300E+01, 0.15393200E+01, -.48909700E+00, 0.37592100E+01, 0.13676300E+00, -.89214900E+00, -.12777400E+01, 0.16848600E+01, 0.18034600E+01, 0.11746900E+01, -.15457300E+01, 0.15121400E+01, 0.21830800E+01, 0.26459800E+01, -.53069500E+01, -.11132300E+00, 0.25691300E+01, -.11200900E+01, 0.22002200E+00, 0.11490600E+01, -.11388100E+01, -.68823100E+01, 0.62511600E+01, 0.16015200E+01, 0.30026200E+00, -.12699600E+01, 0.13506900E+01, 0.24273000E+00, -.14421600E+00, -.52767100E+00, -.22127400E-01, -.21207000E+00, 0.32908500E+00, 0.10142400E+01, -.80318700E+00, -.30014900E+00, 0.25221100E+01, 0.13602200E+01, -.60149600E+00, 0.10588300E-01, 0.20673000E+00, 0.10553800E-01, 0.34958200E+01, 0.89913700E+00, 0.20750800E-02, -.26295800E+01, -.30021000E+00, -.14027800E+00, 0.40417400E+01, 0.10702200E+01, 0.18472900E+00, -.11093400E+01, 0.32709900E+00, -.12423400E+00, 0.90968500E+00, -.11026300E+01, 0.20781400E+00, -.84794200E-02, -.13069600E+00, -.20170200E+01, -.72411800E-02, 0.92315600E+00, -.47143300E+00, -.60003500E-01, -.36024000E+01, 0.25010700E+01, 0.62634900E+00, 0.47221900E+01, 0.56256900E+01, 0.50451300E+00, -.39203700E+01, 0.11921100E+01, -.14748000E+01, -.22186100E+01, -.17430400E+00, 0.39165700E+00, -.51583700E+00, 0.77234500E+00, -.33135600E+00, 0.12053700E+00, -.50942100E+00, 0.42118200E+01, -.33217900E+00, -.12007900E+01, -.68072200E-01, 0.13769000E+01, -.95357900E+01, -.11668300E+01, 0.98984500E-01, -.62133500E+00, -.61780900E+00, -.21539000E+00, 0.67580100E-01, -.76160600E+00, 0.60563400E+00, -.13741200E+01, -.25943300E-01, 0.51696500E+00, -.69759200E+00, 0.17292900E+01, 0.29447700E+01, 0.13255900E+01, -.22844100E+01, -.48851900E+00, 0.40374600E+00, -.31868200E+00, -.27676300E+01, 0.21372800E+00, -.13378200E+01, -.15466100E+00, 0.14325500E+01, 0.12922500E+02, 0.18782500E+01, 0.60479300E+01, -.65297300E+00, -.12444000E+01, 0.52772700E+00, -.16269400E+00, 0.64114200E-01, 0.20619500E+00, -.64175600E+00, 0.14395700E+01, -.18127200E-01, -.33258300E-02, -.39883800E+00, 0.35127500E+00, -.82514000E+01, 0.22840900E+00, 0.17797700E+00, -.63630800E-01, 0.30888900E+00, 0.20415600E+00, -.75656700E+00, 0.28818200E+00, 0.24195000E+00, 0.43495400E+01, 0.47064900E+00, -.67084000E+01, -.11975300E+01, -.12244500E+01, -.14964900E-01, 0.97560000E+02, 0.21958500E+03, -.14465600E+03, -.11833200E+03, -.22105000E+03, 0.18845200E+03, 0.14905900E+03, 0.58316500E+02, -.29491300E+02, -.56203600E+02, -.27846900E+02, 0.79208100E+00, 0.82144900E+01, -.83112000E+02, -.80507900E+02, -.27285700E+02, 0.26711600E+02, 0.82356100E+02, 0.86334700E+02, -.35087500E+02, 0.12396100E+03, -.42197800E+02, 0.95089200E+01, 0.92038600E+01, -.75066200E+02, -.53969600E+02, -.13498400E+03, 0.10486800E+02, -.49984700E+02, -.14551100E+03, 0.93420100E+02, 0.21218100E+03, 0.72574900E+02, -.83461800E+02, -.19900800E+02, -.58753300E+02, -.10853000E+03, -.13626400E+03, 0.15843600E+02, 0.27567100E+03, 0.13723100E+02, 0.11081800E+02, -.73754600E+00, -.50341800E+01, -.71200900E+01, 0.78145800E+01, 0.21440100E+01, 0.31820500E+00, -.16550000E+01, -.58592300E+01, -.43931500E+00, 0.19657100E+02, 0.11865100E+02, 0.60080500E+01, 0.38084900E+02, 0.76712300E+00, 0.41801300E+01, -.55603400E+01, 0.40333400E+02, -.15523600E+01, 0.12655700E+02, 0.35075200E+00, -.30502600E+02, -.15437000E+01, -.60574000E+01, 0.28404600E+02 },
        { -.19856300E+01, -.14022200E+01, -.28763600E-01, -.77364500E+00, -.17533600E+01, -.22256300E+01, 0.22580700E+00, -.73869800E+00, -.55312000E+00, 0.16940200E+01, 0.37717900E-01, -.17526500E-01, 0.10063200E+00, 0.90255500E+00, -.63845700E+00, -.69630100E+00, 0.12260300E+00, -.52786600E-01, 0.68521000E+00, -.40616100E+00, 0.17653600E+00, -.22939100E-01, -.48013100E-01, -.25987100E+00, 0.19971100E+01, 0.55623100E-01, 0.15885100E+00, 0.13867400E+00, -.23896900E+00, -.13304900E+00, 0.44954100E+00, 0.40993400E+00, 0.73049900E+00, 0.47381800E+00, 0.32231800E+00, 0.49080000E-01, -.84263500E-01, 0.61296500E+00, -.65604300E+00, 0.21399300E+01, 0.18146500E+00, 0.11807900E+00, -.17557500E+00, -.17243700E+00, -.38944700E-01, -.10053700E+00, -.39341300E-02, -.11287700E-01, -.12112000E-01, 0.11013900E+00, 0.83661400E+00, 0.89327700E-01, -.21643400E+00, -.17383000E+00, -.18370900E+00, 0.47139200E-01, -.19559100E+00, 0.73942800E-01, -.28062700E-01, 0.58096200E-01, 0.37096700E+00, -.19256900E+00, -.23635700E+00, 0.13178800E+00, 0.19302200E+00, 0.56823400E-02, 0.92926600E-01, -.10236600E+00, 0.94691300E-01, -.20232200E-01, 0.42944600E+00, -.17112500E+00, -.16986700E+00, 0.76064300E-02, 0.28504900E-01, -.69969700E-01, 0.72084600E-01, 0.41429000E-01, 0.12261300E+00, -.18665600E+00, 0.10622800E-01, -.19030100E+00, 0.11152900E+01, 0.43777400E-01, -.60581800E+00, 0.75121900E-01, -.72737000E+00, -.55593100E-01, -.19186100E+01, 0.56559000E+00, -.39048400E+00, 0.83835700E-02, -.12638800E-01, -.96403100E-03, -.59593900E-01, 0.51303000E+00, -.21732100E+00, -.19304600E+00, -.20687400E+00, 0.93764200E-01, 0.37559000E-01, -.24943300E+00, -.87342700E-01, 0.48917100E+00, -.48787100E-01, -.24558000E+00, -.45419500E+00, -.74062200E+00, -.11059600E+00, -.98362100E-02, 0.73525500E-01, -.35531000E-01, 0.32098400E-02, -.14768700E+00, -.31459800E+00, 0.40844900E+00, -.10196100E+01, -.15755100E+00, 0.20878100E+00, -.16944400E+00, -.55172700E+00, -.43514700E+00, 0.13489700E+00, 0.17345300E+00, 0.14981700E-01, 0.42888100E-01, -.15502500E+00, 0.39524800E+00, 0.26005800E+00, 0.14174200E+00, -.50163400E+00, 0.55326600E+00, -.41404600E+00, 0.65723900E-03, 0.46794400E-01, 0.47212200E-02, 0.20423300E+00, 0.95433700E-01, -.12527800E+00, 0.16792900E+00, -.46531900E-01, 0.53109600E+00, 0.63891300E+00, 0.51040000E-01, 0.91732700E-01, -.76120300E-01, -.63828700E-03, -.93455700E-01, 0.22032600E-02, 0.38820100E+00, 0.17456700E-01, -.15141400E+00, 0.12174200E+00, -.14161700E+00, -.44241400E-01, 0.84048500E-01, 0.97297300E-01, -.57074300E-02, -.47434800E+00, 0.42167200E+00, 0.29121400E-01, 0.14260700E+00, 0.33672500E+00, -.10832600E+00, -.79068700E-01, 0.43847100E-01, 0.17625900E+00, -.10715900E+00, -.11638000E-01, -.50131800E-01, -.11800400E+00, -.23290200E+00, -.79924800E-01, -.37358500E-01, -.16150700E+00, -.10848700E+01, 0.46189000E-01, 0.79439200E-01, -.30254500E+00, -.50519800E+00, -.21536800E+01, 0.51784700E+00, 0.17127000E+00, 0.31847200E+00, 0.25078500E+00, 0.14724600E+00, -.29404700E-01, 0.14711100E+00, -.46051800E-01, 0.47891600E-01, -.19741100E-01, -.10381300E+00, -.12646600E+00, -.74279400E+00, 0.15277000E+00, -.11168300E-01, -.47527000E+00, 0.84944100E-01, -.44762700E-01, -.27905700E-01, -.20780200E+00, 0.35521100E-01, -.23518700E+00, 0.23219200E+00, 0.74258700E+00, -.26618600E+01, -.54203700E+00, -.28297200E+00, 0.15796500E+00, -.40643500E+00, -.53474700E-01, -.73003300E-01, 0.14131500E-01, -.22745000E-01, -.46448800E-01, -.15475800E+00, 0.12858500E+00, -.46374400E-01, 0.98806200E-01, 0.53857800E-01, 0.66877900E+00, 0.64502000E-01, -.94638700E-02, 0.17509500E-02, -.16909800E+00, 0.39408000E-01, 0.16346200E+00, -.82774100E-01, -.75677800E-01, -.16838500E+01, 0.24041200E+00, 0.15359600E-01, -.30302900E+00, 0.13319200E+00, 0.24948000E-01, -.92434500E-02, 0.17520100E+02, -.22360800E+02, -.10900900E+02, -.64217600E+01, 0.13079100E+02, 0.11525200E+02, -.13503500E+02, 0.58375700E+01, 0.82843100E+01, 0.66380200E+01, -.64213300E+00, -.22289700E+01, 0.20111500E+02, 0.98842000E+01, 0.29629000E+01, -.27061900E+01, 0.41631500E+01, -.30952300E+02, 0.14248000E+02, 0.10662300E+02, 0.16110000E+02, 0.51173000E+01, 0.94897100E+01, -.13535200E+02, -.11449500E+02, 0.31027700E+02, 0.71614000E+01, 0.15653500E+02, -.82911300E+02, 0.43157700E+02, -.33668800E+01, 0.41640700E+02, 0.15694900E+02, 0.13183800E+02, 0.11648700E+02, -.25395700E+02, 0.74149300E+01, 0.88873400E+01, 0.46919000E+02, -.20168000E+01, 0.75042500E-01, 0.28269600E+00, 0.10211400E+01, -.48328100E-01, 0.60466000E+00, -.18983900E+01, -.35349300E+00, -.22039800E+00, -.67224400E-01, 0.13251300E+00, 0.89841700E-01, -.25342500E+01, -.47261000E+00, -.65868700E+00, 0.11365300E+01, -.16217700E+01, 0.24203500E+00, -.10877300E+00, -.19958100E+01, -.19145300E+00, -.23368000E+01, -.60509700E+00, 0.16092300E+01, -.11191500E+01, 0.38494600E+01 },
        { -.26825800E+01, -.16942500E+01, -.96929800E-01, -.17544700E+01, -.23751100E+01, -.10407700E+01, -.83487300E+00, 0.13166500E+01, -.11520500E+01, 0.22659900E+01, 0.66952500E-01, -.70759900E-01, 0.17698800E+01, -.18479400E+01, 0.10540100E+01, 0.28478900E+01, -.10575000E+01, -.20048100E+00, -.17575400E+01, -.23629100E+00, 0.29737300E-01, 0.19465900E+00, 0.55220400E-01, 0.13742800E+00, -.18749300E+01, -.11341500E+00, -.88980500E+00, -.47526400E+00, 0.14030800E+01, 0.15708500E+00, 0.27878300E+00, 0.39430500E+00, 0.82472400E+00, 0.92138600E+00, -.70611100E-01, 0.28009000E+00, -.74186800E-01, 0.15965000E+00, 0.13328600E+01, -.13827000E+01, -.10903200E+00, 0.21235700E-01, -.16164700E+01, -.17247800E+00, 0.18970500E+00, -.19850700E+00, -.60132500E+00, 0.59655100E-02, 0.20296600E-01, -.12794600E+00, -.72330400E+00, 0.11862900E-01, 0.32602600E+00, 0.19186000E+01, 0.16298800E+00, 0.11384000E+00, 0.59830800E-02, 0.74433700E-01, -.83889000E-01, -.39378700E+00, -.46986000E-01, 0.97630600E-01, -.19792000E+00, 0.60155700E+00, -.53599100E+00, 0.10144500E-01, -.39264400E+00, 0.33333800E+00, -.17591500E+00, 0.11447400E-01, 0.15974500E+00, 0.42573400E+00, -.13094400E+01, 0.73453800E-01, -.30316300E+00, -.48932600E+00, -.81519600E-01, -.57905600E-01, -.18104200E+00, 0.30508700E+00, 0.11377700E+00, -.53608100E-02, -.72894900E+00, -.17928100E+00, 0.87114500E+00, 0.63786200E-01, -.29222600E+00, -.16746800E+00, -.41584300E+00, -.17757800E+00, -.47514600E+00, 0.25584100E-01, 0.10514800E+00, 0.89767700E-01, 0.13157300E-01, 0.91117600E-01, 0.42812700E-01, 0.26807300E-01, 0.38703700E+00, -.21043400E-01, 0.11709300E+00, 0.61183500E-01, -.23692300E+00, -.39492000E+00, 0.88362700E-01, -.24896100E+00, -.50729600E+00, -.31630600E+00, 0.92364800E+00, 0.22037700E-01, 0.36307000E+00, 0.40036000E+00, -.14972300E+00, 0.20184400E+00, 0.94038000E-01, 0.38330700E+00, -.25786000E+01, 0.54491700E+00, -.98051600E-01, 0.49989300E+00, -.15573000E+00, -.42369200E+00, 0.36509900E-01, -.14773000E+00, -.65349600E-02, -.50346100E-01, 0.85445600E-01, -.13788000E+00, 0.17366200E+00, 0.64021400E-01, 0.15320200E+00, 0.32073800E+00, -.21423400E-01, 0.61396800E-02, 0.99923500E-01, -.13021900E-04, -.91293800E+00, -.34385300E-01, -.16259100E+00, 0.34962400E+00, -.55534700E+00, 0.11117700E+01, 0.10387900E+01, -.56350700E-01, -.31098600E-02, 0.60093000E+00, 0.27646200E-02, -.71812500E-01, -.40710700E-01, 0.45381200E+00, 0.12395200E+00, -.20323900E+00, -.22491200E+00, 0.61952500E-01, -.41875200E-01, -.11846800E-01, 0.63039700E+00, 0.13108300E-02, 0.83229100E-01, -.12124900E+00, 0.85726300E-01, 0.13593500E+00, -.21813200E+00, 0.97199400E-01, -.19584200E+00, 0.73664000E-01, 0.19065200E+00, -.10210300E+01, 0.87603300E-04, -.13045800E-01, 0.24535400E-01, 0.99544400E-01, 0.28512000E-02, 0.41717800E-01, -.75234000E-01, -.33164000E+00, 0.78393800E-02, 0.75044700E-01, 0.12924200E+00, -.21840700E+00, 0.13268200E+01, -.10652900E+00, -.21266900E+00, 0.12332000E+00, -.12560400E+00, 0.65231400E-01, -.19997600E-01, -.85619900E-01, 0.17332600E+00, -.10471300E+00, -.94687700E-02, 0.44304800E+00, -.49759000E-01, 0.68932300E+00, -.21356100E+00, -.24179200E-01, -.61737000E+00, -.26087400E+00, 0.80759900E-01, -.18165800E+00, -.84142300E+00, 0.48528000E-01, -.10720000E+00, -.14686600E+00, -.61931600E-01, 0.20534200E+01, 0.43622500E+00, 0.72637500E+00, 0.94829500E-01, 0.81057700E-01, 0.24759100E-01, -.11281200E+00, 0.87887600E-02, -.17763500E+00, -.18941100E+00, -.45495000E+00, 0.47977400E-01, -.12950100E-01, 0.12792200E+00, -.18999100E-01, -.63190200E+00, -.40996900E-01, -.25476300E-02, 0.11565500E-01, 0.55249700E-01, 0.87785100E-01, -.90310300E-01, 0.85804600E-01, 0.34816900E-01, 0.22719200E+00, -.21032100E+00, 0.26886700E+00, -.49144000E-01, 0.67044500E-02, -.54595700E-01, 0.19097400E-01, 0.30520300E+00, 0.20321500E+02, 0.15936100E+02, 0.10316000E+02, -.38517900E+01, -.34465200E+01, -.15396500E+02, 0.81417300E+01, 0.60681400E+01, 0.79195200E+01, 0.29901000E+01, 0.36196000E+01, 0.40233400E+01, 0.67553700E+01, 0.55049700E+01, 0.27416000E+01, 0.15937300E+01, 0.47849900E+00, 0.47808300E+00, 0.10319800E+02, -.25435700E+00, -.42089800E+01, -.16361200E+01, -.37306300E+00, -.25079600E+01, -.73131900E+01, -.10271500E+00, 0.26275500E+00, 0.18459300E+02, -.10328000E+02, 0.10038200E+02, -.92343400E+01, -.35810400E+01, -.41087500E+01, -.55465200E+01, 0.65571200E+01, 0.16090000E+01, -.25799500E+01, 0.83116700E+00, 0.31464800E+00, 0.56668400E+00, 0.15424600E+00, 0.46850300E-01, 0.18959000E+00, -.30328700E+00, 0.76794500E+00, 0.45987500E-01, -.32944400E+00, 0.64428700E-01, 0.47055900E+00, 0.28352200E+01, 0.11199000E+01, 0.15000200E+00, 0.28445800E+01, -.72377400E+00, 0.10905500E+01, 0.31704900E+00, 0.21601800E+01, 0.86364400E+00, 0.62843800E+00, 0.72791600E+00, -.23803800E+01, -.54845100E+00, 0.50505300E+00, -.11217300E+01 },
        { 0.51773800E+01, 0.13639700E+00, -.17684200E+00, 0.17960700E+01, 0.29362100E+01, -.19024800E+01, 0.41206500E+01, -.74565000E+01, 0.28484700E+01, -.35546300E+01, -.10031500E+00, 0.13387700E+00, -.14259700E+01, -.34797800E+01, 0.93915600E+00, -.45211600E+01, 0.30316600E+01, 0.86086200E+00, -.33126600E+00, 0.60861800E+00, -.85423100E+00, -.19474600E-01, -.29587600E-01, -.80504700E-01, 0.24421300E+01, 0.12393600E+00, 0.16403600E+01, 0.41029600E+01, -.26889200E+01, 0.15148700E+01, -.13077300E+01, -.15794300E+01, 0.14030100E+00, -.77228600E+00, -.11986800E+01, -.82090600E+00, -.24382600E+00, -.97335800E+00, 0.39532900E+01, -.13979300E+02, -.15317600E+00, -.20130400E-01, 0.59472500E+00, 0.52189800E+00, -.56247100E-01, 0.22997400E+00, 0.15362400E+00, 0.12699000E+00, -.14601500E+00, -.61747100E+00, -.13313500E+01, -.67704000E+00, 0.11479000E+01, -.45117700E+00, -.25859000E+00, -.16282000E+00, 0.27660200E+00, -.22179400E+00, 0.27695100E+00, 0.66898400E+00, -.25230100E+00, -.10499400E+01, -.79874700E-01, -.80165000E+00, 0.10569500E+01, -.14505900E-01, 0.66182700E+00, -.40870600E+00, 0.20633800E+00, -.12222300E-02, -.31883500E+00, -.26640900E+00, 0.13588900E+01, -.33484900E+00, -.36042200E+00, 0.89392000E+00, 0.16873200E+00, -.11322900E+00, -.63297900E-01, 0.56664100E+00, -.14975500E+00, 0.16682800E+00, 0.38690200E-01, 0.35089100E+00, -.12381800E+01, -.27877200E+00, 0.19157200E+01, 0.12331500E+01, 0.22886200E+01, -.77113100E+00, 0.16027100E+01, -.12332600E-01, -.38161400E+00, 0.68924200E+00, 0.64401400E+00, -.85512500E+00, 0.19346800E+00, 0.91313200E+00, -.71690100E+00, -.18433100E+00, -.53868200E+00, -.29130000E-01, 0.83286400E+00, 0.24372700E+00, 0.24067200E+00, -.20226000E-01, 0.65072800E+00, 0.11215400E+01, -.76836900E-01, 0.27360600E+00, -.10445600E+01, -.44735900E+00, -.78251700E-01, -.18889100E+00, -.92441700E+00, -.22736900E+00, 0.26937400E+01, -.15723200E+01, 0.22287600E+00, -.41083100E+00, 0.64100100E+00, -.32698300E+00, -.19934500E+00, -.39452500E+00, 0.10075500E-01, 0.91208600E-01, 0.28541400E-01, 0.10769000E+01, -.11034000E+01, 0.11594000E+00, 0.45988400E+00, -.12238300E+01, -.14876500E+01, -.12729200E-01, 0.24472500E+00, 0.19200800E-01, 0.25075000E+01, 0.26520200E+00, 0.28356900E+00, -.10517600E+01, -.26655200E+00, 0.52565100E+00, 0.37439400E+01, -.28955500E-01, 0.68646600E-02, 0.72557900E+00, 0.14516200E+00, -.21846600E+00, -.26977800E+00, 0.62996000E+00, 0.98047500E+00, -.11958700E+00, 0.61335600E-01, 0.51194900E+00, -.36560900E-01, -.59192500E-01, 0.20029200E+00, 0.37500100E-01, 0.33076200E+00, -.12303200E+00, -.14778500E+00, -.50733400E+00, -.20521800E+00, -.13581700E+00, -.39093100E-01, 0.97161900E-01, -.16375800E+00, 0.94801000E+00, 0.43421900E-01, -.14022900E+00, -.12550700E+00, 0.10240900E+00, 0.70251500E-01, -.73741300E-01, 0.29267900E+00, -.99182700E+00, 0.13303800E+00, -.63099400E-01, -.10109500E+00, 0.26702000E+00, -.99673300E+00, 0.20096600E-02, 0.50135500E+00, -.98563600E-01, 0.27093700E+00, -.17681300E+00, -.10609700E-02, -.53572400E+00, -.28377300E+00, -.85644100E-01, 0.10962300E-01, -.56205000E+00, -.11483700E+00, -.29516900E+00, -.30914000E+00, -.21687300E+00, 0.60322700E+00, 0.13462300E+00, 0.16411200E+00, 0.88396800E-01, 0.24641300E+00, 0.40318300E-01, 0.11172000E+00, -.13406500E+00, -.49462100E+00, -.10837600E+01, -.54570400E+00, -.49149200E+00, 0.10251600E+00, 0.39169900E-01, 0.24423700E+00, -.63554200E-01, 0.27535300E-02, -.25051500E+00, 0.10280400E+00, -.48960600E+00, 0.22910900E+00, -.15354700E+00, 0.10976000E+00, 0.81477200E-01, 0.35716700E+00, -.12372300E-02, 0.38352600E-01, -.11231100E-01, -.53014000E-01, 0.31661900E-01, 0.52633700E-01, -.15730600E-01, -.48913800E-01, -.13453300E+01, -.19921100E+00, 0.77184900E+00, -.10955100E+00, 0.59118100E+00, -.35624700E-01, 0.43333400E-01, -.50213700E+00, 0.88246700E+00, 0.83006000E+02, 0.75840300E+02, -.63178800E+01, -.18535500E+02, -.71100300E+02, 0.34529200E+02, 0.30720000E+02, 0.35203200E+02, 0.45642700E+01, -.58148200E+01, 0.62621900E+02, 0.25614900E+02, 0.33326900E+02, -.52256200E+01, 0.16864400E+02, -.51004700E+02, 0.22428900E+02, 0.32572000E+02, 0.26194200E+02, 0.45957800E+01, 0.16061200E+02, -.22336200E+01, -.50962400E+01, 0.65771700E+02, 0.15115700E+02, 0.17445000E+02, -.16032100E+03, 0.80317100E+02, -.53376100E+01, 0.80468700E+02, 0.28879500E+02, 0.26711900E+01, 0.51557700E+02, -.16590100E+02, 0.68591100E+02, -.19157100E+01, 0.25006500E+02, -.46957900E+01, -.11629300E+01, 0.18018000E+01, 0.13343800E+01, 0.91402700E+00, 0.57827700E-01, -.24650000E+01, -.97257300E+00, -.10258800E+01, 0.88757200E+00, -.57788200E+00, 0.40885700E+01, -.45654600E+01, -.13475600E+01, 0.53557500E+01, 0.33615900E+01, -.31486500E+01, 0.38835400E+00, 0.39998600E+01, -.23049100E+01, -.35605600E+01, -.44444700E+01, -.46333100E+01, 0.21455700E+01, -.28462600E+00, 0.58577400E+00 },
        { -.79558900E+01, 0.34922600E+01, 0.11365000E+01, -.26917500E+01, -.26728200E+01, 0.26222700E+01, -.67888300E+01, 0.49702500E+01, -.35000200E+01, 0.52207700E+01, 0.11201200E+00, -.18005200E+00, -.23990700E+01, -.42028500E+00, 0.50700200E+00, -.17841400E+01, -.40957600E+00, -.30563400E+00, 0.65159700E+00, 0.62964000E+00, -.16709000E+01, 0.34979000E+00, 0.97194200E-01, 0.82242000E+00, -.59073500E+01, -.82335400E-01, -.96337000E-01, -.11027400E+01, 0.10347000E+01, -.10454200E+00, -.91773200E+00, 0.49532800E-01, -.12788100E+01, -.40031400E-01, -.79330500E+00, 0.41896600E+00, -.42329900E+00, -.12893200E+01, 0.34013100E+01, -.86717400E+01, -.36578900E+00, -.31350100E+00, -.10294000E+01, -.58730100E+00, -.15858900E+00, -.26887000E+00, -.10647500E+01, -.39582000E-01, 0.20022300E+00, 0.74762900E+00, -.28784200E+01, -.30783000E+00, 0.80100900E+00, 0.73969400E+00, 0.14609300E+01, 0.15257500E+01, 0.45176200E+00, 0.30221200E+00, -.33380700E-01, -.10398200E+01, 0.12948300E+01, 0.55205800E+01, 0.27604000E+01, 0.33447800E-01, -.92396900E-03, -.46787200E-01, -.28841700E-01, 0.41176700E+00, 0.12311900E+00, 0.12229800E+00, -.41236500E+00, 0.43465900E-01, -.24112600E+01, -.21795600E+00, 0.24700400E+00, 0.24778600E+00, 0.29540000E+00, 0.24253100E+00, -.58656600E+00, 0.63727100E+00, 0.17743800E+00, 0.16062200E+00, -.16688200E+00, 0.33285000E+00, 0.74856200E+00, 0.57997800E-01, 0.46195800E+00, -.42923400E+00, 0.12042400E+01, -.21146600E+00, -.12717600E+01, 0.45548700E-01, 0.46407700E+00, 0.92446400E+00, 0.51899600E+00, -.50803300E+01, 0.12794700E+01, 0.15954400E+01, -.18993000E+00, -.49063300E+00, 0.37821600E+00, -.46566700E+00, -.13124200E+01, -.12754800E+01, 0.31439900E+00, -.95318600E+00, -.25086900E+00, -.30372700E+00, 0.47642900E+00, 0.89949100E-01, 0.13615900E+01, 0.43418800E+00, 0.65910100E-01, 0.59436700E+00, 0.15970500E+01, 0.26451800E+00, -.54329000E+01, 0.20998000E+01, 0.12905600E+00, -.61952600E+00, 0.99273500E+00, -.14604300E+01, -.92581700E-01, -.50955700E+00, -.50029400E-01, -.83487300E+00, 0.52586900E-02, 0.29091500E+00, -.71723300E+00, -.79240000E+00, 0.11774400E+01, 0.19551400E+00, 0.24595100E+01, 0.25066700E-01, -.47369600E-01, -.16017100E-01, -.25435900E+01, -.46581200E+00, -.10712900E+00, -.10352900E+01, -.18653900E+01, 0.21502100E+00, 0.13993900E+00, 0.59732200E+00, 0.16835100E+00, -.16554300E+01, -.10946600E+00, 0.23540000E+00, 0.30155800E+00, -.53075200E+00, 0.28958600E+00, 0.12437100E+01, -.14180800E+01, 0.67961700E-01, 0.18644800E+00, -.40043300E+00, -.96013400E+00, -.41091000E-01, 0.10515400E+01, -.11996600E+01, -.41797200E+00, -.25777100E+01, -.49479800E+01, 0.15777800E+00, 0.34611100E+01, -.56817300E+00, 0.67288800E+00, -.23678600E+01, 0.24985000E+00, -.12941200E+00, 0.73983000E+00, 0.16946000E+01, -.13027900E+00, 0.34751500E+00, 0.12982100E+01, 0.24015100E+01, -.45140600E+00, -.12076800E+01, -.96771000E-01, 0.25056400E+01, 0.11912400E+02, -.49924300E+00, 0.55093900E+00, -.76538800E+00, 0.53860500E-01, -.23358600E+00, -.17998700E+00, -.27043900E+01, 0.29885200E+00, -.99670600E+00, -.82192600E-03, 0.55413400E+00, -.90558700E-01, 0.37882000E+00, 0.21641100E+01, 0.68474000E+00, 0.10932400E+01, -.60994600E-01, -.52106900E+00, 0.26472700E+00, 0.56278100E-01, 0.95775300E-01, -.19582500E+00, -.12566400E+00, 0.51480100E+00, 0.10785000E+01, -.15036300E+00, 0.83854300E-01, -.63708700E+00, -.11458300E+01, 0.67893900E+00, 0.12925800E+00, 0.27532200E-01, 0.23043300E+00, 0.25334100E+00, 0.54760600E-01, -.24133000E+00, 0.20341700E+00, -.39602200E+00, 0.17620800E-01, -.28509900E+01, 0.36711800E+00, 0.28501000E+00, -.10603900E+00, -.20650000E+00, 0.15147000E+00, -.12109500E+00, -.25858400E-01, 0.20364700E+00, 0.28591500E+01, -.46979800E+00, -.71616400E+00, -.20154800E+00, -.16715600E+01, -.16997300E+00, -.15771900E+00, -.11831400E+01, 0.28434400E+01, -.10261200E+01, -.84876300E+02, 0.14365800E+02, 0.93005300E+01, -.78262100E+02, 0.34668900E+02, 0.48232500E+02, 0.38639800E+02, -.45326700E+01, 0.83298800E+01, 0.48550700E+02, 0.40072900E+01, 0.93910900E+01, 0.58095100E+01, 0.41867100E+02, -.50155900E+02, 0.21702100E+02, 0.18754900E+02, 0.26658100E+02, 0.21306400E+02, 0.22443900E+02, -.38488300E+02, -.29463900E+02, 0.54878300E+02, 0.18095800E+02, 0.16621800E+02, -.14832700E+03, 0.80542300E+02, -.88446000E+01, 0.74026100E+02, 0.76133300E+02, 0.35956600E+02, -.28518800E+01, -.69531500E+02, -.48051400E+02, 0.30462500E+02, 0.94739200E+02, -.88770400E+01, -.80914100E+00, -.52551300E-01, 0.95755700E+00, -.27857000E+01, 0.15826900E+01, -.59716400E+01, -.10395500E+01, -.19264400E+00, -.94796600E+00, -.68862500E+00, -.96088000E+01, -.10097500E+02, -.32475100E+01, -.81187700E+01, 0.15777900E+01, -.26237600E+01, 0.33431800E+00, -.67420600E+01, -.65132900E+01, -.12271900E+01, -.31718600E+01, 0.74691100E+01, 0.19430500E+01, 0.12482000E+00, 0.13123700E+02 },
        { -.74122600E+01, 0.41324000E+01, 0.55829900E+00, 0.17068800E+00, -.33410600E+01, -.18436700E+01, -.44565600E+01, -.42117800E+00, -.35395600E+01, 0.57495000E+01, 0.10309300E+01, -.77657100E-02, -.12932100E+01, 0.29444400E+01, -.58237100E+01, -.10436700E+01, 0.73906400E+00, -.23211900E+01, 0.22615600E+01, -.16252400E+01, 0.93261000E+00, -.10052000E+00, 0.99490100E-01, -.18256500E+00, 0.81288100E+00, -.13950200E+00, -.81269000E+00, -.30280900E+01, 0.27010100E+01, -.16583400E+01, 0.11362800E+01, 0.11995100E+01, 0.20612000E+00, 0.76430900E+00, 0.53866700E+00, 0.86249400E+00, 0.35693600E+00, 0.89024900E+00, -.12358400E+01, 0.55457700E+01, 0.25465700E-01, 0.95672300E-01, -.50724800E+00, 0.53101300E+00, -.21657200E+00, -.52746900E+00, 0.65087300E-01, -.28106600E-01, 0.36738400E-01, 0.14254900E+00, 0.22336600E+01, 0.11540500E+01, -.11735900E+01, 0.56377900E+00, -.19860600E+01, 0.13222900E+01, -.12709600E+01, 0.57882200E+00, -.14266900E+00, -.12113000E+01, -.55708100E+00, -.12521500E+01, -.54822700E+00, 0.80216100E+00, -.11657300E+01, 0.37392000E+00, 0.17489600E+01, 0.75003800E+00, 0.45802400E+00, -.20754800E-02, 0.11891100E+01, 0.31142900E+00, -.42482900E+01, 0.37718400E+00, 0.27160200E+00, -.17403000E+01, 0.11287400E+01, 0.27044800E+00, 0.32830700E-01, -.13580000E+00, 0.14382300E+00, -.21512500E+00, -.27970300E+00, -.37769500E+00, 0.43886500E+00, -.19419800E+00, 0.10357700E+00, -.22087800E+00, -.24252700E+01, 0.48213900E+00, 0.12655700E+01, 0.11106100E-01, -.55360000E-01, 0.32078900E-01, -.76237300E+00, 0.95212200E+00, -.26893400E+00, -.24889700E+00, -.36391300E+00, -.32335000E-01, -.92466700E-01, -.77070400E-01, 0.95734600E-01, -.36263500E+00, 0.16265500E+00, -.79418800E+00, -.45059600E+00, -.96764600E+00, 0.89427500E+00, -.82699300E-01, 0.20468600E+00, 0.40832500E+00, -.11388500E+00, -.75522100E-01, -.15961500E+00, 0.35179400E+00, -.39007000E+01, 0.83834500E-01, -.98283100E-01, 0.92366500E+00, -.47700400E+00, -.20848300E-01, 0.90854100E-01, 0.16780200E+00, 0.14430300E-02, 0.67892700E-01, -.43576100E-01, -.22194200E+00, -.76221000E-01, 0.31543500E+00, -.45181700E+00, 0.10742200E+01, -.16989800E+01, -.58794600E-03, 0.21760800E+00, 0.17626500E-01, 0.60534200E+00, 0.65548100E+00, -.44369900E+00, 0.17297700E+01, 0.89182600E+00, 0.54431000E+00, 0.16993900E+01, 0.14550000E+00, 0.11092000E+00, -.56467300E-01, 0.16155500E-01, -.22054900E+00, 0.35363400E+00, 0.19077100E+00, 0.78565900E-01, -.56707900E+00, -.15559100E+01, 0.47596500E+00, -.22651200E+00, 0.11396600E+00, 0.16085800E+01, 0.21114000E-01, 0.70244500E+00, -.15761200E+01, 0.34406500E+00, 0.10896400E+00, -.80118100E+00, 0.15454900E+00, -.55330700E+00, -.18678100E+00, 0.11092300E+01, -.99404700E+00, -.23696200E+00, -.60142600E-01, 0.24271400E+00, -.11150200E+01, 0.36104600E-01, -.14445400E+00, -.76443300E+00, -.21153500E+01, 0.40664400E+00, 0.12590600E+01, 0.33151000E+00, -.12798300E+01, -.17100900E+01, -.31567000E-01, 0.89643800E+00, 0.68609200E+00, -.13735300E+01, 0.41362200E+00, 0.26076800E+00, 0.18669900E+01, -.43345900E-01, 0.73470100E+00, 0.48093800E-01, 0.49368200E+00, 0.75833700E-01, 0.39254100E+00, -.15938200E+01, -.14304600E+00, -.16920500E+01, -.10238700E+00, 0.87426800E+00, -.18958800E+00, -.13274800E+01, -.73261800E-01, 0.16673300E+00, -.59013500E-02, 0.19593200E+00, -.35220400E+01, -.39319300E+00, -.14630200E+01, 0.10621500E+00, 0.54837400E-01, 0.58268500E-01, 0.24680500E-01, -.45794000E-01, 0.61535800E-01, 0.24831900E+00, -.52047200E+00, 0.10462000E+00, -.72913800E-01, -.54645900E-01, -.55435600E-01, -.22860300E+00, -.21252700E+00, -.30802200E-01, 0.15834300E-01, 0.84045600E-01, 0.28964000E-01, 0.49417500E-01, 0.53759500E-01, 0.42788700E-01, -.11237700E+01, -.30494700E-01, -.60725800E+00, -.55377000E-01, -.40624900E+00, -.81665200E-01, -.30887000E+00, 0.13933900E+01, -.16579500E+01, -.30876700E+00, 0.53709100E+00, -.14172400E+02, 0.11247100E+03, 0.64681600E+02, -.27329700E+02, -.51322700E+02, -.31075100E+02, 0.12414800E+02, -.22359100E+01, -.63292200E+02, -.30602300E+02, -.87927600E+01, 0.97313700E+01, 0.27318700E+01, 0.89538000E+02, -.37306300E+02, 0.33010400E+02, -.46010600E+02, -.24612800E+02, -.21181900E+02, 0.14978800E+02, 0.88568500E+01, -.11252200E+03, -.16859100E+02, -.37286000E+02, 0.91430100E+02, -.43673100E+02, 0.84386800E+02, -.45828400E+02, -.96419200E+02, -.43335200E+02, -.29793800E+02, 0.21906000E+02, 0.25990900E+01, -.23468000E+02, -.49608000E+01, 0.13837600E+02, 0.62480300E+01, 0.52179200E+00, -.34756000E+01, 0.16502600E+01, 0.36126300E+01, 0.90319700E+01, 0.13264700E+01, -.79075200E+00, -.27961800E+01, 0.23986100E+01, 0.13256300E+02, 0.15868500E+02, 0.53747900E+01, 0.20495500E+02, -.23992200E+01, 0.42278100E+01, -.29151600E+01, 0.18999400E+02, 0.82500900E+01, 0.48134700E+01, 0.90412100E+00, -.15226100E+02, -.74254800E+00, -.24581500E+01, -.31541900E+01 },
        { -.24850300E+01, -.10724500E+01, -.25311200E-01, -.11415800E+01, -.21128400E+01, -.41581100E+00, -.11110000E+01, 0.15707800E+01, -.12300200E+01, 0.13804700E+01, 0.11334800E+00, -.12122700E+00, -.33470700E+00, 0.12982700E+01, 0.49376500E+00, 0.23032000E+01, -.82204200E-01, 0.12158500E+00, -.77448200E+00, 0.47776600E-01, 0.14652700E+00, 0.27205600E-01, -.12014600E+00, -.76042300E-01, 0.48087000E+00, -.23156100E-01, -.45046800E+00, -.17805600E+00, 0.18771400E+00, -.23383200E-01, 0.25874400E+00, -.35821700E+00, 0.43384800E+00, 0.37283600E+00, 0.11587300E+00, -.22721500E+00, -.13573100E+00, 0.21587900E+00, 0.89454900E+00, 0.69430200E-01, -.92568800E-01, -.20634000E+00, 0.15620300E+00, 0.43579400E+00, -.36937800E+00, 0.73460400E-01, -.11222700E+00, -.24592300E-01, 0.78374200E-02, -.33020300E+00, -.69941500E+00, 0.22451900E+00, 0.33174800E+00, 0.87110200E+00, 0.42779200E+00, -.72008900E+00, 0.21386700E+00, -.21960100E-01, -.67964400E-01, -.43436400E+00, -.24573600E+00, 0.62777800E+00, 0.29989000E+00, -.40913200E-01, -.24870400E+00, -.38584800E-01, -.13550500E+01, 0.19938800E+00, -.23675900E+00, -.10814300E-02, 0.35022600E+00, 0.47795700E+00, -.10910700E+01, 0.10239600E+00, -.23446000E+00, -.44242100E+00, -.22288700E+00, 0.11795500E+00, -.78574900E-02, 0.23733700E+00, 0.91061800E-01, 0.77740500E-01, -.85623600E-01, -.15820400E+00, -.40672900E+00, -.11617200E+00, -.92241400E+00, -.58238000E+00, -.77397100E+00, 0.31168900E+00, 0.88012300E-01, 0.16932900E-01, 0.11650100E+00, 0.45011100E+00, 0.42967100E-01, 0.39513900E+00, 0.44725300E-01, -.16353600E+00, 0.65016500E+00, 0.80178300E-01, 0.10004400E+00, 0.10485400E+00, -.42376100E-01, -.16867900E+00, 0.12893500E+00, -.24736300E-01, -.65339400E+00, -.16500700E+00, 0.10429300E+01, -.25619700E-01, -.10792900E+00, 0.10813900E+00, -.15818700E+00, 0.13776800E-01, -.20018600E+00, 0.10719100E+01, 0.53994500E+00, -.58896700E+00, -.15486800E+00, 0.59893900E+00, -.50993900E+00, 0.85655600E-01, 0.87014200E-01, -.13609500E-01, -.20364400E-01, 0.36622100E-01, 0.70516400E-01, 0.12125400E+00, -.80695600E-01, 0.12486100E-01, -.36955200E+00, 0.59814700E+00, -.31540800E+00, -.72568700E-02, 0.11855100E+00, -.50496700E-02, 0.77313000E+00, -.27089400E+00, 0.83842900E-01, 0.44374500E+00, -.13392100E+00, 0.42179200E+00, 0.24936200E+00, -.72921500E-01, -.71468300E-01, 0.39226600E+00, -.15529500E-01, -.96252700E-01, -.15193300E+00, -.20912400E+00, -.20042100E+00, -.10052400E+00, 0.23879300E+00, -.50196000E-01, 0.25326100E-01, 0.42607200E-01, 0.37561200E+00, 0.13409500E-01, -.26569500E+00, 0.31188100E+00, 0.20176800E-01, 0.63195300E+00, 0.85955900E+00, 0.84365500E-01, -.71001600E+00, 0.19135700E+00, -.35075600E+00, -.17851700E+00, 0.47026500E-01, -.30319800E-01, -.12483800E+00, 0.34796000E-01, -.49158700E-01, -.11252000E+00, 0.20685500E+00, -.76515300E-01, 0.35061100E-01, -.20232400E+00, -.14291900E+00, 0.43630700E+00, -.20250700E+01, 0.58242600E-03, 0.31609100E+00, -.11616300E+00, -.53333100E-02, -.36713400E-01, -.30117500E-01, 0.10206500E-01, -.13091200E+00, 0.45025600E-01, -.28428300E-02, -.34742200E+00, 0.41188400E-01, -.56451700E+00, 0.24295600E+00, 0.40011200E-01, 0.18192800E+00, 0.10692400E+00, -.52952000E-01, 0.95572900E-01, 0.70364700E+00, 0.31376100E-01, -.44107700E-01, 0.35585000E-01, -.22968100E-01, -.35245400E+01, -.60616400E+00, -.26989900E+00, -.22866100E-01, -.28929000E+00, -.15796100E-01, 0.48757300E-02, 0.18548700E-01, 0.20449000E-01, 0.30401900E-01, -.20765400E-01, 0.89039000E-02, -.28795300E-02, 0.41176700E-01, 0.31259800E-01, 0.16465900E+00, 0.43121800E-01, 0.26025000E-01, -.13648300E-01, -.48027700E-01, -.59708200E-01, 0.79060400E-01, -.78636700E-01, -.89918700E-02, -.29755800E+00, 0.13359800E+00, 0.63011300E+00, 0.17409500E+00, 0.91186000E-01, 0.10197000E-01, -.84843400E-01, -.56320300E+00, -.82525200E+00, 0.43708400E-01, -.47583700E-01, 0.31580100E+00, -.28449200E+02, -.34314000E+02, 0.15398700E+02, 0.25586800E+02, 0.16863700E+02, -.25561200E+01, 0.16677300E+01, 0.32390700E+02, 0.21263300E+02, 0.77315200E+01, -.22342400E+01, -.27830100E+01, -.33890400E+02, 0.14693800E+02, 0.12016800E+01, 0.17417000E+02, 0.79864900E+01, 0.88819000E+01, -.12063300E+02, -.82958300E+01, 0.38028400E+02, 0.73379000E+01, 0.14149400E+02, -.43322800E+02, 0.21832200E+02, -.17978300E+02, 0.21587300E+02, 0.37105300E+02, 0.20486400E+02, 0.30371700E+01, -.21025300E+02, -.13469300E+02, 0.14561000E+02, 0.22589000E+02, -.49192800E+01, -.16956500E+01, -.18048300E+00, 0.12728700E+01, -.22275900E-01, -.99331600E+00, -.28216500E+01, -.67596000E+00, 0.91839000E-01, 0.55377100E+00, 0.21554400E+00, -.41465200E+01, -.51082700E+01, -.17132500E+01, -.46004300E+01, 0.53884100E+00, -.81442800E+00, 0.79804000E+00, -.42620400E+01, -.26973900E+01, -.12275800E+01, -.14039200E+01, 0.43973600E+01, 0.10162300E+01, 0.60374800E+00, 0.26262900E+01 },
        { 0.11401900E+02, -.33282000E+01, -.60790600E+00, 0.12021600E+01, 0.44081700E+01, -.60398200E+00, 0.89416900E+01, -.22079000E+01, 0.56559600E+01, -.86280000E+01, 0.15490300E+00, 0.88655100E+00, 0.61615500E+01, -.55084100E+01, 0.61496100E+01, -.70174400E+00, -.58385900E+00, 0.18424600E+01, -.27892300E+01, 0.23694200E+01, -.12923600E+00, -.21037200E+00, 0.52786500E-01, 0.35132000E+00, -.59345200E+00, -.13613200E+00, 0.54261000E+00, 0.26206800E+01, -.64982400E+00, 0.13736800E+01, -.59718600E+00, -.15955500E+01, -.57546100E+00, 0.75353300E-01, 0.19938200E+00, -.23001100E+00, 0.36672800E+00, 0.35199900E-01, -.56032700E+00, 0.14969800E+01, -.16149900E+00, -.48563100E+00, 0.70349300E+00, -.12265200E+01, -.50662500E-01, -.14861400E+00, 0.29846800E+00, -.66104200E-01, 0.18811900E+00, -.62699700E+00, 0.25680900E+01, 0.73473800E+00, -.72139700E+00, 0.11146500E+01, -.10034600E+01, -.14188500E+01, 0.78057300E+00, -.88844400E+00, 0.12574500E+00, 0.26629000E+01, -.29830300E+01, -.10081200E+02, -.44725900E+01, 0.18594000E+01, -.87913100E+00, -.50708000E-01, -.18457000E+01, -.42346500E+00, -.55334100E+00, 0.40412500E-02, 0.71738200E+00, 0.59029100E-02, 0.47600700E+01, -.78057700E-01, -.24017800E+00, -.15409100E+00, 0.17244000E+00, -.13155400E+01, -.30604600E+00, 0.73382700E+00, -.37932800E-01, 0.12975400E+00, -.20920100E+01, -.10512800E+01, 0.13871000E+01, -.46037200E+00, 0.64601800E+00, 0.10271400E+01, 0.13271000E+01, -.17507700E+00, -.23239800E+00, -.84467400E-01, 0.16029600E+00, -.13648800E+01, -.10512900E+00, 0.93871100E+00, -.67267400E+00, 0.15891000E+01, -.99379300E+00, -.76657400E+00, -.11768200E+01, 0.12900200E+01, 0.31166700E+01, -.70865300E+00, 0.36362700E+00, 0.57845100E+00, 0.13703600E+01, 0.27027800E+01, -.35854500E+00, 0.47303900E+00, -.20265500E+00, -.99386600E-01, -.34914900E-01, -.20138700E+00, -.70622800E+00, -.17140400E+01, -.71043500E+00, -.22426800E+00, -.23831300E-01, -.17642300E+00, 0.40892700E+00, 0.12888200E+01, 0.17862400E+00, 0.18290900E+00, 0.39271100E-01, -.63520800E+00, 0.30400900E+00, 0.89459300E+00, -.11015800E+01, 0.58655600E+00, 0.34061200E+00, 0.33974400E+01, -.19741500E+01, 0.18919100E-01, -.18591500E+00, 0.54915900E-04, 0.36641800E+00, -.31667300E+00, -.37925500E+00, 0.52691600E+01, -.43688000E+00, -.15189500E+01, 0.14310500E+01, 0.24000600E+00, -.49096700E-01, 0.12887400E+01, -.16048000E+00, 0.27072700E+00, 0.16134400E+00, -.15386600E+00, -.60026200E+00, -.11309500E+01, 0.95153900E-01, 0.19602300E+00, -.18972300E+00, -.15578900E+00, 0.11267200E+01, 0.86467000E-02, 0.45446800E+00, -.12893000E+01, 0.19834600E+00, 0.94798600E+00, -.29777600E+00, 0.50934100E+00, -.16020700E+01, -.22716600E+00, -.39429500E+00, -.71228400E+00, -.24579300E+00, -.76910900E-01, -.45023100E+00, 0.10272600E+01, -.88570300E+00, -.23726900E-01, 0.17028100E+00, 0.89996200E+00, -.32760900E+00, -.92131600E+00, 0.11388300E+01, -.43193800E+00, -.68234500E+01, 0.16322200E+00, -.27510000E+01, -.10997500E+01, -.16848600E+01, 0.49335900E+00, 0.12256400E+00, 0.49222000E+00, 0.96464500E+00, -.62955300E+00, -.12433000E-01, 0.11159200E+01, 0.48468500E+00, -.92851200E+00, 0.16775700E+01, 0.37681500E+00, -.27657300E+00, 0.76198000E+00, 0.27833000E+00, 0.33819400E+00, -.17579500E+01, -.16627100E+00, -.21944100E+00, -.58735500E+00, 0.88160600E+00, 0.11967700E+02, 0.51246100E+01, 0.15262600E+00, -.18341700E+00, 0.10824600E+01, 0.25064200E-01, 0.46827800E+00, -.14929600E+00, 0.60458200E+00, -.73531500E-01, 0.54782400E+00, 0.16539600E+00, 0.16157100E+00, -.60317200E+00, -.68866100E+00, 0.11537500E+02, -.72365100E+00, 0.16565500E+00, -.38515200E-01, 0.86575900E+00, -.90208700E+00, 0.10734300E-01, 0.51775100E+00, -.25430500E+00, -.35605600E+01, -.38722000E+01, -.11110600E+01, 0.15732100E+01, -.13213400E+01, -.19211200E+00, 0.54386600E-01, -.30909000E+01, -.94668800E-01, -.15363000E+00, 0.59224400E-01, 0.59990000E+00, 0.54588700E-02, -.56468400E+03, 0.28156900E+03, 0.33614800E+03, 0.28354500E+03, 0.59740700E+02, -.12330700E+01, 0.37893300E+03, 0.22286300E+03, 0.18947700E+03, -.84779500E+01, 0.16408000E+03, -.24900600E+03, 0.11488600E+03, 0.24193500E+03, 0.13508700E+03, 0.86787300E+01, 0.66245400E+02, -.11055300E+03, -.10722200E+03, 0.21792700E+03, 0.60090000E+02, 0.12028400E+03, -.30579200E+03, 0.13978900E+03, 0.42806900E+02, 0.15433500E+03, 0.10429800E+03, 0.91022500E+02, -.17940800E+02, -.11382100E+03, 0.16002200E+03, 0.58266900E+02, 0.88095300E+02, -.13688300E+02, 0.37153300E+01, 0.94010600E+01, 0.84317500E+01, 0.47122900E+01, 0.22678600E+00, -.96441200E+01, 0.13888100E+01, -.57078600E+01, -.97640100E+00, 0.10396400E+02, 0.22655900E+02, -.17561600E+02, -.85467500E+01, 0.24900600E+02, 0.19686400E+01, -.20055000E+01, 0.39795900E+01, 0.19722800E+02, -.81599000E+01, 0.14000300E+01, -.36772500E+02, -.24297600E+02, 0.20429100E+02, 0.98171300E+00, 0.59315200E+01 },
        { -.11785800E+02, -.12755500E+02, -.12111300E+01, -.51547200E+01, -.85871600E+00, -.74918900E+01, -.12964800E+02, -.10361400E+01, -.72407400E+01, 0.10371500E+02, 0.31681400E+00, -.47727200E+00, -.41645100E+01, 0.11722500E+02, -.84322900E+00, -.14785900E+00, 0.27399500E+01, 0.62803300E+01, -.33585600E+01, 0.15146600E+01, -.49190600E+00, 0.26105200E+00, -.39048800E+00, -.64923000E+00, 0.23716900E+01, 0.12812300E+00, 0.32471700E+00, 0.44840800E+01, -.54541200E+01, 0.30193900E+01, -.91299300E+00, -.24586900E+01, 0.16614700E+01, 0.14389800E+01, 0.26026500E+01, -.15520000E+01, 0.74514500E+00, 0.20007800E+01, -.29396700E+01, 0.25715100E+01, 0.24327200E+00, 0.14619500E-01, 0.25039300E+01, 0.19912100E+01, -.14906900E+00, -.31414400E+00, 0.16447600E+01, -.12717900E+00, 0.24332700E+00, -.46812800E+00, 0.61766600E+01, 0.93171300E+00, -.12252200E+01, -.15717400E+01, -.29844900E-01, -.20926900E+01, 0.10578600E+01, -.94972800E+00, -.23593000E+00, 0.13225200E+01, 0.13750100E+01, -.10834700E+02, -.58490100E+01, -.27008400E+01, 0.26650100E+01, -.27516800E+00, 0.35188200E+00, -.15521500E+01, -.50020800E-01, 0.78291600E-01, 0.75942300E+00, 0.60858400E+00, 0.44647800E+01, 0.55407100E+00, -.78545300E+00, -.12422400E+01, 0.90464600E+00, -.18558700E+01, -.49518100E+00, 0.16584700E+01, 0.47290800E+00, 0.20624400E+00, 0.27539000E+00, 0.70401600E+00, -.41353400E+01, -.12958900E+01, 0.91579500E+01, -.18595300E+01, -.81048200E+01, 0.37361100E+01, -.26623400E+01, -.40691900E-02, -.11533200E+01, 0.20329100E+00, 0.23747700E+01, 0.11270600E+01, 0.10532700E+00, 0.85148900E+00, 0.88013200E+00, 0.19871200E-01, -.65899300E+00, -.90402900E+00, -.10918100E+00, 0.43956300E+01, -.80942000E+00, 0.23207800E+01, 0.40072100E+00, 0.70988700E+00, -.48279800E+00, 0.11962500E+00, -.30450800E+01, 0.67701400E+00, 0.12172100E+00, -.69597400E+00, 0.10372400E+01, 0.10722800E+01, -.59752400E+01, 0.79774200E+00, 0.40935200E+00, -.51002100E+00, -.18599000E+01, 0.51951100E+00, 0.31880700E+00, -.27626600E+00, -.56063300E-01, -.51872100E-01, -.13917600E+00, 0.27599100E+01, 0.17582500E+00, 0.51809000E+00, -.43191100E+01, 0.50808400E-01, -.15152100E+01, -.45268000E-01, -.93578500E-01, 0.92521700E-02, 0.28193000E+01, -.18074900E+01, 0.12974400E+01, 0.16666700E+01, 0.55314100E-01, -.46594300E+00, -.85217800E+00, 0.91805100E+00, 0.17251600E+00, -.20867600E+01, -.65216900E-01, 0.43039400E+00, 0.88458800E+00, -.86135500E+00, -.15326100E+00, 0.57831400E-01, 0.86883500E+00, -.87938200E+00, 0.26655800E+00, 0.47350900E+00, 0.13413400E+01, -.42638100E-01, 0.66700000E-01, -.65255600E-01, -.40822300E+00, -.57082900E+00, -.43454700E+01, -.14007500E-01, 0.15213600E+01, 0.20184700E+00, 0.35478500E-01, -.13680500E+00, 0.18642200E+00, 0.37571200E+00, 0.28620100E+00, -.36733700E+00, -.90558800E-01, 0.21921900E+00, -.74581800E+00, -.33090200E+01, 0.17416600E+00, -.59524300E+00, -.17504300E+00, -.15145700E+00, 0.34468400E+01, -.35750900E+00, -.55510300E-01, -.24403200E+00, -.41740400E+00, -.86453700E+00, -.37073500E+00, 0.10438600E+01, -.17238000E+00, 0.16261600E+00, 0.61960300E-01, -.26054900E+01, -.57539200E+00, -.23324100E+01, 0.26608300E+01, -.10550800E+01, 0.36566800E+00, 0.91414800E+00, 0.28636000E+00, 0.64816600E-01, -.22861100E+01, -.16873700E+00, -.18638700E+00, 0.47699100E-01, 0.16610200E+01, 0.93906100E+01, 0.31607800E+01, 0.28947800E+00, 0.12929000E+01, 0.87294400E+00, -.10109000E+00, -.93178600E+00, -.11256900E+00, -.30545200E+00, 0.76348200E+00, -.27182500E+01, -.93121100E+00, -.98046100E-01, 0.34160600E+00, 0.39881400E+00, 0.75950100E+01, -.27758700E+00, -.87319800E+00, 0.26944300E+00, 0.76756100E+00, 0.13458900E+00, -.28816100E+00, 0.16950700E+00, -.77239600E-01, -.44695100E+00, 0.15236700E+01, 0.11884900E+01, 0.12997400E+01, 0.35854500E+00, -.63994300E-01, -.52810500E-01, -.14535900E+01, -.12128000E+01, 0.22602900E-01, -.27208000E+00, 0.34431100E+00, 0.13254700E+01, 0.31925300E+00, 0.11441600E+02, -.30858200E+02, -.99017300E+00, -.12585100E+02, 0.28429800E+02, -.11521900E+03, -.12569800E+03, -.35186100E+02, 0.32169700E+02, 0.35796000E+02, 0.60269700E+02, -.26773200E+02, -.55205200E+02, -.34500100E+02, 0.15538300E+02, -.82816800E+01, 0.34417500E+02, 0.41391400E+02, -.53557400E+02, -.54154000E+01, -.38825700E+02, 0.58378600E+02, -.23608500E+02, -.42627900E+02, -.30027000E+02, 0.73803800E+01, -.10705700E+02, 0.52667600E+00, -.54491000E+01, -.80821400E+02, -.22204000E+00, -.28729600E+02, 0.28518900E+01, -.44410400E+01, -.32445500E+01, -.23374800E+01, 0.29220000E+01, -.15152600E+01, 0.21380600E+01, -.23352200E+01, 0.28281400E+01, 0.70817800E+00, -.30966400E+01, -.28395700E+01, 0.51905600E+01, 0.41561200E+01, -.30072600E+01, -.13488800E+01, 0.19834200E+01, -.62213200E+00, -.20969900E+01, 0.92883600E+00, -.56430100E+01, 0.13228600E+02, 0.31923800E+01, -.81473900E+01, 0.15760000E+01, -.78610800E+00 },
        { 0.61977500E+01, -.17852900E+01, -.49388400E+00, -.24644900E+01, 0.43519500E+00, 0.86195800E+01, 0.12143300E+01, -.40376700E+00, 0.28356300E+01, -.33934300E+01, 0.81408900E-02, 0.20370500E+00, -.45447100E+00, 0.16952400E+01, -.19254600E+01, -.14484900E+01, 0.13568400E+01, -.65391900E+00, -.23121600E+00, -.21188000E+01, -.30244900E+00, 0.37313100E-01, -.27305800E+00, 0.14546300E+00, -.76825300E+00, -.13497300E+00, -.97494800E+00, -.59289200E+00, 0.25541600E+01, -.23002300E+01, -.18614400E-01, 0.68389000E+00, -.62752300E+00, -.90733000E+00, -.89969000E+00, 0.74188900E+00, -.64608700E-01, -.99173000E+00, -.40618300E+00, 0.26137500E+00, -.25488300E+00, -.69504200E-02, -.26572300E+01, -.80770600E+00, 0.30085800E+00, -.50490700E-02, -.11164300E+01, 0.67371800E-01, 0.94828200E-01, 0.68746100E+00, -.39711300E+01, -.10876700E+00, 0.11288600E+01, 0.73668500E+00, 0.11336900E+01, 0.29672000E+00, 0.20453900E+01, 0.19401200E+00, 0.27317000E+00, 0.35120600E+00, -.15057500E+01, -.34854100E+00, 0.55867100E+00, 0.10250600E+01, 0.10543300E+01, 0.26866600E-01, 0.13484600E+00, 0.55278100E+00, 0.23047400E+00, 0.11640900E+00, -.74580600E+00, 0.17195200E+00, 0.17611400E+00, 0.89685400E+00, 0.84799700E+00, 0.33506400E+00, 0.41162800E+00, 0.19331200E+01, -.19329400E+00, 0.71220400E+00, 0.32858300E-01, 0.20858500E+00, -.87186600E+00, -.11113800E+00, 0.25718900E+00, -.22285000E+00, 0.21447300E+01, 0.67093000E+00, 0.46703200E+00, -.62693300E-02, 0.10949600E+01, -.29033400E-01, -.21165400E+00, -.67234300E-01, 0.47845200E-01, -.11543100E+01, 0.16066200E+00, 0.88618900E+00, -.95287100E+00, -.33613000E+00, -.89450700E-01, 0.20791300E+00, 0.15038900E+00, -.60388000E+00, -.18076100E+00, -.25357300E+00, 0.95679500E+00, 0.33738500E+00, -.12745700E+01, -.19633600E+00, 0.14146900E+01, -.25319600E+00, 0.44331400E-01, 0.43843200E+00, 0.90771700E+00, -.17297500E+01, 0.91911600E+00, 0.12540900E+01, 0.93895000E-02, -.23340000E+00, 0.13614800E+01, -.38553400E+00, -.13543000E+00, -.54519400E+00, -.48271800E-01, -.55007800E+00, 0.12521900E+00, 0.75445700E+00, -.44784100E+00, -.36949100E+00, 0.54329200E+00, -.48272400E+00, 0.85585500E+00, 0.21329600E-02, -.92431900E-01, 0.62809600E-02, -.59514600E+00, 0.72899200E+00, -.19331800E+00, 0.18757300E+00, 0.51178900E+00, 0.29870200E+00, 0.95698200E+00, 0.17943100E+00, 0.20282000E-01, -.43143900E+00, 0.57307100E-02, -.10646800E+00, 0.15817800E+00, -.44819000E+00, -.21880000E+00, -.41882100E+00, -.11016400E+01, 0.46355700E+00, -.95213700E-01, -.16741500E+00, 0.53375800E+00, 0.23393800E-01, 0.33851000E+00, -.11172600E+01, 0.60865500E-01, 0.46764800E+00, -.11686700E-01, 0.27234100E+00, -.81036300E+00, -.21582900E-02, 0.92645100E-02, -.85376300E+00, -.25127100E-02, 0.70669400E-01, -.31788500E-01, 0.10719200E+01, 0.14095500E+00, 0.13319800E+00, 0.40440700E+00, 0.11196300E+01, -.31283200E+00, -.42651500E+00, 0.84119900E+00, -.56459700E+00, 0.26609600E+01, 0.20435200E+00, -.38408600E+00, -.16494600E+00, 0.33528400E+00, -.19480600E+00, 0.20745800E+00, -.47903300E+00, -.83748800E-01, 0.88644800E-01, 0.19247000E-01, -.19928200E+00, 0.89259500E-01, 0.53245900E+00, -.28947400E+00, -.28529800E+00, -.11385700E+00, -.28454200E+00, 0.12168400E+00, -.67033200E-04, 0.10938100E+01, 0.41775800E-01, -.11616200E+00, -.53403100E+00, -.16159500E+01, 0.68463900E+01, 0.66075500E+00, 0.42009500E+01, -.68669700E+00, 0.12261700E+00, -.42840000E-01, -.51144600E+00, 0.20572300E-01, -.20679400E+00, -.38565200E+00, 0.73987800E+00, 0.98631000E-01, 0.20325000E-01, 0.55382900E-01, 0.16529000E-01, 0.11265100E+01, -.41305700E+00, -.12207700E+00, 0.45358300E-01, -.12428400E-01, 0.13528000E+00, 0.21669400E+00, -.11152900E+00, 0.17059800E-01, -.45255300E-01, -.31771000E+00, 0.20885800E+00, -.25392200E+00, -.18698800E+00, 0.24815300E-02, -.23278700E-01, 0.59701000E-01, 0.74460200E+00, -.15658800E+00, -.23254200E-02, -.20174000E+00, -.83810500E+00, -.23713500E+00, -.28841100E-01, 0.32133300E+02, 0.59560000E+00, 0.44352900E+01, -.17503100E+02, 0.10278100E+03, 0.16632800E+03, 0.36412100E+02, -.29722300E+02, -.41307100E+02, -.93806000E+02, 0.44199800E+02, 0.80421100E+02, 0.50638300E+02, -.18359500E+01, 0.18704600E+02, -.40296400E+02, -.41177400E+02, 0.81128100E+02, 0.17393500E+02, 0.53842900E+02, -.77784900E+02, 0.35629800E+02, 0.31803900E+02, 0.39560200E+02, 0.35060000E+02, 0.29265400E+02, -.14397900E+01, -.22571400E+02, 0.25470900E+02, 0.18546600E+02, 0.49814800E+02, -.82005600E+01, 0.30812300E+00, 0.31937200E+01, 0.32989100E+01, -.67868900E+00, -.58556400E+00, -.36532800E+01, -.56291800E+00, -.19772900E+01, 0.12324800E+00, 0.44010000E+01, 0.26188400E+01, -.77681200E+01, -.42418100E+01, 0.32720200E+01, -.71021100E-01, 0.12125600E+00, 0.32286700E+00, 0.22496900E+01, -.23633200E+01, 0.13102200E+01, -.80920600E+01, -.30444300E+01, 0.46418600E+01, 0.25207200E+01, 0.24557700E+01 },
        { -.11802700E+02, 0.16496000E+01, 0.56749100E+00, -.85384700E+01, -.83837400E+01, 0.13191600E+02, -.15955000E+02, 0.22502200E+02, -.73961800E+01, 0.10440100E+02, 0.87003900E-01, -.41976800E+00, 0.62698400E+01, 0.61092100E+01, 0.62518000E+01, 0.51793000E+01, -.45428000E+01, 0.19732100E+01, -.27669400E+01, 0.39345800E+01, -.25390100E+00, 0.21699100E+00, 0.14627900E+00, 0.17871300E+01, -.96936200E+01, 0.10414300E+01, -.46778800E+01, -.37670800E+01, 0.40850800E+01, 0.21302800E+00, 0.93376100E+00, -.33610800E+01, -.28365800E+01, 0.29956700E+01, 0.38858200E+00, 0.68680100E-01, -.25764100E+01, -.29285200E+01, -.12353700E+01, -.35077400E+02, -.70608600E+00, -.20106200E+01, 0.34015800E+01, 0.57273300E+00, -.19131900E+01, -.63484100E+00, -.70827700E-01, -.33345500E-01, 0.77126600E+00, -.26835500E+00, 0.43403000E-01, 0.20581900E+01, 0.35974200E+00, 0.17956000E+01, 0.18517900E+01, 0.47013900E+00, 0.33631000E+00, -.38307800E+00, 0.21319700E+00, -.45634800E+00, -.10030400E+00, -.31328300E+01, -.24676000E+01, 0.19348000E+01, -.19093900E+01, -.61625000E-01, -.83193800E+00, 0.16941500E+00, -.85052500E+00, 0.49963600E+00, 0.83016300E+00, 0.19301800E+00, 0.20372800E+01, 0.15061500E+00, -.86301900E+00, 0.13665300E+01, -.25687000E+00, 0.43910900E+00, 0.44569000E+00, -.28504800E+00, 0.35319500E+00, -.15305000E+00, 0.63523500E-01, 0.94432100E-01, 0.42320000E+00, -.69377300E+00, 0.12790900E+01, 0.18468700E+00, -.61147000E+00, 0.31187800E+00, 0.53217400E+01, 0.36451600E+00, 0.30304200E+00, 0.30716600E+00, -.28401500E+00, 0.12753600E+01, -.43215100E+00, 0.41533900E+00, -.13701000E+01, -.20155300E+00, 0.13418300E+00, 0.11878700E+01, -.82811900E-02, -.58317600E+00, 0.18319600E+00, -.20551100E+00, 0.84943000E+00, -.14712900E+00, -.84729500E-02, 0.11653600E+00, -.11656600E+01, 0.23512600E+00, 0.21588900E+00, 0.74633400E-01, 0.14833300E+01, -.24694600E+00, 0.30607300E+00, 0.16269400E+01, 0.10675900E+00, -.57124100E+00, -.12351700E+00, 0.15401400E+01, 0.21386500E+00, 0.48968000E+00, 0.39786600E+00, -.94055100E-02, -.28747700E+00, -.84278800E+00, 0.16475600E+01, 0.10198500E-01, -.36546800E+01, 0.24238800E+01, -.11474500E+01, -.15103800E-01, -.79588300E-01, -.78694900E-01, 0.20697700E+01, -.15992700E+01, 0.42692400E+00, 0.24519800E+01, 0.44607000E+00, -.30970700E+01, 0.42595300E-01, 0.81762700E+00, 0.41055300E-01, -.10764100E+01, 0.23776000E+00, 0.47791400E+00, 0.88432600E+00, -.14466700E+01, -.22415300E+00, -.37433700E+00, -.10286200E+00, 0.55526500E+00, -.41708500E+00, 0.42993300E+00, -.71031400E+00, 0.16967200E+00, -.65864000E+00, -.19928300E+01, 0.24431600E+00, 0.87993000E+00, -.81354100E+00, 0.17061400E+00, -.28610000E+00, -.67424100E+00, 0.79316600E+00, -.48182500E+00, -.23735100E+00, 0.33229800E+00, 0.26768700E+00, -.32873600E+00, -.41419600E+00, -.17465300E+00, 0.10711000E+01, 0.60334200E+01, -.40429300E+00, -.87474100E+00, 0.65871900E+00, 0.14997300E+01, -.42236700E+01, -.63676800E-01, 0.16754800E+00, -.15186000E+01, -.95031500E+00, -.14001400E+00, -.58557000E-01, 0.80356300E+00, 0.24451800E+00, -.15426700E+01, -.16454000E+00, -.97076400E+00, -.87997100E+00, -.97190400E-02, 0.40066500E+01, 0.55194700E+00, 0.12806600E+01, 0.99534500E+00, -.20640500E+00, 0.34773500E-01, -.27338800E+01, 0.31687200E-01, -.45406700E+00, 0.84390600E-01, 0.18784800E+01, 0.19164300E+02, 0.21635700E+01, -.26316100E+01, 0.69849600E+00, 0.16777900E+01, 0.43055200E+00, 0.18716100E+00, -.18302600E+00, 0.38070000E+00, 0.55756500E+00, -.39864200E+00, -.26766100E+00, -.68743600E-01, -.40908000E+00, -.59174600E-01, 0.19074700E+00, 0.16463000E+00, -.22504100E-01, 0.15193400E+00, 0.28999200E-01, -.32850400E+00, -.22264600E+00, 0.15736200E+00, 0.15819800E+00, 0.42291400E+00, -.43556100E+00, -.58267800E+00, 0.32647300E+00, -.36444400E+00, -.99125500E-03, 0.29964000E-01, -.93507800E+00, 0.11247000E+00, -.11541500E+00, 0.18876800E+00, 0.12237500E+00, 0.50846000E+00, 0.38509300E+00, -.23566900E+00, -.10947300E+01, 0.11740400E+02, 0.60987800E+01, 0.16132700E+02, -.57028000E+02, -.84205300E+01, -.12201900E+02, 0.85105600E+01, 0.85408600E+01, -.27672900E+00, -.26094700E+00, 0.51577800E+01, 0.23018700E+01, 0.87596400E+01, 0.75779600E+01, -.13855900E+02, -.11919900E+02, -.12932600E+02, 0.89475100E+01, -.22527900E+01, 0.30599000E+02, -.12263700E+02, -.12777500E+01, -.13489300E+02, 0.95509600E+00, 0.21811600E+01, -.98046500E+01, -.26759800E+01, -.34435700E+02, 0.42856800E+01, -.15736700E+02, -.57267100E+00, -.46841100E+00, -.45558200E+00, -.16703700E+01, -.24625500E+01, -.13073000E+00, -.49039200E+00, 0.29236100E+00, 0.25002900E-01, 0.61005300E-01, -.14874400E+01, 0.52195400E+00, -.76090600E+00, -.53931300E+00, 0.41773700E+00, -.13959600E+01, 0.13848900E+01, -.78301000E+00, 0.46202400E+00, -.78397700E+00, 0.12418600E+01, 0.72207400E+01, -.55230500E+00, -.50298000E+01, 0.65386100E+00, 0.31785500E+01 },
        { -.24739000E+01, -.11097800E+01, -.27079100E-01, 0.21600500E+01, 0.41659400E+00, -.50366800E+01, -.18210100E+01, -.17613600E+01, -.18538800E+01, 0.15752400E+01, 0.14658400E-01, -.18947700E+00, -.40955800E+01, 0.28456600E+01, -.42102300E+01, 0.70529100E+00, 0.26284900E+01, -.26159700E+00, -.35578300E-01, -.76387500E+00, -.80648800E-01, 0.11016100E+00, -.90121600E-01, -.26837100E-01, 0.57352200E-01, 0.18011500E-02, -.41320600E+00, -.55915800E+00, 0.30411100E+00, -.31453000E+00, 0.10183700E+00, -.39479300E-01, 0.18213100E+00, -.56722100E-01, 0.72976400E-01, -.89679100E-01, -.40140900E-01, -.89970200E-01, 0.58055500E+00, 0.58182500E+00, -.10194900E+00, -.12629100E+00, 0.31585900E-01, 0.30720600E+00, -.11812300E+00, -.38867000E-01, -.12233100E+00, 0.11682500E-01, -.20806200E-01, 0.85428100E-01, -.71805600E+00, 0.11793800E+00, 0.15563600E+00, 0.31751100E+00, 0.45004800E+00, 0.40721200E-01, 0.15524000E+00, 0.37519700E-01, 0.49105300E-01, -.44221000E+00, 0.49030400E+00, 0.63414600E+00, 0.27071700E+00, -.35242000E+00, 0.77767600E-01, -.64539300E-02, -.17754000E+00, -.31165500E-01, 0.22563200E-01, 0.14717500E-01, 0.36108700E+00, -.49109000E-01, 0.11023800E+00, -.17307200E-01, -.45814600E-01, 0.35771900E+00, -.44770100E-01, 0.12181900E+00, -.44770000E-01, 0.30661000E-01, -.24235300E-01, 0.18919700E+00, 0.10802500E+01, 0.16646800E+00, -.14142900E+01, -.67164900E-01, -.18712400E+00, 0.52141800E+00, -.12967700E+01, 0.17772800E+00, 0.10796600E+01, 0.22627000E-01, 0.30328700E-01, 0.38291100E+00, 0.80738800E-01, -.13207900E+00, -.70664200E-01, 0.23128200E+00, -.50783400E+00, -.11912700E+00, -.86925100E-01, 0.10182700E+00, -.25774900E+00, 0.28918400E+00, -.27481700E+00, 0.10251700E+00, 0.45684700E+00, -.64418100E-01, -.33429700E+00, -.11572100E-01, -.21991800E+00, -.36978600E-01, 0.65445500E-01, -.64437900E-01, 0.45486300E+00, -.22934600E+00, -.37620200E+00, 0.32903100E+00, 0.67048500E-01, -.81345700E-01, -.65559200E-01, 0.23209100E+00, 0.27549000E-01, 0.12667200E+00, 0.69451600E-02, 0.15252800E-02, -.82463800E-01, 0.17518700E-01, -.21492000E+00, -.20727200E+00, -.16895100E+00, 0.27820200E+00, -.46470000E-01, -.96860400E-02, -.66106800E-02, -.56758200E-02, -.75569100E+00, 0.26485600E+00, -.60651300E-01, -.88682600E+00, 0.45004300E+00, -.10028200E+01, 0.12226400E+00, 0.34335000E+00, -.91679700E-01, -.57611800E+00, -.25978700E-01, 0.11338500E+00, 0.26191700E+00, -.54027000E+00, -.19738700E+00, -.23778000E+00, -.27297600E+00, 0.34092200E-01, -.77371800E-01, 0.60129600E-01, -.49768100E+00, 0.68569600E-02, 0.43864000E-01, -.62781800E+00, -.12136000E-01, 0.36612400E+00, -.69116100E-01, -.45868900E-01, 0.77889900E-01, -.60197400E-01, -.50065200E-01, 0.24056700E+00, 0.21063900E-01, 0.31210400E-01, 0.63814500E-01, 0.16669100E-01, 0.58427800E-02, -.82495900E-01, 0.53400900E+00, -.18932400E+00, 0.23035900E-01, -.16242900E+00, 0.22749200E-01, 0.16178400E+00, -.75395700E+00, -.13176200E+00, 0.28032700E-01, -.33268800E-02, -.30783400E+00, -.55211600E-01, 0.21426600E-01, 0.33237000E+00, -.12475200E+00, 0.19247100E+00, 0.13680300E-02, -.23672100E+00, 0.24541500E-01, -.28581100E+00, 0.27101800E+00, -.14941000E+00, 0.15449500E+00, 0.10204300E+00, -.13888500E+00, 0.13301600E+00, -.42951200E+00, -.46562500E-01, 0.19877700E+00, 0.19204800E+00, 0.77818000E+00, 0.11312300E+01, 0.29710500E-01, -.12236600E+01, 0.12091600E+00, -.92245100E-01, 0.16410700E+00, -.16751900E+00, -.49716000E-02, -.10240700E+00, 0.35999800E+00, -.96628200E+00, -.17447800E+00, -.10271600E+00, 0.70993200E-01, 0.77863900E-01, -.39552400E+00, -.51967200E-01, -.46407100E-01, 0.75099700E-02, 0.11814400E+00, 0.52782500E-01, -.13927300E+00, -.34432400E-01, 0.39133300E-01, 0.61625900E+00, -.78954700E+00, -.65088300E+00, -.44291800E+00, -.23838500E+00, 0.34625500E-01, 0.22762300E-01, -.45487700E+00, 0.10547600E+00, 0.55414300E-01, 0.13884700E+00, 0.60162200E-01, 0.29116700E+00, 0.12905500E+00, 0.38719800E-01, -.26991200E+00, -.52937600E-02, 0.32940800E+02, 0.23594400E+01, -.19096000E+02, -.13158300E+02, -.20149300E+01, 0.68977900E+01, -.23013200E+02, 0.27866900E+02, -.12415700E+02, -.18056400E+02, -.13862100E+02, -.10865000E+02, -.83631000E+01, 0.48049800E+01, -.51087500E+01, -.32390200E+02, -.75349200E+01, -.12612300E+02, -.21773000E+02, 0.14917200E+02, 0.17575500E+02, 0.11074000E+02, -.28658600E+02, -.13842300E+02, 0.34090100E+01, 0.71398200E+01, 0.17533000E+02, -.83953500E+01, -.25257900E+01, 0.40460400E+01, 0.26099000E+01, 0.18809700E+00, -.18422800E+01, -.18734000E+01, 0.18787200E+01, 0.15078700E+01, 0.14606800E+01, -.90822500E-01, -.88522300E+00, -.10689000E+01, -.24413300E+00, 0.24462200E+01, 0.39287900E+00, -.56628900E+00, 0.14968200E+01, -.21140300E+01, -.11666600E+01, -.35028600E+00, 0.11235700E+01, 0.26493300E+01, -.16759600E+00, 0.21323300E+00, -.51145200E+00, -.23690600E+01, 0.22883000E+01 },
        { -.10413900E+02, 0.23591200E+01, 0.11066000E+01, -.42817400E+00, -.37175600E+00, -.85715900E+01, -.64944700E+01, -.13507800E+01, -.47079900E+01, 0.68230800E+01, 0.82878200E-01, -.29692500E+00, -.27081200E+01, -.30916400E+01, 0.66708300E+00, -.20556500E+01, 0.20475300E+01, 0.23037600E+01, 0.21147100E+00, 0.17093200E+01, -.13056100E+01, 0.15376900E+00, 0.92884300E-01, 0.62525000E+00, -.42159400E+00, 0.60553300E-01, 0.26689000E+01, 0.22036400E+01, -.37794500E+01, 0.30934200E+01, -.17029100E+01, -.31774000E+01, -.10616500E+01, 0.10555600E+01, -.48792200E-01, -.92892900E+00, 0.89820900E-01, 0.12363900E+00, 0.76498400E+00, -.20426500E+02, 0.18573300E+00, 0.80747200E+00, 0.97370900E+00, 0.14252800E+01, 0.10712500E+01, 0.43910600E+00, 0.15935800E+01, -.16945100E-01, 0.55731600E+00, -.41130200E+00, 0.76471100E+01, -.11254400E+01, -.18398300E+01, -.28298600E+01, -.39305200E+01, 0.17118200E+01, -.23135400E+01, -.70788500E-01, -.16936100E+00, 0.14547300E-01, -.11076900E+01, 0.50173500E+00, 0.57426300E+00, -.39477400E+01, 0.21663000E+01, -.89146600E-01, 0.72144000E+00, 0.20462200E+00, 0.61254300E+00, 0.17075200E+00, 0.15144700E+01, -.30997200E+00, 0.14071400E+00, -.19248200E+00, -.12731100E+00, -.19413200E+00, -.83251000E+00, -.24225400E+01, 0.26581600E+00, 0.73769400E+00, 0.35776400E+00, 0.34234500E+00, -.25287800E+01, -.57905500E+00, 0.73690100E+00, 0.19591600E+00, -.23296400E+00, 0.82417700E+00, -.15772600E+01, -.16957900E+01, 0.94460300E+01, 0.27116500E+00, 0.66980200E+00, 0.31876200E+01, -.69948000E+00, -.40467300E+01, 0.14508100E+01, -.13224000E+01, -.45540600E+00, -.42531500E+00, -.17813600E+00, -.85575600E+00, -.35060700E+00, 0.80811100E+00, -.53701400E+00, -.42882100E-01, -.18147300E+00, 0.59762300E+00, -.32258100E+01, -.78635800E+00, 0.12971800E+00, -.47220900E-01, 0.17646500E+00, 0.40972200E+00, 0.86713900E+00, 0.22921300E+00, 0.44543600E+00, 0.41589200E+00, -.32780800E+00, 0.17375900E+00, -.96746300E+00, 0.18231800E+01, 0.16598600E+00, 0.59830600E+00, -.49428900E-02, 0.14835300E+00, 0.21627300E+00, 0.20197800E+00, 0.45508800E+00, 0.35810500E+00, -.12278400E+01, 0.29207000E+01, -.85531300E+00, -.20261300E-01, -.21315500E+00, -.15073800E-01, -.12323800E+01, -.58085500E+00, -.81918900E-01, 0.17951400E+01, 0.27820300E+00, -.94859100E+00, -.22892100E+00, 0.24804900E+00, -.28456800E+00, -.48153700E+00, 0.81613100E-02, 0.32800200E+00, 0.42741200E+00, -.50740400E+00, 0.17413700E+00, -.17140500E+00, -.60025700E+00, 0.80213100E+00, 0.26961100E-01, 0.14658600E+00, -.36009100E+00, 0.31857800E-01, 0.21029200E+00, -.18062000E+01, -.53032000E-01, -.40216000E+00, -.18670200E+01, 0.15607800E+00, 0.14080100E+00, -.22964500E+00, 0.31111300E+00, 0.79712700E-01, 0.56793100E-01, -.87564700E-01, 0.95917700E-01, 0.92439400E+00, -.44973000E+00, -.24713300E+00, 0.55584500E+00, 0.11952200E+01, -.67961500E-01, -.12968200E+01, -.36358600E-02, 0.14940700E+01, -.40687200E+01, -.58984700E+00, 0.11816300E+01, -.34047500E+00, -.10373500E+01, 0.64030800E-01, -.28640400E+00, 0.80585100E+00, 0.34227000E-01, -.55916200E+00, -.46042600E-01, -.29650900E+00, -.35020900E+00, 0.83424400E+00, 0.11011600E+01, -.33829800E+00, 0.96720200E+00, 0.11603800E+00, 0.12355800E+00, -.20397300E+00, -.22884300E+01, 0.22664300E-01, 0.18106900E+00, -.82405800E-02, 0.10938600E+01, 0.93859700E+01, 0.23148000E+01, -.14906500E+00, 0.76883400E+00, 0.76985500E+00, 0.51492400E+00, 0.24220500E+00, -.68854700E-02, -.29168800E+00, 0.53960300E+00, -.27775500E+01, -.56602700E+00, -.14392200E-01, 0.26093600E+00, 0.16656200E+00, -.27298200E+01, 0.44519000E+00, -.62331200E-01, 0.32733200E-01, 0.41050000E+00, 0.72941700E-01, -.78616600E+00, 0.22484500E+00, 0.20177000E+00, 0.62942400E+01, -.13255500E+00, 0.14112700E+01, 0.76236300E+00, -.28516800E+00, -.45195800E-01, -.96047100E-01, -.21941200E+01, -.22440500E+00, -.37355000E+00, -.51026400E-01, 0.14080200E+00, 0.32487500E+00, 0.33710400E+00, -.12254900E+00, 0.15819300E+01, -.15864800E+00, -.64750400E+00, 0.74786900E+02, -.29690700E+03, -.38209600E+03, -.11265900E+03, 0.93189100E+02, 0.39499200E+02, 0.21176100E+03, -.99059200E+02, -.24875100E+03, -.11604600E+03, 0.22685000E+02, -.42654800E+02, 0.81451200E+02, 0.78917000E+02, -.21119800E+03, -.36650200E+02, -.11034800E+03, 0.20842200E+03, -.85218000E+02, -.10544400E+03, -.10570200E+03, -.46744000E+02, -.47698500E+02, -.40277900E+02, 0.34701000E+02, -.13092200E+03, -.22109900E+02, -.12934800E+03, 0.16939500E+02, -.38462300E+01, -.85461800E+01, -.10129700E+02, -.57720900E+00, -.10408000E+01, 0.78477500E+01, 0.15777500E+01, 0.54428400E+01, -.49334600E-01, -.10550200E+02, -.16088600E+02, 0.16230300E+02, 0.87379500E+01, -.17324700E+02, -.18259000E+01, 0.93037000E+00, -.18819700E+01, -.14100100E+02, 0.41374400E+01, -.18304100E+01, 0.27894800E+02, 0.17323700E+02, -.16764400E+02, -.33393100E+01, 0.14608000E+01 },
        { 0.24340100E+01, 0.10488400E+01, 0.67132500E-01, 0.81592800E+00, 0.15633200E+01, 0.14864100E+01, 0.92799500E+00, 0.26743400E+00, 0.10197300E+01, -.20984000E+01, -.50385600E-01, 0.10085900E+00, 0.35774900E-01, -.20442300E+00, 0.12241200E+00, -.12523100E+01, 0.67791400E-01, 0.37812900E+00, 0.55472800E+00, -.34172000E+00, -.76578100E-01, -.67718600E-01, -.19025600E+00, -.33379400E+00, 0.12593300E+01, 0.12225100E-01, 0.36187100E+00, -.10136400E+00, 0.11140400E+00, -.13749400E+01, 0.49349600E+00, -.77252300E+00, 0.15591500E+00, 0.29594100E+00, 0.15387900E-01, 0.26528900E+00, -.58805500E-01, 0.49194200E+00, -.34953300E+00, 0.51745900E+01, -.34417600E-01, 0.38152700E-01, -.32310300E+00, -.42594100E+00, 0.96990500E-01, -.47913100E-01, -.32095700E+00, 0.59652400E-02, -.28026500E-01, 0.34140500E+00, -.71303700E-02, -.10974200E+00, -.52201900E-01, -.11526900E+00, 0.54476900E+00, 0.91975500E-01, 0.29038700E+00, 0.65610000E-02, 0.39343700E-01, 0.28888000E+00, -.13418000E+00, 0.39060600E-01, -.11841300E+00, 0.27712800E+00, 0.12381600E+00, -.10442400E+00, -.54109300E+00, -.32278300E-01, -.95049100E-01, -.23602600E-01, -.67076700E-01, -.98681500E-01, 0.52551600E+00, -.45710100E-01, -.29796100E-01, 0.23591900E+00, 0.30637400E-01, -.18255700E+00, -.84645800E-01, -.19756700E+00, -.79580700E-01, -.73566100E-01, 0.10880800E+01, -.20151800E-01, -.60855400E+00, 0.23541500E+00, -.40571900E+00, 0.31723900E+00, -.19385000E+01, -.10812000E+00, -.48516300E+00, -.17581400E-01, -.15592400E+00, -.68469500E-01, -.45952400E+00, 0.10690300E+01, -.35763800E+00, -.76379100E-01, -.50644500E+00, -.54003100E-01, -.22230800E-01, 0.11062700E+00, -.14084400E+00, 0.34311700E-01, -.15582600E-01, -.62230000E-01, 0.20908300E+00, -.14332600E+00, 0.66988900E-01, 0.38240900E-01, -.94323700E-02, 0.37991300E-01, -.27887800E-01, -.12028000E+00, 0.31955600E+00, -.13418900E+00, -.70423200E+00, 0.16441000E+00, -.48539500E-01, 0.11690600E+00, -.13425600E-01, -.73289000E-01, 0.50085100E-01, -.12520200E+00, -.74129400E-02, 0.12536400E-01, -.66986100E-01, 0.22485400E+00, -.16085600E+00, 0.72021200E-01, -.62087400E+00, -.69715800E-01, -.56227400E+00, -.51959100E-02, -.10061300E+00, 0.99719400E-02, 0.30758600E+00, 0.47981600E-01, 0.96887900E-01, 0.71933600E+00, 0.48318700E+00, 0.32995700E+00, -.22648200E+00, 0.64989200E-01, 0.32732500E-01, -.99903100E-01, -.86643000E-02, 0.33258300E-01, 0.18645700E+00, 0.10524000E-02, 0.21727900E-01, 0.50923300E-01, 0.17045500E+00, 0.46294400E-01, -.27085000E-01, -.94691500E-02, 0.17147200E+00, -.11471000E-01, -.13101100E+00, 0.94279400E-01, 0.35428400E-01, -.10492600E+00, -.46609700E-01, -.43508700E-01, 0.14094000E+00, 0.65210700E-02, 0.23000900E+00, -.10032800E-01, -.54691900E-01, -.57852900E-04, 0.10273600E-01, -.36343900E+00, 0.41635500E-01, -.40324700E-01, -.82527100E-02, -.52253800E+00, 0.20017100E-01, 0.74181600E-01, -.78809700E-01, -.29909200E+00, -.11750000E+01, 0.34123100E+00, 0.85112200E-02, 0.28682500E-01, 0.18079700E+00, 0.50630800E-01, -.12165700E-01, 0.13289300E+00, -.20820600E-01, 0.19984200E-01, -.28246300E-02, -.18447500E+00, -.13437000E+00, 0.11283100E+00, 0.19954600E+00, -.10025100E-01, -.64936300E-01, 0.15581100E-02, -.18295500E-01, -.81926300E-01, -.25846100E+00, -.95314100E-02, -.16367300E+00, 0.12695100E+00, 0.28217500E+00, 0.27527100E+00, -.48011100E+00, 0.61560700E-01, 0.14002500E+00, -.92660200E-01, 0.46079300E-01, -.82583700E-01, -.68956400E-02, -.78634900E-01, -.41331900E-02, -.41759800E+00, 0.26268500E-01, -.36882200E-01, 0.11721300E+00, 0.35834000E-01, 0.11568700E+01, -.35983800E-02, -.62804200E-01, 0.22748900E-01, -.21788400E-01, 0.37869300E-02, 0.46836400E-01, -.60357000E-02, -.52459700E-01, 0.76975900E+00, 0.26023500E+00, 0.10139900E+00, 0.62041900E-02, 0.39761800E-01, 0.31765100E-01, 0.14566200E-01, 0.55419000E+00, 0.16160000E+00, -.17208300E-01, -.64297700E-02, -.11547900E+00, -.34684100E+00, -.48904800E-01, 0.23820700E-01, -.10827600E+00, 0.16113200E-01, -.11537400E-01, 0.25498700E-01, 0.29507200E+02, 0.48710600E+02, 0.67497700E+01, -.71273900E+01, -.21284500E+02, -.41275500E+02, 0.18984200E+02, 0.30327700E+02, 0.22112900E+02, 0.34549600E+00, 0.89537300E+01, -.14039900E+02, -.14273400E+02, 0.36917700E+02, 0.76047400E+01, 0.26197800E+02, 0.22018600E+01, -.42429900E+01, -.31646700E+01, -.73469600E+00, 0.18549600E+02, 0.12678200E+02, -.38500200E+01, -.16280600E-01, 0.10185800E+02, 0.48534800E+01, -.56991800E+01, -.38561000E+01, -.21543000E+00, 0.12506500E+00, 0.18384500E+01, 0.16473100E-01, -.13008200E+01, -.15391700E+01, -.23338700E+00, -.49694200E+00, 0.11215600E+01, 0.41940000E+00, 0.94663400E+00, -.32722400E+01, -.16528200E+01, 0.12145300E+01, -.11601500E+01, 0.12782200E+01, 0.11504900E+01, 0.49579400E+00, -.10008800E+01, -.34242700E+00, 0.11041500E+01, -.11473300E+01, -.47616800E+00, 0.13534400E+01, -.14322100E+01 },
        { -.31330300E+01, -.21573800E+01, -.31404700E+00, -.39806300E+01, -.18572700E+01, 0.53206700E+01, -.70321700E+01, 0.18012100E+01, -.11221100E+01, 0.28405200E+01, -.18175700E+00, 0.27633700E-01, -.30539300E+01, 0.35172700E+01, -.17286200E+01, -.31674700E+01, -.91351700E+00, 0.33599700E+01, -.12704200E+01, -.68461300E+00, -.61329000E-01, 0.21962500E+00, -.56983300E+00, 0.70514400E-01, -.39581700E+01, 0.10863600E+00, -.13211200E+01, -.33982600E+01, 0.16670800E+01, -.12174600E+01, 0.46276600E+00, -.12097900E+01, -.89136300E+00, 0.24486000E+01, 0.10209500E+01, 0.54728400E+00, -.14996000E+00, 0.21355900E+01, 0.26953800E+00, 0.20145600E+01, -.16876100E+00, 0.20538000E+00, -.33413900E+00, -.89424100E+00, 0.28035100E-01, -.17997300E+00, -.87079600E+00, 0.17744300E-01, -.29984600E-01, 0.31455000E+00, -.19572800E+01, 0.36230300E+00, 0.10663200E+01, 0.14837200E+01, 0.22434800E+01, 0.29246600E+00, 0.11348200E+01, 0.30563700E-01, 0.96111200E-01, 0.28730600E+00, 0.76557500E+00, 0.19479700E+00, -.85288700E-01, 0.86296700E+00, -.40322100E+00, -.29875800E-01, -.10964900E+01, 0.46955200E+00, -.22169400E+00, -.83928400E-02, 0.13677100E+01, -.11621900E+00, 0.17770200E+01, 0.44075500E+00, -.28309400E+00, 0.44116200E+00, 0.26572500E+00, 0.60290400E+00, -.14208700E+00, -.69083000E+00, -.19234600E-01, 0.49336500E+00, 0.12282100E+01, 0.57339400E+00, -.23333200E+01, -.17161400E+00, 0.86617600E+00, 0.13406500E+01, -.20644300E+01, -.30829900E+00, 0.30495700E+01, 0.18992500E-01, 0.27637800E+00, 0.48120600E+00, -.14141700E+01, 0.58774900E+00, -.17653900E+00, 0.10830900E+01, -.96948000E+00, -.28219900E+00, -.23542900E+00, 0.33546700E-01, -.35057000E+00, 0.79724400E+00, -.84350600E+00, -.42040300E+00, -.11862100E+00, -.67248500E+00, 0.64022200E-01, 0.13731400E-01, 0.42744400E+00, -.91006100E-01, 0.73368500E-01, 0.11842600E+00, -.14034200E+00, 0.21204100E+00, 0.84991300E-01, 0.57987800E+00, 0.15099900E+00, -.24357300E+00, -.18331800E+00, -.25407300E-01, 0.25553900E-01, 0.18397300E+00, 0.12167100E-01, 0.93862900E-01, -.68783200E-02, 0.94560200E-01, 0.64709500E+00, 0.31642300E+00, -.88527800E+00, -.59097200E-01, 0.11601600E+00, -.10409100E-01, 0.15021100E+00, -.72595800E-02, -.65766100E+00, -.14363300E+00, 0.12381800E+00, -.56629500E+00, 0.60683600E-01, -.13313600E+01, 0.15218900E+01, 0.52149100E+00, 0.34893800E-01, -.50722400E+00, -.16339300E-01, 0.81427500E-01, 0.24459900E-01, -.93208000E+00, -.19026400E+00, -.22816100E+00, -.15961100E+01, 0.51781800E+00, -.27720100E+00, -.81551100E-01, -.73708000E+00, 0.52190400E-02, 0.59965500E-01, -.14995300E+01, -.71327800E-02, 0.55568600E+00, -.12583900E+01, 0.14221600E+00, -.16902100E+00, 0.80073400E-01, 0.20677400E-01, -.16993000E+00, 0.52927100E-01, 0.12406000E+00, 0.82608100E-01, 0.12547500E-01, -.14354200E+00, 0.34803000E+00, 0.43471400E-01, 0.11992100E+01, -.25194400E+00, -.61311000E+00, 0.31755400E+00, 0.41832300E+00, 0.13233700E+01, -.79019800E+00, -.33165400E+00, -.16766800E+00, -.80692900E+00, -.19054700E+00, -.12326800E+00, 0.61043800E+00, 0.22887700E+00, -.54264600E-01, 0.13459100E-01, -.13921400E+00, 0.56290000E-01, -.49770400E+00, 0.10958800E+00, -.63812000E+00, 0.45572000E+00, 0.34701200E+00, 0.21689800E+00, 0.20564500E+00, -.96115500E+00, -.64262700E-01, 0.45066600E+00, -.24399000E+00, 0.24959500E+00, 0.70925200E+01, 0.28064300E+01, 0.12440400E+00, 0.14897600E+00, 0.73730500E+00, 0.94382700E-01, 0.41355200E-01, -.48541900E-01, 0.79942900E-01, 0.24056000E+00, -.12688300E+00, -.18899100E+00, -.25118600E-01, -.32271400E+00, 0.28789200E-01, -.20647900E+01, 0.57234800E-01, 0.24097600E+00, -.83147100E-01, 0.73411300E-01, 0.12718600E-01, -.12985500E+00, 0.10397300E+00, 0.14021300E+00, 0.14632900E+01, -.79014800E-02, -.80723000E+00, 0.18793600E+00, 0.16220800E+00, -.30741000E-01, 0.53198800E-02, -.54335200E+00, -.23520300E+00, 0.16411400E+00, -.18860100E-01, 0.16281900E+00, 0.58662700E+00, -.65757300E-01, 0.12649200E+00, -.61393300E+00, 0.43688300E-01, 0.12793000E+00, -.25570100E+00, -.62305800E+00, 0.39824800E+02, 0.32087500E+02, -.99505900E+01, -.11084300E+02, -.61592800E+02, 0.29610100E+02, 0.11089800E+02, 0.30828900E+02, -.52330500E+01, 0.88726400E+01, -.16337400E+02, -.23832600E+02, 0.43442800E+02, 0.78718400E+01, 0.27745700E+02, -.12556200E+03, 0.61187400E+02, 0.28258100E+01, 0.63036000E+02, 0.17590600E+02, 0.20989300E+02, 0.36292400E+01, -.30631900E+02, 0.47150100E+02, 0.10543700E+02, 0.85086200E+02, -.12081200E+01, 0.21501300E+01, 0.90016200E+00, 0.15728500E+01, 0.33178800E+01, -.77491400E+00, -.23679200E+01, 0.10737100E-01, -.76577200E+00, 0.15623100E+01, 0.11033500E+01, 0.19179700E+01, -.14175700E+01, -.73401100E+00, 0.23112200E+01, 0.71789100E+00, -.14760700E+01, 0.11318300E+01, 0.22051000E+01, -.19024600E+01, 0.35629300E+00, 0.26829400E+01, -.21283400E+01, -.17869500E+01, -.67617500E+00, 0.19877300E+01 },
        { 0.23940600E+02, -.31023000E+01, -.11284600E+01, -.18109700E+01, 0.40326600E+01, 0.17401300E+02, 0.19436100E+02, -.53193100E+00, 0.13527800E+02, -.17873700E+02, 0.87378000E-01, 0.14798000E+01, 0.61414900E+01, -.63820900E+01, 0.71563100E+00, 0.13640100E+01, -.49649700E+01, -.63927800E+01, 0.30423700E+01, -.33807300E+01, 0.11669200E+01, -.26725400E+00, 0.15003100E+00, -.12422400E+01, 0.17988100E+01, 0.40551700E-01, 0.35319300E+00, 0.14706600E+01, 0.16545500E+01, -.19689400E+01, 0.56984100E+00, 0.50240100E+01, 0.30045200E+00, -.35488100E+01, -.25214300E+01, 0.98478200E+00, -.93305400E+00, -.18907400E+01, -.57965200E+00, 0.17514100E+02, -.85286200E-01, 0.12285200E+01, -.50816500E+01, -.22692700E+01, 0.11880600E+01, -.65203700E+00, -.85141000E+00, 0.19894000E+00, -.11372200E+00, 0.12795500E+00, -.33056600E+01, -.16626900E+01, 0.37116200E+00, 0.31617500E+01, -.57094500E-01, -.23177700E+01, 0.75033600E+00, -.80155200E+00, 0.35055700E+00, 0.80182500E+00, 0.16234200E+01, 0.14643500E+01, 0.14436200E+01, 0.20781000E+01, -.16381400E+01, 0.17344700E+00, -.82665200E+00, 0.35074800E+00, -.42579500E+00, 0.81394400E-01, -.14103100E+01, -.36013800E-01, 0.70874400E+00, -.27459500E+00, 0.13943600E+00, -.83809600E+00, 0.37701900E+00, 0.58611600E-01, -.12579300E+01, 0.14629200E+01, -.50041000E-01, 0.48561900E+00, -.22221900E+01, -.25384900E+00, 0.16573800E+01, 0.80779200E+00, -.43337100E+01, 0.25889000E+00, 0.33112400E+01, 0.73128900E+00, -.10341000E+02, -.80021400E-01, -.92711400E+00, -.26841000E+01, 0.22385500E+01, -.13827300E+00, -.50073000E-01, 0.29875100E+01, 0.23697000E+01, -.52787300E+00, -.19327000E+01, 0.13408900E+01, 0.22802700E+01, -.14326100E+01, -.15755400E+00, 0.70779300E+00, 0.91365200E+00, 0.39552300E+01, 0.12047100E+00, 0.77293400E+00, 0.19198800E+01, -.55098400E+00, -.49629500E+00, 0.67266000E+00, -.19768900E+01, -.25590600E+01, 0.19406000E+00, -.24119000E+01, 0.21863900E+00, -.81995600E+00, 0.19126800E+01, -.23628600E+01, -.67490900E-01, -.16010100E+01, -.86046500E-01, -.16825500E+01, 0.16223200E+00, 0.32094300E+01, -.59708200E+01, -.15016100E+01, 0.84223700E+01, 0.17032300E+00, 0.31332200E+01, 0.68113600E-01, -.20923200E-01, 0.54315600E-02, 0.25916100E+01, 0.11689900E+01, -.48998200E+00, -.50173400E+00, -.10574600E+01, 0.18983600E+01, 0.48210900E+00, 0.21902100E-01, 0.15990600E+00, -.61285300E+00, 0.92357600E-01, -.75916800E+00, -.17233800E+00, -.53034100E+00, -.84203700E+00, 0.54022300E+00, -.37221000E+01, -.12441800E+01, 0.31463300E+00, -.70922400E+00, -.43723800E+01, -.19039500E-01, 0.66726100E+00, -.13619600E+01, 0.38964500E+00, 0.21614800E+01, 0.31826000E+01, 0.69906300E+00, -.15300300E+01, 0.13324100E+01, -.34638700E+01, 0.98681000E+00, 0.24964400E+00, -.85260400E-01, -.95618100E+00, 0.19036500E+01, -.58598100E+00, 0.78168900E+00, -.18555700E+01, -.73644200E+01, -.36335400E+00, -.16817100E+01, -.15974200E-01, 0.35696500E+01, 0.97200300E+01, -.18365800E+01, 0.34674500E+01, -.34386000E+00, -.16814400E+01, -.41184900E+00, 0.35258700E+00, -.53756400E+01, 0.55038100E+00, 0.12742200E+01, 0.33884000E-02, 0.23560700E+01, 0.14357700E+01, 0.12066700E+01, -.68971000E+01, -.78826200E+00, -.40292800E+01, -.26543000E+01, 0.68782600E+00, 0.10117100E+00, 0.23221000E+01, 0.58777200E+00, -.84156600E+00, -.24694600E+01, -.37301300E+01, -.37722500E+02, -.20793900E+01, 0.48273300E+01, -.25291500E+01, -.70714900E+01, 0.21727000E+00, -.18637200E+01, 0.15399600E+00, -.56852500E+00, -.27869300E+00, -.42403700E+01, 0.69416000E+00, 0.30245200E+00, 0.15737200E+01, 0.24245200E+00, -.16857400E+01, -.86422800E+00, 0.44175600E+00, -.11906600E+00, 0.19773700E+00, 0.47749200E+00, 0.44774300E+00, 0.29944000E+00, 0.20994300E+00, 0.17926600E+01, 0.44826500E+00, 0.12854100E+01, -.64396600E+00, 0.43484800E+00, -.27719500E+00, 0.40600000E-01, 0.11715300E+00, -.14642500E+00, -.10758500E+00, -.40460200E+00, 0.40457400E+00, 0.65812100E+00, -.38265600E+00, 0.10950400E+01, 0.19717900E+01, 0.56050100E+00, -.10561800E+01, -.52321600E+00, 0.34214100E+01, -.42350400E+01, 0.12338400E+03, -.64632900E+01, -.42236000E+02, -.93641400E+02, 0.47220900E+02, -.65866300E+02, 0.41303700E+02, 0.48681900E+01, 0.46740700E+01, -.10986200E+02, -.25102400E+02, 0.47444500E+02, 0.11477600E+02, 0.23597300E+02, -.56380000E+03, 0.28438400E+03, 0.99420800E+00, 0.28046200E+03, 0.41577400E+02, -.28033700E+00, 0.10160400E+03, -.97229000E+02, 0.19282500E+03, 0.21608600E+01, 0.32152600E+03, 0.96681400E+01, 0.72268700E+01, 0.33146000E+01, 0.10082500E+01, 0.14708200E+02, 0.24751800E+01, -.25988500E+01, -.12255200E+01, -.70615700E+00, 0.17784800E+01, 0.50823000E+01, 0.58924500E+01, 0.72444600E+01, 0.56864800E+01, 0.68283300E+01, 0.79945200E+01, -.10755900E+02, 0.38344900E+00, 0.78228300E+01, -.21242000E+01, -.12403500E+01, 0.37953500E+01, -.59674300E+01, -.15146900E+01, -.33323800E+01, 0.68164500E+01 },
        { 0.20603000E+02, -.97289000E+01, -.16521400E+01, -.43353500E+01, 0.38080400E+01, 0.86112200E+01, 0.18891600E+02, -.49315300E+01, 0.13057700E+02, -.14551400E+02, 0.48569800E-01, 0.18291600E+01, 0.31616200E+01, -.58920400E+01, 0.27577500E+01, 0.53402800E+00, -.38369000E+01, -.21115000E+01, -.16241800E+01, 0.30126600E+01, 0.28176900E+01, -.68651600E+00, 0.79413400E+00, 0.39772900E+00, -.19202300E+01, -.30373800E+00, -.15967600E+01, -.99579200E-01, -.37469500E+00, -.62769400E+00, -.82446800E+00, 0.26050400E+00, -.23648600E+01, -.30303000E+01, -.13280800E+01, 0.22612600E+00, 0.73217800E+00, -.10175700E+01, 0.11575600E+00, -.91552500E+00, 0.81865000E-01, 0.48467700E+00, 0.61797900E-01, -.23654800E+01, -.20134100E+01, -.56990800E+00, -.46618500E+00, 0.11645800E-01, -.42559300E-02, -.87860700E+00, -.50454500E+00, 0.77758400E+00, 0.11101800E+01, 0.26316300E+01, 0.13962200E+01, -.66505500E+00, 0.30308100E+01, -.82536900E-01, -.12143200E+00, 0.16920500E+01, -.11125300E+01, -.67855300E+01, -.46844700E+01, 0.73164400E+00, -.22153800E+01, -.19807800E+00, -.22635700E+01, -.10702700E+01, -.98222500E+00, 0.26467400E-02, -.15810800E+01, 0.48375700E+00, 0.70897300E+01, -.23121600E+00, 0.51210200E+00, 0.22144900E+01, 0.17583500E+00, -.40295800E+00, -.69900200E+00, 0.20525700E+01, -.34273000E+00, -.27724000E+00, -.34639900E+01, -.58731100E+00, 0.52401900E+01, -.27231900E+00, -.15656700E+00, -.13589300E+01, 0.12451900E+01, 0.10699900E+01, -.58127000E+01, -.16985900E-01, -.66564000E+00, -.31321500E+01, -.37746700E+01, 0.92570700E+00, 0.60914800E+00, 0.46138300E+01, -.84531500E+00, -.10861000E+01, -.11907800E+01, -.73056100E-01, 0.34754200E+01, 0.68366500E+00, 0.10442700E+01, -.54046300E+00, 0.14267100E+01, 0.32187200E+01, -.40002100E+00, 0.69304500E+00, -.58689100E+00, -.79445600E-01, 0.57105600E-01, 0.26955300E+00, -.19008600E+00, -.30053000E+01, 0.33474000E+00, 0.14003200E-01, 0.28548500E+00, -.34089500E+00, 0.53083800E+00, 0.87685900E+00, 0.35111600E+00, 0.22007000E+00, -.10811600E+00, -.10998200E+01, -.10753400E+00, 0.17394600E+01, -.25821400E+01, -.80672900E+00, 0.15991900E+01, 0.57519600E+01, -.20597600E+01, 0.57873800E-02, -.12400800E+00, -.90323700E-03, 0.82790300E+01, -.37284400E+00, 0.18384600E+00, 0.31742300E+01, 0.29044900E+00, -.12180400E+01, 0.10957300E+01, 0.85722000E+00, 0.24287700E+00, -.16420300E+01, 0.37744600E+00, -.20069300E+00, 0.96297300E+00, -.15415200E+01, -.90586800E+00, -.29395400E+00, -.18781900E+01, -.17747200E+00, -.45243000E+00, 0.12628800E+00, -.39090900E+01, 0.14324200E+00, -.27362600E+00, -.23796600E+01, 0.31719200E+00, 0.14800400E+01, -.74685600E+00, 0.76709400E+00, -.89465700E+00, 0.16170300E+00, -.15994400E+01, 0.23844100E+00, -.26363200E-01, 0.23634100E+00, -.31199600E+00, 0.15641700E+01, -.10842300E+01, 0.41210100E+00, -.24063700E+01, 0.40715600E+01, -.92677900E+00, -.18708400E+01, 0.38487700E+00, 0.53890600E+01, -.31294400E-02, -.23364600E+01, 0.48874100E+01, -.77481500E+00, -.64192900E+00, -.13811700E+01, -.39801700E-01, -.26007900E+01, -.13939900E+00, -.56045100E+00, -.51367600E-01, -.40358100E+01, -.10435900E+01, -.23775800E+01, -.31966700E+01, -.16337500E+01, -.12996500E+01, 0.29220600E+00, 0.15830400E+01, -.46858000E-01, -.18938500E+01, 0.77759000E+00, -.14094000E+01, -.15309400E+01, -.88952300E+00, -.27218000E+02, -.63493600E+00, 0.68053600E-01, 0.41183500E+00, -.32356000E+01, -.91367700E-02, -.10475900E+01, 0.70021700E-01, 0.36774000E+00, 0.79850100E+00, -.54507500E+01, -.30632600E+00, 0.90881400E-01, 0.15710900E+01, 0.74401400E+00, 0.23841800E+01, -.11871900E+01, -.11537100E+01, 0.40637800E+00, 0.39054900E+00, -.24042400E-01, 0.29330700E+00, 0.55833300E+00, -.27557500E+00, -.92758700E+01, 0.59936300E+01, 0.79936800E+01, 0.29105800E+01, 0.21046500E+01, -.49407100E+00, -.21279600E+00, -.33716400E+01, -.38613700E+01, -.11748000E-01, -.15600200E+01, 0.12443300E+01, 0.43854400E+01, 0.52903900E+00, -.49055100E+00, -.84330200E+00, -.41206000E-01, -.26126800E+01, 0.35634300E+00, 0.64742000E+01, 0.95848400E+00, -.25853400E-01, 0.34712700E+02, 0.28370000E+02, 0.18658200E+03, -.90823300E+02, 0.93701500E+02, -.97338500E+02, 0.81867700E+02, -.72295300E+01, 0.66342200E+02, 0.13134800E+03, -.12301700E+03, 0.18809400E+02, -.11975800E+03, -.14166000E+02, 0.34246300E+02, 0.87083700E+02, 0.43428700E+01, 0.89818700E+02, -.90027800E+02, 0.16142300E+03, -.34848700E+02, -.33484800E+03, 0.52484900E+01, -.96118900E+02, -.35699500E+01, -.19939400E+02, 0.15645200E+01, -.56264500E+01, -.21744500E+00, -.39752900E+00, 0.43334800E+01, -.14955500E+02, 0.67721500E+01, -.56464300E+01, 0.42062800E+01, 0.55336900E+01, 0.50664700E+01, 0.10801100E+02, 0.57653900E+01, 0.31056900E+01, 0.17722400E+01, -.12020500E+02, 0.58601500E+01, 0.30661100E+01, -.20145200E+02, -.84879400E+01, -.48851700E+01, 0.18198500E+01, 0.18045900E+02, 0.64123500E+01 },
        { -.88120200E+01, 0.34066400E+01, 0.62598600E+00, 0.35924900E+01, 0.25193000E+00, -.16296700E+02, -.10778800E+01, -.12170500E+02, -.34665200E+01, 0.61110700E+01, 0.10473400E+01, -.16753200E-01, -.32879100E+00, -.55646900E+01, 0.90984200E+00, -.30864700E+01, 0.29707400E+01, 0.25251400E+01, -.40417100E+00, 0.69709900E+00, 0.67049400E+00, -.31483000E+00, -.12824800E+00, -.80076900E+00, 0.81073700E+01, 0.15811000E+00, 0.12402000E+01, 0.20863000E+01, -.40484700E+01, 0.16310400E+00, 0.18402900E+00, -.31898900E+01, 0.30541900E+01, 0.34627400E+01, 0.12485400E+01, -.86333800E+00, 0.38567500E+00, 0.94306700E+00, -.16052500E+01, -.23111100E+02, 0.86433400E+00, -.38501700E+00, 0.36478500E+01, 0.63806000E+00, -.51921300E+00, -.39008200E+00, 0.83201500E+00, -.96325600E-01, -.57373700E+00, 0.18796500E-02, -.18558400E+01, 0.10350300E+01, 0.40024900E+00, 0.11534600E+01, -.20355800E+01, 0.15801500E+00, -.18792700E+01, 0.43899700E+00, -.35987000E+00, -.59544400E+00, 0.14356900E+01, -.11532800E+01, 0.89691600E-01, 0.18237400E+01, -.85286700E+00, 0.68881500E+00, 0.29946600E+01, -.20504700E+00, 0.48997000E+00, -.35237100E+00, 0.15258600E+01, -.47155600E+00, -.16684700E+01, 0.86803700E-01, -.91235300E+00, 0.17915000E+01, -.13072500E+01, 0.34813100E+01, 0.23533900E+01, -.18628700E+01, -.84438300E-01, 0.23580300E+00, 0.17665500E+01, 0.54296600E+00, -.36541900E+00, 0.47575300E+00, -.20782600E+01, 0.55124600E+00, -.11678400E+01, 0.43370900E-01, 0.16097300E+01, 0.46118200E-01, 0.12810000E+01, -.86640300E+00, -.73239500E+00, 0.19723600E+01, -.65901000E+00, 0.15294000E+01, 0.63313100E+00, -.34902500E+00, 0.86857000E-01, 0.94214000E+00, -.60950500E+00, 0.64922900E+00, -.16638700E+01, -.23971500E+00, -.13757000E+01, -.20749900E+01, -.54497300E+00, -.72936300E-01, 0.23673000E+01, -.33589800E+00, 0.26891500E+00, 0.78198000E+00, -.25367900E+01, 0.37744300E+00, -.16518200E+01, 0.11445400E+01, 0.32484900E+00, 0.39952300E+00, -.12837100E+01, 0.36664800E+00, -.61984100E-01, 0.14340000E+01, 0.27259300E-01, 0.54405300E+00, 0.37404600E+00, -.58389500E+00, 0.15889700E+01, 0.90119300E+00, 0.25617700E+01, -.15607100E+01, 0.36575300E+01, 0.51552400E-02, 0.18669300E+00, -.41636700E-01, -.32100300E+01, -.13286400E+01, 0.55757900E+00, -.66640500E+01, -.26772000E+01, -.35803300E+01, 0.15039900E+01, 0.11086700E+01, -.33262800E+00, -.83555200E+00, -.35407400E-03, 0.70698400E+00, -.18644500E-01, -.21409800E+01, 0.90207400E+00, 0.18153000E+01, 0.50816600E+00, 0.14524600E-01, 0.12226000E-01, -.21555800E+00, -.14546800E+01, -.65149100E-01, -.48656300E+00, 0.10923600E+01, -.13013300E+00, 0.16629400E+01, 0.81289500E+00, 0.18863900E+00, 0.53228600E+00, 0.76782300E+00, -.87273100E+00, -.10059200E+01, 0.23633300E+00, 0.36710500E+00, 0.37294100E+00, 0.13752300E+00, -.44165700E-01, 0.70842100E+00, -.10039600E+01, 0.80258700E+01, -.40337800E+00, -.11339200E+01, -.48014000E+00, 0.22314300E+01, 0.51356500E+01, -.20940800E+01, -.69609500E+00, -.95634800E+00, 0.89998200E+00, -.71674200E+00, -.53942700E+00, -.10984000E+00, 0.20363400E+00, -.88776800E+00, -.16804000E-01, -.14447200E+01, -.95368400E+00, 0.92998700E+00, -.82672800E+00, -.99052700E+00, 0.69784700E+00, 0.26567600E+00, 0.86581500E+00, -.51439900E+00, -.17030300E+01, 0.21422300E+00, -.58628600E+00, 0.17961100E+00, -.50400700E+00, 0.61888300E+01, 0.61906600E-01, 0.15845100E+01, 0.88005700E+00, 0.77486100E+00, 0.59739300E-01, 0.60709800E+00, 0.85958300E-01, -.11193000E+00, -.61645400E+00, 0.20954600E+01, -.23902800E-02, 0.97907200E-01, -.42587700E+00, 0.22848300E+00, -.28030900E+01, 0.65593800E+00, 0.26007300E+00, -.11920300E+00, -.33846800E+00, 0.20299900E-01, 0.13863600E+00, 0.40795800E-01, -.11298100E+00, 0.38281100E+00, 0.12560300E+01, -.47959400E+00, 0.15198000E+00, 0.71460800E+00, -.64631400E-01, -.13550500E+00, 0.10214300E+01, -.56583700E+00, 0.70807000E-01, -.11218300E+00, 0.46482300E+00, 0.11407100E+01, 0.23136100E+00, 0.18999500E+00, -.14132000E+01, 0.67233200E-01, -.10289500E+01, -.58479500E-02, 0.23177700E+01, 0.10562800E+01, -.69540000E-01, 0.31517700E+00, 0.21924900E+03, -.30209700E+02, 0.17380200E+02, 0.15137100E+02, 0.16024900E+02, -.10879200E+02, 0.10098800E+02, -.25267600E+02, -.31876700E+02, 0.10725100E+01, 0.32204500E+01, -.11751800E+02, -.49503700E+02, 0.23096900E+02, 0.23093900E+01, 0.24921100E+02, -.79547300E+02, -.21024400E+02, 0.33945700E+00, 0.12710300E+02, 0.78318100E+02, -.22595800E+02, 0.14132700E+03, 0.26796300E+01, 0.41131100E+01, 0.33425600E+01, -.33719300E+00, -.42020900E+01, 0.55949200E+01, 0.10562900E+00, 0.20831300E+01, -.16373900E+01, -.25078800E+01, 0.15490000E+00, 0.78458000E+01, 0.35715600E+01, -.34025100E+00, 0.73642600E+01, 0.12919100E+01, -.14476900E+01, 0.20470000E+00, 0.92612800E+01, -.20088300E+00, 0.72259800E+01, -.68840200E+01, -.77386200E+01, 0.29826200E+01, -.68654600E+01, 0.54851700E+01 },
        { -.59264300E+01, 0.22375700E+01, 0.26539400E+00, 0.16526400E+01, -.17764000E+01, -.67365600E+01, -.11715200E+01, -.67845500E+01, -.21398700E+01, 0.44424700E+01, 0.50241700E+00, -.19870800E+00, -.73343100E+00, -.37002500E+01, -.20688800E+01, -.38941100E-01, 0.82713500E+00, -.10665200E-01, 0.96677900E+00, -.22537900E+01, 0.71972800E+00, -.33556500E+00, -.18338900E+00, -.88906100E+00, 0.51045500E+01, 0.85400600E-01, 0.16071500E+01, 0.21330600E+00, -.19484700E+01, 0.13964100E+00, 0.25539400E-02, -.26788800E+00, 0.11855300E+01, 0.28058400E+00, 0.19542300E+00, -.48560900E+00, 0.14132200E+00, 0.77829200E+00, 0.63817800E+00, 0.18485200E+01, 0.12747600E+00, 0.38496300E+00, 0.10488800E+01, 0.81639700E-01, 0.23356600E+00, 0.18110900E+00, 0.52334700E+00, 0.80974000E-01, -.38463200E+00, -.25326700E-01, -.13439500E+01, 0.18324000E+00, -.24007700E+00, 0.34720500E+00, 0.57030000E+00, -.55993000E+00, -.34407200E+00, -.39401100E-01, 0.18456700E+00, -.49024400E+00, 0.34636600E+00, -.87128300E+00, -.58747000E+00, -.56713600E+00, -.37803900E+00, 0.55006300E-02, -.20477200E+00, -.42471100E-01, -.18413600E+00, -.13508800E+00, 0.11518400E+01, 0.28922800E+00, 0.34125600E+00, 0.66523100E-01, -.13990400E+01, 0.28921400E-01, -.88216600E+00, 0.31395600E+00, 0.36002900E+00, -.10689700E+01, -.15757400E+00, 0.12293400E+01, 0.11762800E+01, 0.69493500E+00, -.41814400E+01, 0.19571200E+00, -.26691500E+00, 0.31804100E+01, -.11809900E+01, -.20306400E+01, 0.76508800E+00, 0.62739400E-01, 0.21372000E+00, 0.25298700E+00, -.49024800E+00, 0.17165700E+01, -.53547800E+00, -.36550000E+00, -.35195300E+00, -.43496900E+00, -.14994800E+00, -.19473000E+00, -.54552200E+00, 0.14700900E+01, -.12718100E+01, 0.92604600E+00, 0.82953900E+00, 0.46052300E+00, -.20757900E+01, -.59381500E+00, 0.13871300E+01, -.42388500E+00, -.87432800E-01, 0.71029900E+00, 0.12445300E+01, -.69765200E+00, 0.77468200E+01, 0.12976100E+00, -.86474200E+00, -.11609300E+01, 0.64781900E-01, 0.16848000E+00, 0.14493300E+00, -.13172500E+01, -.12829600E+00, -.30000500E+00, -.95924500E-01, 0.94369400E+00, -.13572100E+01, -.67508200E+00, -.97862800E+00, -.16882100E+01, 0.10868100E+01, -.25605100E-01, -.63892000E-01, 0.10918100E-01, -.98530200E+00, 0.34370400E-01, 0.40348100E+00, 0.60299600E+01, 0.67069700E+00, 0.46385700E+00, 0.18225600E+01, 0.86645100E+00, 0.70180300E-01, -.12624500E+01, 0.34412300E-02, -.35606100E-01, 0.30189100E-01, -.10057500E+01, -.29419800E+00, 0.65620300E+00, -.12591400E+01, 0.19061800E+00, 0.22355600E+00, -.18215000E+00, 0.14652300E+01, 0.43226400E-02, 0.38704200E+00, -.60907600E+00, -.11801100E+00, -.45026200E+00, -.11412500E+01, 0.18396900E+00, 0.40383800E+00, -.37973900E-01, 0.14867700E+00, -.86632900E+00, -.41129300E-01, -.13255400E+00, 0.21258800E+00, -.28329900E+00, -.33637400E+00, -.26613100E+00, 0.23407600E+00, 0.14338600E+01, -.38575100E-01, -.44667500E+00, 0.18814500E+00, -.21451200E+00, -.53458200E+01, 0.46140400E+00, -.12752800E+01, -.37972700E+00, 0.19986900E+00, 0.28860600E+00, -.11469600E+00, 0.13802200E+01, 0.19485800E+00, -.37079500E+00, -.56585400E-01, 0.17477700E+00, 0.10545500E+00, -.12699200E+01, 0.23573000E+01, 0.10220000E+01, 0.34189200E+00, 0.79949200E+00, -.16731100E+00, 0.21607500E+00, 0.26788500E+00, -.15131100E+00, 0.30922400E+00, 0.15437700E+00, 0.15518200E+00, 0.36099300E+01, 0.66142200E+00, -.98391000E+00, -.45637600E+00, 0.10150400E+01, -.13084500E+00, 0.67172000E+00, -.14638300E-01, 0.50016100E+00, -.18348000E+00, 0.24285700E+01, -.29404400E+00, 0.77349900E-01, -.78788600E+00, -.18422700E+00, -.85453500E+00, 0.15923400E+00, 0.23880500E+00, -.10771300E+00, 0.16782900E+00, -.25620400E+00, -.24977700E+00, 0.25317600E-01, 0.10071400E+00, 0.21452900E+01, -.80344300E+00, -.93933200E+00, 0.63442600E+00, -.27979700E+00, 0.28894700E-01, 0.45589900E-01, -.11337400E+01, 0.28766300E+00, -.10844800E-02, -.97498900E-01, -.12478000E+00, -.11497600E+01, -.38334800E-01, -.27420600E+00, 0.78009400E+00, -.14831300E+00, -.22181800E+00, 0.29730200E+00, -.41878300E+00, -.33069800E+00, 0.55383300E-01, 0.33258100E-01, -.40271700E-02, -.67019800E+02, 0.31726300E+02, -.23491400E+02, 0.33382300E+02, -.10035200E+02, -.14203900E+00, -.11776500E+01, -.33435800E+02, 0.18369600E+02, -.23164400E+01, 0.81197500E+02, -.14151500E+03, 0.67084400E+02, -.34272500E+01, 0.70713300E+02, 0.32966600E+02, 0.37804300E+02, -.22631800E+02, -.50116800E+02, 0.47704100E+02, 0.21414000E+02, 0.93511800E+02, 0.21508700E+00, 0.12844400E+01, 0.33282700E+00, 0.21568000E+01, 0.50904400E+01, -.13832000E+01, -.89182500E+00, 0.11994300E+01, -.83923600E+00, 0.14120400E+01, -.19613100E+01, -.39627200E+01, -.21312400E+01, -.19002500E+01, -.33838600E+01, 0.92290900E+00, -.19983600E+01, 0.26778700E+01, -.26228900E+01, -.12375600E+01, 0.81982800E+00, 0.62736200E+00, 0.39916900E+01, -.81952200E+00, 0.10371600E+01, 0.32653100E+01 },
        { -.77725900E+01, -.85421900E+01, -.96727800E+00, -.40990900E+01, -.26073700E+01, -.13138300E+01, -.79441700E+01, -.79860900E+00, -.42694300E+01, 0.72041200E+01, 0.10904300E+00, -.45699600E+00, -.79557000E+00, 0.58876400E+01, -.17013900E+01, 0.57806900E+00, -.45161300E+00, 0.23258100E+01, -.12777100E+01, -.11581400E+01, 0.46106100E+00, 0.24918700E+00, -.22017100E+00, -.74075800E+00, 0.14059300E+01, 0.32553700E-01, 0.14469900E+00, 0.26195400E+01, -.33991800E+01, 0.19796700E+01, -.65594500E+00, 0.57724300E+00, 0.18695200E+01, 0.20223600E+00, 0.12649600E+01, -.75723900E+00, 0.45865900E+00, 0.11428500E+01, -.21242900E+01, 0.79921400E+01, 0.20999800E+00, 0.52894100E+00, 0.24414000E+00, 0.70703400E+00, 0.55456400E+00, -.63622200E-01, 0.10813500E+01, -.38644400E-01, 0.23317200E-01, -.33157400E+00, 0.28451900E+01, 0.91336900E-01, -.90211300E+00, -.67562500E+00, -.71852500E+00, -.19704200E+01, 0.36326800E+00, -.66279600E+00, -.10386100E+00, 0.64240900E+00, 0.11862400E+01, -.59170900E+01, -.32035100E+01, -.14404400E+01, 0.15965200E+01, -.13411700E+00, 0.98432400E+00, -.92260000E+00, 0.48760700E-01, -.21459200E-02, 0.25562000E+00, 0.20442400E+00, 0.16455000E+01, -.58039300E-02, -.73850300E+00, -.93465300E+00, 0.61635900E+00, -.14894200E+01, -.56960500E+00, 0.10647700E+01, 0.24925200E+00, -.53388800E-01, -.86527200E+00, 0.50124100E+00, -.11732300E+01, -.16634900E+00, 0.41336300E+01, -.15398800E+01, -.32979700E+01, 0.17199700E+01, -.61708000E+01, -.56411400E-01, -.93174200E+00, -.51600400E+00, 0.16922200E+01, 0.71389800E+00, 0.15077200E+00, -.13887900E+00, 0.14024400E+01, 0.52404600E+00, -.39708600E+00, -.87594200E+00, 0.42379600E-01, 0.32273000E+01, -.74642700E+00, 0.22506800E+01, 0.63473100E+00, 0.14047700E+01, -.61969300E+00, 0.12308400E+00, -.14911200E+01, 0.33742800E+00, -.74091400E-01, -.36927200E+00, 0.18919600E+00, 0.40538200E+00, -.26770600E+01, -.53680700E+00, 0.20773400E+00, -.39378700E+00, -.86071600E+00, -.55307300E+00, 0.43574700E-01, -.84336500E+00, -.93553800E-01, -.24185200E+00, -.38671300E-02, 0.21886900E+01, -.14293400E+01, -.89258500E-01, -.78199000E+00, -.27391600E+01, -.31238200E-01, -.25906400E-01, -.19340200E-01, 0.22226900E-01, 0.37485600E+01, -.75926500E+00, 0.88939700E+00, 0.30061700E+01, -.20779900E+00, 0.27733200E+01, 0.41714200E-01, -.16210400E+00, 0.11427100E+00, -.89960500E+00, 0.96763900E-01, -.32847000E+00, 0.15428500E-02, 0.68120900E+00, 0.19199200E+00, 0.62986700E+00, 0.52356200E+00, -.29633700E+00, 0.45764600E+00, -.18353000E-01, 0.14160800E+01, 0.94415200E-02, 0.79747000E+00, 0.68488000E+00, -.24695500E+00, -.17438200E+01, -.11697800E+01, 0.43249400E-01, 0.68691300E+00, 0.44435100E+00, -.79540100E-01, 0.31902000E+00, 0.18135400E+00, -.13787100E+00, -.11578700E+00, 0.58984900E+00, 0.19652500E+00, 0.64315400E-02, 0.22330900E+00, -.23105200E+01, 0.13476700E+00, -.48640000E+00, 0.12272300E+00, -.59245600E-01, -.10182000E+00, -.27399600E+00, -.44780100E+00, -.14694700E+00, -.36412800E+00, -.88577900E-01, -.20513900E+00, 0.58917200E+00, 0.20658600E-01, 0.20229400E+00, 0.60194300E-02, -.17009100E+00, 0.19407800E+00, -.67260100E+00, 0.35129800E+00, 0.27520100E-01, 0.16928100E+00, 0.12006200E+00, 0.17605000E+00, 0.11269500E+00, 0.67339800E+00, -.37730000E-02, -.12093600E+00, -.23229400E+00, -.72855500E+00, 0.21793200E+00, 0.65990200E+00, 0.16829100E+01, -.48027600E+00, -.20020000E+00, -.21792000E+00, -.44408000E+00, 0.13063200E-01, -.98823000E-02, 0.53198400E-01, 0.36207800E+00, -.36988300E+00, 0.64535400E-01, 0.13857600E+00, 0.25726300E+00, -.92864300E+00, 0.64270700E-01, -.10379700E+00, 0.11354600E-01, 0.21676300E+00, -.13610600E+00, -.16747900E+00, 0.13056400E-01, 0.43772400E-01, 0.12172600E+01, 0.75819900E-01, -.11359000E+00, 0.39598000E+00, 0.10113100E+00, -.97251000E-02, 0.63326400E-01, -.11829000E+01, -.47153000E+00, 0.82100700E-01, -.32217700E+00, 0.43723000E-01, -.57038900E-02, 0.12739100E+00, 0.10112600E+00, 0.38454400E+00, -.78295400E-01, -.38087300E+00, 0.77496600E-01, -.31453100E+00, 0.89626000E-02, 0.91962600E-01, 0.17655600E+00, -.82499000E-01, 0.44523000E+00, 0.79357700E+01, -.34223700E+02, 0.23775400E+00, -.14677400E+02, -.11332400E+02, 0.19539400E+02, -.12496600E+01, -.21835200E+02, -.12684900E+02, -.11453600E+02, 0.75762300E+02, -.36398700E+02, 0.23689800E+02, -.37643500E+02, -.31526600E+02, -.34562400E+01, -.38994600E+02, 0.27522400E+02, 0.33496000E+01, -.54032300E+01, -.25401500E+02, -.60137800E-02, 0.20430800E+01, 0.12728400E+00, -.10094000E+01, -.34444100E+01, -.22331400E+01, 0.12184600E+01, 0.24081100E+01, -.81039700E+00, 0.11382700E+01, -.91633600E+00, -.15733100E+01, 0.22618000E+00, -.17841500E+01, -.20646100E+01, -.82092400E+00, 0.73455400E+00, -.34291300E+00, -.10895700E+01, 0.11705000E+01, 0.41583600E+01, 0.20071000E+01, 0.18101000E+01, -.15280100E+01, -.14008000E+01, 0.32858500E+00 },
        { 0.37037500E+00, 0.19095400E+00, 0.46848300E-02, 0.10219900E+00, 0.30406200E+00, 0.37653100E+00, -.22332500E-01, 0.19815300E+00, 0.10510300E+00, -.31921100E+00, -.48310300E-02, 0.10347900E-01, 0.74057900E-01, -.15529200E+00, 0.20071700E+00, 0.20743800E-01, -.89510000E-01, 0.64498800E-01, -.83951700E-01, 0.11307400E+00, -.29654900E-01, 0.59459200E-03, -.38505000E-04, 0.37234600E-01, -.22107400E+00, -.29981300E-02, 0.27062800E-01, 0.11275800E-01, 0.16587000E-01, 0.28562000E-01, -.42136000E-01, -.64960700E-01, -.72011300E-01, 0.44669400E-02, -.13298200E-01, 0.62622400E-02, 0.59409300E-02, -.28764600E-01, 0.24433000E-01, -.35922200E+00, 0.59179500E-03, -.13034500E-01, 0.97464200E-02, 0.17284500E-01, -.88742700E-02, 0.22268100E-03, -.24344100E-01, -.11906500E-02, 0.67338300E-02, 0.49104600E-02, 0.24476600E-01, -.62369400E-02, 0.57348900E-02, -.33272500E-01, -.34412500E-02, 0.37994800E-01, -.15312400E-02, 0.15695500E-01, -.17454700E-02, 0.19677000E-01, -.45316300E-01, 0.66079900E-01, 0.41738700E-01, 0.23775600E-02, -.14552700E-01, -.35510800E-02, -.16179400E-01, 0.13079500E-01, 0.46861200E-02, 0.95068800E-03, -.13018000E-01, -.49023200E-02, -.48828600E-02, 0.85486500E-03, 0.22923600E-01, -.79867700E-02, 0.63360600E-02, 0.28461000E-01, 0.10862800E-01, -.27596300E-01, -.85052400E-04, -.95777900E-02, -.74904900E-01, -.62464900E-02, 0.60293500E-01, -.38803400E-02, 0.40008900E-01, -.41643300E-01, 0.14246800E+00, -.49612600E-01, 0.19958300E-01, -.22368300E-02, 0.15157800E-01, 0.89319100E-02, -.17657500E-01, -.41104000E-01, 0.11509800E-01, 0.15601500E-03, 0.60078000E-02, 0.11609500E-01, 0.68717000E-02, 0.43890400E-02, 0.18407400E-01, -.48905500E-01, 0.22919400E-01, -.23146300E-01, -.48932600E-01, -.23717900E-01, 0.10766200E+00, 0.87515000E-02, -.13129200E-01, 0.40236000E-02, -.98732900E-02, -.15949100E-01, -.69283500E-01, 0.45616700E-01, 0.57251300E-01, -.65989300E-01, -.14942900E-02, 0.12860000E-01, 0.34909400E-01, -.51427200E-01, -.14199500E-01, -.77712000E-02, 0.44277100E-03, 0.41079300E-01, -.38100300E-02, -.71526900E-01, 0.11242000E-01, -.82111200E-02, 0.11326600E+00, -.68458100E-01, 0.40604100E-01, 0.93156000E-03, 0.39193000E-02, -.21749600E-03, -.65074100E-01, 0.59302600E-01, -.26559500E-01, -.17566400E+00, 0.37468600E-01, -.60361700E-01, -.75261400E-01, -.40444100E-01, -.23462800E-02, 0.32614400E-01, -.75862900E-03, -.60506200E-02, -.22673400E-01, 0.22818700E-01, -.86702100E-02, -.20832700E-01, 0.34627700E-01, 0.60830000E-02, -.65203700E-02, -.12217700E-01, 0.14812500E-01, 0.76551600E-03, 0.59479100E-02, 0.45734600E-01, 0.29999400E-02, -.16335000E-02, 0.54676900E-01, -.13015500E-01, -.19826100E-01, 0.13316700E-01, 0.12894100E-01, -.16247400E-01, -.24053900E-02, -.10727200E-01, -.81272200E-02, -.27405400E-01, -.34109500E-02, 0.26177500E-02, -.41453100E-01, -.19929500E-01, 0.80531600E-03, 0.29922400E-01, -.31734300E-01, 0.22656900E-01, -.36833000E-01, -.40994200E-01, 0.85181400E-01, 0.65591900E-01, -.54109600E-01, 0.15886300E-03, -.39187800E-02, 0.20979400E-01, 0.25088800E-01, 0.93413900E-02, 0.70886700E-03, 0.62310300E-01, 0.29395800E-01, 0.69492900E-02, 0.25177900E-01, 0.55164100E-01, -.99530200E-01, -.22961300E-01, 0.51119500E-01, 0.31858400E-02, -.23420100E-01, 0.69962200E-02, -.37076300E-02, -.33573200E-01, -.49196100E-01, -.10565500E+01, 0.46599200E-01, 0.18277300E-01, -.10881400E-01, -.36170200E-01, -.15241600E-01, 0.17035400E-01, 0.51037100E-03, 0.14129000E-01, 0.40785500E-01, -.17519800E-01, -.30418300E-01, 0.12608900E-01, 0.30488900E-02, 0.17742000E-01, -.45243900E+00, 0.10591000E-01, -.58151800E-02, 0.18873800E-02, 0.40947000E-02, 0.23221200E-01, -.28649200E-01, 0.48606900E-02, 0.13150100E-01, 0.14179400E+00, 0.39262800E-01, 0.63068200E-01, 0.61433700E-04, 0.13983900E-01, -.52632800E-02, -.55996900E-02, -.73164800E-01, -.48861600E-01, -.11464900E-02, -.34080800E-02, 0.18583800E-01, 0.68375100E-01, 0.14819400E-03, -.66830700E-02, -.52425400E-01, 0.31833800E-03, -.30962400E-01, -.66576600E-02, 0.48168800E-01, 0.56183800E-01, 0.65581100E-03, 0.16236000E-01, 0.30582300E-03, -.55763600E-01, -.26208500E-02, -.89789600E+01, -.70442600E-01, 0.66233700E+00, -.61418300E+00, 0.39087300E+00, -.67773300E+00, -.17845400E+01, -.79625300E+00, 0.32577400E+01, -.14594500E+00, -.41196200E-01, 0.99521000E+00, 0.60229400E-01, -.38801200E+00, 0.18006500E+01, -.38051500E+01, -.14761700E+01, 0.66171500E+00, 0.14194700E+01, 0.12922400E+01, 0.18167700E+00, -.12164000E+00, -.11715900E+00, 0.42659100E-01, 0.92361300E-01, -.31109000E+00, 0.40880000E-01, 0.11749000E+00, 0.18010000E+00, 0.24846500E+00, -.41739300E+00, -.33023600E+00, 0.31885300E-01, 0.37487700E-02, -.32828600E+00, -.22582800E-01, 0.11877200E+00, 0.13432600E+00, -.21677400E+00, 0.77972100E-02, 0.33089000E+00, 0.36116600E+00, 0.37450500E+00, -.37472200E+00, -.11283600E+00, 0.24816600E+00 },
        { -.78227900E+01, 0.11234600E+01, 0.22821200E+00, -.41809100E+01, -.61868000E+01, 0.75532100E+01, -.85346900E+01, 0.98768900E+01, -.42322700E+01, 0.68962000E+01, -.73091600E-01, -.48683500E+00, 0.22196000E+01, 0.31828000E+01, 0.40343700E+00, 0.31101300E+01, -.31143600E+01, -.60156300E+00, -.37027900E-01, -.11576500E+00, 0.57019100E+00, 0.17058800E+00, 0.33973900E-01, 0.34978300E+00, -.32063900E+01, 0.54002000E+00, -.19990600E+01, -.19021900E+01, 0.13947000E+01, 0.87336700E-02, 0.54628700E+00, 0.66477200E-01, -.29382500E+00, 0.94942100E+00, 0.15038900E-01, 0.37773000E-01, -.15202900E+01, -.18080500E+01, -.12002000E+01, -.13754400E+02, -.21308300E+00, -.49308300E+00, 0.15479100E+01, 0.22957200E+00, -.58058200E+00, -.36828800E+00, 0.36378300E+00, -.37652700E-01, 0.28170000E+00, -.26189900E+00, -.12578200E+01, 0.60470400E+00, 0.22213300E+00, 0.10375800E+01, 0.92098100E+00, -.11830500E+01, 0.26629900E+00, -.47424400E+00, 0.41692000E-01, -.19382500E+00, 0.10255800E+01, -.54438200E+00, -.69416700E+00, 0.14037700E+00, -.98926000E-01, -.92116700E-01, 0.44743200E+00, -.32147700E+00, -.34959600E+00, 0.14037500E+00, -.18109000E+00, 0.63240900E-01, -.13673400E+00, -.37529700E+00, -.71934400E+00, 0.51620700E+00, 0.62548400E-01, -.66140100E+00, 0.11314800E+00, -.51950600E+00, 0.10997300E+00, -.20071200E+00, 0.94002300E+00, 0.49932300E+00, -.13182500E+01, -.16841300E+00, -.53937700E+00, 0.40588300E-01, 0.18872800E+01, -.22637100E+00, -.38946500E+00, 0.92088900E-01, -.24332800E+00, 0.39572200E+00, 0.33814000E+00, 0.51138200E+00, 0.64297800E-01, -.68074200E+00, -.11319300E-01, 0.48451700E+00, 0.31627700E+00, -.65017400E+00, 0.12447300E+00, 0.12553000E+01, 0.27817500E-01, 0.58654300E+00, 0.99033100E+00, 0.44499600E+00, 0.20812900E+00, 0.16950600E+00, -.14268100E+01, 0.42801600E+00, -.17730000E+00, -.33609100E+00, 0.62914900E+00, -.12161100E+01, -.15098500E+01, -.28027400E+00, -.12383700E+00, 0.27035900E+00, 0.79697700E+00, -.45981300E+00, -.97551400E-01, -.48659800E+00, 0.70874600E-01, -.67322100E+00, -.95719100E-01, 0.11419300E+01, -.13069500E+01, -.32087000E+00, 0.46836700E+00, -.17432500E+00, -.42990700E+00, 0.11590200E-01, -.12761200E+00, 0.29879000E-02, 0.23176200E+01, -.46661100E-01, 0.66354600E-01, -.51695900E+00, 0.21472700E+00, 0.54838600E+00, -.19322400E+01, -.36392200E+00, 0.14376400E+00, -.21419900E+00, 0.94894400E-01, -.99187000E-01, 0.35041600E+00, 0.49651900E+00, -.13954200E+00, -.31512800E+00, 0.18159000E+01, -.28740500E+00, 0.10326300E+00, -.83449500E-01, 0.61417600E+00, 0.35477500E-01, -.59390400E+00, 0.82221400E+00, 0.12462900E+00, 0.92447500E+00, 0.16364900E+01, 0.14115600E+00, -.12265700E+01, 0.15769300E+00, -.38349200E+00, -.61502300E+00, -.39172700E-01, 0.15783100E+00, -.29223500E+00, 0.56802900E+00, 0.54713500E-01, 0.11603700E+00, -.39815700E+00, 0.90164800E-01, 0.10418800E+00, 0.46774600E+00, -.38103600E-02, -.19376600E+01, -.30025200E+01, 0.74117200E+00, -.17031300E+01, 0.21058600E+00, 0.62158200E+00, 0.17033300E+00, -.26490100E-01, 0.56413800E+00, -.17363200E-01, -.13602300E-01, -.12168500E-01, -.42412000E+00, 0.28250500E-01, -.12666000E+01, 0.67466100E+00, -.12449300E+00, 0.68278100E+00, 0.61234200E+00, 0.17829700E+00, 0.20306700E+00, 0.73156300E+00, 0.46944200E-01, -.27506200E+00, -.16674000E+00, -.33970600E+00, 0.30320400E+01, 0.15728200E+01, 0.14609000E+01, -.47501000E+00, 0.20302100E+00, -.29033000E+00, -.11416200E+00, -.10839400E+00, 0.41451100E+00, 0.14026400E+00, 0.19640700E+01, -.63622300E+00, 0.59545400E-01, -.33272500E+00, 0.26196200E+00, -.14901000E+01, 0.22712100E+00, -.13325800E+00, 0.12311800E+00, 0.17858700E+00, -.22734600E+00, -.28839000E+00, -.13634000E+00, -.11487400E+00, 0.73029000E+00, -.15609700E+00, -.39871300E+00, 0.51409100E+00, -.15582100E+00, 0.96995000E-01, 0.69209800E-01, -.14040100E+01, -.15248900E+00, 0.69254300E-01, -.22479300E+00, -.17152300E+00, -.63187400E+00, 0.10439700E+00, -.36290100E+00, 0.41114300E+00, 0.84775100E-01, -.21899100E+00, 0.12988400E+00, -.16643200E+01, -.23765200E-01, 0.68498600E-01, 0.15722400E+00, -.86276700E-01, 0.63716100E+00, 0.18698700E+00, 0.23705700E+01, 0.14491900E+02, -.21283000E+02, -.71148200E+01, 0.15747700E+02, 0.17876800E+01, -.87114600E+01, -.99157000E+01, -.22293400E+02, 0.73494900E+02, -.33813800E+02, 0.16081400E+02, -.33902700E+02, -.22109000E+02, 0.91615700E+01, -.44046600E+02, 0.14173300E+02, -.16065500E+02, 0.30198400E+01, -.39506600E+02, -.15018100E+01, 0.19970700E+01, -.42577300E+00, -.85193300E+00, -.21809100E+01, -.23813900E+01, 0.72720000E+00, 0.15877300E+01, -.88430800E+00, 0.10014400E+01, -.83208200E-02, -.16365300E+01, -.23363400E+00, -.19318600E+01, -.18827200E+01, -.10415000E+01, 0.64354400E+00, -.58065800E+00, -.15531200E+01, 0.49870800E+00, 0.18217500E+01, 0.13576700E+01, 0.16489300E+01, -.78650400E+00, -.16406700E+01, 0.26623800E+00 },
        { -.16096200E+02, 0.80967300E+01, 0.84308600E+00, 0.35697600E+01, -.46101400E+01, 0.78088900E-02, -.18396400E+02, 0.30181600E+01, -.10285800E+02, 0.13477700E+02, -.36000300E+00, -.15186100E+01, -.77051500E+01, 0.55257700E+01, -.11387900E+02, 0.13545800E+01, 0.44467200E+01, -.34804600E+01, 0.47000100E+01, -.66381600E+01, -.19937800E+01, 0.90226600E+00, -.15730300E+00, 0.63770400E-03, -.38290000E+01, 0.42252000E-01, -.11836600E+01, -.54267800E+01, 0.24686400E+01, 0.78304700E+00, 0.55444700E+00, 0.19620900E+01, 0.10786200E+01, 0.19769500E+01, -.33958100E+00, -.52000600E+00, -.65824400E+00, -.16190000E+01, 0.35699500E+01, -.21548500E+02, -.38441900E+00, -.51087300E+00, 0.28825000E+01, 0.19451200E+01, -.69596200E+00, 0.16242800E+00, 0.12971200E+01, -.96787400E-02, -.69056000E-01, 0.35248100E+00, -.46491000E+01, 0.99364300E+00, 0.17072400E+01, 0.16557900E+00, 0.38992700E+01, -.38154400E-01, 0.38954100E+00, -.11030100E+00, 0.30466500E+00, -.21879900E+01, -.89465200E+00, 0.78564800E+01, 0.50204200E+01, 0.84160000E-01, 0.16147700E+01, 0.59345700E+00, 0.11901800E+01, 0.71717500E+00, 0.18987100E+00, -.61816200E-01, -.29681800E+00, -.11484700E+00, -.75983600E+01, -.51191100E-01, 0.11788800E+00, -.62954200E+00, -.27343900E+00, 0.82732300E+00, 0.10145100E+01, -.33291000E+01, -.16034100E+00, -.46027600E+00, 0.30836900E+01, 0.53693700E+00, -.25784800E+00, 0.14570700E+01, -.48791600E+01, -.12614200E+01, 0.74659900E+00, -.21482300E+01, 0.88533800E+00, 0.65203500E-01, 0.15972400E+01, 0.31770300E+00, -.25732400E+01, 0.97589200E-01, 0.13446000E+00, -.22887300E+01, -.86958600E-01, 0.10416300E+01, 0.24292300E+01, -.14034700E+01, -.16850900E+01, 0.12010500E+01, -.10652100E+01, -.44723400E+00, -.11957000E+01, -.49274600E+01, 0.98867900E+00, -.76124900E+00, 0.21394500E+01, -.23816600E+00, 0.18759500E+00, -.21506300E+00, -.10650600E+01, 0.26272100E+01, 0.30423300E+01, -.81939200E+00, -.18577400E+00, 0.11200000E+01, -.68355000E+00, -.58703200E+00, -.20097600E+00, 0.15800200E+01, 0.33446400E-01, 0.59336500E+00, -.22379100E-02, 0.40920400E+00, 0.24297500E+01, 0.11257100E+01, -.26301300E+01, 0.19950700E+00, 0.38696300E-01, -.23585200E-01, 0.20745300E+00, -.17978100E-01, 0.12455200E+01, -.71531800E+00, 0.72260000E-01, -.28041700E+01, -.13917800E+01, 0.21790900E+01, 0.28260800E+01, -.12270300E+01, 0.34730000E+00, 0.28429700E+01, -.10752700E+00, -.41023700E+00, -.20955800E+01, 0.25186500E+01, 0.26683200E+00, -.74126700E-01, 0.18915800E+01, 0.95197400E+00, -.46101300E-01, 0.68154800E+00, 0.24836700E+01, 0.64405100E-01, -.13921700E+01, 0.33359700E+01, -.18434900E+00, -.19110700E+01, 0.19660900E+01, -.33225200E+00, -.17807900E+01, -.64462800E+00, 0.46521700E+00, -.92662400E+00, 0.34755400E+00, -.75464700E+00, -.97176600E-01, 0.31538100E+01, 0.19626300E+00, -.10127000E+01, -.15294600E+00, -.27925500E+01, 0.90570000E+00, 0.18013000E+01, -.11311900E+01, -.90315000E+00, -.64376400E+01, -.29358800E+00, 0.12751200E+01, 0.16465700E+01, 0.37001800E+00, 0.18253200E+00, 0.31805700E+00, 0.14545500E+01, -.52281700E+00, -.60629000E+00, -.26630000E-03, 0.21407400E+00, -.37812600E+00, 0.13799300E+00, 0.99410600E+00, 0.96957800E+00, 0.52633200E+00, 0.15403800E-01, -.63161900E+00, -.31872700E-01, 0.13459000E+01, 0.94551300E-01, -.12690700E+00, -.77213300E+00, -.85407900E+00, 0.18685800E+02, 0.39054200E+01, -.17665600E+01, -.11406200E+01, -.75369100E+00, -.19706300E+01, -.19010600E+01, -.54967100E-01, -.89838200E+00, -.24632100E+00, 0.60474700E+00, -.72002200E+00, -.76778100E+00, 0.74713800E+00, 0.87717000E+00, -.11066000E+02, 0.84785200E+00, 0.37801500E+00, -.10472300E+00, 0.22038200E+00, -.12836000E+01, -.56300400E+00, -.17314600E+00, 0.33846000E+00, 0.56323300E+01, 0.72469100E-01, 0.15480900E+01, 0.17087300E+01, -.25858800E+00, 0.41224500E-01, -.12668600E+00, -.44439400E+01, -.12580200E+01, 0.95123200E-01, -.66148900E+00, -.22293300E+00, -.10347600E+01, 0.47495900E+00, -.86882800E+00, -.67872700E+00, -.23865400E+00, -.35295700E+00, -.51102800E-01, -.28216900E+01, 0.20550800E+01, -.19576800E+00, 0.69994800E+00, -.45245500E+00, -.42565300E+00, 0.89109100E+00, 0.14461300E+02, -.18199500E+00, -.97039500E+02, -.37174200E+02, 0.25416200E+02, -.39336900E+02, -.42835500E+02, -.46975700E+02, 0.24163700E+02, -.10614300E+02, 0.24349100E+02, 0.22396900E+02, 0.66597300E+01, -.65429200E+02, 0.85632500E+02, -.19717400E+03, -.51585400E+02, 0.79069900E+01, 0.42349700E+02, 0.43278300E+02, 0.46991700E+01, 0.97468400E+01, -.57253700E+00, -.28165500E+01, -.24810500E+01, 0.12181300E+01, 0.35619000E+01, 0.96126200E+01, -.65097000E+01, -.25865100E+01, 0.54924000E+01, -.18329700E+02, 0.36371300E+00, -.94122700E+01, -.18850400E+02, -.47688700E+00, -.48961700E+01, -.18667400E+01, -.14754400E+02, 0.79240100E+00, 0.10309900E+02, -.12170000E+01, 0.18532700E+02, 0.35224500E+01, -.55516900E+01, 0.14177900E+02 },
        { 0.63290900E+01, 0.84687800E+01, 0.83684900E+00, 0.57601500E+01, 0.17506200E+01, -.23170600E+01, 0.89522300E+01, -.33450200E+01, 0.38538500E+01, -.59363900E+01, -.39346400E+00, 0.14203300E+00, -.51786500E-01, -.72389600E+01, 0.56680800E+00, -.22847500E+01, 0.34276500E+00, -.23668700E+01, 0.17563900E+01, -.56935700E+00, -.22094000E+00, -.19985100E+00, 0.29951800E+00, -.79306100E+00, 0.61905900E+01, 0.69691200E-01, 0.14385500E+01, -.24807400E+00, 0.26097300E+00, -.16611000E+01, 0.11939900E+01, 0.19320500E+00, 0.17886200E+00, 0.42006500E+00, -.51527000E+00, 0.39821500E+00, -.46330000E+00, 0.32228900E+00, 0.37687200E+01, -.34489800E+01, 0.94372100E-02, 0.40076500E+00, 0.73811900E-01, -.67409000E+00, -.35629200E+00, -.77457700E+00, -.20641600E+00, 0.45808300E-01, -.31981700E+00, 0.28573700E-01, -.22462700E+01, -.17603700E+00, 0.99058400E-01, 0.14555800E+01, -.57555500E+00, 0.60170600E+00, -.14611100E+01, 0.15647900E+00, -.14534800E-01, 0.14314800E+00, 0.83025000E+00, 0.46372900E+00, 0.46587900E+00, 0.22712100E+01, -.19618900E+01, 0.41824400E+00, -.60659700E+00, 0.46046300E-02, -.21224400E+00, -.28050700E-01, 0.60658200E+00, -.49825700E+00, 0.12238800E+01, -.11442900E+01, -.76001100E+00, 0.90204600E+00, -.40914300E+00, -.43327300E+00, -.32970400E+00, 0.91463200E+00, -.57021100E-01, 0.52761100E+00, -.41110900E+00, -.75640400E-01, 0.17007600E+01, 0.70524300E+00, -.25979000E+01, 0.90408100E+00, 0.24214100E+01, -.94452800E+00, -.21369600E+01, 0.73844100E-01, 0.14163300E+00, -.66722900E+00, 0.18016000E+01, -.11920800E+01, -.18024600E-01, 0.23156700E+01, 0.54077300E+00, -.26906800E+00, 0.22686200E+00, 0.15207100E+01, -.32518000E+00, -.62017200E+00, -.10902100E+01, 0.61155600E+00, 0.98428900E+00, -.16573300E+00, -.15458100E+01, -.20622900E+00, 0.26967900E+01, -.19787800E-01, 0.26925000E+00, 0.96201800E+00, 0.11784500E+01, -.40228200E+01, 0.15800500E+00, 0.33842500E+01, -.38407500E-01, -.11998100E+00, 0.95904400E+00, -.96412500E+00, -.20524800E+00, -.10992800E+00, -.19830200E-01, -.46826200E+00, 0.33592200E-02, 0.72196200E+00, -.54825900E+00, 0.23294700E-01, -.15995500E+00, 0.16255500E+01, -.26527400E+00, 0.22755900E-03, -.14140200E+00, 0.26000600E-02, 0.16329300E+00, 0.25024900E+00, -.21040000E+00, 0.25145300E+01, 0.15319600E+00, -.16612800E+00, 0.37434400E+00, 0.37063500E+00, 0.12234000E+00, -.36079400E+00, -.12200100E+00, 0.35978500E-01, -.26903200E-01, -.13424000E+00, -.31023600E+00, -.77516400E-01, -.81319700E+00, -.32987800E+00, -.79503000E-02, 0.35351200E+00, -.10192400E+01, -.14440200E-01, 0.86591600E-01, -.73068900E+00, -.72504400E-01, -.46129800E+00, -.97803700E+00, -.13006800E-01, 0.56879000E+00, -.89246600E-01, -.92270700E+00, 0.11080100E+01, 0.11296400E+00, -.10101500E+00, -.32726200E-01, 0.60048100E+00, -.44327900E+00, -.17880800E+00, 0.12413000E+01, -.25117500E+01, 0.17045900E+00, -.10477800E+01, -.76479800E-01, 0.15931300E+01, 0.16476000E+01, -.64670900E+00, 0.98275000E+00, -.29650200E+00, -.80091500E+00, 0.58211300E-02, -.59545900E-01, -.18548400E+01, 0.52142300E+00, -.98996800E+00, -.31425300E-01, 0.85683200E+00, -.13046300E+00, 0.95665000E+00, 0.72410700E+00, 0.27924000E+00, -.68727200E+00, -.31170800E+00, 0.13795300E-01, -.69866900E-01, -.14528400E+01, 0.13708300E+00, -.47541200E+00, -.19400400E+00, 0.10623900E+01, 0.43528800E+01, 0.72660700E+00, 0.16613300E+00, -.12451100E+00, -.12092900E+01, 0.53541400E+00, -.14132200E+00, 0.11573600E-01, -.17251900E+00, -.13033200E+00, -.12411400E+01, -.14694000E+00, -.21598900E-01, -.71756400E-01, 0.14421900E+00, -.61470600E+01, 0.50821300E+00, 0.36978100E+00, -.98994900E-01, -.43832700E-01, 0.20764200E+00, -.39948800E+00, 0.15100500E+00, 0.27737100E+00, 0.46174300E+01, 0.70552700E+00, 0.15770200E+01, 0.13213200E+01, -.27290600E+00, -.17119200E+00, -.28434600E+00, -.27419100E+01, 0.61902000E+00, -.46280500E+00, 0.16062400E+00, 0.52847100E-01, -.62965500E+00, 0.13154300E-01, -.30137900E+00, 0.17037500E+00, -.51650500E-01, -.38708600E-01, 0.22097600E+00, 0.13265600E+01, -.49801200E+00, 0.35443000E-01, 0.17538600E+00, 0.13484200E+00, 0.63946200E+00, 0.45494900E+00, -.30870900E+00, -.15663200E+00, 0.17533500E+00, 0.25912900E+02, -.81590500E+02, -.38620700E+02, 0.13794500E+02, 0.19657200E+02, -.38365400E+02, -.14517200E+03, 0.77134000E+02, -.11122000E+02, 0.72927300E+02, 0.35603500E+02, 0.49689400E+02, -.19479900E+02, -.10819500E+03, -.51429900E+02, 0.44666200E+02, 0.14239000E+03, -.17506900E+01, 0.45205000E+01, -.80231400E+00, -.18764900E+01, 0.48204800E+01, 0.56715600E+01, -.20095200E+01, -.27205500E+01, 0.11676900E+01, -.34653000E+01, 0.41141900E+01, 0.13966600E+01, -.12548300E+00, 0.16442800E+01, 0.23591400E+01, 0.27578600E+01, -.20550900E+01, -.15868200E+01, 0.12603500E+01, -.29802300E+01, -.50709600E+00, -.54998500E+01, -.18160100E+01, 0.51460700E+01, -.98391100E+01, 0.11948600E+02 },
        { -.27025600E+01, 0.41109100E+00, 0.13955000E+00, -.17354600E+00, -.21405800E+01, -.73853200E+00, -.59161400E+00, -.71179000E+00, -.96181300E+00, 0.22723400E+01, 0.19631400E-01, -.22123600E+00, 0.43166400E+00, -.11438400E+00, -.13207800E+01, -.30563400E+00, -.58376800E+00, -.74844200E+00, 0.77179100E+00, -.11790300E+01, 0.42820500E+00, 0.86414300E-01, 0.17632000E+00, -.14252500E+00, 0.83510500E+00, -.44085100E-02, -.26622800E-01, -.26965300E+00, 0.39125700E-01, 0.54687700E+00, 0.79226000E-01, 0.14511400E+01, 0.51563800E+00, -.32788500E+00, -.27282200E-01, -.62049800E-01, -.32745600E-03, 0.81259000E-01, -.45111600E+00, 0.38150900E+01, 0.12044300E-01, 0.33772300E+00, -.24518600E+00, 0.13875800E-01, 0.44171800E+00, 0.13594100E+00, 0.35171600E+00, 0.23966800E-01, -.98377000E-01, -.46511600E-01, -.15440800E+00, -.29328900E+00, -.13854300E+00, -.24996700E+00, -.19009500E+00, 0.82523500E-01, -.40227600E+00, -.38227300E-01, 0.26006200E-01, -.38136400E+00, 0.60187000E+00, 0.55128700E+00, 0.18435100E+00, -.46872200E+00, 0.32005200E+00, 0.45187000E-01, 0.69459200E+00, 0.74153700E-01, 0.11715200E+00, -.19374200E-01, -.32711300E-01, 0.12100300E+00, -.57206500E+00, 0.20376100E+00, 0.46510200E-01, -.25554300E+00, 0.58307200E-02, 0.16891500E+00, 0.63877400E-01, 0.14775000E-01, 0.21830800E-02, 0.12473900E-01, -.16776100E+00, 0.14390900E+00, -.51208200E+00, -.22886000E-01, -.49350000E+00, -.23406000E-01, 0.81640700E+00, -.11084100E+00, 0.38450000E+00, -.13114100E-01, -.89431800E-01, 0.30281400E+00, 0.14333600E+00, 0.89271300E-01, 0.15287200E+00, -.31591400E+00, 0.23623900E+00, 0.17307300E+00, 0.19827400E+00, -.25833000E+00, -.10748600E+00, 0.24202500E+00, 0.71782600E-01, -.13156900E+00, -.47360300E+00, -.34728700E+00, 0.29307700E+00, -.27245200E-01, -.34068300E+00, 0.10362100E+00, -.31972400E-01, -.12075200E-02, -.12540300E+00, 0.60378800E-01, 0.86353700E+00, -.22765500E+00, -.28623800E-01, -.54695700E-01, 0.12136000E+00, -.24183700E+00, 0.22198200E-01, -.50072500E-02, -.19662900E-01, -.26353700E-01, -.43752800E-01, 0.19355200E-01, 0.60470500E-01, -.25424800E+00, 0.58908400E+00, -.55009500E+00, 0.92362900E+00, 0.48327100E-02, 0.17397500E-01, -.52177700E-03, -.99122700E-01, -.18303900E-01, -.49903400E-01, -.11663900E+01, -.48474600E+00, -.20596800E+00, -.11736300E+00, -.73240200E-01, 0.11918500E-01, 0.83853300E-01, -.36016300E-02, 0.10112500E+00, 0.61776000E-01, 0.13580500E+00, 0.82946100E-01, 0.84803800E-01, 0.91445100E+00, -.11267100E+00, 0.45531100E-01, 0.16430900E-01, 0.70644400E+00, -.86015600E-02, -.28650900E+00, 0.74836600E+00, -.25715600E-01, -.11643900E+00, 0.19263000E+00, -.82681900E-01, -.13924500E-01, 0.74212500E-01, 0.13074600E+00, -.13015100E+00, -.26699100E-02, 0.43078900E-01, 0.73657500E-01, -.25494900E+00, 0.56878600E-01, 0.25115600E-01, -.42437600E-01, 0.65741800E-01, 0.46497800E-01, 0.66624200E-01, -.10322200E+00, -.30710400E+00, 0.58865800E+00, 0.34800500E-01, -.29586100E+00, 0.11636400E+00, 0.65579900E+00, 0.15299300E-01, -.22494400E-01, -.18549400E-01, -.10126500E+00, -.54755300E-01, -.94263200E-02, -.49718900E-01, -.85906400E-01, -.49333000E-01, 0.52472400E+00, 0.29796800E+00, 0.24160600E-01, 0.12845400E+00, 0.87863800E-01, -.10346500E-01, -.83618600E-01, -.20080600E-01, -.76734400E-01, 0.86004500E-01, 0.89850000E-01, -.12562500E+01, -.76221100E-01, -.58009000E+00, 0.19297800E+00, 0.17037900E+00, -.11516800E+00, 0.21524100E+00, -.14778000E-01, 0.29138700E-01, -.90636200E-01, 0.27712400E+00, -.60627200E-01, -.35128900E-01, -.82280100E-01, 0.26838800E-01, 0.59555200E+00, -.61704900E-02, -.90728500E-01, 0.31540800E-01, 0.82322800E-01, -.68888700E-01, -.57916600E-01, -.68918100E-02, -.69606000E-01, -.74662000E+00, 0.75505000E+00, 0.38996700E+00, 0.51870500E+00, 0.10497400E+00, 0.16668300E-01, 0.29305100E-03, 0.17131200E+00, -.15240200E+00, 0.37055800E-01, -.64557200E-01, -.12303300E-01, 0.10284800E+00, -.68279200E-01, -.37672300E-02, 0.92142500E-01, -.72191000E-02, -.15494300E+00, 0.13666100E-01, -.11699300E+00, 0.13894500E-01, 0.44504200E-02, 0.79914400E-01, 0.41512800E-01, 0.36469400E+00, 0.53800800E-01, -.11093400E+01, 0.25242500E-01, -.35102000E-01, 0.27595100E+00, 0.21313800E+02, 0.65874800E+01, -.92052000E+01, -.68792300E+00, -.18532900E+01, 0.87142700E+02, -.44470600E+02, 0.27201600E+01, -.43445100E+02, -.24980700E+02, -.95387400E+01, -.22557300E+02, 0.35695400E+02, 0.20393200E+02, -.11735700E+02, -.75680400E+02, 0.23890600E+00, -.13421600E+01, 0.20779900E-01, -.49667200E+00, -.12420200E+01, -.16089100E+01, 0.19133200E+01, 0.11305600E+01, -.19302600E+00, 0.99311600E+00, -.87698800E+00, 0.53616300E+00, 0.11500100E+01, -.51812700E+00, 0.15642600E+00, -.25534300E+01, 0.21392100E+01, -.38380300E+00, 0.35103500E+00, 0.19363400E+01, 0.92276500E+00, 0.20533500E+01, -.49270700E+00, -.16202000E+01, 0.69640300E+00, -.46063000E+01 },
        { -.13004600E+02, 0.26945300E+01, 0.49218600E+00, 0.28213600E+00, -.40388400E+01, -.90628000E+00, -.10955400E+02, -.20258300E+01, -.61797700E+01, 0.89156800E+01, -.10703800E+00, -.98446600E+00, -.57525200E+01, 0.18887000E+01, -.72498600E+01, -.29433600E+01, 0.26248800E+00, -.98625100E+00, 0.38750800E+01, -.11211600E+01, 0.12920300E+01, 0.12145500E+00, 0.17602000E+00, -.75890100E+00, 0.85402400E+00, 0.20377200E+00, 0.28102400E+00, -.43709600E+00, -.15023600E+01, -.34346300E+00, 0.30784900E+00, 0.13567500E+01, 0.95958300E+00, -.45677700E+00, -.12005300E+01, 0.37560400E+00, -.64819700E+00, 0.51990300E+00, -.25054900E+01, -.15317800E+01, 0.24895400E+00, 0.81824700E+00, -.96256900E+00, 0.13816000E+01, 0.13157600E+01, 0.44862000E-02, -.41778400E+00, -.81669600E-02, 0.67152400E-01, 0.10605800E+01, 0.10851300E+01, -.51615300E+00, 0.33811100E+00, -.12439700E+01, 0.11053400E+01, 0.22108400E+01, 0.24876700E+00, 0.46233100E+00, 0.30058500E-01, -.91652700E+00, 0.83281200E+00, 0.17946800E+01, 0.70965600E+00, 0.56332100E+00, 0.61287900E+00, 0.34358900E+00, 0.34727800E+01, 0.12855000E+01, 0.17290400E+00, 0.93236100E-01, -.28648700E+01, 0.13586900E+01, -.21544700E+01, 0.67409800E+00, -.36049000E+00, 0.48504900E+00, -.78669600E-01, 0.13757000E+01, 0.29858200E+00, 0.89469300E+00, 0.14201400E+00, -.62580700E+00, -.31422200E+01, 0.47055600E+00, 0.34333200E+01, 0.41052800E-01, 0.15399700E+01, -.34402800E-01, 0.55874900E+01, -.96096800E+00, -.79219700E+00, -.70255000E-02, -.74166500E+00, -.48600800E-01, 0.14219800E+01, -.97962200E+00, 0.87626900E+00, 0.12625000E+01, 0.54508900E+00, 0.45575400E+00, 0.60164300E+00, 0.54892000E-01, -.58481400E+00, 0.53700000E+00, -.47770000E+00, 0.62027700E+00, -.36963700E+00, -.89495100E+00, -.14499000E+01, -.48732100E+00, 0.10185800E+01, -.35420800E+00, -.73813600E-02, 0.56456000E-01, -.43449700E+00, 0.86335700E+00, 0.18302300E+01, -.10262400E+01, 0.17777200E+00, 0.39909100E+00, 0.35526000E+00, -.16480900E+01, -.36752300E+00, -.65718500E+00, -.74368300E-01, 0.14490100E+00, 0.47723900E+00, -.90542400E+00, 0.10488000E+01, -.61253600E+00, -.18216400E+00, -.13170100E+01, 0.22591200E+00, -.10809300E-02, -.64804800E-01, -.95314300E-03, -.60306700E+00, 0.51074400E+00, -.14522300E+00, -.11052200E+01, 0.11475900E+01, 0.27367800E+01, -.40184100E+01, -.17381500E+01, 0.46269700E-01, 0.16659700E+01, 0.71693700E-01, -.68002800E+00, -.13843100E+01, 0.20650000E+01, 0.35656600E+00, -.29117100E+00, -.67014000E-01, -.43830700E+00, 0.38624700E+00, 0.64572500E+00, -.20679400E+00, 0.51793600E-01, -.85927700E+00, 0.19629100E+01, 0.10843600E-01, -.34352100E+00, 0.27861400E+01, -.24034800E+00, -.82944300E+00, 0.33553500E+00, -.10427200E+01, 0.89831100E-01, 0.37553100E+00, -.45625200E+00, -.19062600E+00, 0.63454700E+00, 0.25058100E+00, -.47501200E+00, -.16115000E+01, 0.54502400E+00, 0.38718900E+00, 0.16080800E+01, -.51240600E+00, 0.40275100E+00, -.42629800E+01, -.27188800E+00, 0.50984800E+00, 0.16836000E+01, -.28074600E-01, 0.16557500E+00, 0.14353600E+00, -.18163500E+00, -.26333100E+00, 0.44033700E+00, 0.30570100E-01, 0.65261000E+00, 0.40725600E+00, 0.56066600E+00, -.25490400E+01, -.70824300E-01, 0.36854900E+00, -.25934500E+00, 0.78815600E-01, -.20347700E+00, 0.11222200E+01, 0.41231400E-03, 0.60892100E+00, -.12700700E+00, -.12935400E+01, -.84221800E+01, -.76497100E-01, -.76319800E+00, 0.42645200E+00, -.19006000E+01, 0.59829100E+00, -.41165400E-01, 0.26675500E+00, 0.28005600E+00, 0.85807600E+00, 0.61505300E+00, -.96962800E+00, 0.40732300E+00, -.10701200E+01, 0.67669300E-01, -.53414200E+01, 0.75995500E+00, 0.47817900E-01, -.10518000E-01, -.75785100E+00, 0.69822000E+00, -.24630000E-02, -.35715100E+00, 0.11492500E+00, 0.11149400E+00, 0.37879700E+01, 0.30360800E+01, 0.18695200E+01, 0.61857700E+00, 0.15169900E+00, -.18396800E+00, 0.22214200E+01, -.71507400E+00, -.15302500E-01, 0.58027500E-01, -.50005500E+00, -.12234500E+01, -.45311100E+00, -.24249900E+00, -.75734800E+00, -.64996500E-01, 0.19345700E+00, -.19127100E+00, -.99427600E+00, 0.11058400E+01, -.25892900E+00, -.74497600E-01, -.35203300E+00, -.10902400E+01, -.33115600E+00, 0.20883200E+02, -.33697300E+00, 0.42955300E+00, -.42220800E-01, 0.15149400E+01, 0.51265000E+02, 0.35528100E+02, 0.10440300E+01, -.32004800E+02, 0.63285400E+02, -.45801100E+02, -.15929400E+03, -.32175800E+02, 0.53444700E+02, -.33404500E+02, 0.14802400E+03, 0.39407300E+02, -.59939000E+02, -.31112900E+02, 0.12748400E+03, -.10813800E+02, -.32753400E+01, -.62195200E+00, 0.47673800E+01, 0.96916800E+01, 0.14657000E-01, -.26084600E+01, -.98715800E+01, 0.21981900E+01, -.11073200E+01, 0.78875300E+01, -.63868000E+01, -.61564800E+00, 0.40280600E+01, -.53427900E+01, 0.18062600E+01, -.71520100E+00, 0.28206500E+01, -.79991600E+01, -.97226700E+00, -.20193000E+02, -.80701700E+01, 0.59490400E+01, 0.72510000E+01, 0.42116900E+01, -.16721700E+02 },
        { 0.31099500E+00, 0.24315000E+00, 0.15039100E-01, -.62233100E-01, 0.14438500E+00, 0.17933500E+00, 0.27756800E+00, 0.36096600E-01, 0.19739300E+00, -.26360500E+00, -.79647700E-02, 0.27043900E-01, 0.11392400E+00, -.25631400E+00, 0.41981600E+00, 0.25831800E-01, -.76092200E-01, 0.52817400E-01, -.11244500E+00, 0.20608800E+00, -.95431800E-01, -.79431000E-02, 0.69932000E-02, 0.53652400E-01, -.23848100E+00, -.55881900E-02, 0.38797500E-01, 0.85391400E-01, 0.12303800E-01, 0.35472800E-01, -.54923200E-01, -.57618100E-01, -.11654500E+00, -.26960300E-01, -.29777600E-01, 0.14248900E-01, 0.81051900E-02, -.23901900E-01, 0.11622400E+00, -.21165200E+00, -.68674300E-02, -.11351500E-01, -.85575900E-02, -.22077600E-01, -.14820300E-01, 0.79767700E-02, -.27962500E-01, -.17349400E-03, 0.32774500E-02, 0.84569100E-02, 0.28484400E-02, -.20059000E-01, 0.18906300E-01, -.34200000E-01, 0.23094700E-01, 0.56559500E-01, 0.21143500E-01, 0.11693400E-01, -.75601700E-03, 0.31001500E-01, -.32302000E-01, 0.27161300E-01, 0.17036600E-01, 0.56675300E-02, -.41999600E-03, -.64796600E-02, -.38871000E-01, 0.11419900E-01, 0.50362000E-02, 0.18521000E-02, -.22109900E-01, 0.11465900E-01, 0.36106300E-01, 0.23053400E-01, 0.54778800E-01, -.14279100E-01, 0.16567900E-01, 0.21472200E-01, -.13379600E-01, 0.33597500E-01, -.16966300E-02, 0.28872100E-02, -.30731300E-01, -.18199900E-01, 0.19505700E-01, -.26063100E-01, 0.76798600E-01, -.36436000E-01, 0.72501400E-01, 0.28284400E-01, 0.14272400E+00, -.38286700E-02, 0.20868200E-01, 0.25941600E-01, -.52586800E-02, -.13497000E+00, 0.34199600E-01, 0.61044500E-01, -.89424000E-02, -.11495500E-01, -.11786400E-01, 0.21948900E-01, 0.31965600E-01, -.74886500E-01, 0.30666000E-01, -.29820600E-01, -.15860100E-02, 0.30035700E-01, 0.50116200E-01, 0.11735500E-01, -.59810700E-02, -.19750000E-02, 0.83576100E-03, 0.12452200E-01, 0.96504600E-02, -.17449400E-02, 0.49199800E-01, 0.25510100E-01, 0.11395400E-01, -.34809000E-01, 0.39868700E-01, 0.53617600E-02, -.22977200E-02, -.68350700E-02, -.50435600E-03, -.50496900E-02, 0.90571800E-02, -.62164800E-01, 0.25552800E-01, -.15126700E-02, -.58842000E-02, -.47953000E-01, 0.49284700E-01, 0.19404600E-03, 0.23715200E-02, -.40389000E-03, -.85392000E-01, -.25583200E-01, 0.26069500E-02, 0.11082900E+00, -.40732200E-01, 0.56342800E-02, 0.14117800E-01, -.11040300E-01, -.94967400E-02, 0.10581100E+00, -.26320500E-02, 0.95748400E-02, -.31372900E-01, 0.21186200E-01, 0.52570600E-03, -.10357700E-01, -.34357000E-01, -.16717300E-01, -.36811900E-02, 0.70055100E-02, -.94790000E-01, -.21592900E-02, -.42488200E-01, -.30773900E-02, 0.66294100E-02, 0.62237400E-01, 0.54582200E-01, -.24455900E-02, -.46295600E-01, -.31385900E-02, -.15805800E-01, 0.23339100E-01, 0.14668300E-02, 0.10352400E-01, -.16930400E-02, -.48462700E-01, 0.98162900E-02, 0.22389200E-01, -.36559200E-02, 0.72137300E-01, -.11932800E-01, 0.18510500E-01, 0.77441600E-02, -.19085800E-01, 0.45224600E+00, 0.23281600E-01, -.82066600E-02, -.46190800E-02, 0.40935200E-01, -.52423000E-02, 0.27733600E-02, -.66314500E-01, -.15616700E-03, 0.22426100E-01, 0.31341000E-02, 0.26910700E-01, 0.20251600E-01, -.65960400E-02, -.53540800E-01, -.15153700E-01, -.28171100E-02, -.23925200E-01, -.22725400E-01, 0.97533700E-02, 0.42875400E-01, -.98292900E-03, 0.10851800E-01, -.40184000E-02, 0.17062800E-01, -.50768300E+00, 0.12766600E-01, -.53195200E-01, 0.24602300E-02, -.93683900E-01, -.34306300E-02, 0.21831700E-03, -.21370400E-02, 0.19806500E-01, 0.72907100E-02, 0.78695100E-02, 0.29660100E-02, 0.10844500E-02, -.40234600E-02, -.15897800E-02, 0.58763500E-01, 0.97704200E-02, 0.58779700E-02, -.18249600E-02, -.10322900E-01, -.11380400E-01, 0.14610400E-01, -.74629300E-02, -.90688600E-02, -.90152800E-01, 0.40790500E-01, 0.76961300E-01, 0.38479700E-01, 0.11079200E-01, 0.32104200E-02, -.84936500E-02, 0.35941800E-01, 0.86127000E-02, -.22328200E-02, 0.11382400E-01, 0.33633300E-02, 0.10309200E-01, 0.15578500E-02, 0.13178300E-02, -.30684900E-01, 0.87213100E-03, 0.38726800E-01, -.84837700E-02, 0.62472900E-01, -.49802100E-03, -.37666200E-03, -.40015300E-02, 0.34026400E-02, -.88655000E-02, 0.39992900E-02, -.78125300E-01, -.98741300E-02, -.58924200E-02, 0.23216900E-01, 0.19070800E-01, -.29060400E-02, -.19131600E+01, 0.19700800E+00, 0.16414000E+01, 0.71339000E+01, -.34763900E+01, 0.24924900E-02, -.35667800E+01, -.19894000E+01, -.74583000E+00, 0.47719900E+00, 0.23836800E+01, -.20807600E+01, -.55019400E+00, -.48844900E+01, -.47660800E-01, -.15294600E+00, -.13581700E+00, -.77983200E-02, -.12780200E+00, -.13368900E+00, 0.10856300E+00, -.99007000E-01, -.17229100E-01, 0.37712800E-01, 0.35361500E-01, -.83187800E+00, 0.15343300E+00, 0.11864000E+00, -.86544800E+00, -.96125500E-01, 0.34602900E-01, -.39587400E-01, -.80726700E+00, 0.10590400E+00, -.62425800E-01, -.15598000E-01, 0.84016700E+00, 0.94556600E-02, 0.19421600E+00, -.24710300E+00 },
        { -.24351100E+01, 0.32257300E+00, 0.13123300E+00, -.19806800E+00, -.19687400E+01, -.25518600E+00, -.72350700E+00, -.12266000E+00, -.97038200E+00, 0.16227100E+01, 0.46770200E-01, -.22747400E+00, 0.60457300E+00, 0.21288400E+00, -.78151600E+00, -.15825000E+00, -.60315000E+00, -.33363500E+00, 0.54839000E+00, -.93364800E+00, 0.65832100E+00, 0.20499600E-01, 0.11099100E+00, -.23954400E+00, 0.15293600E+01, 0.56434800E-03, -.16226000E+00, -.42687700E-01, -.30248200E+00, 0.25413600E+00, 0.19320800E+00, 0.11057400E+01, 0.70020600E+00, -.17653900E+00, 0.11883700E+00, -.80946200E-01, 0.48271400E-01, 0.41079000E+00, -.72836800E+00, 0.55168600E+01, 0.37499100E-01, 0.33856900E+00, -.33689600E+00, -.26348500E+00, 0.59287400E+00, 0.16674000E+00, 0.23072900E+00, 0.22595600E-01, -.91291100E-01, -.70431700E-01, -.71974600E+00, -.26017300E+00, -.60847400E-01, -.44982400E-01, -.18913500E+00, -.32416700E+00, -.14977000E+00, -.10107600E+00, 0.34599400E-01, -.29025200E+00, 0.68880000E+00, 0.40137500E+00, 0.13926200E+00, -.29656600E+00, 0.36994900E+00, 0.39463300E-01, 0.41322400E+00, 0.66546800E-01, 0.67003200E-01, -.95556000E-02, 0.45941900E-01, 0.14790700E+00, -.34031100E+00, 0.26301200E+00, 0.67151100E-01, -.30411000E+00, 0.19755200E-01, 0.19229600E+00, 0.38623300E-01, 0.35144900E-01, 0.16523200E-01, 0.10107000E+00, -.28906500E+00, 0.13125700E+00, -.60130500E+00, -.12757700E+00, -.13533200E+00, 0.28516100E-01, 0.49030400E+00, -.38211900E-01, 0.47288600E+00, -.71849100E-02, -.32059700E-01, 0.25562300E+00, 0.13178300E+00, 0.10701400E+00, 0.96212600E-01, -.21298800E+00, 0.25227500E+00, 0.21352000E-01, 0.54119300E-01, -.17328800E+00, -.11691200E+00, 0.34984400E-02, 0.62886600E-01, -.25029700E+00, -.37500400E+00, -.14995000E+00, 0.12891300E+00, -.16167700E-02, -.10830300E+00, 0.73137500E-01, -.21817300E-01, 0.10766000E+00, -.16653400E-01, -.10326200E+00, 0.74210800E+00, 0.14691700E+00, -.70993700E-02, -.24707100E+00, 0.13522300E+00, -.41208100E-01, 0.38861200E-01, -.32555900E-01, -.10827400E-01, -.11265100E+00, 0.37137900E-01, -.39039600E-01, 0.21350700E+00, 0.36459500E-01, 0.24127500E+00, -.89285900E+00, 0.98784000E+00, 0.25641100E-02, 0.17791600E-01, -.10131100E-02, -.44684500E+00, -.25018000E+00, 0.59781100E-01, 0.97145300E-01, -.64098200E+00, 0.29246700E+00, 0.28891300E+00, 0.41189600E-02, -.18110700E-01, 0.35400900E+00, 0.54851500E-02, 0.12038200E+00, 0.60930100E-01, 0.17566300E+00, 0.96957400E-01, 0.97851000E-01, 0.84666500E+00, -.15147300E+00, 0.50875700E-01, 0.25733200E-02, 0.78559600E+00, -.11365000E-01, -.13849200E+00, 0.69798200E+00, -.35149900E-01, -.17159500E+00, -.10088900E+00, -.77831300E-01, 0.37542300E-01, 0.16267800E-01, 0.26860900E+00, 0.84778000E-01, -.26208400E-01, 0.73850900E-01, 0.10917800E+00, -.60516600E+00, 0.12316000E+00, 0.64647100E-01, 0.10339300E+00, -.97413600E-01, 0.72155300E-02, 0.73421400E-01, -.15735900E-01, -.34495200E+00, 0.11357000E+01, 0.93174300E-01, -.38445300E+00, 0.80924300E-01, 0.41012900E+00, -.95520700E-02, 0.43548500E-01, -.97848300E-01, -.84478700E-01, 0.31117200E-01, 0.48019100E-02, -.52673700E-01, 0.18559000E-01, -.13825900E+00, 0.55552000E+00, 0.20931100E+00, 0.10175000E+00, 0.11887200E+00, 0.56640300E-01, 0.53229800E-01, 0.45392900E-01, -.18724200E-01, -.45299200E-01, 0.21185400E-01, 0.61600800E-01, -.15521900E+01, 0.19400200E+00, -.50321700E+00, 0.38354700E-01, 0.73275400E-01, -.97176000E-01, 0.21278500E+00, -.21730200E-01, 0.12258000E+00, -.63726000E-01, 0.45749100E+00, -.10680500E+00, -.15412500E-03, -.12823500E+00, 0.26237100E-01, 0.46600800E+00, 0.42078300E-01, -.71979200E-01, 0.27345400E-01, 0.85819600E-01, -.77925200E-01, -.76955700E-01, -.19409800E-02, -.65964000E-01, -.54083700E+00, 0.52844900E+00, 0.41532400E+00, 0.56364000E+00, 0.10827200E+00, 0.13696500E-01, 0.26251100E-02, -.24885400E+00, -.12449100E+00, 0.51632800E-01, -.10694900E+00, -.35921900E-01, -.56211300E-01, 0.17627200E-02, -.53846600E-01, 0.65983800E-01, -.18961800E-01, -.16789600E+00, 0.42005600E-01, -.96882100E-02, 0.10231200E+00, -.38222600E-02, 0.85504200E-01, 0.11333300E-01, 0.24172700E+00, 0.67617200E-01, -.14384100E-01, 0.17637200E-01, 0.14219400E-01, 0.21837300E+00, 0.73368400E+00, -.18422700E-02, 0.13814100E+00, 0.31063100E+01, -.75128500E+00, -.91134400E+01, 0.37736600E+01, 0.52890100E+01, 0.45941300E+01, 0.41801600E+01, -.40220900E+01, 0.96461700E+01, 0.11788700E+01, -.95916700E+00, -.15332900E+01, 0.84926200E+01, -.38288900E+00, 0.20191800E+00, 0.27575100E+00, -.60845200E-01, -.31303700E-01, 0.52837900E-01, -.17084200E+00, -.31257600E+00, 0.55613800E-01, -.59876200E-01, -.21658000E-01, -.48015200E+00, -.33342200E+00, 0.78260900E-01, -.53301500E+00, 0.55184500E+00, -.53563100E+00, -.16854000E-01, -.50762300E+00, -.51458500E-01, -.24593700E+00, -.29159400E+00, 0.47340700E+00, 0.17652200E+00, 0.46789200E+00, -.94098300E-01 },
        { 0.14931900E+02, -.29039100E+01, -.63100400E+00, -.69262600E+00, 0.45207100E+01, 0.17436900E+01, 0.13938900E+02, -.17157400E+01, 0.86649700E+01, -.11026100E+02, -.71328000E-01, 0.12472400E+01, 0.53751200E+01, -.56750500E+01, 0.72438600E+01, 0.10302400E+01, -.18115600E+01, -.68442900E+00, -.24461700E+01, 0.34009500E+01, -.11797400E+01, -.39104300E+00, 0.46776000E+00, 0.73647800E+00, -.38976600E+01, -.44626600E-01, 0.20669800E+00, 0.17379000E+01, 0.14605800E+01, 0.94137500E+00, -.59302700E+00, 0.17075200E+01, -.18847200E+01, -.14092200E+01, -.77820400E+00, 0.44972700E+00, -.68996500E-01, -.13618600E+01, 0.15106400E+01, 0.52637800E+01, -.48855900E+00, -.26794300E+00, -.53227000E+00, -.56653200E+00, 0.64856800E-01, -.23780700E+00, 0.24555900E+00, 0.42622100E-01, 0.45700700E-02, -.28579500E+00, 0.13598400E+01, -.50109200E+00, -.29237500E+00, 0.45677600E+00, -.34435900E+00, 0.45933600E+00, 0.40126300E+00, -.21508200E+00, -.49974000E-01, 0.16735800E+01, -.16417400E+01, -.56078000E+01, -.24855700E+01, 0.98710400E+00, -.21887100E+00, -.15370000E+00, -.99071900E+00, -.15907600E+00, 0.69179600E-01, 0.67844700E-01, 0.20786100E+00, 0.75575900E-02, 0.42337100E+01, 0.96469600E+00, 0.12366900E+01, -.25062600E-01, -.20556300E+00, 0.23429400E+01, 0.17140000E-01, 0.19683900E+01, 0.53036000E+00, 0.29849900E+00, -.31054700E+01, -.75491300E+00, -.28089400E+00, -.13723700E+01, 0.25631000E+01, 0.58784900E+00, 0.62775800E+01, 0.14515700E+01, 0.53085300E+01, -.15847400E+00, -.15451600E+01, 0.56608700E+00, 0.23901000E+01, -.22367600E+01, 0.94361900E+00, 0.19790300E+01, 0.10679400E+01, -.17034100E+00, -.10816000E+01, 0.18654700E+01, 0.19993000E+01, -.18343000E+01, 0.13936200E+01, 0.15190500E+01, 0.21746900E+01, 0.53611200E+01, -.15587600E+00, 0.42203700E+00, -.20404700E+01, 0.58526600E+00, -.40256800E-01, 0.12525000E+01, 0.35380100E+01, -.43786300E+01, 0.93078800E+01, 0.18567100E+01, -.10028500E+01, -.24705500E+01, 0.26014300E+01, 0.10081200E+01, 0.61123900E-01, -.21281100E+01, -.16533800E+00, -.89458000E+00, -.43641700E+00, -.17272200E+01, -.19841900E+01, -.32422800E+01, -.94065100E+00, 0.59158400E+01, 0.80525800E+00, 0.11723200E-01, -.52429800E+00, -.18836700E-01, -.15592800E-02, 0.15559200E+00, -.66430700E+00, 0.25826800E+01, 0.16621900E+01, -.85675800E+01, -.61959100E+01, 0.57517200E+00, -.61686900E+00, -.25616800E+01, -.13673500E+00, 0.77309700E+00, 0.83444700E+00, -.35256700E+01, -.57042300E+00, 0.14234800E-01, -.36176600E+01, 0.14495000E+01, -.14330400E+00, -.64314500E+00, -.11776300E+01, -.19642800E-01, -.20037300E-01, -.52464900E+01, 0.38933800E+00, 0.19527400E+01, -.59119600E+00, 0.31668200E+00, 0.22385700E-01, -.52924700E-02, 0.80698200E+00, -.12703300E+01, -.52639400E+00, 0.83006600E+00, 0.74202700E+00, -.23748500E+01, -.44803100E+00, 0.39038900E-01, -.95500300E+00, 0.42526600E+01, -.26254000E+00, -.10109500E+01, -.50119000E+00, 0.14917600E+01, -.66138300E+01, -.79003900E+00, 0.16497500E+01, 0.31999100E+00, -.28164400E-02, 0.43157200E+00, 0.44782900E+00, -.12540300E+01, -.13971100E+00, 0.56916300E-01, -.40809300E-01, 0.14044400E+01, 0.60743800E-01, 0.28020200E+01, 0.66199800E+00, 0.53252900E+00, -.12975800E+01, -.65032600E+00, -.36854300E+00, -.68999400E-01, -.34327500E+01, -.26830600E+00, -.41964600E+00, -.43392100E+00, 0.16992300E+01, 0.19235500E+02, 0.26246700E+01, -.50749300E+01, 0.80562500E+00, 0.98704500E+00, 0.29122900E+00, 0.19822900E-01, -.58949300E-01, -.35746100E+00, 0.30007100E+00, -.29401100E+01, -.77678800E+00, -.22410900E+00, -.20449500E+00, -.27003200E+00, -.43867400E+01, -.63733600E+00, 0.26696600E+00, -.10641600E+00, 0.95287900E+00, -.12825500E+00, -.77802000E+00, 0.65737900E+00, 0.43964100E+00, 0.93821100E+01, -.30579000E+00, -.53414800E+00, 0.13090400E+01, -.89668300E+00, -.13736100E+00, -.62914300E-01, -.25430800E+01, 0.51031900E+00, -.35470700E+00, 0.63563500E+00, 0.79636400E+00, 0.34116500E+01, -.53573700E+00, 0.58971200E+00, -.44116000E+00, 0.11331300E+00, -.40903300E-01, -.30906200E+00, 0.22691600E+01, -.47996800E+00, 0.11665200E+00, 0.10841100E+00, 0.55298000E+00, 0.13894800E+01, -.17477700E-01, -.11911000E+02, -.11009400E+00, -.82667900E+00, 0.87087500E+00, 0.33435200E+00, -.12550900E+01, 0.30113400E+02, -.11222200E+01, -.83052500E+02, -.95310400E+02, 0.43941400E+02, -.20534000E+03, 0.47810300E+02, -.15065700E+02, 0.13488400E+02, -.30307400E+01, -.22740200E+02, 0.13336700E+03, -.11764700E+02, 0.11104900E+03, 0.57410700E+01, 0.35893900E+01, 0.60012200E+01, -.41068300E+01, 0.11203400E+02, 0.12042100E+02, 0.38469900E+01, 0.20043700E+01, -.29513300E+01, -.84122700E+01, 0.11093500E+02, 0.15898400E+02, 0.46078200E+01, -.30662700E+01, 0.16744400E+02, -.37431500E-01, -.24377600E+01, -.27317600E+01, 0.14825300E+02, 0.28250800E+01, -.95551100E+01, -.80625600E+01, -.16967000E+02, 0.96674900E+01, -.21599300E+01, -.56815100E+01 },
        { -.30107500E+01, 0.12913400E+01, 0.29533200E+00, 0.10278800E+01, -.10614400E+01, -.34655000E+01, -.94143600E+00, 0.49626800E+00, -.16702600E+01, 0.13587400E+01, 0.96146900E-01, -.18241500E+00, 0.89138100E+00, -.11137700E+01, 0.10745200E+01, 0.14792200E+01, 0.15040600E+00, -.25574600E+00, -.12191500E+01, 0.88174400E+00, 0.26731200E-01, 0.24730700E-01, 0.24321100E+00, 0.44952900E+00, -.74996300E+00, -.52079000E-01, -.21065000E+00, 0.51097800E+00, -.33009200E+00, 0.14002600E+01, -.47673300E+00, -.28841900E+00, -.10216400E+00, 0.96094900E-01, 0.28961800E+00, -.54151600E+00, 0.25233300E+00, -.22024900E+00, 0.58783000E-01, -.64799400E+01, 0.90454800E-01, -.41063100E+00, 0.94330100E+00, 0.80252000E+00, -.28002600E+00, 0.12460400E+00, 0.18368900E-01, -.27503400E-01, 0.70217400E-01, -.22731100E+00, 0.16385600E+01, 0.24354200E+00, -.19368000E+00, -.28565100E+00, -.58744200E+00, -.86326200E-01, -.20242600E+00, 0.14957400E+00, -.80847600E-01, 0.14299100E+00, -.10567700E-01, -.81989900E+00, -.54670600E+00, -.31542200E+00, 0.41247000E+00, 0.28173200E-03, -.62441700E+00, -.15076200E+00, 0.12269900E+00, 0.16543600E-01, 0.11622800E+01, -.19597200E+00, -.37021100E+00, 0.29457300E+00, 0.22729100E+00, -.67252100E+00, -.10562000E+00, 0.61619300E+00, 0.58539400E+00, -.99406400E+00, 0.12562400E+00, 0.25690000E+00, 0.93693100E+00, -.73484600E-02, -.21463700E+01, -.48249000E+00, -.82495300E+00, 0.18512600E+00, -.15291100E+01, 0.51123500E+00, 0.20091500E+01, 0.73274200E-01, 0.17899000E+00, 0.86725100E+00, -.18532100E+00, -.70319000E+00, 0.18468600E+00, 0.74965100E-01, 0.30692400E-01, -.22277600E+00, 0.13391700E+00, -.38514900E+00, -.48873300E-01, 0.28590500E+00, 0.96226000E-01, -.56472900E+00, -.47079900E+00, -.69272900E+00, -.91950100E+00, -.17863800E+00, 0.10693400E+01, -.13321500E+00, -.57700400E-01, 0.35264700E+00, -.16759900E+00, 0.57644200E-01, 0.17605000E+00, 0.17174100E+00, 0.10720600E+00, -.37492800E+00, -.66019600E+00, 0.21140400E+00, 0.23650600E+00, 0.42887000E+00, -.10004700E-01, -.38984400E+00, 0.83495100E-01, 0.32213000E+00, 0.38017400E+00, 0.37316600E+00, -.11407700E+00, 0.26915200E+01, 0.31321800E+00, 0.25942100E-02, 0.34697700E-01, -.10101300E-01, 0.73318600E+00, -.47433300E+00, 0.89836200E-02, -.15952300E+01, -.70231200E+00, -.97873500E+00, -.26750300E+00, 0.12820900E+00, 0.30519000E-01, -.13605900E+00, -.31146100E-01, 0.15965400E+00, 0.14536000E+00, -.28996200E+00, -.56716500E-01, 0.54841200E-01, 0.26013200E+00, 0.14813800E+00, -.15462200E+00, 0.33510000E-01, -.23685800E+00, -.74159900E-02, -.59461400E+00, 0.24545100E+00, 0.52073000E-01, 0.18562200E+00, 0.45586600E+00, -.32547200E-01, -.18712100E+00, -.10809900E-01, 0.32214300E+00, -.26902100E+00, -.41102400E-01, 0.46934400E-01, 0.10312500E-01, -.25447500E+00, 0.11057200E+00, -.10391500E-01, 0.20065900E+00, 0.60019600E+00, -.79280900E-01, 0.27831500E-01, -.99975700E-01, -.11918700E+00, -.37999600E+00, 0.14107600E+00, -.13973500E+00, -.11190300E+00, -.10569700E+00, 0.48602200E-01, -.22974200E-01, 0.36651800E+00, 0.90174900E-01, 0.10705100E+00, 0.11353000E-02, 0.21878000E+00, 0.19257800E-01, -.10518200E+00, 0.91319600E+00, 0.32636600E+00, -.22844100E+00, 0.10481800E-01, 0.46805500E-01, 0.63831300E-01, -.88206300E+00, -.29981400E-02, -.32236700E-01, 0.27293900E+00, 0.11038700E+01, -.35869000E+01, -.75690200E-01, -.18124700E+01, 0.39730100E+00, -.32306400E+00, 0.18491400E+00, 0.18127900E+00, -.11823700E-01, -.68858300E-01, 0.38515700E+00, -.10329800E+01, -.13550900E+00, 0.36479400E-01, -.59722000E-01, -.72585000E-01, 0.13803200E+01, 0.26695800E-01, -.38005700E-01, 0.73203500E-02, 0.47714400E-01, 0.65856800E-01, -.79091500E-01, -.58684900E-01, -.44304500E-01, 0.31385800E+00, -.33452500E+00, -.23670600E+00, -.23908200E+00, -.13759100E+00, 0.56324500E-01, 0.15918600E-01, 0.58724600E+00, 0.22545000E+00, -.49270600E-01, 0.13956000E+00, -.76462300E-01, -.22418500E+00, 0.84695000E-01, 0.43876800E-01, -.16162200E+00, 0.15745300E-03, 0.23059200E+00, 0.19037500E+00, 0.12653100E+01, -.32269700E+00, 0.35298900E-01, 0.65329500E-01, 0.11227900E+00, 0.19271400E+00, -.87551000E-02, 0.10910600E+01, 0.43522000E-01, 0.17251300E-01, 0.92785000E-01, 0.42712500E-01, 0.35559500E-01, -.29179800E+01, 0.13073800E+00, -.76798600E-02, 0.62985800E+02, -.34028000E+02, -.12676600E+02, -.31334800E+02, -.23978000E+02, -.13673700E+02, 0.48624400E+01, 0.34951900E+02, 0.28515600E+02, -.15431200E+02, -.53643500E+02, 0.10854100E+01, 0.31667400E-01, -.16161600E+00, -.48599700E-01, -.17484500E+01, 0.32836000E+00, 0.59098600E+00, 0.74055200E+00, -.51833800E+00, 0.23083400E+00, -.14087200E+00, -.12432200E+01, 0.92702700E+00, 0.18198800E+00, -.15721100E+01, -.89936600E+00, 0.38466200E+00, 0.10363600E+00, -.16911700E+01, 0.10272800E+01, 0.82938800E+00, -.17828100E+00, 0.11831000E+01, 0.17025400E+00, 0.52207200E-01, -.41456800E+01 },
        { 0.10355400E+02, -.24623900E+01, -.45152300E+00, 0.26753300E+01, 0.53524400E+01, -.49510400E+01, 0.12072000E+02, -.10395300E+02, 0.63866300E+01, -.83550800E+01, -.60725800E-01, 0.64094400E+00, 0.32635800E+01, -.11078100E+02, 0.10365800E+02, -.12776500E+01, -.48010200E+00, 0.39676800E+01, -.31797000E+01, 0.95060200E+00, -.10152900E+01, -.13151400E+00, -.26004900E+00, -.51573500E+00, 0.43796900E+01, 0.16549900E+00, 0.26140100E+01, 0.55928900E+01, -.50200800E+01, 0.28662900E+01, -.16263600E+01, -.20595800E+01, -.17478700E+00, -.14438800E+01, -.90919700E+00, -.17811500E+01, -.55220700E+00, -.98207000E+00, 0.39775400E+01, -.87013800E+01, -.14739700E+00, 0.16286000E+00, 0.13869100E+01, 0.73620800E+00, -.25277700E+00, 0.53161700E+00, 0.12150100E+00, 0.51443200E-01, -.42591600E+00, -.90516800E+00, -.24722600E+01, -.12716300E+01, 0.16573100E+01, -.88022300E+00, 0.94462100E-01, 0.16028300E+00, -.15904000E+00, 0.13750400E+00, -.16112300E-01, 0.93232000E+00, 0.13834100E+01, -.51118100E+00, -.12163500E+01, 0.13626100E+01, -.11987700E+01, 0.11021800E+00, -.13464700E+01, -.79270900E-01, -.46619500E+00, 0.82616600E-02, 0.35591200E+00, -.28725100E+00, 0.47334500E+01, -.40780500E+00, -.79033600E+00, 0.17771300E+01, -.76646900E+00, 0.48549500E+00, 0.25685700E+00, -.33182300E+00, -.75749700E-01, 0.22790900E+00, -.17914100E+01, 0.62886900E+00, 0.22252200E+00, 0.18008100E+00, -.91909300E-01, 0.14039200E+01, 0.46207500E+01, -.24224200E+01, -.11310700E+01, 0.41850500E-02, 0.10325600E+00, 0.44056700E+00, 0.35993000E+00, 0.77941700E+00, -.87122500E-01, 0.17013700E+00, 0.56123900E+00, 0.53813900E-01, 0.22180600E+00, 0.31212600E+00, -.36982400E+00, 0.48603500E+00, -.25989500E+00, 0.75675000E+00, -.51131500E+00, 0.11357300E+01, -.18390700E+01, -.49169400E-01, 0.63292700E+00, -.19415800E+00, -.27582000E+00, 0.98039400E+00, -.93938600E+00, -.11988900E+01, 0.54064900E+01, 0.11441600E+01, 0.25076200E+00, -.69169700E+00, -.45846300E+00, -.55677200E+00, 0.13115800E+00, -.32664900E+00, -.50859500E-01, -.28010500E-01, -.20150600E-01, -.32723800E+00, 0.11580900E+00, 0.14862600E+00, -.92410700E+00, 0.46519100E+00, -.10517400E+01, 0.23096900E-02, 0.25443400E+00, 0.11160200E-01, -.74886300E+00, -.14639600E+00, -.20718600E+00, 0.14316800E+01, -.46903400E+00, 0.19354700E+01, 0.24235700E+01, -.14231400E+00, 0.11121600E-01, 0.93396300E+00, -.16634200E+00, -.25594300E+00, -.24576700E+00, 0.94741500E+00, 0.37778400E+00, -.62169200E+00, -.36504800E+00, 0.98046300E+00, -.10618800E+00, -.30602500E+00, 0.33318500E+01, 0.26366700E-01, 0.13622400E+01, -.12307800E+01, 0.82590900E-01, -.22353000E+00, -.20604200E+01, 0.24577500E+00, -.29157600E+00, -.63002500E-01, 0.14454800E+01, -.31128800E+01, -.76956900E-01, -.90180300E-01, 0.39112500E+00, -.80323900E+00, 0.20509800E+00, 0.82504700E-02, -.32165700E+00, -.23107900E+01, 0.38202300E+00, 0.10601200E+01, 0.23215700E+00, -.11737700E+01, 0.42042700E+01, 0.19678700E+00, 0.55111400E-01, 0.29747600E+00, -.96044800E-01, 0.93552600E-01, 0.57356400E-01, 0.12819100E+01, -.18735100E+00, 0.42964000E+00, 0.14222700E+00, -.15247600E+00, -.42025900E-01, -.26542400E+00, -.14736900E+01, -.48187400E+00, 0.81368700E-01, 0.10851000E+00, 0.29427100E+00, -.10396100E+00, -.12116400E+00, -.90693100E-02, 0.27081100E+00, 0.51926700E-01, -.40764800E+00, -.66650500E+01, -.13588900E+01, -.25370500E+01, 0.21784100E+00, -.15605300E+00, -.24526500E-01, -.74925400E-01, -.18715600E-01, -.10798300E+00, 0.19855400E+00, -.36554400E+00, 0.11940300E+00, -.11577600E+00, 0.11009600E+00, -.20180600E-01, 0.24917100E+01, -.23598300E-01, -.33447200E-01, 0.63186000E-02, -.15627200E+00, -.11709200E+00, 0.31015800E+00, -.20465600E+00, -.11831400E+00, -.26518100E+01, 0.55213600E+00, 0.21214700E+01, 0.78776000E+00, -.10863200E+00, -.20693700E+00, -.48432100E+00, 0.62377300E+00, -.18246400E+01, 0.44948100E-01, 0.68622400E+00, 0.99254700E+00, 0.38493900E+01, -.22331000E+00, 0.45291900E+00, -.28402400E-01, 0.13832700E+00, 0.87527500E+00, -.34436800E+00, -.23691000E+01, 0.49101800E+00, -.28802800E-01, 0.56292800E-01, 0.13826200E-01, -.47240300E+00, 0.20738800E+00, -.31826300E+01, 0.13662300E+00, 0.22473000E+00, -.15775900E+00, -.37324800E+00, -.18020500E+00, 0.17818100E+02, -.53442100E+00, -.13154400E+00, 0.13296600E+01, -.21514500E+02, -.22341000E+02, 0.37250100E+00, 0.23506400E+02, -.37650900E-01, -.21545400E+02, -.88802200E+01, 0.10048600E+03, -.66241400E+01, 0.48365100E+02, 0.57408600E+01, 0.46876600E+01, 0.37547200E+01, 0.17796000E+01, 0.12116100E+02, -.37387900E-01, 0.24205500E+01, 0.83924100E+00, 0.15636600E+01, 0.60924200E+00, -.17947300E+00, 0.34458900E+02, 0.41982000E+01, 0.69548300E+00, 0.36127500E+02, -.23318500E+01, 0.60665300E+01, 0.36973700E+01, 0.30790500E+02, 0.33910500E+01, -.22750100E+01, 0.13536400E+01, -.37340600E+02, -.93054200E+00, -.10551500E+01, -.12666700E+02 },
        { 0.15791100E+02, -.21614200E+01, -.45359200E+00, 0.44408400E-01, 0.67647600E+01, 0.41767100E+01, 0.11572000E+02, -.16283700E+00, 0.79050000E+01, -.12465500E+02, 0.26210900E+00, 0.12561800E+01, 0.37955200E+01, -.37996800E+01, 0.61685200E+01, -.82939100E+00, -.64754900E-01, 0.55408800E+00, -.14763300E+01, 0.28021600E+01, -.10402100E+01, -.29139200E+00, 0.10185100E+00, 0.45346900E+00, -.19217200E+01, 0.84456000E-01, -.74236500E-02, 0.18628400E+01, 0.11680900E+01, -.52866400E+00, -.15157000E+00, -.11865700E+01, -.20320400E+01, -.99128000E+00, -.87794200E+00, 0.28991600E+00, -.36453500E+00, -.12352700E+01, 0.12744200E+00, -.68287300E+00, -.33564400E+00, -.45974100E+00, -.61438500E+00, -.55963700E+00, -.36902200E+00, -.40211300E+00, -.47296600E+00, 0.48808200E-01, 0.12619700E+00, -.74261700E-01, 0.75514900E+00, 0.64585800E-01, 0.33837400E+00, 0.10777000E+01, 0.53929100E+00, 0.59297700E+00, 0.10529800E+01, -.18118800E+00, 0.64738200E-01, 0.14136100E+01, -.11396100E+01, -.41744700E+01, -.20505500E+01, 0.17040300E+01, -.11729400E+01, 0.28914100E-01, -.16902900E+01, 0.97113600E-01, -.40601500E+00, 0.14574500E+00, -.30334200E+00, 0.34601800E+00, 0.31951700E+01, 0.70135500E+00, 0.85619100E+00, -.28283000E+00, 0.23503400E+00, 0.56710700E+00, -.41269500E+00, 0.13579800E+01, 0.54117700E-01, 0.31931000E+00, -.10139700E+01, -.95267400E+00, 0.69102200E+00, -.58886400E+00, 0.24800400E-01, 0.45702000E+00, 0.66880000E+00, 0.15364100E+01, 0.18408500E+01, -.83295600E-02, -.37198200E+00, -.32688300E+00, 0.10902500E+01, -.24610200E+01, 0.41796200E+00, 0.41361900E+01, -.74044600E+00, -.13554200E+01, -.12892500E+01, 0.16781400E+01, 0.21232700E+01, -.29834400E+01, 0.13249100E+01, -.92190900E+00, 0.63787700E+00, 0.26222600E+01, 0.12874000E+00, 0.55446100E+00, -.30646000E+00, -.42782400E-01, 0.17570500E+00, 0.34509700E+00, 0.51989300E+00, -.20896900E+01, -.10044700E+01, 0.13760500E+01, 0.59022600E+00, -.11479200E+01, 0.14343400E+01, -.65468500E-01, 0.71239600E-01, -.61646200E-01, 0.97798200E-01, -.47152600E+00, -.18391000E+00, 0.45988100E+00, -.94778300E+00, -.47447300E+00, 0.21310600E+00, 0.54367800E+01, -.83245500E+00, 0.22142000E-01, -.84940000E-01, -.35250200E-01, 0.83217800E-02, -.87962100E-01, -.37744700E+00, -.14212700E+01, 0.50441800E+00, -.40339400E+01, 0.57159500E+00, 0.10341500E+01, -.11312500E-01, -.14109900E+01, -.11097800E+00, 0.26500000E+00, 0.51320900E+00, -.20356100E+01, -.78549300E+00, -.99099600E+00, -.31000900E+01, -.63396700E-01, -.46256000E+00, 0.67281400E-01, -.26227600E+01, 0.10969400E-01, -.15914500E+00, -.34139500E+01, 0.33603400E+00, 0.18392800E+01, -.55147900E+00, 0.45952700E-01, -.31824300E-01, 0.24437100E-01, -.35274400E+00, 0.83224700E+00, -.31075800E+00, 0.43620800E+00, 0.40554600E-01, -.11591700E+01, -.59014900E+00, 0.25796500E+00, -.17850800E+00, -.14679800E+00, -.40531800E+00, -.12178000E+01, 0.13863400E+00, 0.17627000E+01, 0.20709100E+01, -.20486700E+00, 0.18221400E+01, -.86545600E+00, -.59981700E+00, -.12158300E+00, 0.24479300E-01, -.21757600E+01, 0.27164500E+00, -.28558700E+00, -.34533300E-01, -.61262900E-01, -.41212300E+00, 0.14159000E+01, -.16782700E+01, -.91338500E+00, -.11540800E+01, -.75256900E+00, 0.63923800E-01, -.34355200E+00, -.22194300E+01, 0.17805200E+00, -.59318300E+00, -.31843000E+00, 0.87106000E+00, 0.17585400E+01, -.88827400E+00, -.39076200E+00, 0.55261800E+00, -.10763100E+01, 0.72786500E+00, -.37476200E+00, 0.23821400E-01, -.48556600E+00, -.52179700E-01, -.38239500E+01, 0.63197400E+00, 0.24782600E-02, 0.70679600E+00, -.33672700E+00, 0.53466700E+01, -.61098900E+00, 0.10094500E+00, 0.61912400E-02, 0.31911000E-01, 0.98903600E-01, 0.42837600E+00, 0.23767300E+00, 0.36215300E-01, 0.65064300E+00, -.10208800E+01, 0.23207500E+00, -.80717600E+00, -.41718100E+00, -.12660600E+00, -.71526600E-01, 0.12728600E+01, 0.97481800E+00, -.31797100E+00, 0.59472800E+00, 0.33347600E+00, 0.99685000E+00, 0.55618100E-01, 0.60515000E+00, -.96277500E+00, 0.28015100E+00, 0.37801100E+00, -.33879700E+00, 0.31865200E+01, -.41992100E+00, 0.66585300E-02, -.24483200E+00, 0.16091500E+00, -.14761400E+01, 0.10284900E+00, -.49704500E+01, 0.13048500E+00, -.46169800E+00, 0.54340900E-01, -.13343000E+01, -.60480700E+00, 0.27221700E+01, 0.12786400E+00, -.72879100E+00, -.20624500E+01, 0.61021400E+00, -.28213800E+03, -.70673200E+00, -.52209500E+02, -.65447100E+01, 0.50718900E+02, 0.46923700E+02, 0.13890000E+03, -.41399300E+02, 0.25545100E+02, 0.40016000E+01, -.33227400E+01, 0.22012000E+01, -.22173900E+01, 0.55435600E+01, 0.13754700E+02, 0.38716200E+01, 0.11837600E+01, -.51150600E+01, -.91716500E+01, 0.13143800E+02, -.20700900E+02, 0.36008100E+01, -.28837100E+01, -.21106800E+02, -.10305600E+01, -.63824100E+01, -.26798900E+01, -.19297200E+02, 0.28972900E+01, -.12026600E+02, -.12099100E+02, 0.21397600E+02, 0.13091500E+02, 0.39583400E+01, -.10840900E+02 },
        { -.58861000E+01, 0.28475100E+01, 0.46459500E+00, -.28372400E+01, -.52058400E+01, 0.74597700E+01, -.71182400E+01, 0.92319000E+01, -.31838400E+01, 0.45188200E+01, 0.91545600E-02, -.31926000E+00, 0.30297100E+01, 0.12628700E+01, 0.41962500E+01, 0.26305600E+01, -.37336000E+01, -.44728600E-01, -.88781600E+00, 0.43410100E+00, -.28080300E+00, 0.22019100E+00, 0.16825500E+00, 0.52193700E+00, -.28188400E+01, 0.51650400E+00, -.11936600E+01, -.56138200E+00, 0.10990200E+01, 0.16405000E+01, 0.23087300E+00, 0.22925600E+00, -.73854600E+00, -.70892900E+00, -.16279800E+00, -.36189200E-01, -.13496400E+01, -.19483600E+01, -.51742700E-01, -.14770200E+02, 0.46491900E-01, -.26738700E+00, 0.12807600E+01, 0.83872700E+00, -.14105700E+01, -.17813500E+00, 0.27157900E+00, -.34153200E-01, 0.21019400E+00, -.39584500E+00, -.15874700E+01, 0.56704400E+00, 0.88853500E+00, 0.15828300E+00, 0.15001700E+01, 0.19370500E+00, 0.93166400E+00, 0.20163900E-01, 0.33761500E-01, 0.26406100E-01, -.80512000E-01, -.92197900E+00, -.83214000E+00, -.60548300E+00, -.52723700E-02, -.11904000E+00, -.15265800E+00, -.36582700E+00, -.19750100E+00, 0.14210500E+00, -.10276800E+01, 0.32455200E+00, 0.15031600E+01, 0.20831800E+00, 0.90510000E+00, 0.21936400E+00, -.11971400E+00, -.67178300E+00, -.22147400E+00, 0.91576100E-01, -.84891000E-01, 0.85494000E-01, -.63287500E+00, -.17154400E+00, 0.35533700E+00, -.87477600E-01, 0.21317500E+00, -.10009600E+01, 0.54079800E+01, -.45705400E+00, -.12506900E+01, -.64646200E-01, 0.61162400E+00, -.23478800E+00, 0.54545200E-01, -.24539000E+01, 0.62125800E+00, 0.99890900E-01, 0.49892100E+00, 0.43696000E+00, 0.28230800E+00, -.43740500E+00, 0.15697700E+01, -.35915500E+00, 0.85904000E+00, 0.33201800E+00, 0.17950000E-02, 0.11916300E+01, 0.27112700E+01, 0.21449900E+00, -.24317200E+01, 0.73042800E+00, -.71228300E-02, 0.51158400E-01, 0.46561700E+00, -.74861000E+00, 0.25978800E+01, 0.28216500E+00, -.19337200E+00, 0.63527100E-01, 0.98871500E+00, 0.47635100E-01, -.65702600E-01, -.12220500E+00, 0.48919800E-01, -.37829100E+00, 0.11497900E+00, -.48186900E+00, -.51556500E+00, -.22690600E+00, 0.17512300E-01, 0.43474800E+00, -.42040100E+00, -.56041600E-02, -.26122800E+00, -.81169000E-02, -.61327300E-01, 0.35980900E+00, -.12030300E-01, 0.17563500E+01, 0.21180700E+00, -.70026600E-01, -.77252600E+00, -.15484400E+00, -.19918600E+00, 0.11115400E+01, -.58013800E-01, 0.21168000E+00, 0.49480100E-01, 0.13477600E+00, 0.97716800E-01, -.12936600E+00, 0.49615900E-01, 0.27884200E+00, -.12732400E+00, -.80861800E-01, -.53936500E+00, 0.26221100E-01, 0.16991200E+00, -.66311000E+00, 0.66554400E-01, -.50687800E+00, -.10115700E+01, -.77593000E-01, 0.52854300E+00, -.25800700E+00, 0.70482800E+00, -.35453500E-01, -.21741700E-01, -.10357600E+00, 0.97342200E-01, -.58601900E+00, -.49088300E-02, 0.27662300E-01, 0.12525600E+00, -.85427500E+00, 0.14585300E+00, 0.33910700E+00, -.19747900E+00, -.35311600E+00, -.85185100E+00, 0.50212100E+00, 0.36056200E+00, 0.49687300E+00, 0.48843000E+00, -.79103700E-01, 0.24843900E+00, -.29868300E+00, -.34548400E+00, 0.26582000E+00, 0.75361200E-01, -.65471100E+00, 0.75508300E-01, -.47551500E+00, -.54943900E+00, -.32887900E+00, 0.52385500E+00, 0.19951400E+00, -.17009600E+00, 0.75700400E-01, 0.11289300E+01, -.15187100E+00, 0.13289900E+00, 0.57304500E-01, -.61246700E+00, 0.45157200E+00, -.93148200E+00, -.10397400E+01, 0.59095100E-01, 0.59819600E+00, -.17801300E+00, 0.10640300E-01, -.16868900E+00, 0.10051700E+00, -.43529600E-01, 0.83265900E+00, 0.17630700E-01, -.11071600E+00, -.83206100E-01, 0.14497300E-01, 0.97709000E+00, -.76866000E-01, -.13644900E+00, 0.12992200E+00, -.98532000E-01, 0.42812900E-01, 0.16131500E+00, -.65303800E-01, -.87552800E-01, -.13752200E+01, 0.52678200E+00, 0.95782900E+00, 0.39888800E+00, 0.19936700E+00, 0.61086200E-01, -.84573200E-01, -.33102900E-01, -.12893600E+00, 0.59547800E-01, -.55401800E-01, -.10390000E+00, -.11168600E+00, -.87239500E-01, -.52960900E-01, 0.24280000E+00, 0.97437900E-01, -.42459600E-02, 0.86963600E-02, -.67021600E+00, -.33140900E+00, 0.46619000E-01, -.28634000E-01, 0.17159800E-01, 0.18209300E+00, -.14328900E+00, -.11491000E+01, 0.16009600E+00, -.21206800E-01, 0.70306500E-01, 0.35854600E+00, 0.58751100E-01, -.15197000E+01, -.63366700E-01, -.72501800E-01, -.10723500E+00, 0.21076600E+00, 0.19861500E-01, 0.10362400E+02, -.57589200E+01, 0.87508500E+01, -.42484700E+01, -.50957400E+01, -.22763800E+02, 0.72287500E+01, -.26104500E+02, -.77988500E+00, -.12921100E+01, -.12598600E+01, -.55416900E+00, -.18561400E+01, -.66389600E+00, -.52440300E+00, -.14529700E+00, -.10642500E+00, 0.24543600E+00, -.54190600E+00, -.74400200E+01, -.72922000E+00, -.17128700E+00, -.77283900E+01, 0.27612900E+00, -.11068900E+01, -.86858400E+00, -.67275900E+01, -.82498600E+00, -.11382200E+00, 0.29497300E+00, 0.79281800E+01, -.36010300E+00, 0.26458800E+00, 0.28202700E+01 },
        { -.21699000E+01, -.57971900E+00, -.18884900E-01, -.48631800E-01, -.11861000E+01, -.15279800E+01, -.10164900E+01, 0.60619600E+00, -.11943800E+01, 0.11964100E+01, 0.64934600E-01, -.11171300E+00, 0.12939400E+00, 0.12431600E+01, -.81703000E+00, 0.58032100E+00, 0.33292700E+00, -.91557500E-01, -.55257700E-01, -.12715300E+01, -.55713600E-01, 0.31168700E-01, -.15827800E+00, -.76723700E-01, 0.76737400E+00, 0.23300400E-01, -.22837000E+00, 0.24425100E-01, -.29231500E+00, -.12263400E+00, 0.23089400E-01, -.12885200E+00, 0.28939700E+00, -.46622800E-01, 0.29154900E+00, -.25725900E+00, 0.26435300E-01, 0.11744400E+00, -.10559600E+01, 0.17205900E+01, 0.63551800E-01, -.33694000E+00, 0.27745700E+00, 0.82562200E+00, -.11167800E+00, -.11135900E-01, 0.45577100E-01, -.26185300E-01, 0.13393900E+00, 0.98348500E-01, 0.22276100E+01, -.22384200E-01, -.41754900E+00, -.64410300E+00, -.27493600E+00, -.35690500E-01, 0.15262800E-01, 0.11525100E-01, -.48927500E-01, 0.29969200E+00, -.67572100E+00, -.13074500E+01, -.61617100E+00, -.33473600E+00, 0.73278300E+00, 0.53840300E-01, -.21949100E+00, -.74694800E-01, 0.18013300E+00, 0.44525300E-01, -.21694400E+00, -.14697700E+00, 0.10762400E+01, 0.68370400E-01, 0.42119200E+00, 0.54625000E+00, -.30780200E+00, 0.65844100E-01, 0.16919500E+00, -.11586300E+00, -.16662800E-01, -.58257900E-01, -.26924600E+00, -.14631500E-01, 0.54865800E+00, 0.29128900E+00, 0.10516000E+01, -.42166200E+00, -.85439000E+00, -.27812300E+00, -.38649700E+00, -.47021100E-02, 0.13359200E+00, 0.10592000E+00, -.27140300E+00, 0.53909900E+00, -.11844700E+00, -.72710500E-01, -.57052100E-01, -.42566200E-01, -.32994800E+00, 0.24432600E+00, 0.14415600E+00, 0.43276000E-01, 0.90825100E-01, 0.27914600E+00, -.13366900E-01, 0.54117500E+00, 0.30249600E+00, 0.92406800E-01, -.68356200E+00, 0.39019300E-01, -.25581500E-01, -.23916200E+00, -.31510100E+00, 0.80991000E+00, -.20554600E+00, -.73339800E+00, -.88616100E-01, 0.31591600E+00, -.67560500E+00, 0.53331800E+00, 0.19294500E-01, 0.75525600E-01, 0.11448700E-01, 0.44925100E+00, 0.24460800E-01, -.46695000E+00, 0.50089400E+00, 0.24631900E+00, -.71054500E+00, 0.61085500E+00, -.10446900E+01, -.41056300E-02, 0.10343800E+00, -.23836700E-02, -.94141000E-01, -.53397100E-01, -.28569200E-01, 0.11063600E+00, 0.31015100E-01, -.38194400E+00, 0.99295100E-01, -.22397500E-01, 0.20908400E-01, 0.25399900E+00, -.17096600E-01, -.12084500E-02, -.15707500E+00, 0.17031100E+00, -.32852100E-01, -.99092000E-01, -.33856600E-01, -.11250500E+00, -.20354500E-01, 0.91342800E-01, -.19288700E+00, -.68330500E-03, -.46516200E+00, 0.22254500E+00, 0.15683700E-01, -.60793300E-02, 0.43930300E+00, -.14526500E+00, -.76620900E-01, 0.91182500E-01, -.86618100E-01, 0.45368800E+00, -.24683600E-01, 0.18858800E-01, -.37578600E-01, -.48365400E+00, 0.42177100E-01, -.50379500E-01, 0.27822300E+00, -.63125200E+00, 0.73461400E-01, 0.10230500E+00, -.11986800E+00, -.26401600E+00, -.63367900E+00, 0.11833400E+00, 0.53653900E-01, 0.79224800E-01, -.25224700E+00, 0.87724400E-01, -.83567900E-01, 0.33183000E+00, 0.65848400E-01, 0.55618400E-01, -.31972900E-02, 0.22093500E+00, 0.22596600E-01, 0.73088600E-01, 0.30097700E-01, -.56882400E-01, 0.27307500E-01, -.79474200E-01, -.49565100E-02, 0.15232100E-01, -.74197400E-01, 0.29797600E-01, -.19238400E-01, 0.10983100E+00, 0.25967100E+00, -.75038500E+00, 0.65664000E-01, 0.45265000E+00, -.69923900E-01, -.56126700E-01, -.57662200E-01, 0.75705100E-01, 0.19592900E-01, 0.40032500E-01, -.11165200E-01, 0.24485800E+00, -.62332700E-01, 0.42175600E-01, 0.31476200E-01, 0.16587900E-01, 0.32589800E+00, 0.91407900E-01, -.87633500E-02, 0.65587300E-03, -.15916800E-01, 0.30048800E-01, -.65103000E-01, -.51272600E-01, 0.12714100E-01, 0.10039200E+01, 0.15264000E+00, 0.31557800E+00, 0.55739800E-01, -.14900500E-01, 0.10888100E-01, 0.45609500E-02, 0.28731400E+00, 0.10011700E+00, -.72569200E-01, 0.65182200E-03, -.13811100E+00, -.45934800E+00, -.63692400E-01, -.41112500E-01, 0.19266000E-01, -.55294700E-03, -.11144800E+00, 0.42089900E-01, 0.48682800E+00, 0.10022400E+00, -.35221900E-01, 0.13057800E-02, -.46287600E-01, -.65092200E-01, 0.30164300E-01, 0.14107100E+01, -.19104500E-01, -.40489800E-02, -.79417800E-01, -.17241900E+00, -.60256400E-01, 0.20292700E+01, -.24009400E+00, 0.75701500E-01, 0.38624000E+00, -.14394600E-01, -.90466700E-03, -.20320200E-01, 0.24866400E+02, 0.93554300E+01, -.10489500E+02, -.10421300E+02, -.22516900E+02, 0.43203300E+01, 0.23985100E+02, -.14911200E+01, -.42508800E+00, -.16922000E+00, 0.57359600E+00, 0.12651400E+01, -.76133600E+00, -.55715700E+00, -.61512500E+00, 0.36446800E+00, 0.30101000E+00, 0.51164100E+00, -.52567900E+00, -.97511800E+00, -.17521300E+00, -.29752200E+00, -.39333600E+00, 0.57178900E+00, 0.61253100E+00, -.47697600E+00, -.65914600E+00, -.83145900E+00, -.39701100E+00, 0.64736900E+00, 0.33757400E+00, 0.39860800E+00, -.12196700E+00 },
        { -.15854500E+01, -.11899000E+01, -.55965900E-01, 0.43043500E+00, -.74546200E+00, -.10333900E+01, -.13480100E+01, -.29280800E+00, -.99542900E+00, 0.13323200E+01, 0.38577200E-01, -.13649400E+00, -.52957100E+00, 0.16335800E+01, -.20593000E+01, -.52832200E+00, 0.44789200E+00, -.16513800E+00, 0.61516800E+00, -.88500400E+00, 0.56271400E+00, 0.17126000E-01, -.21962600E-01, -.27470800E+00, 0.15261000E+01, 0.27811400E-01, -.35271700E+00, -.54156500E+00, -.19639000E+00, -.39308300E+00, 0.32153000E+00, 0.37524100E+00, 0.57118500E+00, 0.28559600E-01, 0.22842500E+00, -.80500500E-01, 0.11314500E-01, 0.22243300E+00, -.10705900E+01, 0.25629100E+01, 0.80480000E-01, 0.80409000E-01, 0.85478300E-01, -.17232700E+00, 0.44885300E-01, 0.14810800E-01, 0.95765300E-01, -.53329200E-03, -.20675200E-01, 0.26017300E-01, -.30698300E+00, 0.13796100E+00, -.91016400E-02, -.12158500E-01, -.29695600E-01, -.52407400E-01, 0.21904800E-01, -.49574100E-01, 0.14080800E-01, -.29655500E+00, 0.39868900E+00, 0.22131000E+00, -.49917900E-01, -.69310200E-01, -.20223400E-02, 0.35154700E-01, 0.61197600E-01, 0.99828400E-02, -.15155800E-01, 0.13486000E-02, 0.36261800E+00, -.11152100E+00, 0.25405700E+00, 0.13337500E+00, 0.86275800E-01, 0.96583000E-01, -.29521200E-01, -.65055200E-01, 0.12869300E+00, -.44797900E+00, -.33777500E-01, 0.12712500E-01, 0.89902100E+00, 0.10850500E+00, -.69386600E+00, -.32392800E-02, -.91234100E+00, 0.92046500E-01, -.16161900E+01, 0.35977900E+00, -.16263700E+00, 0.21698500E-01, 0.21166300E-01, -.21933600E+00, -.51987400E+00, 0.13388100E+01, -.39359400E+00, -.62859600E+00, -.61525200E-01, 0.39829300E-01, 0.24724000E-01, -.23727300E+00, -.18586100E+00, 0.62389200E+00, -.38170600E+00, 0.58367700E-01, -.21887800E+00, -.40120300E+00, -.29896800E+00, -.17424700E+00, 0.39143300E-01, -.13684500E-01, 0.18438800E-01, 0.86917300E-01, -.55631300E-01, 0.58114900E+00, 0.51103100E+00, 0.19378000E-01, -.30040400E-01, -.89764000E-01, -.31453400E+00, 0.57595300E+00, 0.50467400E-01, 0.11631300E+00, 0.12812000E-01, 0.12699900E+00, -.28394400E-01, 0.58004100E-01, 0.44441100E-01, 0.37963400E+00, -.72878600E+00, -.11151600E+01, 0.63862600E-01, -.74555400E-02, 0.50462500E-02, 0.21933000E-02, -.10663100E+01, -.33132000E+00, 0.14020000E+00, 0.11415900E+01, -.49991900E-01, 0.91672400E+00, 0.28394900E+00, -.61288700E-01, 0.59586500E-02, 0.46036900E+00, 0.25510900E-01, -.99313600E-01, -.14628200E+00, 0.33614000E+00, 0.14887000E+00, -.25110000E-01, -.73011200E+00, 0.11209300E+00, 0.64578200E-02, 0.13567500E+00, -.11816700E+00, 0.56876200E-02, 0.13543600E-01, -.17991000E+00, 0.80261300E-01, 0.20224600E+00, 0.42355900E+00, 0.67405300E-01, -.25229200E+00, 0.13184700E+00, -.39596500E+00, 0.13513300E+00, 0.75885600E-01, -.73688600E-01, -.83476100E-01, 0.17608600E+00, 0.31042600E-01, 0.42122500E-01, -.29300800E+00, 0.61992600E+00, 0.23402900E-02, 0.11511900E+00, 0.23971500E+00, -.12279900E+00, 0.15495200E+01, -.41705600E-01, -.17248500E+00, -.17430600E+00, 0.23595800E+00, 0.32463700E-01, -.13556700E+00, 0.24027700E+00, 0.39872300E-01, 0.82246000E-01, -.13754400E-01, 0.27984100E+00, 0.54037200E-01, -.71156700E-01, -.17909600E+00, 0.46035700E-01, -.17384200E+00, -.55701500E-01, 0.64180300E-02, -.15920300E-01, 0.35908500E+00, -.10743600E-01, 0.29444600E-01, 0.33465300E-01, -.19962400E+00, -.12947400E+01, -.84576300E-01, 0.73686000E+00, 0.72603000E-01, -.20301600E+00, -.84065700E-01, -.12098500E+00, -.20499100E-01, 0.36713000E-01, 0.11069900E+00, -.10897700E-01, 0.40700300E-02, 0.12020800E-01, 0.13535400E+00, 0.19225400E-01, 0.11728900E+01, -.27221600E-01, -.54843500E-01, 0.27987000E-01, -.77812400E-01, 0.65906700E-02, 0.12202000E+00, -.13427100E+00, -.32614800E-01, -.94919400E+00, 0.26720400E+00, 0.59627900E+00, -.51189100E-01, 0.32976800E-01, 0.55792200E-01, -.50374400E-01, 0.68531800E+00, 0.29061800E-01, -.65411100E-01, 0.31838100E-01, -.16127200E+00, -.36083500E+00, -.64634200E-01, 0.27050800E-01, 0.14191600E+00, 0.14702700E-01, 0.96789100E-01, -.97844300E-03, -.24315300E+00, 0.30567800E-01, -.30984100E-01, -.54478300E-01, -.10596600E-01, -.13474400E+00, -.99947900E-02, -.16625800E+00, -.19430000E-01, -.26972100E-01, 0.89763600E-01, 0.17466300E+00, 0.60356400E-01, 0.26039600E+01, -.33309200E+00, -.10477200E+00, 0.43750100E+00, -.67496100E-01, 0.33660300E-01, 0.39776100E-02, 0.46333700E+00, 0.92425600E+01, -.19234200E+02, -.13388000E+02, -.38913100E+00, 0.82052200E+01, -.37212300E+01, 0.41988400E+00, 0.33902700E+00, 0.85171400E+00, -.24318800E+00, 0.62006100E+00, 0.18107900E+00, 0.18389900E+00, 0.27985400E+00, 0.66833000E+00, -.20448900E+00, 0.33522200E+00, 0.67122600E+01, -.11100200E-01, -.83469700E+00, 0.69084300E+01, -.35430300E+00, 0.93254800E+00, 0.23526000E-01, 0.65142800E+01, 0.75909600E-01, 0.33383000E-01, 0.21830100E+00, -.70144500E+01, -.93681400E-01, -.12759500E+00, 0.12193500E+01 },
        { -.31849200E+01, -.67279000E+00, 0.11370000E-01, -.18568400E-01, -.81976100E+00, -.15173900E+01, -.17482900E+01, -.57589500E+00, -.13768800E+01, 0.19338900E+01, -.29104400E-02, -.20108000E+00, -.11842500E+01, 0.74087200E+00, -.18371000E+01, -.68021400E+00, -.30888600E+00, 0.70011900E+00, 0.51452100E+00, 0.28688600E+00, 0.78998600E+00, -.15203000E-01, -.70367800E-01, -.26800000E+00, -.10373300E+01, 0.69716600E-01, -.32277500E+00, -.28710500E+00, -.48658400E+00, -.54278600E+00, 0.18275300E+00, 0.11218400E+00, 0.44678000E+00, 0.28827500E+00, -.37166900E+00, 0.22757900E+00, -.18908400E+00, 0.22238400E+00, -.18698800E+01, 0.13522800E+01, 0.10495900E+00, 0.24106000E+00, -.74299700E+00, 0.95816200E-01, 0.71867800E+00, -.83662900E-01, -.57461600E+00, 0.43793000E-02, 0.14370100E+00, 0.39585500E+00, 0.86662300E+00, -.54643900E+00, -.18702600E-01, -.12272600E+00, 0.43642800E-01, 0.15996800E+00, 0.20033100E+00, 0.41345300E-01, 0.16688600E-01, 0.16797000E+00, 0.13872700E+00, 0.31419500E+00, 0.69455500E-01, 0.12432600E+01, -.20498800E+00, 0.20329900E+00, 0.55745200E+00, 0.62815800E+00, -.56100300E-01, 0.12211700E+00, -.72326000E+00, 0.34502300E+00, 0.23464500E+00, 0.13233400E+00, 0.13949500E+00, 0.22019200E+00, -.67353400E-03, 0.53796600E+00, 0.13522800E+00, 0.23464800E+00, 0.99194200E-01, -.15022800E+00, -.10703900E+01, -.13318100E-01, 0.74018700E+00, -.15834900E+00, -.61772100E+00, -.36767100E-01, 0.14027000E+01, -.15375200E+00, -.38169600E+00, 0.37607800E-01, -.32208200E+00, 0.10677500E+00, 0.39774000E+00, -.86322000E+00, 0.20728700E+00, 0.77177800E+00, -.31905300E+00, -.14204000E+00, 0.56977900E-01, 0.47043000E-01, 0.49464200E-01, -.17815000E+00, 0.70844600E-01, -.94209100E-01, 0.92491200E-01, 0.18051300E+00, -.52057500E+00, -.98189800E-01, 0.15101600E+00, -.37802700E-01, 0.42600400E-02, 0.61956000E-01, -.12901600E+00, -.25726800E+00, 0.10648600E+01, 0.82585600E-02, 0.84740800E-02, -.11330100E+00, 0.23307500E+00, -.14539300E+00, -.58137200E-01, 0.76397400E-02, 0.86789000E-02, 0.92128300E-01, 0.10130500E+00, -.97869400E-01, -.74648500E-01, 0.23663400E+00, -.34821200E+00, 0.17436200E+00, 0.66686900E-01, -.18509100E-02, -.66217200E-02, -.12043200E-01, -.49320300E+00, -.61626900E-01, -.54358300E-01, 0.65939400E+00, 0.44132500E+00, 0.17043100E-01, -.81047200E+00, -.26238200E+00, -.45653100E-01, 0.49639300E+00, -.22212400E-01, -.88710400E-01, -.26933300E+00, 0.28985500E-01, -.12319700E+00, -.28036500E+00, -.10676300E+01, 0.26059900E+00, -.55963500E-01, 0.10102000E+00, -.12006600E+00, 0.30848800E-01, 0.17844300E+00, -.55483500E+00, 0.12679300E+00, -.27368600E-01, 0.54389900E+00, 0.30177700E-01, -.17080700E+00, 0.87451600E-01, -.15610200E+00, -.42402900E-01, 0.33086000E-01, -.18035900E+00, 0.44153400E-02, 0.75947400E-01, -.11017700E+00, -.22051500E+00, -.22780200E+00, 0.13168600E+01, -.81714700E-01, -.17733500E-01, 0.84691400E-01, 0.11002100E+01, -.32575100E+01, -.44437200E+00, 0.29416500E+00, 0.28928900E+00, -.92296100E+00, 0.19211700E+00, 0.11792100E+00, -.52667600E-01, 0.14536800E+00, 0.18865400E-01, -.45892000E-02, 0.59913400E+00, 0.30696300E+00, 0.59628200E+00, -.26928300E+00, 0.17883700E+00, -.34109500E+00, -.13160500E+00, 0.37436700E-03, -.10116200E+00, -.70500400E-02, -.49245700E-01, 0.18025500E+00, -.89395600E-01, -.24005200E+00, -.47522200E+00, 0.41573800E+00, -.47099000E+00, 0.80178100E-01, -.30501400E+00, -.23508100E+00, -.18747200E-01, -.11206500E-01, -.61027900E-02, -.70361900E-02, -.38689100E+00, 0.78315300E-01, -.78876800E-01, 0.54205400E-01, -.10281500E-01, -.15271700E+01, -.34076700E-01, 0.89580200E-01, -.24563600E-01, -.32393000E-01, -.36669400E-01, 0.58132200E-01, 0.56460000E-02, 0.19035900E-01, -.87425300E+00, -.55758200E+00, -.25599600E+00, -.38152700E+00, 0.10859700E+00, 0.13688900E-01, -.24083400E-01, 0.16109000E+00, -.10927400E+00, 0.12924300E+00, 0.70281600E-01, 0.10078900E+00, 0.48814300E+00, 0.56796500E-02, 0.69748200E-01, -.35442100E+00, 0.29716900E-01, 0.22624200E+00, -.14542900E+00, -.11447800E+00, 0.92797800E-01, 0.12718300E-01, 0.45516400E-02, 0.86482800E-01, -.54628100E-01, -.29271300E-01, 0.14516800E+00, -.76253300E-02, -.51690800E-01, 0.23664300E+00, 0.42415800E+00, 0.12137900E-01, 0.29196300E+01, 0.19209300E+00, -.87566000E-01, -.43534700E+00, 0.43908700E-01, 0.23574100E-01, 0.18736100E-01, -.11004200E+01, -.12846200E+01, -.16603600E+02, -.18355400E+00, 0.21151300E+02, -.41187900E+01, -.58064300E+01, -.39640400E+00, 0.22694100E+00, 0.22459400E+01, -.69679200E-01, -.70631200E+00, 0.70156100E+00, 0.20897000E+00, 0.21121300E-01, 0.83434300E+00, -.42855100E+00, 0.57962600E+00, 0.11427000E+02, -.52071000E+00, -.16585700E+01, 0.11677200E+02, -.75064800E+00, 0.15000900E+01, 0.43589000E+00, 0.10891200E+02, 0.10810200E+00, -.25011400E+01, 0.69593500E-01, -.11830200E+02, 0.67720800E-01, 0.80286300E+00, 0.24321600E+00 },
        { 0.42673900E+01, -.84393900E+00, -.24434300E+00, -.45797000E+00, 0.17251200E+01, 0.22472900E+01, 0.15731700E+01, -.70476200E+00, 0.19344400E+01, -.28353800E+01, 0.34852700E-01, 0.31222200E+00, -.10360400E+00, 0.59701900E+00, 0.13878000E+01, 0.38199900E+00, 0.95558900E+00, 0.18144700E+00, -.73251700E+00, 0.10335200E+01, -.52782200E+00, -.16135900E+00, -.13617600E-02, 0.39494100E+00, -.85363400E+00, -.37361300E-02, -.32017400E+00, 0.47858800E+00, 0.76074700E+00, -.32231900E+00, -.24194900E+00, -.26342200E+00, -.10248600E+01, -.68971100E+00, -.35462000E+00, 0.15321400E+00, -.71190900E-01, -.75572200E+00, 0.10385300E+01, -.24204200E+01, -.17124900E+00, -.47495800E+00, -.25284500E+00, 0.23679200E+00, -.31958000E+00, 0.78911800E-01, -.32848700E+00, 0.68014700E-02, 0.23322500E-01, -.19243000E-01, -.59633700E+00, 0.58084600E-01, 0.60085400E+00, -.72574400E-01, 0.87349600E+00, 0.70922600E+00, 0.93956200E+00, 0.18843900E+00, 0.23762900E-01, 0.47945600E+00, -.71735900E+00, -.10000800E+01, -.63297000E+00, 0.41800800E-02, -.44813900E-01, -.72002900E-01, -.34980800E+00, 0.44712500E-01, 0.28701900E-02, 0.24283100E-01, -.36068200E+00, 0.19534600E+00, 0.13082300E+01, 0.60911800E+00, 0.48158100E+00, 0.28735700E+00, 0.79242000E-01, 0.64634300E+00, -.66250300E-01, 0.32110200E+00, -.40881300E-01, 0.37675600E-01, -.11279500E+01, -.26569600E+00, 0.18074800E+01, -.99449600E-01, 0.17647500E+01, -.12128100E-01, 0.27908900E+01, 0.16693900E-01, 0.21410300E+01, -.48322900E-01, 0.19202200E+00, -.10168500E+00, -.89993800E-01, -.13600300E+01, 0.38648500E+00, 0.11142700E+01, -.29002000E+00, -.28782700E+00, -.17722000E-01, 0.28505600E+00, 0.73615100E+00, -.11537700E+01, 0.57489800E+00, -.65445400E+00, -.55323400E+00, -.27491400E-01, 0.92991500E+00, 0.91802800E-01, -.21128700E+00, 0.44773300E-01, -.14361000E-01, 0.10409400E+00, 0.57412900E-01, -.18894100E+00, 0.15714700E+01, 0.18370300E+00, -.10594700E-01, -.37886100E+00, 0.79069700E+00, -.61106000E+00, -.82208800E-01, -.22198000E+00, 0.76430900E-02, 0.52143200E-01, -.11413800E+00, -.54005100E+00, 0.28991000E+00, -.39203300E+00, 0.18227700E+00, 0.10344900E+01, 0.34812000E+00, 0.13980000E-01, 0.11245400E-01, -.10324800E-01, -.16472700E+01, 0.26548600E+00, -.28547400E+00, -.19315300E+01, -.18644100E+00, -.19553800E+01, 0.21896000E+00, 0.23179800E+00, -.18795800E-01, -.17591900E+00, -.77041000E-01, 0.19240800E+00, -.27986100E-01, -.44608200E+00, -.73206700E-01, -.34728700E+00, -.81489600E+00, -.13279100E+00, -.14759000E+00, 0.14339600E-01, -.63957300E+00, -.20346800E-01, -.87883100E-01, -.86459700E+00, 0.16219900E-01, 0.38061800E+00, -.99060200E+00, -.99498900E-01, 0.47076000E+00, -.79452100E-01, 0.19306200E+00, 0.19626400E+00, -.78760500E-01, 0.25464700E+00, 0.21458200E+00, -.77485100E+00, -.10253100E+00, 0.15734300E+00, -.92203700E+00, -.69927800E+00, 0.57865700E-01, 0.33034600E+00, -.47382600E+00, 0.16009700E+00, 0.34931500E+01, -.11315600E-01, 0.13122600E+01, 0.37045100E+00, 0.70206600E+00, -.13646500E+00, 0.16813500E+00, -.11315700E+01, -.20435700E+00, 0.20589200E+00, 0.33076100E-01, -.53564400E-01, -.98337700E-01, 0.38983600E+00, -.11330200E+01, -.40055800E+00, -.77095700E-01, -.32478300E+00, -.23786600E+00, -.14905300E+00, -.30102800E+00, -.33276600E-01, 0.21417400E+00, 0.77068900E-01, 0.32649400E+00, -.18864900E+01, -.59464100E+00, -.13390100E+01, 0.42235100E+00, 0.96684100E-01, 0.10896000E+00, 0.19321700E+00, -.87548400E-02, -.70667500E-01, 0.11104700E-01, -.76715000E+00, 0.15719200E+00, -.27143500E-01, 0.14593500E+00, -.16976800E+00, 0.13301800E+01, -.23759600E+00, 0.18356100E-01, -.11959900E-02, -.39888600E-01, 0.21109100E-01, 0.17808800E+00, -.44076900E-01, -.20512300E-01, -.26122500E+00, 0.13660700E+00, 0.51365000E+00, -.44011000E-01, 0.11293400E+00, 0.19485700E-01, -.11409700E+00, 0.89729700E+00, 0.24930700E+00, -.56577600E-01, 0.17602100E+00, -.54640900E-01, 0.15432400E+00, -.19922300E+00, 0.11190400E+00, -.20445500E+00, 0.61856300E-01, 0.14405500E+00, -.12965900E+00, 0.27056900E+00, -.16651000E+00, -.23709100E-01, -.96160200E-01, 0.17119800E+00, -.35347400E-01, -.14062100E+00, -.50089500E+01, -.28176300E-01, -.19537500E+00, 0.22440700E+00, -.10098400E+00, -.14412100E-01, 0.73193700E+01, -.85034500E+00, -.11130800E+00, -.76815100E+00, -.33444400E-02, 0.12202900E+00, 0.51960400E-01, -.65268700E+00, 0.13828100E+01, 0.11906200E+01, 0.12477600E+02, 0.17370100E+02, -.27834300E+01, -.17245700E+02, 0.31003000E+01, 0.10847600E-02, -.26611600E+01, -.20230200E+00, 0.96314700E+00, -.28566800E+00, 0.51054500E+00, 0.19374300E+01, -.20152900E+01, 0.69216100E+00, -.18920100E+01, -.17156000E+02, 0.62412900E+00, 0.13294100E+01, -.17696800E+02, 0.65138900E+00, -.26173800E+01, -.48076000E+00, -.16459700E+02, 0.53420800E+00, 0.47675900E+01, 0.74233900E+00, 0.17796800E+02, -.71827600E+00, -.13056700E+01, -.24928700E+01 },
        { 0.11904900E+02, -.56170700E+01, -.92660700E+00, -.20793000E+01, 0.51833300E+01, 0.30513500E+01, 0.91114500E+01, -.20101300E+00, 0.58438400E+01, -.77978500E+01, 0.90301500E-01, 0.90189600E+00, 0.16209100E+01, -.13067300E+00, 0.48909700E+01, 0.11589900E+01, 0.97547000E+00, 0.20085800E+01, -.23200900E+01, 0.50205800E+01, -.46068900E+00, -.52785000E+00, -.32395400E+00, 0.76816100E+00, -.55426600E+01, -.13609100E+00, -.11965300E+01, 0.14759000E+01, 0.19891100E+00, -.22323400E+01, -.75103500E+00, -.23999500E+01, -.22778600E+01, 0.13879500E+01, -.51686400E+00, -.13525700E+00, 0.90809400E-01, -.69882500E+00, -.64282600E+00, 0.46690800E+01, -.74889200E+00, -.53048000E+00, 0.79234500E+00, -.17367700E+01, 0.87143300E+00, -.35079600E+00, 0.30910700E-01, 0.30730600E-01, 0.33895800E-01, -.30542700E+00, 0.26405200E+00, -.19311600E+00, -.36420200E+00, 0.18213800E+01, -.98929300E+00, -.17795800E+01, -.22166600E+00, -.92717100E+00, -.48984400E-02, 0.79054800E+00, 0.89355500E+00, -.19610000E+01, -.99606500E+00, 0.17452700E+01, -.56947300E+00, -.86804800E-01, -.11734900E+01, 0.63055300E-01, -.32266400E+00, 0.60597200E-03, 0.23079500E+01, -.72627100E+00, 0.82432700E+00, -.48482400E+00, -.13632200E+01, 0.16353200E+00, 0.54302800E+00, 0.10513400E+00, 0.28629200E+00, -.28311100E+00, 0.23796400E+00, -.44483200E+00, 0.26705900E+01, -.16371000E+00, -.20658100E+01, -.48906200E+00, -.24419700E+01, 0.21054000E+01, -.82096000E+01, 0.18171300E+01, 0.28784600E+01, 0.18639100E+00, -.17689000E+01, 0.11844300E+01, 0.11638100E+01, 0.41522700E+01, -.88610000E+00, 0.14711000E+01, -.13444300E+01, -.10773900E+01, -.80806000E+00, 0.94056400E+00, -.91116900E+00, 0.13693400E+00, -.18237400E+00, -.81396400E+00, 0.59438500E+00, -.33753000E+00, -.26423500E+01, 0.13050800E+00, 0.13911400E+01, -.53759800E+00, -.29695600E+00, -.34588300E+00, 0.24437200E+00, -.83972100E+00, -.84387800E+01, -.30809700E+00, 0.68908800E+00, -.10746300E+00, 0.37627200E+00, -.27541300E+00, 0.18345600E+00, -.72710400E+00, 0.29209600E-01, -.12088600E+01, -.17423900E+00, 0.36014100E+01, -.34361900E+01, 0.16901600E+00, -.34371400E+00, 0.25586500E+01, -.20757300E+01, 0.25339400E-01, 0.98151600E-01, 0.12656500E-01, 0.49229900E+01, -.12616900E+01, 0.59869100E+00, -.23232400E+01, -.47104000E-01, 0.17862900E+00, -.11930400E+01, 0.46382200E+00, 0.65988500E+00, -.25331900E+01, 0.71182700E-01, -.29691800E+00, 0.93950700E+00, -.78004900E+00, -.46757700E+00, -.39784300E+00, -.12606600E+01, -.53870000E+00, -.64829700E-01, 0.27203100E+00, -.15280000E+01, 0.10212800E-01, -.65498400E+00, -.15799100E+01, 0.46034000E+00, 0.23692800E+01, 0.19798300E+01, 0.41457800E+00, -.15445100E+01, 0.34323000E+00, -.18130100E+01, 0.46488900E+00, -.12183600E+00, 0.60942200E+00, -.27279100E+00, 0.90141900E+00, -.33543600E+00, 0.29410900E+00, -.50009100E+00, 0.26395300E+01, -.61982100E+00, -.12379700E+01, 0.86752200E+00, 0.17893500E+01, 0.56930700E+01, -.99765400E+00, 0.28809000E+00, -.20466900E+01, -.15512000E+01, -.11261700E+00, -.44186200E+00, -.70740800E+00, 0.84421800E+00, -.65578800E+00, -.48707700E-01, 0.97508100E+00, -.15631500E+00, 0.56942000E+00, 0.39865200E+00, -.28867900E-01, -.79894100E+00, -.43963400E+00, 0.27702100E+00, 0.38902100E-01, -.25569500E+01, 0.23933300E+00, -.59600500E+00, -.65270800E+00, 0.11685800E+01, -.40354100E+01, 0.23640900E+01, 0.15520800E+01, -.12194100E+00, -.20339300E+01, 0.63694700E+00, -.40302000E+00, -.34846000E-02, 0.91384200E-01, 0.56635800E+00, -.32945000E+01, -.20816600E+00, 0.35423600E+00, 0.51763300E+00, -.61005300E-01, 0.13823600E+01, -.18891900E+00, 0.12213100E+00, -.14823300E-01, 0.35131400E+00, -.10390700E+00, -.25041600E+00, 0.22628400E+00, 0.86492000E-01, 0.23857300E+01, -.15647700E+01, -.86104900E+00, -.69564700E+00, -.57237000E+00, -.11028200E+00, 0.29860700E-01, -.56767300E+00, 0.70124700E+00, -.27757200E+00, 0.28100400E+00, 0.36059600E+00, 0.71068300E+00, 0.29516300E+00, 0.14786100E+00, -.53548000E+00, 0.11616800E+00, -.94420000E-01, -.23311400E-01, 0.22493700E+01, 0.16898100E+00, 0.33901700E-01, 0.80003600E-01, 0.47975100E-01, -.47449000E+00, 0.21923300E+00, -.18154200E+00, 0.65822300E-02, -.12971100E+00, -.62774500E-01, -.99789200E+00, -.40327800E+00, 0.10757300E+02, -.66106400E-01, 0.10920500E+00, 0.77071400E-01, -.38252200E+00, 0.91470100E-01, 0.35033200E+00, 0.12307900E+01, -.32402500E+01, 0.22651000E+01, -.19882500E+01, 0.62262100E+02, 0.10470400E+02, 0.24043700E+02, 0.11132300E+02, 0.50363800E+01, -.37458800E+01, -.23978800E+00, 0.88721800E+01, 0.37142300E+00, 0.23464900E+01, 0.60855600E+01, -.38006700E+01, 0.10473500E+01, -.39661500E+01, -.14686500E+02, 0.35217300E+01, 0.31006700E+01, -.15020800E+02, 0.17503400E+01, -.29207800E+01, -.69745700E-01, -.15031900E+02, 0.32910100E+01, 0.16319300E+02, 0.20665600E+01, 0.14377900E+02, -.18339800E+01, -.56800800E+01, -.78499000E+01 },
        { -.26472200E+01, -.16219700E+01, -.82077500E-01, -.78735800E+00, -.21050900E+01, -.19964300E+01, -.10338300E+00, -.15732400E+01, -.85162800E+00, 0.23462200E+01, 0.51337600E-01, -.13452800E+00, -.60012100E+00, 0.13312300E+01, -.19224000E+01, -.10038400E+00, 0.41110100E+00, -.41871600E+00, 0.98179200E+00, -.13165500E+01, 0.40038400E+00, 0.20691300E-01, -.14073700E-01, -.25788700E+00, 0.26185400E+01, 0.31456200E-01, 0.26451700E-01, -.32434300E+00, -.32394000E+00, -.68303500E-01, 0.26542700E+00, 0.53025800E+00, 0.64723800E+00, 0.23156900E+00, 0.38643300E+00, -.99596000E-01, 0.12209100E-01, 0.21526200E+00, -.83181200E-01, 0.32697600E+01, 0.58640200E-02, 0.17514600E+00, -.31986700E+00, -.14359000E+00, 0.28042900E+00, 0.56434200E-01, 0.93841500E-01, 0.21545300E-01, -.49391100E-01, -.21421900E-01, -.29042900E+00, -.13260500E+00, -.76049000E-01, -.22393300E+00, -.32308900E+00, 0.15964900E+00, -.40365400E+00, -.67588000E-01, 0.45415500E-01, -.23033500E+00, 0.48047600E+00, 0.63840500E+00, 0.41973600E+00, -.42262000E+00, 0.36678700E+00, -.50726700E-02, 0.46832300E+00, -.72695200E-01, 0.84011200E-01, -.98310800E-02, 0.10752000E+00, -.12418200E+00, 0.19139000E-01, 0.12874600E+00, -.21470500E-02, -.27743100E-01, 0.39015100E-01, -.81110500E-01, -.59314500E-01, 0.10738200E+00, 0.12622500E-01, -.41444800E-01, 0.33122800E+00, 0.11553500E-01, 0.12582000E+00, 0.10133100E+00, -.50764700E+00, 0.18871400E+00, -.88527000E-01, 0.32973500E+00, 0.25191700E+00, 0.11567000E-01, -.11406500E+00, -.20540700E+00, 0.45892500E+00, 0.77696800E+00, -.83209600E-01, -.48891200E+00, 0.49296900E+00, 0.27670300E+00, 0.39875400E+00, -.73441500E-01, -.27406700E+00, 0.44744000E+00, -.30199400E+00, 0.12983900E+00, -.47715700E+00, -.79839400E+00, -.16929500E+00, -.14668000E+00, 0.21816600E+00, 0.37039700E-01, 0.49211300E-01, 0.95361800E-01, 0.16059700E+00, -.48239900E+00, 0.72296200E+00, 0.42736800E+00, -.71220600E-01, -.17535000E+00, 0.16273100E+00, 0.21165600E-01, 0.64959200E-01, 0.50970200E-01, -.50643000E-02, -.35125800E+00, 0.34167500E-01, 0.49935000E+00, 0.58158200E-01, 0.36926300E-01, -.50967800E+00, -.14188600E+00, 0.39606200E+00, -.22303200E-02, 0.12579700E-01, -.82703300E-03, 0.27223800E+00, -.16403600E+00, 0.34891600E-03, -.15540200E-02, -.48177200E+00, -.37374300E+00, -.96436300E-01, 0.12383200E+00, 0.34200200E-01, -.77660100E-01, -.17257900E-01, 0.88439000E-01, 0.13686200E+00, 0.11220300E+00, 0.14897500E+00, 0.12855000E+00, -.63288900E-01, -.52878600E-01, 0.96309900E-02, 0.11367500E+00, 0.47922800E-01, -.23231300E-02, -.26810000E+00, 0.13872700E+00, -.62916900E-02, -.11834500E+00, -.14285200E+00, -.55602600E-01, 0.16980700E+00, -.53775500E-01, 0.20613000E+00, -.10654400E+00, -.43819700E-01, 0.32375800E-01, 0.10034800E+00, -.34326000E+00, 0.15592200E+00, -.26892200E-01, -.14625900E+00, -.28273800E+00, 0.11097300E+00, 0.43306600E+00, -.95249400E-01, -.27277100E+00, 0.10458500E+01, 0.12553700E+00, 0.29677500E-01, -.94485700E-01, 0.37747600E+00, -.50196200E-01, 0.13616500E+00, -.22675200E+00, -.16577400E+00, -.64148100E-01, -.57082200E-03, -.66049600E-02, -.13237200E+00, 0.23055000E+00, 0.58584800E+00, 0.26691900E+00, 0.65157700E-01, 0.81441400E-02, -.99277900E-01, 0.99755200E-02, -.61133000E+00, -.40036700E-01, -.11135400E+00, 0.13209800E+00, 0.75874500E+00, 0.18723500E+01, 0.45520500E+00, -.39748700E+00, 0.24501700E+00, 0.20583900E+00, 0.34847100E-01, 0.12246800E+00, -.23511000E-01, -.72763600E-01, 0.40910600E-01, -.24320800E+00, -.43684300E-01, 0.18231100E-02, -.85024500E-01, -.11039600E+00, 0.28493300E+01, -.12867200E+00, -.11961300E+00, 0.42158000E-01, 0.14292300E+00, -.39044600E-01, -.88102800E-01, -.25743500E-01, -.83991500E-01, 0.10715200E+00, 0.42599500E+00, 0.41151200E+00, 0.48329400E+00, -.14212400E+00, 0.47124000E-01, 0.76630100E-02, 0.47610400E+00, 0.34068100E+00, -.10575000E+00, 0.49738600E-01, -.24076400E+00, -.64392500E+00, -.70030000E-01, -.40252200E-01, 0.11118000E+00, -.78511500E-03, -.15798200E+00, 0.84354000E-01, 0.23904800E+00, -.35165500E-01, -.11520200E-01, -.30911000E-02, 0.40325300E-01, 0.38700400E-01, -.69932000E-02, 0.17917100E+00, 0.35824200E-01, -.60663600E-01, -.10337900E-01, -.32241600E+00, -.12438900E+00, 0.17694500E+01, -.32462800E+00, 0.51571300E-01, 0.80122500E+00, -.58871600E-01, 0.14032200E-01, -.37248400E-03, 0.11292900E+01, 0.74577700E-01, 0.68290900E+00, -.54863400E+00, -.30574800E-01, 0.89751300E+01, -.19439800E+02, 0.21509600E+01, -.44502400E+00, -.27951000E+01, -.60146500E+00, 0.21813900E+01, -.31993300E+00, 0.96805100E+00, 0.12258300E+01, -.16808100E+01, 0.40475800E+00, -.18954700E+01, -.16452500E+02, 0.75914300E+00, 0.15104200E+01, -.16891700E+02, 0.53129700E+00, -.18925300E+01, -.70923800E+00, -.15786400E+02, 0.10484000E+01, 0.41480000E+01, 0.79086600E+00, 0.16873000E+02, -.86591700E+00, -.10295100E+01, -.10827400E+01 },
        { 0.17346000E+02, -.72306300E+01, -.13090700E+01, -.15892300E+01, 0.52590500E+01, 0.18594600E+01, 0.14092600E+02, -.25083700E+01, 0.90947300E+01, -.12007900E+02, -.18493700E-01, 0.13876900E+01, 0.15133600E+01, 0.12653700E+01, 0.49286600E+01, 0.15602700E+01, 0.15512100E+01, 0.20037300E-01, -.22418400E+01, 0.39789000E+01, -.11128500E+01, -.32679400E+00, -.32594800E-01, 0.55251400E+00, -.19465800E+01, -.19603000E+00, -.12141300E+01, 0.13303800E+01, 0.17284000E+01, -.14303700E+01, 0.41835100E+00, -.95734000E+00, -.69346000E+00, 0.20618000E+00, -.26192800E+00, 0.11822700E+00, 0.15674700E+00, 0.35551300E+00, 0.15107900E+01, 0.82476700E+01, -.29841800E+00, -.88113800E+00, -.18876500E+00, -.12168100E+01, -.77154500E+00, -.25869400E+00, -.73699300E+00, 0.76838300E-02, 0.12109600E+00, 0.11174300E+00, 0.20956600E+01, -.25463600E+00, 0.37885700E+00, 0.62044000E+00, 0.14942500E+01, -.28643100E+00, 0.13073300E+01, -.46704200E+00, 0.83550900E-03, 0.14185800E+01, -.49447200E+00, -.11780800E+01, -.79957900E+00, 0.11185700E+01, -.92012800E+00, -.48828800E+00, -.31808900E+01, -.42693800E+00, -.52751200E+00, 0.29492600E+00, -.19758700E+00, -.28767000E+00, 0.38982100E+01, -.55221800E-01, 0.11171200E+01, 0.24991500E+00, -.30012500E+00, -.42076000E+00, -.71505600E+00, 0.20763700E+01, -.19339700E+00, 0.54065800E+00, -.35177800E+00, -.83555600E+00, 0.25797200E+00, -.58006100E+00, 0.13265800E+01, -.28067900E+01, -.11378900E+01, 0.25502000E+01, 0.22636100E+01, -.13457600E+00, -.24156500E+00, 0.37408500E+00, 0.35787400E+00, -.33602700E+01, 0.45134900E+00, 0.19869700E+01, -.73592700E-01, -.59569100E+00, -.14757600E+01, 0.13586600E+01, 0.15352200E+01, -.28782700E+01, 0.18625800E+01, -.60568200E+00, 0.25360400E+01, 0.44480900E+01, 0.17530300E+01, 0.11232800E+01, -.26737300E+01, 0.81200800E+00, -.38057900E-01, 0.40577500E+00, 0.25531600E+01, -.78657300E+00, -.23229900E+01, 0.15476500E+01, 0.52211300E+00, -.18138100E+01, 0.86456800E+00, 0.48755400E+00, 0.31925300E+00, -.21320900E+00, 0.59047800E-02, -.94648600E+00, -.19943900E+00, -.12369100E+01, -.28707900E+00, 0.54941200E-01, -.21762900E+01, 0.25131000E+01, -.14340000E+00, 0.59705400E-01, -.43711700E+00, 0.96907400E-02, 0.68064900E+00, -.15634700E+01, 0.42984400E-01, 0.77720500E+01, -.46999300E+00, -.30069100E+01, -.64085000E+00, 0.37138100E+00, -.37799000E+00, 0.11051000E+01, -.75150300E-01, 0.74560700E+00, 0.49100800E+00, -.15879300E+01, -.39061300E+00, 0.30181200E+00, -.83273700E+00, 0.17408100E+01, -.30659000E+00, -.17315100E+01, -.15558800E+01, -.84327900E-01, 0.27555600E+01, -.46452400E+01, 0.18827800E+00, -.66889100E+00, -.12775300E+01, 0.10465800E+00, 0.13935500E+01, -.39685600E+00, -.82565500E+00, 0.50755600E+01, -.52857800E+00, 0.64992900E+00, 0.17683900E+00, -.18277800E+01, -.48202600E+00, -.20188000E+00, 0.30544500E+01, -.50554600E+01, -.75994500E-02, -.13328900E+01, 0.88304400E+00, -.77404600E+00, 0.74373400E+01, 0.25122900E-01, 0.22017400E+01, -.54998600E+00, -.24110000E+01, -.18150800E+00, 0.94087100E-01, -.77551600E+00, 0.41494300E+00, 0.12824300E+01, 0.14406100E+00, 0.17223300E+01, 0.13750400E+01, 0.12363400E+01, -.37994600E+01, -.20014000E+01, 0.24796200E+01, -.87594500E+00, -.77450600E+00, 0.70306800E+00, 0.12417200E+01, -.31846700E+00, 0.98640300E+00, 0.11171700E+00, 0.69611800E+00, -.46625600E+01, 0.79315200E+00, -.40668700E+01, -.37169100E+00, -.10847600E+01, 0.31016000E+00, 0.23028200E+00, -.13680200E+00, 0.11066200E+01, 0.10622700E+01, -.36385500E+00, -.47563200E+00, 0.81092800E-01, -.13498700E+00, -.22804000E+00, 0.73504100E+00, 0.63476500E+00, 0.38214900E+00, -.13215300E+00, -.91464200E-02, -.24790200E+00, -.26843100E+00, 0.82226900E-02, 0.91425500E-01, 0.70194100E+01, 0.23989100E+00, 0.68305200E+00, 0.10746000E+01, -.77442700E+00, 0.18703800E+00, 0.18422600E+00, 0.11934800E+01, 0.17879500E+01, -.49824100E+00, 0.49547300E+00, -.10720100E+01, -.27678600E+01, -.17772100E+00, 0.12817900E+00, -.57693200E+00, -.37851200E-01, 0.47640000E+00, -.66138600E-01, 0.20464300E+01, 0.71289300E+00, -.11084500E+00, -.18906000E-01, -.14177200E+00, -.15558200E+01, -.39444700E+00, 0.17769500E+02, -.22549800E+00, 0.36453400E+00, 0.22803300E+00, 0.19822300E+00, 0.15037600E-01, 0.20695900E+02, 0.15858500E+01, 0.72680200E-01, -.12480200E+01, 0.91096500E+00, 0.15118000E+00, -.60601800E-01, 0.15146900E+01, -.44864800E+01, -.74750100E+00, 0.24623300E+00, 0.11073700E+01, -.96329500E+00, -.28495700E+03, -.76119200E+01, -.34214700E+01, 0.69215400E+01, -.44622200E+01, -.15053000E+02, 0.32481400E+01, -.10990400E+01, -.99205000E+00, 0.33714500E+01, -.36328300E+01, 0.41135000E+01, 0.20603200E+02, -.94535200E+01, -.10363800E+02, 0.20687100E+02, -.72177300E+00, -.25994200E+00, -.37055400E+01, 0.20564200E+02, -.13903900E+01, -.14593600E+02, -.26954000E+01, -.20157500E+02, 0.27321700E+01, 0.70030500E+01, 0.11061600E+02 },
        { -.80026200E+01, 0.41679900E+01, 0.12212800E+01, -.71173100E+00, -.15957400E+01, -.17584100E+01, -.45785700E+01, -.14467700E+01, -.29081200E+01, 0.51118500E+01, 0.81005900E-01, -.32067200E+00, -.12750300E+01, -.23010000E+01, -.26983500E+01, -.48963300E+01, -.41979300E+00, -.78813000E+00, 0.28743700E+01, -.27093800E+01, -.54786500E+00, 0.33618100E+00, 0.26991500E+00, -.13110800E+00, 0.10280300E+01, 0.14455700E+00, 0.16961100E+01, 0.92611300E-01, -.50610400E+00, 0.21050700E+01, -.44811700E+00, 0.15639500E+01, -.18068300E+00, 0.74607700E+00, 0.22780200E+00, 0.49384000E+00, -.13509200E+00, -.84780200E+00, 0.12565500E+01, -.17552500E+02, 0.25419400E+00, 0.54494700E+00, -.96975100E+00, 0.31862100E+00, -.14370800E-01, -.30374500E+00, 0.51485700E+00, -.60775400E-02, -.18755200E+00, 0.10398200E+00, -.12758400E+01, 0.86081500E+00, 0.20758000E+00, 0.53732100E+00, -.22089900E+00, 0.93089200E+00, -.58764200E+00, 0.44448100E+00, -.18526600E-01, -.12008200E+01, 0.19084300E+01, 0.13807400E+01, 0.66607500E+00, -.12097300E+01, 0.60951800E+00, 0.80472300E-01, 0.18758000E+01, -.17821800E+00, 0.27770700E+00, -.12505500E+00, 0.12398700E+01, -.23055100E+00, -.24016300E+01, -.43910500E+00, -.14732000E+01, 0.46378500E-01, -.15685500E+00, -.46302600E+00, 0.22540800E+00, 0.12959000E-01, 0.10632800E+00, -.31937700E+00, 0.28942900E+00, 0.46028500E+00, -.15590900E+00, 0.49920900E+00, 0.27306800E-01, 0.12590300E+01, 0.13709500E+00, -.10147800E+01, -.33100300E+01, 0.38965300E-01, -.14082300E-01, -.12112300E+01, -.64127400E+00, 0.20500900E+01, -.95897500E+00, -.27384100E+01, -.64260300E+00, 0.65731900E+00, 0.75251700E+00, -.64633700E+00, -.97198700E+00, 0.11871000E+01, -.10470000E+01, 0.28608200E+00, -.69910100E+00, -.21851000E+01, -.12045800E+01, -.60921700E+00, 0.12352600E+01, -.12056500E+00, -.10217200E+00, -.14023800E+00, -.23770400E+00, -.34043000E+00, 0.78154000E+00, -.20609100E-01, -.67197700E+00, 0.81024600E+00, -.19611900E+00, -.47459700E+00, -.39401600E-01, -.48411800E+00, -.43024700E-01, 0.27617300E-01, 0.21127500E+00, -.85584300E-01, 0.32059800E-01, 0.37589100E+00, -.10126300E+01, -.20405800E+01, -.82705000E+00, -.10807700E-01, 0.47589700E-02, 0.20847200E-01, -.30666400E+01, 0.50247300E+00, -.17280200E+00, 0.34836600E+00, 0.61429600E+00, 0.27390000E+01, -.60630600E+00, -.45295200E+00, 0.73965400E-01, -.58119700E-01, 0.35790400E-01, -.14724500E+00, 0.16274300E+00, 0.11593300E+01, 0.53325600E+00, 0.30257200E-01, 0.12140400E+01, -.10580000E+00, 0.15675400E+00, 0.15257800E+00, 0.11904800E+01, -.84058600E-02, -.94484300E+00, 0.15841200E+01, -.13137500E+00, -.24512400E+00, 0.76258100E-01, -.57886500E-01, 0.14632300E+00, 0.93837400E-02, 0.57634400E+00, -.89268500E+00, -.63935400E-01, -.20284800E+00, 0.78855800E-01, 0.22070100E+00, -.34133300E-02, -.31509800E+00, -.93287700E+00, 0.31622000E-01, 0.11901200E+00, 0.35518800E+00, -.14578400E+00, -.15755100E+01, -.53316700E+01, 0.73986700E+00, -.48301800E+00, 0.87935900E+00, 0.90722400E+00, 0.38932900E+00, 0.63521100E-01, 0.11515900E+01, -.49245100E-01, 0.75384400E+00, -.76485300E-02, 0.13302700E+01, 0.69338000E+00, -.93586600E+00, 0.40533900E+00, 0.66281800E+00, 0.10190100E+00, 0.61021800E+00, -.33997800E+00, 0.19201600E+00, -.45301100E+00, -.19895100E+00, 0.11684700E+01, 0.55438400E+00, 0.14055800E+01, -.16453600E+01, 0.12744600E+01, -.57562900E+01, 0.95283500E+00, 0.79786500E+00, -.10495500E+00, 0.31219400E+00, -.84112400E-01, -.25427500E-01, 0.68119300E+00, -.12293600E+01, 0.16637400E+00, -.33424800E+00, -.29247800E+00, -.24732200E+00, 0.66740100E+00, -.17942200E+00, 0.37832500E+00, -.12990600E+00, 0.25009500E+00, -.25922200E+00, -.12936100E+00, 0.69241300E-01, 0.43563500E-01, -.10075800E+01, -.15462000E+01, -.29828800E+01, -.60362600E+00, -.25100100E+00, 0.90207200E-01, 0.12922400E+00, 0.80293700E+00, -.11701300E+00, 0.29426500E+00, 0.12692400E+00, 0.17613100E-01, 0.47527800E+00, -.18890600E+00, 0.13963500E+00, 0.29765400E+00, 0.45211400E-01, 0.58833900E+00, -.20884500E+00, -.28474400E+01, -.74457000E+00, 0.63978400E-01, -.30246400E+00, 0.11682500E+00, 0.12033700E+01, 0.49460700E-01, -.68904700E+01, 0.11765900E+00, -.24914200E+00, 0.60896900E-01, 0.67498300E+00, 0.22765600E+00, -.11858600E+02, 0.12051600E+01, -.69640900E-01, -.98717800E+00, -.76337900E+00, 0.29613500E+00, 0.10007500E+00, -.13036800E+01, 0.10847500E+01, 0.24190200E+01, 0.12829500E+01, 0.32131300E+00, 0.25087200E+00, 0.24611000E+00, 0.56365900E+01, 0.22367000E+01, -.18530800E+01, 0.34070100E+01, 0.55509800E+01, -.58855300E+01, 0.27460600E+00, -.32877600E+01, 0.31404300E+01, 0.47326300E+01, -.27320300E+01, 0.19508400E+02, 0.91646600E+01, 0.90663000E+01, 0.20591200E+02, 0.15561600E+00, 0.36499300E+01, 0.33602200E+01, 0.17000000E+02, 0.87797700E+00, -.49970800E+00, 0.46282800E+01, -.21836300E+02, -.43680000E+01, -.36356600E+01, -.58877500E+01 },
        { 0.10257900E+01, 0.53287000E+00, 0.85011100E-01, -.41063500E+00, 0.29917800E+00, 0.13555400E+00, 0.18612200E+01, 0.88805900E-02, 0.95734100E+00, -.81280900E+00, -.95022000E-01, 0.97116500E-01, 0.59801400E-01, -.69034500E+00, 0.47608700E+00, 0.37734800E+00, -.21313000E+00, -.30076900E+00, -.16516600E+00, 0.15535700E+00, -.26326800E+00, 0.38792900E-01, 0.23773500E-01, 0.13940100E+00, -.60612600E+00, -.20368600E-01, 0.41797400E-01, -.18639200E+00, 0.32349800E+00, 0.49123300E-01, -.21423900E-01, -.23863600E+00, -.25055500E+00, 0.97411100E-01, -.57737100E-03, 0.26416000E-01, -.28178000E-01, -.16117700E+00, 0.43652500E+00, -.19788200E+01, -.31236400E-01, -.10664700E+00, 0.13285400E+00, -.84936400E-01, -.20748900E+00, -.78400800E-01, -.66552500E-01, -.16922800E-01, 0.37555200E-01, 0.15014800E-01, -.18860200E+00, 0.91627600E-01, 0.48504700E-01, 0.22375800E+00, 0.24812400E-01, 0.49454800E-01, -.75164400E-01, -.15245000E-01, -.34526600E-01, -.16036200E+00, -.25439800E+00, 0.48512000E+00, 0.53053700E+00, 0.55459300E-01, -.52108500E-01, 0.85091700E-02, -.97857200E-01, -.66838700E-02, 0.16687900E-01, 0.67038800E-02, -.11691400E+00, -.92673100E-01, -.20944700E+00, -.10384000E+00, 0.11458700E+00, 0.17404000E+00, -.67178000E-01, 0.55094700E-01, -.88152000E-02, 0.13852900E+00, 0.17649100E-01, -.37705700E-01, 0.33580100E+00, -.33527600E-01, 0.63799100E-01, -.23328400E-02, -.19302500E+00, -.24744100E+00, -.40313100E+00, 0.37593900E+00, 0.41105100E+00, 0.91767400E-02, -.18280000E-01, -.23116800E-01, 0.10930800E+00, -.16078600E+00, -.23397300E-01, -.14583300E+00, 0.19345800E-02, 0.95261700E-01, 0.27795400E-01, 0.10789100E+00, -.15340400E+00, -.13009500E+00, -.50349900E-01, -.59394900E-01, 0.17389700E+00, -.21198000E+00, 0.47346300E-01, -.42833600E-02, -.77030400E-01, -.31970600E-02, 0.66768500E-01, -.12336300E+00, 0.21992700E+00, -.30559500E+00, -.56964200E+00, 0.32368500E-01, 0.36604200E-01, 0.83994500E-01, -.97396700E-01, -.31337100E-01, -.34254500E-02, 0.13243000E+00, 0.93549900E-02, -.33192600E-01, -.23645700E-01, -.58712200E-01, 0.29841800E-01, -.77737900E-01, 0.10934100E+00, 0.18010300E+00, 0.18384100E-01, 0.86092900E-03, -.95986200E-02, -.22334300E-02, 0.14422600E+00, 0.29835400E-01, -.44599300E-01, 0.90448600E-01, 0.53776700E-01, -.80283300E-01, -.21496500E+00, -.36519800E-01, -.14342700E-01, -.80092500E-01, -.76762400E-02, -.77323800E-02, -.28357300E-01, -.40213400E-01, -.40174400E-01, 0.33445200E-01, -.81363000E-01, 0.77558600E-01, 0.20030200E-01, -.39110600E-01, -.28320500E+00, 0.59287000E-02, 0.78211600E-01, -.21399800E+00, -.23994000E-01, -.78098300E-01, -.28491100E-01, 0.77221800E-02, 0.21701600E-01, -.24623400E-01, -.70750800E-01, 0.98670200E-01, 0.16194500E-01, 0.16985900E-01, -.38659100E-01, 0.16950400E+00, 0.21744800E-01, 0.18099500E-02, -.12041200E-01, -.67367000E+00, 0.32954300E-01, 0.80061400E-02, -.42516000E-02, -.65168100E-01, 0.43843300E+00, 0.97373000E-02, 0.10485600E+00, -.35665000E-01, -.13522200E-01, -.22740300E-01, 0.67362700E-02, -.12447900E+00, -.33951000E-01, 0.38443900E-01, 0.32338300E-02, -.75940600E-02, -.13804100E-01, 0.26115300E-01, -.90586300E-01, -.50204800E-01, 0.18176900E-01, -.45710400E-01, -.18971600E-01, 0.86540500E-02, -.55654300E-02, 0.22809300E-01, -.35849400E-01, -.70133400E-02, 0.30611600E-01, -.46487700E+00, -.12865500E+00, -.67748500E-01, 0.30134400E-02, -.57502600E-01, 0.30671000E-01, -.28229800E-01, 0.97585400E-02, -.39067400E-01, 0.17111800E-01, -.18271300E+00, 0.26397100E-01, -.30124900E-02, 0.43220400E-01, 0.21540200E-01, -.21324900E+00, 0.12686100E-01, 0.87591700E-02, -.38725200E-02, -.15266600E-01, 0.30860200E-01, -.25117400E-02, 0.10328000E-01, 0.96744500E-02, -.48611600E-01, 0.13950400E-02, -.51963300E-01, -.81149700E-01, 0.34728700E-01, -.17173200E-01, -.38392800E-02, 0.53739800E-01, -.17388800E-01, -.11698700E-01, 0.19459700E-01, 0.47212800E-01, 0.12184000E+00, 0.67673100E-02, 0.13579400E-01, -.34934700E-02, 0.43300600E-02, 0.56070700E-02, -.45455200E-02, 0.98897800E-02, -.14248900E-01, 0.67985800E-02, -.79155900E-03, -.72485100E-02, 0.32414000E-01, 0.24464300E-01, -.48959500E+00, -.50404700E-02, -.56749900E-02, -.28755600E-02, -.22395200E-01, -.10458000E-01, 0.39037700E+00, 0.41405100E-01, 0.32466600E-01, -.22750900E-01, -.59147500E-02, -.26191500E-01, -.50400700E-02, -.94121300E-01, -.35894200E-01, -.19842800E-01, 0.43980900E-01, -.72662300E-02, -.43880100E-01, -.11681600E-01, 0.12775300E-01, 0.74292500E+00, 0.61291400E-01, -.11060200E+00, -.20253300E+00, 0.72240300E-01, -.13115800E+00, 0.13666200E+00, -.44117500E-01, -.79706300E-01, 0.11410800E+00, 0.17895700E+00, -.23306500E+00, -.18036200E+00, 0.14387600E+00, 0.76704600E-01, -.30597300E+00, -.14474600E+00, 0.16440800E+00, -.84976800E-01, 0.46119000E-01, -.85426200E-01, -.13365500E+00, 0.10293700E+00, -.87636600E-01, 0.17597100E+00 },
        { 0.19276400E+02, -.66369400E+01, -.12770600E+01, -.14339300E+01, 0.67353700E+01, 0.23773100E+01, 0.16517900E+02, -.14991900E+01, 0.10394200E+02, -.14444400E+02, 0.80588900E-02, 0.15572500E+01, 0.21546100E+01, -.39053000E+01, 0.72043000E+01, 0.15444500E+01, 0.96647300E-01, 0.12980800E+01, -.41681200E+01, 0.67777300E+01, -.25596300E+00, -.74792700E+00, -.19265200E+00, 0.74997800E+00, -.58404800E+01, -.16162600E+00, -.82154700E+00, 0.34336500E+00, 0.17434000E+01, -.22500200E+01, -.16133800E+00, -.32190600E+01, -.28531700E+01, 0.19365600E+00, -.94481400E+00, 0.89092600E-01, 0.67347100E-01, 0.43999800E+00, -.27725300E+01, 0.80167500E+01, -.41480600E+00, -.85544700E-01, -.43435600E-01, -.10797800E+01, 0.18426800E+00, -.63166400E+00, -.11945400E+01, 0.49054500E-01, 0.57414600E+00, -.51281300E+00, 0.48393000E+01, 0.29544000E-01, -.78814000E+00, 0.41876800E+00, -.22905700E+01, -.10819200E+00, -.32168800E-02, -.41926400E+00, 0.61419200E-01, 0.24680400E+01, -.23898000E+01, -.46018200E+01, -.24912900E+01, 0.37681700E+01, -.64843700E+00, -.10941600E+00, -.35189400E+01, 0.43063300E+00, -.33969700E+00, 0.32289500E+00, 0.78678400E+00, -.49008900E+00, 0.34196400E+01, -.91579100E-01, 0.18728900E+01, -.56090500E+00, 0.72930300E+00, 0.42140500E-01, -.29262800E+00, 0.78164400E+00, 0.13393100E+00, -.42030000E-01, 0.29830500E+00, -.11949300E+01, -.19495400E+01, -.17184000E+01, -.37053100E+01, -.82874500E+00, -.53773500E+01, 0.25877700E+01, 0.46036900E+00, 0.98872700E-01, -.82219400E+00, 0.74172300E+00, 0.65805200E+00, -.84914500E+00, -.83347500E-01, 0.44158900E+01, -.17257500E+01, -.18661500E+01, -.15322200E+01, 0.15708200E+01, 0.15336900E+01, -.17112000E+01, 0.82858400E+00, -.60830600E+00, 0.29990400E+01, 0.38173800E+01, -.82756600E+00, 0.73164400E+00, -.50898600E+00, 0.17062200E+00, 0.32902300E-01, 0.53323200E+00, 0.14958500E+01, -.28714700E+01, -.50043800E+01, 0.22814700E+01, 0.56713700E+00, -.11134200E+01, 0.12505900E+01, 0.18693100E+01, 0.34763400E+00, -.23880500E+00, 0.41047300E+00, -.12340900E+01, -.14493400E+00, 0.21322900E+01, -.35515200E+01, -.46106200E+00, -.22355800E+00, 0.63314400E+01, -.13615000E+01, 0.88079900E-01, -.35279100E+00, -.21413800E-01, 0.53498300E+01, -.15366800E+01, 0.52714200E+00, 0.38588900E+01, 0.87683300E+00, -.82750100E+00, -.12119000E+01, 0.10423700E+01, 0.40200600E+00, -.26081000E+01, -.11573300E+00, -.24272900E-02, 0.85444400E+00, -.17293700E+01, -.14373000E+01, -.77979500E+00, -.20399100E+01, -.11736000E+01, -.55765200E-01, 0.11601200E+01, -.35331800E+01, 0.32841400E-01, -.10933100E+01, -.28245200E+01, 0.50374800E+00, 0.15535900E+01, 0.16792200E+01, 0.24339000E+00, -.12944300E+01, -.30565700E+00, -.49954100E+00, 0.18529700E+00, -.26635300E+00, 0.29681300E+00, -.47616600E+00, 0.92505700E+00, -.47593400E+00, -.34774800E-01, 0.20823200E+01, 0.33893900E+01, -.83906900E+00, -.19813600E+01, 0.10015800E+01, 0.32410900E+01, -.34767900E+01, -.19038000E+00, 0.39367900E+00, -.24817700E+01, -.26824500E+01, 0.68779500E-01, -.10244700E+00, -.18000700E+01, 0.65400000E+00, -.17090100E+01, -.97132800E-01, -.11494800E+01, -.12970100E+01, 0.28812500E+01, 0.90047100E+00, -.31968800E+00, -.23556700E+01, -.13359700E+01, 0.49833300E+00, -.70847700E+00, -.25836900E+01, 0.54274800E+00, -.28701200E+01, -.90158300E+00, -.32377600E+00, 0.64344700E+01, -.32455400E+01, 0.97277600E+01, -.13884100E+01, -.36334700E+01, 0.13160700E+01, -.18017900E+01, 0.23616000E+00, -.70326000E+00, -.24852600E+00, -.29493700E+01, 0.62666700E-01, 0.49024200E+00, 0.11023600E+01, 0.42320000E+00, -.32435800E+00, 0.74531600E-01, -.92429600E-01, 0.10796000E-02, -.26418100E+00, 0.75320200E+00, 0.19374600E+00, 0.30800100E+00, 0.18690300E+00, 0.38465600E+01, -.34111200E+01, -.28591400E+00, -.28281500E+01, -.76675300E+00, -.37272200E+00, -.21244100E+00, -.22532300E+01, 0.13357200E+01, -.59518200E+00, 0.46268200E+00, 0.11728800E+01, 0.18556700E+01, 0.11935700E+01, 0.26297200E+00, -.16452300E+01, 0.61990600E-01, -.48703800E+00, 0.72067400E-01, 0.59129300E+01, 0.10318100E+01, 0.61807900E-01, 0.31524600E+00, -.12365000E+00, -.23438100E+01, 0.23263600E+00, 0.81017000E+01, -.17349600E+00, 0.66773800E-01, -.50158700E+00, -.26491200E+01, -.74084900E+00, 0.30866300E+02, -.84418900E+00, 0.35844500E+00, -.15328200E+00, 0.66443100E+00, -.17754900E+00, -.13088600E+00, 0.51469400E+00, -.75199400E+01, 0.19640000E+01, -.30104700E+01, -.15777900E+01, 0.41958800E+01, -.10568000E+01, -.27019600E+00, 0.13053600E+02, 0.85332100E+01, -.25349400E+01, -.17246300E+02, 0.56046800E+01, -.32888700E+01, 0.87647500E+01, -.56214900E+00, -.27713400E+01, 0.12710400E+01, 0.36561400E+02, -.12268300E+02, -.13084900E+02, 0.36686800E+02, 0.33282100E+01, 0.99787000E+00, -.17091400E+01, 0.36700200E+02, -.32232700E+01, 0.16769500E+02, -.20581200E+01, -.36488500E+02, 0.17946900E+01, -.13456200E+01, 0.15730500E+02 },
        { 0.40431500E+01, -.87155900E+00, -.24632600E+00, -.11741300E+01, 0.10033300E+01, 0.40139500E+01, 0.16901400E+01, -.66514500E+00, 0.21647400E+01, -.23197000E+01, 0.80637100E-02, 0.23161300E+00, -.86641000E-01, -.20135800E+00, 0.56403400E+00, -.21014700E+00, -.17127900E+00, -.22621600E+00, 0.10677600E+00, 0.80189900E+00, 0.47726100E+00, -.11720500E+00, 0.12082600E+00, 0.13303000E+00, 0.24121400E+00, -.61805200E-01, -.14210200E+00, -.86615900E-01, 0.28179100E+00, 0.34453800E+00, -.21108800E+00, 0.16493500E-02, -.56312300E+00, 0.57670800E-01, -.17288900E+00, 0.81497600E-01, 0.90926300E-01, -.28134300E+00, 0.13645800E+01, -.13098600E+01, -.12451700E+00, 0.14339800E+00, 0.63309100E+00, -.88996600E+00, -.31649200E+00, 0.35377600E-01, 0.33366100E+00, 0.77188800E-02, -.14368100E+00, -.29972000E+00, -.13472700E+01, -.28878900E-01, 0.27065100E+00, 0.33966200E+00, 0.25596800E+00, -.50193000E+00, -.62403900E-01, -.12695200E+00, -.20727900E-02, 0.25533000E-01, 0.94771200E+00, 0.10974100E+01, 0.16646900E+00, 0.21032900E+00, -.11899700E+01, -.94256800E-01, 0.21136300E+00, -.15402300E+00, -.28652300E+00, -.90537700E-01, -.17666500E+00, 0.21905000E+00, -.10648400E+01, -.40831000E-01, -.35313000E+00, -.74006200E+00, 0.35250100E+00, -.36121200E-01, -.49314400E-01, -.26539300E+00, -.52482500E-01, -.22976700E+00, 0.30675400E+00, 0.19275900E+00, -.47374700E+00, -.28717800E+00, -.70324200E+00, -.64524900E+00, 0.19143400E+01, 0.35034700E+00, -.68119100E+00, -.59560100E-01, -.12198300E+00, 0.55212200E-01, 0.64561500E+00, -.12335400E+01, 0.31314900E+00, -.57071500E-01, 0.22763500E+00, 0.34330300E+00, 0.29886700E+00, -.44930500E+00, -.97938400E-01, 0.12860400E+00, 0.34723100E+00, 0.30174300E-02, -.21882000E+00, -.41669300E+00, 0.85430600E+00, 0.14758000E+00, -.77815400E+00, 0.17744900E+00, -.51241100E-01, -.22346000E+00, -.12406100E+00, 0.57771900E+00, -.87249000E+00, -.40031900E+00, 0.45069200E+00, -.33137700E-01, 0.62792100E+00, -.17247000E+01, -.18600300E+00, -.24021900E+00, -.16885700E-01, -.56275800E-01, -.25920800E+00, 0.99115200E-01, -.33390100E+00, -.43200700E+00, 0.71854800E+00, -.11211600E+01, -.20161900E-01, 0.29977900E-02, -.76978900E-01, 0.22560100E-01, 0.14569000E+01, 0.58462300E+00, 0.61658100E-01, -.98163400E+00, 0.12146300E+01, 0.24755100E+00, -.84796900E+00, -.33116300E+00, 0.87847300E-01, -.68680400E+00, 0.62890700E-01, -.33740100E+00, -.12567700E+00, -.62656000E-01, -.96462100E-01, -.15446300E+00, 0.54292200E+00, -.20437500E-01, 0.44999300E-01, -.11987000E+00, 0.71179500E+00, 0.76204000E-03, 0.92528400E+00, -.27741800E+00, 0.67133800E-02, -.50092400E-01, -.74426500E-01, 0.56404800E-02, 0.10951100E+00, -.15070800E-01, -.84372700E-02, 0.85972000E-01, -.13869200E-01, -.31549200E-01, -.45639100E-01, 0.74805100E-01, -.50175500E-01, -.44945400E-01, -.10930200E+00, -.68445000E+00, 0.14875100E+00, 0.31086800E+00, -.20834900E+00, -.19130800E+00, -.12043900E+01, -.22181300E-01, 0.23318600E+00, 0.30226200E+00, -.13492600E+00, 0.46884400E-02, 0.78931300E-01, 0.10444600E-01, -.31542900E-01, 0.85541200E-01, 0.92996300E-02, -.16637200E+00, 0.98095600E-02, -.10275400E+00, -.58526700E+00, -.27386900E+00, -.18958200E+00, -.78568000E-01, 0.49625600E-01, -.84641500E-01, 0.29263500E+00, -.13449100E-01, -.24262800E-01, 0.12232600E+00, -.25225800E+00, -.61103400E+00, -.87813600E+00, 0.28735700E+00, 0.53144000E-01, 0.22983800E+00, -.35422000E-01, 0.45038100E-01, 0.81113100E-02, 0.26684900E-01, -.68636200E-01, 0.14180600E+00, 0.51350600E-01, 0.25600000E-01, 0.10488500E+00, -.10737100E-01, 0.72403400E+00, -.13185400E+00, -.70434200E-01, 0.20043700E-01, -.21663100E-01, 0.53048100E-01, 0.93901100E-01, -.39786600E-01, 0.34333100E-03, -.51656100E+00, -.54625800E+00, 0.89627700E-01, -.34259400E+00, -.42581400E-01, 0.10602600E-01, 0.31159700E-01, 0.42740600E+00, 0.26304100E+00, -.18939300E-01, 0.57243300E-01, -.98032400E-01, -.30854100E+00, 0.37551800E-01, 0.49025800E-01, -.15086900E+00, 0.34616600E-02, -.13748500E-01, -.43329900E-02, 0.28377700E+00, -.74965800E-01, 0.19388000E-02, -.12062300E-01, 0.54704300E-01, -.67134200E-01, -.62486500E-01, -.16448800E+00, -.39715100E-02, -.71021700E-01, 0.32691800E-02, 0.14041500E-01, -.62896900E-01, 0.12110000E+01, -.12496900E+00, 0.30225900E-02, 0.21448300E+00, 0.49444300E-01, 0.51200600E-01, -.19283100E-02, 0.39712100E+00, -.29635400E+00, 0.14452100E+00, -.87596700E+00, 0.70687000E-02, 0.26310000E+00, 0.62017200E-01, 0.34634500E+00, -.86226400E+00, -.18298300E+00, -.19103000E+01, -.59836600E+01, 0.28649100E+01, -.96197000E+00, 0.41870900E+01, -.25037200E+01, -.15899700E+01, -.75116100E+00, -.13319300E+02, -.55094900E+01, -.45838400E+01, -.14022600E+02, 0.16163900E+01, -.36231400E+01, -.21118400E+01, -.11727700E+02, -.11234000E+01, 0.73918500E+01, -.10612200E+01, 0.14624900E+02, 0.91842500E+00, -.42535000E+00, 0.61717300E+01 },
        { -.17706200E+01, -.79037300E+00, 0.26784500E-01, -.44364800E+00, -.15723200E+01, -.14759800E+01, 0.64497100E-01, -.59656300E+00, -.52843600E+00, 0.15143300E+01, 0.40751500E-01, -.61319600E-01, 0.39399200E+00, 0.91771600E+00, -.49488600E+00, -.19199400E+00, -.63579100E-01, -.29612200E+00, 0.35409200E+00, -.28546800E+00, 0.25084200E+00, -.21233100E-01, 0.88059700E-01, -.15059800E+00, 0.11708500E+01, 0.23234500E-01, -.13091900E+00, -.19565900E+00, 0.23786100E-01, 0.21070900E+00, 0.28646200E+00, 0.67687900E+00, 0.41186600E+00, 0.23088700E+00, 0.30230500E+00, -.90337000E-01, 0.23453500E-01, 0.26104700E+00, -.68279100E+00, 0.81219900E+00, 0.92190600E-01, 0.50992300E-01, 0.96152200E-01, 0.15852900E+00, -.41946200E-01, -.23671200E-01, 0.14592500E+00, -.26751500E-02, -.10657600E-01, -.14412700E+00, 0.45955600E+00, 0.10884100E+00, -.26173100E-01, 0.39308300E-02, -.24423000E+00, -.98941300E-01, -.21904300E+00, 0.16509000E-01, -.18291800E-01, -.16636800E+00, 0.25246000E+00, 0.13930200E-01, 0.51439100E-02, -.18212400E-01, 0.57838700E-01, 0.52390400E-01, 0.53318900E-01, -.21471400E-01, 0.52730700E-01, -.10419700E-03, 0.27412700E+00, -.10366500E+00, 0.94482500E-02, 0.92570600E-01, 0.47113600E-01, -.12731600E+00, -.70477200E-01, 0.14201000E+00, 0.11923600E+00, -.16889200E+00, 0.33434300E-01, 0.57349700E-01, -.65367000E+00, 0.40613200E-01, 0.62026300E+00, -.10937700E+00, 0.35648800E-01, 0.12017800E+00, 0.12665500E+01, -.16207400E+00, 0.20645000E+00, 0.20681900E-01, -.35075800E-01, -.30877000E+00, 0.25766800E+00, 0.93375000E+00, -.18005100E+00, -.42446200E+00, 0.80660600E+00, 0.30630800E-01, -.11431500E-01, 0.34668800E-01, -.41328400E-01, -.67116400E-01, 0.17192500E-01, -.74855100E-01, -.21052700E+00, -.10533600E+00, 0.14217000E+00, -.19923300E-01, -.43762400E-01, -.20641200E-01, -.21077400E-01, -.24551200E-01, -.26673600E+00, 0.26728900E+00, 0.59683500E+00, -.31847500E+00, -.97032700E-01, 0.13335500E+00, -.74806000E-01, 0.23853500E+00, 0.65521100E-02, 0.50966300E-01, 0.13525400E-02, 0.18344000E+00, -.44266900E-01, -.23880100E+00, 0.13427200E+00, -.33083500E-01, 0.17298600E+00, 0.29864300E+00, -.18631700E+00, 0.35376100E-02, 0.40003600E-01, 0.66740900E-03, -.18800800E+00, 0.24134900E+00, -.14430600E+00, -.10021800E+01, 0.19004000E+00, -.21313200E+00, -.24987000E+00, -.87420900E-01, 0.59828300E-01, -.11309100E+00, 0.80947500E-03, -.68844000E-01, -.40683100E-02, -.37732400E-01, -.81939400E-01, -.13051900E+00, -.26576900E+00, 0.82091300E-01, -.60084100E-01, -.17954700E-02, -.47934400E-01, 0.57978100E-02, -.31204000E-01, -.93520400E-01, 0.61773000E-02, -.54938400E-01, -.12592700E+00, 0.64144500E-02, -.36199200E-01, 0.63162900E-01, -.93188200E-01, -.16541600E+00, 0.25001200E-01, -.71555300E-01, -.58342700E-01, 0.30553000E+00, -.88796300E-01, 0.45014000E-01, -.14170700E+00, 0.66604700E-01, 0.27758000E-01, 0.41869800E-01, -.56366500E-01, 0.16641800E+00, -.48160100E+00, -.32570000E+00, 0.38327200E+00, 0.24264900E+00, -.35907900E+00, 0.25076900E-01, -.22025800E-01, 0.28887000E+00, 0.65511900E-01, 0.75083700E-01, -.26498400E-02, 0.29772100E+00, 0.11241900E+00, 0.15477700E-01, 0.20225700E+00, 0.17331400E+00, -.23643600E+00, -.58733800E-01, 0.34113600E-01, 0.40941100E-01, 0.84128800E-01, -.24272600E-01, 0.76912400E-01, -.48701700E-01, -.13224400E+00, -.11540900E+01, 0.11857300E-01, -.37288300E-01, -.37541700E-01, 0.95841300E-01, -.21376100E-01, -.26804100E-01, -.13420200E-01, 0.98583500E-02, 0.21396700E+00, -.27379400E+00, -.56016200E-01, 0.12841900E-01, 0.57126500E-01, 0.26448400E-01, -.11388100E+01, -.56204500E-01, -.26659500E-01, 0.13422100E-01, 0.29762300E-01, 0.74208700E-01, -.57006700E-01, 0.74789400E-02, 0.56635100E-01, 0.64956500E+00, -.11533200E+00, 0.95476100E-01, -.12074400E+00, 0.68884900E-02, -.18319700E-02, -.24376600E-01, -.36068700E+00, -.17073500E+00, 0.27111400E-01, 0.73424000E-02, 0.28665500E-01, 0.19712400E+00, -.28168100E-01, 0.54641300E-02, -.56460700E-01, 0.12484000E-01, 0.19815300E-01, -.32718600E-01, -.19954300E+00, 0.83709700E-01, -.16620700E-01, -.83851900E-02, -.70172200E-02, -.71158200E-01, -.17349800E-01, 0.85411900E+00, 0.81393600E-02, -.11880600E-03, 0.44011800E-01, 0.77200400E-01, 0.25575800E-01, 0.38403600E+00, 0.37659100E-01, -.27438800E-01, -.52675800E-01, -.25030400E-01, 0.43395400E-02, 0.58387100E-02, -.14215600E+00, 0.23939400E+00, -.27029200E-01, 0.71792900E-01, 0.28304200E-01, -.16494100E+00, 0.30735300E-01, 0.10357900E+00, -.15773600E+00, 0.28958000E-01, 0.29628800E+00, 0.19033600E+01, -.97053600E-01, 0.70101200E+00, -.10321300E+01, -.23402000E+00, -.13262600E+00, 0.65741200E+00, 0.56941500E+00, 0.13367400E+01, 0.11747400E+01, 0.63520900E+00, -.34464800E+00, 0.42444700E+00, -.41971100E-02, 0.26953100E+00, 0.70419700E+00, -.23096200E+01, -.29954300E+00, -.75527700E+00, 0.35063800E+00, 0.41311800E+00, -.18436500E+01 },
        { -.17588000E+02, -.42086800E+00, 0.22619600E+00, -.34483500E+01, -.66951700E+01, -.12098400E+01, -.17158000E+02, 0.61382800E+01, -.94077600E+01, 0.14024500E+02, -.70624400E-01, -.10870700E+01, 0.17433500E+01, 0.17130500E+01, 0.32729300E+01, 0.20318900E+01, -.15794900E+01, 0.37882700E+01, -.34710200E+01, 0.38839800E+00, 0.40727600E-01, 0.40071600E+00, 0.29716300E-01, -.40909500E-01, 0.39999800E+00, 0.18520400E+00, -.10935100E+01, 0.23038000E+01, -.46099700E+01, 0.81894400E+00, -.11036100E+01, -.19895200E+01, 0.75120900E+00, 0.75694600E+00, 0.15251000E+01, -.23401800E+00, 0.35286900E+00, 0.46410300E+00, 0.33252200E+01, -.93124200E+01, -.44369200E-01, -.71525800E+00, 0.88673900E+00, -.27124200E+00, 0.26365800E-01, 0.41492700E+00, 0.34781400E+00, -.10811400E+00, -.21399100E-01, -.33166500E+00, -.32193800E+01, 0.82276900E+00, 0.27593900E+00, -.95724800E+00, -.10809700E+01, -.51304700E-01, 0.53750800E+00, 0.55389100E+00, -.20254500E+00, -.20330100E+00, 0.18354200E+00, -.41666000E+01, -.26636200E+01, -.54517900E+00, 0.74471100E+00, 0.32785400E-01, 0.91169600E+00, -.52879200E+00, 0.52559000E+00, 0.85659600E-01, 0.19702100E+01, -.50549100E+00, 0.12638500E+01, 0.34646400E+00, 0.19907100E+00, 0.83287900E+00, 0.33498900E+00, 0.79000000E-01, 0.42214100E+00, -.19325300E+00, 0.15897200E+00, -.77799800E+00, -.17896200E+01, 0.54199100E+00, 0.37490700E+01, -.86056600E-01, 0.62871800E+01, -.41611800E+01, -.67377400E+00, 0.11234100E+01, 0.57838700E-02, 0.19429800E-01, 0.66986500E+00, -.61367200E+00, -.12136200E+01, 0.82345700E+00, 0.31479800E-01, -.25397500E+01, 0.28354000E+00, 0.15773300E+01, 0.80937800E+00, -.39930800E+00, -.40302400E+00, 0.17517700E+01, -.59155200E+00, 0.49798300E+00, -.21021800E+01, -.24426100E+01, 0.23697800E+01, 0.21804800E-01, -.17597700E+01, 0.68639600E+00, 0.28110000E+00, -.50354500E+00, -.88564400E+00, 0.13645400E+01, -.12900900E+00, 0.10805400E+01, 0.26024800E+00, -.52553600E+00, 0.11769000E+00, -.53495200E-01, -.27640000E+00, 0.20450200E+00, 0.82308000E-03, 0.61619300E+00, 0.20715400E-01, -.25009700E+01, 0.24732100E+01, 0.11901300E+01, -.29041800E+01, -.35811500E+01, -.95798900E+00, -.22387700E-01, -.92102400E-01, -.65036200E-02, -.44421300E+01, -.97018700E+00, 0.50966900E+00, 0.27292000E+01, -.19764500E+01, 0.14362100E+01, 0.18768700E+01, -.10051000E+01, -.29777400E+00, 0.33331100E+01, 0.47825500E+00, 0.44776000E+00, -.60162200E+00, 0.26421500E+01, 0.19271700E+01, 0.30288800E+00, 0.49022500E+01, 0.14884200E+00, 0.27765100E+00, 0.44107700E+00, 0.43330900E+01, 0.14269400E+00, 0.16233000E+01, 0.16901100E+01, -.19910100E+00, -.21421600E+01, -.23112300E+01, -.26137200E+00, 0.14162100E+01, -.12295700E+01, 0.27948600E+01, -.79301900E+00, -.21279800E-01, 0.24666600E-01, 0.79055900E+00, -.50446500E+00, 0.80683200E+00, -.83263700E+00, -.44455800E+00, 0.13603700E+01, 0.63911800E+00, 0.25575200E+01, -.16922700E+00, -.33780200E+01, -.79035500E+00, 0.11070600E+01, -.28139200E+00, 0.15896000E+01, 0.29773600E+01, -.52186400E+00, 0.71835700E+00, 0.18881500E+01, -.97053200E+00, 0.12387700E+01, 0.11131000E+00, -.12233400E+01, 0.38135900E+00, -.24433100E+01, -.20905400E+01, -.19501300E+00, 0.15040500E+01, 0.98883100E+00, -.60058600E+00, 0.13490900E+00, 0.39047000E+01, -.44298800E+00, 0.18506400E+01, 0.14144600E+01, -.13793000E+01, -.46758900E+00, -.26484500E+01, -.47491700E+01, 0.78391900E+00, 0.35067200E+01, -.11815700E+01, 0.12404100E+01, -.86515800E-01, 0.98617500E+00, -.48073500E+00, 0.48192500E+01, 0.28128000E+00, -.27586500E+00, -.35599300E+00, -.41325300E+00, 0.58150600E+01, 0.15431100E+00, -.88376500E-01, 0.26139600E-01, -.55330000E+00, -.58383400E+00, 0.53597800E+00, -.51014900E+00, -.45861500E+00, -.12511700E+02, 0.26413200E+01, 0.38980400E+01, 0.18658700E+01, 0.19087400E+00, 0.15790400E+00, -.26461400E+00, 0.10346200E+00, -.57044900E+00, 0.48399100E-01, 0.31249400E-01, -.52813300E+00, -.48513100E+00, -.33874500E+00, -.81672500E+00, 0.19242900E+01, -.30204200E+00, 0.43410200E+00, 0.42766400E+00, -.60789400E+01, -.55032900E+00, -.66019000E-01, -.22532900E+00, 0.24457200E+00, 0.56148100E+00, -.64479700E+00, -.16143200E+02, -.47494000E-03, -.22208300E+00, 0.52663100E+00, 0.24651800E+01, 0.76775300E-01, 0.39823300E+01, -.20617800E+01, -.58847300E+00, 0.60830000E+00, 0.10264800E+00, 0.23454000E+00, 0.33094000E-01, 0.31852800E+01, 0.70431300E+01, -.48189900E+01, 0.20687800E+01, 0.25642900E+00, -.14983600E+01, 0.31604400E+00, -.20430700E+01, 0.40122800E+01, -.16418000E+00, -.39989800E+01, -.89723000E+01, -.85714700E+01, -.22591300E+00, -.28457200E+01, -.22032300E+01, 0.67596300E+01, -.11503700E+02, 0.25808400E+02, 0.23359400E+01, 0.52141500E+01, 0.26811100E+02, 0.17186100E+01, 0.47214800E+01, 0.13043400E+01, 0.21671200E+02, -.19993800E+00, -.86891800E+01, 0.98171700E+01, -.28511400E+02, -.10108400E+02, -.30851400E+00, -.43633200E+00 },
        { 0.48941300E+01, -.31314300E+00, -.23241300E+00, -.61425200E+00, 0.15213100E+01, 0.30175100E+01, 0.17500900E+01, -.17251300E+00, 0.22198000E+01, -.31297200E+01, -.82546700E-02, 0.31689600E+00, 0.25937800E+00, -.10773000E+01, 0.20179900E+01, 0.21663600E+00, 0.18756700E+00, 0.35114200E+00, -.97855800E+00, 0.13223900E+01, -.42618900E+00, -.52823900E-01, -.87674000E-02, 0.35239600E+00, -.16736000E+01, -.68884500E-01, -.48333700E-01, 0.18342700E+00, 0.66357500E+00, -.21128800E+00, -.33252300E+00, -.62856700E+00, -.92232200E+00, -.15033300E+00, -.27382500E+00, 0.19527800E+00, 0.97248500E-01, -.53372100E+00, 0.78968400E+00, -.26101600E+01, -.11223400E+00, -.21268400E+00, -.26954100E+00, -.22249700E+00, -.20687400E+00, -.30766500E-01, -.42793000E+00, 0.86434800E-02, 0.70549500E-01, 0.43584600E-01, -.65784500E+00, -.21114300E+00, 0.49450200E+00, 0.72259400E-01, 0.49814800E+00, 0.15962000E-01, 0.65492000E+00, 0.89715600E-01, 0.41259700E-01, 0.48068800E+00, -.85451100E-01, 0.84213600E+00, 0.36645200E+00, 0.52361500E+00, -.39976900E+00, -.67218300E-01, -.25064600E+00, 0.25691800E+00, -.73166500E-01, 0.22783100E-01, -.37003000E+00, 0.25652500E+00, -.36543800E+00, 0.20914400E+00, 0.46531800E+00, -.76181500E+00, 0.34821200E+00, 0.26641700E+00, -.45056600E-01, -.54966800E-01, -.11196900E-01, -.30820700E-02, 0.60652100E+00, -.12284100E+00, -.10205700E+01, -.49252900E+00, -.15027100E+00, -.19865900E+00, -.43093800E+00, 0.69840900E+00, 0.98341200E+00, -.18896700E-01, -.11135700E+00, 0.58967400E-01, -.26172200E+00, -.94252500E+00, 0.18608100E+00, 0.52463700E+00, -.44705600E+00, -.12389700E+00, 0.68471900E-01, -.22562200E+00, 0.28315700E+00, -.32299900E+00, 0.19730400E+00, -.43649900E+00, 0.15016600E+00, -.36288000E-02, 0.11328200E+00, 0.53639500E-02, 0.27373100E+00, -.70224800E-01, -.37730000E-01, 0.14678100E+00, 0.33000200E+00, -.45305000E+00, 0.38426700E+00, 0.32612000E+00, 0.14513000E+00, -.42797100E+00, 0.71730400E+00, -.64826200E+00, -.81550100E-01, -.31123300E+00, -.32374000E-02, -.17271600E+00, -.74979000E-01, 0.39986300E+00, -.12486100E+01, 0.53426100E-03, -.64260400E+00, 0.33913800E+00, -.62826200E+00, -.35669900E-02, -.88659900E-01, 0.59672600E-03, 0.16711800E+00, 0.32074400E-02, 0.62882100E-01, 0.17464900E+01, 0.85894100E+00, 0.96189300E+00, -.62796600E+00, -.34218300E+00, -.56249600E-03, 0.44314600E+00, -.11009700E-01, -.30644600E+00, -.54504600E+00, 0.14456900E+00, -.21396600E+00, -.35121000E+00, -.12769300E+01, 0.64810900E-01, 0.42780200E-01, 0.94279800E-01, -.64238200E+00, 0.19178200E-01, 0.31914000E+00, -.95350900E+00, 0.11763500E+00, 0.20852100E+00, 0.76206400E+00, 0.66438300E-01, -.31065800E+00, 0.55405100E-01, -.76710300E+00, 0.57247900E+00, 0.73322900E-01, -.13387600E+00, -.19662400E+00, 0.66781800E+00, -.19035000E+00, -.25718400E+00, 0.90930200E-02, -.77570600E+00, 0.65728800E-01, -.82741800E-01, -.15807600E+00, 0.11580900E+01, -.24558600E+01, -.47290400E+00, 0.94416100E+00, 0.39998400E+00, -.89260800E+00, 0.96581700E-01, 0.10577700E-01, -.15378200E+00, 0.48000200E-01, -.27001800E-01, -.33012100E-03, -.11093800E+00, 0.11939300E+00, -.52084500E+00, -.31807500E+00, -.15050400E+00, -.34685200E+00, -.54427500E-01, 0.26117900E-01, -.11327600E+00, 0.84705600E+00, 0.24828400E-01, -.66464600E-01, 0.55335500E-01, -.45821700E+00, -.38425700E+01, -.94914000E+00, 0.58523100E+00, -.14267600E+00, 0.15994300E+00, -.28520500E+00, 0.13262600E+00, 0.37783500E-01, 0.13422300E+00, -.28681700E+00, 0.44075700E+00, 0.58716100E-01, 0.13445500E+00, 0.13419900E+00, -.24102200E-01, -.15288900E+01, 0.12543700E+00, 0.84845000E-01, -.31232500E-01, -.27437300E+00, 0.52279400E-01, 0.22166400E+00, -.15389900E+00, 0.68290700E-01, -.55882800E+00, -.93822500E+00, 0.36658300E+00, -.65755700E+00, 0.14519400E+00, 0.38242300E-01, -.24227200E-01, 0.17823800E+00, 0.96500000E-01, 0.46703000E-01, -.21547600E-01, -.10192300E+00, -.29443400E+00, -.65284900E-01, -.52187200E-01, 0.24084100E+00, -.42874500E-01, -.31986600E-01, 0.69814400E-01, -.34228900E+00, -.83044100E-01, -.20375100E-01, -.56568900E-01, 0.38492200E-02, 0.39690400E-01, -.11401800E+00, -.63764000E+00, -.14005900E-01, -.17924900E-01, -.22650600E-02, 0.29751300E+00, 0.69885100E-01, -.38718300E+01, 0.28217900E+00, -.42133800E-01, -.46448300E+00, 0.12439300E+00, -.67361000E-01, 0.40679000E-02, -.47355000E+00, 0.73220100E+00, -.13585000E+01, 0.35384500E+00, 0.13005200E+00, -.77584800E+00, 0.59961800E-01, -.48059600E+00, -.13057900E+01, -.58528800E-01, -.42271500E+00, -.16315700E+01, 0.62457500E-01, 0.87776100E+00, -.17457500E+01, 0.28675400E-01, -.17546000E+00, 0.12792900E+01, -.39919900E+00, 0.16809700E+01, 0.20984700E+01, -.26619400E+00, 0.97539800E-01, -.34520200E+00, 0.94166400E-01, -.98187600E+00, 0.88707200E+00, -.34652500E+01, -.70080600E+00, -.94220000E-01, 0.76426600E+00, 0.33739000E+00, -.30475600E-01 },
        { 0.19085600E+01, 0.39232000E+00, -.51044300E-01, 0.43946900E+00, 0.71246100E+00, 0.12449400E+01, 0.63950300E+00, 0.69747900E+00, 0.65892600E+00, -.96073200E+00, -.55428300E-01, 0.79330300E-01, 0.37917200E+00, -.44628200E+00, 0.15433700E-01, 0.20957800E+00, -.13999700E+00, -.27948500E+00, -.17276000E+00, -.13163700E+00, -.19527000E-02, -.30336900E-01, 0.22618300E-01, 0.85917400E-01, -.14654300E+00, -.28091000E-01, -.13062200E+00, -.36480600E+00, 0.43291400E+00, -.44369500E+00, 0.34247100E-01, -.24382900E+00, -.21796100E+00, -.12511600E+00, -.40084200E-01, 0.59756900E-01, 0.21684400E-01, -.84313400E-01, 0.14254200E+00, -.33431700E-01, -.18532000E-01, -.12226000E+00, -.33964200E-01, -.59124400E-01, -.14982900E+00, 0.11475500E-01, -.23123100E+00, -.19695400E-02, 0.19556600E-01, 0.32218200E-01, -.51299100E+00, 0.82697600E-01, 0.17002500E+00, 0.99632300E-01, 0.30306500E+00, 0.11105200E+00, 0.22292000E+00, 0.94647800E-01, 0.14412200E-01, -.29360400E-02, -.25507400E+00, 0.58501700E+00, 0.29657000E+00, -.87973300E-01, -.13873600E+00, -.74180400E-01, -.30516200E+00, -.13350200E-01, -.35324000E-01, -.59345800E-02, -.74634400E-01, -.46354300E-01, 0.54009100E-01, -.29569400E-01, 0.92878300E-01, 0.18886200E+00, 0.14557200E-01, 0.38617300E-01, -.75087900E-02, -.13397700E+00, -.52825200E-01, -.17819600E-01, 0.27402400E+00, -.44480500E-03, -.38361000E-01, 0.36034700E-01, 0.16099400E+00, -.10561000E+00, 0.14593000E+00, -.15982100E+00, 0.64969500E+00, -.14381100E-01, 0.12850000E+00, 0.13645300E+00, -.30283900E+00, -.23837300E+00, 0.26836800E-01, 0.45634100E-01, -.28096300E+00, 0.10884000E-01, -.17935800E-01, 0.22232900E-01, 0.76004300E-01, -.17185200E+00, 0.55991600E-01, -.12191700E+00, -.82557300E-02, -.71265200E-01, 0.35705400E+00, 0.32623300E-01, -.81144700E-01, -.13259300E-01, -.29024000E-01, -.79374300E-01, -.11086500E+00, 0.23590600E+00, 0.59468400E-01, -.25238100E+00, 0.34169600E-01, 0.70826300E-01, 0.21130500E+00, -.12608900E+00, -.59978900E-01, -.40245500E-01, 0.22262900E-02, 0.86011500E-01, -.32799800E-01, -.18658100E+00, -.14362100E+00, -.77280200E-01, 0.45828600E+00, -.50433300E+00, 0.21684000E+00, 0.15757800E-02, 0.30516200E-01, -.20267800E-03, -.30028100E+00, 0.19578200E+00, -.49981500E-01, -.53924900E+00, 0.13285500E+00, -.21764100E+00, 0.23264300E-01, -.72778200E-01, -.15431000E-01, 0.12208800E+00, -.31975200E-02, -.12143900E-01, -.79635900E-01, -.20728800E-01, -.54536900E-01, -.33371600E-01, 0.14574900E+00, 0.10262500E-01, -.25637700E-01, -.46467300E-01, -.51490900E-02, 0.61256400E-03, 0.55293900E-01, 0.11896100E+00, 0.14094200E-01, 0.19803400E+00, 0.26446700E+00, 0.42496900E-01, -.21555500E+00, 0.12347100E-01, -.70098800E-01, -.17238300E+00, 0.17121600E-01, -.20882400E-01, -.41109200E-01, 0.23448400E+00, -.46098100E-01, 0.48916400E-01, -.26461800E+00, 0.27887400E+00, -.15126300E-01, 0.54074400E-01, 0.17303400E-01, -.87851100E-02, -.19278200E+00, -.10422400E+00, -.51871400E-01, 0.84413500E-01, 0.15909600E-01, -.47883900E-02, 0.36341100E-01, -.75274200E-01, 0.68265000E-02, 0.16150000E-01, 0.51131600E-03, 0.50275600E-01, 0.46511500E-01, -.16141900E-01, -.29878700E+00, -.20451500E-01, -.81943700E-01, -.13104700E-02, 0.82847400E-01, 0.22131800E-01, 0.12515400E-01, 0.44063300E-02, -.11243900E-01, -.87996500E-01, -.13090200E+00, -.98786200E-01, 0.38980800E+00, 0.41102700E+00, -.42063600E-01, -.53219300E-01, -.49694100E-01, -.61488300E-02, -.30668600E-02, 0.27563900E-01, 0.41837400E-01, 0.74688100E-01, -.31750200E-01, 0.13288400E-01, -.91690900E-02, 0.29429500E-01, -.88276800E+00, 0.10237100E-01, 0.17154600E-02, 0.14018800E-02, -.16589000E-01, 0.32298100E-01, -.79423400E-02, 0.26600200E-02, 0.18729600E-01, -.51724500E-01, 0.29400600E-01, 0.49873200E-01, -.31302400E-01, 0.47344500E-01, -.53263900E-02, -.10507000E-01, -.14999000E+00, -.10489000E+00, 0.23368100E-01, -.20663200E-01, 0.51719200E-01, 0.16557200E+00, 0.15966200E-02, -.78791700E-02, -.34491700E-01, 0.76071300E-03, -.10017600E-01, -.13064900E-01, -.17200400E-01, 0.35659800E-01, -.47096900E-03, 0.18125600E-01, -.86503000E-03, -.18402600E-01, -.84511100E-03, 0.64257400E+00, -.39111500E-02, 0.13470200E-01, 0.24809500E-01, 0.95064700E-01, 0.31860800E-01, -.67690500E-02, 0.48834000E-01, -.73081100E-02, -.92915300E-01, -.16979000E-02, -.96775600E-02, 0.29766700E-02, -.20028600E+00, -.36935200E-01, 0.86197300E-02, 0.50685600E-01, 0.11482800E-01, -.92397700E-01, 0.28854500E-02, 0.25243400E-01, -.16809200E+00, 0.11338600E-01, 0.10181700E+00, 0.35188800E+00, -.13575100E-02, 0.39327600E+00, 0.63358300E+00, 0.11744500E+00, 0.36579400E-01, -.42929100E+00, 0.22868300E+00, -.55597000E+00, -.84502800E+00, 0.17681800E+00, -.88833900E-01, 0.23807600E+00, -.41257500E-01, 0.45265900E+00, 0.44813500E-01, 0.13271800E+01, 0.19722500E+00, -.36106100E-01, -.23741800E+00, -.15179800E+00, 0.11925500E-01 },
        { -.27992400E+01, -.90937300E+00, -.49580700E-01, -.44526700E+00, -.12190600E+01, -.10370500E+01, -.22935300E+01, 0.33350500E+00, -.14771400E+01, 0.23301700E+01, -.70675800E-02, -.17867600E+00, -.72210300E+00, 0.14231600E+01, -.10102600E+01, -.39970000E-01, 0.39595100E+00, 0.22240400E+00, 0.37239300E+00, -.23598200E+00, 0.29276300E+00, -.29661400E-01, -.11020700E+00, -.10657400E+00, 0.55697200E+00, 0.21426700E-01, -.94354300E-01, -.12872300E+00, -.33380200E+00, -.32762900E+00, 0.43636900E-01, -.22915000E+00, 0.14911300E+00, -.31765000E-01, 0.40911800E-01, 0.33463100E-02, -.12921700E-01, 0.58499300E-01, -.13835600E+00, 0.22430600E+00, 0.27621500E-02, -.51115300E-02, 0.18619800E+00, 0.56184000E-01, 0.23130300E-02, 0.47926700E-01, 0.69177500E-01, -.10915300E-01, -.18055400E-01, 0.42084200E-01, -.33820100E+00, 0.13699600E+00, -.75928900E-01, 0.87476900E-01, 0.63395900E-01, -.15427700E+00, -.24377900E-01, 0.41200000E-01, -.11638500E-01, -.20390500E+00, 0.51090900E-01, 0.31705400E-01, -.20315300E-01, -.13533200E+00, -.36350000E-03, 0.25286600E-01, 0.26999800E-01, -.32812100E-01, 0.10332100E-02, -.92051900E-02, 0.36368000E+00, -.45339900E-01, -.30545200E+00, -.72015400E-02, -.20088300E+00, -.42269000E-02, 0.42441900E-01, -.56435000E-01, 0.67404900E-01, -.31447600E+00, 0.17366000E-01, 0.13265700E-01, 0.47748900E+00, 0.13307700E+00, -.57464700E+00, 0.77478300E-02, -.12158500E+00, 0.33911500E+00, -.86747100E+00, -.37474600E-01, -.36738700E+00, 0.15721200E-01, 0.19676500E-02, -.86084500E-02, -.40115300E+00, 0.43354700E+00, -.17272900E+00, -.35476900E+00, -.28300900E+00, -.14318600E-01, 0.31636800E-01, -.31074900E+00, -.17394600E+00, 0.52045500E+00, -.21960900E+00, 0.59255400E-01, 0.20166200E-02, -.21991500E+00, -.42803600E+00, -.13830200E+00, 0.10977200E+00, -.39591100E-01, 0.82987500E-02, -.25344600E-01, 0.70664500E-01, 0.46687900E+00, 0.12639900E+00, -.40950500E-01, -.43472200E-01, -.12456700E-01, -.29627500E+00, 0.26034800E+00, 0.23736000E-01, 0.30238500E-01, -.98015900E-03, 0.12047200E+00, -.10213400E-01, -.34637000E-01, 0.14457500E+00, 0.25040800E+00, -.55166800E+00, -.70506800E+00, -.13524700E+00, -.69162300E-02, 0.77826700E-02, 0.40817000E-02, -.53400500E+00, -.14014100E+00, 0.11064400E+00, 0.49437400E+00, -.20626600E-01, 0.58502200E+00, 0.22959800E+00, -.31345200E-01, -.72133100E-02, 0.12892400E+00, 0.11785200E-01, -.37541100E-01, -.33894100E-01, 0.20630900E+00, 0.16797800E+00, 0.12598300E+00, -.42631600E-01, 0.11465900E+00, 0.31712100E-01, 0.17345000E-01, 0.41795700E+00, 0.16537000E-03, 0.22511800E+00, 0.14842600E+00, -.36494000E-01, -.29789300E+00, -.31867000E+00, -.77671600E-02, 0.21149200E+00, -.23176500E-01, 0.11636900E+00, 0.31190800E-01, 0.31243500E-01, -.79193900E-01, 0.16371100E-01, -.87413300E-02, 0.44137200E-01, -.56603700E-01, 0.12486000E-01, -.17457700E+00, 0.42934500E-01, 0.46566700E-01, 0.38925700E-01, -.21972400E+00, -.79531100E-01, 0.14877700E+00, -.11762700E+00, -.24416000E-01, 0.21273300E+00, 0.37170500E-01, -.28257800E-01, 0.16313200E+00, -.45123000E-01, 0.35348800E-01, -.22119900E-02, 0.62176300E-01, -.55092100E-03, -.92151400E-01, 0.13232700E+00, 0.10495000E+00, 0.55241200E-01, 0.53768900E-01, -.50699700E-01, 0.31417600E-03, 0.10696300E+00, -.14973000E-01, 0.67419200E-01, 0.11680700E+00, 0.77517600E-01, 0.44901200E+00, -.11441100E+00, -.97998400E-02, 0.26801800E-01, 0.19289600E+00, -.12097300E-01, 0.59495800E-01, -.13837200E-02, 0.10368900E-01, -.62291000E-02, 0.23407900E+00, 0.17708600E-01, -.48705000E-02, -.29559000E-01, -.26567600E-01, 0.54097400E+00, 0.36561300E-01, 0.24936000E-01, -.97578200E-02, -.28711200E-01, -.23368600E-01, 0.12225700E-01, -.48927500E-01, -.15911700E-01, -.53877300E-01, -.62384500E-01, -.14047300E+00, -.54116500E-01, -.62667000E-01, 0.29351100E-01, 0.86024500E-02, 0.25828300E+00, 0.13744600E+00, -.16931900E-01, 0.28654800E-01, -.89141600E-01, -.27609900E+00, -.35621600E-01, -.33624600E-01, 0.10072200E+00, -.81715200E-02, 0.47937200E-01, 0.19591200E-01, -.26367600E+00, -.18200200E-01, -.12962000E-01, -.36581200E-01, -.11359800E-01, 0.65890400E-01, -.65063300E-02, -.66768700E+00, 0.11036100E-01, -.10139500E-01, -.28698700E-01, -.10712800E-01, 0.15381200E-01, -.58705500E+00, -.14361900E+00, -.17730300E-01, 0.11540900E+00, -.47342800E-01, 0.99162900E-02, 0.33948200E-02, 0.18109100E+00, 0.28646600E+00, 0.96742400E-02, 0.85395500E-01, 0.66729000E-02, 0.72692800E-02, -.38246900E-02, -.63975200E-01, 0.11618000E+00, -.15090000E-01, -.40994000E+00, -.11393300E+01, -.39799500E-01, 0.20950600E+00, 0.73470500E+00, -.10042400E+01, 0.65558700E-01, -.25013300E+00, -.54261700E+00, -.36959400E-01, 0.30805400E+00, -.57980900E+00, 0.12854600E+00, -.82297300E-01, -.49798800E-01, -.74731900E+00, -.21190500E-01, -.58218600E+00, 0.14002900E+00, 0.46923100E+00, -.11953700E+00, 0.25061500E+00, 0.31041800E-01 },
        { -.18936200E+01, 0.24636400E-01, 0.11488200E+00, 0.47041800E+00, -.93330700E+00, -.32722700E+01, 0.18521400E-01, 0.37518700E+00, -.10575600E+01, 0.93561900E+00, 0.86295600E-01, -.10529500E+00, 0.20359400E+00, 0.12521600E+00, 0.29964100E+00, 0.11716000E+01, 0.75843900E+00, -.39093700E+00, -.62616000E+00, -.28686300E+00, -.42933500E+00, 0.11808400E+00, 0.84527300E-01, 0.36579800E+00, -.66777100E+00, -.13122400E-01, -.17395900E+00, -.84013000E+00, 0.76893800E+00, 0.49999200E+00, -.34611300E+00, 0.63203000E-01, -.43800500E+00, -.62878400E+00, 0.22272800E+00, -.22510400E+00, 0.12705600E+00, -.10633300E+01, 0.65267600E+00, -.51539000E+01, -.15041100E+00, -.64031400E+00, 0.56347900E+00, 0.55061100E+00, -.11494600E+00, 0.15993100E+00, 0.20356200E+00, -.47653200E-02, 0.51142200E-02, 0.31271800E-01, -.47695800E+00, -.18268300E-01, -.21072900E+00, -.72468100E+00, -.44205200E+00, 0.19310800E+00, -.29361800E+00, 0.15580700E+00, 0.21173000E-01, 0.53987300E-01, -.19791700E-02, -.22622000E+00, -.37545900E+00, -.65148400E+00, 0.22542700E+00, -.15300200E+00, 0.22989600E+00, -.29297200E+00, 0.10783500E+00, 0.24888400E-02, 0.25243200E+00, -.80940400E-01, -.62024100E+00, 0.20551300E+00, -.53890000E-01, -.52754600E+00, 0.20753800E+00, 0.98933300E-01, -.30923800E-01, -.35378400E+00, 0.54962800E-01, 0.13150800E+00, 0.67807300E+00, 0.11483600E+00, -.14940000E+01, -.14266100E+00, 0.57416400E+00, -.53903800E-01, -.16561700E+00, 0.76341800E-01, 0.17164000E+01, 0.10712200E-01, 0.35162600E-01, 0.61683500E+00, 0.34373200E+00, -.13412200E+00, 0.35606800E-01, 0.70318500E-01, 0.13021100E+00, 0.14894700E+00, 0.17774600E+00, 0.92698200E-01, 0.13529500E-01, -.21980500E-01, 0.53114100E-01, 0.31080900E-01, -.41758300E+00, -.55381200E+00, 0.11668400E+01, 0.81190500E-01, -.36185000E+00, 0.95045800E-01, -.84908000E-01, -.14433800E+00, -.40080500E+00, 0.73799800E+00, 0.45020500E-01, -.47516600E+00, 0.52362400E-01, 0.53014900E-01, 0.78608200E-01, -.50560000E+00, -.70335000E-01, -.10628600E+00, -.25080800E-02, 0.21755200E+00, -.76767500E-01, -.17752400E+00, 0.83466200E-01, -.10246600E+00, 0.17564900E+00, -.56858200E+00, 0.29899600E+00, 0.19134600E-04, 0.87918600E-01, -.28343100E-02, -.27139700E+00, 0.23801500E+00, -.28734200E-01, -.13516100E+01, 0.19288600E+00, -.86693000E+00, -.80134400E-01, 0.26110900E-01, 0.24529900E-01, -.10276000E+00, -.21300600E-01, 0.20827200E-01, -.78754200E-01, -.15522500E+00, -.77933100E-01, -.67844000E-01, -.39520400E-02, -.11630700E+00, -.59614600E-01, 0.28206800E-01, 0.76225600E-01, -.25377800E-02, -.99387500E-01, 0.17605300E+00, -.22870000E-01, -.52948500E-02, 0.34473000E-01, -.80894900E-01, 0.14773600E+00, 0.61249600E-01, -.34296300E-01, 0.32005500E-01, 0.26268400E-01, 0.21430400E-01, 0.32190800E-01, -.14814100E+00, 0.73439100E-01, -.14303100E-01, 0.20277000E+00, -.71751400E+00, 0.10625600E+00, 0.18846100E+00, -.17560200E+00, -.13724800E+00, 0.10015200E+01, 0.33455600E-01, -.15231400E+00, 0.31066300E-01, -.28311200E+00, 0.18644100E-01, 0.88053500E-02, 0.18332600E+00, 0.84351500E-01, 0.11738600E+00, 0.61085300E-02, 0.34183400E+00, 0.15695000E+00, 0.21064400E-01, 0.34673900E+00, 0.14873000E+00, -.93400700E-01, -.98159700E-01, -.98073900E-01, 0.29528300E-01, 0.27422900E+00, -.19334500E-01, 0.15664700E+00, 0.90251100E-01, 0.28416600E-02, -.18837600E+01, -.48447900E+00, -.50391300E+00, -.44484600E-01, -.98049700E-02, -.29623400E-01, 0.48577500E-01, 0.77186300E-02, -.44022900E-01, -.23597100E-01, 0.15955900E+00, 0.11122500E+00, 0.27773600E-02, -.24890900E-01, -.92652400E-01, 0.11664400E+00, -.91904500E-01, 0.19726300E-01, -.10650700E-01, 0.39096900E-02, 0.42584800E-02, 0.46556600E-01, -.42273400E-01, 0.16901500E-01, -.31273700E+00, -.43062800E+00, -.29711300E+00, -.24194700E+00, -.58742000E-01, 0.16382500E-01, -.13347500E-01, 0.67947800E-01, 0.99319600E-01, 0.52352800E-01, 0.98361200E-01, 0.39726400E-02, 0.60168300E-01, 0.16446100E-01, 0.61042100E-01, -.15113400E+00, 0.13613500E-01, 0.23408900E+00, -.96993400E-01, -.54343700E+00, -.28437200E-01, -.13225400E-01, -.66669100E-01, 0.23192800E-01, -.18249600E+00, -.17789000E-01, 0.26136200E+00, -.39796200E-02, -.89384500E-02, -.29407400E-01, -.88788600E-01, -.51175800E-01, 0.15907600E+01, 0.11382000E+00, -.26932700E-01, -.39304300E+00, 0.73550000E-01, 0.57505100E-01, 0.63836800E-02, -.18256300E-01, -.26526500E+00, -.81044700E-02, -.25012000E+00, 0.46917800E-01, -.69141200E-01, 0.58540300E-01, 0.21143400E+00, -.75395500E+00, -.52703600E-01, 0.56481100E+00, 0.89061000E+00, -.11891100E+00, -.11267200E-02, -.40932400E+00, -.23461500E+00, 0.24171600E+00, -.16245400E+01, 0.28273900E+01, -.22448400E+00, -.38139100E-01, 0.28875900E+01, 0.32962900E+00, 0.41706600E+00, 0.46720200E-01, 0.24863900E+01, 0.48119100E-01, -.26250100E+00, 0.97176000E+00, -.29762700E+01, -.11144800E+01, -.84270600E-01, -.10431300E+00 },
        { -.13489300E+01, -.86579200E+00, -.77834400E-01, -.54101100E+00, -.10718300E+01, -.48083600E+00, -.88413400E+00, -.29965900E+00, -.45548400E+00, 0.85277200E+00, -.14613300E-01, -.49559600E-01, -.45062600E+00, 0.63397900E+00, -.27342300E+00, -.93230600E-01, 0.21856200E-01, 0.31870000E+00, -.72354700E-01, -.12669100E+00, -.83327000E-02, 0.30806500E-01, -.71326300E-01, -.11001400E+00, -.72091100E-01, 0.94267400E-02, -.46964300E-01, -.15357100E+00, -.13295300E+00, 0.44022300E-01, 0.95746700E-01, 0.12669200E+00, 0.24832500E+00, 0.24712700E+00, 0.20679900E+00, -.12919800E-01, 0.24627100E-01, 0.31075100E+00, -.16760400E+00, 0.14173400E+01, 0.36492000E-01, 0.11031600E+00, -.32041900E-01, -.55238600E-01, 0.89369700E-01, -.17908100E-01, -.21058600E-01, 0.42698800E-03, -.44563200E-02, -.12035600E-01, 0.18046400E+00, -.57437100E-01, 0.48446100E-01, 0.74075600E-01, 0.82927400E-01, -.18399400E+00, 0.61754700E-01, -.53879600E-01, -.34410400E-02, 0.11743000E+00, 0.28769700E+00, -.11968200E-01, -.15042700E-01, 0.32412900E-01, 0.72090600E-01, 0.18264400E-02, -.40792300E-01, 0.10517700E-01, -.21719400E-02, -.92151300E-02, 0.18620700E+00, -.27070900E-01, 0.86323200E-01, -.77884600E-02, -.50034000E-01, -.11836400E+00, 0.33843500E-01, -.11843200E+00, -.23771500E-01, -.31168800E-01, 0.10796700E-01, 0.23035000E-01, 0.28341600E+00, 0.12051400E-01, -.34010700E+00, -.17735100E-01, -.17223600E+00, 0.66197500E-01, -.31799800E+00, 0.18839500E+00, -.47186000E-01, 0.15904400E-02, -.71433100E-01, 0.57627900E-01, 0.13730300E+00, -.64816000E-02, 0.18639900E-01, 0.11659900E+00, 0.92044300E-01, -.11912100E-01, 0.15020400E-02, -.61121100E-01, 0.32340900E-01, 0.18426400E+00, -.11372000E-01, 0.34045500E-01, -.34509500E-01, -.24093000E-01, 0.18687100E-01, 0.12779000E-01, -.62184300E-01, 0.21030800E-01, -.98723600E-02, -.42044100E-02, -.58810100E-01, 0.20918700E-01, -.18730400E+00, -.17778400E-01, 0.27975200E-01, -.16200500E-01, -.12699400E+00, -.10522600E-01, 0.35322700E-01, 0.45561200E-01, -.72511800E-02, -.43064800E-01, -.13708700E-01, 0.20465000E+00, -.18452800E-01, 0.69595400E-01, -.22670000E+00, 0.31011500E+00, -.11097700E+00, -.43764000E-03, 0.17414600E-01, 0.11886100E-02, 0.42660500E+00, -.11417900E+00, 0.51599800E-01, -.26895100E+00, -.11126300E+00, -.34917600E-01, 0.37505400E-01, 0.60876400E-01, 0.49963500E-01, -.12526900E+00, -.11843100E-01, -.12959800E-01, 0.17867200E-01, -.53145800E-01, -.36831600E-01, -.44911000E-02, -.15657200E+00, -.36260700E-01, -.21105400E-01, 0.35423200E-01, 0.32127100E-01, -.55740100E-02, -.10047500E+00, 0.17861300E-01, 0.29086800E-02, 0.16994100E-01, -.62479000E-01, -.21950500E-01, 0.42842100E-01, 0.29030100E-01, -.13139300E-01, 0.39181600E-01, 0.28814000E-02, 0.18406500E-01, 0.13967300E-01, -.15039300E+00, 0.15506400E-01, 0.10390200E-01, -.19467400E-01, -.40037700E+00, 0.22020300E-01, 0.16045700E-01, -.48108400E-01, -.74873300E-02, 0.32146700E+00, 0.18672800E-01, 0.85826100E-02, -.21586000E-01, -.12846900E-01, 0.10441700E-01, -.46411900E-02, -.31682700E-01, -.50604500E-02, 0.12829800E-01, -.47228700E-03, 0.53916700E-01, -.99367000E-02, -.36161600E-01, 0.28575200E+00, 0.88248100E-01, -.11388600E+00, -.18995100E-01, -.24314200E-01, 0.51658200E-02, -.15357600E+00, -.54567000E-03, -.34384300E-01, 0.86556100E-02, 0.20605200E+00, -.58757600E+00, 0.32115600E-01, -.54949900E-01, 0.19894500E-01, -.98816200E-01, 0.26125000E-01, -.17030000E-01, 0.11737900E-02, -.29803000E-01, 0.16283700E-01, -.14374900E+00, 0.29734300E-02, 0.84712000E-02, -.36890500E-02, -.15662200E-01, 0.32119200E+00, -.72311500E-02, -.43891900E-02, -.19137700E-02, 0.31413300E-02, 0.38123200E-02, 0.91614700E-02, -.15813800E-01, -.73642800E-02, 0.16373300E-01, 0.23799900E-01, -.14281100E-01, 0.48914800E-03, -.70332500E-02, 0.84135200E-02, -.12608900E-02, 0.98731700E-01, 0.47269200E-01, -.60492500E-04, 0.19530900E-01, -.19853600E-01, -.55572700E-01, -.17561500E-01, 0.18659700E-01, -.10361100E-01, -.20895600E-02, 0.39645900E-01, -.15851100E-01, -.25962200E-01, -.24038000E-02, -.11063900E-02, -.11233800E-01, -.26805300E-02, -.30394400E-02, -.35617400E-02, -.30345900E-01, -.19912500E-02, -.23038700E-02, -.14637900E-02, 0.26785500E-02, -.42954500E-02, 0.80664000E-01, -.17876700E-01, -.13574100E-02, 0.47782900E-01, 0.23978500E-02, 0.68951000E-02, -.75068000E-03, 0.96099200E-01, 0.71650100E-01, -.61856800E-01, -.14884700E-01, 0.54854900E-02, -.99498600E-02, 0.32282100E-02, -.19125700E-01, 0.43404000E-02, -.11301600E-01, -.48803400E-01, -.21057300E+00, -.90437100E-02, 0.50656100E-01, 0.10999900E+00, 0.15391900E+00, 0.59677800E+00, 0.88210500E+00, -.12650100E+01, 0.15712600E+00, 0.41652500E-01, -.12975900E+01, -.20384300E+00, -.17299500E+00, 0.27106900E-01, -.11069300E+01, -.32655500E-01, 0.18608700E+00, -.48022200E+00, 0.13300900E+01, 0.56668100E+00, 0.39484300E-01, 0.49121900E-01 },
        { 0.17720500E+01, 0.73878800E+00, 0.77811500E-02, 0.15424800E+00, 0.82971200E+00, 0.46964400E+00, 0.12848600E+01, -.67347500E+00, 0.86156500E+00, -.14617800E+01, -.44717100E-02, 0.76171800E-01, 0.10759500E+00, -.80762200E+00, 0.82576700E+00, -.55265400E+00, 0.28748200E+00, 0.17329600E+00, -.45821900E+00, 0.28188900E+00, -.32793900E+00, 0.31181000E-01, 0.13104200E-01, 0.13658600E+00, -.31592100E+00, -.30371900E-01, 0.78727300E-01, 0.33586100E+00, 0.27138300E+00, 0.12233300E+00, -.15079100E+00, -.17042500E+00, -.17219000E+00, -.78820500E-01, -.88462700E-01, -.23057400E-02, 0.15788800E-01, -.11419500E+00, 0.42040400E+00, -.12411600E+01, -.28532400E-01, -.81467400E-01, -.96206900E-01, -.36064400E-01, -.41311100E-01, 0.10202500E-01, -.10413300E+00, 0.24533700E-02, -.39668300E-02, -.37982300E-01, -.23578200E+00, 0.35542800E-03, 0.17121000E+00, 0.13777100E+00, 0.12848800E+00, 0.84394800E-01, 0.15366600E+00, 0.15438300E-01, -.18492400E-02, 0.11046800E+00, -.10263900E+00, -.26840700E+00, -.99223600E-01, 0.16365600E+00, -.41059900E-01, -.16479200E-01, -.82025300E-01, 0.19800400E-01, -.14215400E-01, 0.43852800E-02, -.32081600E-01, 0.47157900E-01, 0.85214700E-01, 0.67885100E-01, 0.83462200E-01, -.18965100E-01, 0.31361000E-01, 0.12626700E+00, -.15128300E-01, 0.77007300E-01, 0.32412600E-02, 0.57838700E-01, -.12102800E+00, -.49584800E-01, -.22085600E-01, -.93972100E-01, 0.27304800E+00, -.71868100E-01, 0.15168900E+00, 0.71427500E-01, 0.48946200E+00, -.54804800E-02, 0.73615700E-01, 0.70531800E-01, -.29570400E-01, -.27319700E+00, 0.86798700E-01, 0.27172100E+00, -.17471800E-01, -.57550700E-01, -.33562000E-01, 0.12442100E+00, 0.10168100E+00, -.23365100E+00, 0.52988800E-01, -.11530300E+00, 0.52403900E-01, 0.58311200E-01, 0.16651900E+00, 0.51923300E-01, 0.80998400E-01, 0.11329400E-02, 0.73136100E-02, 0.60210600E-01, -.23863500E-01, -.17460700E+00, -.20838100E+00, 0.11973600E+00, 0.22586400E-01, 0.30851000E-01, 0.90654000E-01, 0.86667800E-03, -.64745700E-02, 0.42098200E-01, 0.10932400E-02, -.81702900E-01, 0.51415400E-01, -.12091000E-01, 0.46690000E-01, -.82622300E-02, 0.12490800E+00, 0.33281100E+00, 0.62648700E-01, 0.18439400E-02, 0.11434000E-01, -.26449200E-02, 0.72618500E-01, 0.41233500E-02, -.39380700E-01, -.11512200E-01, -.37402600E-01, -.12662900E+00, 0.69398400E-01, 0.45924200E-01, -.19891400E-02, 0.94422900E-02, -.59128300E-02, 0.88171100E-02, -.93324100E-02, -.10997500E+00, -.44849600E-01, -.43874300E-01, -.26682400E+00, -.48994300E-01, -.13523800E-01, 0.29263600E-01, -.28446100E+00, -.53251300E-03, -.63485100E-01, -.13592100E+00, 0.17417700E-01, 0.21361600E+00, 0.17747000E+00, 0.23499900E-01, -.12356900E+00, -.21327200E-01, -.12262300E+00, 0.25422700E-01, -.36138900E-02, 0.35801400E-01, 0.45656200E-02, 0.49410900E-01, -.13489500E-01, 0.10936300E-01, -.52409600E-01, 0.19023300E+00, -.24296500E-01, -.62858500E-03, 0.30456200E-01, 0.22469600E-01, 0.41776600E+00, -.68797800E-01, 0.52658500E-01, 0.13374600E-01, -.64031900E-01, -.16917500E-01, 0.35470500E-01, -.16859200E+00, 0.16423600E-01, -.26970700E-01, 0.13159400E-02, 0.66223500E-01, 0.14749800E-01, 0.79174600E-01, -.54122700E-01, -.36042500E-01, -.13636600E-01, -.57681300E-01, -.24359100E-01, -.25421300E-02, -.10096400E-01, 0.20504300E-01, -.15735000E-01, -.49105500E-01, -.97318300E-03, -.29894000E+00, 0.13781800E+00, 0.22133800E+00, -.63927900E-01, -.13201200E+00, -.46070800E-02, -.12016300E-01, 0.68992200E-02, 0.24603000E-01, -.36685100E-01, 0.69181900E-01, -.25507000E-02, 0.25195100E-01, -.77907200E-02, -.21834100E-02, -.18068400E+00, 0.24028700E-01, 0.15636000E-02, 0.32147700E-03, -.10237400E-01, 0.38125400E-03, 0.44394100E-02, -.39144300E-02, 0.57922200E-02, -.13393200E+00, 0.41580800E-02, 0.12613000E+00, 0.43755600E-01, 0.25052100E-02, -.14853900E-01, -.21622200E-01, -.13861000E+00, -.33873700E-02, -.25530900E-01, 0.24025300E-02, 0.11147600E-01, -.10283800E-01, 0.23518700E-01, -.13795300E-01, 0.17562000E-01, -.22449700E-02, -.21384500E-01, 0.99453400E-02, -.40426500E-01, 0.46811900E-02, -.58176100E-03, 0.14032700E-01, 0.66724300E-02, -.16834200E-01, 0.11199100E-01, 0.26597200E+00, -.35835200E-02, 0.79288600E-02, 0.19358800E-01, -.54006200E-01, -.49891100E-02, 0.69034800E+00, 0.35454600E-01, 0.96058500E-02, 0.45800200E-01, 0.10618500E-01, -.15349900E-01, -.26692100E-02, 0.28180200E-01, -.10891400E+00, 0.85486800E-01, -.74862100E-01, -.20590100E-01, 0.94152600E-01, -.14575400E-01, 0.11498700E-01, -.73209200E-01, 0.64706300E-01, 0.28139500E-01, 0.51606100E+00, 0.69362200E-02, -.14850900E+00, -.28834600E+00, -.15687900E+00, -.11779400E+00, -.34496500E+00, -.33933000E+01, 0.12192100E-01, 0.12610600E+00, -.34713300E+01, 0.11450300E+00, -.66621200E+00, -.71143400E-01, -.31690200E+01, -.87993200E-02, 0.90699100E-01, -.66033400E-01, 0.35376700E+01, 0.99973600E-01, -.81420800E-01, 0.10288000E+00 },
        { 0.12659000E+01, -.54361200E+00, -.30319800E-01, -.26858500E+00, 0.45503100E+00, 0.11641500E+00, 0.86814600E+00, -.24873300E+00, 0.58594900E+00, -.66429500E+00, 0.37979700E-02, 0.87017800E-01, -.13662200E+00, 0.26039400E+00, -.12379100E+00, -.27217000E+00, 0.44036600E+00, -.20593300E+00, -.39545100E-02, -.48795200E-01, -.89461000E-01, -.13496100E-01, 0.14315000E-01, 0.99380900E-01, 0.18716900E+00, -.30770800E-01, 0.31909500E-01, -.47857900E-01, 0.39011500E+00, -.54897500E-01, -.77732800E-01, 0.22976300E-01, -.27808100E+00, -.15642800E+00, 0.98842000E-02, 0.85073000E-01, 0.72067500E-01, -.24811800E+00, 0.30123800E+00, -.11371800E+01, -.50547800E-01, -.87969400E-01, -.17460600E+00, -.59098300E-01, -.10341500E+00, -.63801900E-02, -.19529400E-01, 0.15301000E-02, 0.11253100E-02, -.13379400E-01, -.43521900E+00, 0.11259900E+00, 0.11082900E+00, -.33985900E-01, 0.45130800E-01, 0.30191700E+00, 0.51957100E-01, 0.90514300E-01, 0.11249700E-01, -.64932800E-02, -.11327700E+00, 0.93225900E-01, 0.65769000E-01, -.22775800E-01, 0.11643100E-01, -.32687100E-01, 0.94557300E-01, 0.55719100E-02, 0.55548100E-01, 0.42385200E-03, 0.92165500E-01, -.59638700E-02, -.36205700E+00, 0.83192300E-01, 0.12273800E+00, -.19479100E+00, 0.12112200E+00, 0.19368200E+00, 0.21552800E-02, 0.29573800E-01, 0.13176600E-01, -.23054200E-01, -.29613000E-01, 0.89549800E-03, -.27286700E+00, -.19634900E+00, 0.27909500E+00, 0.16020000E-01, 0.21859200E+00, 0.30283800E-01, 0.39951700E+00, -.63979700E-02, 0.37590800E-03, 0.87967100E-01, -.70985000E-01, -.20177900E+00, 0.61584200E-01, -.36742800E-01, -.77871200E-01, 0.29640900E-01, 0.75559400E-01, -.13137800E+00, 0.29630400E-01, -.42427400E-01, 0.65676400E-01, -.15175200E+00, -.13639000E+00, -.13060800E+00, 0.12308400E+00, -.17391000E-01, 0.16759600E-02, 0.17409900E-01, -.12464700E-01, 0.27982500E-01, -.15220100E-01, -.48230800E-02, 0.11767100E+00, 0.83375100E-02, 0.12750000E-01, -.50067800E-01, 0.17472000E+00, -.16516300E+00, -.11969400E-01, -.47287300E-01, -.46045600E-02, -.20066500E-01, -.15567400E-01, 0.19951000E-01, -.18249800E+00, -.53105000E-01, 0.40001600E-01, 0.33012600E-01, 0.72320800E-03, 0.10695900E-02, 0.13838500E-01, 0.12180400E-03, -.18604900E+00, 0.10576800E+00, -.73125900E-01, 0.38140000E-01, 0.17462600E+00, 0.16270200E+00, -.23036800E+00, -.10402400E+00, 0.80445200E-02, 0.11013400E+00, -.29285400E-02, -.52945100E-01, -.80904800E-01, 0.76128600E-01, -.36877600E-01, -.10319800E+00, -.29623800E+00, -.13572000E-01, 0.55462800E-02, 0.28678200E-01, -.17601800E+00, 0.22153800E-02, -.42584700E-01, -.12109700E+00, 0.26498400E-01, 0.40103000E-01, 0.21211700E+00, -.38102300E-02, -.10502600E+00, 0.11974900E-01, -.12540400E+00, 0.10810800E+00, -.22532900E-02, -.15365700E-01, -.30814800E-01, 0.12099900E+00, -.21015400E-01, -.28029700E-01, 0.31281100E-01, 0.51362500E-01, 0.27835400E-01, 0.79080300E-01, -.38282700E-01, 0.94379700E-01, -.97485500E-02, -.12514300E+00, 0.20659700E+00, 0.12817200E+00, -.84444600E-01, 0.13789500E-01, -.23394600E-02, 0.83180600E-02, 0.98896700E-02, 0.99563200E-02, 0.91706000E-03, 0.48103000E-01, 0.39226100E-01, -.10575300E+00, -.63574000E-01, 0.28170900E-01, -.95723800E-01, -.28055800E-01, 0.75752600E-02, -.10687200E-01, 0.17258600E+00, -.25833400E-02, 0.31355600E-01, 0.29954100E-01, -.62224100E-01, -.15957700E+01, -.22081600E+00, 0.10000000E+00, -.13239000E-01, -.29555200E-01, -.37130500E-01, 0.59977000E-01, 0.14849200E-02, 0.59057800E-01, 0.75919200E-02, 0.14206100E+00, -.58879400E-02, 0.26461600E-01, -.88768200E-02, 0.61386300E-02, -.63848700E+00, 0.80132400E-02, 0.13881000E-01, -.53210500E-02, -.31349200E-01, 0.20199300E-01, 0.15950700E-01, -.29595100E-01, 0.13016600E-01, -.17999800E+00, -.19842800E+00, -.72625400E-01, -.16034500E+00, 0.26263800E-02, 0.11001700E-01, -.10220400E-02, 0.12627400E-01, -.48451000E-02, 0.15409500E-01, -.88150000E-02, -.96545000E-02, -.32074300E-01, -.46151700E-02, -.22455600E-01, 0.34335400E-01, -.86363900E-02, 0.31441200E-03, 0.11124800E-01, -.14259700E+00, -.31084900E-01, 0.17427900E-02, -.10083900E-01, 0.98943100E-02, 0.19873900E-01, -.22717400E-01, 0.57528000E-02, 0.49178600E-02, -.52644100E-02, 0.30089700E-02, 0.33554800E-01, 0.21063800E-01, -.72859300E+00, 0.39960300E-01, -.81369000E-02, -.34621000E-01, -.20835100E-01, -.37286100E-03, 0.56009400E-02, -.67276200E-01, 0.13919200E+00, -.54822300E-01, 0.14152800E-01, 0.11430900E-01, -.10412300E-01, 0.97685300E-02, -.69373200E-02, -.22165800E+00, -.62578000E-02, -.12340100E-01, -.10980900E+00, 0.43186800E-02, 0.17839300E+00, 0.24763800E+00, 0.24241900E-01, 0.35828300E-01, 0.19358600E-01, 0.31635900E-01, 0.16407800E+00, -.45430500E-01, 0.14915700E-02, -.14362800E+00, 0.10670800E+00, 0.59655300E-01, 0.34287000E-01, -.17940500E-01, -.20872800E-01, -.17648500E-01, -.73526100E-02, 0.40524300E-02, 0.64313300E-01, -.12091300E-01 },
        { 0.19283100E+01, -.51836400E+00, -.27184600E+00, 0.30408300E+00, 0.12266300E+00, 0.62398400E+00, 0.12399500E+01, 0.39861800E+00, 0.72077400E+00, -.15282500E+01, -.53959900E-01, 0.33024100E-01, 0.54010500E+00, -.39251600E+00, 0.13674400E+01, 0.11577300E+01, -.38436900E-01, 0.86469100E-01, -.39006200E+00, 0.47968700E+00, -.11859200E+00, -.53081100E-01, -.22022100E-01, -.47760900E-01, 0.55340000E+00, -.72122500E-02, -.15132100E-01, 0.32816400E+00, -.26409200E+00, -.22971200E+00, 0.84928800E-01, -.35394500E+00, 0.16358200E+00, -.92818900E-01, 0.87806900E-01, -.18568300E+00, 0.57808200E-02, 0.32425300E+00, -.10779900E+00, 0.37164800E+01, -.39602700E-02, -.90847000E-01, 0.23271600E+00, 0.10436100E+00, -.13965500E+00, 0.50465500E-01, -.98092500E-01, -.33341400E-02, 0.27568100E-01, -.36117800E-01, 0.47931500E+00, -.77928400E-02, 0.11527100E-01, 0.78402500E-02, 0.22509800E+00, -.27222500E+00, 0.28994600E+00, -.49413400E-01, -.38995200E-02, 0.21094200E+00, -.25950200E+00, -.39350800E+00, -.14206100E+00, -.19460400E+00, 0.31614300E-01, -.80184100E-01, -.42584000E+00, -.96256700E-01, -.93990300E-01, -.49408400E-02, -.26633100E+00, 0.16320100E+00, 0.31309100E+00, 0.43086400E-03, 0.28048100E-01, -.78731100E-01, 0.30574200E-01, -.21929900E+00, -.14795600E+00, 0.26204200E+00, -.17740200E-01, 0.15876100E-01, -.88001700E-01, -.13127600E+00, 0.20123700E-01, -.12982900E-01, 0.52491000E+00, -.22122200E+00, -.17150500E+00, 0.11740500E+00, -.11998100E-01, -.28025000E-01, 0.42297600E-01, -.80564600E-01, 0.41614100E-01, -.32081200E+00, 0.10211100E+00, 0.40245900E+00, 0.40671100E-01, -.41168300E-01, -.18089000E+00, 0.27174700E+00, 0.27087900E+00, -.25790500E+00, 0.78367300E-01, 0.20053800E+00, 0.26780300E+00, 0.41333500E+00, 0.23747100E+00, 0.13242200E+00, -.50472000E-01, -.21859200E-01, -.21280800E-01, -.72138100E-01, 0.58326100E-01, -.13116700E+00, -.54848400E+00, -.60691700E-01, 0.56764000E-01, 0.71889200E-01, 0.16453100E+00, 0.26157800E-01, -.67857800E-01, -.11598900E+00, 0.22271000E-02, -.85972900E-01, 0.76878200E-01, -.77260200E-01, -.11367300E+00, 0.81906400E-02, 0.30098900E-01, -.24426500E+00, -.13305900E+00, -.19432100E-02, -.51520300E-01, 0.10219600E-02, 0.56994300E+00, -.14838200E+00, 0.15933700E+00, 0.12490400E+00, -.55234900E-01, -.18451300E+00, -.10482500E+00, -.60020900E-01, -.44246700E-01, 0.15476200E+00, 0.70042100E-02, 0.19756900E-01, -.84771000E-01, 0.22455600E-01, 0.72378800E-02, 0.34217100E-01, 0.43734000E+00, -.33401400E-01, 0.54663100E-02, -.26210800E-01, 0.37064200E-01, -.28717900E-02, 0.79148900E-01, 0.14871100E+00, -.18772000E-01, 0.16794300E+00, 0.59746800E-02, 0.56722400E-01, -.11446700E+00, -.32861900E-01, -.20475700E-01, -.17131200E+00, 0.33724600E-01, 0.19018800E-01, -.51390300E-01, 0.12968500E+00, -.97289400E-02, 0.32461300E-01, -.38086200E+00, -.27973700E+00, -.31780900E-01, 0.26471100E-01, 0.21999100E-01, -.21300400E+00, -.25325100E+00, 0.18651300E+00, -.27044200E+00, 0.42229900E-01, -.13297000E+00, 0.14950700E-01, 0.62244100E-01, -.12773400E+00, 0.15629600E-01, 0.79713500E-01, 0.88056100E-02, 0.28068500E-01, 0.75535600E-01, -.72905800E-01, -.98594700E-01, -.94042800E-01, -.69627000E-01, 0.56592100E-02, 0.88292300E-01, 0.17032600E-01, -.10409800E+00, 0.29759900E-01, -.10621400E+00, -.10394600E+00, -.30513500E-01, 0.42233600E+00, 0.46875600E+00, -.23627800E-01, -.18485600E-01, -.70214200E-01, -.31001700E-02, -.11094300E+00, 0.26681300E-02, -.44529700E-01, 0.25013300E-02, -.14783900E+00, -.24782800E-01, 0.14825200E-01, 0.23947000E-01, -.10383700E-01, 0.21269200E+00, 0.24444500E-01, 0.61164200E-02, -.18191500E-02, -.34339700E-02, -.78455100E-02, 0.91152600E-02, 0.14541200E-01, -.98942900E-02, -.86836400E-01, -.95806000E-02, 0.23104000E+00, 0.89272500E-01, 0.51730100E-01, -.16311400E-01, -.26851600E-01, -.29060400E+00, -.46693800E-01, 0.20342900E-01, -.21240300E-01, 0.38679200E-01, 0.77584100E-01, 0.43368600E-01, -.13567900E-01, -.34790700E-01, -.33253400E-02, -.13466700E-01, 0.28719500E-03, 0.53753900E-01, 0.26958500E-01, -.20121600E-02, 0.95990000E-02, -.67851300E-02, -.31703600E-01, 0.24637500E-01, -.49127900E-01, -.80709400E-02, 0.74741700E-02, -.87999200E-02, -.69201800E-01, 0.34868500E-02, 0.46337200E+00, 0.10161700E+00, 0.69143200E-02, -.21103800E+00, 0.10090100E-01, -.19113200E-01, 0.20255300E-02, -.21910200E+00, -.45595300E-01, -.80912300E-02, 0.10051700E+00, -.22649800E-01, -.65350300E-01, -.22467400E-01, 0.35793700E-01, -.11030900E-01, 0.51550400E-01, 0.15083300E+00, 0.56961500E+00, 0.81488900E-02, -.12582100E+00, -.69132500E+00, -.45915800E+00, -.26812300E+00, -.64671300E+00, 0.39528200E+00, -.19351800E+01, -.32764400E+00, 0.14692600E-01, 0.39618200E+00, -.17248500E+00, 0.10530200E+00, 0.39180800E-01, -.14417500E-01, -.31583100E+00, -.42120900E-01, -.16525200E-01, 0.26827800E-01, 0.81647000E-01, -.11740400E-01 },
        { -.22611100E+01, -.17861100E+01, -.12807400E+00, -.12956900E+01, -.16695200E+01, 0.14119000E+01, -.28141200E+01, 0.33509600E+01, -.16078300E+01, 0.18002100E+01, 0.34671500E-01, -.14729200E+00, 0.14644300E+01, 0.15862200E+01, 0.23459700E+01, 0.17109100E+01, -.10745500E+01, 0.99506900E+00, -.17632700E+01, 0.96089100E+00, -.25220000E+00, 0.85512700E-01, -.82717300E-01, 0.44386000E+00, -.31223600E+01, -.13113500E+00, -.79530200E+00, 0.25476500E+00, 0.54811800E+00, 0.68881000E+00, -.27671000E+00, 0.14683000E-01, -.18038900E+00, 0.35530900E+00, 0.31984200E+00, 0.14446700E+00, 0.17023000E+00, 0.11437900E+00, 0.12296900E+00, 0.11857600E+01, -.13306100E+00, -.20889900E+00, -.67228900E+00, -.23822000E+00, 0.10302300E+00, 0.15751400E+00, -.15552100E+00, -.69622400E-01, 0.11288200E+00, -.21028400E+00, -.10539600E+00, 0.16799000E+00, 0.11205300E+00, 0.79881700E+00, 0.49803300E-01, -.33845300E+00, 0.30318700E+00, -.84061100E-01, -.20285700E+00, 0.67574600E-01, -.48028000E+00, -.11808400E+01, -.62542100E+00, 0.65100100E+00, -.10991900E+00, -.46973400E-01, -.52345800E+00, 0.13060300E+00, -.15610600E+00, 0.38355500E-01, 0.21635600E-01, 0.38030100E+00, -.71818000E+00, 0.35457300E+00, 0.36630900E+00, -.80975400E+00, 0.10566200E+00, 0.44465100E-01, -.56692600E-01, 0.21795400E+00, 0.19778500E+00, -.15429100E+00, 0.14483000E-01, -.29531100E+00, -.13230400E+00, -.33667500E+00, -.56656900E+00, -.16062200E+01, -.20875100E+01, 0.17247900E+01, -.63208500E+00, -.57974200E-02, -.14445600E-01, 0.38697200E-02, 0.89210200E-01, 0.20926600E+00, 0.39409800E-01, -.49890200E-01, 0.32939400E+00, 0.22551600E-01, 0.11480900E+00, 0.36611900E-01, -.96038900E-01, -.21077100E+00, 0.13631900E+00, -.84259300E-02, -.42146300E+00, -.48803400E-01, 0.67390900E+00, 0.10225100E-01, -.12586400E-01, 0.12948400E+00, -.87853800E-01, -.13710000E+00, 0.84787500E-01, 0.69436100E+00, -.16374100E+00, 0.11780200E+00, -.10026000E+00, -.22472700E-02, -.21896100E+00, -.19530200E+00, 0.10751500E+00, -.18386600E+00, -.13072000E-01, 0.61543000E-01, -.18795500E-01, -.16601900E+00, 0.16045500E+00, -.14959100E+00, -.22715800E+00, -.50055600E+00, 0.54004500E+00, -.25577200E-02, 0.82657100E-02, -.74442100E-02, -.22083100E+00, -.33395800E+00, 0.14101700E+00, 0.88321500E+00, -.19492700E+00, 0.37156800E+00, 0.27340100E+00, 0.21901100E-01, -.34610100E-01, 0.12576900E-01, -.57738500E-01, -.14434400E-01, -.16615300E+00, -.14570400E+00, -.80523700E-01, 0.86102800E-01, -.73175100E-03, 0.11643100E+00, 0.64628700E-01, -.90303200E-01, 0.55486900E+00, 0.10525700E-01, 0.37282900E+00, -.18742600E+00, -.72959400E-01, -.18637300E+00, -.59439400E+00, 0.71806200E-01, 0.12769300E+00, 0.18285700E-01, 0.67876600E-01, -.60216700E+00, 0.62130500E-01, -.24232600E-01, 0.83071000E-01, 0.93957300E-02, -.69794400E-02, -.35991200E-02, 0.24032700E+00, -.23300700E+00, 0.20796900E-01, -.79207200E-01, -.55052200E-01, 0.56259000E+00, 0.22957300E+01, -.12178600E+00, 0.31162500E+00, -.14756800E+00, 0.84279200E-01, -.11147200E+00, -.21145300E-01, -.26705600E+00, -.38888000E-01, -.73940700E-01, 0.24503400E-01, -.16305400E+00, 0.48978200E-02, -.17361900E+00, 0.35083600E+00, 0.10532800E+00, 0.29876100E+00, 0.40257600E-01, -.13757000E+00, 0.58657400E-01, 0.40657400E+00, 0.16017100E-01, -.96269000E-03, 0.59177500E-01, 0.27256300E-01, -.14815800E+01, -.37839400E+00, -.24201100E+00, -.26975900E-01, -.16083200E+00, 0.11132400E-01, 0.18208400E-01, 0.16572500E-01, 0.33344600E-01, 0.69389300E-01, -.12122700E+00, -.36045900E-01, 0.16472400E-01, 0.36305600E-01, 0.33180100E-01, -.44738000E+00, 0.63499900E-01, 0.22247600E-01, -.15143000E-01, -.47326900E-01, 0.60350800E-02, 0.62509800E-02, -.24340300E-01, 0.18830700E-01, 0.22936700E+00, 0.21563700E+00, 0.19558300E+00, 0.63373900E-01, -.16158500E-02, -.38220300E-01, 0.21657000E-02, -.78042800E+00, -.48916000E+00, -.10057900E-01, -.31268500E-01, 0.10834300E+00, 0.67520400E+00, -.14041800E-01, -.21065100E-01, 0.18478800E-01, -.11659900E-01, -.28692500E-01, 0.14980900E-01, 0.17561700E-01, -.18952300E-01, -.75514700E-02, -.11438300E-01, 0.17671000E-02, 0.48093200E-01, -.14242200E-01, -.95204000E-01, -.11583800E-01, -.25047500E-01, 0.30209300E-01, 0.97524100E-01, 0.15012600E-01, -.63114500E+00, 0.12029000E+00, 0.28282700E-02, -.12822100E+00, -.53035700E-01, 0.70547500E-02, 0.88151500E-02, -.53789200E-01, 0.67658500E-01, -.10676200E-01, 0.88793600E-01, 0.19368400E-01, -.36775700E-01, 0.12529800E-01, -.95044800E-02, 0.15772500E+00, 0.17768600E-01, -.73356300E-01, -.74608900E-01, 0.26243900E-02, 0.63569300E-01, 0.11850200E+00, 0.75122900E-01, 0.47313200E-01, 0.94131900E-01, 0.40656500E-01, -.60570000E-01, -.38928700E-01, -.37076600E+00, -.66738900E-01, -.19370100E-02, 0.41293800E-01, -.39043200E+00, 0.21496300E-01, -.18093000E+00, -.10083400E-01, -.22591700E+00, 0.87657700E-02, 0.85559500E-01, 0.17982500E-01 },
        { 0.37493200E+01, -.12120000E+01, -.18743600E+00, -.32235300E+00, 0.12920000E+01, 0.31729000E+00, 0.33768400E+01, -.27530700E+00, 0.21094100E+01, -.27876800E+01, 0.23257100E-02, 0.34601900E+00, 0.54405900E+00, -.27086500E+00, 0.12702500E+01, 0.45684300E-01, -.11275100E-01, 0.87988100E-02, -.40019300E+00, 0.91340200E+00, -.19621600E+00, -.10165700E+00, 0.23279400E-01, 0.10848900E+00, -.32899200E+00, -.17616200E-01, -.35226600E-01, 0.19987800E+00, 0.38746100E+00, -.16505700E+00, 0.83413300E-01, -.17794400E+00, -.38320400E+00, -.76089400E-01, -.45210900E-01, 0.82524700E-01, 0.83582400E-02, 0.29061200E-01, 0.11974100E+00, 0.10569800E+01, -.30370000E-01, -.91347700E-01, -.11150200E+00, -.10464900E+00, -.19484600E+00, -.11973400E+00, -.16656500E+00, 0.11590200E-02, 0.49597100E-01, -.57993900E-01, 0.83060000E+00, 0.43237900E-01, -.33979500E-01, 0.76581800E-01, -.23824800E-01, 0.12272500E+00, 0.15162100E+00, -.60828700E-02, -.15178900E-01, 0.42856200E+00, -.25874700E+00, -.77235500E+00, -.40035800E+00, 0.22245600E+00, -.19077200E+00, -.63032400E-01, -.59386300E+00, -.90637000E-01, -.61464600E-01, 0.15463600E-01, 0.50569400E-01, -.68450300E-01, 0.10092100E+01, -.49467000E-03, 0.21942300E+00, -.11034100E-01, 0.43675200E-01, -.11672300E+00, -.12787800E+00, 0.31118900E+00, -.40741900E-02, 0.48578200E-01, -.27934000E+00, -.18739400E+00, 0.26268500E+00, -.14177000E+00, 0.30575900E+00, -.11634800E+00, 0.25245500E+00, 0.28882000E+00, 0.21524600E+00, -.12246800E-01, 0.10589300E-01, -.13773100E+00, 0.94063200E-01, -.42412200E+00, 0.15207800E-01, 0.62129700E+00, -.11118500E+00, -.22706400E+00, -.28759300E+00, 0.35420900E+00, 0.43431900E+00, -.57221500E+00, 0.25202900E+00, -.12474500E+00, 0.31790500E+00, 0.71168500E+00, 0.97438800E-01, 0.17622100E+00, -.10919100E+00, 0.36774200E-01, -.31751200E-03, 0.11083500E+00, 0.17915100E+00, -.61920700E+00, -.20525500E+00, 0.38726800E+00, 0.21831000E-01, -.25089200E+00, 0.28231900E+00, 0.19131800E+00, 0.51685400E-01, -.10388800E+00, 0.79702800E-02, -.22715300E+00, 0.30326100E-01, -.12520500E+00, -.32774000E+00, -.79287700E-01, 0.10782200E+00, 0.54768000E+00, -.53922900E-01, 0.39453500E-02, -.36291700E-01, -.23721600E-02, 0.71839400E-01, -.70503600E-01, -.28725300E-01, 0.95469900E+00, -.56722900E-01, -.53926500E+00, -.60224500E-01, 0.16277500E+00, -.39088000E-01, -.31427200E-01, -.10692800E-01, 0.98621000E-01, 0.98813600E-01, -.28958500E+00, -.10965300E+00, 0.56943500E-02, -.32504300E+00, -.57964200E-01, -.48459700E-01, -.63139400E-01, -.83427700E+00, -.10150500E-01, -.69296000E-01, -.53359100E+00, 0.47627200E-01, 0.33358400E+00, 0.31564800E-01, 0.40445400E-01, -.73416300E-02, -.44441100E-01, -.44888500E-01, 0.22895700E+00, -.72643200E-01, 0.10022900E+00, -.28656700E-01, -.21121700E+00, -.74465600E-01, 0.66713200E-01, 0.20399200E+00, 0.45523900E-01, -.10601500E+00, -.23148100E+00, 0.30222800E-01, 0.17188700E+00, 0.19091900E+00, 0.76099500E-01, 0.27393200E+00, -.72310000E-01, -.30878000E+00, -.57441800E-01, 0.67091600E-01, -.41346100E+00, 0.50576900E-01, 0.52110700E-01, 0.12243600E-01, -.62124800E-01, 0.49789300E-01, 0.50817000E-01, -.42440200E+00, -.31007600E+00, -.74980500E-01, -.10217200E+00, -.32598000E-01, 0.14100000E-01, -.17264000E+00, 0.11976700E-01, -.10796900E+00, -.11188600E+00, 0.76202300E-01, 0.52187200E+00, 0.17767600E+00, 0.57202100E-01, -.47415500E-01, -.19889600E+00, 0.49161700E-01, -.12396500E+00, -.39724100E-02, 0.29234300E-01, -.29803800E-01, -.22503300E+00, 0.63544000E-01, 0.66941800E-03, 0.55839200E-01, -.20035600E-01, 0.15071100E+00, -.53102400E-01, 0.33062700E-01, -.71242100E-02, 0.43087200E-02, 0.14562200E-02, 0.36467800E-01, 0.61114500E-01, 0.13229900E-01, 0.19426100E+00, -.10485600E+00, -.59999300E-01, -.52723600E-01, -.10038500E-01, -.23574700E-01, -.57888600E-02, -.21497400E+00, 0.27864700E-01, -.26362000E-01, 0.21258400E-01, 0.10123000E+00, 0.27084000E+00, 0.36550900E-01, 0.29765100E-01, -.72177800E-01, 0.13099000E-01, 0.13590800E-01, -.86103800E-02, 0.38061800E+00, -.52009300E-01, 0.11010300E-01, -.10147700E-01, 0.23515300E-01, -.44056000E-01, -.30981800E-01, -.57406600E+00, -.18182900E-01, -.32332000E-01, 0.63097700E-02, -.17708700E+00, -.41307200E-01, 0.18759300E+01, 0.10594200E+00, 0.28958300E-01, -.32377800E+00, 0.32620700E-01, 0.18949300E-02, 0.83561400E-02, -.25214600E+00, -.19793000E+00, -.20811600E-01, 0.16403200E+00, -.35865900E-02, -.78401700E-01, 0.47021800E-02, 0.14637100E+00, 0.23888900E-01, 0.83735400E-01, 0.26433500E+00, 0.85235400E+00, 0.11361300E-01, -.17182800E+00, -.51630600E+00, -.53833900E+00, -.70650200E+00, -.11186700E+01, 0.31269200E+00, -.20322300E+01, 0.14233200E+01, 0.11313000E+00, -.85173200E+00, 0.39807400E+00, 0.44663200E-01, -.27112200E-01, -.38631600E-01, -.78944900E+00, -.33133000E-01, 0.28621300E-01, -.22989000E-02, 0.22882000E+00, -.40045400E-02 },
        { -.27904700E+01, -.73144800E+00, 0.10072800E-01, -.54304800E+00, -.90141700E+00, -.21250400E+00, -.26631400E+01, 0.18571100E+00, -.14565400E+01, 0.23840300E+01, 0.63977200E-01, -.16293700E+00, -.60739600E+00, 0.16443400E+01, -.15192100E+01, -.48583100E+00, -.64437200E-02, 0.13756700E+00, 0.26849100E+00, -.77141600E+00, 0.30094600E+00, 0.76813700E-01, -.51114800E-01, -.63990100E-01, -.17151000E+00, 0.20984600E-01, -.11640200E+00, -.31623700E+00, -.17454100E+00, 0.18637600E+00, -.83098900E-01, 0.19699500E+00, 0.12903700E+00, -.29967900E-01, 0.43267500E-01, -.24727600E-01, 0.11194700E-01, -.24301500E+00, -.15433400E+00, -.15377800E+01, -.11344700E-01, 0.37400200E-01, 0.10710600E+00, -.65116300E-02, 0.84383100E-01, 0.26380100E-01, 0.14975800E+00, 0.14625700E-02, -.25473000E-01, -.27113300E-01, -.56585000E+00, -.79095500E-02, 0.41271900E-01, 0.86041900E-01, -.11490500E+00, -.83080100E-01, -.10471000E+00, -.13450200E-01, 0.32548600E-02, -.22975800E+00, 0.35802300E+00, 0.97749900E-01, -.66367100E-01, -.16175400E-01, -.59794300E-01, 0.41933400E-01, 0.38482200E+00, 0.75800400E-01, 0.27275600E-01, 0.26688000E-02, 0.11097400E+00, 0.36603600E-01, -.35667900E+00, -.92988700E-02, -.17910600E+00, 0.81872500E-01, -.36397500E-01, 0.48764700E-01, 0.74400900E-01, -.12056100E+00, 0.77176100E-02, -.10700900E-01, -.10861300E-03, 0.14583000E+00, -.12085100E+00, 0.60831300E-02, -.21383800E+00, 0.20022100E+00, 0.45602700E+00, -.22453100E+00, -.27745800E+00, 0.14311500E-01, -.89265700E-01, 0.93598400E-01, 0.25058200E-01, 0.17790000E+00, -.35004100E-01, -.37189600E+00, 0.20706200E-01, 0.10014000E+00, 0.99680400E-01, -.24338100E+00, -.16329600E+00, 0.26004200E+00, -.15562600E-01, 0.22143900E-02, -.18973600E+00, -.15363600E+00, -.14149900E+00, -.82179000E-01, -.11714700E+00, 0.22552000E-02, -.10523900E-01, -.39335200E-01, -.13496400E+00, 0.22124800E+00, 0.51008200E+00, -.23932200E+00, -.38284900E-01, 0.11478100E-01, -.61015000E-01, -.11200800E+00, 0.13994800E-01, -.39357200E-02, -.48199600E-02, 0.10167300E+00, -.54288500E-01, 0.11851100E+00, -.38331000E-01, -.80596300E-02, -.27679900E-02, -.50302900E-01, -.70321300E-01, -.36803300E-04, 0.86948700E-02, 0.23468100E-02, -.20283000E+00, 0.94829400E-01, -.46160300E-01, -.46180300E+00, 0.14277100E+00, 0.16053000E+00, -.21088200E+00, -.54632800E-01, 0.14433400E-01, -.86628700E-01, 0.84043500E-02, -.17941900E-01, 0.73005700E-01, 0.47307200E-01, 0.45502800E-01, -.34229100E-01, 0.15558000E+00, 0.54945000E-01, 0.16061000E-01, -.21647600E-01, 0.51255000E+00, 0.20873200E-02, 0.64248000E-01, 0.15114400E+00, 0.12340300E-02, -.18217900E+00, -.62531600E-01, -.26177400E-01, 0.82690300E-01, 0.52332800E-01, 0.12917500E+00, -.64013200E-01, -.17982000E-01, -.34778200E-01, 0.25190000E-01, -.95253100E-01, 0.22434800E-01, -.38270000E-01, 0.18060100E+00, 0.13444100E+00, 0.46831900E-01, 0.36618800E-01, -.35298700E-01, 0.17268800E-01, -.40624000E+00, -.40541800E-01, 0.11687500E+00, 0.39628400E-01, 0.15218300E+00, -.34821000E-02, -.45343700E-01, 0.28063400E+00, -.40608500E-01, 0.13730800E-01, -.41669500E-02, -.13041400E+00, -.25612400E-01, -.15961300E+00, 0.32128000E+00, 0.18509500E+00, -.12419600E+00, 0.68436300E-01, 0.20890900E-01, -.15985300E-01, 0.16939000E+00, -.30394200E-01, 0.25028700E-01, 0.11697000E+00, -.29473100E-01, -.52501500E+00, -.48648400E+00, -.17871000E+00, 0.70364300E-01, 0.18238900E+00, -.53798300E-01, 0.77945400E-01, -.50132800E-02, -.80261600E-04, 0.63718400E-02, 0.58353500E-01, 0.53126000E-02, -.34116800E-01, 0.15600100E-01, 0.13339500E-01, 0.25788000E-01, -.42230400E-01, -.29021000E-01, 0.10075300E-01, 0.11179100E-01, 0.43394000E-02, 0.11756100E-02, -.25148700E-01, -.19370600E-02, -.35538300E-01, -.12829100E-01, -.86588300E-01, -.87353000E-01, -.29222100E-01, 0.26166700E-01, 0.25225700E-01, 0.19704800E+00, -.48542500E-01, 0.18564500E-01, -.94149400E-02, -.40980300E-01, -.59162600E-01, -.41155200E-01, 0.10595900E-01, 0.23304700E-01, 0.19225000E-02, 0.44657600E-02, -.56630600E-02, -.10852000E+00, -.37688700E-02, -.37031500E-02, -.12553600E-01, -.72852800E-02, 0.24082300E-01, -.30392100E-01, 0.15418900E+00, 0.17885100E-01, -.15769200E-02, -.25583600E-01, 0.75896500E-01, 0.17930700E-01, -.13703000E+01, -.63271100E-01, -.19656500E-01, 0.12407000E+00, -.30968900E-01, 0.22425500E-01, 0.28425800E-02, 0.11235800E+00, 0.54629900E-01, 0.33934400E-01, -.62522200E-01, 0.28204200E-01, 0.35057000E-01, 0.22548400E-01, -.13624300E-01, -.28821400E+00, -.50475400E-01, -.12002300E+00, -.51964500E+00, -.13170700E-01, 0.24806400E+00, 0.94890000E+00, 0.49636300E+00, 0.16867400E+00, 0.47884400E+00, -.51013900E+00, 0.15430900E+01, -.82023300E+00, -.29417300E-01, -.18874100E+00, 0.26371800E+00, 0.31509000E-01, -.89684300E-01, -.25039600E-01, -.16828800E+00, 0.25318400E-01, -.25350000E-01, -.25731500E-01, -.11126600E-02, 0.10568900E-01 },
        { 0.75436200E+00, 0.49626900E+00, 0.11998600E+00, 0.39415600E+00, 0.67493300E+00, -.45845000E+00, 0.11054100E+01, 0.16607900E+00, 0.53277800E+00, -.74634100E+00, -.64983900E-01, 0.89285700E-01, -.30948000E-01, -.17815200E+00, -.95410500E-01, -.26586400E+00, -.90882300E-01, -.19315500E+00, 0.41960600E-02, 0.34604600E+00, -.23570400E-01, -.24944600E-01, 0.31987500E-01, 0.65226700E-01, -.66059200E+00, -.25843900E-01, -.97622900E-01, -.20385200E+00, 0.31370200E+00, -.13980400E+00, 0.86787000E-01, 0.74683700E-01, -.14790100E+00, 0.13416400E+00, -.71451000E-01, 0.15824400E+00, 0.12747700E-01, 0.50893000E-01, 0.14962800E+00, 0.14145900E+00, -.11031500E-01, 0.23990500E-01, -.20262700E+00, -.49412000E-01, -.47357000E-03, -.37369200E-01, -.83355000E-01, -.41202700E-02, 0.19796100E-01, 0.74663800E-01, 0.55420700E+00, -.82546400E-01, -.13576700E+00, -.15521100E+00, -.20530900E+00, 0.16537300E+00, -.17147100E+00, 0.32947900E-01, -.18834400E-01, 0.45877600E-01, -.56935700E-01, 0.27817000E+00, 0.99333700E-01, 0.16475900E+00, -.62157000E-01, 0.15861900E-01, -.11909500E+00, 0.24577300E-01, 0.28964900E-01, 0.39625300E-02, 0.56353500E-01, -.15220700E+00, 0.26164600E+00, -.63749600E-01, 0.16324400E+00, 0.10097500E+00, 0.26466900E-01, -.47980800E-01, 0.15684400E-01, -.35204100E-01, -.12671900E-01, -.89833300E-01, 0.10923600E+00, -.56480100E-01, 0.32234400E+00, 0.56808200E-01, -.35514400E+00, -.19047500E+00, -.22923600E+00, 0.12177200E+00, 0.23675000E+00, 0.15233400E-02, -.11228400E-01, -.44826100E-01, -.17984300E+00, 0.20558000E+00, -.10168000E+00, -.13889500E+00, -.10973700E+00, -.34554400E-01, 0.30247000E-02, 0.36840100E-01, -.43470300E-01, -.99762700E-01, 0.46362800E-01, -.12807100E+00, 0.55115700E-01, 0.32773700E-01, -.13933400E+00, 0.61477300E-02, -.19633500E-01, 0.16785400E-01, 0.29591700E-01, 0.27252400E-01, 0.43409600E-01, -.48697700E-01, 0.27842500E-01, 0.19758500E+00, -.11386600E-01, -.73877300E-02, 0.12872200E-01, 0.32097200E+00, 0.29056000E-01, 0.14075400E+00, 0.59889800E-02, 0.38448800E-01, -.25028000E-01, -.22331300E+00, 0.18221000E-01, 0.21984300E-01, 0.25385300E+00, -.23516100E+00, 0.20335000E+00, 0.12083500E-02, -.14810300E-01, 0.20584100E-03, -.33020100E+00, 0.39926900E-02, -.97503500E-02, -.41361200E-01, -.18603100E+00, -.10600700E+00, 0.17211800E+00, 0.50313500E-01, -.47546700E-01, 0.94350900E-01, -.24707200E-02, 0.82544100E-01, 0.81977900E-01, -.73223400E-01, 0.66143200E-01, 0.13132500E+00, 0.26534700E+00, 0.76790400E-01, -.34480000E-01, -.56142000E-01, -.18682700E+00, -.68670000E-02, 0.12679700E+00, -.33682600E-01, -.71528300E-02, -.13821600E-01, -.14823400E+00, 0.29967600E-01, 0.11379800E+00, -.57034100E-01, 0.74948800E-01, -.36984700E-01, 0.78675800E-02, 0.92364500E-04, 0.40476700E-02, 0.12755800E+00, 0.60911400E-02, 0.46005100E-01, 0.85613500E-01, 0.24763700E+00, -.62397900E-01, -.14884400E+00, 0.39208500E-01, 0.19213200E+00, 0.73299600E+00, 0.30911400E-02, 0.80878800E-01, -.11575700E+00, -.62756600E-01, -.43047300E-01, 0.17021200E-01, -.15123800E+00, -.66035800E-02, 0.63230400E-01, 0.11873200E-01, -.57788500E-02, 0.35089500E-01, 0.11419100E+00, -.25989400E+00, -.12294200E+00, 0.62639500E-01, -.53875000E-01, -.57761000E-02, 0.17822200E-01, 0.56751100E-01, -.78339400E-02, 0.20791000E-01, 0.21178800E-01, -.22497300E-01, -.68606900E-01, -.13007800E+00, -.13608000E+00, 0.13255200E-01, 0.35088600E-01, 0.18973200E-01, 0.18624800E-01, -.11446100E-02, 0.13252300E-01, 0.33273300E-01, -.11384300E+00, 0.26051000E-01, -.53784400E-02, 0.26096700E-01, -.11907300E-01, 0.34496800E+00, -.33794400E-02, 0.12416600E-01, -.49192400E-02, -.53607100E-02, 0.10278800E-01, 0.90094700E-02, 0.59033500E-02, -.85237600E-03, 0.14418400E+00, -.78516200E-01, -.62940800E-01, -.65428700E-01, -.40490300E-01, 0.18253600E-02, 0.41179600E-02, 0.67257700E-01, 0.67192600E-01, -.24779900E-01, 0.29470400E-01, -.66090900E-02, -.31567500E-01, 0.44764400E-02, 0.12220000E-01, -.38141800E-03, 0.13233300E-02, 0.22603400E-01, 0.64591500E-02, 0.91084900E-01, -.12119600E-01, -.23471700E-02, -.16422700E-01, 0.30662700E-03, -.34377800E-01, -.18486900E-01, -.48637000E-01, -.27875900E-02, -.52203300E-02, -.94496400E-03, -.50685000E-01, -.13101200E-01, 0.50346800E+00, 0.27549500E-01, 0.27445000E-02, -.64720700E-01, 0.14205200E-01, 0.67749000E-02, -.13732400E-02, 0.29725700E-01, -.92449800E-01, -.14216000E-01, 0.43804900E-01, 0.17249600E-01, -.18020800E-02, 0.19894000E-01, 0.42091600E-01, 0.13738700E+00, 0.27375700E-01, 0.42315100E-01, 0.18663600E+00, 0.82691000E-02, -.55814900E-01, 0.11742400E+00, -.44232400E-01, -.26431100E+00, -.23365700E+00, 0.27803400E-01, -.18635000E-01, -.24534000E+00, -.12315300E-01, -.63855500E-01, -.10254500E+00, 0.64321200E-01, -.10531300E+00, -.26712500E-01, -.81260200E+00, -.18149000E-01, -.53195800E-01, -.22685400E-02, 0.81505200E-01, -.13621500E-01 },
        { 0.57004800E+01, -.29010700E+01, -.78768400E+00, 0.17239300E+01, 0.15937600E+01, -.82341000E+00, 0.45688300E+01, -.25587000E+01, 0.23947400E+01, -.37381800E+01, -.13217100E+00, 0.13815400E+00, 0.74012400E+00, 0.17522200E+01, 0.55852700E+00, 0.16363500E+01, 0.46950800E+00, 0.16148900E+00, -.45251700E+00, -.54734000E+00, 0.66880200E+00, -.18997700E+00, -.22579900E+00, -.54231900E+00, 0.43360900E+01, 0.14917100E-01, -.10729000E+00, 0.66322100E+00, -.11259500E+01, -.32130700E+00, 0.58612400E+00, -.42365400E+00, 0.78415600E+00, -.54908100E+00, 0.84813300E+00, -.75552600E+00, 0.23479700E+00, 0.78265800E+00, -.81255500E+00, 0.11953900E+02, -.24565300E-01, -.23810900E+00, 0.20073000E+01, 0.95717200E+00, -.57303300E+00, 0.28532700E+00, 0.89552600E+00, -.29564000E-01, -.88027000E-01, -.72321900E+00, 0.97909900E+00, 0.29392100E+00, -.18998900E+00, -.36683200E+00, -.10775300E+00, -.13243100E+01, 0.12739400E+00, -.99895600E-01, -.90734900E-01, 0.68497700E+00, -.12122600E+01, -.31717000E+01, -.16609000E+01, -.12178200E+00, -.15316900E+00, 0.91841000E-02, -.94482200E+00, -.21175600E+00, -.20213500E+00, -.57748100E-01, -.20370400E-01, 0.45951400E+00, 0.10244100E+00, 0.29016700E+00, 0.27250300E+00, -.11804400E+01, -.59156000E-01, -.29471100E+00, 0.30793400E+00, -.76416300E+00, -.64271800E-01, -.13954400E+00, -.21859500E-01, -.35774500E+00, -.12146500E+01, -.42817000E+00, -.29640000E+00, 0.40055500E+00, 0.21030900E+01, -.38745400E+00, 0.32610800E+00, -.83505800E-01, -.18672100E+00, -.13341700E+00, -.49905500E+00, 0.58685700E+00, -.15499400E+00, -.53299300E+00, -.32054200E+00, 0.15631800E+00, -.20346900E+00, -.16664500E+00, 0.13736200E+01, -.28277900E+00, 0.54335600E+00, 0.80971500E-01, -.53759200E+00, 0.17866700E+00, 0.16363700E+01, 0.82594000E-01, -.11018700E+01, -.13635300E+00, -.11096900E+00, -.70505000E+00, -.12314600E+01, 0.88434000E+00, 0.35223000E+01, -.24505100E+01, -.14741100E+00, 0.49560500E+00, 0.79288400E-01, -.25979000E+00, 0.60756400E-02, -.11769500E+00, -.75454000E-02, 0.26525100E+00, -.14459400E+00, 0.77882100E+00, -.10255700E+01, 0.33278600E+00, -.15482500E+00, 0.28961500E+00, -.17471000E+01, -.98059100E-02, -.54331200E-01, 0.18368100E-01, 0.26237700E+01, 0.25961400E+00, 0.59622200E-01, -.16671400E+01, 0.14021000E+01, -.18747400E+01, -.12841300E+01, -.23415300E+00, 0.70721900E-01, -.10753200E+01, -.63817300E-02, -.12669100E+00, 0.23978700E+00, -.48136000E+00, -.15173700E+00, -.36898300E+00, 0.16043700E+01, 0.38529000E+00, 0.11959400E-01, -.72309900E-01, 0.32726300E+01, 0.28810200E-01, 0.10884200E+01, 0.15503400E+00, -.48986300E-01, -.30505000E+00, -.98990300E+00, 0.15787700E+00, -.37557500E+00, 0.20215400E+00, 0.27241000E+00, -.78100400E+00, -.10008600E+00, -.27624300E+00, -.80031700E-01, 0.67447200E-01, -.32380800E+00, -.60471200E+00, 0.10951600E+00, -.50258100E+01, 0.53153000E+00, -.24850300E+00, -.21382200E+00, -.48686100E+00, -.99239900E+01, 0.31464800E+00, 0.84707800E+00, 0.31007000E+00, -.76547000E+00, 0.53892500E-01, 0.71981800E-02, 0.90114200E+00, -.15591000E+00, 0.71889500E+00, 0.20872000E-01, -.40490100E+00, 0.21069500E+00, -.90708500E+00, -.15151000E+01, -.38053000E+00, -.10530000E+01, 0.53305000E-01, 0.74765500E+00, -.56932100E-01, 0.19787300E+00, -.21864000E-01, 0.28993800E+00, 0.14969200E+00, -.38614500E+00, -.11462200E+02, -.18234500E+01, -.28033800E+01, 0.37241100E+00, -.41328500E+00, -.10518200E+00, 0.19219900E-01, -.22869800E-01, -.90058100E-01, 0.22188900E+00, -.10979600E+01, 0.13553700E+00, -.13412800E+00, 0.32303600E+00, -.69995800E-01, 0.24266200E+01, -.46108200E-01, -.47226500E-03, 0.11422300E-01, -.17867000E+00, 0.29300100E-01, 0.26264900E+00, -.23897600E+00, -.91224000E-01, -.34491700E+01, -.68347600E+00, 0.22793600E+01, -.25831100E+00, -.96877300E+00, 0.19749000E-01, -.26356300E+00, -.13809600E+01, 0.32552700E+00, -.26619100E+00, 0.56755800E+00, 0.50994400E+00, 0.18477100E+01, 0.68247600E-01, 0.12309900E-01, -.56675900E-01, -.10917300E-01, 0.17894700E+00, -.38515800E-01, -.47285200E+00, 0.12240100E+00, -.32374100E-01, -.63113700E-01, -.43961100E-01, -.89440100E-02, -.17106300E+00, -.15440400E+01, 0.61622900E-01, -.53560800E-01, -.13458000E+00, 0.41137400E+00, 0.93843500E-01, -.22385200E+01, 0.46461400E+00, -.71901300E-01, -.58926900E+00, -.15369100E+00, 0.60229400E-03, 0.49636300E-01, -.56143900E+00, -.23632000E+00, 0.89823200E-01, 0.27452000E+00, 0.30904300E+00, -.57505700E+00, 0.16959800E+00, 0.21100200E+00, -.46892700E+00, -.34325400E-01, 0.45016700E+00, 0.11584500E+01, 0.48956600E-01, 0.44804400E-01, -.97820800E-01, -.11357000E+01, -.60059700E+00, -.99576700E+00, -.95872700E+00, -.11883600E+00, 0.43149000E+00, -.14120300E+01, 0.92155400E+00, -.79447800E+00, 0.27732500E+01, -.34991900E+01, 0.15764000E+00, 0.13560500E+01, 0.53415500E-01, -.81739800E+00, -.18594900E-01, -.19314500E+00, 0.24250000E+00 },
        { 0.25502100E+01, 0.16960900E+00, -.39709100E-01, 0.13527800E+00, 0.10689500E+01, 0.14988100E+01, 0.12630500E+01, 0.17153300E+00, 0.11135000E+01, -.15853700E+01, -.12901400E-01, 0.14156900E+00, 0.64732000E+00, -.71939400E+00, 0.47759800E+00, -.25456900E+00, -.21386800E+00, -.10971000E+00, -.34022200E+00, -.71633100E-01, -.13941800E+00, -.43421700E-01, 0.13051400E-01, 0.14717600E+00, -.46302400E+00, -.35287700E-01, 0.76710500E-03, -.16215400E-01, 0.41243500E+00, -.10048400E+00, -.85706000E-01, -.14204500E+00, -.37297500E+00, -.70481600E-01, -.70806700E-02, 0.72700700E-01, 0.70555800E-01, -.51387300E-01, 0.10369200E-01, -.34109700E+00, -.16586700E-01, -.67262800E-01, -.14063600E+00, -.99827800E-01, -.38578100E-01, -.21636400E-01, -.13215100E+00, 0.26309100E-03, 0.25953000E-01, -.17313400E-01, -.53171400E-01, 0.40043000E-01, 0.64097500E-01, -.17804200E-01, -.33597900E-01, 0.16495400E+00, 0.11197700E+00, 0.37014800E-01, 0.10269000E-02, 0.17582500E+00, -.20225100E+00, -.11863700E+00, -.11894900E+00, 0.69474100E-01, 0.14625400E-01, -.51491500E-01, -.14529400E+00, 0.52433300E-02, 0.88358400E-02, 0.10761300E-02, -.67806700E-01, -.45414700E-01, 0.19757400E+00, 0.45471100E-03, 0.12243600E+00, 0.85525800E-01, 0.13281800E-01, 0.61497900E-01, -.16396600E-01, 0.86499300E-02, -.21691300E-01, 0.49663800E-02, -.10371400E+00, -.39578700E-01, 0.66128800E-01, -.26897700E-01, 0.24601000E+00, -.34340100E-01, 0.30653100E+00, -.11302300E+00, 0.43504400E+00, -.12130700E-01, 0.38679900E-01, 0.10914900E+00, -.10450900E+00, -.23307900E+00, 0.46010200E-01, 0.11303400E+00, -.15088300E+00, -.33310400E-01, -.95692500E-01, 0.93764800E-01, 0.12872900E+00, -.28543100E+00, 0.11260000E+00, -.90262400E-01, 0.10465000E+00, 0.25927500E+00, 0.24161700E+00, 0.67229700E-01, -.16595000E+00, 0.21337400E-01, -.20672500E-01, -.17460500E-01, -.13012600E-01, -.58309800E-01, 0.84682100E-02, -.61931600E-01, 0.89180600E-02, 0.30275500E-01, 0.23446500E+00, -.21624800E-01, -.42906300E-01, -.58944700E-01, 0.28604400E-02, 0.55002100E-01, -.30198200E-02, -.23373900E+00, -.68084800E-01, -.84723300E-01, 0.42492700E+00, -.75275200E-01, 0.16042900E+00, 0.40711400E-02, 0.22111100E-01, -.21498300E-02, -.36302600E+00, 0.16496800E+00, -.85330000E-01, -.39036300E+00, 0.18953400E+00, -.32553900E+00, -.12542200E+00, -.73458500E-02, -.21227500E-01, 0.19916800E-01, -.55868000E-02, 0.99097700E-02, 0.52630500E-02, -.18784400E+00, -.10387200E+00, -.10304500E+00, -.19742800E+00, -.11992300E-01, -.35579400E-01, -.56722600E-01, -.26461200E+00, -.46522400E-03, -.45790900E-01, -.15127300E+00, 0.37790300E-01, 0.33355300E+00, 0.28469300E+00, 0.20934000E-01, -.19985600E+00, 0.46406700E-01, -.96918400E-01, -.27566100E-01, -.19647100E-01, 0.33979300E-01, -.14523100E-01, -.76014200E-01, -.46266200E-01, 0.77662000E-01, -.18914700E+00, 0.40743700E+00, -.56921000E-01, 0.38031200E-02, 0.26345200E-01, 0.98528500E-01, 0.15654000E+00, -.10042100E+00, 0.98329000E-01, 0.43949000E-01, -.42189200E-01, -.27071000E-01, 0.59123200E-02, -.51601100E-01, 0.38376800E-01, 0.54488100E-01, 0.32389200E-02, -.10639400E-02, 0.42678500E-01, -.10252100E+00, -.24536400E+00, -.37893000E-01, -.17952900E+00, -.18026200E-01, 0.84970300E-01, 0.21180800E-01, 0.20619000E-01, 0.13888900E-01, 0.59396900E-02, -.36501900E-01, -.44017900E-01, -.13445800E+01, 0.16799700E+00, 0.15412400E+00, -.12357500E-01, -.10185800E+00, -.58405000E-01, 0.41747500E-01, 0.42156000E-02, 0.69922600E-01, 0.18524600E-01, 0.18108100E-02, 0.38712000E-02, 0.22246800E-01, 0.16059300E-02, 0.56859500E-02, -.62321700E+00, 0.46425000E-03, 0.80667700E-02, -.15905100E-02, -.18484300E-01, 0.36353100E-01, 0.10828600E-01, 0.11878000E-01, 0.98076600E-02, -.24836200E+00, -.35892400E-01, -.13153100E-01, -.91690700E-01, 0.31185300E-01, -.10725100E-01, -.55526800E-02, -.83892100E-01, -.74510100E-01, 0.18866200E-01, -.21142000E-03, 0.74271500E-01, 0.23234800E+00, 0.32174900E-02, 0.11320100E-01, -.43845700E-01, 0.70577000E-02, -.70407000E-03, -.14784900E-01, 0.78856800E-01, -.51335000E-02, 0.14967800E-02, 0.46683700E-02, 0.10692500E-01, -.62573300E-02, -.26518600E-01, 0.24338100E+00, 0.73898300E-03, -.12552300E-01, 0.22749800E-01, 0.10455700E+00, 0.22580400E-01, 0.82338900E-01, 0.57653200E-01, 0.15975800E-03, -.15273700E+00, 0.36398100E-02, -.10723300E-01, 0.78478100E-03, -.24598300E+00, -.70164800E-01, -.14448700E-01, 0.66320300E-01, 0.77983100E-02, -.11803700E+00, 0.27497000E-02, 0.33708700E-01, -.26073800E+00, 0.14302700E-01, 0.14915400E+00, 0.47764900E+00, -.49223500E-03, 0.53257700E+00, 0.13435200E+01, -.55920500E-01, 0.69259800E-01, 0.11672800E+00, -.85075400E-02, -.80808900E-01, -.62482200E-01, -.26342400E-01, -.12438900E-01, -.82923500E-01, 0.46454900E+00, -.60585500E-02, -.18840800E+00, 0.31070700E+00, 0.59641800E-02, 0.68778900E-02, -.39356300E-02, -.33803000E-01, 0.75277100E-02 },
        { -.29561000E+01, -.91802100E+00, -.40585400E-01, -.61605300E+00, -.12991300E+01, -.98281800E+00, -.26211200E+01, 0.24786700E+00, -.15714900E+01, 0.23778300E+01, -.23572600E-02, -.18670600E+00, -.88841700E+00, 0.17192400E+01, -.86254900E+00, -.18154900E+00, 0.47321100E+00, 0.40358100E+00, 0.34715500E+00, -.44593200E+00, 0.71991600E-01, 0.16470400E-01, -.18175600E+00, -.15373100E+00, 0.58211700E+00, 0.40701900E-01, -.15432200E-01, -.14192500E+00, -.27998700E+00, -.19657100E+00, 0.14335100E+00, -.22530700E+00, 0.29927700E+00, 0.27569400E+00, 0.23029800E+00, -.84274100E-02, -.35308600E-01, 0.23626300E+00, -.15443200E+00, 0.56427000E+00, 0.23033700E-01, -.37211700E-02, 0.15187800E+00, 0.65814200E-01, -.11203800E-01, 0.15547300E-01, 0.45649700E-01, -.10529700E-01, -.77302400E-02, 0.65915400E-01, 0.28628200E-01, 0.13195800E+00, -.75372800E-01, -.13734300E-02, 0.53601600E-01, -.66641100E-01, -.86678500E-01, 0.15290400E-01, -.87440400E-02, -.18051200E+00, 0.17968400E+00, 0.15675600E+00, 0.45227600E-01, 0.69517100E-02, 0.61528100E-03, 0.31701600E-01, 0.51420500E-01, 0.24828200E-01, 0.78185400E-02, -.67701800E-02, 0.29236400E+00, -.29663000E-01, -.33251700E+00, -.49851700E-01, -.15809000E+00, -.19395100E-01, -.87979000E-02, -.97019500E-01, 0.55377700E-01, -.17929400E+00, 0.12166300E-01, -.28211300E-01, 0.49937600E+00, 0.86824800E-01, -.48479300E+00, 0.21409900E-01, -.11553300E+00, 0.19034900E+00, -.96377900E+00, -.75676300E-03, -.19960600E+00, 0.16391200E-01, -.15108500E-01, 0.15054000E-01, -.22418200E+00, 0.46393300E+00, -.17695300E+00, -.47850800E+00, -.13331400E+00, 0.39455200E-01, 0.59051600E-01, -.20165700E+00, -.24203200E+00, 0.36543700E+00, -.16458900E+00, 0.78436700E-01, -.47911900E-01, -.23033200E+00, -.42030000E+00, -.11921600E+00, 0.97704300E-01, -.44480000E-01, 0.22030000E-01, -.31884500E-01, 0.29281300E-01, 0.33817600E+00, 0.11905800E+00, -.37196600E-01, -.37851700E-01, 0.76268300E-02, -.33416000E+00, 0.23250600E+00, 0.28364100E-01, 0.76452900E-01, 0.14439600E-03, 0.13269200E+00, -.54571500E-02, -.39392500E-01, 0.19273600E+00, 0.22707600E+00, -.55540700E+00, -.47840700E+00, -.21044900E+00, -.62614200E-02, 0.15855300E-02, 0.33542500E-02, -.27323000E+00, -.13506800E+00, 0.92300100E-01, 0.46345100E+00, -.20927900E-01, 0.58054700E+00, 0.13660900E+00, -.57911700E-01, -.54521100E-02, 0.14502100E+00, 0.11024800E-01, -.46299000E-01, -.55872000E-01, 0.22190100E+00, 0.15468700E+00, 0.98363500E-01, -.97129600E-01, 0.11202300E+00, 0.32016600E-01, 0.24296300E-01, 0.38701900E+00, 0.11438500E-02, 0.20092400E+00, 0.10397800E+00, -.23113900E-01, -.28993300E+00, -.23021200E+00, -.20631500E-01, 0.18380000E+00, -.17329900E-01, 0.90121500E-01, 0.92565000E-01, 0.34520500E-01, -.77340800E-01, 0.76308600E-02, -.31443900E-01, 0.45545700E-01, -.67366300E-01, 0.10037000E-01, -.38249500E+00, 0.72820200E-01, 0.10977600E+00, 0.21662100E-01, -.28859300E+00, -.28908000E+00, 0.13157100E+00, -.14407800E+00, 0.64695700E-01, 0.13170300E+00, 0.77040000E-01, -.24959100E-01, 0.23034200E+00, -.45787500E-01, 0.77382900E-01, -.24442500E-02, 0.15317800E+00, 0.27356800E-01, -.55591400E-01, 0.12859600E+00, 0.12499100E+00, 0.14758900E-01, 0.28845300E-01, -.65336800E-01, -.35162200E-02, 0.13031800E+00, -.18325400E-01, 0.78877300E-01, 0.15859900E+00, 0.13114800E+00, 0.35656800E+00, -.17844600E+00, 0.30817100E-01, 0.15560500E-01, 0.20646300E+00, -.29961200E-01, 0.69302600E-01, 0.98598100E-03, 0.11046800E-01, -.23662200E-01, 0.27983600E+00, 0.26646000E-01, -.25729400E-02, -.26350300E-01, -.27199000E-01, 0.43384100E+00, 0.40533100E-01, 0.21196200E-01, -.91028500E-02, -.30889300E-01, -.15342400E-01, 0.50998700E-02, -.47063300E-01, -.12446000E-01, 0.10644000E+00, -.96461700E-01, -.17858200E+00, -.86870300E-01, -.66818400E-01, 0.32417600E-01, 0.97914800E-02, 0.23299100E+00, 0.15820300E+00, -.94303000E-02, 0.27429700E-01, -.99004900E-01, -.32161500E+00, -.30205700E-01, -.43005100E-01, 0.84626200E-01, -.10905800E-01, 0.48042300E-01, 0.29847000E-01, -.21207100E+00, -.16742600E-01, -.14760700E-01, -.43706300E-01, -.13682700E-01, 0.48575700E-01, -.87838500E-02, -.47509300E+00, 0.10249800E-01, -.94158800E-02, -.42838600E-01, -.58069700E-01, 0.78431000E-02, -.91658100E+00, -.99800500E-01, -.71107700E-02, 0.11302100E+00, -.57006500E-01, 0.19432800E-02, 0.13114300E-02, 0.22159000E+00, 0.27590400E+00, -.48834100E-01, 0.46325800E-01, 0.84058400E-02, 0.13324000E-01, -.69820100E-02, -.84052800E-01, -.20430900E-01, -.13558600E-01, -.37269400E+00, -.98884300E+00, -.23421700E-01, 0.20192900E+00, 0.58525400E+00, 0.77178200E+00, 0.15561700E+00, 0.36342900E+00, -.22996700E-01, 0.27592600E+00, -.14644900E-01, 0.52613900E-02, -.10967200E-01, 0.41213400E-01, 0.25579600E+01, -.73153500E-01, -.40338300E+00, 0.22843200E+01, 0.20593900E-01, 0.64558300E-01, 0.27908500E-01, -.20231700E+00, 0.54445700E-01 },
        { -.33885000E+01, 0.16189800E+01, 0.33991500E+00, 0.11700800E+01, -.11645900E+01, -.44261000E+01, -.53805400E+00, -.56297300E+00, -.16390000E+01, 0.24156100E+01, 0.53676700E-01, -.16741200E+00, 0.59997500E+00, -.17231200E+01, -.34080900E-01, 0.11859200E+01, 0.23680100E+00, -.98091900E+00, -.11276600E+01, 0.57440400E+00, -.14579000E+00, 0.11749800E+00, 0.34077800E+00, 0.60354900E+00, -.15490500E+01, -.79126500E-01, -.25451700E+00, 0.62650700E-01, 0.38994400E+00, 0.17984000E+01, -.58177100E+00, 0.72533100E+00, -.19009700E+00, 0.16815700E+00, 0.58516200E-01, -.41065600E+00, 0.16663600E+00, -.35759100E+00, 0.18252600E+00, -.79613000E+01, 0.78883400E-01, -.21731200E+00, 0.66447400E+00, 0.71064900E+00, 0.71716000E-01, 0.14545300E+00, 0.22562200E+00, -.19493000E-01, 0.60279500E-01, -.10041700E+00, 0.13857600E+01, 0.16083700E-01, -.27710600E+00, -.61032600E+00, -.84008200E+00, 0.33260600E+00, -.33540400E+00, 0.15478100E+00, -.71142800E-01, 0.74656700E-01, -.40564000E+00, -.66180600E+00, -.23515800E+00, -.67384200E+00, 0.61454100E+00, -.73862400E-02, 0.42304200E-01, -.10150100E+00, 0.20956200E+00, 0.83377400E-02, 0.64305700E+00, -.11932400E+00, -.39752500E+00, 0.19726500E+00, 0.14650400E+00, -.30174300E+00, -.18244500E+00, 0.39084100E+00, 0.47697200E+00, -.44331500E+00, 0.10104500E+00, 0.16543000E+00, -.10004000E+00, -.63436500E-01, -.94757800E+00, -.22131200E+00, 0.14203800E+00, -.15276800E+00, -.87996800E+00, -.43948100E-01, 0.23952000E+01, 0.52135200E-01, 0.27926100E+00, 0.87407100E+00, -.31034100E+00, -.94369000E+00, 0.31386200E+00, -.10608600E+00, -.60041100E-01, -.11516400E+00, 0.59809000E-01, -.16673700E+00, -.92062300E-01, 0.82316600E-01, -.24907500E-01, -.28308600E+00, -.40490800E+00, -.48642200E+00, -.40708600E+00, -.13138100E+00, 0.58905100E+00, -.76969500E-01, -.19330700E-01, 0.18249700E+00, -.23788400E+00, 0.28432000E+00, 0.10997800E+00, 0.20196500E-02, 0.35338900E-01, -.12753500E+00, -.32727700E+00, 0.11601000E+00, 0.70871100E-01, 0.22564000E+00, -.85165300E-02, -.48960500E-02, 0.73373600E-01, -.13725100E+00, 0.25225400E+00, 0.18444800E+00, 0.29926000E+00, 0.84528800E+00, 0.42294300E+00, -.18077100E-02, 0.11671800E-01, -.74245000E-02, -.42435400E+00, -.10405500E+00, -.35941400E-01, -.10398700E+01, -.21553400E+00, -.83133700E+00, -.25812600E+00, 0.20162100E-01, -.90370300E-01, -.26988100E-03, -.90867800E-02, 0.13832600E+00, 0.46154300E-01, -.22433800E+00, 0.70678400E-01, 0.10703300E+00, 0.22152200E+00, 0.19935200E+00, -.64820800E-01, -.39735400E-01, -.26139600E+00, -.15278200E-02, -.12597300E+00, 0.17057800E-01, 0.22143800E-02, 0.42566800E-01, 0.83048900E-01, 0.15460900E-01, -.24846200E-01, 0.15557900E-01, 0.20997400E+00, -.21166300E+00, 0.12305600E-01, -.22858900E-01, 0.37097300E-03, 0.12059200E+00, 0.14891500E-01, -.20414100E-02, 0.14117200E+00, 0.88291300E+00, -.55699300E-01, -.11130300E+00, -.13269700E+00, 0.25137900E+00, -.37734900E+00, -.13693000E+00, 0.23571200E+00, -.12423600E-01, -.32253200E+00, -.28431700E-01, -.40781400E-01, 0.34289800E+00, 0.94741100E-01, 0.83150900E-01, 0.84128400E-02, 0.13810700E+00, 0.78332900E-01, -.33123800E-01, 0.22319700E+00, 0.31602500E-01, 0.14292200E-01, -.20555100E-01, 0.98639400E-01, 0.31469600E-01, -.42466500E+00, -.47469800E-02, 0.10685400E+00, 0.18798100E+00, 0.48099600E+00, -.27208900E+01, -.71166100E-01, -.11007200E+01, 0.26490000E+00, -.10541700E-01, 0.98555000E-01, 0.24129000E+00, -.19244900E-02, -.57306400E-02, 0.29301200E+00, -.61957400E+00, -.15019100E+00, 0.36547800E-01, -.78872100E-02, -.15750800E-01, -.25616400E+00, 0.78627200E-01, 0.79215800E-02, -.73336200E-02, 0.65553500E-01, 0.77022000E-01, -.15190500E+00, -.78951400E-02, 0.71691400E-03, 0.66306200E+00, -.32625200E+00, -.52775300E-01, -.16056800E+00, -.89122800E-01, 0.21504900E-01, -.90695100E-02, -.62934900E-01, 0.19866400E-01, -.51890600E-01, 0.56342300E-01, 0.27490900E-01, 0.80542400E-01, 0.12211300E+00, -.91640500E-02, -.15819700E-01, -.22051100E-01, 0.55923400E-01, 0.22323700E+00, 0.81455700E+00, -.16787600E+00, 0.24580500E-01, 0.43655000E-01, 0.12049600E+00, 0.83837300E-02, -.14471900E-01, 0.12308900E+01, 0.23530400E-01, 0.99048400E-02, 0.72813000E-02, -.95657200E-01, -.88300000E-02, -.10663200E+01, 0.20224900E+00, 0.73559600E-02, 0.33068100E+00, 0.15465300E-02, 0.78382100E-02, 0.42809100E-02, 0.45614400E-01, -.16821500E+00, 0.37785300E-01, -.12631100E+00, 0.35714200E-01, 0.27230400E-01, 0.27041600E-01, 0.70017000E-01, -.43317900E+00, -.40990100E-02, 0.16956700E+00, 0.43908300E+00, -.26798700E-01, 0.31523100E-01, -.49175700E-01, -.11331300E+00, -.32917200E-01, -.46408200E+00, 0.10928700E+00, -.32223600E+00, 0.15128800E+00, 0.20840100E-01, 0.12356300E+00, -.23414400E+00, 0.45465600E+00, -.12502500E-01, 0.10375800E-01, 0.20233600E+00, -.45110400E+00, -.22483100E-02, 0.21941600E+00, 0.28830600E-01, -.51739000E-02 },
        { 0.20307400E+02, -.50435800E+01, -.10093900E+01, 0.43234100E+01, 0.10522400E+02, -.97046900E+01, 0.23287000E+02, -.19513400E+02, 0.12550500E+02, -.16189000E+02, -.11071300E+00, 0.13354700E+01, 0.75627100E+01, -.23452500E+02, 0.13684600E+02, -.23401400E+01, -.63261200E+00, 0.47112800E+01, -.31970600E+01, 0.82625000E-01, -.55708800E+00, -.31381000E+00, -.22369800E-01, -.15611500E+01, 0.10331700E+02, 0.55533600E+00, 0.47609800E+01, 0.87114500E+01, -.82644100E+01, 0.36940900E+01, -.17553400E+01, -.31432300E+01, 0.89655900E+00, -.17424800E+01, -.19614500E+01, -.26320600E+01, -.94223700E+00, -.99745100E+00, 0.41446700E+01, -.11955100E+02, 0.74498600E-01, 0.86397400E+00, 0.25189100E+01, 0.77985800E+00, 0.14946800E+00, 0.22809200E+00, 0.46300900E+00, 0.30845300E+00, -.70960800E+00, -.99302000E+00, 0.90972400E+00, -.19665300E+01, 0.12821200E+01, -.18536700E+01, -.90180900E+00, -.15058400E+00, -.50022900E+00, -.20658800E+00, 0.54787600E+00, 0.28735600E+01, 0.23725900E+01, -.38016900E+01, -.25886100E+01, -.11390800E+00, -.42778300E+00, 0.14780200E+00, -.13130400E+01, -.12775900E+01, -.20944300E+00, -.89357800E-01, 0.10979900E+01, -.16692800E+01, 0.12249500E+02, -.14848000E+01, -.21301400E+01, 0.48359700E+01, -.11613900E+01, -.56320700E-01, 0.95264600E-01, 0.34611200E+00, -.58894000E+00, 0.12289500E+01, -.29319300E+01, 0.15139100E+01, -.45912700E+00, 0.81248000E+00, 0.17823700E+01, 0.55309700E+01, 0.12176300E+02, -.60407000E+01, -.22744600E+01, -.24753300E-01, 0.21413100E-02, -.20579700E+00, 0.14442000E+01, 0.35475900E+00, -.21560400E+00, 0.26625700E+01, 0.38813900E+00, -.25618700E+00, -.85316500E+00, 0.15005700E+01, 0.13471700E+01, 0.18930700E+01, -.12316600E+01, 0.26469900E+01, 0.16868800E+01, 0.44730800E+01, -.58991300E+01, 0.28280300E-01, 0.60726700E+00, -.17472200E+01, -.20044900E+00, 0.98538900E+00, -.14625500E+01, -.48396500E+01, 0.17273000E+02, -.27121100E+00, 0.47969900E+00, -.26674100E+01, 0.10183900E+01, -.77548300E+00, -.28378000E+00, -.11603000E+01, -.33040800E-01, 0.20296000E+00, 0.25708900E+00, 0.65525500E+00, -.56033800E+00, -.38393400E+00, 0.71627600E+00, -.20547100E+01, 0.63876100E+00, -.86562100E-02, 0.44116800E-01, -.92530700E-02, 0.18533800E+01, -.85645400E+00, 0.82004300E+00, -.20030100E+01, -.12960900E+01, 0.14932300E+01, 0.25330400E+01, 0.21877800E-01, -.30339000E-01, 0.96507000E+00, 0.60372800E-02, -.13979700E+00, -.58852700E+00, 0.34707500E+00, 0.12043300E+00, -.54876500E-01, 0.14723900E+01, -.10606400E+01, 0.14639400E+00, 0.15649900E+00, -.63980100E+00, -.70756300E-02, -.17880000E+01, 0.26131500E+01, -.91620400E-01, 0.16959600E+01, 0.28899100E+01, 0.93587800E-01, -.14984400E+01, 0.86002600E+00, -.16190900E+01, -.98271500E-01, 0.31423000E+00, 0.22874300E+00, -.62946000E+00, 0.10563500E+01, 0.13017800E-01, 0.10168000E+00, 0.61200300E+00, 0.17874400E+01, -.51034100E+00, -.13861700E+01, -.64548500E+00, 0.23075900E+01, 0.24231500E+01, -.13387100E+00, 0.68143600E+00, -.49289400E+00, 0.12003400E+01, -.59559700E+00, -.35978700E-02, -.43279100E+01, -.11726000E+00, -.87430600E+00, -.16429700E-01, -.70325500E+00, -.23786100E+00, 0.48510700E+00, 0.18609600E+01, 0.26736200E+00, 0.83860500E+00, -.12277600E+00, -.41832600E+00, 0.92691300E-01, 0.53577800E+00, 0.20152700E+00, -.59175900E+00, -.20667400E+00, -.39868000E-01, 0.81159200E+01, 0.36341800E+00, 0.30825300E+01, -.23492500E-01, 0.12504500E+00, 0.31490800E+00, -.24362600E+00, 0.10991500E+00, -.36853000E+00, -.13610200E+00, -.11990600E+01, 0.37018700E-01, -.53383500E-01, 0.35441800E+00, 0.27149400E+00, -.45009900E+01, -.25177200E-01, -.70519300E-01, 0.17104600E-01, 0.13017600E+00, 0.38980600E+00, -.40947200E+00, 0.30519900E+00, 0.12506000E+00, 0.16762600E+01, -.21662200E+00, -.12810300E+01, -.11057200E+01, 0.65977700E+00, 0.11117000E-01, 0.62940500E+00, -.24229200E+01, 0.23486100E+01, 0.72059900E+00, -.60266100E+00, -.63445600E+00, -.24378400E+01, 0.25504900E+00, -.51889200E+00, 0.15175900E+00, -.15434300E+00, -.10703200E+01, 0.42386500E+00, 0.24744700E+01, -.53928200E+00, -.26997800E-02, -.55557900E-01, -.43845000E-01, 0.59933700E+00, -.25612600E+00, 0.25860800E+01, -.14452900E+00, -.30615400E+00, 0.28119900E+00, 0.89601800E+00, 0.21848200E+00, -.19203200E+02, 0.95899700E+00, 0.14655400E+00, -.19824300E+01, -.11157700E+01, 0.13304000E-01, 0.51885800E-02, -.50875800E+00, -.39782800E+00, -.11218400E+00, 0.22306300E+00, 0.14454200E+00, -.32721600E+00, 0.77900900E-01, 0.35059300E-01, 0.47921000E+00, 0.58944100E-01, -.41925000E-01, 0.14819600E-01, 0.45707100E-01, 0.12408000E+00, -.20994100E+00, -.34828500E+00, -.62419800E+00, -.86431200E+00, 0.10655000E+01, -.19136700E+01, 0.11720300E+01, -.61672700E+01, 0.16729400E+01, 0.14121100E+01, 0.46718900E+01, 0.15113200E+00, -.20448500E+01, 0.16536400E+01, -.92938600E-01, -.52646000E+01, -.65271100E-01, 0.46858200E+00, 0.18017600E+00 },
        { 0.79219200E+00, 0.82600100E+00, 0.96960900E-01, 0.22666200E+00, 0.11100100E+01, 0.11171100E+01, -.36766400E+00, 0.74159700E+00, 0.78033200E-01, -.10021800E+01, 0.33656900E-01, -.25693700E-02, 0.22408300E+00, -.12808300E+00, 0.89931000E+00, -.28814100E+00, 0.18690400E-01, 0.61265900E+00, 0.10865800E+00, 0.17501000E+00, -.14096500E+00, -.26990700E-01, -.77680500E-01, -.42733300E-01, 0.40586900E+00, 0.19412400E-01, 0.36004600E+00, 0.57135900E+00, -.44030900E+00, -.14347300E+00, -.82086100E-01, -.62489500E+00, -.82774900E-01, -.31801000E-01, -.34020200E-01, 0.59308300E-02, -.47513900E-02, -.62401300E-01, 0.51305100E-01, -.84444700E-01, -.15611800E-01, -.41742200E-01, 0.12605000E-01, 0.34904000E-01, 0.13892700E-01, 0.19313200E-01, -.12176400E-01, -.16160200E-02, 0.13717600E-02, 0.30695900E-01, 0.77899100E-01, 0.13513800E-01, -.30823200E-01, -.11636800E+00, 0.51616600E-01, 0.56828200E-01, 0.42903500E-01, 0.93311000E-02, 0.20904200E-02, 0.22821500E-01, -.10270700E+00, -.11864400E+00, -.64864200E-01, -.20197100E-01, 0.28237000E-01, -.20891200E-01, 0.12056500E-01, -.75645500E-02, -.33733400E-02, -.78530300E-03, -.64022400E-01, 0.35360400E-01, -.74831200E-01, 0.84270200E-02, -.10138500E-01, -.84382700E-01, 0.52784400E-01, -.16524400E-01, -.13018000E-01, 0.39797500E-01, 0.50640100E-02, -.46752700E-01, -.89749200E-01, -.18967700E-01, 0.53145000E-01, -.18169900E-01, 0.30818900E+00, -.11062700E+00, -.87808200E-01, -.38366400E-02, -.15177900E+00, -.69805500E-02, -.10332400E-01, -.48939700E-01, -.70607800E-01, 0.58300700E-01, -.30292600E-01, -.79765500E-01, -.81031700E-01, 0.13450800E-01, 0.30763000E-01, -.42585300E-02, -.35648900E-03, -.47294600E-01, 0.46823100E-01, -.17290100E-01, -.70158000E-01, -.10996600E+00, 0.98902200E-01, -.58045100E-02, -.31363200E-01, 0.83470500E-02, -.62036400E-02, -.45132900E-01, -.32296600E-01, 0.10369200E+00, -.69212600E-01, -.64471500E-01, -.27887800E-02, 0.59677800E-01, 0.24229900E-01, -.65347500E-01, -.18983400E-01, -.29087500E-01, -.50136700E-03, 0.67309200E-01, -.80103600E-02, -.90425300E-01, -.85104300E-02, -.33480100E-02, -.63683100E-02, -.18901500E+00, -.11163500E+00, -.18763400E-02, -.75543600E-02, 0.17859400E-02, -.31598300E-01, 0.87905600E-01, -.13059600E-02, 0.12522300E+00, 0.12870200E+00, 0.80082800E-01, 0.25775800E-01, -.32848800E-01, -.12495800E-01, 0.39773900E-01, 0.26881600E-02, -.11709800E-01, -.19243600E-01, 0.82118000E-01, 0.37544500E-01, 0.22897700E-01, 0.11230600E+00, -.37609900E-02, 0.81968200E-02, 0.64355600E-02, -.64642200E-02, 0.50435900E-03, -.45510000E-02, 0.88940400E-01, -.62489100E-02, -.78070400E-01, 0.10472700E-01, -.22366900E-01, 0.52102600E-01, -.10404700E-01, 0.64728600E-01, 0.19213800E-01, -.36033400E-02, -.32089800E-01, -.96792300E-02, -.17196100E-01, -.90049100E-02, -.26851300E-01, -.65104300E-01, 0.87214200E-02, 0.23172200E-01, 0.72414000E-01, -.69420000E-01, -.26939000E-01, -.69232800E+00, 0.48148900E-01, 0.10098900E+00, 0.72179900E-01, 0.12029500E-02, 0.29280400E-01, 0.13310400E-01, 0.27919900E-01, -.89415300E-02, -.90244100E-02, -.12587300E-02, 0.12945400E-01, -.18318900E-01, 0.45073800E-01, -.11498400E+00, -.12374400E-01, 0.16936700E-01, -.23979400E-02, -.42059500E-02, -.19374900E-01, 0.60325500E-02, 0.11565900E-02, -.17834000E-02, 0.42830500E-01, 0.30697100E-01, -.86083300E-01, -.13996600E+00, -.30571700E-01, 0.10638500E-01, 0.29285500E-01, 0.39222600E-03, 0.23463400E-01, 0.45550800E-02, -.44855500E-02, -.13657300E-01, -.27138300E-02, 0.15910900E-01, -.84617300E-03, 0.21115300E-01, 0.15381600E-02, -.22319900E+00, 0.17570500E-01, 0.16383500E-02, -.11019300E-02, -.11925000E-01, -.34546200E-02, -.70691900E-02, 0.23958300E-02, -.15321700E-02, 0.30359700E+00, -.22937900E-01, -.68853000E-02, -.25821000E-01, -.20592700E-02, 0.40191800E-02, -.31617600E-04, 0.30151800E-01, 0.71055400E-02, 0.22914100E-02, 0.26225600E-02, -.87897100E-02, -.25867200E-01, 0.13425500E-02, -.17443400E-01, -.39788500E-01, -.12473500E-02, -.32496000E-03, -.15466000E-02, 0.33515300E-01, 0.92733800E-02, -.54566400E-02, -.19661000E-02, -.63614400E-02, -.20899200E-01, 0.45497200E-02, 0.16086000E+00, -.40854100E-03, 0.10769100E-03, -.69603200E-02, -.27265200E-01, -.89889500E-02, 0.13234400E+00, 0.24929800E-01, 0.46164400E-02, -.40770200E-01, -.15573400E-03, 0.14787300E-02, 0.31309200E-03, 0.91521300E-02, -.55003400E-01, 0.18932800E-01, -.32474700E-01, 0.56162100E-02, 0.89397300E-02, 0.24719300E-02, 0.17743900E-01, -.66157400E-01, 0.21746000E-02, 0.44167600E-01, 0.11614600E+00, -.75276600E-02, -.47269800E-02, -.55106200E-01, -.33272800E-01, -.10535300E-01, -.11617400E+00, 0.58623300E-01, -.86856400E-01, 0.52206700E-01, 0.12895700E-02, 0.25620600E-01, -.40215600E-01, 0.13386100E+00, -.39166900E-02, -.35725300E-01, 0.65567300E-01, 0.17958700E-01, 0.45108400E-03, 0.74040700E-01, -.95725100E-02, -.22374400E-02 },
        { -.12644900E+01, 0.70990000E+00, 0.12030200E+00, 0.27367300E+00, 0.11554300E-01, 0.32222400E+00, -.18119300E+01, 0.43114700E+00, -.95565300E+00, 0.77053700E+00, 0.86181000E-01, -.10802400E+00, -.35441200E+00, 0.68309000E+00, -.82924300E+00, 0.81350700E-01, 0.31631300E+00, 0.81805000E-01, 0.19346300E+00, -.41269400E+00, 0.16643400E+00, 0.28164800E-03, -.65305000E-01, -.73457200E-01, 0.63896500E+00, 0.35078800E-01, -.84004400E-01, -.12167200E+00, -.10550000E+00, -.17766000E+00, 0.59556100E-01, -.22505000E+00, 0.15988600E+00, 0.17428500E+00, 0.37558900E-01, -.36433300E-01, -.52985300E-01, -.86494200E-02, -.21614700E-01, -.17008100E+01, 0.12817600E-01, -.46881400E-01, 0.78161900E-01, 0.10341200E-02, 0.96026800E-02, 0.36108600E-01, -.15728600E-01, 0.55953600E-02, -.16509900E-01, 0.69420600E-01, -.60212500E+00, 0.12177800E+00, 0.10076900E+00, 0.47099000E-01, 0.28485400E+00, -.57556200E-01, 0.13440600E+00, -.96715100E-02, 0.45204900E-01, -.14813000E+00, 0.70679800E-01, 0.24464100E+00, 0.11454000E+00, -.97134500E-01, 0.46624300E-01, -.58215600E-04, 0.67211600E-02, 0.26892400E-01, -.36151400E-01, -.42368800E-02, 0.97256900E-01, 0.25608500E-01, -.88345900E-01, 0.75841600E-01, -.18098100E+00, 0.69668600E-01, -.94286600E-01, 0.10090100E+00, 0.95305300E-01, -.31030100E+00, -.16805200E-01, 0.11235400E+00, 0.23060000E+00, 0.99273200E-01, -.30789900E+00, 0.62171300E-01, 0.15329000E+00, 0.37097100E+00, -.46265800E+00, -.28979400E+00, 0.34820500E+00, 0.21012500E-01, 0.10058000E+00, 0.71041900E-02, -.23760000E+00, 0.51940700E+00, -.15456400E+00, -.29314700E+00, -.89960700E-01, -.44530800E-01, 0.66564800E-01, -.14424500E+00, -.16932400E+00, 0.16783700E+00, -.16532400E+00, -.10262100E+00, -.14429300E+00, -.33427500E+00, -.25894100E+00, -.11933300E+00, 0.28922200E+00, -.49195100E-01, -.59584000E-02, 0.62347100E-01, -.20888200E-01, 0.88110600E-01, 0.47934300E+00, 0.58293600E-02, -.78574900E-01, -.17002200E-01, -.10441000E+00, -.28696800E-01, 0.18578100E-01, -.54085700E-04, 0.25298200E-03, 0.31227500E-01, -.12329500E-01, 0.16040100E+00, 0.12032700E+00, 0.11901300E+00, -.12627600E+00, -.10394000E+00, 0.71642700E-01, -.40506900E-03, 0.10231900E-01, 0.10372300E-02, -.38783800E+00, 0.54572600E-01, -.19961100E-01, 0.19844300E+00, 0.23348100E-01, 0.36953400E+00, 0.29948400E+00, 0.75448800E-01, 0.36437000E-01, -.60892500E-01, 0.63313300E-02, -.26809400E-01, 0.43341900E-01, 0.29081200E-01, 0.34519600E-02, 0.16001300E-02, -.82063000E-01, 0.92058000E-02, -.63605100E-02, -.26787100E-02, 0.25830200E+00, 0.13623100E-02, 0.82853600E-01, 0.55812300E-01, -.67832100E-03, -.78936900E-01, -.19440900E+00, 0.19817900E-01, 0.50775100E-01, 0.11766600E-02, 0.28080500E-01, -.12423900E+00, 0.11241100E-01, -.39497400E-01, 0.91581400E-02, 0.95340100E-01, -.32214800E-01, -.70884400E-02, -.78587500E-01, -.14592500E-01, 0.38542100E-01, 0.69824200E-01, 0.20723900E-03, -.57405900E-01, -.34144700E+00, -.52246500E-01, -.19300600E-02, 0.52742200E-01, -.46839900E-01, 0.21629800E-01, 0.61154700E-02, 0.17020100E+00, 0.19055600E-01, -.26836000E-01, -.48159900E-02, 0.90609400E-01, 0.33374800E-01, -.75425800E-01, 0.22822000E+00, 0.11090700E+00, 0.45953400E-01, 0.34259300E-01, -.42935300E-01, 0.21862900E-01, 0.14027100E+00, -.20957000E-01, 0.77191900E-01, -.29444600E-02, -.69441200E-01, 0.21217300E+00, 0.65339700E-01, 0.81166200E-01, -.90255000E-01, 0.10190000E+00, -.25613400E-01, 0.34354600E-01, -.95126900E-02, 0.46995700E-01, 0.54577600E-01, 0.22359500E+00, -.89657500E-01, 0.21661400E-01, -.53473700E-01, 0.54086000E-02, -.57998200E+00, 0.77730000E-02, 0.39364100E-02, 0.18919800E-02, 0.17226500E-01, 0.69765000E-02, -.51200400E-01, -.18459300E-01, 0.27137900E-01, 0.56536700E+00, -.12082300E+00, -.19386000E-01, 0.18589700E-01, -.34545900E-01, 0.12446100E-01, 0.16796300E-02, -.27038200E+00, 0.22078700E-01, -.16147700E-02, -.17482100E-01, -.76473900E-01, -.24864700E+00, -.87021500E-02, -.55272400E-01, 0.47493900E-01, -.63688200E-02, -.90782700E-02, 0.29037600E-01, -.10033900E+00, 0.98386900E-02, -.15792800E-02, -.45734300E-03, -.96471000E-02, -.17942900E-01, -.10909500E-01, 0.92289400E+00, 0.13924300E-01, 0.32788900E-01, -.28326500E-01, -.15561100E+00, 0.21922200E-01, -.33714300E+00, 0.83069800E-01, -.14255600E-01, 0.99919000E-01, -.13955900E-01, 0.14594500E-02, 0.71409000E-02, 0.12514900E+00, 0.66631100E-01, 0.76809700E-01, -.36788000E-01, 0.16510000E-01, 0.58115700E-01, 0.15571700E-01, -.48188700E-01, -.13553500E+00, -.30441000E-01, -.10911600E+00, -.34275300E+00, -.89798500E-02, 0.44290200E-01, 0.10077400E+00, 0.22758400E+00, 0.25655000E+00, 0.33207400E+00, -.15043800E+00, 0.74709400E+00, -.28954800E+00, 0.26875900E-01, -.11470300E+00, -.30226900E-01, 0.10606900E+00, -.94022400E-02, -.16935000E+00, 0.19495500E+00, 0.64627100E-01, 0.79448000E-03, -.12928700E+00, 0.26995300E+00, 0.58589800E-03 },
        { -.12464800E+01, 0.64558900E+00, 0.47750500E-01, 0.51648300E+00, -.24544600E-01, -.55915500E+00, -.82768000E+00, 0.11213900E+01, -.80484900E+00, 0.71191200E+00, -.28305100E-01, -.10830800E+00, 0.31320400E+00, 0.76976700E-01, 0.39514100E+00, 0.35294300E+00, -.39682500E+00, 0.19285300E+00, -.21896100E+00, -.57130900E-01, -.14654400E+00, 0.34116700E-01, -.45479700E-01, -.34608900E-01, -.64086500E+00, 0.39005900E-01, -.57127300E-01, -.17563800E-01, -.13404800E+00, -.72240800E-01, 0.91564000E-01, -.42452500E-02, 0.18770600E+00, -.66180800E-01, 0.68406100E-01, -.54331300E-01, -.68442400E-01, 0.98401500E-01, -.35772000E+00, 0.13593000E+00, 0.54823900E-01, -.39497700E-01, 0.10572100E+00, 0.17860800E+00, -.59215000E-01, -.48431000E-02, 0.23449300E-01, -.75149600E-02, 0.31911200E-01, 0.94525900E-02, 0.25293800E+00, 0.64219500E-01, -.55349500E-01, -.22336300E-01, 0.66193400E-01, -.11189100E-01, 0.29539200E-01, 0.43483700E-02, -.86222500E-02, 0.25922800E-01, -.27698500E+00, -.45247400E+00, -.16105600E+00, -.66021200E-01, 0.12675200E+00, 0.19635200E-01, -.98751800E-01, -.13857100E-01, 0.18321400E-01, 0.17438400E-01, -.67305000E-01, 0.61548200E-03, 0.33882200E+00, -.12327100E-01, 0.40052200E-01, 0.27962200E+00, -.17216900E+00, 0.19413300E-01, 0.31555300E-01, 0.51476200E-01, -.58740800E-02, 0.39221900E-01, -.34707900E+00, -.28846000E-01, 0.38662700E+00, 0.12436600E+00, 0.42876100E+00, -.12963100E+00, 0.93680600E-01, -.24778900E+00, -.28569600E+00, 0.76451800E-03, 0.15496800E+00, -.58184200E-01, -.15635900E+00, 0.71309200E-01, -.39357800E-01, -.22036000E-01, 0.24314700E-02, -.12576700E-01, -.89702500E-01, 0.14713400E+00, 0.10137200E+00, -.69474100E-01, -.18471900E-01, 0.13312800E+00, 0.29382600E-01, 0.24778300E+00, 0.15019100E+00, 0.72272800E-02, -.21191200E+00, 0.28278100E-01, 0.18509600E-01, -.23607900E-01, -.66356200E-01, 0.15271700E+00, 0.37789000E+00, -.10177900E+00, -.11082000E+00, 0.13536400E+00, -.27960300E+00, 0.39081800E+00, 0.21250600E-01, 0.91687900E-01, 0.74223000E-02, 0.16418800E+00, 0.53239600E-01, -.29032800E+00, 0.36777400E+00, 0.10395600E+00, -.32617700E+00, 0.34169500E+00, -.29294800E+00, -.27461800E-02, 0.23813800E-01, -.42411300E-02, -.29016600E+00, -.15681100E-01, -.40925500E-01, 0.34053900E+00, -.78613700E-01, -.15336000E+00, 0.12861100E+00, 0.42010100E-01, -.29094600E-01, 0.17615500E+00, -.14079300E-01, 0.57014000E-01, -.21021000E-01, 0.29535500E-01, 0.10694800E-01, -.25731400E-02, -.97200800E-01, -.67309200E-03, -.19072800E-01, 0.30198800E-01, -.17803900E+00, 0.11120500E-02, -.22051000E+00, 0.42824800E-01, -.31833700E-02, -.65824800E-01, -.78664800E-02, -.30992200E-01, 0.32063500E-01, -.44757400E-02, 0.63130300E-01, 0.67914600E-01, -.52801300E-02, -.10741300E-01, 0.81945100E-02, -.11058200E+00, 0.10839100E-01, -.26688300E-01, 0.13447400E+00, -.66292400E-01, 0.17323300E-01, 0.92272600E-03, -.46358600E-01, 0.74778800E-02, -.39996900E+00, 0.13748600E-01, 0.61580500E-01, 0.43180200E-01, -.30790700E-01, 0.13581700E-01, 0.29636500E-02, 0.49702700E-01, -.16474200E-01, -.13682200E-01, -.10189300E-02, -.32352800E-02, -.11333500E-01, 0.31257700E-01, 0.13141400E+00, 0.32374300E-01, 0.28258300E-01, 0.35764700E-02, -.14108900E-01, 0.40750400E-02, -.28342500E-01, 0.20193400E-02, -.12945900E-01, 0.23940600E-01, 0.75088300E-01, 0.35570300E+00, 0.74942800E-02, -.11500300E-01, -.12100800E-01, 0.43883400E-01, -.83122200E-02, 0.19141000E-01, 0.40639100E-03, -.13784800E-01, -.91434500E-03, 0.27396400E-01, -.11097100E-01, -.13681300E-01, -.18965200E-02, 0.13464900E-01, -.13555200E+00, 0.23026400E-01, -.71074300E-03, 0.28339600E-02, 0.42711600E-02, 0.13917400E-01, -.29909100E-01, 0.91395600E-03, 0.94578100E-02, 0.30751200E+00, 0.42667800E-01, 0.52058800E-01, 0.31358100E-01, 0.20830200E-02, -.15389700E-02, 0.59594300E-03, -.23128600E-01, -.13527700E-02, -.15065800E-01, -.12033700E-01, -.21118300E-01, -.72717900E-01, -.14580100E-01, -.13424500E-01, 0.29311000E-01, 0.30700600E-02, -.35401300E-01, 0.14894100E-01, 0.88172700E-01, -.97654500E-03, -.14361200E-02, 0.46989800E-02, -.74894000E-02, 0.19513800E-01, 0.97461600E-02, 0.20339800E+00, 0.28767900E-02, 0.17331600E-02, -.86374500E-02, -.35474000E-01, -.96442800E-02, 0.16361800E+00, -.45710600E-01, 0.19865600E-01, 0.75794300E-01, -.30522200E-02, -.72630100E-02, -.43247500E-03, 0.16209600E+00, 0.92449400E-02, 0.16784700E-02, 0.31551600E-01, -.14242700E-01, 0.44182600E-02, -.16631200E-02, 0.10950900E-01, -.56997700E-01, 0.50461300E-02, 0.18714700E-01, 0.12341100E+00, 0.12644800E-02, -.33870100E-01, -.36652700E-01, -.58702400E-01, -.53281900E-01, -.54321400E-01, 0.50174800E-01, -.17505400E+00, 0.89806100E-01, -.14423900E-01, 0.74193700E-01, 0.36636200E-01, -.69953200E-01, 0.49810100E-02, 0.18049100E-01, -.33570100E-02, 0.15652400E-01, 0.16327800E-02, -.30219000E-01, 0.21703700E-02, 0.10603700E+00 }
    },
    {
        { -.30634800E+06, 0.15460000E+06, 0.14776600E+06, 0.14826100E+06, 0.12101500E+06, 0.19450500E+06, -.80570700E+05, -.15427900E+06, -.64910000E+05, 0.17914800E+06, 0.12067900E+06, -.17275600E+06, 0.87719800E+05, 0.11551400E+06, 0.80741000E+05, 0.11188900E+06, 0.18037900E+06, -.87492600E+05, -.11777900E+06, -.77952200E+05, 0.16389600E+06, 0.53304900E+05, -.14985600E+06, 0.75653300E+05, 0.91433600E+05, 0.72231900E+05, 0.60533300E+05, 0.11059400E+06, -.48578000E+05, -.90364400E+05, -.52791800E+05, 0.10225700E+06, 0.56032800E+05, -.31784600E+06, 0.15941500E+06, 0.17213300E+06, 0.15227700E+06, 0.14863500E+06, 0.23691900E+06, -.10359800E+06, -.16869300E+06, -.88477800E+05, 0.21640100E+06, 0.11150300E+06, 0.12803600E+06, -.62826500E+05, -.82816600E+05, -.62617600E+05, -.43475200E+05, -.89217100E+05, 0.33573300E+05, 0.74538900E+05, 0.31140400E+05, -.80533000E+05, -.51317800E+05, -.29680400E+06, 0.14965600E+06, 0.12898700E+06, 0.14452600E+06, 0.10185500E+06, 0.16735600E+06, -.66636700E+05, -.14421400E+06, -.58568200E+05, 0.15576400E+06, 0.11705600E+06, 0.10475400E+06, -.53468600E+05, -.76027400E+05, -.49174400E+05, -.10419000E+06, -.19580000E+06, 0.97469200E+05, 0.10793700E+06, 0.96078600E+05, -.17435200E+06, -.43220700E+05, 0.52553900E+05, -.25091200E+05, -.82782300E+04, -.27752900E+05, 0.30633000E+05, 0.83270000E+05, -.51344100E+05, -.29224200E+05, -.70217700E+05, 0.73016500E+05, -.14079800E+05, 0.30134200E+06, -.15432600E+06, -.11877100E+06, -.14605200E+06, -.15720300E+06, -.25571400E+06, 0.11180700E+06, 0.15346800E+06, 0.56615400E+05, -.22558000E+06, -.11449000E+06, 0.57086500E+05, -.28306300E+05, -.22674900E+05, -.28407900E+05, -.11617500E+05, -.24082900E+05, 0.54600100E+04, 0.24894900E+05, 0.40686600E+04, -.21793000E+05, -.22711400E+05, 0.20924100E+06, -.10328300E+06, -.63568700E+05, -.10331500E+06, -.79258800E+05, -.12248700E+06, 0.53806400E+05, 0.89527300E+05, 0.20404500E+03, -.11143200E+06, -.93392300E+05, -.94396100E+05, 0.45607200E+05, 0.25589800E+05, 0.46407700E+05, 0.26421300E+05, 0.45354200E+05, -.89001100E+04, -.23290800E+05, 0.17618900E+05, 0.36995400E+05, 0.48971900E+05, 0.41634400E+05, -.20611900E+05, -.19386000E+04, -.20660800E+05, -.29708100E+05, -.59964500E+05, 0.23883300E+05, 0.15538100E+05, -.30728500E+04, -.51856900E+05, -.30605900E+05, -.30292500E+05, 0.13158100E+05, -.18125700E+05, 0.17365400E+05, -.37606000E+05, -.82271600E+05, 0.47458400E+05, 0.32730700E+05, 0.66331100E+05, -.72227700E+05, 0.16201300E+05, -.25265300E+06, 0.12376900E+06, 0.11354800E+06, 0.12181800E+06, 0.11518900E+06, 0.18108000E+06, -.74354100E+05, -.12820800E+06, -.49094500E+05, 0.16509600E+06, 0.99289600E+05, 0.22647200E+06, -.11081100E+06, -.66961200E+05, -.10740700E+06, -.61312300E+05, -.81488800E+05, 0.13106100E+05, 0.76627700E+05, -.10389200E+05, -.69409500E+05, -.94332300E+05, 0.19671300E+06, -.98217000E+05, -.11535400E+06, -.95451600E+05, -.12537300E+06, -.20986600E+06, 0.97368700E+05, 0.13339500E+06, 0.86591300E+05, -.18945900E+06, -.64374400E+05, 0.83067900E+05, -.40919700E+05, -.64223500E+04, -.41318000E+05, -.25744700E+05, -.48835800E+05, 0.11116900E+05, 0.15543000E+05, -.22090900E+05, -.39955800E+05, -.49483400E+05, 0.27317000E+06, -.12795100E+06, -.55207700E+05, -.14010400E+06, 0.46123600E+05, 0.15057500E+06, -.11870300E+06, -.22079300E+05, -.15354600E+06, 0.12873800E+06, -.96247200E+05, -.16971100E+06, 0.83487500E+05, 0.45691100E+05, 0.80877400E+05, 0.45593400E+05, 0.58568700E+05, -.80780500E+04, -.56678600E+05, 0.21793500E+04, 0.52026100E+05, 0.69464900E+05, 0.12052000E+06, -.59945300E+05, -.35761300E+05, -.59407200E+05, -.47106900E+05, -.71716100E+05, 0.26781700E+05, 0.44538600E+05, -.72764500E+04, -.64540400E+05, -.52881100E+05, -.11237100E+06, 0.54995500E+05, 0.37662400E+05, 0.58097900E+05, -.18192900E+05, -.66835400E+05, 0.55222300E+05, 0.20973600E+05, 0.80119100E+05, -.59080100E+05, 0.32567000E+05, -.26458600E+06, 0.13037800E+06, 0.98325500E+05, 0.13014900E+06, 0.77137800E+05, 0.10126300E+06, -.39918900E+05, -.10431400E+06, -.76301000E+04, 0.97425700E+05, 0.97712200E+05, -.43100400E+05, 0.20725800E+05, 0.43618000E+05, 0.37272400E+05, -.19682000E+05, 0.72496800E+05, -.33229400E+05, -.42633800E+05, -.83711200E+05, -.65027500E+05, -.83486000E+05, 0.27620800E+05, 0.12757100E+06, -.10988400E+06, -.50941200E+05, 0.26556600E+05, 0.11213200E+06, 0.32825600E+05, 0.12432400E+06, -.88736200E+05, 0.99691500E+05, 0.85653500E+05, -.97250400E+05, 0.14554600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11882800E+00, 0.15763000E+05, 0.69324000E+05, -.65392800E+04, 0.98421200E+05, 0.27809800E+06, -.15264300E+06, -.13143500E+06, -.13788200E+06, 0.22813700E+06, 0.22528000E+05, 0.16204000E+06, -.64783900E+05, 0.67954100E+05, -.88584000E+05, 0.11276200E+06, 0.29621000E+06, -.17798000E+06, -.10193600E+06, -.17605500E+06, 0.24048600E+06, -.70279800E+05, 0.27346800E+05, -.27598000E+04, 0.56597500E+05, -.17223900E+05, 0.46746200E+05, 0.17210500E+06, -.10078100E+06, -.88294300E+05, -.94812400E+05, 0.14081000E+06, 0.22531100E+03, 0.36267000E+05, 0.44221500E+04, 0.63654600E+05, -.27029400E+05, 0.13474200E+06, 0.35124300E+06, -.19058800E+06, -.14367000E+06, -.17723600E+06, 0.28543300E+06, -.55927600E+04, -.13334300E+05, 0.31674300E+04, -.70262900E+05, 0.85129200E+04, -.36732800E+05, -.16233400E+06, 0.92161700E+05, 0.93539300E+05, 0.82972900E+05, -.13174700E+06, -.93931600E+04, -.97219900E+05, 0.65125100E+05, 0.51227500E+05, 0.43499200E+05, 0.75317700E+05, 0.22423400E+06, -.11566600E+06, -.13214500E+06, -.92742200E+05, 0.18542400E+06, 0.64247900E+05, -.29913300E+06, 0.12749000E+06, -.14024600E+05, 0.15383000E+06, -.11575200E+06, -.37417200E+06, 0.23417300E+06, 0.11480700E+06, 0.23172500E+06, -.30471000E+06, 0.96985800E+05, 0.29195700E+06, -.13158300E+06, -.71130200E+05, -.14794000E+06, 0.34707300E+05, 0.19150300E+06, -.13793500E+06, -.36904500E+05, -.16003000E+06, 0.15412100E+06, -.95015800E+05, -.33127400E+05, -.15368300E+05, -.44751600E+05, 0.22723900E+05, -.15612700E+06, -.42060400E+06, 0.22551000E+06, 0.16039100E+06, 0.16445700E+06, -.32960300E+06, -.11681800E+05, 0.30624300E+05, -.17399000E+05, -.10634700E+05, -.15139100E+05, -.71406100E+04, -.40045000E+05, 0.19603300E+05, 0.34625900E+05, 0.14910400E+05, -.33137100E+05, -.17507000E+05, 0.10537400E+06, -.57868500E+05, -.42386200E+05, -.50933900E+05, -.70242700E+05, -.17612600E+06, 0.95103500E+05, 0.10864200E+06, 0.21609000E+05, -.14683400E+06, -.74876000E+05, -.23077100E+06, 0.11359700E+06, 0.61883000E+05, 0.11433100E+06, 0.32094600E+05, 0.84893200E+05, -.14652400E+05, -.63086600E+05, 0.56168400E+05, 0.56845100E+05, 0.12814000E+06, 0.10061700E+05, -.59491700E+04, 0.94630300E+04, -.48217600E+04, -.34046000E+05, -.11533900E+06, 0.56977500E+05, 0.23097000E+05, 0.35338300E+04, -.89170400E+05, -.40689600E+05, -.30504300E+06, 0.14016900E+06, 0.33683400E+05, 0.15550300E+06, -.45549000E+05, -.18237900E+06, 0.12630800E+06, 0.20470000E+05, 0.16263300E+06, -.14869400E+06, 0.10662800E+06, -.33210100E+05, 0.23540000E+05, 0.83700000E+05, 0.10535700E+05, 0.11314500E+06, 0.27699900E+06, -.14295500E+06, -.12181900E+06, -.10622800E+06, 0.22707700E+06, 0.52098100E+05, 0.35766400E+06, -.17790700E+06, -.10489400E+06, -.17101600E+06, -.67528000E+05, -.12290900E+06, 0.21717600E+05, 0.12082700E+06, -.45952100E+05, -.88312700E+05, -.16925200E+06, -.25623400E+06, 0.11961700E+06, -.71707800E+05, 0.13199200E+06, -.12284400E+06, -.36412500E+06, 0.22201200E+06, 0.11451700E+06, 0.22247900E+06, -.29695700E+06, 0.68071100E+05, 0.17477800E+06, -.86937100E+05, -.23770700E+05, -.87101200E+05, -.30096000E+05, -.89281600E+05, 0.22456800E+05, 0.40921900E+05, -.55695600E+05, -.61383400E+05, -.11233900E+06, 0.85172100E+06, -.38401300E+06, -.13708600E+06, -.43059700E+06, 0.72010800E+05, 0.41316800E+06, -.32958200E+06, -.46388000E+05, -.38770800E+06, 0.33128200E+06, -.29884400E+06, -.23191300E+06, 0.11577800E+06, 0.63909200E+05, 0.11063200E+06, 0.45624700E+05, 0.77358400E+05, -.11683600E+05, -.77923500E+05, 0.22592200E+05, 0.58516400E+05, 0.10798700E+06, 0.81693600E+05, -.43295100E+05, -.19076700E+05, -.39706300E+05, -.41946300E+05, -.10437400E+06, 0.47511000E+05, 0.53849000E+05, 0.47138400E+04, -.82386100E+05, -.54811100E+05, -.33831000E+06, 0.15550400E+06, 0.11487300E+06, 0.17170900E+06, -.16795000E+05, -.16758800E+06, 0.14194800E+06, 0.39963100E+05, 0.17315800E+06, -.13687100E+06, 0.94409100E+05, -.15428800E+06, 0.76559600E+05, 0.42237100E+05, 0.74257200E+05, 0.45393100E+05, 0.88230900E+05, -.41442600E+05, -.89245400E+05, -.11479800E+05, 0.79100900E+05, 0.72213900E+05, 0.28287900E+05, 0.26109000E+05, 0.64183700E+05, 0.50308200E+05, -.11564800E+05, 0.81471700E+05, -.48034800E+05, -.24722800E+05, -.11154500E+06, -.90166100E+05, -.10154400E+06, -.38503000E+05, 0.18701800E+06, -.16429500E+06, -.18363200E+05, -.32405200E+05, 0.16389900E+06, 0.79896600E+04, 0.18533500E+06, -.11029900E+06, 0.15648500E+06, 0.13258500E+06, -.14059300E+06, -.43658500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25927100E+00, -.38986200E-01, 0.14720900E+06, 0.16768300E+04, 0.30010600E+04, 0.23496200E+05, 0.12050900E+02, 0.15508600E+05, -.12584400E+05, 0.16251900E+05, -.45954600E+05, -.49554900E+04, 0.20602100E+04, 0.12997600E+06, 0.44825700E+04, 0.13114400E+05, 0.36768100E+05, -.49882700E+04, 0.13351200E+05, -.87384100E+04, 0.25707900E+05, -.41014800E+05, -.22845800E+05, 0.11151200E+05, 0.83446700E+05, 0.12303400E+05, 0.88376000E+04, 0.20968200E+05, 0.44302300E+03, 0.75422400E+04, 0.14474900E+04, 0.14650900E+05, -.15573500E+05, -.60696000E+05, 0.29320700E+05, 0.13583100E+06, 0.32685000E+05, 0.18432200E+05, 0.41846200E+05, -.35268100E+04, -.44375300E+03, 0.53380900E+04, 0.30187900E+05, -.14941700E+05, 0.14102100E+05, -.66428200E+04, -.89226100E+05, -.75039400E+04, -.11749900E+05, -.20780400E+05, -.10923600E+04, -.79298900E+04, 0.41406400E+04, -.14686400E+05, 0.23060400E+05, -.29574200E+05, 0.14547500E+05, 0.12509000E+06, 0.16059800E+05, 0.71090000E+03, 0.16363900E+05, 0.22235500E+04, 0.52545300E+04, -.20066700E+04, 0.11183300E+05, -.24442300E+05, -.41168100E+05, 0.21526600E+05, -.18372400E+06, 0.19484200E+05, -.97934400E+04, -.35220000E+05, 0.60140400E+04, -.27465600E+05, 0.26558100E+05, -.23908900E+05, 0.66299500E+05, 0.19643700E+05, -.10102600E+05, 0.75908900E+05, -.93224100E+04, 0.49491400E+04, 0.16006100E+05, 0.10049400E+04, 0.21601400E+05, -.10259200E+05, 0.98007700E+04, -.33436800E+05, 0.29453200E+05, -.14249900E+05, -.24410000E+06, -.16333700E+05, -.36696300E+04, -.38508000E+05, -.53741900E+04, -.25794300E+05, 0.83128500E+04, -.26107300E+05, 0.53326700E+05, 0.11967400E+05, -.59237700E+04, -.23548500E+05, -.60227300E+04, -.20709000E+04, -.30134500E+04, -.21224200E+04, -.64926500E+03, -.50904800E+03, -.19761700E+04, 0.38891000E+04, -.32579800E+05, 0.17439100E+05, -.19621600E+06, 0.15829600E+05, 0.10565900E+05, -.81719100E+02, -.13935600E+05, -.41371200E+05, 0.18906800E+05, 0.32856700E+03, 0.57832200E+05, -.24751500E+05, 0.11379900E+05, 0.11164500E+06, 0.12648000E+05, -.40487400E+03, 0.72794400E+04, 0.73051300E+04, 0.73948200E+04, 0.46783400E+04, 0.44720100E+04, -.10101200E+05, -.23319800E+05, 0.12112700E+05, -.96235600E+05, 0.11606100E+05, 0.24958400E+04, -.78151500E+04, 0.39572700E+04, -.84723600E+04, 0.10125200E+05, -.48879100E+04, 0.25333000E+05, -.87865300E+04, 0.41676300E+04, -.44825600E+05, 0.36022500E+04, -.12873200E+05, -.23281200E+05, 0.67741700E+04, -.32781900E+04, 0.11344300E+05, -.16671300E+05, 0.31840600E+05, 0.20241200E+05, -.11820500E+05, 0.20047500E+06, -.85173600E+04, 0.38581700E+04, 0.20650500E+05, 0.28573600E+04, 0.21808300E+05, -.23492400E+05, 0.14905900E+05, -.71274500E+05, 0.34956200E+05, -.16213900E+05, -.15290700E+06, -.19547800E+05, 0.77990100E+04, -.27879300E+04, -.18058100E+05, -.16719400E+05, -.29884100E+04, -.10541000E+04, 0.24297500E+05, -.12125600E+06, 0.61266400E+05, -.22981400E+06, 0.59617700E+05, -.45663900E+04, -.30069700E+05, 0.13886000E+05, -.33852100E+05, 0.67211300E+05, -.21828500E+05, 0.13165400E+06, -.10374500E+05, 0.58630800E+04, -.10872400E+06, 0.51135800E+04, 0.45358700E+04, -.41940000E+04, 0.91142100E+03, -.60809000E+04, 0.63198800E+04, -.19268900E+04, 0.19482100E+05, 0.75224400E+05, -.36358400E+05, 0.11812800E+06, -.36358100E+05, 0.16136400E+05, 0.45921400E+05, -.20102100E+05, 0.21686900E+05, -.31775200E+05, 0.29272800E+05, -.71114700E+05, -.23594100E+05, 0.11080600E+05, 0.88889400E+05, 0.13206200E+05, -.49960100E+04, -.21092500E+03, 0.11688400E+05, 0.10236200E+05, 0.23431000E+04, -.93686400E+03, -.14333400E+05, 0.45891600E+05, -.22487800E+05, -.77668200E+05, -.23244200E+05, -.75091200E+03, -.91439600E+04, -.85809300E+04, -.63724800E+04, -.13874000E+05, -.57246100E+04, -.27197200E+03, -.18274100E+05, 0.93121300E+04, -.53172600E+05, 0.84767000E+04, -.18088600E+04, -.91422300E+04, -.61043900E+03, -.15218900E+05, 0.90234600E+04, -.41720400E+04, 0.27274100E+05, -.18997400E+05, 0.87740900E+04, 0.89659400E+05, 0.10270000E+05, -.42780200E+04, -.21915900E+04, 0.14075800E+05, 0.18881200E+05, 0.10727400E+04, -.14747400E+04, -.21646700E+05, 0.42581500E+04, 0.61305700E+04, -.49438000E+04, -.59594000E+04, 0.36503800E+05, -.11851900E+05, -.14859700E+05, 0.28520800E+04, -.82786800E+04, -.15064400E+05, -.20853100E+04, -.72381900E+03, 0.84516500E+04, -.72978400E+04, 0.34083400E+04, -.25908100E+04, 0.15780300E+05, 0.12673400E+05, 0.95947100E+04, -.11861100E+05, 0.29324100E+05, 0.25644200E+05, -.18884500E+05, -.10778600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46083100E+00, 0.91821400E-01, -.66905900E+00, 0.66273300E+04, -.18615500E+05, -.26383700E+05, 0.30727900E+05, 0.74032300E+05, 0.86672800E+05, -.34778600E+05, -.23434300E+05, -.14106000E+05, 0.67768800E+04, 0.12774900E+05, 0.14784700E+05, -.13600100E+05, -.21509200E+05, 0.27824600E+05, 0.62841100E+05, 0.77199400E+05, -.29947900E+05, -.15185000E+05, -.85071000E+04, 0.41595900E+04, 0.39883900E+04, 0.78249200E+04, -.12212300E+05, -.14659800E+05, 0.19044600E+05, 0.45898400E+05, 0.56560000E+05, -.20776000E+05, -.97438100E+04, 0.75469500E+04, -.37476800E+04, -.36238600E+04, 0.52992600E+04, -.22658100E+05, -.30231300E+05, 0.27685600E+05, 0.77735100E+05, 0.10011200E+06, -.40340400E+05, -.19322000E+05, 0.16326400E+05, -.86136300E+04, -.79821600E+04, -.10012800E+05, 0.17620000E+04, 0.80293200E+04, -.16851400E+05, -.41580400E+05, -.48567400E+05, 0.13631600E+05, 0.10281600E+05, -.38373900E+04, 0.18311900E+04, -.22278200E+04, 0.70644100E+04, -.20475900E+05, -.22423500E+05, 0.24047600E+05, 0.62212400E+05, 0.81855400E+05, -.30751100E+05, -.15098700E+05, 0.73073300E+05, -.36286300E+05, -.37840500E+05, -.40866100E+05, 0.84101800E+04, 0.21693900E+05, -.39904400E+05, -.66824100E+05, -.10053500E+06, 0.31258400E+05, -.29440000E+04, -.30566000E+05, 0.15216600E+05, 0.16400300E+05, 0.17267300E+05, -.25559300E+04, -.12656800E+05, 0.22656600E+05, 0.40826300E+05, 0.47525300E+05, -.18037500E+05, -.89258500E+04, 0.11332200E+06, -.55757200E+05, -.54542100E+05, -.62936900E+05, 0.66126900E+04, 0.70124600E+04, -.43709400E+05, -.79640200E+05, -.13122000E+06, 0.22041000E+05, -.18297300E+05, 0.23804100E+04, -.13739200E+04, 0.24365700E+03, -.13609000E+04, 0.17883200E+01, 0.25792900E+04, -.42877500E+04, -.12759900E+05, -.13889600E+05, 0.42003300E+04, 0.39435500E+04, 0.15266400E+06, -.76208100E+05, -.68612300E+05, -.78117400E+05, -.43175500E+04, -.34593000E+04, -.43700700E+05, -.44425300E+05, -.90771400E+05, 0.46201200E+04, -.41608800E+05, -.83001700E+05, 0.41146600E+05, 0.34686900E+05, 0.42571200E+05, 0.78436700E+04, 0.19754700E+05, 0.78102300E+04, 0.16322500E+05, 0.56413100E+05, 0.10422900E+05, 0.26973300E+05, 0.95544500E+05, -.47294500E+05, -.41584100E+05, -.47984000E+05, -.82511700E+04, -.16847500E+05, -.64649100E+04, 0.11041500E+03, -.47265700E+05, -.76554900E+04, -.35573100E+05, 0.27805500E+04, -.12099300E+04, -.62543700E+04, -.44377300E+04, 0.56395900E+04, 0.18180600E+05, -.14468900E+05, -.24431800E+05, -.27368700E+05, 0.19816700E+05, 0.16711900E+05, -.80249800E+05, 0.40364900E+05, 0.36088700E+05, 0.46314700E+05, -.83422100E+04, -.13371600E+05, 0.37600600E+05, 0.59046000E+05, 0.97428200E+05, -.22195300E+05, 0.12842100E+04, 0.55806000E+05, -.27904800E+05, -.20737400E+05, -.35891600E+05, 0.17581000E+04, -.67450200E+04, -.19578200E+05, -.50636800E+05, -.77573800E+05, 0.16392000E+04, -.53582600E+04, 0.44484300E+05, -.22192700E+05, -.25448100E+05, -.26188200E+05, 0.88860900E+04, 0.24508100E+05, -.39926500E+05, -.68777900E+05, -.83443000E+05, 0.32462500E+05, 0.20831900E+05, 0.98052600E+05, -.48430800E+05, -.38676600E+05, -.49317700E+05, -.93653100E+04, -.24717100E+05, -.20009600E+04, -.45370500E+03, -.52285700E+05, -.13944900E+05, -.39640500E+05, -.68103700E+05, 0.32665700E+05, 0.44584300E+05, 0.38886800E+05, -.30067900E+03, -.20263100E+05, 0.31161100E+05, 0.44609600E+05, 0.68801300E+05, -.29916000E+05, -.39160900E+04, -.18832500E+05, 0.94574800E+04, 0.30794700E+04, 0.14860600E+05, -.41543100E+04, -.95652500E+03, 0.12436600E+05, 0.35905600E+05, 0.48121300E+05, -.56101800E+04, -.35945600E+04, 0.67399900E+05, -.33445600E+05, -.31411700E+05, -.34861900E+05, -.34925700E+04, -.66019400E+04, -.14124000E+05, -.19181300E+05, -.47408600E+05, 0.44311300E+03, -.18571400E+05, 0.12901900E+05, -.64629300E+04, -.84374200E+04, -.90436500E+04, 0.34826500E+04, 0.15587000E+05, -.18809200E+05, -.37087900E+05, -.37478700E+05, 0.20497500E+05, 0.15229700E+05, -.23107600E+05, 0.11941600E+05, 0.79490200E+04, 0.14509600E+05, -.90813000E+04, -.15287200E+05, 0.29005600E+05, 0.47986500E+05, 0.50718000E+05, -.18605200E+05, -.40101600E+04, -.47501300E+04, -.22610300E+04, -.41661400E+04, 0.85430700E+04, 0.21725600E+05, -.21308900E+05, -.89464800E+04, 0.12557900E+05, 0.88839600E+04, 0.29576500E+05, 0.29675300E+05, -.95683400E+04, -.29367800E+05, 0.36611000E+05, -.25858100E+04, -.16125400E+04, -.17845100E+05, -.21873100E+04, -.34435000E+05, 0.43922200E+04, -.14802400E+05, -.37841700E+05, 0.15737900E+04, -.20506300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.48897400E+00, -.11216600E+00, -.23145200E+00, 0.25679500E+00, -.82271000E+05, -.13499400E+06, 0.18794500E+06, 0.18159600E+06, 0.12337600E+06, -.12724500E+06, -.41316700E+05, -.18591700E+05, 0.93221700E+04, 0.11167400E+05, 0.92683700E+04, -.68480900E+05, -.12068000E+06, 0.16826900E+06, 0.15165200E+06, 0.10860400E+06, -.11432900E+06, -.34989300E+05, -.37008500E+05, 0.18552500E+05, 0.16764500E+05, 0.18519400E+05, -.36993900E+05, -.67920400E+05, 0.10022900E+06, 0.98571700E+05, 0.82729900E+05, -.63772400E+05, -.11587500E+05, 0.65702100E+05, -.32536800E+05, -.35164000E+05, -.32874100E+05, -.10544000E+06, -.16502900E+06, 0.19910900E+06, 0.17815900E+06, 0.11459600E+06, -.15490800E+06, -.49384500E+05, 0.11051900E+06, -.55556600E+05, -.52599200E+05, -.55267600E+05, 0.67029200E+04, 0.39177300E+05, -.86636100E+05, -.78677000E+05, -.76592100E+05, 0.35912700E+05, -.49912300E+04, 0.15908100E+05, -.79090100E+04, -.90829900E+04, -.79347800E+04, -.74104900E+05, -.11561800E+06, 0.14773200E+06, 0.14239100E+06, 0.10243400E+06, -.10811600E+06, -.34262800E+05, 0.15681200E+06, -.78582100E+05, -.77125200E+05, -.78404200E+05, 0.41480300E+05, 0.98828800E+05, -.17881800E+06, -.15668600E+06, -.14542700E+06, 0.92937900E+05, -.84374300E+04, -.19933700E+06, 0.99678600E+05, 0.91596800E+05, 0.99669700E+05, 0.49751300E+04, -.27506500E+05, 0.93635600E+05, 0.71202600E+05, 0.10009500E+06, -.24741100E+05, 0.37176000E+05, 0.17327300E+06, -.86500000E+05, -.91767500E+05, -.86628600E+05, 0.90138900E+05, 0.16457100E+06, -.28721000E+06, -.23644400E+06, -.18798700E+06, 0.15014100E+06, -.57301000E+03, 0.33241500E+05, -.16709600E+05, -.16786700E+05, -.16623500E+05, -.20800200E+04, 0.87214900E+04, -.21150000E+05, -.18667100E+05, -.20143000E+05, 0.75922900E+04, -.66858600E+03, 0.16276900E+06, -.81724000E+05, -.82515600E+05, -.81378400E+05, 0.52338600E+05, 0.10437900E+06, -.22046100E+06, -.20789000E+06, -.15098500E+06, 0.99175900E+05, -.48523300E+03, -.19281600E+06, 0.96651000E+05, 0.90692500E+05, 0.96407000E+05, 0.88676200E+04, -.10885600E+05, 0.76375400E+05, 0.40803600E+05, 0.72879300E+05, -.47023500E+04, 0.39898400E+05, 0.89296200E+05, -.44689000E+05, -.45314300E+05, -.44647800E+05, 0.11805800E+04, 0.20946700E+05, -.47582700E+05, -.21864400E+05, -.37743100E+05, 0.16531900E+05, -.12295700E+05, 0.34965800E+05, -.17329800E+05, -.18163300E+05, -.17470900E+05, 0.11733400E+05, 0.34950600E+05, -.46585500E+05, -.37711100E+05, -.41934700E+05, 0.32827700E+05, 0.16473900E+05, -.95920100E+05, 0.48574700E+05, 0.50458900E+05, 0.47933700E+05, -.60301100E+05, -.11404500E+06, 0.19214800E+06, 0.17700600E+06, 0.13541400E+06, -.10798100E+06, -.31710100E+05, 0.27264100E+06, -.13673200E+06, -.13811300E+06, -.13629400E+06, 0.29392500E+04, 0.27810500E+05, -.13432400E+06, -.10604500E+06, -.12635500E+06, 0.19083100E+05, -.54903900E+05, 0.76039300E+05, -.38194400E+05, -.41678500E+05, -.38014600E+05, 0.62759600E+05, 0.12984200E+06, -.20208100E+06, -.18872300E+06, -.14447300E+06, 0.12305000E+06, 0.46867700E+05, 0.11688500E+06, -.58526800E+05, -.60567100E+05, -.58442500E+05, -.49418900E+04, 0.13089800E+05, -.45410000E+05, -.12811200E+05, -.40219100E+05, 0.66253000E+04, -.20075900E+05, -.25381700E+06, 0.12597200E+06, 0.12034200E+06, 0.12688800E+06, 0.11087800E+03, -.48150900E+05, 0.10969300E+06, 0.60772000E+05, 0.11616300E+06, -.44767600E+05, 0.54123700E+05, -.13830000E+06, 0.69375600E+05, 0.76854600E+05, 0.69134700E+05, -.61839900E+04, -.20811000E+05, 0.77274000E+05, 0.63610800E+05, 0.73223300E+05, -.16271800E+05, 0.24760600E+05, 0.84681200E+05, -.42440700E+05, -.44495900E+05, -.42338200E+05, 0.24130200E+05, 0.50224300E+05, -.98931200E+05, -.75836900E+05, -.62248100E+05, 0.45246600E+05, -.45837400E+04, 0.19854200E+06, -.99272600E+05, -.89143300E+05, -.99268000E+05, -.12170000E+03, 0.26874800E+05, -.81344300E+05, -.52709200E+05, -.89893700E+05, 0.23980300E+05, -.54636300E+05, 0.25609200E+05, -.12442900E+05, -.12645800E+05, -.12818600E+05, -.74986900E+05, -.11749400E+06, 0.17641700E+06, 0.18123400E+06, 0.10182100E+06, -.11310200E+06, -.42595300E+05, -.47000200E+04, -.11481100E+05, -.87662800E+04, -.17510400E+05, 0.37237900E+05, -.59141500E+05, 0.39800900E+04, 0.41569900E+05, 0.55437200E+05, 0.44780100E+05, 0.80853900E+05, -.17457300E+05, -.90582400E+05, 0.88014300E+05, 0.78156200E+03, -.31880200E+04, -.68129800E+05, -.10664900E+05, -.94402900E+05, 0.12890700E+05, -.72640800E+05, -.66173800E+05, 0.20116200E+05, -.19741000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37100000E+00, 0.34174400E+00, -.74015900E+00, -.38770100E+00, -.34044900E+00, -.86077600E+05, 0.88291700E+05, 0.12430300E+06, 0.68491600E+05, -.77477400E+05, -.71970700E+05, -.49209800E+04, 0.33657200E+04, -.50872300E+03, 0.24225200E+04, 0.78620600E+04, -.80509900E+05, 0.84147900E+05, 0.12133300E+06, 0.65487300E+05, -.74236800E+05, -.66117800E+05, 0.31064600E+05, -.14845700E+05, -.93267600E+04, -.15516000E+05, -.28351400E+04, -.60971500E+05, 0.51693500E+05, 0.85106600E+05, 0.29003600E+05, -.54106500E+05, -.62111000E+05, 0.96564300E+05, -.44937600E+05, -.40439800E+05, -.48314500E+05, -.84210000E+03, -.10628100E+06, 0.81890100E+05, 0.14523600E+06, 0.52632800E+05, -.94947700E+05, -.11024400E+06, 0.86485000E+04, -.61074300E+04, -.12023600E+05, -.43379000E+04, -.91329400E+04, 0.56710100E+05, -.58705800E+05, -.90935400E+05, -.46840300E+05, 0.51099800E+05, 0.50679600E+05, 0.79887400E+05, -.39326900E+05, -.32461500E+05, -.39922900E+05, -.10154800E+05, -.81925500E+05, 0.61241600E+05, 0.10893500E+06, 0.29745100E+05, -.72322900E+05, -.95634400E+05, 0.33560000E+05, -.19499200E+05, -.28440900E+05, -.16776200E+05, -.15406800E+05, 0.10783200E+06, -.11164600E+06, -.15828400E+06, -.85849800E+05, 0.98062600E+05, 0.75960100E+05, -.60958900E+05, 0.31514500E+05, 0.33513500E+05, 0.30482300E+05, 0.14019900E+05, -.58062500E+05, 0.68727600E+05, 0.92969400E+05, 0.63210400E+05, -.53541800E+05, -.33382200E+05, -.37312700E+05, 0.18173400E+05, 0.52031200E+04, 0.18674000E+05, -.16943900E+05, 0.12313800E+06, -.12991900E+06, -.20760700E+06, -.82802300E+05, 0.10705300E+06, 0.12799500E+06, 0.42907800E+04, -.25886000E+04, -.36431100E+04, -.21488800E+04, -.41736500E+04, 0.16491000E+05, -.17178000E+05, -.28096300E+05, -.15160300E+05, 0.15217200E+05, 0.15188800E+05, 0.68982400E+05, -.37900300E+05, -.59795300E+05, -.34486000E+05, -.15051100E+05, 0.64517800E+05, -.10993000E+06, -.14362200E+06, -.67150900E+05, 0.59182700E+05, 0.50778400E+05, 0.13088900E+06, -.62818300E+05, -.39157300E+05, -.65445000E+05, 0.12073400E+05, -.33807300E+05, 0.22497200E+05, 0.87556400E+05, -.14098100E+05, -.25803600E+05, -.10563400E+06, -.60313200E+05, 0.29366300E+05, 0.10733900E+05, 0.30156500E+05, -.10838200E+05, 0.34316200E+05, -.21459100E+05, -.49237800E+05, 0.92160800E+04, 0.30277700E+05, 0.61854000E+05, 0.76545100E+05, -.37401700E+05, -.34325800E+05, -.38257800E+05, -.90867200E+04, 0.43362100E+05, -.44694400E+05, -.37753400E+05, -.48924800E+05, 0.39681900E+05, 0.14965000E+05, 0.21130100E+05, -.49232600E+04, 0.14649500E+05, -.10588000E+05, 0.10276800E+05, -.82886800E+05, 0.92157800E+05, 0.14067800E+06, 0.55332800E+05, -.73902900E+05, -.11196300E+06, -.99961700E+05, 0.46110300E+05, 0.25700400E+05, 0.50019400E+05, -.14812200E+05, 0.41704300E+05, -.49015300E+05, -.12820600E+06, -.20740500E+05, 0.32561300E+05, 0.11140700E+06, 0.11221200E+06, -.58055300E+05, -.68621200E+05, -.56095600E+05, -.22529700E+05, 0.94201000E+05, -.12054700E+06, -.13763800E+06, -.98222000E+05, 0.85724600E+05, 0.73110800E+05, -.14106300E+06, 0.69234000E+05, 0.39860300E+05, 0.70531200E+05, -.97238000E+04, 0.32759600E+05, -.85431200E+04, -.61244000E+05, 0.33749400E+05, 0.26036500E+05, 0.99106200E+05, -.14038400E+06, 0.64784400E+05, 0.56822300E+05, 0.70172200E+05, 0.24506700E+05, -.11446400E+06, 0.11140100E+06, 0.11892200E+06, 0.10627000E+06, -.10595200E+06, -.27039800E+05, 0.65680300E+05, -.30633000E+05, -.16596200E+05, -.32867400E+05, 0.81640100E+04, -.24691800E+05, 0.26685700E+05, 0.76517100E+05, 0.12793200E+05, -.20231600E+05, -.68578900E+05, -.27189600E+05, 0.12497900E+05, 0.82831300E+04, 0.13598200E+05, -.93905300E+04, 0.35304600E+05, -.40148000E+05, -.71847800E+05, -.19597000E+05, 0.32051900E+05, 0.52837200E+05, 0.63957500E+05, -.32772500E+05, -.32901800E+05, -.31976600E+05, -.12197100E+05, 0.58589200E+05, -.62727200E+05, -.80828500E+05, -.62747700E+05, 0.55447600E+05, 0.24696500E+05, -.59864200E+05, 0.32636300E+05, 0.34706500E+05, 0.29914700E+05, 0.40451500E+04, -.39226700E+05, 0.75137700E+05, 0.88408500E+05, 0.58085800E+05, -.38035900E+05, -.22267200E+05, 0.22008900E+03, 0.32207300E+05, -.26002500E+05, 0.19923400E+05, 0.25549100E+05, 0.74652000E+04, -.33450800E+05, 0.23299600E+05, 0.38732400E+05, 0.31193900E+05, -.35304400E+04, -.10288600E+05, -.59269100E+05, 0.58695000E+05, 0.13108800E+05, 0.85417500E+03, -.43549000E+05, -.17661100E+05, -.63370200E+05, 0.23860800E+05, -.48701300E+05, -.43225800E+05, 0.28341900E+05, -.16387300E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34409200E+01, -.38743700E+00, 0.74050400E+00, -.16146200E+01, -.35422600E+01, -.21801400E+01, 0.46020200E+06, 0.69306700E+06, 0.31812600E+06, -.47423900E+05, -.10843800E+06, 0.39269000E+06, -.19550000E+06, -.77330700E+03, -.19630300E+06, 0.79582000E+05, 0.64063100E+05, 0.33270000E+06, 0.68058600E+06, 0.15867900E+06, -.24191300E+04, -.35202200E+06, 0.61175300E+05, -.30480500E+05, 0.67675300E+05, -.30612400E+05, -.14464200E+05, 0.55843300E+04, 0.22138400E+06, 0.39998300E+06, 0.13862900E+06, -.18951900E+05, -.12687300E+06, 0.72234300E+06, -.36069500E+06, -.26214800E+06, -.36113600E+06, 0.63117700E+04, 0.13401800E+05, 0.36482300E+06, 0.76761700E+06, 0.12999300E+06, -.50594500E+05, -.37548300E+06, 0.26500800E+06, -.13061700E+06, -.24249400E+06, -.13249500E+06, -.78213500E+05, -.61618900E+05, -.23158200E+06, -.37151000E+06, -.22393100E+06, -.31488800E+05, 0.31185800E+05, 0.12234700E+06, -.61089500E+05, -.14291500E+06, -.61204700E+05, -.65383700E+05, -.44984300E+05, 0.33211500E+06, 0.52515300E+06, 0.21028600E+06, -.68763600E+05, -.99618200E+05, -.11454400E+06, 0.55876600E+05, -.12811700E+06, 0.57269500E+05, -.19526700E+06, -.21278000E+06, -.35120300E+06, -.79576700E+06, -.24391800E+06, -.12489500E+06, 0.26141300E+06, -.32303000E+05, 0.17629100E+05, 0.94670800E+05, 0.16151100E+05, 0.13217100E+06, 0.15219700E+06, 0.18059300E+06, 0.48370400E+06, 0.14270800E+06, 0.10184800E+06, -.17162800E+06, 0.16966000E+06, -.87796600E+05, -.19587100E+05, -.84839200E+05, -.16039300E+06, -.12577200E+06, -.70221400E+06, -.11518600E+07, -.52721800E+06, -.32755000E+05, 0.16200500E+06, 0.15304100E+06, -.75977800E+05, -.51729700E+05, -.76517400E+05, -.31205400E+05, -.11810400E+05, -.70907900E+05, -.89060300E+05, -.86499600E+05, -.52976400E+04, -.21465500E+05, 0.11613700E+07, -.58008500E+06, -.43102700E+06, -.58069800E+06, -.93447000E+05, 0.42544300E+05, -.77865400E+06, -.82419800E+06, -.69721500E+06, 0.75478300E+05, -.22874600E+06, -.42368500E+06, 0.21091400E+06, 0.10897100E+06, 0.21184500E+06, 0.12625500E+06, 0.75988700E+05, 0.22448500E+06, 0.35716800E+06, 0.28780600E+06, 0.55703500E+05, 0.71887200E+05, 0.71761900E+05, -.35784900E+05, 0.22889000E+05, -.35881700E+05, -.11975600E+06, -.13846200E+06, -.54757200E+05, -.19250500E+06, -.81258700E+05, -.10074600E+06, -.92148100E+04, -.51545600E+06, 0.25621900E+06, 0.57617900E+05, 0.25770900E+06, -.68521600E+05, -.13687000E+06, 0.16220100E+05, -.26095300E+06, 0.90933400E+05, -.88666600E+05, 0.27776800E+06, -.21355800E+06, 0.10551900E+06, 0.13081900E+06, 0.10682700E+06, 0.11759100E+06, 0.73864400E+05, 0.49594500E+06, 0.77183800E+06, 0.37917600E+06, 0.19043300E+05, -.12814700E+06, 0.96088100E+06, -.47864000E+06, -.29182700E+06, -.48048000E+06, -.16716800E+06, -.72630200E+05, -.46545000E+06, -.59817000E+06, -.56345100E+06, -.54448000E+05, -.21029300E+06, -.54013800E+05, 0.26862700E+05, -.16549900E+06, 0.27000600E+05, -.15524200E+06, -.14206300E+06, -.45813000E+06, -.82770500E+06, -.30278800E+06, -.55322400E+05, 0.26247400E+06, 0.17372900E+06, -.86481200E+05, 0.40362800E+05, -.86865200E+05, -.11822400E+06, -.11055100E+06, -.73444000E+05, -.19574700E+06, -.13676600E+06, -.80595400E+05, -.48783200E+05, 0.96724300E+06, -.47683400E+06, -.72016500E+05, -.48358500E+06, 0.19363800E+06, 0.32996400E+06, -.52101000E+05, 0.60573700E+06, -.18635500E+06, 0.21608200E+06, -.52344800E+06, -.53328500E+06, 0.26551100E+06, 0.13488100E+06, 0.26666200E+06, 0.10264000E+06, 0.48267200E+05, 0.26268600E+06, 0.34532900E+06, 0.32151100E+06, 0.37189600E+05, 0.12062300E+06, 0.29863700E+06, -.14910800E+06, -.55648900E+05, -.14932200E+06, -.69378800E+05, -.19641100E+05, -.28374700E+06, -.37194800E+06, -.25434100E+06, 0.47597600E+04, -.40487100E+05, -.18223600E+06, 0.89746200E+05, 0.36347600E+05, 0.91111000E+05, -.58064600E+05, -.83535600E+05, -.10782100E+06, -.41254100E+06, -.54123200E+05, -.44851900E+05, 0.13706100E+06, -.60097500E+06, 0.29890700E+06, 0.14692400E+06, 0.30051000E+06, -.68691700E+05, -.20727300E+06, 0.64382700E+06, 0.60131800E+06, 0.50130300E+06, -.21186000E+06, 0.11162100E+06, 0.49980900E+05, 0.14318900E+06, 0.68854600E+05, 0.19686400E+06, 0.11874100E+06, 0.80837800E+05, -.23873100E+06, 0.14901800E+06, 0.55176500E+05, 0.29660600E+05, -.46149300E+05, -.19212000E+06, -.39341200E+04, 0.88247700E+05, -.22933000E+05, -.72933400E+05, 0.85720500E+05, -.60411300E+05, -.53779800E+05, -.13405500E+06, 0.18015100E+05, -.59767600E+05, -.15174900E+06, -.17287500E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30183100E+00, -.30841300E-01, -.63220600E+00, -.46076300E+00, -.38156500E+00, 0.41802300E+00, 0.11123400E+00, 0.48183500E+05, 0.10383100E+06, -.85716400E+04, 0.19683300E+05, -.14567800E+05, 0.83331500E+04, 0.22931500E+05, 0.70102100E+04, 0.94495200E+04, 0.14204600E+05, -.51131600E+04, 0.35098800E+05, 0.84690800E+05, 0.40491100E+04, 0.24302500E+05, -.12806300E+04, 0.11357200E+04, 0.57397000E+04, 0.78628300E+03, -.79544700E+04, -.35427300E+04, 0.38052800E+04, 0.28365900E+05, 0.63716300E+05, -.92397200E+04, 0.11956600E+05, -.17575500E+05, 0.10647100E+05, 0.14397100E+05, 0.85575800E+04, 0.53827200E+04, 0.74385100E+04, -.34175100E+04, 0.51770100E+05, 0.12652600E+06, -.35414400E+04, 0.32866800E+05, 0.31441800E+04, -.15619000E+04, -.70165800E+04, -.16565700E+04, 0.41754700E+03, -.15031800E+04, -.29409600E+04, -.26983200E+05, -.55148600E+05, 0.33358800E+04, -.12935500E+05, -.15671100E+05, 0.81911200E+04, -.16204100E+04, 0.80215100E+04, -.94139200E+04, -.74128100E+04, 0.52714500E+04, 0.41240800E+05, 0.10460200E+06, -.14503600E+05, 0.27542200E+05, 0.19974300E+05, -.11998400E+05, -.23281000E+05, -.99697700E+04, -.82202800E+04, -.17044600E+05, 0.11252200E+04, -.38720400E+05, -.96227100E+05, -.48466900E+04, -.24087000E+05, 0.56473100E+04, -.18988400E+04, 0.24250300E+04, -.28094900E+04, -.59704400E+03, 0.12882200E+04, 0.42239600E+04, 0.22327300E+05, 0.41074600E+05, -.30767800E+04, 0.67065800E+03, 0.16308300E+06, -.82815000E+05, -.76799500E+05, -.81456200E+05, -.31552500E+05, -.42240900E+05, 0.13573800E+04, -.19236100E+05, -.15493900E+06, -.25383000E+05, -.10224500E+06, -.24049700E+04, 0.12556200E+04, 0.32486900E+04, 0.11750500E+04, 0.14823100E+04, 0.27263200E+04, -.21453600E+04, -.10005700E+05, -.18288400E+05, 0.33915400E+04, -.35077400E+04, 0.14198700E+06, -.71856100E+05, -.51852800E+05, -.70936300E+05, -.23448700E+05, -.32459200E+05, 0.44335500E+03, 0.76714800E+04, -.86016600E+05, -.22125200E+05, -.73659100E+05, -.17689000E+06, 0.88103700E+05, 0.66919200E+05, 0.88435400E+05, 0.17449300E+05, 0.26950600E+05, 0.11605800E+05, -.14902600E+05, 0.86261900E+05, 0.18474000E+05, 0.88905100E+05, 0.16555300E+06, -.82222500E+05, -.69753900E+05, -.82774200E+05, -.20568000E+05, -.30665000E+05, -.73966800E+04, 0.21434100E+05, -.70590900E+05, -.21854100E+05, -.79627600E+05, -.66266400E+05, 0.32455700E+05, 0.15024200E+05, 0.33250800E+05, 0.37700700E+04, 0.11965400E+04, 0.54905800E+04, -.27450700E+05, -.14058800E+05, 0.43031700E+04, 0.19271100E+05, -.51708000E+05, 0.27598300E+05, 0.21922200E+05, 0.25605100E+05, 0.91164300E+04, 0.17099100E+05, -.17584000E+04, 0.29442800E+05, 0.10002500E+06, 0.59030400E+04, 0.45958900E+05, 0.11237000E+06, -.56315500E+05, -.30208800E+05, -.55918800E+05, -.10793300E+05, -.12970100E+05, -.11229400E+05, -.15127300E+05, -.10414600E+06, -.52161000E+04, -.70354300E+05, -.51937400E+05, 0.25023500E+05, 0.12053700E+05, 0.26022500E+05, -.36299500E+04, -.11742100E+05, 0.10897700E+05, -.48053000E+05, -.71911100E+05, -.71286500E+03, -.18772100E+04, 0.20486000E+06, -.10171500E+06, -.79503400E+05, -.10242900E+06, -.20971200E+05, -.32888100E+05, -.11434000E+05, 0.25690700E+05, -.87874100E+05, -.23145300E+05, -.10006000E+06, -.26564800E+05, 0.14257500E+05, 0.48738600E+05, 0.13082900E+05, 0.14552800E+05, 0.25641500E+05, -.37039900E+04, 0.14429600E+05, 0.49507700E+05, 0.13776700E+05, 0.16364200E+05, -.43416500E+05, 0.21834600E+05, 0.78740800E+04, 0.21549200E+05, 0.23484900E+04, 0.10452900E+04, 0.76734100E+04, 0.17283800E+05, 0.64967300E+05, -.30375500E+04, 0.31614100E+05, 0.12111600E+06, -.60466100E+05, -.53759100E+05, -.60534300E+05, -.18629300E+05, -.23315400E+05, -.31856200E+04, 0.96889100E+04, -.61824200E+05, -.16922200E+05, -.62311900E+05, -.64349600E+04, 0.23360400E+04, 0.15033700E+04, 0.32470600E+04, 0.48379000E+03, 0.20536900E+04, -.33986500E+04, -.17523500E+05, -.32153200E+05, 0.51322800E+04, -.25950900E+03, -.65276900E+04, 0.38303400E+04, -.70138900E+04, 0.31261700E+04, 0.28897000E+04, 0.79037800E+03, -.40308300E+04, 0.20788800E+05, 0.49053300E+05, -.24028900E+04, 0.14717500E+05, -.21111400E+04, 0.26811300E+03, 0.52201700E+03, 0.30239300E+05, 0.11408500E+05, -.13355100E+05, -.21776500E+05, -.57652100E+03, -.11904100E+05, 0.21671300E+05, 0.16594500E+05, -.88178800E+04, -.13872400E+05, 0.21559700E+05, -.10528200E+05, -.17591200E+04, -.70901300E+04, 0.88223000E+04, -.17600700E+05, -.75747300E+04, -.31332800E+04, -.33039100E+05, -.14980400E+05, 0.15551900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20413500E+01, -.54883800E+00, -.83842600E+00, 0.43746300E+00, 0.25492900E+00, -.50857900E+00, -.19034900E+00, -.91416600E+00, 0.16042900E+06, -.31389800E+05, -.24702300E+05, -.35023600E+05, 0.18295200E+05, 0.75805500E+05, 0.17229400E+05, 0.19297600E+05, 0.37126800E+05, -.77173700E+04, -.10018600E+05, 0.13039300E+06, 0.73933900E+03, 0.16679900E+04, -.10236600E+04, 0.84143000E+03, 0.18414100E+05, 0.66920800E+03, -.13564900E+05, 0.41579700E+03, -.19788400E+04, -.54875600E+04, 0.10005100E+06, -.20239700E+05, -.12340900E+05, -.86484000E+05, 0.44453100E+05, 0.66406800E+05, 0.43006100E+05, 0.23289600E+04, 0.65196100E+04, 0.23034500E+05, 0.92237200E+04, 0.21727900E+06, -.32385800E+05, 0.10305500E+05, 0.46345000E+05, -.22744600E+05, -.41952500E+05, -.23259900E+05, -.14724000E+05, -.30384500E+05, 0.18735200E+05, 0.25878300E+05, -.71267200E+05, -.10940700E+05, -.58022500E+04, -.73901200E+05, 0.37145900E+05, 0.29787200E+04, 0.37151700E+05, -.18102100E+05, -.19355500E+05, 0.21765500E+05, -.32936400E+04, 0.18427100E+06, -.45209300E+05, 0.68667600E+04, 0.55445000E+05, -.29215100E+05, -.78002800E+05, -.27708100E+05, -.29372200E+05, -.65762300E+05, 0.30277300E+05, 0.40315100E+05, -.14019700E+06, -.22398400E+05, -.45223700E+04, 0.61797500E+04, -.22105900E+04, 0.16896400E+05, -.30753100E+04, 0.50378600E+04, 0.25431900E+05, -.23848500E+05, -.30585700E+05, 0.50315300E+05, 0.64145000E+04, -.71024900E+04, 0.36899300E+06, -.18552500E+06, -.16338100E+06, -.18441800E+06, -.71713900E+05, -.97013500E+05, 0.17361900E+05, 0.13956900E+06, -.24321600E+06, -.40232800E+05, -.14102800E+06, 0.24018000E+05, -.11922100E+05, -.46353000E+04, -.12039200E+05, -.34480900E+04, -.28372100E+04, 0.94191900E+03, 0.70125200E+04, -.26754700E+05, 0.75404800E+03, -.52140300E+04, 0.14662400E+06, -.73123000E+05, -.65390500E+04, -.73249100E+05, -.36822400E+05, -.53511900E+05, 0.42288300E+05, 0.12128900E+06, -.10849100E+06, -.24904300E+05, -.84299200E+05, -.44520100E+06, 0.22099600E+06, 0.14912400E+06, 0.22259000E+06, 0.46917900E+05, 0.69094500E+05, 0.42338200E+04, -.11522400E+06, 0.16151500E+06, 0.44409700E+05, 0.19395900E+06, 0.37006100E+06, -.18378500E+06, -.14121900E+06, -.18502800E+06, -.47184800E+05, -.64093800E+05, -.13099000E+05, 0.75767500E+05, -.14800500E+06, -.41230800E+05, -.14925100E+06, -.70596300E+05, 0.34196600E+05, -.30326700E+05, 0.35421600E+05, -.96976500E+04, -.22064000E+05, 0.11430500E+05, -.13061800E+05, -.16407800E+05, -.80381700E+04, 0.65138300E+05, -.16850300E+06, 0.84561100E+05, 0.68517000E+05, 0.83977900E+05, 0.31131600E+05, 0.51238600E+05, -.16253600E+05, -.68828200E+05, 0.16149100E+06, 0.13393100E+05, 0.54512600E+05, 0.36905100E+06, -.18317200E+06, -.92785200E+05, -.18425400E+06, -.55996800E+05, -.66787800E+05, 0.22685000E+05, 0.12873000E+06, -.16693200E+06, -.37655100E+05, -.16527900E+06, -.56451700E+05, 0.27753700E+05, -.21663300E+05, 0.28276000E+05, -.31832900E+05, -.58409800E+05, 0.36093300E+05, 0.30516200E+05, -.99560000E+05, -.17291300E+05, 0.66456000E+05, 0.48771000E+06, -.24214700E+06, -.16618500E+06, -.24385400E+06, -.50595300E+05, -.71365100E+05, -.20858500E+05, 0.99413400E+05, -.18483000E+06, -.46324300E+05, -.20565200E+06, -.13792700E+06, 0.71411000E+05, 0.19797800E+06, 0.68746300E+05, 0.56676600E+05, 0.10506700E+06, -.32693500E+05, -.58579100E+05, 0.81071300E+05, 0.60519400E+05, 0.59624700E+04, -.19056900E+06, 0.94552600E+05, 0.43398800E+05, 0.95128800E+05, 0.25839300E+05, 0.26112500E+05, -.67933300E+04, -.63487800E+05, 0.10967400E+06, 0.94028700E+04, 0.80863600E+05, 0.24836500E+06, -.12355100E+06, -.97198900E+05, -.12415900E+06, -.36717400E+05, -.40851600E+05, -.14777800E+04, 0.74270300E+05, -.10416300E+06, -.22332600E+05, -.10310600E+06, 0.46541200E+05, -.24178800E+05, -.29212000E+05, -.23238000E+05, -.11128700E+05, -.17679500E+05, 0.12772700E+05, 0.34555100E+05, -.50056100E+05, -.18903800E+04, -.17112700E+03, 0.10901500E+06, -.54534800E+05, -.89427900E+05, -.54651800E+05, -.18281500E+05, -.32853200E+05, -.81699000E+04, -.65150100E+04, 0.51296000E+05, -.41726600E+05, -.35769000E+05, -.24730000E+04, -.15671200E+05, -.69046000E+04, 0.28079500E+05, 0.22645900E+05, -.36498100E+05, -.15401200E+05, -.17177400E+05, -.54448400E+05, 0.39567400E+05, 0.40767000E+05, -.30920000E+04, -.66562800E+04, 0.72167500E+04, -.10214600E+05, -.10685000E+05, -.23326600E+05, 0.10970200E+05, -.39607900E+04, -.17932000E+05, -.13056300E+05, -.48199900E+05, -.41203700E+05, 0.29004400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15468800E+01, 0.87567300E+00, 0.18983300E+00, 0.11752300E+01, -.11364700E+01, 0.97949300E+00, 0.13161500E+00, -.21002900E+01, 0.68639700E+00, 0.34123400E+05, -.30994900E+05, 0.51003600E+05, -.23937500E+05, -.50271000E+05, -.25896400E+05, -.10328000E+04, 0.74700500E+04, -.15189800E+05, -.44790500E+04, -.25174000E+05, 0.41313600E+05, -.46111900E+05, -.28074300E+05, 0.14776100E+05, 0.66145300E+03, 0.14238800E+05, 0.50702500E+04, -.15787900E+03, 0.68975800E+04, -.56964200E+04, 0.58939300E+04, 0.21199600E+05, 0.83762500E+03, 0.69824500E+05, -.33651000E+05, -.46867700E+05, -.35246400E+05, 0.11349100E+05, 0.21292000E+05, -.22641800E+05, 0.11423100E+04, -.27064100E+05, 0.60874700E+05, -.68791400E+05, -.41326100E+04, 0.28636300E+04, 0.15172600E+05, 0.19461300E+04, 0.13380200E+05, 0.16236100E+05, -.12037000E+05, -.14493800E+04, -.98414800E+04, -.66716200E+04, 0.10241400E+05, -.14254300E+05, 0.76915300E+04, 0.21053000E+05, 0.73831600E+04, 0.10936700E+05, 0.47129800E+04, 0.27342000E+04, -.15526600E+04, 0.22793200E+04, 0.34453000E+05, -.19298600E+05, -.10817800E+06, 0.52188900E+05, 0.79369400E+05, 0.54119100E+05, 0.65437900E+04, -.31781400E+04, 0.12985600E+05, -.79617400E+04, 0.31163700E+05, -.38467600E+05, 0.76947000E+05, 0.35893600E+05, -.17557500E+05, -.28731400E+05, -.17926800E+05, -.12257000E+04, -.11469300E+04, 0.19643100E+04, 0.39563500E+03, -.55011900E+04, 0.20943500E+05, -.39553100E+05, -.93473000E+05, 0.44322200E+05, 0.43672800E+05, 0.46872500E+05, 0.14904600E+05, 0.11323100E+05, -.56464100E+03, -.20088900E+05, 0.33488400E+05, -.44712200E+05, 0.92188400E+05, -.14650100E+05, 0.77870300E+04, 0.32547800E+04, 0.72884800E+04, 0.54561100E+04, 0.43686900E+04, -.13885200E+04, -.29294900E+03, -.12914400E+04, -.24044300E+04, 0.62504700E+04, -.40919900E+05, 0.19667200E+05, 0.30024100E+03, 0.20537500E+05, 0.16203700E+05, 0.41854800E+04, 0.22384600E+04, -.44279500E+04, 0.26033600E+05, -.17789800E+05, 0.32192500E+05, 0.22119400E+05, -.10809700E+05, 0.15885900E+05, -.11073000E+05, -.17124700E+05, -.35217700E+05, 0.28938200E+05, 0.12345600E+05, -.94768100E+04, -.52814800E+04, -.40541100E+05, -.45962600E+04, 0.19862700E+04, -.15594000E+05, 0.23007700E+04, 0.87947900E+04, 0.15300000E+05, -.14100100E+05, 0.12290100E+05, 0.20267600E+05, -.88636600E+04, 0.36623900E+05, -.26667400E+05, 0.12476900E+05, 0.38007100E+05, 0.13500600E+05, -.42029500E+04, -.49720000E+04, 0.58829100E+04, -.34141800E+02, 0.16449300E+03, -.16637900E+05, 0.38438900E+05, 0.34998000E+05, -.16703600E+05, -.17669100E+05, -.17837000E+05, -.58788900E+04, -.11790300E+05, 0.32962200E+04, 0.82230600E+04, -.13596000E+05, 0.21723400E+05, -.55238500E+05, -.96896800E+05, 0.48253300E+05, 0.12110500E+05, 0.48836200E+05, 0.38989700E+05, 0.54261900E+05, -.36782900E+05, -.51519700E+05, 0.55588200E+04, 0.18490800E+05, 0.65786200E+05, 0.38954100E+04, -.27428600E+04, 0.23668300E+05, -.18631400E+04, 0.12070200E+05, 0.20815900E+05, -.50307500E+04, 0.90234700E+04, -.51604900E+04, -.17551800E+05, 0.38798800E+05, 0.56792400E+04, -.32445900E+04, -.32295000E+05, -.28390100E+04, 0.11746200E+05, 0.29133300E+05, -.26886700E+05, 0.63798700E+04, 0.13691500E+05, -.30730600E+03, 0.35968700E+05, 0.57194900E+05, -.25341500E+05, -.93178600E+05, -.28871300E+05, -.11412600E+05, -.13376100E+05, -.19342700E+04, -.14989500E+05, -.26025800E+05, 0.28435100E+05, -.79697400E+05, 0.68071500E+05, -.33840700E+05, -.13568500E+05, -.34275600E+05, -.21788100E+05, -.29886600E+05, 0.18758800E+05, 0.30473000E+05, -.36832800E+04, -.82021900E+04, -.44288500E+05, 0.90842500E+03, -.74454500E+03, -.10057700E+05, -.41935200E+03, 0.63281200E+04, 0.44893600E+04, -.65654300E+04, 0.41804100E+04, 0.10916300E+05, -.17921000E+05, 0.22489600E+05, -.15444700E+05, 0.74223000E+04, 0.15898600E+05, 0.77628400E+04, 0.45717800E+04, 0.92900200E+04, -.61965400E+04, 0.29127400E+04, -.47569700E+03, -.14853700E+05, 0.40099500E+05, -.33131500E+05, 0.16265700E+05, 0.30899000E+05, 0.16370200E+05, 0.53051900E+04, 0.19054400E+05, -.13561900E+05, -.11390500E+05, -.72452300E+03, 0.31018100E+05, 0.91875900E+04, 0.10149900E+05, -.18705000E+03, 0.13647900E+04, 0.75158100E+04, -.19214200E+05, 0.16930200E+04, -.18511700E+04, -.89568600E+03, 0.65525100E+04, -.21009500E+05, -.32770000E+04, -.77352400E+04, 0.18043300E+04, 0.73977000E+04, 0.94311200E+04, -.80284500E+04, 0.19177300E+05, -.17477600E+05, -.27088700E+04, -.34147800E+04, 0.15979900E+05, 0.79449500E+04, 0.11783300E+04, -.15151600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.85262100E+00, 0.62421400E-01, -.73669700E-01, 0.46181300E+00, -.36754200E+00, -.49983200E+00, 0.94899000E-01, -.16579500E+00, -.99736700E-01, 0.11424100E+00, 0.43575800E+05, -.28327200E+05, 0.13458900E+05, 0.45032700E+04, 0.14317100E+05, -.97736600E+04, -.16011100E+05, 0.96769800E+04, -.24512100E+04, 0.13258500E+05, -.13325900E+05, 0.51325700E+05, 0.25125900E+05, -.12928200E+05, -.59847500E+04, -.12637700E+05, -.32069600E+04, -.10812700E+04, -.30943800E+04, 0.28227600E+04, -.96856800E+04, -.87949100E+03, 0.12954900E+05, -.36963500E+05, 0.17620100E+05, 0.15358500E+05, 0.18612700E+05, -.10407200E+05, -.16993000E+05, 0.11499600E+05, -.40240500E+04, 0.13818200E+05, -.14062200E+05, 0.66373100E+05, -.12384600E+05, 0.60270600E+04, -.98150700E+02, 0.62381500E+04, -.22977500E+03, -.23923100E+04, 0.27973200E+04, -.21820300E+04, 0.50670200E+04, -.20283000E+04, -.19108900E+05, 0.30705300E+05, -.15637200E+05, -.11388400E+05, -.15447100E+05, -.29984300E+04, -.10178900E+02, -.38702800E+04, 0.44847300E+04, -.10523700E+05, -.10040400E+03, 0.25897000E+05, 0.34278000E+05, -.16088500E+05, -.96523600E+04, -.17152800E+05, 0.14783300E+05, 0.21637400E+05, -.11163000E+05, 0.69703300E+04, -.96431300E+04, 0.17007700E+05, -.56288600E+05, -.88955100E+04, 0.41560600E+04, 0.69054600E+04, 0.44402500E+04, -.59442800E+04, -.70901700E+04, 0.26644900E+04, -.33608600E+04, -.93928500E+03, -.56983700E+04, 0.22674600E+05, 0.26517800E+05, -.12326400E+05, -.61990100E+04, -.13317200E+05, 0.41352400E+04, 0.13305700E+05, -.80965600E+04, 0.14179400E+04, -.13250800E+05, 0.11470600E+05, -.72330000E+05, -.33085900E+04, 0.15206600E+04, 0.12811400E+04, 0.16671700E+04, 0.39924800E+02, -.11812100E+04, 0.64456900E+03, -.14478200E+04, 0.83787000E+03, -.86012100E+03, -.67667700E+04, -.96823600E+04, 0.53480400E+04, 0.15026500E+04, 0.48129700E+04, -.43636800E+04, 0.35775800E+03, 0.96742500E+03, -.81700500E+02, 0.32595700E+04, -.91645800E+02, -.17184900E+05, 0.24288800E+05, -.12167200E+05, -.31498900E+04, -.12139400E+05, 0.37976600E+04, 0.18109700E+04, -.32902100E+04, 0.66117300E+04, -.82086000E+04, 0.57307500E+03, 0.74853400E+04, -.10629400E+05, 0.52668100E+04, 0.95421800E+03, 0.53139200E+04, -.25655900E+04, -.48946200E+03, 0.16273300E+04, -.36040400E+04, 0.38111100E+04, 0.18987300E+02, -.11455100E+05, 0.18161300E+04, -.54339300E+03, 0.84794700E+04, -.97189500E+03, 0.18828500E+05, 0.18907900E+05, -.56940000E+04, -.12230400E+04, -.70605300E+04, 0.15646200E+05, -.33300000E+05, 0.18915400E+05, -.10234400E+05, -.12860200E+05, -.93349000E+04, -.95943600E+04, -.11477100E+05, 0.13188300E+04, 0.44709500E+04, -.10831900E+04, -.93628900E+04, 0.41710100E+05, -.16079600E+05, 0.81973900E+04, 0.32987000E+04, 0.78872600E+04, -.74492400E+04, -.40441900E+04, 0.40448200E+04, -.38708900E+04, 0.45915800E+04, -.25702000E+04, -.23173200E+05, -.35037700E+05, 0.18006500E+05, 0.28928200E+05, 0.17483000E+05, 0.20731900E+05, 0.19714400E+05, -.27401000E+04, -.96470400E+04, -.44534200E+03, 0.16615800E+05, -.48350600E+05, -.26501100E+05, 0.13199300E+05, 0.48790200E+04, 0.13250500E+05, -.35006300E+04, -.17711900E+04, 0.36063300E+04, -.72036600E+04, 0.90058700E+04, -.51180900E+03, -.49393700E+04, 0.94075600E+02, -.92923900E+03, -.39474000E+04, 0.53779400E+02, -.16937700E+05, -.15712100E+05, 0.27858500E+04, -.19943600E+04, -.87702500E+03, -.12906300E+05, 0.42334500E+05, 0.47397600E+04, -.24934400E+04, -.15935500E+04, -.22722100E+04, 0.49752000E+04, 0.32768100E+04, -.20608800E+04, 0.15999200E+04, -.17080200E+04, 0.22557800E+04, 0.17975300E+05, 0.62394800E+04, -.30390400E+04, -.10480300E+04, -.31335500E+04, -.46274800E+04, -.20788700E+04, -.89456800E+01, -.55669000E+03, -.34307100E+04, -.12799200E+04, -.21335700E+05, -.14903400E+05, 0.77001400E+04, 0.22324500E+04, 0.74368300E+04, 0.43366900E+04, 0.62686600E+03, 0.33170400E+04, 0.23401900E+03, 0.80803400E+04, 0.71670900E+03, -.14883900E+05, 0.10060100E+05, -.51774600E+04, -.55835700E+04, -.49552200E+04, 0.12939300E+04, 0.35037600E+03, 0.43920700E+03, 0.30604900E+04, 0.11529400E+04, -.16134300E+03, 0.15276900E+05, -.57076600E+04, -.32725200E+04, 0.14769200E+04, -.48284200E+03, -.32171500E+04, -.12881900E+04, 0.12527200E+04, -.16261600E+04, 0.66933500E+04, 0.19910600E+04, -.29614000E+04, 0.69127600E+04, -.20764400E+04, 0.23038400E+04, -.61032700E+04, 0.77951900E+04, -.34625500E+04, 0.11673900E+05, -.18382400E+04, 0.60094400E+04, -.46290800E+04, -.39245000E+04, 0.84381300E+04, 0.69446100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11538600E+01, -.34704000E-01, -.72680900E-01, -.76791000E+00, 0.48781200E+00, 0.96935500E+00, -.12505900E+00, 0.42416300E+00, 0.29537200E+00, -.16423300E+00, -.34075600E+00, 0.51893200E+05, -.24167300E+05, -.16921900E+05, -.26021300E+05, 0.83859200E+04, 0.11471700E+05, -.10872800E+05, 0.91691700E+04, -.17699800E+05, 0.90088100E+04, -.23166700E+05, -.14670100E+05, 0.83472700E+04, 0.76298100E+04, 0.73750500E+04, 0.26755200E+04, 0.21014100E+04, 0.11646000E+04, -.17692900E+04, 0.47838200E+04, 0.17707400E+04, 0.76565100E+04, 0.45641500E+05, -.21591900E+05, -.17165900E+05, -.22884400E+05, 0.86334800E+04, 0.13553700E+05, -.11210400E+05, 0.61683400E+04, -.18190800E+05, 0.11303100E+05, -.19057200E+05, 0.36362900E+05, -.17032900E+05, -.18237900E+05, -.18201400E+05, -.21485300E+04, 0.73378900E+02, -.49819300E+04, 0.75291600E+04, -.75651900E+04, -.16813400E+03, -.15699400E+05, -.22960900E+05, 0.12297500E+05, 0.76080300E+04, 0.11530900E+05, 0.22604000E+04, 0.16823500E+04, 0.20606900E+04, -.37747300E+04, 0.74729200E+04, 0.20496700E+04, 0.11658000E+05, -.42830000E+05, 0.19378000E+05, 0.12369000E+05, 0.21420700E+05, -.19410600E+05, -.22173200E+05, 0.14950300E+05, -.71496600E+04, 0.19417000E+05, -.17827100E+05, 0.27985900E+05, 0.11004800E+05, -.51594800E+04, -.43258100E+04, -.54997900E+04, 0.14019500E+05, 0.11147300E+05, -.60222100E+04, 0.18493500E+04, -.10914700E+05, 0.10696500E+05, -.15741100E+05, -.33589900E+05, 0.14250500E+05, 0.14545400E+05, 0.16818200E+05, -.12287300E+05, -.16806000E+05, 0.12694800E+05, -.24400900E+04, 0.17264300E+05, -.14401300E+05, 0.20952400E+05, 0.18663300E+05, -.87386100E+04, -.81041700E+04, -.93379000E+04, -.86112800E+03, 0.67959500E+03, -.27978300E+04, 0.34039700E+04, -.40733400E+04, 0.29948100E+03, -.92178800E+04, -.59839500E+04, 0.26070100E+04, 0.51259300E+04, 0.30082600E+04, -.19355800E+04, -.60205800E+04, 0.47110600E+04, -.38787500E+04, 0.13104200E+04, -.34393300E+04, 0.37098000E+04, -.44741200E+05, 0.21846200E+05, 0.14862900E+05, 0.22367500E+05, 0.36609000E+04, 0.58452900E+04, 0.18326600E+04, -.13593600E+05, 0.91047300E+04, 0.70247500E+04, 0.14425600E+05, 0.19845300E+05, -.97468900E+04, -.37808000E+04, -.99218900E+04, -.60429900E+04, -.53475000E+04, 0.50207500E+03, 0.50423200E+04, -.42754500E+04, -.60303300E+04, 0.12845700E+04, -.21357100E+05, 0.94484100E+04, 0.35952100E+04, 0.10711200E+05, -.96668300E+04, -.47741900E+04, 0.24078500E+04, -.82358500E+04, 0.37879600E+04, -.33511800E+04, 0.20608800E+05, 0.26625800E+05, -.13003700E+05, -.95417600E+04, -.13383400E+05, 0.61259500E+04, 0.83442400E+04, -.69092000E+04, 0.63990300E+04, -.57389600E+04, 0.58701400E+04, -.16813800E+05, 0.30850800E+05, -.14862300E+05, -.67109600E+04, -.15352500E+05, -.83788100E+03, -.61767300E+04, 0.62497300E+03, 0.12702400E+05, -.18202900E+04, -.67312100E+04, -.14140200E+05, -.33784100E+05, 0.16165600E+05, 0.69686100E+04, 0.16906900E+05, -.71791900E+04, -.18417200E+04, 0.36295000E+04, -.14619300E+05, 0.74248300E+03, 0.12713200E+04, 0.22388000E+05, 0.47886100E+05, -.23682600E+05, -.13786500E+05, -.23942600E+05, -.53978300E+04, -.58271300E+04, -.25874000E+04, 0.12086200E+05, -.12517300E+05, -.71221600E+04, -.12565300E+05, 0.51819600E+05, -.21595300E+05, -.48425100E+04, -.25966000E+05, 0.33605600E+05, 0.21152700E+05, -.15432800E+05, 0.74791300E+04, -.24862300E+05, 0.18328500E+05, -.56164900E+05, -.10532100E+05, 0.50633100E+04, -.46720000E+03, 0.52231500E+04, -.34214300E+03, 0.27367200E+04, -.80746200E+03, -.54743300E+04, -.13878700E+04, 0.33762800E+04, 0.57620100E+04, 0.95174000E+03, -.45822900E+03, 0.11204300E+04, -.46921700E+03, -.84958000E+03, -.21489800E+04, 0.11344000E+04, 0.18252900E+04, 0.20918000E+04, -.26073400E+04, 0.32583100E+04, -.67779600E+04, 0.31240600E+04, 0.37363200E+03, 0.33981700E+04, -.15516800E+05, -.62856800E+04, 0.34741800E+04, -.66809300E+03, 0.86493300E+04, -.66908300E+04, 0.20826500E+05, 0.12753400E+05, -.69268500E+04, -.10183400E+05, -.64147600E+04, -.79674500E+04, -.74168600E+04, 0.23628500E+04, 0.87324400E+04, 0.36231800E+04, -.80120800E+04, 0.20144300E+04, 0.65863800E+04, 0.51610800E+04, 0.32430200E+03, 0.65955700E+04, -.84556000E+03, 0.43220800E+04, -.56860900E+04, 0.53617200E+03, -.70427900E+04, -.42435200E+04, -.30625200E+03, -.69248600E+04, 0.97977900E+04, -.78787700E+04, 0.53207900E+04, -.51963100E+04, 0.79067100E+04, -.48847700E+04, 0.97094700E+04, -.53741900E+04, 0.66862900E+04, 0.58833700E+04, -.90378900E+04, -.55772600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35244200E+00, 0.13643200E+00, 0.17153600E-02, -.12332000E+00, -.19849200E+00, -.86070000E-01, 0.20107800E-01, 0.11151700E-01, -.49364600E-01, -.51733000E-01, -.17421900E+00, -.17703800E-01, -.45514300E+03, -.59982400E+04, 0.51041100E+01, -.32047300E+04, -.45845200E+04, 0.56743100E+03, -.12115200E+04, 0.15592500E+04, -.35444300E+04, 0.17946700E+04, 0.56818300E+04, -.31724600E+04, -.16083200E+04, -.28429900E+04, -.82608200E+03, 0.25132300E+03, -.92670500E+03, 0.16284700E+04, -.26397400E+04, 0.26384000E+03, -.22187900E+04, 0.30087800E+04, -.19897300E+04, -.24025700E+04, -.14998500E+04, -.23712100E+04, -.36753500E+04, 0.43614900E+03, 0.37719300E+03, 0.13178800E+04, -.30974500E+04, -.49202800E+03, -.13913300E+05, 0.68122900E+04, 0.53096600E+04, 0.69578100E+04, 0.10167300E+04, -.10324300E+04, 0.46348500E+04, -.27110000E+03, 0.38280200E+04, -.87373600E+03, 0.42322900E+04, 0.78956400E+04, -.42343400E+04, 0.14538100E+03, -.39503500E+04, -.10832600E+03, 0.12871400E+04, -.70913900E+03, 0.33064800E+04, -.27601600E+04, 0.76866900E+03, -.47321200E+04, -.16965800E+04, 0.14684500E+04, 0.41709500E+04, 0.84749600E+03, 0.55837400E+04, 0.77839000E+04, -.33574700E+03, 0.15020700E+04, -.87998100E+03, 0.58809800E+04, -.82375100E+03, 0.15970500E+05, -.80875000E+04, -.64163000E+04, -.79853600E+04, -.41362900E+04, -.40619700E+04, -.33730800E+04, 0.48572500E+03, -.38809600E+04, -.36543100E+04, -.66773700E+04, -.14309600E+05, 0.77202000E+04, 0.94802700E+04, 0.71522600E+04, 0.33636000E+04, 0.40008900E+04, 0.15659800E+04, -.44075600E+04, -.12685800E+04, 0.36800900E+04, 0.22945900E+04, -.81277000E+04, 0.39530800E+04, 0.30432900E+04, 0.40640100E+04, 0.54085300E+03, -.11979500E+04, 0.29469500E+04, 0.34188200E+03, 0.24828600E+04, -.82768100E+03, 0.22625300E+04, -.25119200E+04, 0.15543500E+04, -.36288600E+04, 0.12551800E+04, 0.15857600E+04, 0.59495200E+03, -.34673400E+03, -.10456800E+03, 0.14167800E+04, -.10870200E+03, -.23207000E+04, 0.41884100E+05, -.20969000E+05, -.10847600E+05, -.20941900E+05, -.11789500E+04, 0.55331400E+03, -.88532000E+04, 0.70191300E+04, -.92646800E+04, -.54830600E+03, -.15210300E+05, -.13238400E+05, 0.66133400E+04, 0.11830300E+04, 0.66191700E+04, -.29025400E+03, -.85503200E+03, 0.41844800E+04, -.97609200E+03, 0.35742400E+04, -.11993500E+02, 0.52517700E+04, 0.83819900E+04, -.39788300E+04, 0.13534200E+04, -.41930400E+04, 0.40963900E+04, 0.65508300E+04, -.28271400E+04, 0.16756100E+04, -.37929300E+04, 0.52701300E+04, -.33858900E+04, 0.86337700E+03, -.86237000E+03, 0.39605200E+03, -.42834000E+03, -.19165500E+04, -.38895300E+04, 0.56006300E+03, -.44132500E+03, 0.88238900E+02, -.24841600E+04, 0.11486000E+03, -.35415500E+05, 0.17810900E+05, 0.10427300E+05, 0.17702500E+05, -.18156600E+02, -.14058100E+04, 0.71794200E+04, -.89627200E+04, 0.55667000E+04, -.36497700E+03, 0.11867000E+05, 0.14614800E+04, -.44980000E+03, 0.47611600E+04, -.73227800E+03, 0.50657700E+04, 0.80096000E+04, -.16910900E+04, 0.35306000E+04, 0.29052500E+03, 0.56915300E+04, -.32209500E+04, -.31436600E+05, 0.15722100E+05, 0.65726900E+04, 0.15718300E+05, 0.32120600E+02, -.15889000E+04, 0.73372200E+04, -.49726500E+04, 0.79051100E+04, -.19277300E+03, 0.12071300E+05, 0.79628800E+04, -.45144300E+04, -.12390500E+05, -.39785700E+04, -.81622000E+04, -.11122100E+05, 0.11738700E+04, 0.24034900E+04, 0.17301300E+04, -.90732400E+04, -.55769400E+04, 0.17610100E+05, -.88835200E+04, -.67202900E+04, -.88013800E+04, 0.91736700E+03, 0.13349400E+04, -.39130000E+04, 0.49325400E+04, -.26279200E+04, 0.79313100E+03, -.58205900E+04, -.80479900E+04, 0.40878600E+04, 0.41108800E+04, 0.40234900E+04, -.52351100E+03, -.14943300E+04, 0.25998800E+04, -.17032600E+04, 0.11873200E+03, -.68249000E+03, 0.17560300E+04, -.18074200E+05, 0.90981000E+04, 0.64567900E+04, 0.90366200E+04, 0.37434200E+04, 0.33954600E+04, 0.17800200E+04, -.46736900E+04, 0.28275900E+04, 0.32528500E+04, 0.10638200E+05, -.17231900E+04, 0.79326100E+03, 0.21814800E+04, 0.86398900E+03, -.32975500E+03, 0.13221700E+04, 0.14459300E+04, -.11710100E+04, -.80240800E+03, 0.13801700E+04, 0.30573800E+04, -.47104700E+03, -.96346700E+03, -.71492500E+03, -.16950600E+04, -.42063900E+03, -.62634200E+03, 0.76054200E+03, 0.23125800E+03, 0.26343000E+04, 0.13458200E+04, -.19946700E+04, 0.90115000E+03, -.61946900E+02, 0.14451300E+04, 0.12640600E+04, 0.63385600E+03, 0.85251700E+03, -.78747200E+02, -.52272800E+03, 0.38073800E+04, 0.11082500E+04, -.16584100E+04, 0.43571700E+04, 0.76769700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34367800E-01, -.89530900E-01, -.13302200E+00, 0.80432800E+00, 0.49295500E+00, -.73928300E+00, -.10152100E+00, -.62628000E+00, -.84135900E-01, -.92224600E-01, -.31732800E+00, 0.10947000E+00, 0.90360900E+00, 0.17209800E+05, 0.59463600E+02, 0.23989300E+04, 0.23934600E+04, 0.12666100E+04, 0.31190500E+04, -.73688200E+03, 0.13876200E+04, -.23025300E+04, -.22918300E+04, 0.11910800E+04, -.73877500E+04, 0.11165000E+04, 0.21554500E+04, 0.30916500E+02, 0.20501600E+03, -.13611900E+04, 0.16610300E+04, -.14654500E+03, 0.13247800E+04, -.11937200E+05, 0.62018300E+04, 0.80219000E+04, 0.60193200E+04, 0.29789300E+04, 0.45270600E+02, 0.27714600E+04, 0.21448200E+03, 0.25068200E+04, 0.29993200E+02, 0.36938700E+04, 0.16437300E+05, -.83785100E+04, 0.15707100E+04, -.82011600E+04, -.40072300E+04, -.89774000E+03, -.47807700E+04, -.11845500E+04, -.57484900E+04, -.41498300E+03, -.55992800E+04, -.25823900E+04, 0.13443600E+04, -.11392900E+05, 0.12540200E+04, -.86706400E+03, -.30687500E+04, 0.33460700E+03, -.31051200E+04, 0.10517400E+04, -.21990100E+04, 0.30645300E+04, 0.70402100E+04, -.36820600E+04, -.10516500E+05, -.35253300E+04, -.31826300E+04, -.44498200E+04, -.29882500E+04, -.33405700E+04, -.26291000E+04, -.24724700E+04, -.68357100E+03, -.24995800E+05, 0.12585600E+05, 0.58939900E+04, 0.12495100E+05, 0.35656100E+04, 0.22463800E+04, 0.61551700E+04, 0.52625800E+03, 0.87597000E+04, 0.14735400E+04, 0.10378300E+05, 0.92570900E+04, -.46299300E+04, -.16857800E+05, -.46504600E+04, 0.11995400E+04, 0.27154300E+04, -.41399300E+04, 0.23332000E+04, 0.25509100E+04, 0.19289100E+04, 0.16873600E+04, 0.87337900E+04, -.44192300E+04, -.74572700E+03, -.43618800E+04, -.98780100E+03, 0.13106200E+04, -.35020000E+04, -.14726800E+04, -.32635500E+04, 0.10386700E+04, -.24364100E+04, -.19287100E+04, 0.68292900E+03, 0.71432600E+04, 0.95309700E+03, 0.16533400E+04, 0.15332000E+04, -.22411700E+03, -.34639300E+03, -.34684600E+03, 0.22146600E+04, 0.47467600E+04, -.38723900E+05, 0.19628200E+05, -.25242100E+04, 0.19364000E+05, 0.11146800E+04, -.32605500E+04, 0.10321500E+05, -.40343100E+04, 0.95816900E+04, -.19908200E+04, 0.12618800E+05, 0.11637300E+05, -.59316600E+04, 0.57778100E+04, -.58190200E+04, 0.12100500E+04, 0.26919600E+04, -.57003300E+04, -.16316500E+04, -.40263300E+04, 0.19319300E+04, -.35869400E+04, -.72919500E+04, 0.37615100E+04, -.89216300E+04, 0.36210500E+04, -.29169700E+04, -.57752300E+04, 0.21265300E+04, -.21132000E+04, 0.26321300E+04, -.44629600E+04, 0.28662500E+04, 0.93161400E+03, -.18965400E+02, -.39479400E+03, -.41685000E+03, -.55072300E+03, 0.23171300E+04, 0.21535900E+03, 0.11343400E+04, 0.17281400E+03, 0.80582500E+03, -.15792200E+04, 0.24453100E+05, -.12554100E+05, -.40488300E+04, -.12285400E+05, 0.27233100E+04, 0.52453000E+04, -.71941700E+04, 0.66471400E+04, -.30089800E+04, 0.36970000E+04, -.65684800E+04, -.71524600E+04, 0.34433800E+04, -.14003300E+05, 0.35626900E+04, -.70743100E+03, -.87877400E+04, 0.11647200E+04, -.64394500E+04, -.19575300E+03, -.57809300E+04, 0.72229800E+04, 0.26919000E+05, -.13624900E+05, 0.74403900E+04, -.13459600E+05, 0.10648500E+04, 0.43101100E+04, -.86956900E+04, 0.18213700E+04, -.75044700E+04, 0.27822300E+04, -.88389300E+04, -.16748600E+05, 0.77981800E+04, 0.21412600E+05, 0.84142600E+04, 0.71749100E+04, 0.91639500E+04, 0.23117400E+04, -.47810500E+03, 0.30865900E+04, 0.64308100E+04, 0.85934800E+04, -.12627800E+05, 0.64774700E+04, 0.46901600E+04, 0.63511400E+04, -.23111900E+04, -.29699100E+04, 0.36619200E+04, -.40925300E+04, 0.15280900E+04, -.23402800E+04, 0.34565800E+04, 0.27745800E+04, -.15078300E+04, -.49057900E+04, -.13926300E+04, 0.11976700E+04, 0.42366500E+04, -.31477800E+04, 0.17251700E+03, 0.17046100E+04, 0.29812500E+04, 0.16796600E+04, 0.27989600E+05, -.14047000E+05, -.53249200E+04, -.14000800E+05, -.30270000E+04, -.14289700E+04, -.42784800E+04, 0.46175200E+04, -.77602000E+04, -.96487800E+03, -.14922700E+05, 0.38868800E+04, -.17121000E+04, 0.32511000E+03, -.19142400E+04, -.98940400E+03, -.22093600E+04, -.14784500E+04, 0.86660100E+03, -.80913100E+02, -.20487400E+04, -.43608300E+04, 0.36054100E+03, 0.55991800E+03, -.48235900E+03, 0.26911000E+04, 0.19667900E+04, 0.25681600E+04, 0.37836300E+03, 0.19533300E+03, -.16337600E+04, -.89106700E+03, 0.19118200E+04, -.66551600E+03, -.25326400E+04, 0.54677000E+03, -.11110500E+04, -.53404200E+03, -.32334300E+04, 0.10324200E+04, -.22820200E+04, -.28548000E+04, -.30619300E+04, 0.11827600E+04, -.31529700E+04, -.18223900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17004800E+01, -.18681600E+00, 0.21871100E-01, -.15626900E+00, 0.77437000E+00, 0.53687100E+00, -.20213500E+00, 0.21993800E+00, 0.94726500E-01, -.10085100E+00, -.23668300E+00, 0.74458600E-01, -.12832300E+01, -.50565100E+00, 0.46221800E+03, -.67809800E+04, -.83192300E+04, 0.33182300E+04, 0.13098400E+04, 0.26443800E+04, -.70743400E+04, 0.84678900E+03, -.13720800E+05, 0.67475400E+04, -.71992600E+03, 0.66244100E+04, 0.68051500E+04, 0.58915900E+04, -.17993100E+04, -.48742900E+04, -.60799300E+03, 0.51516400E+04, 0.51162600E+04, 0.50440400E+04, -.16036100E+04, -.85406600E+04, -.21289800E+04, -.41641500E+04, -.81947100E+04, 0.14610300E+04, 0.65268500E+03, 0.26990100E+04, -.67641600E+04, 0.85817600E+03, -.10604400E+05, 0.48431300E+04, 0.14264100E+05, 0.54368100E+04, -.92296800E+03, -.80771100E+03, 0.18902300E+04, -.55115500E+04, -.42459200E+04, 0.23237200E+03, 0.16590300E+04, -.67478400E+04, 0.32632700E+04, -.15757900E+04, 0.30754300E+04, 0.52764700E+04, 0.40164500E+04, -.20162900E+04, -.31439100E+04, -.11264700E+04, 0.34994900E+04, 0.33011900E+04, -.18238600E+04, 0.18500000E+03, 0.85075900E+04, 0.87447400E+03, 0.10486100E+05, 0.12563200E+05, -.38504400E+04, -.33564600E+04, -.85285700E+04, 0.10910700E+05, 0.35797700E+03, 0.77377300E+04, -.31816300E+04, -.11440400E+05, -.38897900E+04, -.36105400E+04, -.50559300E+04, 0.72709900E+03, 0.56905900E+04, 0.72361800E+04, -.57436300E+04, -.48824100E+04, -.45149300E+05, 0.22362300E+05, 0.12797800E+05, 0.22414700E+05, 0.17374700E+05, 0.19744000E+05, -.27824600E+04, -.14263900E+05, 0.23312300E+04, 0.18234600E+05, 0.17269200E+05, -.85689100E+04, 0.40819000E+04, 0.57034400E+04, 0.43246400E+04, 0.52659900E+03, 0.56106600E+02, 0.15000000E+04, -.26225500E+04, -.10894400E+04, 0.45153000E+03, 0.15233400E+04, -.97744500E+04, 0.40590700E+04, 0.39830600E+04, 0.47953300E+04, 0.95671100E+04, 0.93250400E+04, -.52769000E+04, -.65199600E+04, 0.39414100E+03, 0.83652400E+04, 0.83042000E+04, 0.32467700E+05, -.15596900E+05, -.25231300E+05, -.16217400E+05, -.29984000E+04, -.53024000E+04, -.34150800E+04, 0.10856100E+05, -.96404300E+03, -.66966500E+04, -.12256100E+05, -.11074800E+05, 0.53532100E+04, 0.10026100E+05, 0.55340200E+04, 0.42781600E+04, 0.50915500E+04, -.48969300E+02, -.41630100E+04, -.44122100E+03, 0.62635100E+04, 0.57287400E+04, 0.37951000E+04, -.17141700E+04, 0.11186900E+04, -.20938000E+04, 0.58673800E+04, 0.63602500E+04, -.24601400E+04, -.79794800E+03, -.68398000E+04, 0.51598200E+04, -.47536300E+04, 0.41314200E+04, -.63989800E+03, -.59231900E+04, -.16661500E+04, -.79979400E+04, -.11139500E+05, 0.48416500E+04, 0.61293100E+04, 0.46930500E+04, -.94102700E+04, -.23206300E+04, -.56246900E+05, 0.27295200E+05, 0.24228700E+05, 0.27668500E+05, 0.85354300E+04, 0.96940700E+04, 0.40518900E+04, -.19024600E+05, 0.20973100E+04, 0.10059300E+05, 0.20800200E+05, -.35667500E+04, 0.13005000E+04, 0.28679500E+04, 0.16836000E+04, 0.12616400E+05, 0.10273500E+05, -.40741400E+04, -.39362100E+04, -.50160000E+04, 0.82691600E+04, -.45997400E+03, -.23797900E+05, 0.11630800E+05, 0.18828300E+05, 0.11897900E+05, 0.32929900E+04, 0.46689400E+04, 0.27148600E+04, -.71732400E+04, 0.15142300E+04, 0.63063200E+04, 0.96825600E+04, -.83991900E+04, 0.30176000E+04, -.75984700E+04, 0.45228100E+04, -.90289600E+04, -.99173400E+04, 0.47287600E+04, 0.17669800E+04, 0.13341500E+05, -.10324100E+05, 0.25658300E+04, 0.33788300E+05, -.16481000E+05, -.11044800E+05, -.16613600E+05, -.46847000E+04, -.52651000E+04, -.31832100E+04, 0.10353300E+05, -.17675300E+04, -.53939800E+04, -.12749500E+05, -.26112100E+05, 0.12797500E+05, 0.65846100E+04, 0.13014900E+05, 0.59402500E+04, 0.69984500E+04, 0.24006400E+03, -.69203900E+04, 0.46960000E+04, 0.72413500E+04, 0.11950500E+05, -.70413100E+04, 0.29125100E+04, 0.11532600E+05, 0.34712200E+04, 0.27676800E+04, 0.41252400E+04, -.79739400E+03, -.55516900E+04, -.82716700E+04, 0.53183200E+04, 0.46787800E+04, 0.41408500E+04, -.14050800E+04, 0.47780800E+04, -.18407100E+04, -.21053100E+04, -.34054900E+03, 0.10621000E+04, -.21289200E+03, -.52182400E+04, 0.53858300E+03, -.36480700E+04, 0.29408800E+03, -.19720900E+04, -.14770500E+04, 0.40263900E+03, -.16092200E+03, -.18046800E+03, 0.16287300E+04, 0.15926300E+04, 0.37529300E+04, 0.29586000E+04, 0.42364300E+03, 0.61604800E+02, -.83877900E+04, 0.70545600E+04, 0.10154000E+04, -.63229900E+02, -.54406700E+04, -.68989700E+03, -.88263000E+04, 0.52659200E+04, -.34415600E+04, -.35013300E+04, 0.50031600E+04, -.11696900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35536900E+01, 0.66996800E+00, -.32701700E+01, -.99779000E+00, -.32599100E+01, -.45202800E+00, 0.78710100E+00, -.57684300E+00, -.82668200E+00, -.96386700E+00, -.55679300E+01, -.88280700E+00, 0.38462300E+01, 0.21371800E+01, 0.30131700E+00, -.38865800E+05, -.52534000E+05, 0.14109200E+05, -.63172600E+03, -.58885700E+04, -.42946000E+05, 0.40741000E+04, 0.11063600E+06, -.54988600E+05, -.30595700E+05, -.55279700E+05, -.18643200E+04, 0.15689300E+04, -.86259600E+04, 0.21823400E+05, -.35433100E+05, -.13736800E+04, -.47520200E+05, -.36219800E+05, 0.13271500E+05, -.44243600E+03, 0.18117300E+05, -.47248700E+05, -.76729500E+05, 0.21829500E+05, -.17603200E+05, -.27497300E+04, -.58486500E+05, 0.36315700E+05, -.14613600E+05, 0.10388200E+05, -.11513400E+05, 0.73103800E+04, -.53784700E+04, -.20900600E+05, 0.41180700E+04, 0.28343600E+04, 0.26625700E+05, -.16368300E+05, 0.47748900E+04, 0.81186900E+05, -.40277900E+05, -.59782600E+05, -.40542600E+05, 0.35735900E+04, -.29270300E+04, -.42964000E+04, 0.15962400E+05, -.24067500E+05, -.28890100E+04, -.34275800E+05, 0.92635600E+05, -.42926000E+05, -.74009300E+04, -.46336100E+05, 0.50756100E+05, 0.78495200E+05, -.39360900E+05, 0.22267200E+05, -.19572200E+05, 0.65651400E+05, -.34903600E+05, -.21169700E+05, 0.78514400E+04, 0.20223600E+05, 0.10582600E+05, -.15535300E+05, -.31357100E+05, 0.19155000E+05, -.36042800E+03, 0.29531200E+04, -.29202900E+05, -.33179800E+04, -.67492000E+04, 0.27040800E+04, 0.75225200E+05, 0.33188200E+04, 0.25011200E+05, 0.46110200E+05, -.95106600E+04, 0.11954000E+05, 0.42372400E+05, 0.33430400E+05, 0.18350800E+04, 0.11309500E+05, -.44990400E+04, 0.37256900E+04, -.56635100E+04, -.16812400E+04, -.43370300E+04, -.28690700E+04, 0.31972500E+04, 0.33595500E+04, -.33985300E+04, -.10704800E+05, 0.62960600E+04, 0.86360500E+03, 0.75003300E+05, -.31253100E+04, -.19686700E+05, -.23752100E+05, 0.90503000E+04, 0.87754500E+04, 0.11058300E+05, -.23580100E+05, 0.17410500E+05, 0.23726500E+06, -.12082000E+06, -.18645900E+06, -.11863700E+06, -.98176500E+04, -.77861900E+04, -.19450900E+05, 0.42170700E+05, -.97174000E+05, -.73794600E+04, -.10486300E+06, -.16136300E+06, 0.80425200E+05, 0.13695200E+06, 0.80684600E+05, 0.70062700E+04, 0.12606100E+05, 0.14268300E+05, -.26798100E+05, 0.62957800E+05, 0.10233100E+05, 0.83799700E+05, 0.11059500E+06, -.56430900E+05, -.53247200E+05, -.55284800E+05, 0.54854400E+05, 0.80637100E+05, -.42189300E+05, 0.11542800E+05, -.55481300E+05, 0.70872200E+05, -.51270400E+05, -.43911600E+05, 0.14115000E+05, -.58747800E+05, 0.21857100E+05, -.16745000E+05, -.20926400E+05, 0.10720300E+05, -.12099200E+05, 0.45996100E+04, -.16472600E+05, 0.25660600E+04, -.14407200E+06, 0.76135400E+05, 0.15691200E+06, 0.72019400E+05, 0.24073200E+04, -.38682200E+04, 0.58084800E+04, -.26692800E+05, 0.74985200E+05, -.35654400E+04, 0.60217900E+05, 0.67110000E+05, -.31074600E+05, 0.22229500E+05, -.33584900E+05, 0.39443000E+05, 0.29130400E+05, -.12316500E+05, 0.14897200E+05, -.49720700E+05, 0.32568400E+05, -.33195500E+05, -.26873100E+06, 0.13424500E+06, 0.22575100E+06, 0.13436900E+06, 0.10074500E+05, 0.94604300E+04, 0.25441600E+05, -.49412700E+05, 0.98912200E+05, 0.94134100E+04, 0.12108200E+06, 0.10243300E+06, -.42511900E+05, 0.39884300E+05, -.51281600E+05, -.32344400E+05, -.57065600E+05, 0.44166600E+04, 0.19713900E+05, -.50434900E+05, -.56786600E+05, -.84194200E+05, 0.72146900E+05, -.38275800E+05, -.99653100E+05, -.36026200E+05, -.90259100E+03, 0.26907500E+04, -.98265600E+03, 0.15305000E+05, -.35223200E+05, 0.27833400E+04, -.28720400E+05, -.62764300E+05, 0.32101100E+05, 0.64447500E+05, 0.31380200E+05, -.33057700E+04, 0.33186000E+04, 0.74459700E+04, -.10154100E+05, 0.38624600E+05, -.60595400E+03, 0.35485900E+05, -.49257000E+05, 0.27176500E+05, -.76856800E+04, 0.24641700E+05, 0.19318900E+03, 0.10478400E+05, 0.14393500E+03, -.14776500E+05, 0.20662100E+05, 0.14014500E+05, 0.45505300E+05, -.37395700E+05, 0.14494100E+05, -.23475700E+05, 0.18683700E+05, 0.10324700E+05, 0.17355400E+05, -.29631300E+04, 0.59112800E+04, 0.30878300E+05, 0.15238200E+05, 0.25783300E+05, -.13056400E+05, -.11421900E+05, -.86108000E+04, -.13450100E+05, -.22110500E+04, -.72051400E+04, 0.11899100E+05, 0.19086700E+04, 0.24355800E+05, 0.92821500E+04, 0.69804800E+04, 0.80297600E+04, 0.13002200E+04, 0.23630400E+04, 0.74560300E+04, 0.87934800E+04, -.51187600E+04, 0.30480800E+04, -.14423600E+04, 0.29611100E+05, -.21764500E+05, -.74063500E+04, 0.29884800E+05, 0.82876900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14014800E+01, -.70077400E+00, -.13690200E+00, 0.28012100E+00, 0.14906300E+01, -.29516800E+00, -.10677600E+00, 0.29876000E+00, 0.13997100E+00, -.18418600E-01, 0.25570900E-02, 0.80828400E+00, 0.25755400E+01, 0.20536000E+01, 0.94410300E-01, -.12554000E+00, 0.90375400E+04, -.72770000E+04, -.10606300E+05, -.66168600E+04, 0.85787200E+04, 0.29970600E+04, 0.16001400E+05, -.80162300E+04, 0.14384600E+05, -.80028800E+04, -.81745500E+04, -.71289700E+04, 0.56248700E+04, 0.67276900E+04, -.29166900E+04, -.58938700E+04, -.81493900E+04, 0.44910300E+04, -.21242500E+04, 0.49373100E+03, -.22462000E+04, -.47746700E+04, -.11046400E+04, -.12968800E+04, -.31777600E+04, -.67178500E+04, 0.44418500E+03, -.37321800E+03, -.44564700E+05, 0.21804200E+05, -.21974400E+04, 0.22283300E+05, 0.90520400E+04, -.26812900E+03, 0.81099400E+04, 0.87336700E+04, 0.24243400E+05, -.22552900E+04, 0.16769900E+05, -.22873700E+05, 0.11404400E+05, 0.13803700E+05, 0.11433800E+05, -.26053100E+04, -.11471600E+05, 0.16592200E+05, 0.11066500E+05, 0.12183000E+05, -.95525900E+04, 0.52498200E+04, -.20731600E+05, 0.10467900E+05, 0.21321000E+04, 0.10367200E+05, 0.38818900E+04, -.10575400E+05, 0.10068000E+05, 0.15863400E+05, 0.16426500E+05, -.10509200E+05, -.46356300E+04, 0.26564000E+03, -.47451400E+03, 0.13683700E+05, -.13312100E+03, -.73214100E+04, 0.58361200E+04, -.43993000E+04, -.15154800E+05, -.72471000E+04, 0.66200800E+04, 0.16681300E+05, 0.22383900E+05, -.10888400E+05, 0.10802900E+05, -.11188800E+05, -.79984500E+04, -.10543300E+05, 0.53462200E+04, 0.19096400E+05, 0.11490400E+05, -.11726500E+05, -.19426900E+05, -.10925300E+05, 0.53208800E+04, 0.38475400E+04, 0.54635500E+04, 0.25106500E+04, -.49192800E+03, 0.33224200E+04, 0.62814500E+04, 0.83097900E+04, -.18398700E+04, 0.31016800E+04, -.11824600E+05, 0.55436700E+04, 0.25974200E+05, 0.59112600E+04, -.63404600E+04, -.92170700E+04, 0.17519800E+05, 0.19769500E+05, 0.15803000E+05, -.11469500E+05, -.29903100E+04, 0.16981900E+05, -.80181400E+04, -.10530100E+05, -.84908600E+04, -.35952200E+04, -.86324600E+04, 0.38084700E+04, -.62148400E+04, -.18568400E+05, -.45997800E+04, 0.31821900E+02, -.23509400E+05, 0.11512600E+05, 0.13612400E+05, 0.11754600E+05, 0.21422600E+04, 0.56382200E+04, -.29464000E+04, -.17649400E+04, 0.12959300E+05, 0.27497700E+04, 0.37759600E+04, -.16904500E+05, 0.87737700E+04, -.52826000E+03, 0.84517000E+04, 0.18871000E+03, -.14414900E+05, 0.95534300E+04, 0.65850300E+04, 0.10867200E+05, -.11506600E+05, 0.20348800E+03, 0.99877400E+04, -.44323400E+04, -.11232300E+05, -.49891100E+04, 0.40892200E+04, 0.73516700E+04, -.82885600E+04, -.10952200E+05, -.12320700E+05, 0.67270100E+04, 0.11461200E+04, 0.28932200E+05, -.15116700E+05, 0.10490500E+05, -.14465000E+05, -.31740600E+04, 0.53566700E+04, -.96766700E+04, 0.13107300E+05, 0.62120100E+04, 0.20548300E+04, -.15484800E+05, -.14656500E+05, 0.72255600E+04, 0.11530700E+05, 0.73300000E+04, -.13281900E+05, -.33708800E+05, 0.27057100E+05, 0.25398100E+05, 0.19601700E+05, -.28297900E+05, -.91326200E+04, -.28250400E+05, 0.13766100E+05, 0.15879100E+05, 0.14125100E+05, 0.20529300E+04, 0.96513700E+04, -.62672600E+04, -.38604500E+04, 0.17199700E+05, 0.57363700E+04, 0.57922300E+04, 0.11871700E+05, -.73228300E+04, 0.26655200E+05, -.59327300E+04, -.10683100E+05, 0.19874400E+05, -.63336800E+04, -.13920100E+05, -.12777900E+05, 0.16759900E+05, 0.21840800E+05, -.22067900E+05, 0.11401900E+05, -.26372500E+04, 0.11031400E+05, 0.10643700E+04, -.38355700E+04, 0.67012300E+04, -.80821300E+04, -.81650400E+03, -.20749700E+04, 0.10329800E+05, 0.39005300E+04, -.21612400E+04, 0.11825600E+05, -.19501000E+04, -.24610700E+03, 0.34854600E+03, 0.12883100E+04, 0.81765300E+04, 0.65236800E+04, -.22005800E+04, -.65575700E+04, 0.23429500E+05, -.11408200E+05, -.21435300E+05, -.11715100E+05, 0.76354700E+04, -.65995800E+04, -.33925300E+04, 0.97244200E+04, -.27881500E+04, -.72021900E+04, -.29061400E+05, 0.12102400E+04, -.22542300E+03, -.20911600E+05, -.60446100E+03, 0.57336200E+04, 0.10892000E+05, -.18533000E+05, -.16176100E+05, -.50126100E+04, 0.11532900E+05, 0.19851900E+04, 0.27040500E+04, -.93180900E+03, 0.25974000E+04, -.58186600E+04, -.23452800E+04, -.43517000E+04, 0.61658300E+03, -.11733700E+04, -.34358500E+03, -.38525100E+04, -.85642800E+03, -.88315500E+03, 0.34397100E+04, -.71589500E+04, -.12372300E+04, -.19557500E+04, -.24707200E+03, 0.25164700E+03, 0.53346900E+04, -.25563200E+04, -.42737200E+04, 0.37927900E+04, -.20595200E+04, -.19643700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.42113200E+00, 0.24418700E+00, -.19676700E+00, 0.21451500E+00, 0.15128000E+00, -.35677500E+00, 0.13716400E-01, 0.65912200E-02, -.10142300E+00, -.21647900E+00, -.39626300E+00, -.45405200E-02, 0.13901500E+01, 0.18886300E+00, 0.20106600E-01, -.17580900E-01, 0.23204900E+00, 0.25227500E+04, 0.47673600E+04, 0.52766100E+03, -.13573700E+03, 0.34087800E+03, -.88655500E+04, 0.46282500E+04, -.22711200E+04, 0.44344800E+04, 0.24701100E+04, -.52040300E+03, 0.64271600E+03, -.22315200E+04, 0.35974100E+04, -.64414100E+03, 0.52109600E+04, -.50789400E+04, 0.19006200E+04, -.32367700E+04, 0.25398500E+04, 0.29148000E+04, 0.58232700E+04, 0.29894600E+03, 0.11374600E+04, -.14400300E+04, 0.49589700E+04, 0.19625200E+04, 0.33146800E+05, -.16143600E+05, -.88017000E+04, -.16573500E+05, -.26669300E+04, 0.36790800E+04, -.98060800E+04, -.90039300E+03, -.11825300E+05, 0.33779700E+04, -.13740200E+05, -.31755900E+04, 0.17922400E+04, -.24842500E+04, 0.15900900E+04, 0.11622000E+04, -.40010000E+03, -.21369500E+04, -.55983900E+04, 0.36995600E+03, -.15766800E+03, 0.39682700E+04, 0.16277400E+05, -.76739000E+04, 0.63012300E+03, -.81395900E+04, -.46549500E+04, -.43755300E+04, -.45433700E+04, -.44063700E+04, -.28025900E+04, -.29561800E+04, 0.95087900E+02, -.21051700E+05, 0.10113100E+05, 0.49988900E+04, 0.10525800E+05, 0.86457700E+04, 0.92560900E+04, 0.25646400E+04, 0.29230400E+03, 0.19469500E+04, 0.76378700E+04, 0.53639400E+03, 0.11133400E+05, -.55025300E+04, -.76952000E+04, -.55691600E+04, -.14793500E+04, -.23681400E+04, -.20811300E+04, 0.47060100E+04, 0.32512200E+04, -.25591500E+04, 0.32789100E+04, 0.14370000E+05, -.70148400E+04, -.56771400E+04, -.71854600E+04, -.10516600E+04, 0.20963700E+04, -.50964000E+04, -.19601700E+04, -.54626900E+04, 0.18175700E+04, -.59317800E+04, 0.30056600E+04, -.88268800E+03, 0.32932400E+04, -.15018600E+04, 0.11331500E+04, 0.49513700E+04, -.13292500E+04, -.45409000E+03, -.49706700E+03, 0.51846100E+04, 0.17603100E+04, -.64710300E+05, 0.31870600E+05, 0.21890000E+05, 0.32355000E+05, 0.31228100E+04, -.78264900E+03, 0.12928600E+05, -.12359700E+05, 0.14452100E+05, 0.53163400E+03, 0.18484600E+05, 0.30996800E+05, -.15364300E+05, -.10892000E+05, -.15498300E+05, -.21597000E+04, 0.82636600E+03, -.80008900E+04, 0.29561400E+04, -.82465200E+04, -.43821700E+03, -.18299100E+04, -.52790400E+04, 0.24691700E+04, 0.33808500E+04, 0.26400700E+04, -.21672800E+04, -.21126800E+04, -.10380400E+04, -.63807700E+04, -.19433600E+04, -.15944500E+04, 0.89408100E+04, -.83501500E+04, 0.31093700E+04, -.29496800E+04, 0.41708300E+04, -.37752200E+04, -.57722400E+04, 0.50758200E+04, 0.67729400E+03, 0.59507400E+04, -.52613400E+04, 0.27558900E+03, 0.28555600E+05, -.13616000E+05, -.13772000E+05, -.14278500E+05, 0.23563000E+04, 0.36059500E+04, -.54885000E+04, 0.14071200E+05, -.19438100E+04, 0.22334300E+04, -.11235500E+05, 0.80198000E+04, -.36585800E+04, -.15876700E+03, -.40112400E+04, 0.64242100E+04, 0.11252900E+05, -.10341400E+05, -.13006500E+05, -.13395900E+05, 0.10077900E+05, 0.45816200E+04, 0.59443000E+05, -.29516800E+05, -.20193700E+05, -.29721400E+05, -.23587800E+04, 0.23701200E+04, -.12557100E+05, 0.10317100E+05, -.15183200E+05, 0.28271500E+03, -.14043700E+05, -.42703300E+05, 0.22380200E+05, 0.91629200E+04, 0.21348800E+05, 0.12075300E+05, 0.23855300E+04, 0.85684900E+04, -.29293000E+04, 0.10160800E+05, 0.24100400E+04, -.43498800E+04, -.16243000E+05, 0.77657900E+04, 0.10047600E+05, 0.81235500E+04, -.19908200E+04, -.20700300E+04, 0.32696100E+04, -.75446700E+04, 0.12697200E+04, -.14685200E+04, 0.71272000E+04, 0.12914400E+05, -.62728500E+04, -.98200700E+04, -.64573200E+04, -.69087600E+03, 0.17601900E+04, -.37405700E+04, 0.34887400E+04, -.78295600E+03, 0.92718500E+03, 0.62251800E+02, 0.29076200E+05, -.14147500E+05, -.81854100E+04, -.14537600E+05, -.87775700E+04, -.24087400E+04, -.20641900E+04, 0.95692600E+04, -.35103700E+04, -.20797700E+04, -.15414800E+04, 0.11978300E+05, -.65159000E+04, -.27894700E+04, -.59897300E+04, -.24276500E+04, -.51460700E+04, -.15149600E+04, 0.36183200E+04, -.39159100E+03, -.52823300E+04, -.83097100E+03, -.89578800E+03, 0.71213900E+03, 0.94957600E+03, 0.25201900E+04, -.55768700E+02, 0.55003100E+03, -.46097400E+03, 0.63764400E+03, -.32099200E+04, -.72651800E+03, 0.42024900E+04, 0.75033300E+03, -.19406700E+04, -.67632900E+03, -.10488200E+04, 0.22913300E+03, -.34490800E+04, -.10729200E+04, -.78093300E+03, -.39560000E+04, -.24089900E+04, 0.14660300E+04, -.46576800E+04, 0.13505800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25590800E+01, 0.36080400E+00, 0.22324000E+00, 0.40242600E+00, -.23387100E+01, 0.30237600E+00, 0.55241100E+00, -.39785600E+00, -.39724300E+00, 0.27418300E+00, 0.76282200E+00, 0.27560200E+00, -.26556600E+00, 0.24756100E-01, -.42301300E+00, -.59966600E-01, -.72863600E+00, 0.35855600E+00, 0.58277000E+04, -.25161100E+04, -.15015600E+04, -.14761100E+04, -.33184300E+05, 0.16411600E+05, 0.23210500E+05, 0.16585600E+05, 0.29109800E+04, -.22205400E+04, 0.12529200E+05, 0.51958500E+04, 0.15500200E+05, -.30222100E+04, 0.64871300E+04, 0.14947400E+05, -.72893300E+04, -.14261800E+05, -.74745600E+04, -.29695900E+04, -.54562600E+04, 0.32965400E+04, 0.14014000E+05, -.17526300E+04, -.32175200E+04, -.11846600E+05, -.21583100E+05, 0.10414200E+05, 0.35761100E+04, 0.10789400E+05, 0.40880100E+04, 0.61859900E+04, 0.27207300E+04, -.63626300E+03, 0.69830900E+04, 0.64421300E+04, 0.76729000E+04, -.61825700E+05, 0.30692400E+05, 0.27544100E+05, 0.30904400E+05, 0.61758800E+04, -.17006600E+04, 0.21786900E+05, 0.88975500E+04, 0.27053300E+05, -.60319900E+03, 0.15571900E+05, 0.20365800E+04, -.10256900E+04, 0.32200400E+04, -.10156900E+04, 0.51408200E+04, 0.14750400E+05, -.59765800E+04, -.53143400E+04, -.11861200E+05, 0.16362200E+05, -.19628900E+05, 0.30157100E+05, -.15198300E+05, -.10917400E+05, -.15077500E+05, -.67658000E+04, -.97143100E+04, -.19243300E+04, 0.39344000E+04, 0.43941800E+04, -.11580800E+05, 0.15329200E+05, -.78056300E+05, 0.39167000E+05, 0.55077100E+05, 0.39037600E+05, 0.11700900E+05, 0.37319100E+04, 0.18230200E+05, 0.23048800E+04, 0.24971200E+05, 0.35638600E+04, 0.12246300E+05, -.11572500E+05, 0.56328100E+04, 0.40613900E+04, 0.57871100E+04, 0.13094300E+04, 0.38321300E+04, 0.20775200E+04, 0.33857600E+04, 0.41556200E+04, 0.28713400E+04, 0.51233600E+04, -.11290500E+05, 0.54658200E+04, 0.36066000E+05, 0.56411000E+04, 0.92040100E+04, 0.10826200E+05, 0.18628000E+05, 0.45106400E+05, 0.59175100E+04, 0.98760300E+04, -.13152200E+05, 0.79643600E+05, -.39730700E+05, -.56453800E+05, -.39820900E+05, -.15131200E+05, -.53295100E+04, -.20120200E+05, -.58722000E+04, -.26335500E+05, -.27015800E+04, -.85304100E+04, -.60937400E+05, 0.30463200E+05, 0.40139100E+05, 0.30468100E+05, 0.90181300E+04, -.54477400E+03, 0.45301200E+04, -.16532700E+05, 0.15036600E+05, 0.26189300E+03, 0.84159400E+04, -.42383200E+04, 0.22081800E+04, -.65993600E+04, 0.21167400E+04, -.58269800E+04, -.64084800E+04, -.58529100E+03, -.12689100E+05, 0.37731900E+04, -.20213700E+04, -.49573100E+04, 0.16784700E+05, -.80323500E+04, -.28684800E+05, -.83744100E+04, 0.12804700E+04, 0.12398600E+05, -.20883300E+05, -.20637300E+05, -.17999200E+05, 0.96440600E+04, 0.10715400E+05, -.54666400E+05, 0.27125700E+05, 0.53590100E+05, 0.27335900E+05, 0.15133900E+05, 0.76147800E+04, 0.19202600E+05, 0.18843400E+05, 0.21335900E+05, 0.38141900E+04, 0.69308700E+04, 0.36731100E+04, -.19249300E+04, 0.91329600E+04, -.18315900E+04, -.14809600E+05, -.24784600E+05, 0.23811600E+05, 0.31504400E+05, 0.16560700E+05, -.17240500E+05, -.18692700E+05, -.80429100E+05, 0.40201000E+05, 0.53521400E+05, 0.40214000E+05, 0.11161600E+05, 0.70545400E+03, 0.90262700E+04, -.16788700E+05, 0.21627200E+05, 0.41690600E+03, 0.15125300E+05, 0.15155100E+05, -.82934400E+04, 0.69002100E+04, -.75657200E+04, -.17638900E+04, -.52876700E+04, 0.29692500E+05, 0.86430700E+05, 0.21247900E+05, -.17574400E+05, 0.31790400E+05, 0.41091500E+05, -.20440400E+05, -.32070400E+05, -.20554000E+05, -.88428300E+04, -.46147600E+04, -.12156000E+05, -.11436800E+05, -.14223600E+05, -.22582700E+04, -.11892300E+05, -.43625100E+05, 0.21758100E+05, 0.30368900E+05, 0.21812800E+05, 0.79676600E+04, 0.27446300E+04, 0.10210900E+05, 0.95044400E+03, 0.16793800E+05, 0.10949400E+04, 0.71677900E+04, 0.22524200E+04, -.10692400E+04, 0.33884100E+04, -.11289800E+04, 0.19085800E+04, 0.58173400E+04, -.19898000E+05, -.46629600E+05, -.21206200E+05, 0.10260700E+05, -.29095600E+05, -.72641200E+04, 0.38933900E+04, -.79059300E+04, 0.36346700E+04, 0.52110200E+04, 0.35732100E+04, -.20577500E+05, -.39397400E+05, -.13736800E+05, 0.54329200E+04, -.42956500E+04, 0.29840000E+04, 0.82929500E+03, -.40746900E+03, 0.16102200E+04, -.65760100E+03, -.16270400E+04, -.35854800E+04, 0.17214100E+04, 0.58778800E+04, 0.19004000E+04, -.12876200E+04, 0.27903800E+04, -.15438500E+03, 0.33336200E+04, -.83696400E+03, -.18115500E+04, -.22506900E+04, 0.44895200E+02, -.16667700E+04, 0.13937900E+04, -.28281000E+04, -.19850400E+04, 0.46544200E+04, 0.80396900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14131600E+01, -.73139500E-01, -.48082100E-01, -.43843400E+00, 0.18206900E+00, 0.99968000E-01, -.63689400E-01, -.21641000E+00, 0.21931700E+00, -.28614200E+00, -.17208400E+00, -.12211900E-01, -.59420500E+00, -.84978700E+00, -.23756800E-02, -.23168300E-01, -.51641100E-01, -.18419000E+00, -.24813300E+00, -.54248800E+04, 0.29542900E+02, -.15902300E+03, 0.78406200E+04, -.39682200E+04, -.30636700E+04, -.39217200E+04, -.39397600E+03, -.39218000E+04, 0.36402300E+04, 0.49604200E+04, -.20942300E+04, -.36207800E+04, -.38050400E+04, 0.25049100E+04, -.13295900E+04, -.44341700E+04, -.12523900E+04, 0.66794600E+03, 0.14371700E+04, -.20237800E+04, -.32920100E+04, -.79995900E+04, 0.19162100E+04, -.24453600E+03, 0.12146000E+05, -.61292300E+04, -.70656800E+04, -.60744400E+04, -.12692400E+03, 0.12124000E+04, -.38447200E+04, 0.47056300E+04, 0.16731900E+04, 0.13685000E+04, -.55763200E+04, 0.81686000E+03, -.46168500E+03, -.27866100E+04, -.41006500E+03, 0.57347600E+03, -.31940000E+04, 0.44857200E+04, 0.37855700E+04, 0.32022600E+01, -.23536300E+04, -.19216000E+04, -.52996400E+04, 0.27360700E+04, 0.60028800E+04, 0.26500500E+04, 0.25252200E+04, 0.53772900E+04, -.34083500E+04, -.79406900E+03, 0.68474700E+04, 0.52010500E+04, 0.22322400E+04, 0.51415200E+04, -.26828800E+04, -.20598200E+04, -.25701600E+04, -.39860200E+03, 0.33270400E+03, 0.71427100E+03, -.10232000E+04, -.54143800E+04, -.54059000E+03, -.14080700E+04, 0.20074700E+04, -.10538900E+04, 0.18792600E+04, -.10017600E+04, -.24487300E+04, -.53673900E+04, 0.55400400E+04, 0.16254300E+05, 0.25760300E+05, -.58293700E+04, -.84795100E+03, 0.49509600E+04, -.24780700E+04, -.19140700E+04, -.24757000E+04, -.16724800E+02, 0.53703800E+03, -.11352800E+04, 0.26628700E+04, 0.70417700E+02, 0.43598000E+03, -.27778400E+04, -.11541000E+05, 0.56478400E+04, 0.12886400E+05, 0.57694300E+04, 0.33216100E+03, 0.52054200E+04, 0.40550000E+04, 0.48604400E+04, 0.11783900E+05, 0.35694800E+04, 0.51391200E+04, 0.85636900E+04, -.39597700E+04, -.70886700E+04, -.42815000E+04, -.10733100E+04, -.19069600E+04, -.13466300E+04, -.15910800E+05, -.24596700E+05, -.42974900E+03, -.36649400E+04, -.30370600E+05, 0.14927100E+05, 0.16275400E+05, 0.15185100E+05, -.17014700E+03, 0.17378500E+04, 0.86789000E+03, -.25578700E+04, 0.18496800E+05, -.17984400E+03, 0.16061800E+05, -.80472000E+03, 0.51709600E+03, -.13910800E+04, 0.40170300E+03, 0.17317600E+04, 0.39586300E+03, -.21635600E+04, -.48852100E+04, -.27711900E+04, 0.14009800E+04, 0.30207500E+04, 0.59998200E+04, -.29562200E+04, -.83879500E+04, -.29953800E+04, -.15569000E+04, -.28104900E+04, -.11973900E+04, -.49190700E+04, -.10503900E+05, -.19505100E+04, -.37815400E+04, 0.31365600E+04, -.18421400E+04, 0.11608900E+04, -.15678000E+04, 0.24382200E+04, 0.23859900E+04, -.64495200E+03, 0.19242400E+05, 0.20720600E+05, 0.11640700E+04, -.18460200E+04, -.26953600E+04, 0.13493400E+04, 0.41022000E+04, 0.13486700E+04, 0.37091400E+04, 0.24368300E+04, 0.79748300E+03, -.49273300E+03, -.53982500E+03, 0.31379500E+04, 0.23750100E+03, -.29108600E+05, 0.14202500E+05, 0.17435200E+05, 0.14554100E+05, 0.81858400E+03, 0.37545800E+04, 0.14861600E+03, 0.27987800E+04, 0.23783200E+05, 0.13749100E+04, 0.15181200E+05, -.67246400E+04, 0.32046600E+04, 0.12392800E+04, 0.33653100E+04, 0.14122500E+04, -.12362200E+04, 0.11001400E+05, 0.13220700E+05, -.58262800E+04, -.31619200E+04, -.20890300E+04, 0.71602200E+03, -.20364900E+03, -.13925900E+04, -.35988600E+03, -.18801100E+04, -.15811900E+04, 0.21491200E+03, -.10340000E+05, -.10617900E+05, -.85122400E+03, 0.17425000E+03, 0.91406400E+03, -.60302300E+03, 0.46665900E+03, -.45702900E+03, -.20916600E+04, -.20214700E+04, 0.24651600E+04, 0.84538700E+04, 0.12723600E+05, -.30539200E+04, 0.93955000E+03, 0.15706400E+05, -.77393300E+04, -.53227200E+04, -.78541100E+04, -.10517500E+04, 0.33316900E+03, -.77856000E+04, -.47771300E+04, -.20431900E+04, 0.16853700E+04, -.54565800E+04, 0.35146200E+04, -.17617800E+04, -.38107700E+04, -.17566300E+04, 0.47265000E+03, -.50844200E+03, -.69770900E+04, -.26489200E+04, 0.19578500E+04, -.23467500E+03, -.34031800E+03, 0.50329500E+03, 0.40028400E+03, 0.12627600E+03, -.17536800E+03, -.87182200E+03, -.20765200E+03, -.40921900E+03, 0.96454400E+03, 0.26666200E+04, -.22744200E+04, 0.15780200E+04, 0.12609700E+04, 0.39702900E+04, -.73817200E+04, 0.42237800E+03, -.86791000E+02, -.20059800E+04, -.92805900E+03, 0.70041500E+04, -.40124800E+03, -.25664700E+04, 0.62883800E+04, 0.15890500E+04, 0.11935200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18914300E+00, -.11564300E+00, 0.61811300E-01, 0.19529800E+00, -.45589300E-01, 0.33765100E+00, -.27946100E-01, -.76254700E-02, 0.50383300E-01, -.60728500E-01, 0.24903200E+00, 0.35384300E+00, -.44799600E+00, -.77780900E-01, -.20262500E+00, 0.63308400E-01, 0.11787800E+00, 0.34174800E+00, -.22496400E-01, -.36349400E+00, -.75951200E+03, 0.16715700E+04, -.11632500E+05, 0.55800300E+04, 0.43624800E+03, 0.58106800E+04, 0.23062400E+04, 0.56554500E+03, 0.21162200E+04, -.10031800E+04, 0.10510400E+04, 0.47762000E+03, 0.52031100E+04, 0.11975300E+05, -.47930400E+04, -.71588400E+04, -.59881000E+04, 0.18129100E+04, 0.21474400E+04, -.32266500E+04, 0.62541800E+03, -.54925600E+03, 0.14732300E+04, -.59791900E+04, -.29956700E+05, 0.14260700E+05, 0.19040100E+05, 0.14975400E+05, 0.34153900E+04, 0.35737000E+04, 0.33704900E+04, -.72334500E+04, 0.23389000E+04, 0.43336100E+04, 0.88189400E+04, -.77925600E+04, 0.36626900E+04, 0.50424600E+04, 0.38893000E+04, 0.19945500E+04, 0.95688200E+03, 0.20060400E+04, 0.33330900E+03, 0.73661800E+03, 0.10629900E+04, 0.17838700E+04, -.16678500E+05, 0.74421700E+04, 0.69889000E+04, 0.83410900E+04, 0.51850300E+04, 0.10316000E+05, -.44139900E+04, -.83697200E+04, -.55233100E+04, 0.11201500E+05, 0.39663200E+04, 0.16150500E+05, -.72779000E+04, -.10804500E+05, -.80739500E+04, -.80277400E+04, -.12388400E+05, 0.34201000E+04, 0.63693800E+04, 0.85416700E+04, -.14031300E+05, -.22230300E+04, -.54129200E+05, 0.26883300E+05, 0.18520800E+05, 0.27072600E+05, 0.13242200E+05, 0.82565800E+04, 0.35460500E+04, -.10088100E+05, 0.99579300E+04, 0.90100400E+04, 0.10365100E+05, -.20780000E+05, 0.10120800E+05, 0.87872500E+04, 0.10390300E+05, 0.19403500E+04, 0.10040300E+04, 0.36666000E+04, -.24682600E+04, 0.29921300E+04, 0.14408200E+04, 0.71936100E+04, -.77764200E+04, 0.26770500E+04, -.14110800E+04, 0.38844300E+04, 0.86741800E+04, 0.10573700E+05, -.58579200E+04, -.27079500E+04, 0.26862600E+04, 0.90075500E+04, -.29352700E+04, 0.88673800E+05, -.43310400E+05, -.33432100E+05, -.44336000E+05, -.11956000E+05, -.59949800E+04, -.14076700E+05, 0.91401100E+04, -.25132200E+05, -.69841000E+04, -.23561300E+05, -.34859200E+05, 0.17084300E+05, 0.99461600E+04, 0.17429000E+05, 0.79106000E+04, 0.58747200E+04, 0.26312100E+04, -.40116100E+04, 0.10380500E+05, 0.68360800E+04, 0.74289300E+04, -.59005600E+04, 0.32987900E+04, 0.19288900E+04, 0.29480600E+04, -.22874700E+04, -.16749100E+04, 0.72716700E+03, -.38194900E+04, -.12062700E+04, 0.20643400E+03, 0.17762600E+04, 0.67388200E+04, -.13458800E+04, 0.19111000E+04, -.33533500E+04, -.19869300E+04, -.37147700E+04, 0.30863900E+03, 0.35965700E+03, -.44069900E+04, -.31662900E+04, 0.13892600E+04, -.95140500E+05, 0.46249600E+05, 0.33718700E+05, 0.47572400E+05, 0.16066300E+05, 0.10191500E+05, 0.10363800E+05, -.18356900E+05, 0.18237100E+05, 0.99200800E+04, 0.27975800E+05, -.56122300E+04, 0.21422900E+04, -.18549500E+04, 0.28102700E+04, -.38476500E+03, 0.85203900E+03, 0.99074100E+03, 0.21414500E+04, 0.55572500E+04, 0.13285600E+04, -.14148100E+04, -.75246200E+05, 0.37114000E+05, 0.24109800E+05, 0.37622500E+05, 0.10373900E+05, 0.48638800E+04, 0.10715000E+05, -.81532300E+04, 0.23558300E+05, 0.60428200E+04, 0.20417500E+05, -.29967300E+05, 0.13056500E+05, -.27901600E+04, 0.14994200E+05, -.13809100E+05, -.22672500E+05, 0.22574500E+05, 0.18648800E+05, 0.26290800E+05, -.25538700E+05, 0.21510100E+05, 0.54505300E+05, -.26558300E+05, -.18603400E+05, -.27259800E+05, -.83036500E+04, -.54793700E+04, -.64400500E+04, 0.94469500E+04, -.95720300E+04, -.50015800E+04, -.16982300E+05, -.24203100E+05, 0.11696500E+05, 0.83394900E+04, 0.12101700E+05, 0.58933800E+04, 0.26589800E+04, 0.32850500E+04, -.26499900E+04, 0.68505600E+04, 0.32804300E+04, 0.37647800E+04, 0.13712200E+05, -.75712500E+04, 0.17445700E+04, -.68588200E+04, 0.98625100E+04, 0.15937400E+05, -.14927100E+05, -.16026600E+05, -.21124900E+05, 0.17903800E+05, -.83514100E+04, -.11328900E+05, 0.66331100E+04, 0.11084300E+05, 0.56667900E+04, 0.31998400E+04, 0.49709200E+04, -.22889200E+04, -.73420800E+04, -.49628500E+04, 0.59287400E+04, 0.29476500E+04, 0.75579300E+03, 0.64836300E+02, -.45324600E+03, 0.53620500E+03, 0.22697000E+03, -.15760100E+02, -.39214200E+03, 0.11645800E+04, 0.43365900E+04, 0.10786400E+04, -.23451300E+04, 0.78351300E+03, -.51457600E+04, 0.33747000E+04, 0.15465500E+03, -.22010200E+02, -.22833400E+04, 0.24391800E+03, -.47413100E+04, 0.42373100E+04, 0.18194800E+03, -.36185200E+03, 0.67370700E+04, 0.27438600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40615000E+00, -.10289400E+00, -.16018700E+00, 0.16793200E+00, 0.41762900E-01, 0.19418700E-01, -.20469400E-01, 0.21253500E+00, -.53859900E-01, -.83951800E-01, 0.42726500E+00, 0.39889300E+00, 0.11685300E+01, 0.61779000E-01, -.28458800E-01, 0.50473500E-01, 0.69807200E-01, 0.39773900E+00, 0.26907800E-01, -.52014800E-01, 0.19070600E+00, -.15061700E+04, -.34226700E+03, 0.15371700E+03, 0.12430800E+04, 0.16628300E+03, 0.73080600E+03, 0.80122800E+03, -.42709300E+03, 0.19990700E+02, 0.10612100E+03, 0.45559700E+03, -.13367300E+04, -.55459800E+04, 0.28385700E+04, 0.43504700E+04, 0.27719400E+04, -.97159600E+03, -.53295600E+03, 0.61454400E+03, -.98008500E+03, 0.21214900E+04, -.68463800E+03, 0.43402500E+04, 0.52561000E+04, -.25653500E+04, -.30921100E+04, -.26280400E+04, -.13202700E+04, -.19243300E+02, -.20765300E+04, -.19033700E+04, -.18262700E+04, 0.65683300E+02, 0.14129100E+04, 0.40361500E+04, -.20295200E+04, -.53121200E+03, -.20246100E+04, 0.15250700E+03, 0.27147600E+04, -.23853700E+04, -.91163300E+03, -.17000100E+04, 0.21854500E+04, -.16744200E+03, 0.11975200E+05, -.60775800E+04, -.68383700E+04, -.59851200E+04, -.20467600E+04, 0.21643600E+04, -.30781000E+04, -.31888500E+03, -.42256300E+04, 0.20594700E+04, 0.34356100E+03, -.82656300E+04, 0.42702100E+04, 0.35887600E+04, 0.41329200E+04, 0.11603100E+04, -.24782900E+04, 0.30511100E+04, 0.11233000E+04, 0.26871700E+04, -.20651700E+04, -.17127300E+04, 0.10434700E+05, -.53303600E+04, -.53534000E+04, -.52102900E+04, -.10482000E+04, -.37162800E+04, -.15849100E+04, -.10859300E+04, -.38253300E+04, -.25731300E+04, -.33300700E+04, 0.36478900E+04, -.18123500E+04, -.16516400E+04, -.18226500E+04, -.68009300E+03, -.60339900E+02, -.15560300E+04, -.14794500E+04, -.15104300E+04, -.45503600E+02, 0.18987500E+03, 0.86250300E+04, -.43166400E+04, -.89375200E+04, -.43153000E+04, -.32805400E+04, -.39870600E+04, -.23068400E+04, -.31362000E+04, -.40039500E+04, -.34671600E+04, 0.31770300E+04, -.14274200E+05, 0.71075300E+04, 0.98942400E+04, 0.71375100E+04, 0.11668900E+04, 0.49871100E+04, 0.31589900E+04, 0.19773100E+04, 0.48328800E+04, 0.41073400E+04, 0.65446000E+04, 0.40510100E+04, -.20105500E+04, -.16572800E+04, -.20258600E+04, 0.42724800E+03, -.26957300E+04, 0.33699400E+03, 0.71820400E+03, -.10006100E+04, -.23958300E+04, -.28931400E+04, 0.97324200E+04, -.49184300E+04, -.16065600E+04, -.48677800E+04, -.26763200E+02, 0.82458100E+04, -.50230500E+04, -.25563200E+04, -.51949700E+04, 0.77658100E+04, -.38445300E+04, -.84427400E+04, 0.42360700E+04, 0.60430500E+04, 0.42335300E+04, 0.17431400E+04, 0.13853000E+04, 0.30750700E+04, 0.35888500E+04, 0.46441100E+04, 0.50339000E+03, 0.27353300E+04, 0.14762500E+05, -.73154400E+04, -.94079400E+04, -.73791000E+04, -.19619200E+04, -.53310300E+04, -.36353500E+04, -.20639800E+04, -.46209100E+04, -.43545600E+04, -.55710800E+04, 0.12125600E+05, -.60866600E+04, -.59021500E+04, -.60590100E+04, -.28106000E+04, 0.68846600E+04, -.82801600E+04, -.83915500E+04, -.81441900E+04, 0.73334600E+04, -.51010100E+02, 0.83460600E+04, -.41402200E+04, -.56921200E+04, -.41733700E+04, -.11986200E+03, -.51905800E+04, -.65731000E+03, -.51048600E+03, -.26820600E+04, -.42638900E+04, -.61827000E+04, 0.21468500E+05, -.10530900E+05, -.42069900E+04, -.10726200E+05, 0.11446500E+04, -.24005600E+03, -.57868800E+04, 0.86432500E+03, -.88594200E+04, -.12616600E+04, -.15179900E+05, -.92458300E+04, 0.45718300E+04, 0.38721100E+04, 0.46170000E+04, 0.10878400E+04, 0.30709500E+04, 0.22778100E+04, 0.10110900E+04, 0.28274300E+04, 0.26109100E+04, 0.42185600E+04, 0.63873900E+04, -.31855400E+04, -.22820200E+04, -.31934200E+04, -.66115400E+03, -.32221100E+04, -.74303300E+03, -.58966400E+03, -.22902000E+04, -.27521200E+04, -.23284800E+04, -.15679900E+05, 0.77162800E+04, 0.37797500E+04, 0.78384400E+04, -.89179600E+03, -.17894600E+04, 0.42066300E+04, -.70434700E+03, 0.65448800E+04, -.12043300E+04, 0.10942200E+05, -.63454700E+04, 0.31462900E+04, 0.32727800E+04, 0.31744700E+04, 0.14690400E+04, -.20216000E+03, 0.36475200E+04, 0.45733800E+04, 0.45407700E+04, -.33780600E+03, -.54028900E+03, -.17214700E+04, 0.85513100E+01, -.42906900E+03, 0.41826800E+02, 0.73247900E+03, -.68438800E+02, -.20154000E+03, -.53797800E+03, -.26739400E+03, 0.54934500E+03, 0.57267400E+03, 0.46753900E+03, 0.16436000E+04, 0.29171500E+03, 0.13920000E+03, 0.11476100E+04, 0.24229600E+04, 0.67098400E+03, 0.71624600E+03, 0.82616600E+03, 0.19430400E+04, -.32783800E+03, 0.43849400E+02, -.72133600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.63123500E+00, 0.58780800E-01, 0.10315900E+00, 0.43623200E+00, -.32390300E+00, -.41388800E+00, 0.72849100E-01, -.22365300E+00, -.84726400E-01, 0.14053300E+00, 0.33778400E+00, -.34883900E+00, 0.25851900E+00, 0.39944800E+00, -.32587100E+00, -.28516500E-01, 0.11098700E+00, -.34884300E+00, -.12397500E+00, 0.14416100E+00, 0.31169400E+00, 0.22990400E+00, -.78375800E+04, 0.41744700E+04, 0.98072500E+03, 0.39214900E+04, 0.15845500E+04, 0.96050500E+03, 0.27847200E+03, -.16884100E+04, 0.18063500E+04, 0.88764300E+03, 0.26525800E+04, 0.45950600E+03, -.12562900E+04, -.16081500E+04, -.22917900E+03, 0.14973100E+03, 0.70835600E+03, 0.27410200E+03, 0.30170600E+03, -.94802500E+03, 0.70975100E+03, -.10367000E+04, 0.32151600E+04, -.12456600E+04, 0.17811700E+04, -.16074800E+04, -.15147500E+03, 0.12237700E+04, -.37654500E+03, -.25827300E+03, -.30415600E+04, 0.13392100E+04, -.22103400E+04, -.53866500E+04, 0.29232900E+04, 0.14253400E+04, 0.26969600E+04, 0.82469000E+03, 0.50132900E+02, 0.72913000E+03, -.53480700E+03, 0.14872400E+04, 0.15421600E+03, 0.13992400E+04, 0.61244800E+03, 0.55041400E+03, 0.16950700E+04, -.30759800E+03, 0.32826000E+03, -.16604200E+04, 0.10978100E+04, 0.66611600E+02, -.44682500E+03, -.13778400E+04, -.16441000E+04, 0.15611000E+04, -.16686400E+04, -.26243300E+04, -.78064300E+03, -.26810000E+01, 0.24567700E+04, -.20980300E+04, -.99345900E+03, -.26307100E+03, 0.22456700E+04, 0.12893400E+04, -.44404700E+04, 0.26426400E+04, 0.18824700E+04, 0.22162300E+04, 0.31679600E+04, 0.34148900E+04, -.11088000E+04, -.13809100E+04, -.12023100E+04, 0.31240500E+04, 0.25586700E+04, -.55703200E+03, 0.41239800E+03, 0.34024800E+03, 0.27781100E+03, 0.15080900E+03, 0.95452200E+03, -.10093200E+03, -.39649500E+03, -.74305800E+03, 0.92045500E+03, -.38411600E+02, 0.47309500E+03, 0.70831900E+03, 0.30832500E+04, -.23495400E+03, 0.32670000E+04, 0.18952500E+04, -.27386700E+03, 0.14939900E+04, -.13748100E+04, 0.22102900E+04, -.16037400E+04, -.91791000E+04, 0.38310500E+04, -.33491400E+04, 0.45892900E+04, -.67096500E+03, -.15606800E+04, 0.56267400E+03, -.18850400E+04, 0.52861900E+04, -.18649100E+04, 0.20851600E+04, 0.46473100E+04, -.20460400E+04, 0.16077500E+04, -.23234500E+04, 0.17595400E+03, 0.84291800E+03, -.47266600E+03, 0.60176500E+03, -.31170700E+04, 0.10135100E+04, 0.16297500E+03, -.21765500E+04, 0.93823700E+03, 0.38247800E+03, 0.10891800E+04, -.10045400E+04, -.24180700E+04, 0.11840200E+04, -.39009600E+03, 0.58411300E+03, -.23788500E+04, 0.29008000E+03, -.17000100E+04, -.71244200E+03, -.21597700E+04, 0.84305600E+03, -.14564400E+04, 0.90879800E+03, -.95081200E+03, -.18828300E+04, 0.57182700E+03, 0.73225000E+03, 0.15151400E+04, 0.40917100E+04, -.11800100E+04, 0.32578600E+04, -.20470600E+04, 0.24960700E+04, 0.24094800E+04, 0.54495200E+02, 0.46038300E+03, -.50125300E+04, 0.25182400E+04, -.23877100E+04, 0.21604900E+04, -.52535800E+03, 0.43811700E+03, -.10824000E+04, 0.80858200E+03, -.21512600E+04, 0.16171600E+04, 0.23802500E+04, -.11911900E+04, -.20672100E+04, -.20263000E+04, 0.10626800E+05, -.49379100E+04, 0.16707700E+04, -.53132200E+04, 0.20278800E+03, 0.18455500E+04, -.12266000E+04, 0.17851100E+04, -.55692800E+04, 0.20637100E+04, -.14283400E+04, -.11230500E+05, 0.66036500E+04, 0.46946900E+04, 0.56106600E+04, 0.25218100E+04, 0.20510200E+04, 0.11984900E+04, 0.10272900E+04, 0.52510800E+04, 0.23154800E+04, 0.52543100E+04, -.14649800E+04, 0.32183600E+03, -.27029700E+03, 0.73585200E+03, -.15617000E+04, -.15241900E+04, -.71449000E+02, -.16202500E+03, 0.26071000E+04, -.15917100E+04, 0.37732700E+03, -.43180400E+04, 0.24749100E+04, 0.10339000E+04, 0.21588700E+04, 0.19418700E+04, 0.27631400E+04, -.62424600E+03, -.98451300E+03, 0.27455300E+03, 0.26137400E+04, 0.27532800E+04, 0.67690100E+04, -.25849800E+04, -.12232700E+04, -.33836200E+04, 0.16856200E+03, -.11596600E+04, -.46322600E+03, 0.13393400E+03, -.29541800E+04, -.14789400E+04, -.53491000E+04, 0.20759600E+04, -.16956600E+04, -.25690900E+03, -.10389800E+04, -.19539400E+04, -.10953000E+04, -.25426700E+02, -.16476500E+04, -.21389300E+04, -.98561000E+03, 0.18323900E+03, -.81640100E+01, -.16634200E+03, 0.32096400E+03, 0.46391300E+03, -.22310300E+03, -.98559200E+02, 0.13821000E+03, 0.15992200E+03, -.61914100E+03, 0.20417300E+03, 0.81238900E+03, 0.25427800E+02, -.18137200E+04, 0.94447500E+03, -.83136200E+03, -.19458200E+03, -.14132700E+04, 0.13074000E+03, -.16347300E+04, -.11887200E+04, -.81404200E+03, -.67456000E+03, -.12333800E+04, 0.92588800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.51440400E+00, 0.36063200E-01, 0.10930900E+00, -.33494800E+00, -.28523700E+00, 0.13272000E+00, 0.50257200E-01, 0.12486400E+00, -.36577500E-01, 0.87332400E-01, -.21603600E-01, -.12479000E+00, -.27938300E+00, 0.19318700E-01, 0.10379300E+00, -.18223900E-01, 0.15680800E-01, -.99766200E-01, 0.10068700E+00, -.12978000E+00, 0.38848700E+00, 0.14126500E+00, -.77652600E+00, 0.59019800E+03, 0.19519900E+03, 0.77236200E+01, -.27954500E+03, 0.10754700E+04, -.15464100E+04, -.48512600E+03, 0.11039700E+04, 0.83303300E+03, -.31427500E+02, -.11222700E+05, 0.34004900E+04, 0.52385800E+04, 0.56125400E+04, -.15530200E+04, 0.40623300E+02, 0.21757400E+04, -.21657600E+04, 0.22497600E+03, -.71836200E+02, 0.52627500E+04, 0.20138700E+05, -.91613700E+04, -.94845200E+04, -.10067500E+05, -.13559100E+04, 0.51781900E+03, -.28380800E+04, 0.22389400E+04, -.55023200E+04, 0.31901700E+03, -.74360800E+04, 0.20081700E+04, -.44870600E+03, -.23475600E+04, -.99400000E+03, -.12520100E+04, -.29271400E+02, -.15505900E+04, -.97543000E+03, 0.99017800E+02, -.28733400E+02, -.32304000E+03, 0.18498700E+05, -.74567300E+04, -.59320800E+04, -.92527000E+04, -.32132400E+04, -.74694900E+04, 0.24613900E+04, 0.53509300E+04, 0.10545900E+04, -.67729300E+04, -.57687400E+04, -.11037100E+05, 0.37017100E+04, 0.65368500E+04, 0.55176200E+04, 0.52593600E+04, 0.89230300E+04, -.35987800E+04, -.49104800E+04, -.57712800E+04, 0.90541000E+04, 0.69260600E+03, 0.37717000E+05, -.18039500E+05, -.90320900E+04, -.18869800E+05, -.47694000E+04, -.40448100E+04, -.31971700E+04, 0.74597900E+04, -.10157400E+05, -.34979300E+04, -.95621100E+04, 0.91164600E+04, -.42094700E+04, -.39464900E+04, -.45595400E+04, -.36307200E+03, 0.16970500E+04, -.24669900E+04, -.38219600E+03, -.26814100E+04, 0.13517400E+04, -.36087300E+04, 0.14430000E+05, -.51797700E+04, 0.21572500E+04, -.72101600E+04, -.29217000E+04, -.68180900E+04, 0.19837700E+04, 0.27718100E+04, -.58314300E+04, -.47258700E+04, -.53387600E+04, -.63461700E+05, 0.30100700E+05, 0.19116900E+05, 0.31729800E+05, 0.47083700E+04, 0.56013100E+04, 0.61068500E+04, -.12312900E+05, 0.17745300E+05, 0.48086500E+04, 0.17742400E+05, 0.30423300E+05, -.14627700E+05, -.67047100E+04, -.15211000E+05, -.50435700E+04, -.49005500E+04, -.63165000E+03, 0.64560900E+04, -.94595100E+04, -.47886700E+04, -.47059400E+04, 0.59596900E+04, -.33374800E+04, -.36940500E+04, -.29770600E+04, 0.65557800E+03, 0.21708700E+04, -.18663200E+04, 0.40139600E+03, -.15116700E+04, 0.80165600E+03, 0.27467200E+03, -.16130900E+05, 0.46745000E+04, -.58483100E+03, 0.80446400E+04, -.62610900E+03, 0.43556000E+04, -.37395500E+03, -.46245700E+04, 0.63454100E+04, 0.34555300E+04, 0.48419800E+04, 0.57310800E+05, -.26740600E+05, -.13821400E+05, -.28658600E+05, -.51870800E+04, -.69059200E+04, -.35237700E+04, 0.13187600E+05, -.14455500E+05, -.55621100E+04, -.20599600E+05, 0.12803300E+05, -.52137900E+04, 0.10598700E+03, -.64076200E+04, 0.91872400E+03, 0.97867000E+02, -.18824800E+04, -.21240800E+03, -.85420800E+04, -.94446500E+02, -.27698800E+04, 0.59771200E+05, -.29088900E+05, -.14594000E+05, -.29884900E+05, -.52605500E+04, -.47432700E+04, -.49846000E+04, 0.11887600E+05, -.18495800E+05, -.43696200E+04, -.15134500E+05, -.16907200E+04, 0.31803600E+04, 0.12559200E+05, 0.83162400E+03, 0.12455400E+05, 0.99877800E+04, -.86514100E+04, -.88557000E+04, -.81732500E+04, 0.11572200E+05, -.12609700E+05, -.33192300E+05, 0.15676200E+05, 0.70422500E+04, 0.16605800E+05, 0.27208100E+04, 0.37643700E+04, 0.24483200E+04, -.67713700E+04, 0.78802400E+04, 0.29241300E+04, 0.12277600E+05, 0.17180200E+05, -.79097800E+04, -.48566500E+04, -.85904200E+04, -.22361000E+04, -.93861800E+03, -.22989900E+04, 0.29247000E+04, -.54944200E+04, -.80970000E+03, -.26942800E+04, 0.37242800E+04, -.21435400E+03, -.65669700E+04, -.18590800E+04, -.65244000E+04, -.77807800E+04, 0.63932900E+04, 0.93797200E+04, 0.88930300E+04, -.87910200E+04, 0.35208900E+04, 0.36703800E+04, -.33057600E+04, -.66272700E+04, -.18382100E+04, -.33534100E+04, -.38624600E+04, 0.35469000E+04, 0.43582600E+04, 0.32990800E+04, -.45093000E+04, 0.27043400E+04, -.23289100E+04, -.32457100E+03, 0.83239300E+03, -.10091500E+03, -.18686000E+02, -.71952100E+03, 0.61325700E+03, -.89968800E+03, -.38531900E+04, 0.21537800E+02, 0.32770300E+04, 0.55192800E+03, 0.27892000E+04, -.24266900E+04, -.13737400E+04, 0.93465000E+03, 0.11386300E+04, 0.84156400E+03, 0.30634700E+04, -.38062600E+04, 0.12293200E+03, -.73232600E+03, -.53460400E+04, 0.20560400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.57131000E+01, -.26375200E+01, 0.39148800E+01, -.17151100E+01, 0.38660600E+01, -.68181800E+00, -.65274600E+00, 0.24038400E+01, 0.60018500E+00, -.10005500E+01, 0.36709900E-01, 0.12108200E+01, 0.44879000E+01, 0.71123900E+01, -.52415700E+00, 0.18402600E+00, 0.26789200E+01, 0.20826700E+01, -.11944700E+01, -.20006700E+01, 0.24317600E+01, -.38368400E+00, 0.11105100E+00, -.76654100E-01, 0.93246000E+05, -.19636800E+02, -.84996700E+04, 0.90154800E+03, 0.24115200E+04, 0.76511600E+04, -.27890800E+04, 0.12981800E+04, -.11716800E+05, 0.48536800E+05, -.22997600E+05, -.12758900E+04, -.24272800E+05, -.34345200E+05, -.33900700E+05, 0.49344200E+04, -.31509600E+04, -.13605200E+05, -.21883300E+05, -.10054900E+05, -.98034800E+05, 0.47695100E+05, -.52046400E+05, 0.49018300E+05, 0.19073900E+05, 0.98426000E+04, 0.19513300E+05, -.77746400E+04, 0.34452200E+05, 0.10137200E+05, 0.53410400E+05, -.86581400E+05, 0.43240400E+05, 0.57953500E+05, 0.43264100E+05, 0.42796600E+04, 0.31039600E+04, 0.18128500E+05, 0.25447000E+04, 0.33134100E+05, 0.50421600E+04, 0.31873900E+05, 0.62924300E+04, -.38540200E+04, -.33800000E+05, -.31360200E+04, -.22464700E+05, -.12262200E+05, 0.14476700E+05, 0.70054800E+04, -.33298300E+04, -.10835500E+05, 0.47413400E+04, 0.16098400E+05, -.78458100E+04, 0.66376500E+05, -.80490900E+04, 0.12616200E+04, -.26905600E+04, -.10711800E+05, -.11479800E+05, -.11200600E+05, 0.32023100E+04, -.21672100E+05, 0.10186800E+06, -.49846600E+05, 0.72304000E+05, -.50905600E+05, -.75115700E+04, 0.95859800E+04, -.11272000E+05, 0.24297400E+05, -.53554700E+05, 0.46873600E+04, -.60320600E+05, -.17558600E+05, 0.84075300E+04, 0.53597600E+04, 0.87847900E+04, 0.40490800E+04, 0.58520900E+04, 0.62380600E+04, 0.37260700E+04, 0.39383400E+04, 0.55768300E+04, 0.52978300E+04, 0.61692900E+05, -.32030300E+05, 0.56505900E+05, -.30857500E+05, -.33137400E+05, -.99351700E+04, -.13847800E+04, 0.44979200E+04, -.41243600E+05, -.95969300E+03, -.29385300E+05, -.45053500E+05, 0.22988200E+05, 0.26325300E+05, 0.22528400E+05, -.52035500E+04, 0.49442000E+02, -.23474600E+05, -.53281200E+05, 0.33765100E+04, 0.84852600E+04, 0.23530800E+05, 0.38570200E+05, -.18892000E+05, -.61523300E+04, -.19286500E+05, -.78290100E+04, -.89627800E+04, 0.13980600E+05, 0.28007100E+05, -.92581700E+04, -.12237000E+05, -.15256000E+05, 0.22860100E+05, -.10872100E+05, -.40070800E+05, -.11436200E+05, -.78522600E+04, 0.67363700E+04, -.11963600E+05, -.13450900E+05, -.80241500E+04, 0.49447000E+04, 0.16663900E+05, -.30903600E+05, 0.17924600E+05, -.20744400E+05, 0.15500100E+05, 0.22179000E+05, 0.12059800E+05, -.87164500E+04, -.48167800E+04, 0.17309300E+05, 0.95571400E+04, 0.14097700E+05, 0.16997800E+06, -.86383200E+05, 0.30628400E+05, -.84980300E+05, -.17865500E+05, -.10343800E+05, 0.24446000E+04, 0.45164500E+05, -.58517700E+05, -.15765400E+05, -.84993100E+05, 0.34134400E+05, -.17767700E+05, 0.15576800E+05, -.17051800E+05, -.61267300E+05, -.34980100E+05, 0.17679600E+05, 0.10304100E+05, -.14622300E+05, -.23580400E+05, -.12356800E+05, 0.94495300E+05, -.46910300E+05, -.22962800E+05, -.47248900E+05, -.86696500E+04, -.73748200E+04, 0.10896000E+05, 0.46574200E+05, -.23915000E+05, -.13918200E+05, -.36663500E+05, -.23343800E+05, 0.76097900E+04, 0.19047000E+06, 0.11703700E+05, 0.22607200E+05, 0.23433300E+05, 0.32380800E+04, 0.30164100E+05, 0.10325300E+04, 0.24022800E+05, -.45291500E+05, -.10267300E+06, 0.52220200E+05, -.42143000E+05, 0.51313000E+05, 0.87100500E+04, 0.34446200E+04, 0.50573700E+03, -.27887200E+05, 0.37982600E+05, 0.69783300E+04, 0.54713000E+05, 0.48727900E+05, -.24417200E+05, 0.47466500E+05, -.24362800E+05, 0.88894000E+04, 0.15079800E+05, -.81270100E+04, 0.12854800E+05, -.22426400E+05, 0.10651200E+05, -.29635300E+05, 0.54118200E+05, -.27281900E+05, -.11005700E+06, -.27064900E+05, -.61298500E+04, 0.23802200E+04, -.20807300E+05, -.22465400E+05, -.16381600E+05, -.55253600E+04, 0.54382900E+04, -.41361900E+05, 0.22322300E+05, -.76575400E+05, 0.20687800E+05, 0.78035300E+04, -.15994800E+05, 0.20457800E+05, 0.73229500E+04, 0.24701400E+05, -.18633300E+05, 0.24561200E+05, -.66260300E+04, 0.27574000E+04, 0.35106700E+03, -.98579600E+04, -.22091300E+04, -.14727200E+05, -.62927100E+04, -.60521900E+04, -.10892000E+05, 0.47686800E+04, 0.15568000E+04, 0.17707300E+04, 0.62217300E+04, -.37846200E+04, -.24584200E+04, 0.45743900E+04, -.35469400E+03, 0.27606300E+04, 0.86197200E+04, -.11252500E+05, -.14344000E+05, -.19575100E+05, -.16466400E+05, 0.97309500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16398300E+01, -.18545500E+00, -.59806900E+00, -.63251400E+00, 0.81426200E+00, 0.66156900E+00, -.15073300E+00, 0.67242000E+00, 0.22006100E+00, -.32095200E+00, -.47344900E+00, -.46038000E+00, 0.26200400E+00, -.94627300E+00, -.44586500E-01, -.52224100E-01, -.88465500E-01, 0.15975500E+00, -.74331700E-01, 0.40289700E+00, -.12122500E+01, -.13192200E+01, -.80095600E+00, -.12297500E+00, 0.14854400E-01, -.25199600E+02, 0.95848400E+03, 0.26441600E+04, -.84241800E+03, -.92210900E+03, -.40143100E+04, 0.24796500E+04, -.34624000E+02, 0.33132400E+04, -.16118000E+04, -.16442500E+04, -.16613900E+04, -.12164100E+04, -.20895100E+04, -.19527400E+04, -.20009300E+04, 0.64540000E+03, -.14223800E+04, 0.38993400E+04, -.18222600E+05, 0.89346100E+04, 0.86949000E+04, 0.91089300E+04, 0.17726600E+04, -.10354000E+04, 0.12512300E+04, -.45860500E+04, 0.33547600E+04, -.58777900E+03, 0.93641400E+04, 0.37426500E+04, -.18846700E+04, -.10754000E+02, -.19048000E+04, 0.12591800E+03, 0.24863500E+04, -.18412300E+04, -.62459500E+03, -.45757900E+04, 0.27361200E+04, 0.38998500E+03, -.18906500E+04, 0.95739500E+03, -.99265900E+03, 0.95728800E+03, 0.30135800E+04, 0.78489800E+04, -.42101100E+04, -.25203400E+04, -.56416500E+04, 0.72059100E+04, 0.71521300E+04, 0.13716400E+04, -.75666200E+03, -.16848900E+04, -.68429800E+03, -.52160200E+04, -.92937500E+04, 0.54623000E+04, 0.36918100E+04, 0.77046000E+04, -.87110800E+04, -.77112000E+04, -.19938800E+05, 0.10077700E+05, 0.77341500E+04, 0.10005900E+05, 0.27907100E+04, 0.16304800E+04, -.98089900E+03, -.96498800E+04, 0.28909800E+04, 0.21195000E+04, 0.59096300E+04, -.94898000E+04, 0.46846300E+04, 0.35177200E+04, 0.47505600E+04, 0.98578100E+03, -.82317600E+03, 0.10539800E+04, -.18180600E+04, 0.15204400E+04, -.74722100E+03, 0.44612000E+04, 0.49541000E+04, -.26286800E+04, -.46249100E+04, -.24919600E+04, -.84702300E+03, 0.42288200E+03, -.67166900E+04, -.85761400E+04, -.25105800E+04, 0.28657000E+02, 0.62100900E+04, 0.41776400E+05, -.20671300E+05, -.14170800E+05, -.20885600E+05, -.18535500E+04, 0.70833400E+03, -.28332500E+04, 0.12218800E+05, -.11023700E+05, 0.91245300E+03, -.14923100E+05, -.22122500E+05, 0.10958100E+05, 0.95598300E+04, 0.11059300E+05, 0.41111600E+04, 0.24436400E+04, 0.12198000E+04, -.30945300E+04, 0.76130600E+04, 0.21785800E+04, 0.71330100E+04, 0.52833600E+04, -.25077900E+04, -.15742700E+04, -.26501600E+04, 0.29164800E+04, 0.90359700E+04, -.43125400E+04, -.23181000E+04, -.73951400E+04, 0.92250200E+04, -.19017000E+04, -.52861200E+04, 0.28581800E+04, 0.41852800E+04, 0.27078200E+04, 0.49647700E+03, -.43727700E+04, 0.71993600E+04, 0.89623900E+04, 0.47237500E+04, -.43908100E+04, -.17386700E+04, -.28935200E+05, 0.14169000E+05, 0.10491100E+05, 0.14478500E+05, -.13642400E+03, -.38629700E+03, -.20447300E+04, -.16510300E+05, 0.18653900E+04, -.69883100E+03, 0.11407200E+05, 0.40850000E+04, -.20884600E+04, -.27493000E+04, -.20229400E+04, -.36823100E+03, 0.67185300E+04, -.75380100E+04, -.98536900E+04, -.83182000E+04, 0.82128200E+04, 0.21517300E+04, -.45080500E+05, 0.22380700E+05, 0.15871900E+05, 0.22538300E+05, 0.34540000E+04, -.10098000E+04, 0.49529000E+04, -.89918000E+04, 0.14575500E+05, -.11118700E+04, 0.13826800E+05, 0.22882900E+05, -.11908200E+05, -.84448400E+04, -.11398800E+05, -.10347600E+05, -.87586900E+04, 0.83066700E+03, 0.47632700E+04, -.26848700E+04, -.11076700E+05, -.15941900E+05, 0.15746400E+05, -.76847200E+04, -.72090400E+04, -.79041500E+04, 0.79661400E+03, 0.74397600E+02, 0.14282700E+04, 0.92529900E+04, 0.40721800E+03, 0.69770200E+03, -.58318800E+04, -.83797400E+04, 0.41120500E+04, 0.50324200E+04, 0.41911500E+04, 0.89905100E+03, -.30902600E+03, -.71028700E+03, -.42968300E+04, 0.23179300E+04, -.35077900E+03, 0.26988200E+04, -.12750000E+05, 0.64425400E+04, 0.70107100E+04, 0.63663400E+04, 0.71941000E+04, 0.62281900E+04, -.27427600E+04, -.72606900E+04, -.39058700E+04, 0.69289000E+04, 0.11831400E+05, -.11137200E+05, 0.57039700E+04, 0.55538400E+04, 0.55778900E+04, 0.35723200E+04, 0.40573400E+04, 0.90800600E+03, 0.24570600E+04, 0.29906300E+04, 0.42101100E+04, 0.24331600E+04, -.14193800E+04, -.19753800E+03, -.53187700E+03, -.73775200E+03, 0.94219800E+02, -.27474400E+03, 0.33948000E+03, -.15018000E+03, 0.23306500E+04, 0.69622400E+03, -.10498200E+04, 0.16538800E+03, 0.22760600E+03, 0.18998500E+04, 0.67340300E+03, 0.10719100E+04, 0.23446100E+04, 0.37922000E+03, -.11961000E+04, 0.35201700E+04, 0.12837800E+04, -.42207700E+03, 0.38440700E+04, -.11799700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33909200E+01, 0.30967600E+00, 0.11880600E+01, -.11836000E+01, -.73867700E+00, -.17179500E+01, 0.25320200E+00, 0.91688600E+00, -.80925300E+00, -.14917100E+00, 0.20617500E+00, 0.67167400E+00, 0.31122500E+01, 0.68929800E-02, 0.21937200E+00, 0.11087400E+00, -.85676100E+00, 0.10624200E+01, 0.23988200E+00, -.58327200E+00, 0.65573800E-01, 0.68055000E+00, -.14244400E+01, 0.95572000E+00, -.26012000E+00, 0.38877400E+00, -.46078600E+04, -.91753600E+04, 0.83423000E+04, 0.72916700E+04, 0.37696600E+04, -.76472100E+04, -.37532100E+04, 0.14880900E+05, -.54651000E+04, -.17199100E+05, -.74404200E+04, 0.84333800E+04, 0.13368100E+04, 0.25873200E+04, 0.12662700E+05, 0.29069100E+04, 0.16237200E+04, -.12484500E+05, -.18565800E+05, 0.74644100E+04, 0.88983400E+04, 0.92827500E+04, -.28062900E+02, 0.57871000E+03, 0.91242400E+04, 0.80281700E+04, 0.99531500E+04, -.64975700E+03, 0.83855900E+04, -.23025400E+05, 0.11502800E+05, 0.68522600E+04, 0.11512700E+05, -.20689700E+04, -.97725800E+04, 0.18280400E+05, 0.14203600E+05, 0.12445000E+05, -.80284700E+04, -.88015900E+03, -.25299800E+05, 0.11476400E+05, 0.26280000E+05, 0.12649800E+05, 0.52198600E+04, 0.12051700E+04, 0.55177300E+04, 0.65757100E+03, 0.40015700E+04, 0.47060800E+03, -.71630700E+04, 0.32147200E+05, -.15500900E+05, -.15122500E+05, -.16073500E+05, -.87458500E+04, -.34201800E+04, -.82125200E+04, -.44848900E+04, -.54631600E+04, -.20387000E+04, 0.11268500E+05, -.33463200E+05, 0.17430300E+05, 0.27090700E+05, 0.16731600E+05, 0.11775900E+04, -.17559800E+04, 0.12768300E+05, 0.65829500E+04, 0.86109800E+04, -.38266300E+04, 0.49134700E+04, -.47692400E+04, 0.17901900E+04, 0.45173500E+04, 0.23845700E+04, -.70302000E+03, -.54348100E+03, 0.43372800E+04, 0.68497300E+04, 0.48531500E+04, -.12248000E+04, 0.34111200E+04, -.25865900E+05, 0.10722900E+05, 0.29777300E+05, 0.12932900E+05, 0.16769000E+05, 0.75958700E+04, 0.18459700E+05, 0.32191800E+05, 0.12616000E+05, 0.49325000E+04, -.10494900E+05, 0.72482100E+05, -.34380500E+05, -.40393000E+05, -.36241000E+05, -.37286700E+04, -.49422200E+04, -.19703700E+05, -.41683300E+04, -.23884400E+05, -.10918000E+04, -.21290500E+05, -.26327300E+05, 0.12705700E+05, 0.19439600E+05, 0.13163600E+05, 0.21424800E+04, -.35860900E+04, 0.57759900E+04, -.41359000E+04, 0.72386900E+04, -.36653800E+04, -.59286000E+04, -.15411400E+05, 0.87271400E+04, 0.83997700E+04, 0.77056500E+04, -.76328500E+04, -.19225600E+05, 0.72692200E+04, -.18115400E+04, 0.15005900E+05, -.15893600E+05, 0.37753400E+04, 0.23057000E+05, -.76315500E+04, -.30572800E+05, -.11528300E+05, -.56726400E+04, 0.73284400E+04, -.16298200E+05, -.17514100E+05, -.17635400E+05, 0.73129500E+04, 0.95117900E+03, -.27505300E+05, 0.10912100E+05, 0.18482800E+05, 0.13752600E+05, 0.24291000E+04, 0.38816500E+04, 0.16206200E+05, 0.17780000E+05, 0.15551200E+05, -.37180100E+03, 0.17537800E+05, -.24113200E+05, 0.10937800E+05, 0.23548000E+05, 0.12056600E+05, 0.81607200E+04, -.20994900E+05, 0.23946600E+05, 0.32104700E+05, 0.32229200E+05, -.19024600E+05, -.58498100E+04, -.49422800E+05, 0.23917200E+05, 0.35139400E+05, 0.24711400E+05, 0.19581600E+04, 0.56605500E+02, 0.89841800E+04, -.74493500E+04, 0.14403800E+05, -.16442000E+04, 0.10217100E+05, -.20800800E+05, 0.49002400E+04, 0.79185400E+04, 0.10400500E+05, -.14497800E+05, -.84341300E+04, 0.21709800E+05, 0.36158700E+05, 0.20683700E+05, -.73724700E+04, 0.52482700E+05, 0.73673700E+04, -.20913300E+04, -.12162100E+05, -.36837300E+04, -.67583700E+03, -.61702400E+03, -.91371100E+04, -.12919400E+05, -.57796000E+04, 0.11489800E+04, -.78899200E+04, -.17488900E+05, 0.80532900E+04, 0.11917500E+05, 0.87444500E+04, 0.12406200E+04, 0.21780400E+03, 0.86586700E+04, 0.55884100E+04, 0.54607900E+04, -.11189000E+04, -.17934400E+04, 0.12278700E+05, -.66215500E+04, -.76305300E+04, -.61394000E+04, 0.10995700E+05, 0.76582300E+04, -.13427200E+05, -.20077500E+05, -.14440100E+05, 0.55339000E+04, -.32769900E+05, 0.12937700E+05, -.42899000E+04, -.11111200E+05, -.64688400E+04, -.58804700E+04, 0.36749400E+03, -.15169600E+05, -.27231100E+05, -.14565700E+05, 0.11889000E+04, -.53696400E+04, 0.53089900E+04, -.76521400E+01, 0.46712300E+03, -.13635700E+04, -.26697500E+04, 0.15957000E+04, -.28975800E+03, 0.18619200E+04, 0.45525500E+04, -.25977700E+01, -.55678100E+04, -.59415000E+03, 0.27471100E+04, 0.32069700E+03, -.20565300E+03, -.40468400E+04, -.37737300E+03, -.29784400E+04, 0.19265200E+04, 0.15526200E+03, -.50427200E+03, -.13666300E+04, 0.46994200E+04, 0.38653600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15240400E+01, -.66135900E+00, -.24902600E+00, 0.39841300E+00, 0.17433700E+01, -.64155000E-01, -.17512200E+00, 0.21977700E+00, 0.10956200E+00, -.43595900E-01, 0.29372600E+00, -.34986300E+00, -.51984900E+00, 0.21941300E+00, -.73201700E-01, -.12852000E+00, -.10364600E+00, 0.11354200E+01, -.22235400E+00, 0.27425900E+00, 0.20879900E+00, 0.29910900E+00, -.89617800E+00, -.35351100E-01, 0.13530400E+00, -.32011200E+00, 0.38320100E+00, 0.52504800E+04, -.85476600E+03, -.65692100E+03, -.26938000E+04, 0.47519200E+04, 0.63421000E+03, 0.68351700E+04, -.52948000E+04, 0.92061100E+03, -.34178000E+04, -.52737400E+04, -.52155400E+04, -.12511900E+04, -.12653500E+04, -.35771300E+04, -.39938800E+04, 0.41820300E+04, -.24009000E+05, 0.13093800E+05, 0.12181500E+05, 0.12005500E+05, 0.31738400E+04, -.71178600E+04, 0.66921600E+04, 0.30371400E+04, 0.10255500E+05, -.66950200E+04, 0.59635200E+04, -.12869600E+04, 0.60962800E+03, 0.23118300E+04, 0.64333700E+03, -.20507500E+03, 0.10926900E+04, 0.17510200E+04, 0.37602100E+04, -.23413300E+03, 0.13037000E+04, 0.12749100E+04, -.10638700E+05, 0.66995800E+04, -.33982100E+04, 0.53196000E+04, 0.71106100E+04, 0.21853200E+04, 0.43849500E+04, 0.78515000E+04, 0.34429900E+04, 0.12907900E+04, -.27900400E+04, 0.80261100E+04, -.51219100E+04, -.38792300E+04, -.40134500E+04, -.70819400E+04, -.35225200E+04, -.56821200E+03, -.35920500E+02, 0.12577500E+04, -.29768400E+04, 0.36417900E+04, -.39694900E+05, 0.19712400E+05, 0.13117100E+05, 0.19847300E+05, 0.96532800E+03, 0.30300500E+04, 0.40932600E+04, -.11875300E+05, 0.11339600E+05, 0.32624400E+04, 0.13746800E+05, -.13611700E+05, 0.71476300E+04, 0.43183100E+04, 0.68062100E+04, 0.20868400E+04, -.29329800E+04, 0.39595700E+04, 0.17443400E+04, 0.60629700E+04, -.30603000E+04, 0.30991400E+04, -.51284900E+04, 0.43578000E+04, -.14291700E+03, 0.25644900E+04, -.57904900E+04, -.90933400E+04, 0.64549400E+04, 0.35310900E+04, 0.67842100E+04, -.89764700E+04, 0.13050700E+05, 0.62454600E+05, -.32526100E+05, -.36224600E+05, -.31227400E+05, -.24023300E+04, -.23975400E+04, -.47272000E+04, 0.20659600E+05, -.11229500E+05, -.28245600E+04, -.22006000E+05, -.38205500E+05, 0.19316700E+05, 0.23245900E+05, 0.19102800E+05, 0.29257100E+04, 0.38315100E+04, 0.22631100E+04, -.10390700E+05, 0.92594500E+04, 0.44713000E+04, 0.10386100E+05, -.42897600E+04, 0.15759000E+04, -.29628900E+03, 0.21450500E+04, 0.92558800E+04, 0.31798800E+04, 0.27304600E+04, 0.66130200E+04, -.44881100E+03, 0.32414900E+04, -.12900100E+05, 0.96519500E+04, -.80491000E+04, 0.12979800E+04, -.48268900E+04, 0.42007300E+04, 0.50061400E+04, -.25890700E+04, 0.36440300E+04, -.38774200E+04, 0.38978900E+04, -.79211100E+04, -.41431300E+05, 0.22671200E+05, 0.28607000E+05, 0.20715700E+05, -.29408100E+04, 0.46733000E+03, 0.91524600E+03, -.20429100E+05, 0.41473500E+04, 0.68373100E+03, 0.19931200E+05, -.14735900E+05, 0.83867500E+04, 0.23512700E+04, 0.73679300E+04, -.45766800E+04, -.16573600E+05, 0.14302300E+05, 0.93919700E+04, 0.63838500E+04, -.12773800E+05, -.48273900E+04, -.69452400E+05, 0.35124900E+05, 0.37081100E+05, 0.34726300E+05, 0.30562600E+04, 0.20651300E+04, 0.62998700E+04, -.19848200E+05, 0.15886200E+05, 0.33409700E+04, 0.21440100E+05, 0.77686900E+05, -.35282500E+05, -.26714600E+05, -.38844000E+05, -.80819600E+04, 0.11284100E+05, -.17876900E+05, 0.31330300E+03, -.21389900E+05, 0.58307800E+04, -.83622500E+04, 0.26353700E+05, -.14227100E+05, -.13276100E+05, -.13176600E+05, 0.21151700E+04, -.92651700E+03, -.15298400E+03, 0.13289700E+05, -.31692700E+04, -.56384200E+03, -.14244100E+05, -.28875000E+05, 0.14906800E+05, 0.13490200E+05, 0.14437600E+05, 0.55780900E+03, 0.10589700E+04, 0.16227000E+04, -.90057300E+04, 0.78852000E+04, 0.80481200E+03, 0.12194100E+05, -.38908600E+05, 0.20410000E+05, 0.21077500E+05, 0.19454700E+05, 0.55086200E+04, -.57573800E+04, 0.79254800E+04, -.47298600E+04, 0.72539200E+04, -.38436900E+04, 0.26186000E+04, -.11966300E+04, -.10658700E+04, 0.25561200E+04, 0.59815900E+03, 0.44211200E+04, 0.99213500E+04, -.82387600E+04, -.78965700E+04, -.47258500E+04, 0.10273300E+05, -.55186100E+04, 0.14783700E+04, -.97659100E+03, -.70669800E+02, -.11282100E+04, -.39412400E+03, 0.48270800E+02, 0.81030600E+03, -.49171300E+03, 0.23819200E+04, -.73066200E+03, -.25580300E+04, -.16092600E+04, 0.19980200E+04, 0.42525000E+03, 0.28672000E+03, -.10530600E+04, 0.42816200E+04, 0.11053700E+04, -.23224100E+03, 0.37320500E+04, 0.22507900E+04, 0.15280100E+04, 0.26603000E+04, -.41383800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19850000E+01, 0.49267100E+00, 0.99264900E+00, -.11625400E+01, -.22207200E+01, -.45386900E+00, 0.29438400E+00, -.18269200E+00, -.25034100E-01, 0.23926800E-01, 0.68154500E+00, 0.66931900E+00, 0.10781200E+00, 0.48183700E+00, -.27836800E+00, 0.10424200E+00, 0.87752700E-01, -.19987900E+01, -.49573300E-01, -.44295200E-01, 0.44471300E-01, -.21238500E+01, 0.40563100E+01, -.11902700E+01, 0.41071500E-01, 0.65840900E+00, -.34180500E+00, -.35451500E+00, -.37950300E+04, -.95324600E+03, 0.52494700E+04, -.41206500E+03, 0.15887100E+04, -.29473500E+05, 0.16914500E+05, 0.13716200E+05, 0.14736600E+05, 0.33766600E+04, 0.17208200E+04, 0.91333100E+04, 0.63598900E+04, 0.13689700E+05, -.79238000E+02, 0.55043000E+04, 0.44590600E+05, -.23262600E+05, -.20936400E+05, -.22295100E+05, -.56523100E+04, 0.95957000E+03, -.88433300E+04, -.83759500E+03, -.13385600E+05, -.15187100E+03, -.17087900E+05, 0.29583800E+04, -.14025900E+04, -.25828900E+04, -.14793000E+04, 0.81468900E+03, 0.47802100E+04, -.73604600E+04, -.67473600E+04, 0.59014000E+03, 0.33124600E+04, -.10959500E+04, 0.48612900E+05, -.25988800E+05, -.14351500E+05, -.24306200E+05, -.11339200E+05, -.81417900E+04, -.24724900E+04, 0.12882300E+04, -.11368400E+05, -.65544400E+04, -.20330200E+05, -.30357000E+05, 0.16682000E+05, 0.18627600E+05, 0.15178400E+05, 0.12557100E+05, 0.74475000E+04, 0.27166200E+03, -.11831500E+04, -.24491500E+03, 0.73345200E+04, 0.14072000E+05, 0.72162700E+05, -.36237700E+05, -.21969300E+05, -.36081100E+05, -.10963000E+05, -.19724700E+05, -.79174800E+03, 0.14495200E+05, -.20926700E+05, -.16213400E+05, -.32800600E+05, 0.29183700E+05, -.14894500E+05, -.10595000E+05, -.14591700E+05, -.34470900E+04, 0.11399400E+04, -.73705900E+04, -.25491600E+04, -.85282200E+04, 0.64919500E+03, -.98063400E+04, 0.24845200E+05, -.14374300E+05, -.89455000E+04, -.12422600E+05, -.71769500E+04, -.18899500E+05, 0.12214600E+05, 0.13188700E+05, -.58668100E+04, -.15709800E+05, -.22948500E+05, -.11126900E+06, 0.56995000E+05, 0.55032200E+05, 0.55634600E+05, 0.79834300E+04, 0.21603300E+05, 0.10159000E+05, -.16559100E+05, 0.32362300E+05, 0.19536700E+05, 0.55929200E+05, 0.73105200E+05, -.36786700E+05, -.30313400E+05, -.36552600E+05, -.55995000E+04, -.18501400E+05, -.22357900E+04, 0.11866000E+05, -.21823400E+05, -.16736800E+05, -.39903300E+05, 0.19074900E+05, -.90481300E+04, -.28848100E+04, -.95374400E+04, -.65835200E+04, 0.60243400E+04, -.44975700E+04, -.13750400E+03, 0.13969100E+04, 0.52137900E+04, -.12274600E+04, -.22983500E+05, 0.15020700E+05, 0.17916800E+02, 0.11491900E+05, 0.26869000E+04, 0.13908600E+05, -.95408200E+04, -.15726200E+05, 0.58702300E+04, 0.11027000E+05, 0.18524900E+05, 0.74469600E+05, -.39188600E+05, -.35745100E+05, -.37234700E+05, -.92247200E+04, -.22923200E+05, 0.17974900E+04, 0.27328200E+05, -.11087400E+05, -.20028800E+05, -.36622000E+05, 0.31798200E+05, -.17052900E+05, -.53600800E+04, -.15899000E+05, -.48677400E+04, 0.62467600E+03, 0.22077200E+04, 0.73824800E+04, 0.11947300E+04, 0.32246300E+03, -.75355000E+04, 0.12200100E+06, -.61387500E+05, -.47923100E+05, -.61000500E+05, -.71928200E+04, -.24297600E+05, -.86813800E+04, 0.18658100E+05, -.37752500E+05, -.21630600E+05, -.62908600E+05, 0.60369600E+04, -.63676300E+04, 0.37461200E+04, -.30183400E+04, 0.13342900E+05, -.25286100E+04, -.91426300E+04, -.58763700E+04, -.10112800E+05, 0.78713100E+01, -.85827400E+04, -.53749500E+05, 0.27862600E+05, 0.13874100E+05, 0.26874600E+05, 0.53288200E+04, 0.14701200E+05, 0.26378400E+03, -.16072100E+05, 0.79647900E+04, 0.12466200E+05, 0.27886700E+05, 0.44471900E+05, -.22747400E+05, -.17590400E+05, -.22235900E+05, -.48580800E+04, -.11832700E+05, -.24626900E+04, 0.80485600E+04, -.14780600E+05, -.10100900E+05, -.24484700E+05, -.23531800E+05, 0.10453400E+05, -.47359700E+04, 0.11765900E+05, -.14808700E+05, -.61049400E+04, 0.15145900E+05, 0.12345900E+05, 0.21218100E+05, -.59860600E+04, 0.16679000E+05, -.18537900E+03, 0.17982900E+04, -.27052100E+04, 0.92718500E+02, 0.51443200E+03, -.21013800E+04, 0.29917900E+04, 0.28353000E+04, 0.36397100E+04, -.36763300E+04, 0.89412100E+03, -.36454100E+04, 0.36194800E+03, 0.19317100E+03, 0.21343200E+04, 0.15521700E+04, 0.72168100E+03, -.59307700E+03, -.14766900E+04, -.57496400E+04, 0.12060700E+04, 0.39715500E+04, 0.17457300E+04, 0.87477400E+04, -.23972200E+04, -.11392300E+03, 0.19981200E+04, 0.68317700E+04, 0.10704900E+04, 0.65790400E+04, -.19967400E+04, 0.55922600E+04, -.16312300E+04, -.46766900E+04, 0.26480200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.49702800E+00, 0.89497400E-01, -.85166500E-01, 0.11517200E+00, 0.14968400E+00, -.32133600E+00, 0.13179500E-01, -.10581800E+00, -.20148200E-01, 0.63792800E-01, -.45635500E-01, -.10726500E-01, 0.11106400E+01, 0.62217500E+00, 0.50572500E-01, -.58326300E-01, 0.26445700E+00, 0.51222700E+00, -.25285700E-01, -.45393400E-01, -.67521000E+00, -.59699900E+00, 0.83583000E+00, -.48751000E+00, 0.35515100E-01, 0.13175000E+00, -.24627000E-02, 0.97989300E-01, 0.11876600E+00, 0.10943500E+04, 0.16690300E+03, -.13944500E+03, -.70682300E+03, -.36227500E+04, 0.20390600E+04, 0.25819300E+04, 0.18114200E+04, -.25699700E+03, -.19452800E+02, 0.34512300E+03, -.99217600E+03, 0.15256000E+04, -.18636300E+03, 0.18797900E+04, 0.26205900E+04, -.14267700E+04, -.16151500E+04, -.13105100E+04, -.87654200E+03, 0.92791700E+02, 0.16372200E+03, -.43590900E+03, -.94893100E+03, 0.27181700E+03, 0.68230800E+03, 0.27347400E+04, -.13638100E+04, -.45959700E+03, -.13673400E+04, -.37616400E+03, 0.11183300E+04, -.88459400E+03, 0.59773000E+03, -.92764800E+03, 0.80215900E+03, -.79882800E+03, 0.46651800E+04, -.25201100E+04, -.29168300E+04, -.23326500E+04, -.91133400E+03, 0.19013300E+04, -.11448400E+04, -.76557200E+03, -.13209000E+04, 0.17980000E+04, 0.64155000E+03, 0.12078400E+04, -.43368500E+03, -.84524100E+02, -.60383800E+03, 0.18278700E+03, -.23662200E+04, 0.48212600E+02, 0.80956900E+03, -.11628100E+04, -.20696400E+04, -.33504700E+04, 0.83826500E+04, -.41882500E+04, -.28953800E+04, -.41913100E+04, -.36887400E+03, -.25051200E+04, 0.72703100E+03, 0.23162500E+04, -.18596900E+04, -.19344900E+04, -.52472200E+04, 0.24019000E+03, -.16031300E+03, -.41775400E+03, -.12017400E+03, -.29524400E+03, 0.19310100E+03, 0.82852900E+02, -.48569600E+03, -.35982300E+03, 0.28712400E+03, 0.77766700E+03, 0.56580400E+04, -.30483200E+04, -.37906900E+04, -.28290700E+04, -.33945200E+03, -.28121100E+03, -.17401600E+04, -.11075900E+04, -.22231500E+04, -.15215600E+03, -.23466200E+04, 0.11306200E+04, -.40618300E+03, 0.36327000E+04, -.56527500E+03, -.91388500E+02, 0.37207600E+04, -.36697300E+04, -.29293000E+04, -.25813900E+04, 0.28511200E+04, 0.20755700E+04, -.33819800E+03, 0.14706400E+03, -.18031600E+04, 0.16908800E+03, -.57753300E+03, -.30038100E+04, 0.29919400E+04, 0.20276800E+04, 0.13385100E+04, -.25161900E+04, -.10967700E+04, 0.50052200E+04, -.24407300E+04, -.23307600E+04, -.25026500E+04, -.61688500E+03, 0.40051100E+04, -.31024200E+04, -.26306600E+04, -.25929600E+04, 0.37893400E+04, -.48530300E+03, -.49212600E+04, 0.28459000E+04, 0.31670700E+04, 0.24608100E+04, 0.51399100E+03, 0.58895900E+03, 0.67264300E+03, -.14124600E+03, 0.14615700E+04, 0.32081000E+03, 0.31086600E+04, 0.22807000E+04, -.13745200E+04, -.37865100E+04, -.11403600E+04, -.41578700E+03, -.38678400E+04, 0.26089200E+04, 0.21584900E+04, 0.86872300E+03, -.30779100E+04, -.31118800E+04, 0.72560600E+04, -.37562300E+04, -.36363200E+04, -.36280300E+04, -.98407400E+03, 0.52402200E+04, -.57235000E+04, -.46541200E+04, -.37185100E+04, 0.49141300E+04, -.56059400E+03, -.19094400E+04, 0.90785100E+03, -.24788500E+04, 0.95470700E+03, -.30347900E+02, -.40533100E+04, 0.38210000E+04, 0.22916700E+04, 0.23427700E+04, -.31955000E+04, -.19781500E+04, 0.82671100E+03, -.78973500E+03, -.10555300E+04, -.41323700E+03, 0.35174400E+03, -.45018500E+04, 0.13454800E+04, 0.40637400E+04, -.82437100E+03, -.41783100E+04, -.46749700E+04, -.97882300E+02, 0.18179300E+03, 0.21264200E+02, 0.48901500E+02, 0.37829700E+03, 0.23460200E+04, -.17776500E+04, -.11900800E+04, -.11132100E+04, 0.19647100E+04, 0.16847700E+04, 0.53329600E+04, -.27163700E+04, -.17498300E+04, -.26664900E+04, -.84740600E+03, -.27442300E+04, 0.13253900E+04, 0.21238700E+04, -.98127000E+03, -.22305300E+04, -.32007500E+04, -.18768800E+04, 0.79190600E+03, 0.40491100E+03, 0.93836700E+03, 0.12726500E+03, 0.24944800E+04, -.97605200E+03, -.28784500E+04, 0.10356300E+04, 0.24244900E+04, 0.44287600E+04, -.31288600E+04, 0.17578600E+04, 0.13460000E+04, 0.15644600E+04, -.34706300E+03, -.19898900E+04, 0.36327600E+04, 0.24645600E+04, 0.26274400E+04, -.18493400E+04, 0.67713500E+03, -.11505000E+04, 0.55207400E+02, -.21131500E+03, -.10970500E+03, 0.48658600E+03, 0.74974500E+02, -.10415600E+03, -.18884100E+03, 0.20121200E+03, 0.36588600E+03, -.34937200E+03, 0.79142200E+03, 0.19907200E+04, -.10025100E+04, 0.84950100E+01, 0.88514700E+03, 0.14105400E+04, 0.51220800E+03, 0.20703600E+04, 0.30451100E+03, 0.14634700E+04, -.87090900E+02, 0.77003800E+03, 0.10154300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34514800E+01, 0.10479300E+01, 0.64304600E-01, -.25123000E+01, -.17466700E+01, -.38260000E+00, 0.44477000E+00, 0.19229900E+01, -.69171900E+00, -.11427100E+00, 0.18596200E-02, 0.41655000E+00, 0.54170400E+01, 0.14268900E+01, -.68068800E+00, 0.18815700E-01, -.10519600E+00, 0.22097600E+01, 0.50603800E+00, -.10395400E+01, 0.40905100E+00, 0.16785200E+01, -.59959500E+00, 0.76461400E+00, 0.89367500E-01, -.16981100E+01, -.20344300E+00, 0.29898100E+00, -.29423400E+00, -.58553100E+00, -.72941200E+04, 0.10185200E+04, 0.16629900E+04, 0.11998000E+05, -.28594400E+04, -.16638600E+04, -.59993500E+04, 0.39457300E+04, 0.11123200E+04, -.24376700E+04, 0.56624500E+04, 0.70527000E+04, -.41806100E+03, -.67866100E+04, -.40605600E+05, 0.17575900E+05, 0.15491300E+05, 0.20304700E+05, 0.11387900E+04, -.35545200E+04, 0.76424200E+04, -.57550400E+04, 0.11802900E+05, -.39095100E+04, 0.17538300E+05, 0.12468800E+04, -.62572900E+03, 0.67243000E+04, -.62363200E+03, 0.16309000E+04, 0.47896300E+04, -.11367300E+04, 0.74087600E+03, -.72428200E+04, 0.43378100E+04, -.19269500E+03, -.20204500E+05, 0.81351800E+04, 0.39276500E+04, 0.10102600E+05, 0.58121400E+04, 0.16893300E+05, -.73528600E+04, -.11845900E+05, -.10164900E+05, 0.15374100E+05, 0.33227400E+04, 0.30537100E+05, -.14114300E+05, -.78498500E+04, -.15269300E+05, -.16760900E+05, -.30242500E+05, 0.91443100E+04, 0.12349000E+05, 0.12182600E+05, -.28042100E+05, -.28268500E+04, -.44592400E+05, 0.23348600E+05, 0.21929000E+05, 0.22295700E+05, 0.37239700E+04, -.10079400E+05, 0.10166100E+05, -.12797200E+05, 0.10955100E+05, -.72747300E+04, 0.60856300E+03, -.11753200E+05, 0.50620500E+04, 0.49968700E+04, 0.58771400E+04, -.70977300E+03, -.49122200E+04, 0.40110000E+04, -.81375600E+02, 0.32946700E+04, -.43725000E+04, 0.70557200E+04, -.66741900E+04, -.28088800E+03, -.13968600E+05, 0.33376800E+04, 0.29217200E+04, -.67440000E+04, 0.17188900E+04, 0.17628900E+04, 0.12585400E+05, -.92354400E+04, -.14590000E+04, 0.19851400E+06, -.96076000E+05, -.49116800E+05, -.99257200E+05, -.92289300E+04, 0.11226000E+05, -.33597100E+05, 0.34102800E+05, -.61333800E+05, 0.91805100E+04, -.59552100E+05, -.77963500E+05, 0.38157800E+05, 0.16808600E+05, 0.38981900E+05, 0.12005300E+05, -.63245700E+04, 0.15051800E+05, -.80723200E+04, 0.29589800E+05, -.38668200E+04, 0.22663300E+04, -.29788700E+04, 0.31650600E+04, 0.44831600E+04, 0.14977600E+04, -.25051100E+04, 0.35926700E+04, -.11234900E+04, -.40830100E+04, -.77982800E+03, 0.61027700E+04, -.91568200E+04, 0.71239400E+04, 0.27247400E+04, 0.82825500E+04, -.35642200E+04, 0.51072100E+04, 0.10594400E+05, -.41571300E+04, -.30113100E+03, -.13084400E+05, 0.98276100E+04, 0.12954100E+04, -.15327100E+06, 0.71883100E+05, 0.39153800E+05, 0.76635600E+05, 0.33743900E+04, -.12370800E+05, 0.24161200E+05, -.30466700E+05, 0.42399700E+05, -.11263800E+05, 0.62478000E+05, -.47481100E+04, 0.54313700E+03, -.41631300E+04, 0.23738700E+04, -.64878500E+04, -.10733800E+05, 0.51752000E+04, 0.52289000E+04, 0.20443400E+05, -.91775500E+04, -.31966800E+04, -.17218000E+06, 0.84674400E+05, 0.47482600E+05, 0.86090200E+05, 0.11952100E+05, -.16508400E+05, 0.32309200E+05, -.27241300E+05, 0.58493100E+05, -.12742600E+05, 0.36592700E+05, 0.24902200E+05, -.20994100E+05, -.30444500E+05, -.12452600E+05, -.42609400E+05, -.57745400E+05, 0.25472100E+05, 0.30607200E+05, 0.13942200E+05, -.54897900E+05, 0.39053800E+05, 0.75237700E+05, -.34895700E+05, -.34065500E+05, -.37618200E+05, 0.35884800E+03, 0.85179100E+04, -.12328000E+05, 0.15989700E+05, -.17676500E+05, 0.83976200E+04, -.30917800E+05, -.22107900E+05, 0.99347100E+04, 0.13704100E+05, 0.11054000E+05, 0.21763600E+04, -.11964400E+05, 0.92937200E+04, -.22772100E+04, 0.79355100E+04, -.92722600E+04, -.44202600E+04, -.46763500E+05, 0.22402000E+05, 0.15241200E+05, 0.23382500E+05, 0.26254200E+05, 0.33579800E+05, -.11650500E+05, -.26634000E+05, -.94324800E+04, 0.32677000E+05, 0.34998000E+04, -.22455700E+05, 0.14654600E+05, 0.14130400E+05, 0.11227500E+05, 0.85186400E+04, 0.17521900E+05, -.68816900E+04, -.13075500E+05, -.42548900E+04, 0.17375100E+05, -.26649600E+04, 0.81081500E+03, 0.16307900E+03, -.11342000E+04, -.15522700E+04, 0.12913800E+04, 0.15369600E+04, -.35298000E+03, 0.11234000E+04, 0.98752000E+04, 0.74672300E+03, -.81380400E+04, -.31462400E+03, 0.10210300E+05, 0.32692900E+02, 0.78577300E+03, -.11677300E+03, 0.13078300E+05, 0.41091500E+03, 0.59559800E+04, 0.12397900E+05, 0.12020200E+05, 0.19524500E+04, 0.18691500E+05, -.39734300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.48926600E+01, -.15334200E+01, -.61255800E+00, 0.34676400E+00, 0.34413500E+01, -.18994900E+01, -.49574800E+00, 0.35652600E+01, -.10794200E+01, -.15005900E+01, 0.11025300E+01, 0.29066800E+01, 0.61276900E+01, 0.39787600E+01, 0.12813000E+01, -.74235000E+00, 0.12289700E+01, 0.15193600E+01, 0.59876500E+00, -.26876300E+00, 0.32274400E+00, -.18043500E+00, -.35396700E+01, 0.98431500E+00, -.11811700E+00, -.22735300E+00, 0.38311900E+00, 0.88028500E+00, 0.10667400E+01, -.56794500E+01, 0.14148300E+01, -.25874800E+04, 0.78970300E+03, 0.43058100E+04, -.78246200E+04, -.31738900E+04, -.21523600E+04, -.16819000E+05, -.92879500E+04, -.46650500E+04, -.23649300E+05, -.19315900E+05, -.39721000E+04, 0.48846000E+04, 0.17604800E+05, -.41005300E+04, -.56233300E+04, -.88046800E+04, 0.31120000E+04, 0.13068500E+05, -.83928900E+04, -.10845500E+05, -.12898300E+05, 0.17602000E+05, 0.35131800E+04, 0.31561700E+05, -.15815100E+05, -.16214300E+05, -.15780500E+05, -.48469600E+04, -.52339000E+04, -.88527600E+04, -.75121800E+04, -.10634200E+05, -.54830100E+04, -.33780300E+04, 0.24918200E+05, -.89893800E+04, -.12755200E+05, -.12459800E+05, -.91936400E+04, 0.15270200E+04, -.11078800E+05, -.76764700E+04, -.49824400E+04, 0.17918900E+04, 0.39440000E+05, -.42397900E+05, 0.19063400E+05, 0.13831000E+05, 0.21199900E+05, 0.10796400E+05, 0.81822600E+04, 0.75010200E+04, -.13075300E+04, 0.87544100E+04, 0.76905100E+04, -.39371800E+05, 0.71955200E+05, -.37672800E+05, -.90049500E+04, -.35977500E+05, 0.15508400E+05, 0.44089800E+05, -.37280000E+05, 0.51523000E+04, -.22539600E+05, 0.35027100E+05, -.38635100E+04, -.21375400E+05, 0.12156500E+05, 0.41675700E+04, 0.10686800E+05, 0.36861700E+04, 0.12337500E+05, -.17917600E+04, -.95265000E+04, -.31062000E+03, 0.13947600E+05, 0.10560100E+05, 0.54786600E+05, -.21293800E+05, 0.24449100E+05, -.27393800E+05, -.18319400E+04, 0.38625400E+05, -.57992300E+05, -.55757300E+05, -.56086600E+05, 0.40744600E+05, -.56264200E+04, -.12297900E+06, 0.56371200E+05, -.16146100E+05, 0.61489700E+05, -.11977800E+05, -.38306000E+05, 0.24862200E+05, -.31934800E+05, 0.31744400E+05, -.37615600E+05, 0.14891300E+05, -.91724800E+04, 0.57787300E+04, 0.33113800E+05, 0.45861300E+04, 0.23088100E+04, 0.32793300E+05, -.11227200E+04, 0.10548600E+05, -.82528000E+03, 0.29038700E+05, 0.61789400E+05, 0.21591300E+05, -.13519700E+05, -.32677500E+05, -.10807200E+05, -.89761200E+03, 0.15578500E+05, -.15871400E+05, -.13448900E+05, -.27202700E+05, 0.12412100E+05, 0.35245300E+05, -.57561300E+05, 0.17842100E+05, 0.38704800E+04, 0.28782500E+05, -.60745100E+04, -.36551700E+05, 0.35448600E+05, 0.21139700E+05, 0.42177500E+05, -.34805500E+05, 0.36185300E+04, 0.16045800E+06, -.72357200E+05, 0.97997200E+03, -.80229400E+05, 0.17273200E+05, 0.38189000E+05, -.42944000E+05, 0.22835700E+04, -.61146000E+05, 0.37580400E+05, -.80078900E+05, 0.62361700E+05, -.28003100E+05, -.15335400E+05, -.31180900E+05, -.15902200E+04, 0.56968700E+05, -.64650300E+05, -.62542800E+05, -.94094900E+05, 0.56659500E+05, 0.16155000E+05, 0.45400700E+05, -.20674600E+05, 0.29344100E+05, -.22700500E+05, 0.10717100E+05, 0.52788500E+05, -.13121300E+05, 0.29808200E+05, -.12530900E+05, 0.47508600E+05, 0.38388900E+05, -.17503800E+06, 0.10202200E+06, 0.11611900E+06, 0.87520400E+05, 0.45478200E+05, 0.29622700E+05, 0.11083200E+05, -.33506700E+05, 0.34444800E+05, 0.33369500E+05, -.78992100E+05, -.49818800E+05, 0.20498500E+05, 0.98202500E+04, 0.24909000E+05, -.14681100E+05, -.26873400E+05, 0.19221300E+05, 0.10186400E+04, 0.23165600E+05, -.26653500E+05, 0.30841500E+05, 0.19870300E+04, 0.83867900E+03, 0.80957500E+04, -.99362500E+03, 0.91303100E+04, 0.31550800E+05, -.12853600E+05, -.44817500E+04, 0.15329700E+04, 0.27556500E+05, 0.20267600E+05, 0.17649000E+06, -.86331000E+05, -.66245700E+05, -.88245800E+05, -.15286900E+05, -.33523500E+04, -.30127300E+05, 0.16070100E+05, -.47904800E+05, -.76558600E+04, -.11999700E+04, -.22042000E+05, 0.51498600E+04, -.88456100E+04, 0.11021300E+05, -.94143700E+04, -.37663200E+05, 0.49515100E+05, 0.57593500E+05, 0.40781000E+05, -.36719600E+05, 0.36030100E+05, -.10685300E+05, 0.42580000E+03, 0.45436700E+03, -.90611700E+03, -.38799900E+03, -.49302300E+04, 0.12726500E+04, -.19012300E+04, -.86590200E+04, 0.32376500E+04, 0.10101900E+05, 0.40983400E+04, -.29844100E+05, 0.48262300E+04, -.21384200E+04, 0.69350800E+04, -.30162700E+05, 0.14115100E+04, -.19367300E+05, -.16212400E+05, -.29863100E+05, -.85718100E+04, -.19865300E+05, 0.11639900E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11978000E+01, 0.12973100E+00, 0.56529900E+00, -.83172100E+00, -.31142300E+00, -.58866700E+00, 0.84755100E-01, 0.34800900E+00, -.48014300E+00, -.23656900E+00, -.12476400E+01, -.38548300E+00, -.53519000E+00, -.25972800E+00, 0.18575400E+00, 0.24890400E+00, -.25706800E+00, 0.38895000E+00, 0.27577000E+00, -.94064100E+00, 0.15500300E+00, -.17530000E+00, 0.20987000E+00, -.22299300E+00, -.17632200E-01, 0.10460600E+00, 0.25550900E+00, 0.80065100E-01, 0.20963500E+00, 0.10079300E+01, 0.12369300E+00, 0.92698200E-01, 0.28245400E+04, 0.28476900E+04, -.18066800E+04, 0.55376900E+04, -.14236900E+04, -.66278100E+03, 0.51250900E+04, -.38228400E+04, -.23827400E+04, -.36059000E+04, 0.36790500E+04, 0.84821700E+03, 0.70455000E+04, -.34168400E+04, -.43638100E+04, -.35234900E+04, 0.65350600E+03, 0.16016500E+04, -.32850400E+04, 0.73510900E+03, -.31942400E+03, 0.10450400E+04, -.54757300E+04, 0.24570500E+04, -.12431300E+04, 0.17220600E+04, -.12284300E+04, -.20770900E+03, 0.13534700E+04, -.16839600E+04, -.95635500E+03, -.10746400E+04, 0.95692700E+03, 0.12361300E+04, -.40320200E+04, 0.23589900E+04, -.71620600E+04, 0.20158300E+04, -.27806200E+03, -.21068100E+04, 0.83523200E+03, 0.12402100E+04, 0.60253900E+04, -.23982600E+04, 0.40587400E+04, -.11399500E+04, 0.25721700E+03, 0.13327800E+04, 0.57026100E+03, 0.23360500E+04, 0.47444100E+04, -.58282000E+03, -.13982200E+03, -.44957900E+04, 0.45225500E+04, -.43007600E+04, 0.10587600E+05, -.52067300E+04, -.15431000E+05, -.52937100E+04, -.47734000E+04, -.74389900E+04, 0.22313700E+04, 0.66875600E+04, 0.66355000E+04, -.64405100E+04, 0.25485500E+04, 0.25937900E+04, -.12935800E+04, -.19673000E+04, -.12971400E+04, 0.54708700E+03, -.40165000E+03, -.78136000E+03, -.21676700E+02, -.39914100E+02, -.34715100E+03, -.31254700E+04, -.10771800E+05, 0.57728300E+04, -.16407200E+05, 0.53857000E+04, -.42785600E+04, -.31335900E+04, 0.26747100E+04, -.21482300E+04, 0.10623700E+05, -.33081500E+04, 0.11421900E+05, -.20521000E+05, 0.99621100E+04, 0.31250200E+05, 0.10260600E+05, 0.60665600E+03, -.15440800E+01, 0.68554600E+04, -.39159600E+04, 0.10709300E+04, 0.32398500E+03, 0.65742600E+03, 0.33247900E+04, -.15788500E+04, -.15543300E+05, -.16624400E+04, 0.34644900E+03, 0.11951700E+04, -.33841500E+04, 0.61483700E+03, 0.28928300E+04, 0.38543700E+03, 0.42620100E+04, -.29684900E+04, 0.14036000E+04, 0.46839400E+04, 0.14841700E+04, 0.38173900E+04, 0.17865100E+04, -.14979300E+03, 0.12799400E+03, -.20471600E+04, 0.87259000E+03, 0.23208500E+04, 0.59603700E+04, -.36102800E+04, 0.14631700E+05, -.29794500E+04, 0.46336300E+03, -.18947600E+04, 0.22116800E+04, 0.18653200E+04, -.28326200E+04, -.96934600E+03, -.98895600E+04, 0.18746900E+04, -.58680600E+03, -.22352200E+05, -.93738100E+03, -.96747900E+03, -.26715600E+03, -.30638400E+04, 0.40833400E+04, 0.51746400E+04, -.89151900E+02, 0.55250900E+04, -.16127400E+05, 0.82839800E+04, -.30931700E+04, 0.80637200E+04, 0.31855500E+04, 0.62091100E+04, -.14563300E+04, -.54983400E+04, 0.20845300E+04, 0.41367500E+04, 0.82653100E+04, 0.16606200E+05, -.81629700E+04, -.30782900E+05, -.83031600E+04, 0.22843800E+03, 0.12434700E+04, -.59771800E+04, 0.40360100E+04, -.21561300E+03, 0.30504200E+03, 0.51367500E+03, 0.92658400E+04, -.40969200E+04, -.10678600E+05, -.46324300E+04, 0.46018000E+04, 0.42622600E+04, -.49881500E+04, -.10846100E+05, -.95971400E+04, 0.54479700E+04, -.13264600E+05, -.54921900E+04, 0.25688300E+04, 0.12369800E+05, 0.27459000E+04, 0.11567300E+04, 0.72708200E+03, 0.23442300E+04, -.18621000E+04, -.10672000E+04, 0.43699500E+03, -.55094500E+03, 0.10890100E+05, -.53316700E+04, -.81919700E+04, -.54450800E+04, -.20731600E+04, -.33701700E+04, -.70028300E+03, 0.36379600E+04, 0.28640400E+03, -.27271500E+04, -.86529000E+03, -.12698500E+05, 0.66015200E+04, 0.54483500E+04, 0.63489700E+04, -.33486100E+04, -.48009400E+04, 0.62099200E+04, 0.79264300E+04, 0.98676500E+04, -.48475400E+04, 0.11199900E+05, 0.11114000E+05, -.58586600E+04, 0.13168700E+04, -.55568600E+04, -.12497400E+03, 0.15296500E+04, -.37293700E+04, 0.24305700E+04, -.14162700E+04, 0.81404800E+03, -.32810700E+04, 0.76093500E+03, 0.33246500E+03, -.80644700E+02, 0.36195900E+03, 0.98244100E+03, -.26533100E+03, -.42821200E+03, -.13271600E+03, -.80080700E+03, -.21006100E+04, 0.15307000E+04, 0.95029500E+02, 0.12661800E+04, -.32938300E+04, 0.92221300E+03, -.34529700E+03, 0.10607200E+04, -.79076600E+02, 0.25436400E+04, -.19049000E+03, 0.27149000E+04, 0.43519600E+04, -.10241000E+04, -.22453500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16850700E+01, -.56774000E-01, 0.45574100E-01, 0.45805700E+00, 0.69591900E+00, -.26538100E+00, -.15200100E+00, 0.19897800E+00, -.10127800E+00, -.26817500E+00, -.23411800E+00, -.84496600E-01, -.31586500E+01, -.12049500E+01, 0.60616300E+00, 0.17368500E+00, -.42751900E+00, -.17837100E+00, 0.12019700E-02, -.79446700E+00, 0.22508700E+00, -.26419200E+01, 0.44052100E+00, -.64779700E+00, 0.17702000E-01, 0.57947400E+00, -.14794200E-01, -.13115400E+00, -.29064700E+00, 0.21852300E+01, -.27647300E+00, 0.81087500E-01, 0.43107000E+00, -.19220400E+05, 0.11861200E+05, 0.52942500E+04, 0.96094100E+04, 0.51409300E+04, -.30113900E+03, 0.77673600E+04, 0.90379900E+04, 0.11778800E+05, -.12710200E+04, 0.60992500E+04, 0.74641600E+04, -.49813800E+04, -.21689900E+04, -.37287500E+04, -.22544400E+04, -.32302700E+03, -.32446700E+04, 0.64143900E+03, -.84406800E+03, -.15737800E+04, -.28999800E+04, -.68861900E+04, 0.35141700E+04, 0.15363600E+04, 0.34425500E+04, 0.52984900E+03, 0.14438200E+04, 0.23641500E+04, 0.13561400E+04, 0.18475500E+04, 0.11148100E+04, 0.15493400E+04, 0.28495200E+05, -.15867100E+05, -.46626200E+04, -.14246600E+05, -.27085100E+04, 0.13673600E+04, -.50744600E+04, 0.11262600E+04, -.10628600E+05, 0.14436600E+04, -.15147900E+05, -.18725400E+05, 0.10659000E+05, 0.86117800E+04, 0.93613800E+04, 0.21681600E+04, 0.26462100E+03, 0.26284900E+04, -.16666100E+04, 0.53469800E+04, 0.20918700E+03, 0.14410300E+05, 0.22211000E+05, -.11149900E+05, -.54010100E+04, -.11105500E+05, -.60798700E+04, -.11698200E+05, 0.56003600E+03, 0.23952900E+04, -.42560100E+04, -.92283600E+04, -.12817400E+05, 0.12739800E+05, -.67293500E+04, -.31078300E+04, -.63686000E+04, -.18186800E+04, -.23176100E+03, -.41168600E+04, -.10841300E+04, -.31254400E+04, -.97251300E+03, -.40607500E+04, 0.51273100E+04, -.48484300E+04, -.14743100E+03, -.25629200E+04, -.23789700E+04, -.13075000E+05, 0.15103600E+05, 0.16980700E+05, 0.72546200E+04, -.13099300E+05, -.68624200E+04, -.35723900E+05, 0.19761100E+05, 0.14816400E+05, 0.17861500E+05, 0.58209300E+04, 0.10858000E+05, 0.88160500E+04, -.36337700E+03, 0.90160600E+04, 0.10649700E+05, 0.22203300E+05, 0.25227700E+05, -.13182800E+05, -.51461000E+04, -.12613700E+05, -.77959400E+03, -.87020700E+04, -.55406300E+04, -.91565100E+03, -.63562800E+04, -.80994700E+04, -.19163900E+05, 0.85961500E+04, -.35296100E+04, 0.22559400E+04, -.42944900E+04, -.24776700E+04, 0.55250400E+04, -.33100300E+04, -.24709800E+04, -.18302000E+04, 0.60699600E+04, -.48426000E+04, -.81118600E+04, 0.80074800E+04, -.52601000E+04, 0.40532700E+04, 0.67568100E+03, 0.71867200E+04, -.45302700E+04, -.77563600E+04, 0.10666300E+04, 0.55328000E+04, 0.87199800E+04, 0.17841700E+05, -.11491000E+05, -.89155000E+04, -.89205800E+04, -.56877400E+04, -.99146300E+04, -.24817000E+04, 0.91827100E+04, 0.17326600E+03, -.93577200E+04, -.92966000E+04, 0.15122300E+05, -.87951100E+04, 0.32386100E+03, -.75610200E+04, -.14244500E+04, -.39247100E+04, 0.65252300E+04, 0.69254700E+04, 0.34220600E+04, -.23960300E+04, -.75653800E+04, 0.39538900E+05, -.20628700E+05, -.90573900E+04, -.19769200E+05, -.38960600E+04, -.13459900E+05, -.91026600E+04, -.24436400E+04, -.11246500E+05, -.12378500E+05, -.26658900E+05, 0.24175600E+05, -.16372600E+05, -.81801800E+04, -.12089600E+05, -.44255100E+04, -.60400600E+04, -.14747800E+04, 0.51653300E+04, -.60526100E+04, -.69169800E+04, -.18445300E+04, -.22885200E+05, 0.12771000E+05, 0.51414800E+04, 0.11443100E+05, 0.33205000E+04, 0.69573800E+04, 0.30527600E+04, -.58791700E+04, 0.40536200E+04, 0.62545700E+04, 0.11431000E+05, 0.14988200E+05, -.82466600E+04, -.59965600E+04, -.74939400E+04, -.27249700E+04, -.75603200E+04, -.11249000E+04, 0.29066500E+04, -.31985800E+04, -.69194500E+04, -.10278700E+05, -.29638200E+05, 0.13718700E+05, 0.55098800E+04, 0.14820300E+05, -.15615500E+04, -.31862100E+04, 0.87528000E+04, 0.19887500E+04, 0.10659300E+05, -.20465400E+04, 0.86475300E+04, 0.12714000E+04, 0.13063800E+04, -.18278500E+04, -.63616200E+03, 0.37351300E+04, 0.70353400E+04, -.11275100E+05, -.97855700E+04, -.40850100E+04, 0.64384400E+04, -.21165800E+04, -.13815100E+04, 0.60603600E+02, -.10137900E+03, 0.47329000E+03, 0.47354600E+03, 0.12179700E+04, -.32248000E+03, -.48793900E+03, -.53119300E+03, 0.67139700E+03, 0.51057500E+02, 0.12488900E+04, 0.50471500E+04, -.41741400E+03, -.15424300E+03, 0.66653800E+03, 0.39969500E+04, 0.36605900E+03, 0.26846000E+04, 0.19401400E+04, 0.26839700E+04, 0.17249700E+03, 0.10253100E+04, 0.38108300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.62280000E+01, -.83770500E-01, 0.15418900E+01, -.40877300E+01, -.53666800E+01, -.17140600E+01, 0.12695400E+01, -.16620800E+00, -.18564500E-01, -.22697400E-01, -.33709500E+01, -.29085100E+01, -.80052600E+01, -.46306200E+01, 0.52205100E+00, 0.10572700E+01, -.90636500E+00, -.14092000E+01, -.25117300E+00, -.28201900E+01, 0.89207400E+00, -.39812200E+01, -.31702900E+01, -.42297600E+00, 0.25967600E+00, 0.66306200E+00, -.30185700E+00, -.11716700E+01, -.95599700E+00, 0.90479500E+01, -.87409800E+00, -.72320600E+00, 0.18642500E+01, 0.16963200E+01, -.12281000E+05, 0.10921500E+04, 0.10334600E+01, -.71232700E+04, 0.24449200E+04, 0.81630600E+03, -.57878300E+04, -.16599500E+05, 0.42586500E+04, -.35568600E+04, 0.13620100E+05, 0.22278900E+04, -.48518600E+04, -.68141700E+04, 0.11532800E+04, 0.68476800E+04, -.12606400E+04, 0.57481600E+04, -.75692900E+04, 0.71369200E+04, -.38225500E+04, -.53205400E+04, 0.25196200E+04, -.32625400E+04, 0.26609900E+04, -.33351800E+04, -.46687600E+04, 0.44044300E+04, 0.42675200E+04, 0.35687500E+04, -.31740300E+04, -.71096200E+03, 0.96876100E+04, 0.34012700E+04, -.80132900E+04, -.48451600E+04, 0.84707500E+03, -.15679700E+05, 0.10308700E+05, 0.13971700E+05, 0.15882800E+05, -.14963100E+05, 0.64566700E+04, 0.82688000E+04, -.97674300E+04, -.68084800E+04, -.41327600E+04, 0.68762800E+04, 0.32569400E+05, -.21137300E+05, -.18252200E+05, -.23884100E+05, 0.30857000E+05, -.15852800E+05, 0.82883700E+04, -.65732600E+04, -.10706400E+05, -.41443100E+04, 0.60737200E+04, 0.18439600E+05, -.12251900E+05, 0.23010700E+03, -.68317000E+04, 0.14920400E+05, 0.24726300E+05, -.35256700E+04, 0.45471200E+04, 0.17497800E+04, 0.17611700E+04, 0.18921400E+04, 0.45487400E+04, 0.13124600E+03, 0.65216400E+03, -.92551300E+03, 0.44512300E+04, 0.14774900E+04, 0.82394100E+04, 0.89662800E+04, 0.91416100E+04, -.41205500E+04, 0.76268600E+04, 0.17511100E+05, -.10494900E+05, -.32103400E+04, -.13357300E+05, 0.19884100E+05, -.94514200E+04, -.14606500E+06, 0.62352000E+05, 0.22371500E+05, 0.73032900E+05, 0.10574600E+05, -.17216100E+05, 0.21479100E+05, -.31803200E+05, 0.48088900E+05, -.14147200E+05, 0.15705300E+05, 0.46698700E+05, -.20811200E+05, -.40856100E+04, -.23349600E+05, -.16524900E+05, 0.92224900E+04, -.92942000E+04, 0.53953600E+04, -.21601600E+05, 0.58696200E+04, 0.31796700E+05, 0.41227000E+04, -.73067500E+04, -.99283600E+04, -.20684600E+04, 0.51722000E+04, -.51993900E+04, 0.18165900E+04, 0.66116900E+04, -.24670800E+04, -.75958300E+04, 0.17132700E+05, -.15169200E+05, -.15409200E+05, 0.45287300E+04, 0.75876200E+04, -.10135700E+05, -.14103200E+05, 0.79161700E+04, -.50074100E+04, 0.95353200E+04, -.12334300E+05, -.57835800E+04, 0.13880700E+06, -.53592000E+05, -.26971600E+05, -.69403700E+05, -.24003700E+04, 0.17710700E+05, -.20228600E+05, 0.21660600E+05, -.52390300E+05, 0.15568600E+05, -.49704400E+05, 0.10779100E+05, 0.15394600E+04, -.66998800E+04, -.53898300E+04, 0.13097100E+05, 0.16688000E+05, -.11362800E+05, -.29982700E+04, -.30148500E+05, 0.14295900E+05, 0.62945400E+04, 0.12020400E+06, -.55766700E+05, -.22116400E+05, -.60102200E+05, -.16164700E+05, 0.23511000E+05, -.23249100E+05, 0.21709200E+05, -.44392500E+05, 0.18290500E+05, 0.12449000E+05, -.35652100E+05, 0.46565200E+05, 0.37564600E+05, 0.17828000E+05, 0.37777700E+05, 0.57774500E+05, -.18024400E+05, -.12495400E+05, -.25860500E+04, 0.54951900E+05, -.57346500E+05, -.66425800E+05, 0.24463100E+05, 0.30138900E+05, 0.33212400E+05, 0.13015900E+03, -.12618300E+05, 0.11519500E+05, -.89860700E+04, 0.25570800E+05, -.11335700E+05, 0.19819000E+05, 0.16488200E+04, 0.30711400E+04, -.61689100E+04, -.82462200E+03, 0.61218700E+03, 0.19075400E+05, -.10382200E+05, -.35952600E+04, -.45347600E+04, 0.15450900E+05, 0.21428200E+05, 0.59705600E+05, -.25020900E+05, -.21699400E+05, -.29854200E+05, -.10111200E+05, -.31358000E+05, 0.27443000E+04, 0.12309100E+05, -.19011600E+04, -.32229300E+05, -.49473400E+04, 0.18734800E+05, -.21562800E+05, -.95806500E+04, -.93668600E+04, -.16639100E+05, -.20745200E+05, 0.10124400E+05, 0.78510100E+04, -.10429100E+03, -.20066000E+05, 0.20288200E+05, -.20222500E+04, -.91035000E+03, 0.20183800E+04, -.12901900E+04, -.16490500E+03, -.31995900E+04, 0.18439900E+04, -.36421600E+03, -.84105100E+04, -.12049000E+04, 0.56988100E+04, 0.24488100E+04, -.10078900E+05, 0.51574700E+03, -.14109500E+04, 0.73677100E+03, -.12418600E+05, 0.11395900E+04, -.54313300E+04, -.14529800E+05, -.10592200E+05, -.21298800E+04, -.18647500E+05, 0.90014100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11203600E+01, -.17236800E+00, -.10380900E+00, 0.58636500E+00, 0.10765100E+01, 0.92803900E-01, -.13950000E+00, 0.41784900E+00, -.12103400E+00, 0.13818000E+00, 0.22712700E+00, -.17034600E+00, -.64815400E-01, 0.90806300E+00, -.16075500E-01, -.10087400E+00, 0.39508800E+00, -.40716400E+00, -.40456300E-01, 0.24319100E+00, -.36916600E+00, -.10652500E+01, -.30877600E+00, 0.17608900E+00, 0.53705100E-02, 0.21437400E+00, -.67732600E-01, -.20939500E+00, -.11670900E+00, -.12801700E+01, -.99293300E-01, 0.15925600E+00, -.49014200E+00, 0.31896900E+00, -.40884400E-01, 0.84571000E+04, 0.17744000E+00, -.24159900E+03, 0.34621000E+04, -.30239400E+04, -.18511900E+04, -.18067600E+03, 0.18038200E+04, 0.33540100E+04, -.39620700E+04, 0.19499600E+04, 0.79739800E+03, 0.19802400E+04, 0.58144500E+03, 0.15047000E+04, -.19549900E+04, -.35617900E+04, 0.58925500E+03, 0.10634200E+04, 0.22350000E+04, 0.76295000E+04, -.38153700E+04, 0.92045300E+03, -.38146300E+04, -.37288200E+03, 0.36463900E+04, -.38832800E+04, -.16632500E+04, -.31555400E+04, 0.28142000E+04, -.12527000E+04, 0.50205900E+04, -.25113100E+04, -.10661600E+05, -.25105200E+04, -.75676300E+03, 0.39428500E+04, -.36855300E+04, -.12586600E+03, -.15471200E+04, 0.36336700E+04, 0.11025700E+04, -.61349600E+03, 0.32374000E+03, 0.32417100E+04, 0.30705900E+03, -.10796800E+04, -.57880400E+04, 0.43421200E+04, 0.22686000E+04, 0.10807900E+04, -.53589300E+04, -.38205300E+04, 0.38658700E+04, -.19328000E+04, -.74068000E+04, -.19328800E+04, -.23377900E+04, -.10405200E+05, 0.14203400E+04, -.61281600E+03, 0.17294500E+03, -.77212100E+04, -.31675300E+04, -.24486900E+04, 0.11906400E+04, 0.63542400E+03, 0.12240600E+04, 0.23262400E+03, -.61950400E+03, -.19136800E+03, -.16259300E+04, 0.17336900E+03, -.52159900E+03, 0.10683400E+04, -.40720100E+03, 0.18150600E+03, -.22170200E+05, 0.20340900E+03, -.43614300E+04, -.79035100E+04, -.38886900E+03, -.16698900E+04, 0.39968600E+04, -.81666300E+04, 0.85311100E+04, 0.18819700E+05, -.93499400E+04, 0.19420900E+05, -.94097400E+04, -.24066900E+04, 0.67422500E+04, -.50370100E+03, 0.56656500E+04, -.82568900E+04, 0.56859700E+04, -.49485600E+04, -.11118200E+05, 0.55239000E+04, -.78340100E+04, 0.55590700E+04, 0.28046900E+04, -.27541600E+04, 0.18339700E+04, 0.13027700E+04, 0.66010200E+04, -.22044500E+04, 0.49326500E+03, 0.60997700E+04, -.30201900E+04, 0.26721500E+04, -.30486600E+04, 0.15931800E+04, 0.91402100E+04, -.43838900E+04, -.26458700E+04, -.55463100E+04, 0.88561400E+04, -.59508100E+04, -.34389300E+04, 0.17426600E+04, 0.16477600E+05, 0.17201700E+04, 0.27643400E+04, 0.38276700E+04, 0.24750400E+04, 0.30900200E+04, 0.42477200E+03, 0.32794900E+04, -.81456200E+03, -.22312500E+05, 0.11079400E+05, -.13638800E+05, 0.11156200E+05, 0.13295300E+04, -.71871000E+04, -.85133100E+03, -.87054900E+04, 0.74384400E+04, -.61914600E+04, 0.10236300E+05, 0.93855900E+03, -.47456000E+03, -.85100400E+04, -.46928800E+03, -.27755000E+04, 0.65054700E+04, -.58516300E+04, -.57256500E+04, -.16092700E+04, 0.57269500E+04, 0.14404300E+04, -.19545100E+05, 0.97258400E+04, -.13962700E+05, 0.97724800E+04, 0.31800200E+04, -.75332400E+04, 0.33889500E+04, -.12359100E+04, 0.98928100E+04, -.62390900E+04, 0.11913200E+04, 0.29890800E+05, -.14953100E+05, -.15889800E+05, -.14944900E+05, -.32606500E+04, -.10137600E+05, -.24067500E+04, 0.13734500E+04, -.97802000E+04, -.10965000E+05, -.10126700E+05, 0.41038400E+04, -.19977600E+04, 0.19922900E+04, -.20520900E+04, 0.70339600E+03, 0.50994900E+04, 0.20199000E+04, 0.47278100E+04, -.90748400E+03, 0.45414200E+04, -.12175600E+04, 0.91228600E+04, -.45771100E+04, -.38259900E+04, -.45614700E+04, -.15140200E+04, -.76805300E+04, 0.15742800E+03, 0.70458700E+03, -.19598100E+04, -.61471400E+04, -.49966600E+04, -.28029100E+05, 0.13996800E+05, 0.64416800E+04, 0.14014300E+05, 0.18990100E+04, 0.29181800E+04, 0.39429700E+04, -.14017500E+04, 0.95293000E+04, 0.38077100E+04, 0.13976600E+05, -.74398000E+04, 0.37171500E+04, 0.10284000E+05, 0.37200200E+04, 0.35347900E+04, 0.59639300E+04, -.35676100E+03, 0.13816500E+04, 0.19392800E+04, 0.58040100E+04, -.10236400E+04, -.11697200E+04, 0.83504200E+02, -.51910800E+03, -.40840200E+02, 0.15631100E+04, -.22368200E+03, -.28238600E+03, -.64053800E+03, 0.12032800E+04, -.50375100E+03, -.23097300E+03, 0.65320600E+03, 0.38061900E+04, -.15468700E+04, 0.46090700E+03, 0.95006900E+03, 0.60027900E+04, 0.13590700E+04, 0.30516800E+04, 0.32747400E+04, 0.62543100E+04, 0.21611400E+04, 0.32706600E+04, -.18124000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.98308100E+01, -.23342000E+01, -.98990000E+00, 0.76695500E+01, 0.49028600E+01, 0.18849000E+00, -.10984100E+01, -.25977300E+01, 0.11913600E+01, 0.28444400E+00, 0.58327400E+01, 0.91280600E+00, -.13033900E+02, -.12651600E+01, 0.59331500E+00, -.10574900E+01, 0.11484100E+01, -.41313500E+01, -.96831100E+00, 0.27604000E+01, -.32162700E+00, -.69496200E+01, 0.30360600E+01, -.28242800E+01, -.24987900E+00, 0.41421100E+01, 0.64474600E+00, -.67820300E-01, 0.99002100E+00, -.74365600E+00, -.17862200E+01, 0.87133300E+00, -.12382200E+01, 0.93215900E-01, -.20709000E+00, 0.15307400E+01, -.75017500E+01, 0.41253600E+04, 0.53854900E+04, -.11060200E+04, 0.45264400E+03, 0.27848400E+03, 0.27460200E+04, 0.68976000E+04, 0.14063100E+04, -.54699500E+03, 0.75451800E+03, -.70591200E+03, -.99236700E+03, -.43676800E+04, 0.87520000E+03, 0.15448800E+04, 0.66122200E+04, -.54548000E+04, -.68152700E+04, 0.81514800E+03, -.39176300E+03, -.18125300E+04, -.40781700E+03, 0.59966100E+03, 0.10528200E+04, -.25611500E+02, 0.29168700E+03, 0.14449300E+03, -.16755000E+03, 0.64650200E+03, 0.66619400E+04, -.33637100E+04, 0.19290300E+04, -.33284300E+04, 0.19099700E+04, -.66289000E+03, 0.55646600E+03, 0.84767500E+03, -.32416000E+04, 0.14491600E+02, -.11948900E+05, -.12416300E+05, 0.62921400E+04, 0.86428700E+04, 0.62088000E+04, -.18519400E+04, -.18236900E+04, 0.28451700E+04, 0.20900500E+04, 0.55945700E+04, -.29204700E+04, 0.15181400E+05, -.26989600E+05, 0.13223000E+05, 0.14083800E+05, 0.13503400E+05, -.14749300E+04, -.10737300E+05, 0.11292900E+05, -.30960100E+04, 0.12492400E+05, -.74929300E+04, -.64730400E+03, 0.71213400E+04, -.35030700E+04, 0.85692100E+03, -.35604800E+04, -.40593200E+03, -.26392700E+04, -.88647000E+03, 0.81609200E+03, 0.15724100E+04, -.26515600E+04, -.70940800E+04, -.65550800E+04, 0.32777500E+04, -.39928000E+04, 0.32767100E+04, -.38620100E+04, -.16125100E+05, 0.15914500E+05, 0.97125800E+04, 0.10914600E+05, -.16502400E+05, 0.13820600E+05, 0.69480200E+05, -.34662800E+05, -.38649000E+05, -.34739900E+05, -.58849900E+04, 0.74766600E+04, -.89247900E+04, 0.22186800E+05, -.14549500E+05, 0.38125400E+04, -.75093200E+04, -.25234800E+05, 0.12476400E+05, 0.18750100E+05, 0.12617100E+05, 0.57645000E+04, -.53336100E+04, 0.51244100E+04, -.74029800E+04, 0.59231900E+04, -.26284900E+04, -.82221700E+04, -.48547400E+04, 0.23636800E+04, 0.97682100E+04, 0.24497000E+04, 0.12823800E+04, 0.14638900E+04, 0.49194600E+03, -.24481400E+04, 0.92437900E+03, 0.28344600E+04, -.11697500E+05, 0.14518800E+04, -.80928400E+03, -.14099400E+04, -.72234900E+03, 0.30230800E+04, 0.13570700E+05, -.90152400E+04, -.35305300E+04, -.42646600E+04, 0.11843100E+05, -.32339600E+01, -.52174900E+05, 0.26170400E+05, 0.25383700E+05, 0.26097000E+05, 0.65296900E+03, -.11927000E+05, 0.11153500E+05, -.83329100E+04, 0.20034200E+05, -.81033600E+04, 0.12697800E+05, -.11097800E+05, 0.55578600E+04, 0.79242300E+04, 0.55537600E+04, 0.27336900E+03, -.14830900E+05, 0.17382000E+05, 0.76070300E+04, 0.12387800E+05, -.12978800E+05, -.58332700E+04, -.57674100E+05, 0.28690200E+05, 0.43235900E+05, 0.28836800E+05, 0.76505600E+04, -.92752000E+04, 0.93099800E+04, -.18560100E+05, 0.11554600E+05, -.44473200E+04, -.17896300E+04, 0.39985500E+05, -.19602500E+05, -.16523700E+05, -.19991400E+05, -.11515700E+05, -.13125900E+05, -.66496700E+04, -.67205000E+03, -.72389000E+04, -.12859800E+05, 0.14344000E+05, 0.13849800E+05, -.70284000E+04, -.12865200E+05, -.69346800E+04, 0.32209800E+03, 0.81285400E+04, -.45945700E+04, 0.29412300E+04, -.70005700E+04, 0.58730900E+04, -.56458500E+03, -.24343000E+05, 0.12095200E+05, 0.95235000E+04, 0.12172400E+05, 0.57356800E+03, -.67380600E+04, 0.63903500E+04, -.40016400E+04, 0.73735900E+04, -.50468300E+04, 0.29515300E+04, -.46298300E+05, 0.23081600E+05, 0.64264800E+04, 0.23148600E+05, 0.11041700E+04, -.13863300E+04, 0.14057200E+05, 0.53430500E+04, 0.14976200E+05, 0.49293700E+03, 0.68318100E+04, 0.17087300E+04, -.98387000E+03, 0.82564500E+02, -.85680500E+03, 0.43727500E+04, 0.11243400E+05, -.86741600E+04, -.63580200E+04, -.27694700E+04, 0.10141500E+05, -.13143300E+05, 0.86293000E+03, -.51697600E+03, 0.10635500E+03, -.38406900E+02, -.54399900E+03, 0.19705300E+04, 0.32706000E+03, 0.95882300E+02, 0.91889400E+03, -.62688800E+03, -.52499000E+03, -.17170700E+04, 0.70333700E+04, -.15992500E+04, -.69887800E+03, -.11348500E+04, 0.84235900E+04, -.18552000E+03, 0.34003300E+04, 0.47102900E+04, 0.69902100E+04, 0.32474200E+04, 0.34957000E+04, -.45067600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13862500E+01, 0.21571300E+00, -.12082100E+00, -.43154900E+00, -.54132300E+00, 0.37336400E+00, 0.81349500E-01, 0.26161300E+00, -.19355900E+00, -.64680400E-01, -.28451000E+00, -.13731800E+00, 0.76087300E+00, -.74427400E-01, -.12256300E+00, -.51123200E-01, 0.19131700E+00, 0.32891200E+00, 0.23468400E+00, 0.75399900E-01, 0.20662600E+00, 0.67997200E+00, 0.14978600E+00, 0.68151400E+00, 0.27733700E-02, -.13313600E+00, -.22977000E+00, -.46057400E-02, 0.18712600E+00, -.69464500E+00, 0.19153600E+00, 0.25348300E-01, 0.14573700E+00, -.30392600E+00, 0.13752600E-01, 0.13881300E+00, -.20722700E-01, 0.28183600E+04, 0.36498400E+04, -.13387900E+04, 0.39150300E+03, 0.15125000E+04, 0.29605500E+04, 0.56745300E+03, -.21497400E+04, 0.12210400E+04, 0.14741300E+04, 0.10740800E+04, 0.36226000E+03, 0.16737000E+04, -.19999200E+03, -.11193200E+04, -.11387800E+04, 0.15276500E+04, 0.10023000E+04, -.48108700E+03, 0.25332300E+03, 0.75397400E+03, 0.24063900E+03, 0.44860400E+03, 0.22628000E+04, -.34108500E+03, 0.32622600E+03, 0.10579200E+03, 0.18462900E+04, -.45193900E+03, -.25030200E+04, 0.11933800E+04, 0.22553600E+04, 0.12513700E+04, 0.18680200E+03, 0.14652400E+03, 0.43646400E+03, 0.37963700E+03, 0.25131600E+03, 0.86223700E+01, 0.18866800E+03, 0.48777100E+04, -.23223500E+04, -.36169200E+04, -.24385500E+04, -.71011600E+03, -.20929800E+04, 0.79918800E+02, 0.73903600E+03, -.63857600E+03, -.16109900E+04, -.14744100E+04, -.50544700E+04, 0.24237800E+04, -.34667100E+04, 0.25275000E+04, 0.11136100E+04, -.32070000E+04, 0.24819100E+04, 0.22848100E+03, -.10005200E+04, -.26818300E+04, 0.22878900E+03, -.50597100E+03, 0.33144400E+03, 0.12786600E+04, 0.25273700E+03, 0.40042500E+01, -.27307800E+03, 0.25784100E+03, -.21271500E+03, -.60428800E+03, -.13899300E+03, 0.10817600E+03, -.40186800E+04, 0.20324500E+04, -.80129800E+04, 0.20091300E+04, 0.25978500E+04, -.16845800E+03, 0.11910600E+04, 0.23695500E+04, 0.20056400E+04, -.18935400E+03, 0.56391000E+03, 0.62520100E+04, -.31533000E+04, 0.57015300E+04, -.31258900E+04, -.28148000E+03, 0.30186600E+04, -.31122500E+04, -.57270300E+03, -.14499000E+04, 0.29708300E+04, -.19451700E+03, 0.32578200E+04, -.16227200E+04, -.47976700E+04, -.16289600E+04, 0.17215100E+03, -.25495200E+04, 0.75256800E+03, 0.89620300E+03, -.13068700E+04, -.21144600E+04, -.46535600E+04, 0.56935400E+03, -.33985500E+03, 0.47547100E+04, -.28474800E+03, -.65108100E+03, 0.14191800E+03, -.21210100E+03, 0.40053500E+03, 0.13168100E+04, 0.53863100E+02, 0.36372300E+03, 0.23256500E+04, -.12199100E+04, 0.31539800E+04, -.11620400E+04, -.14118300E+04, 0.92864700E+03, -.11051600E+04, -.14571200E+04, -.18633800E+04, 0.88122600E+03, -.84718000E+03, -.90690600E+04, 0.46209400E+04, -.78687500E+04, 0.45346900E+04, 0.14285500E+04, -.18132400E+04, 0.27984000E+04, 0.30303400E+02, 0.19709300E+04, -.21083100E+04, 0.47791900E+04, -.76762900E+04, 0.38357300E+04, 0.14768300E+04, 0.38382600E+04, 0.45824300E+04, 0.34946500E+04, 0.37295100E+02, 0.23830200E+04, 0.64900900E+04, 0.25565300E+04, 0.26860800E+04, -.75910200E+03, 0.39238000E+03, -.62603800E+04, 0.37948900E+03, 0.22286400E+02, -.42867600E+04, 0.21501400E+04, 0.43201500E+03, -.64679500E+02, -.38078200E+04, -.28661500E+04, 0.72955800E+04, -.33714500E+04, -.72643100E+04, -.36473000E+04, -.21575100E+04, -.28240000E+04, 0.97613600E+03, 0.37280400E+04, -.11197600E+04, -.23925100E+04, -.65215100E+03, 0.49991000E+04, -.25534400E+04, 0.17849200E+04, -.24999300E+04, -.37291500E+03, 0.13003900E+04, -.18056000E+04, -.20207500E+03, -.10862300E+04, 0.14325800E+04, -.25373600E+04, 0.24756700E+04, -.12219100E+04, -.34542600E+04, -.12378500E+04, 0.33334900E+02, -.24728100E+04, 0.11538500E+04, 0.80791600E+03, -.22040000E+04, -.19455800E+04, -.29511200E+04, -.96187800E+04, 0.47132800E+04, 0.23825400E+04, 0.48091100E+04, 0.73493300E+03, 0.13089500E+04, -.24960600E+02, -.34217600E+04, 0.21323300E+04, 0.10342300E+04, 0.42921700E+04, -.43573000E+02, -.44387200E+02, 0.39508600E+04, 0.21856600E+02, -.54038600E+03, 0.72802600E+03, -.69203100E+03, -.21934500E+04, -.22478500E+04, 0.65492900E+03, -.60836500E+03, 0.52716100E+03, -.10166900E+03, -.70934500E+02, 0.81081500E+02, -.79764200E+02, -.23410300E+03, -.18506600E+03, 0.16306000E+02, 0.60541200E+03, -.21409200E+03, 0.23977800E+03, 0.11972000E+03, 0.12979100E+04, 0.40134100E+03, 0.66493600E+03, -.38724800E+03, 0.19299200E+04, -.33555500E+03, 0.73894000E+03, 0.71093600E+03, 0.29789300E+04, 0.21265800E+03, 0.10794100E+04, 0.88969900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.95922100E+00, 0.48065000E+00, 0.23982900E+00, -.84095500E+00, -.69872000E+00, -.18147900E+00, 0.15777900E+00, -.10886100E+00, -.21848900E+00, -.10886900E+00, 0.10834000E+00, 0.18088100E+00, -.41742200E+00, -.15468100E+00, -.16481300E+00, 0.84321900E-02, -.14970600E-01, -.19295900E+00, 0.10871500E+00, -.18023600E+00, -.22921300E+00, -.15642300E+01, 0.60893500E+00, -.38771400E+00, -.52042300E-01, 0.25313200E+00, -.11321600E+00, -.21250400E+00, 0.17323900E+00, 0.14614000E+01, -.24219700E+00, -.73130400E-01, 0.82076400E+00, -.19031400E+00, -.54479500E-01, -.45937100E+00, -.10150900E-01, 0.30788000E+00, -.39732400E+04, 0.36168200E+04, 0.63251000E+04, 0.60263200E+04, -.34928900E+04, -.40090000E+04, -.25319700E+05, 0.12634700E+05, 0.12278900E+05, 0.12660100E+05, 0.10759600E+04, 0.21097300E+03, 0.34413200E+04, -.74709600E+04, 0.23272600E+04, 0.40658800E+03, 0.12565500E+05, -.40987800E+03, 0.19426900E+03, 0.21910900E+04, 0.20498100E+03, 0.61828800E+03, 0.19582700E+04, -.35352300E+03, -.70671000E+02, -.46968300E+03, 0.16581100E+04, 0.54982200E+02, 0.10265300E+05, -.51333500E+04, -.28357100E+04, -.51327400E+04, 0.96108300E+03, 0.83500300E+04, -.69830500E+04, -.45149600E+04, -.13781300E+05, 0.80962700E+04, -.63304600E+04, 0.41774300E+04, -.20867400E+04, 0.61831000E+03, -.20887900E+04, -.77596600E+04, -.14504800E+05, 0.61323200E+04, 0.35727200E+04, 0.11507900E+05, -.13366900E+05, 0.51771300E+04, -.23269100E+05, 0.11655600E+05, 0.20359600E+05, 0.11634300E+05, 0.70656600E+04, 0.24739100E+04, -.30545800E+04, -.16155200E+05, -.10338600E+05, 0.33446300E+04, -.19181900E+04, -.91774200E+04, 0.45780400E+04, 0.45628000E+04, 0.45886800E+04, -.22687100E+03, -.37243200E+03, 0.10332600E+04, -.25141900E+04, 0.59746400E+03, -.21986500E+03, 0.68210800E+04, 0.10468200E+05, -.52386100E+04, 0.30356000E+03, -.52339200E+04, 0.18934500E+04, -.57659200E+04, -.12257600E+04, 0.59709200E+04, -.79425800E+04, -.55547900E+04, -.12777100E+05, 0.72625500E+05, -.36286100E+05, -.34979200E+05, -.36312800E+05, -.60467900E+04, 0.41280900E+04, -.98951400E+04, 0.22418900E+05, -.10157500E+05, 0.27094800E+04, -.14490800E+05, -.22475200E+05, 0.11231600E+05, 0.15617500E+05, 0.11237600E+05, 0.62787400E+04, -.26627900E+04, 0.45961900E+04, -.43149500E+04, 0.19872800E+04, -.85978000E+03, -.81044800E+04, 0.86287200E+04, -.43000800E+04, -.34874900E+04, -.43121400E+04, -.43614000E+04, 0.36209000E+04, -.13419000E+04, 0.12400700E+04, 0.20715800E+04, 0.50186300E+04, -.72946600E+04, -.89139400E+04, 0.44624500E+04, -.21299500E+04, 0.44563000E+04, 0.31654500E+04, 0.92590000E+04, -.27100400E+04, -.28516700E+04, 0.31066700E+02, 0.70676700E+04, 0.10828600E+05, -.51582200E+05, 0.25750100E+05, 0.30255600E+05, 0.25791100E+05, 0.45363700E+04, -.41065500E+04, 0.47851600E+04, -.22224400E+05, 0.19097700E+04, -.35686600E+04, 0.14926400E+05, 0.20168500E+05, -.10084900E+05, -.45077600E+04, -.10084400E+05, -.94803300E+04, -.92453900E+04, 0.24399900E+04, 0.10666200E+05, 0.53569100E+04, -.58973800E+04, -.88537300E+04, -.59027200E+05, 0.29495400E+05, 0.34876600E+05, 0.29513600E+05, 0.62034900E+04, -.74740500E+04, 0.10686500E+05, -.15560400E+05, 0.10457300E+05, -.46828300E+04, 0.34636300E+04, 0.13312700E+05, -.66864800E+04, 0.17194800E+02, -.66567900E+04, -.16721000E+05, -.23329500E+05, 0.96622200E+04, 0.20216100E+05, 0.10467100E+05, -.23704600E+05, 0.16421700E+05, 0.24069600E+05, -.12001500E+05, -.20837200E+05, -.12034500E+05, -.18923100E+04, 0.25758300E+04, -.14147500E+04, 0.11779700E+05, 0.99280100E+03, 0.24603700E+04, -.74107300E+04, -.16143100E+05, 0.80721100E+04, 0.12670200E+05, 0.80715700E+04, 0.43797200E+04, -.13542700E+04, 0.78625400E+03, -.83957000E+04, -.23364900E+04, -.70944400E+03, -.33984500E+04, -.16048300E+05, 0.80232200E+04, 0.52706300E+03, 0.80242800E+04, 0.11702500E+05, 0.13037400E+05, -.52408500E+04, -.13775700E+05, -.71708700E+04, 0.12561400E+05, -.27342000E+04, -.22979100E+05, 0.11500400E+05, 0.80825500E+04, 0.11489500E+05, 0.56513400E+04, 0.95850700E+04, -.11294400E+04, -.10165100E+05, -.21144900E+04, 0.94893800E+04, 0.58959900E+04, -.13671700E+04, -.25140600E+03, -.45013800E+03, -.87260200E+02, 0.62814500E+03, 0.15444300E+01, -.82707100E+02, -.10394700E+03, 0.35632800E+04, 0.26079400E+04, -.27181800E+04, 0.24178500E+03, -.91277600E+02, 0.62628100E+04, 0.17806000E+03, 0.76236500E+03, 0.46726000E+04, 0.11689400E+04, -.40513700E+04, 0.50271600E+04, 0.28241500E+04, -.49296100E+04, 0.68648100E+04, 0.86330300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36293500E+01, -.79758800E+00, -.15399900E+01, 0.84604800E+00, 0.17190700E+01, -.60379100E+00, -.22881900E+00, 0.26999800E+01, -.90095400E+00, -.10320400E+01, 0.63889200E+00, 0.17250900E+01, 0.60010400E+01, 0.35894200E+01, -.66384000E+00, -.15437200E+00, 0.19499600E+01, 0.37837900E+00, -.64397900E-01, -.36507200E+00, 0.23713200E+01, -.15522400E+01, -.28727500E+01, 0.23241600E+01, -.11753800E-01, 0.32803100E+00, -.95173000E+00, -.12404700E+01, -.29034900E+00, -.50568900E+01, -.25245800E+00, 0.17161900E+00, -.23179700E+01, 0.40607000E+00, -.66911800E-01, 0.18396900E+01, -.69692200E-01, -.86211100E-01, -.34314200E+00, 0.74767600E+04, 0.15204400E+05, 0.69052400E+04, 0.61495800E+03, -.13920300E+05, 0.78100900E+04, -.38065700E+04, -.39563100E+04, -.39072200E+04, -.28004600E+04, 0.48253500E+03, 0.12838300E+04, 0.24863000E+04, -.12273500E+04, 0.19668300E+03, 0.79533500E+03, -.87156700E+04, 0.43396400E+04, 0.56625300E+04, 0.43582100E+04, 0.15166800E+04, 0.19693400E+04, 0.35647000E+04, 0.29992300E+04, 0.27824400E+04, 0.16585300E+04, -.43464800E+04, 0.24574000E+04, -.12475300E+04, -.44696600E+04, -.12292600E+04, -.15376100E+04, -.22631700E+03, 0.72193700E+03, -.24505500E+03, -.50582500E+04, -.26780600E+04, -.27957600E+04, 0.18932200E+05, -.93597300E+04, -.11040600E+05, -.94652300E+04, -.31390400E+04, -.53620400E+03, -.55280300E+04, -.61195900E+03, -.64583400E+03, 0.31702900E+04, 0.34056900E+04, 0.85618100E+04, -.43901600E+04, -.10403600E+05, -.42805200E+04, 0.77309100E+03, 0.25464800E+04, 0.14950400E+03, 0.45971000E+04, -.50374800E+03, -.73904900E+03, 0.24139400E+04, 0.73379900E+04, -.37003200E+04, -.41174200E+04, -.36698500E+04, -.19292600E+04, -.67328100E+03, -.29171000E+03, 0.17729100E+04, -.12107600E+04, -.53131700E+03, 0.16413300E+04, -.14800900E+05, 0.76623500E+04, 0.37508400E+04, 0.74000600E+04, 0.78299500E+04, 0.10954700E+05, 0.76490100E+04, 0.19267200E+05, 0.47808000E+04, 0.10645300E+05, -.24617800E+05, -.21693800E+05, 0.10473100E+05, 0.10330000E+05, 0.10847200E+05, 0.25999500E+04, -.54894500E+04, -.58564500E+03, -.40545300E+04, 0.91401900E+04, -.13744200E+04, 0.42187200E+04, -.10933800E+05, 0.56727000E+04, 0.22050500E+04, 0.54668000E+04, 0.37076600E+04, 0.37106700E+03, 0.90115400E+03, -.10179400E+05, -.19607100E+03, 0.21957600E+03, 0.30348200E+04, -.47194300E+03, 0.50110600E+02, -.58715800E+03, 0.23789500E+03, -.52136000E+04, -.99048100E+04, 0.44737300E+04, 0.69248100E+04, 0.81714600E+04, -.89248800E+04, 0.15112800E+05, 0.16534500E+05, -.85638100E+04, -.24554200E+04, -.82658000E+04, -.23847500E+04, -.11910200E+04, -.11384600E+05, -.18682500E+05, -.13716600E+05, -.23718800E+04, -.36967600E+04, 0.51941600E+05, -.25563800E+05, -.26819800E+05, -.25970400E+05, -.74577400E+04, 0.41934000E+04, 0.10333300E+04, 0.20379300E+05, -.12420300E+05, 0.22360000E+02, -.14451900E+05, -.97248100E+04, 0.49360100E+04, 0.58303100E+03, 0.48625200E+04, 0.33232200E+04, 0.24835400E+04, 0.61567000E+04, 0.21464900E+05, 0.14125900E+05, 0.37682000E+04, 0.83418600E+04, 0.83926000E+04, -.38780700E+04, -.96135800E+04, -.41964500E+04, 0.42675800E+03, 0.39203100E+04, -.23270500E+04, -.86434900E+04, -.71592300E+04, 0.15988100E+04, 0.37643900E+04, -.59729400E+04, 0.35910600E+04, -.20182600E+04, 0.29873400E+04, -.64081900E+03, 0.11572600E+05, 0.34998400E+04, 0.19444300E+05, 0.45236000E+04, 0.15793600E+05, -.82794500E+04, -.16234000E+05, 0.78633500E+04, 0.14211400E+05, 0.81161900E+04, 0.25338000E+04, -.29307800E+04, -.33103600E+04, -.11548800E+05, 0.38886200E+04, -.14820500E+04, 0.51142800E+03, -.55354300E+04, 0.29046700E+04, -.84028500E+03, 0.27676700E+04, 0.37110000E+04, 0.43807700E+04, 0.15416000E+04, -.86774100E+02, 0.18770700E+04, 0.35145000E+04, -.22290000E+04, 0.20651500E+04, -.11511800E+04, 0.37156100E+04, -.10332700E+04, 0.31659000E+04, -.20916100E+04, -.49422200E+04, -.14289300E+05, -.70840800E+04, -.67545900E+04, -.26568400E+04, 0.12807800E+05, -.65682700E+04, -.44632500E+04, -.64038400E+04, -.63381900E+04, -.92897600E+04, -.23945900E+04, -.11052500E+05, -.61288400E+04, -.10178300E+05, 0.12380300E+05, 0.32020400E+04, 0.32263500E+03, -.39634200E+03, 0.20307200E+03, 0.95171200E+03, 0.59429600E+03, -.79981000E+03, 0.25890100E+03, 0.10006800E+04, -.19278700E+03, -.14987600E+04, 0.19526700E+04, -.19230200E+04, 0.36214000E+04, 0.30291800E+04, -.17967800E+04, -.36411900E+04, -.12978400E+04, -.27994700E+04, -.32070200E+04, -.20377800E+04, -.74912500E+03, -.14732700E+04, 0.67119700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11637600E+01, 0.17900800E+00, 0.30053600E+00, -.75818300E+00, -.10678500E+01, -.30066600E+00, 0.20428400E+00, 0.59145100E-01, -.14705000E+00, -.23823400E+00, -.84082400E+00, -.29904000E+00, -.31041800E+00, -.13524500E+01, 0.22408100E+00, 0.13283300E+00, -.36725700E+00, -.71082000E-02, 0.14282900E+00, 0.24815200E-01, -.31033400E+00, 0.49189700E+00, -.11531700E+01, 0.46441400E+00, -.86401900E-01, 0.84354400E-02, 0.98268500E-01, -.18642100E+00, -.58294800E-01, 0.89015900E+00, 0.24294100E+00, -.39751500E-01, 0.32435600E+00, -.64373000E+00, -.53793100E-01, -.29317100E+00, 0.32889300E-01, -.98910400E-01, 0.43102400E+00, 0.21202700E+00, -.28933900E+04, -.44621800E+04, -.41620000E+03, 0.40233800E+04, 0.14500200E+05, -.71041600E+04, -.59526800E+04, -.72487300E+04, -.39814200E+03, 0.33788200E+03, -.18408100E+04, 0.50610700E+04, -.17585900E+04, 0.11489500E+03, -.95248800E+04, -.26372800E+04, 0.13404200E+04, -.24970400E+04, 0.13183900E+04, -.69022700E+03, -.24155200E+04, 0.17369200E+04, 0.68339300E+03, 0.15439900E+04, -.22375200E+04, 0.11976000E+04, 0.60036800E+02, -.63515400E+02, 0.16476600E+04, -.29646600E+02, -.34615300E+03, -.63537200E+04, 0.57217300E+04, 0.51164400E+04, 0.73189700E+04, -.60138400E+04, -.92969500E+03, -.41494000E+04, 0.21294800E+04, 0.36926000E+04, 0.20741700E+04, 0.57538800E+04, 0.13432000E+05, -.68901900E+04, -.51015500E+04, -.92596600E+04, 0.12120300E+05, -.87142200E+03, 0.15573100E+05, -.79292000E+04, -.89794400E+04, -.77867500E+04, -.27665100E+04, 0.12394800E+04, -.10861100E+04, 0.56877500E+04, 0.44724600E+03, 0.18228800E+04, -.44059200E+03, 0.62939500E+04, -.30763500E+04, -.13778000E+04, -.31464100E+04, 0.27558400E+03, 0.11781300E+04, -.12663500E+04, 0.13837900E+04, -.93768300E+03, 0.90074100E+03, -.58017400E+04, -.21275500E+04, 0.10960800E+04, 0.51579900E+04, 0.10640100E+04, -.95828000E+03, -.75976100E+03, 0.51609400E+04, -.10982600E+04, 0.83960200E+03, -.91467800E+03, 0.90747400E+04, -.70416900E+05, 0.35149400E+05, 0.20939400E+05, 0.35208300E+05, 0.61083600E+04, -.10339400E+04, 0.92381000E+04, -.17335800E+05, 0.15909700E+05, -.21378200E+04, 0.21476500E+05, 0.18061600E+05, -.90392200E+04, -.17344200E+04, -.90307400E+04, -.62883600E+04, -.61733000E+03, -.56761800E+03, 0.45966400E+04, -.49396700E+04, -.42828200E+03, 0.20244600E+04, -.29465800E+04, 0.14004300E+04, 0.11849800E+04, 0.14709700E+04, 0.28137900E+04, -.11324200E+04, 0.61731400E+03, -.82709400E+03, -.11999000E+04, -.20313900E+04, 0.82823400E+03, 0.71795100E+03, -.43503200E+03, -.37953600E+04, -.35979100E+03, -.20357300E+04, -.20316900E+04, -.12212100E+04, 0.28551600E+03, 0.31666600E+04, -.15336900E+04, -.37784100E+04, 0.58347000E+05, -.29018200E+05, -.17909600E+05, -.29173800E+05, -.34485900E+04, 0.16644900E+04, -.81736800E+04, 0.13391900E+05, -.12717800E+05, 0.31681500E+04, -.22710800E+05, -.62011500E+04, 0.31090900E+04, 0.44237700E+04, 0.31005300E+04, 0.42830300E+04, -.11104800E+04, 0.62656900E+04, -.16611900E+04, -.49291800E+04, -.20581300E+04, -.32742000E+03, 0.57317400E+05, -.28647500E+05, -.13667100E+05, -.28658600E+05, -.69447600E+04, 0.29286000E+04, -.78628500E+04, 0.12954800E+05, -.15954000E+05, 0.34199600E+04, -.13077300E+05, 0.50440000E+03, 0.65860300E+01, 0.67745000E+04, -.25268500E+03, 0.13520200E+05, 0.21240300E+05, -.13154600E+05, -.15599800E+05, -.99867600E+04, 0.19980500E+05, -.10445900E+05, -.36415400E+05, 0.18083500E+05, 0.14004400E+05, 0.18208200E+05, 0.15259100E+04, -.71996800E+03, 0.52079900E+04, -.74261400E+04, 0.75411200E+04, -.19146900E+04, 0.15424700E+05, 0.57815500E+04, -.28978900E+04, -.49185800E+04, -.28907500E+04, -.22238500E+04, 0.21978000E+04, -.13964400E+04, 0.26653700E+04, 0.45488700E+03, 0.21632700E+04, 0.34987000E+04, 0.51690200E+04, -.26208700E+04, -.52488200E+04, -.25840800E+04, -.88474900E+04, -.14783600E+05, 0.88883700E+04, 0.12435800E+05, 0.89616200E+04, -.13552100E+05, 0.75676000E+03, 0.15349800E+05, -.77473600E+04, -.61669400E+04, -.76749100E+04, -.40901300E+04, -.46850400E+04, -.11932900E+04, 0.50824700E+04, 0.15814400E+03, -.40586100E+04, -.61672200E+04, 0.15269900E+03, -.12859400E+03, 0.47789100E+03, -.17692900E+02, -.60761100E+03, 0.27384200E+02, 0.47264900E+03, -.15903100E+03, -.34179500E+04, -.64520600E+03, 0.23869500E+04, -.56576600E+03, -.82326100E+03, -.38972700E+04, -.80572800E+03, -.34301000E+03, -.40489000E+04, -.31146100E+03, 0.20510000E+04, -.36930900E+04, -.36652800E+04, 0.14607800E+04, -.63506400E+04, -.63462100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10913600E+01, -.46721700E+00, -.14838100E+00, 0.31444000E+00, 0.11324100E+01, -.77796500E-01, -.11466700E+00, 0.45104800E+00, -.43699800E-01, -.49376600E-01, -.44088500E-01, 0.33776000E+00, 0.22528300E+01, 0.13327300E+01, 0.81275700E-01, -.22356200E+00, 0.47103300E+00, 0.23061100E+00, 0.57797200E-01, 0.53378600E+00, -.10314000E+00, 0.10435700E+01, -.31505000E+00, 0.12794300E+00, -.19008600E-01, -.40763700E+00, 0.29204400E+00, 0.38383200E+00, -.57675900E-01, -.16420600E+01, 0.38882600E-03, 0.14897800E+00, -.23715200E-01, 0.22253400E+00, -.93679700E-02, 0.37805400E+00, 0.57752300E-02, -.66265300E+00, -.46951800E+00, -.15269400E+00, -.10429400E+00, 0.31131900E+04, 0.21652800E+03, -.25628100E+04, -.19814100E+04, 0.10925200E+04, 0.83194800E+02, 0.99032700E+03, -.18413300E+03, 0.69402200E+03, -.71209900E+03, -.53424400E+04, -.26089700E+04, 0.96176700E+03, 0.41670900E+04, 0.50433500E+04, -.25182000E+04, -.81731100E+03, -.25215900E+04, 0.10020700E+04, 0.33050600E+04, -.37850500E+04, -.35930300E+04, -.31184000E+04, 0.28494500E+04, -.15883300E+04, 0.12804900E+04, -.70218600E+03, -.50885200E+03, -.64037600E+03, -.59083000E+03, 0.30098800E+04, -.27459500E+04, -.37682700E+04, -.55660100E+04, 0.29014600E+04, 0.99707300E+03, 0.55591300E+04, -.26645500E+04, 0.36057200E+01, -.27794100E+04, -.30665600E+04, -.95887900E+04, 0.42080500E+04, 0.41969800E+04, 0.45415400E+04, -.81234400E+04, -.25288700E+04, -.51826900E+04, 0.25680000E+04, 0.46233100E+04, 0.25913400E+04, 0.36516100E+04, -.68743300E+03, 0.92986600E+03, -.34430500E+04, -.73158200E+04, -.77753700E+03, -.39409600E+04, 0.10028000E+03, 0.17348500E+02, -.23547300E+01, -.50324800E+02, -.59845200E+03, -.43978700E+03, -.22701900E+02, -.10919500E+04, -.12651400E+04, -.11798800E+03, 0.25284300E+04, 0.84255500E+04, -.42085500E+04, -.41833400E+04, -.42128100E+04, 0.11816600E+04, -.76019100E+03, -.42667800E+04, -.17951800E+04, -.83588200E+04, 0.71140200E+02, -.10041500E+05, 0.40902200E+05, -.20465700E+05, -.11567700E+05, -.20451100E+05, -.32621100E+04, 0.50046900E+04, -.10903000E+05, 0.76402100E+04, -.80589300E+04, 0.44971800E+04, -.78352500E+04, -.83234200E+04, 0.41954100E+04, 0.23772500E+04, 0.41617000E+04, 0.30356100E+04, -.37972300E+04, 0.63503700E+04, 0.18794200E+04, 0.78170400E+03, -.27652100E+04, -.70430200E+04, 0.52261300E+04, -.26417500E+04, -.20807600E+04, -.26117000E+04, -.33103500E+04, 0.10190100E+04, -.99363100E+03, 0.14629200E+04, 0.25569600E+04, 0.14818300E+04, -.43762100E+02, -.56038500E+04, 0.27843500E+04, 0.15852300E+04, 0.28020300E+04, 0.12927200E+04, 0.43000000E+04, -.21632500E+04, -.27989200E+04, -.45725800E+03, 0.31751300E+04, 0.56965900E+04, -.24625500E+05, 0.12337600E+05, 0.79046700E+04, 0.12312800E+05, 0.93360100E+03, -.55831300E+04, 0.73670900E+04, -.73489400E+04, 0.30028600E+04, -.55208700E+04, 0.77828800E+04, 0.73122900E+04, -.36694400E+04, -.26234500E+04, -.36561600E+04, -.21839500E+04, 0.57725100E+03, -.27432400E+04, 0.31490900E+04, 0.39226700E+04, 0.14977800E+04, 0.70433400E+03, -.30398000E+05, 0.15228800E+05, 0.11199600E+05, 0.15199000E+05, 0.35360900E+04, -.70587300E+04, 0.11544300E+05, -.25481100E+04, 0.68247700E+04, -.57678600E+04, 0.16434000E+03, -.24887100E+04, 0.14061600E+04, -.66051300E+03, 0.12444100E+04, -.73256000E+04, -.15773200E+05, 0.71949800E+04, 0.91910000E+04, 0.59203800E+04, -.13859400E+05, 0.73798600E+04, 0.16667100E+05, -.83260500E+04, -.10851600E+05, -.83336600E+04, -.49177300E+03, 0.29586700E+04, -.45733700E+04, 0.36178100E+04, -.26368800E+04, 0.31107400E+04, -.56186600E+04, -.26225900E+04, 0.13460300E+04, 0.25939300E+04, 0.13112800E+04, 0.22218800E+04, -.20732800E+04, 0.22157500E+04, -.20003700E+04, -.33693200E+04, -.15559400E+04, -.52321400E+04, -.36356100E+04, 0.17217500E+04, -.19004800E+04, 0.18177000E+04, 0.44483800E+04, 0.11024200E+05, -.55880500E+04, -.79833300E+04, -.42250600E+04, 0.95107700E+04, 0.19521000E+04, -.13439100E+05, 0.66967700E+04, 0.63887200E+04, 0.67195000E+04, 0.11767200E+04, 0.87755400E+03, 0.54351700E+04, 0.63985300E+03, 0.25800800E+04, 0.44319200E+03, 0.44365300E+04, -.72461300E+03, -.13542200E+03, -.31443700E+03, -.12571900E+00, 0.28543200E+03, -.52096800E+03, -.32112100E+02, -.87111400E+02, 0.18017900E+04, 0.12319400E+04, 0.20251700E+02, 0.44222400E+02, 0.18267700E+04, 0.25831100E+04, 0.74464600E+03, 0.45210600E+03, 0.37240100E+04, 0.18672600E+03, -.13080300E+03, 0.21220700E+04, 0.31683200E+04, -.27178200E+04, 0.37263700E+04, 0.10369200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.54523600E+00, 0.93607600E-01, 0.69666200E-01, -.26858000E+00, -.23764400E+00, -.12249400E+00, 0.51059500E-01, 0.22086200E+00, -.13186300E+00, -.15387100E-01, -.21651900E+00, -.11630400E+00, 0.67674400E+00, 0.16773100E+00, -.80096800E-04, -.14593800E-01, -.31417100E-01, -.41079800E-01, 0.10467400E+00, -.61589200E-01, 0.33835300E-01, -.39504800E+00, -.52014200E+00, 0.41084400E+00, 0.87010300E-03, 0.46739100E-01, -.10681000E+00, -.39685600E-01, -.60611700E-01, 0.48820600E-01, -.77260700E-02, 0.25828400E-01, -.14186900E+00, 0.11550500E+00, 0.10153000E-01, 0.14892200E+00, -.27266200E-01, 0.10750200E+00, -.19487500E+00, 0.56229300E-01, -.11352300E+00, 0.62820000E-01, -.19746700E+03, 0.17329500E+04, -.32684600E+04, 0.15169100E+04, 0.18372700E+04, 0.16337600E+04, 0.76936100E+03, -.25680600E+03, 0.53022200E+01, -.11951500E+04, 0.55182200E+03, -.33841200E+03, 0.21615600E+03, -.11196500E+03, 0.48071000E+02, -.11537100E+03, 0.56059900E+02, -.23144500E+03, -.31546500E+03, 0.29769800E+03, 0.15907500E+03, 0.10232100E+03, -.29519500E+03, 0.54182400E+03, 0.41695400E+04, -.20265000E+04, -.65129000E+03, -.20848800E+04, 0.29520100E+03, 0.12421900E+03, -.66121800E+03, 0.79696700E+03, -.15496100E+04, 0.41202800E+03, -.27910300E+04, -.43136800E+04, 0.20452400E+04, 0.27355400E+04, 0.21570200E+04, -.65722000E+03, -.52490800E+03, 0.10707000E+04, -.60282900E+03, 0.15216600E+04, -.79099200E+03, 0.27848000E+04, -.38227200E+04, 0.20383400E+04, 0.57768800E+04, 0.19114500E+04, 0.68925700E+02, -.16469300E+04, 0.74177500E+03, -.18007700E+04, -.86865900E+03, -.74081700E+03, -.79451400E+03, -.11143400E+04, 0.52961000E+03, 0.99458400E+03, 0.55699000E+03, 0.49138800E+03, -.82182600E+01, -.27721000E+03, -.73277800E+03, 0.13417800E+03, -.10415600E+03, -.29686700E+03, 0.21601400E+04, -.11298900E+04, 0.71720100E+03, -.10801600E+04, -.17956100E+04, -.46125500E+04, 0.25653100E+04, 0.24168200E+04, 0.32971500E+03, -.43946300E+04, 0.21102800E+04, 0.78207200E+04, -.38409600E+04, -.49936300E+04, -.39102900E+04, -.92331300E+03, 0.18986000E+04, -.15792100E+03, 0.36884400E+04, -.11474400E+04, 0.11289200E+04, -.37861200E+03, -.88529800E+02, 0.24015900E+02, 0.25847400E+04, 0.44241800E+02, 0.81041800E+03, -.12980000E+04, 0.15368500E+03, -.50413300E+02, -.28109700E+03, -.78182600E+03, -.28650600E+04, 0.87556100E+03, -.36116600E+03, 0.48048800E+03, -.43744300E+03, 0.48257300E+03, 0.15145500E+04, -.59614000E+03, -.60267500E+03, -.62335000E+03, 0.17124600E+04, -.31269200E+04, -.33708200E+04, 0.17822000E+04, -.11470800E+04, 0.16857400E+04, 0.10598700E+04, 0.31727600E+04, -.70863500E+03, -.31350900E+03, 0.10357000E+04, 0.26624200E+04, 0.12903800E+04, -.10746400E+05, 0.52352200E+04, 0.78977500E+04, 0.53733200E+04, 0.70757800E+03, -.17529600E+04, 0.60362100E+03, -.37510500E+04, 0.17090600E+04, -.11019400E+04, 0.30749300E+04, 0.25969900E+04, -.13062600E+04, 0.12190000E+04, -.12984700E+04, -.16039200E+04, -.40437600E+04, 0.26486800E+04, 0.17019900E+04, 0.56169400E+03, -.32383900E+04, -.26822900E+04, -.39220500E+04, 0.19228900E+04, 0.58243500E+04, 0.19609900E+04, 0.92953600E+03, -.25428000E+04, 0.47734400E+03, -.19464800E+04, 0.43708100E+03, -.15602900E+04, -.25724500E+04, 0.76188400E+04, -.41463900E+04, 0.10030100E+04, -.38092200E+04, -.24252600E+04, -.30877100E+04, -.84622900E+03, -.37458300E+02, -.10900200E+04, -.37801600E+04, 0.18135500E+04, 0.14059800E+04, -.61329300E+03, -.46335800E+04, -.70317500E+03, -.14842700E+03, 0.13284600E+04, 0.38188900E+03, 0.16704600E+04, 0.43007500E+03, 0.99162800E+03, 0.31959400E+03, -.14922200E+04, 0.72423500E+03, 0.25849900E+04, 0.74610200E+03, 0.52895500E+02, -.13157100E+04, 0.27758500E+03, -.83458700E+03, -.39129500E+03, -.98312000E+03, -.55589400E+03, -.67826400E+04, 0.34826900E+04, -.22484400E+03, 0.33911700E+04, 0.10830500E+04, 0.18855700E+03, 0.21044500E+04, 0.15355500E+04, 0.23154100E+04, 0.69470700E+03, 0.71937800E+03, -.26683500E+04, 0.14164100E+04, -.38474800E+03, 0.13341900E+04, 0.19666300E+04, 0.37136100E+04, -.23096700E+04, -.25571400E+04, -.85250700E+03, 0.36206600E+04, -.13035300E+04, -.45139500E+03, -.12192000E+03, 0.12111800E+03, -.68899300E+02, -.19393900E+03, -.65184800E+02, 0.14385100E+03, -.19884200E+03, -.19006700E+02, 0.21695000E+03, 0.65147400E+03, -.18596700E+03, 0.99405700E+03, -.49103200E+02, -.41315900E+03, 0.93858100E+02, 0.16344700E+04, 0.22998800E+03, 0.31607800E+03, 0.10100500E+04, 0.96500700E+03, -.28722700E+03, 0.72353300E+03, -.72812400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34892500E+01, -.77909700E+00, 0.24661700E+01, -.23525200E+00, 0.18700400E+01, 0.59341300E+00, -.44338600E+00, 0.14649300E+01, -.44681900E+00, -.10889300E+00, -.29289000E+00, -.10009800E+01, -.31040400E+01, -.24377300E+01, 0.14615200E+00, -.25627400E+00, -.94175200E+00, -.11621300E+01, 0.13287600E+00, 0.75565100E+00, 0.81906900E+00, -.50028400E+00, -.36203000E+01, 0.21884100E+01, -.41370400E+00, -.11029300E+00, 0.21669900E+00, -.62228000E-01, -.12126200E+01, -.33999100E+01, -.77110600E+00, 0.22956400E+00, -.12964800E+01, 0.65641400E+00, -.30148600E+00, 0.63065400E+00, 0.25302600E-01, 0.41178700E-01, -.35304300E+00, 0.33084400E+00, 0.11311400E+01, 0.11323800E+01, -.38622600E+01, 0.10613300E+05, -.94639000E+04, 0.38906400E+04, 0.73219400E+04, 0.47307300E+04, 0.14145800E+04, -.22556500E+04, -.17961600E+04, -.64100600E+04, 0.18542000E+04, -.27628100E+04, 0.60052400E+03, -.42417000E+03, 0.15211500E+03, -.40710000E+04, 0.21233400E+03, -.28567200E+04, -.25547000E+04, 0.19183700E+04, 0.70249000E+03, 0.61820300E+03, -.15017700E+04, 0.40426000E+04, 0.31807900E+05, -.15519500E+05, -.62631800E+04, -.15904300E+05, -.15813500E+03, 0.18516300E+04, -.57085100E+04, 0.49018600E+04, -.11581800E+05, 0.39065000E+04, -.10381500E+05, -.35418800E+05, 0.16970500E+05, 0.20624600E+05, 0.17709900E+05, -.11205700E+04, -.43531500E+04, 0.91414700E+04, -.44944000E+04, 0.11976100E+05, -.52372900E+04, 0.12442000E+05, -.77107500E+04, 0.46463600E+04, 0.29452600E+05, 0.38554600E+04, -.18962000E+04, -.14046200E+05, 0.32086400E+04, -.59038700E+04, -.52398800E+04, -.93721100E+04, -.11253100E+05, -.24539100E+03, -.15916400E+03, 0.36706800E+04, 0.12215300E+03, 0.13809800E+04, 0.24650300E+03, -.33575500E+04, -.43451200E+04, -.67212900E+03, -.67405000E+03, -.25423500E+04, 0.26093500E+05, -.13368200E+05, 0.69575700E+03, -.13046900E+05, -.98632100E+04, -.25295600E+05, 0.90753300E+04, 0.10087400E+05, -.45639100E+04, -.22703800E+05, 0.80575700E+04, 0.24214600E+05, -.11633400E+05, -.24924500E+05, -.12107100E+05, -.45262500E+04, 0.12138800E+05, 0.27570100E+04, 0.14646300E+05, -.33349600E+04, 0.10872000E+05, 0.11704900E+05, 0.14745200E+05, -.75404100E+04, 0.12951700E+05, -.73726400E+04, 0.53973100E+04, -.71299600E+04, -.23456400E+04, 0.61738700E+04, -.28504200E+04, -.65042100E+04, -.22782800E+05, 0.11387200E+05, -.51833000E+04, 0.17358400E+04, -.56875500E+04, 0.24914600E+04, 0.15515400E+05, -.79309900E+04, -.85769100E+04, -.93081100E+04, 0.17071000E+05, -.13760100E+05, -.31592500E+05, 0.16400500E+05, -.95241500E+04, 0.15796800E+05, 0.42033300E+04, 0.13962100E+05, -.13717300E+03, -.79846200E+03, 0.13357700E+05, 0.10555900E+05, 0.12951600E+05, -.33247500E+05, 0.15707400E+05, 0.38257000E+05, 0.16624000E+05, 0.25384100E+04, -.12862300E+05, -.77263800E+03, -.15271100E+05, 0.38186400E+04, -.11288300E+05, -.20637000E+04, 0.32216100E+05, -.16148900E+05, 0.32281600E+04, -.16108100E+05, -.84841900E+04, -.13625800E+05, 0.76596100E+04, 0.39255800E+04, -.10905800E+05, -.71452900E+04, -.15631600E+05, -.12973900E+04, 0.36273000E+03, 0.29615000E+05, 0.64861700E+03, 0.62505600E+04, -.15427700E+05, -.13201600E+04, -.32078400E+04, -.24098400E+02, -.13216200E+05, -.28155300E+05, 0.46290900E+05, -.25308500E+05, 0.15794200E+05, -.23145200E+05, -.87796700E+04, -.15251700E+05, -.52460700E+04, 0.32608100E+04, -.93562700E+04, -.21706300E+05, -.10529400E+05, -.10129500E+05, 0.56538300E+04, -.23700200E+05, 0.50643900E+04, 0.31275100E+03, 0.95111200E+04, 0.47464600E+04, 0.53808600E+04, 0.70245100E+04, 0.89562900E+04, 0.15594700E+05, 0.79908000E+04, -.41606500E+04, 0.90082400E+04, -.39954300E+04, -.85912000E+03, -.76587600E+04, -.27319900E+04, -.21832600E+04, -.41239500E+04, -.73314000E+04, -.99519600E+04, -.22339300E+05, 0.11779800E+05, -.10883600E+05, 0.11169300E+05, 0.43566300E+04, 0.28867400E+04, 0.63058400E+04, 0.50957700E+04, 0.71517700E+04, 0.58859500E+04, 0.95607200E+04, -.23669700E+05, 0.12354100E+05, 0.52709000E+04, 0.11834800E+05, 0.94925100E+04, 0.16034600E+05, -.66544900E+04, -.58619800E+04, 0.30815400E+04, 0.15147300E+05, -.40330500E+04, -.46646300E+04, -.80152600E+03, 0.52441800E+03, -.33995700E+03, -.78257700E+03, 0.30259000E+03, 0.12878100E+04, -.13596500E+04, -.99268200E+03, 0.17109500E+04, 0.31675300E+04, -.20170900E+01, 0.69925800E+04, -.50765600E+03, -.18577700E+04, 0.17810900E+04, 0.10158900E+05, 0.14653300E+04, 0.26158200E+04, 0.48241900E+04, 0.47299900E+04, -.24658600E+04, 0.24497600E+04, -.20821700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15445900E+01, 0.38884100E+00, 0.11960400E+00, 0.72854600E-01, -.11039200E+01, 0.56815000E+00, 0.26467800E+00, 0.46147400E+00, -.37660800E+00, 0.20119000E+00, -.32782300E+00, -.67052400E+00, -.15963500E+01, -.11732400E+01, -.61843300E-01, 0.10702100E+00, -.56670400E+00, 0.18947300E+00, 0.17329000E+00, -.14526900E+00, 0.92769000E-01, 0.78817700E+00, 0.98391700E+00, -.70999100E+00, 0.32986400E-01, -.32773800E+00, 0.31860600E+00, 0.65280000E+00, 0.50855300E+00, -.70791300E+00, 0.38322000E+00, 0.14505000E+00, 0.31139300E+00, 0.26222500E+00, 0.94495000E-01, -.27497500E+00, -.60002200E-02, -.13552400E+00, -.46227100E+00, -.27729600E+00, -.67016100E+00, -.52911600E+00, 0.16375100E+01, -.38106200E+00, 0.17966300E+05, -.90919200E+04, -.83584200E+04, -.89831100E+04, -.23109800E+04, 0.19945100E+03, -.27192300E+04, 0.19205200E+04, -.48371400E+04, 0.28910900E+03, -.38731000E+04, -.14400700E+04, 0.70372100E+03, -.24776300E+04, 0.72003300E+03, -.66017800E+03, -.28291500E+03, -.76884100E+03, -.25236500E+04, -.19915100E+03, -.19226700E+02, 0.14316100E+04, -.23979600E+04, 0.12135000E+04, 0.87681000E+03, 0.11989800E+04, -.97318100E+03, -.20734300E+04, 0.15607600E+04, -.48394100E+03, 0.42268200E+04, -.26953200E+04, 0.62210900E+04, 0.26289200E+04, -.13757900E+04, -.41157400E+03, -.13144700E+04, 0.46179800E+04, 0.40869500E+04, -.81358500E+03, 0.35780300E+04, -.48603500E+04, 0.51379600E+04, -.71940600E+04, 0.25640100E+05, -.12672000E+05, -.15759200E+05, -.12820100E+05, -.38776600E+04, -.24971700E+04, -.16001600E+04, 0.58606000E+04, -.51031200E+04, -.26896800E+04, -.70124600E+04, 0.89951600E+04, -.45366700E+04, -.34762600E+04, -.44975800E+04, -.85134000E+03, 0.69518100E+03, -.15946800E+04, 0.79654100E+03, -.26242800E+04, 0.59726400E+03, -.20609300E+04, 0.42022600E+03, -.24330700E+03, -.26135000E+04, -.21010100E+03, 0.14402400E+04, 0.29016900E+04, -.24128100E+04, -.43485300E+04, -.29562800E+04, 0.32432400E+04, -.72712900E+03, -.49173300E+05, 0.24579700E+05, 0.26243000E+05, 0.24586600E+05, 0.53630900E+04, 0.15122100E+04, 0.41419000E+04, -.12580300E+05, 0.10398700E+05, 0.23709000E+04, 0.17752200E+05, 0.11571800E+05, -.57339400E+04, -.62734500E+04, -.57858800E+04, -.34036200E+04, -.23195400E+04, 0.24850000E+04, 0.54677800E+04, -.20188100E+04, -.25551600E+04, -.31953700E+04, 0.14743100E+04, -.68720900E+03, 0.96056700E+03, -.73589700E+03, 0.16577100E+03, 0.25050700E+02, -.56634800E+03, 0.38613400E+03, 0.13943000E+04, -.24022000E+03, 0.56597300E+04, -.15543500E+03, 0.14749400E+03, -.14022700E+04, 0.77669600E+02, -.20761100E+04, -.31233800E+04, 0.24479400E+03, -.61983100E+03, 0.10144900E+04, -.35172000E+04, -.15880100E+04, 0.53979900E+05, -.27062300E+05, -.29137700E+05, -.26990000E+05, -.62345800E+04, -.22175900E+04, -.47991200E+04, 0.11750200E+05, -.11746200E+05, -.26091700E+04, -.19167900E+05, -.36545700E+03, 0.16904200E+03, -.31109500E+03, 0.18271800E+03, 0.54314200E+04, 0.84215800E+04, -.55209700E+04, -.38806900E+04, -.22678100E+04, 0.81590900E+04, 0.59113500E+04, 0.35529800E+05, -.17721600E+05, -.19434900E+05, -.17764900E+05, -.39854900E+04, -.65997400E+03, -.12270600E+04, 0.11712600E+05, -.79410700E+04, -.15255300E+04, -.12675900E+05, 0.19714000E+04, -.12599200E+04, 0.20843600E+04, -.98573100E+03, 0.11511100E+05, 0.12593900E+05, -.72658000E+04, -.50939100E+04, -.91621500E+04, 0.12914700E+05, -.13290300E+05, -.24888500E+05, 0.12517400E+05, 0.12324400E+05, 0.12444300E+05, 0.32192200E+04, 0.11259200E+04, 0.16800800E+04, -.59114500E+04, 0.48426800E+04, 0.10204200E+04, 0.93905000E+04, 0.15758700E+05, -.78553200E+04, -.87711100E+04, -.78793700E+04, -.23083200E+04, -.31531500E+03, -.90035600E+03, 0.33778900E+04, -.39372000E+04, -.47576800E+03, -.55845100E+04, 0.91556300E+04, -.45239300E+04, -.41297800E+04, -.45778000E+04, -.66087600E+04, -.38799300E+04, -.38701200E+03, 0.57936700E+03, 0.18589600E+04, -.51954300E+04, 0.33548900E+04, 0.84008400E+04, -.41078000E+04, 0.28341000E+03, -.42004300E+04, -.56887600E+04, -.87718100E+04, 0.66563400E+04, 0.89374400E+04, 0.30003100E+04, -.84994400E+04, -.11515500E+04, 0.14073200E+03, 0.18807800E+03, -.62371500E+02, 0.30778300E+03, 0.22251500E+03, 0.23258300E+03, 0.17768100E+03, 0.29884500E+03, -.82760500E+03, -.90093600E+02, 0.18271500E+04, -.17298000E+03, 0.58001100E+03, -.18505000E+04, 0.12239000E+04, -.18330100E+03, -.14597800E+04, -.95213700E+03, 0.20917500E+04, -.27806800E+04, -.11098600E+04, -.19307900E+03, -.35618600E+04, 0.81702700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30775200E+00, -.22829400E+00, -.16539300E+00, 0.15533300E+00, 0.80888800E-01, -.21606200E-02, -.27397700E-01, 0.19497100E+00, -.21795600E-01, 0.58676100E-01, 0.48616500E+00, 0.28319100E+00, 0.11881400E+01, 0.22442300E+00, 0.37158800E-01, 0.45148000E-01, 0.27590800E-01, 0.15956600E+00, 0.45896300E-01, -.12053600E+00, 0.88351300E-01, 0.10465900E+01, -.33675500E+00, 0.24549200E+00, 0.14792700E-01, 0.15729200E-01, -.61092500E-01, -.25557300E-02, -.63137700E-02, 0.43250400E-01, 0.24465600E-01, -.66997500E-02, -.23975300E+00, 0.94737800E-01, 0.15791700E-01, 0.98333300E-01, -.39104900E-02, 0.61465400E-01, -.15833900E-01, -.98247800E-02, 0.23556300E+00, -.48809500E-01, -.12015200E+01, -.79128300E-01, -.16883600E+00, -.35279200E+03, 0.30772200E+03, -.11583200E+01, 0.15329100E+03, -.12937900E+04, 0.18342600E+03, -.67908500E+02, 0.32628400E+03, -.13390100E+04, -.47519300E+03, -.79183100E+03, 0.36530100E+03, -.46663500E+03, 0.39610600E+03, -.52714500E+03, -.82761300E+03, 0.67621300E+03, 0.32839800E+03, 0.42206500E+03, -.64802800E+03, 0.11170100E+04, 0.14935000E+04, -.59239000E+03, 0.46164400E+03, -.74703100E+03, 0.72872300E+03, -.11137200E+04, 0.44123300E+03, 0.12241000E+04, 0.16434700E+03, -.93529600E+03, -.27039200E+04, -.30249500E+04, 0.12129000E+04, 0.18175400E+04, 0.15129200E+04, -.49791200E+03, 0.39443100E+03, 0.50031600E+03, -.59576400E+03, 0.38980800E+03, 0.37702700E+03, 0.22333400E+04, 0.16806400E+04, -.45138400E+03, 0.37476500E+04, -.84008700E+03, -.14710400E+04, -.26522800E+04, 0.10906900E+04, 0.39665100E+03, -.13757000E+04, -.20280300E+04, -.11181900E+04, 0.10147800E+04, -.62182600E+03, 0.16941300E+02, -.50783100E+03, 0.28331200E+03, -.49416700E+03, -.31549800E+03, -.55990500E+02, -.49580400E+02, -.61645100E+03, -.65866800E+03, 0.98492500E+03, -.58670800E+03, 0.10967900E+04, -.49269000E+03, -.17166200E+04, -.50485200E+04, 0.29683300E+04, 0.28591500E+04, 0.10540800E+04, -.44641500E+04, 0.68377400E+03, 0.48525900E+04, -.23227200E+04, -.29789000E+04, -.24261300E+04, 0.26145100E+03, 0.20810400E+04, -.29053900E+03, 0.28263800E+04, -.68373200E+03, 0.17774000E+04, -.23595800E+04, 0.25837800E+04, -.12750500E+04, 0.10129100E+04, -.12919500E+04, 0.51710200E+03, -.18143500E+04, 0.90958900E+02, 0.46142000E+03, -.44433200E+03, -.16920600E+04, -.33609700E+04, -.70659100E+03, 0.54225700E+03, 0.14751200E+04, 0.35453500E+03, 0.89340400E+03, 0.46706200E+03, 0.28768300E+03, 0.57512200E+03, 0.12448500E+04, -.67954200E+02, -.27265800E+04, -.17477000E+04, 0.11040600E+04, -.26213800E+04, 0.87467500E+03, 0.10263700E+04, 0.36187500E+04, -.12914600E+04, -.10177000E+04, -.32325400E+03, 0.35620800E+04, 0.14622500E+04, -.59088200E+04, 0.26338900E+04, 0.54834500E+04, 0.29546500E+04, -.13316400E+04, -.26391200E+04, 0.15891000E+04, -.93880000E+03, 0.15452600E+04, -.21374500E+04, 0.40104700E+04, 0.81953300E+03, -.42274000E+03, 0.22888300E+04, -.40969100E+03, -.85702800E+03, -.51386200E+04, 0.32068500E+04, 0.35978900E+04, 0.31345900E+04, -.52275600E+04, -.20886000E+04, 0.29048900E+03, -.15820500E+03, 0.28509700E+04, -.14532700E+03, 0.29017000E+03, -.26906500E+04, 0.23651800E+03, -.98839300E+03, -.21170600E+03, -.23057200E+04, -.15034800E+04, 0.10147900E+05, -.59720400E+04, 0.13771300E+04, -.50734700E+04, -.20861800E+04, -.94844500E+03, -.22051000E+04, -.59634600E+03, -.36421200E+04, -.91684900E+03, 0.33653100E+04, -.97535100E+03, 0.71304600E+03, -.37843700E+04, 0.48721700E+03, 0.94221300E+03, 0.18743000E+04, -.32140100E+03, 0.12316600E+03, 0.42690900E+03, 0.16135600E+04, -.15141500E+03, 0.16186900E+04, -.82510000E+03, 0.15463600E+04, -.80937100E+03, -.57167800E+03, -.15709100E+04, 0.29577400E+03, 0.56002400E+02, -.97313200E+03, -.13708400E+04, -.91773900E+03, -.64028000E+04, 0.34423100E+04, 0.46439500E+02, 0.32010200E+04, 0.11779900E+04, -.15592700E+03, 0.21070500E+04, 0.15877800E+04, 0.29473100E+04, -.15644900E+03, -.35725100E+03, -.37707700E+03, 0.41759300E+03, -.13639100E+04, 0.18857000E+03, 0.10443600E+04, 0.28681100E+04, -.20831700E+04, -.27181000E+04, -.12724600E+04, 0.27228900E+04, -.24443400E+04, -.19724600E+02, -.14888500E+03, 0.21467000E+03, -.80099500E+02, -.28971400E+03, 0.10616500E+03, 0.23919300E+03, -.59967400E+02, 0.66857100E+01, -.14834600E+02, 0.82694500E+03, -.47856400E+03, 0.18828100E+04, -.53779000E+03, -.18958000E+03, -.20518800E+03, 0.19768100E+04, -.78161100E+02, 0.11465000E+04, 0.58586700E+03, 0.12391200E+04, -.12034300E+03, 0.51834800E+03, -.82970200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16601200E+01, -.26101500E+00, 0.17463100E-01, -.29301000E+00, 0.11599000E+01, 0.12347600E+00, -.28495500E+00, -.86216200E-01, 0.16433800E+00, -.23698800E+00, -.13150600E+01, -.57242100E+00, -.95224200E+00, -.97734300E+00, 0.29742300E+00, 0.16014800E+00, -.10980100E+00, -.11869400E+01, -.22157100E+00, 0.27218400E+00, -.13704500E+00, -.16878700E+01, -.13587100E+01, 0.74130400E+00, -.84313500E-01, 0.42379600E+00, -.37394100E+00, -.43905100E+00, -.17723300E+00, -.75457700E+00, -.33350300E+00, -.15607900E+00, 0.11116500E+00, 0.11251400E+00, -.67197000E-01, -.30362500E+00, -.17262300E-01, -.20846400E-01, 0.30350500E+00, 0.27176900E+00, -.16925000E+00, 0.20301100E-01, -.15739300E+01, 0.11851700E+00, -.76216100E-01, 0.11792600E+00, 0.10361100E+04, -.22599900E+00, -.12308200E+03, 0.14226400E+04, -.81152700E+03, -.61918400E+03, -.16030100E+04, 0.15444000E+04, 0.47618400E+03, 0.27549000E+03, -.13542300E+03, -.97996100E+03, -.13774200E+03, -.10772700E+04, 0.21339400E+03, 0.94449300E+02, 0.39353600E+03, 0.82473900E+02, 0.41135900E+03, 0.78917600E+03, 0.34285300E+04, -.17094200E+04, 0.35964200E+03, -.17142700E+04, 0.18919600E+03, -.27127600E+03, -.24133200E+03, 0.32769800E+03, -.15942100E+03, -.68912300E+01, -.59888400E+03, 0.19302400E+03, -.11956500E+03, -.16791600E+04, -.96431800E+02, 0.16061400E+04, 0.32838200E+04, -.15554300E+04, -.85498800E+03, -.22037000E+04, 0.28350400E+04, -.86194800E+03, 0.15001800E+04, -.71118300E+03, -.20794000E+04, -.74994000E+03, 0.15275700E+04, -.91946700E+03, -.22023500E+04, -.47864200E+04, -.52376300E+04, 0.37822000E+03, 0.31437600E+03, -.31572900E+03, 0.16143900E+03, 0.10570800E+04, 0.15783100E+03, 0.21991300E+03, 0.73033000E+03, -.79175500E+03, -.11606000E+04, -.96236700E+03, 0.64460500E+03, 0.57643700E+03, 0.51390800E+04, -.25422100E+04, -.57510300E+04, -.25696300E+04, 0.77104500E+03, -.22965600E+04, -.19416600E+04, -.40099400E+04, -.41457400E+04, -.19015100E+04, -.43449900E+03, -.26316300E+05, 0.13077900E+05, 0.12715800E+05, 0.13158200E+05, 0.16261100E+04, 0.24222000E+04, 0.46130300E+04, -.25023300E+04, 0.88721000E+04, 0.14842500E+04, 0.90909100E+04, 0.11861500E+05, -.58707900E+04, -.26444700E+04, -.59307900E+04, -.22159400E+04, -.17112900E+04, -.44576400E+03, 0.26953400E+04, -.43250300E+04, -.13763100E+04, -.27121000E+04, 0.43018800E+04, -.21662800E+04, 0.22685800E+04, -.21519500E+04, 0.52822100E+03, 0.31216100E+04, -.73751700E+03, 0.21982700E+04, -.10257600E+04, 0.29380200E+04, -.34794600E+04, -.55733600E+04, 0.27713900E+04, 0.19978300E+04, 0.27870500E+04, -.42926200E+03, 0.11731700E+04, 0.14385000E+04, 0.12877900E+04, 0.34432200E+04, 0.77823600E+03, 0.21908700E+04, 0.17461100E+05, -.86612600E+04, -.98017900E+04, -.87305100E+04, 0.14178300E+04, -.10802700E+04, -.51050700E+04, -.23391200E+04, -.86023900E+04, -.39070000E+03, -.76539700E+04, 0.98006100E+04, -.48949600E+04, -.33515300E+04, -.49002300E+04, 0.75816400E+03, 0.16655200E+04, -.30724000E+04, -.62832500E+03, -.41459700E+04, 0.20119300E+04, -.29575100E+04, 0.23782900E+05, -.11812400E+05, -.88216500E+04, -.11891500E+05, -.21104900E+04, -.24810400E+04, -.28961100E+04, 0.40969100E+04, -.79968400E+04, -.15932200E+04, -.88977300E+04, 0.15534500E+05, -.77980000E+04, 0.14652600E+04, -.77670200E+04, 0.43461800E+04, 0.70472700E+04, -.70957500E+04, -.12869500E+04, -.68087400E+04, 0.42492100E+04, -.79088900E+04, -.14661000E+05, 0.72910900E+04, 0.55587700E+04, 0.73303500E+04, -.49274300E+03, 0.93350000E+03, 0.37830700E+04, 0.98598600E+03, 0.61606700E+04, 0.63365900E+03, 0.61786200E+04, 0.53449600E+04, -.26415300E+04, -.23661300E+04, -.26724800E+04, -.52179300E+03, -.10739400E+04, -.12290800E+04, -.10945300E+04, -.36162400E+04, -.80738300E+03, -.12658400E+04, -.55479600E+04, 0.27938400E+04, -.10879900E+04, 0.27738900E+04, -.13736400E+04, -.51225400E+04, 0.29940300E+04, -.21443600E+02, 0.38595700E+04, -.38452800E+04, 0.15322300E+04, -.14135700E+04, 0.72104800E+03, 0.13499000E+04, 0.70683900E+03, -.12551000E+04, 0.17327500E+03, 0.16674400E+04, 0.19481900E+04, 0.96573400E+03, 0.57614700E+03, 0.12870000E+04, -.91615600E+03, -.20283100E+03, 0.17690800E+03, -.58391300E+02, 0.15971000E+03, -.20994900E+03, 0.28711700E+03, 0.60711000E+02, -.56376900E+03, 0.47579300E+03, 0.11777300E+04, -.20774800E+03, -.39564100E+03, 0.26911800E+03, -.22613800E+03, 0.45240800E+03, 0.53417200E+03, 0.56257100E+03, -.28499500E+03, -.43814000E+03, 0.74208900E+03, -.93004400E+03, -.16120600E+04, -.12444200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19394600E+01, 0.51074700E+00, 0.18082000E+00, -.10085000E+01, -.99679700E+00, 0.10176300E+00, 0.16749900E+00, 0.38377900E+00, -.25200900E+00, 0.75079300E-01, -.54618500E+00, -.70248600E+00, 0.20164000E+01, -.62354200E-01, 0.42267400E+00, -.87413300E-01, -.22731900E+00, -.11117400E+00, 0.35657100E+00, -.11179300E-01, 0.24597900E+00, -.26907100E+00, -.28802100E+01, 0.22751600E+01, -.80694200E-03, -.59318500E-01, -.10732800E+00, -.33242500E-01, -.17810900E+00, -.13236400E+01, 0.92392100E-01, 0.12209200E+00, -.29003400E+00, 0.34929300E+00, 0.39730100E-01, 0.51920600E+00, 0.85986800E-01, -.18469800E+00, -.38393000E+00, 0.44264200E-02, -.40064000E+00, 0.35278600E+00, -.30510900E+00, 0.15013700E+00, -.50750000E+00, 0.66063500E+00, 0.21580300E-01, 0.43288900E+01, -.82151500E+02, 0.14670100E+04, -.56841100E+03, -.24504700E+03, -.20466100E+04, 0.17245600E+04, 0.61153400E+03, -.18947900E+04, 0.95238500E+03, 0.58622000E+03, 0.94673100E+03, 0.26018100E+03, 0.43941100E+03, 0.19524900E+03, -.21791600E+03, 0.35568000E+03, 0.44497300E+03, 0.38401100E+03, -.33043500E+04, 0.16379300E+04, 0.69314700E+03, 0.16531500E+04, -.32860700E+03, -.13503200E+02, 0.37671800E+03, -.10927900E+04, 0.24445800E+04, -.22364400E+03, 0.22953100E+04, 0.44805000E+04, -.22399000E+04, -.25594700E+04, -.22419100E+04, 0.13819600E+04, 0.14060200E+04, -.10986000E+04, 0.16968000E+04, -.31505800E+04, 0.14524500E+04, -.19231400E+04, 0.19837000E+04, -.96771100E+03, -.68419000E+04, -.99287000E+03, 0.18855400E+04, 0.18955400E+04, -.12225900E+04, -.70237900E+03, -.22278200E+04, 0.19138500E+04, -.86821600E+03, -.51906600E+03, 0.26515200E+03, 0.15022100E+03, 0.26905300E+03, -.21550300E+03, 0.57825100E+03, -.18452400E+03, -.54296600E+03, -.92322300E+03, 0.71308000E+03, 0.70061400E+03, -.59578100E+03, 0.27305400E+03, -.34408200E+04, 0.29881200E+03, 0.16736300E+04, 0.27452400E+04, -.16950100E+04, -.32708800E+04, -.64799200E+03, 0.24810000E+04, -.46910100E+03, -.17008300E+05, 0.85126100E+04, 0.12089100E+05, 0.85035300E+04, 0.84043100E+03, -.71452700E+03, 0.13621500E+04, -.57571500E+04, 0.38723600E+04, -.12293600E+04, 0.74233000E+04, 0.50887300E+04, -.25372000E+04, -.49050200E+04, -.25441400E+04, -.20304600E+04, -.14614200E+03, 0.70271500E+03, 0.21146200E+04, -.17725900E+04, 0.27981500E+03, -.14525300E+04, 0.68388200E+03, -.33214000E+03, 0.38050300E+03, -.34588400E+03, -.56213300E+03, -.10006500E+04, 0.46241300E+03, 0.11752000E+04, 0.84245100E+03, -.57995400E+03, 0.93158100E+03, 0.20302400E+04, -.98839900E+03, 0.21627000E+04, -.10185000E+04, -.77804300E+03, -.15063200E+04, 0.12561300E+03, 0.85307200E+02, -.54408700E+03, -.18198500E+04, -.11734900E+04, 0.82950300E+04, -.41612600E+04, -.91895800E+04, -.41484100E+04, 0.19132500E+04, 0.28319300E+04, -.21587100E+04, 0.69788700E+03, -.40004000E+04, 0.27689500E+04, -.33726700E+04, 0.17656200E+03, -.99257200E+02, -.28745600E+04, -.88650800E+02, 0.13751300E+04, 0.29091500E+04, -.21474400E+04, -.17559100E+04, 0.25930600E+03, 0.32590400E+04, 0.90383200E+03, 0.12847500E+05, -.64250600E+04, -.11430200E+05, -.64234600E+04, -.16268300E+04, 0.86781700E+03, -.42781100E+03, 0.51840500E+04, -.33012300E+04, 0.13824900E+04, -.54501900E+04, -.44327200E+04, 0.21556400E+04, 0.32588600E+02, 0.22142800E+04, 0.48366100E+04, 0.48408800E+04, -.95025900E+03, -.16065300E+04, -.15504400E+02, 0.40082400E+04, -.83085700E+03, -.15355800E+04, 0.78330400E+03, 0.45947200E+04, 0.76960200E+03, -.11343300E+04, -.16964000E+04, 0.68477200E+03, -.39379500E+02, 0.85150000E+03, -.17362300E+04, 0.19206600E+03, 0.31659100E+04, -.15811500E+04, -.38483400E+04, -.15828700E+04, 0.20532000E+03, 0.59767100E+03, -.51500500E+02, 0.85164900E+03, -.17085100E+04, 0.75416800E+03, -.17304100E+04, 0.63116900E+04, -.31471400E+04, -.75009000E+03, -.31544000E+04, -.19936500E+04, -.13270000E+04, -.16388900E+04, -.13127800E+04, -.11115100E+04, -.12744300E+04, -.25639800E+04, 0.25575200E+04, -.12526400E+04, 0.17501900E+04, -.12789400E+04, -.20200400E+04, -.24937200E+04, 0.15673900E+04, 0.22159400E+04, -.10104200E+04, -.20909000E+04, 0.51206100E+03, 0.18300700E+03, 0.85669900E+02, -.41921700E+02, 0.91784800E+02, 0.24988700E+03, -.29129800E+03, -.13129400E+03, 0.26704200E+03, 0.16623500E+03, 0.48769000E+02, 0.36144800E+02, 0.49095800E+02, -.18371300E+04, -.94778100E+02, 0.20999000E+03, -.70987000E+01, -.19323800E+04, 0.35599100E+02, -.52560600E+03, -.89325700E+03, -.72653000E+03, -.29201100E+03, -.10120600E+04, 0.32090300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.28578900E+01, 0.98512000E+00, -.11732700E+01, 0.63748800E+00, -.16017000E+01, -.28381500E+00, 0.32694500E+00, -.23033500E+00, -.34812700E+00, 0.42662700E+00, 0.23361100E+01, 0.36301700E+00, -.18564800E+01, -.27893100E+01, -.10034900E+00, -.36026900E+00, -.83341900E+00, -.86305200E-01, 0.30875600E+00, 0.85325100E+00, 0.55240400E+00, 0.50073500E+00, 0.14880100E+00, 0.40448100E+00, -.23272000E+00, -.34019800E+00, 0.22092500E+00, -.90449200E-01, 0.96355700E-01, -.22795100E+01, -.15569500E-01, 0.18002600E+00, 0.13146000E+00, -.97869900E-01, -.60987200E-01, 0.37953200E+00, 0.59219500E-01, 0.16713500E+01, 0.55965900E+00, 0.17149400E+00, -.15059900E+00, -.15759500E+01, 0.18270300E+01, -.46844400E+00, 0.80095200E+00, 0.43719900E+00, 0.92856400E+00, 0.97968800E+00, -.29665400E+04, -.91453500E+04, 0.25682800E+04, 0.29029300E+03, 0.97598000E+04, -.98869400E+04, 0.12742400E+03, 0.97520400E+04, -.48702200E+04, -.46718200E+04, -.48759100E+04, -.33815000E+03, -.93598800E+03, -.31087500E+04, -.20660200E+04, -.33095300E+04, -.11652300E+04, 0.40626600E+03, 0.18111000E+05, -.90565700E+04, -.38022700E+04, -.90556700E+04, -.18113600E+04, 0.19481000E+04, -.45627000E+04, -.42196900E+02, -.12374200E+05, 0.37989400E+04, -.74732200E+04, -.31333000E+05, 0.15674600E+05, 0.19575700E+05, 0.15666500E+05, -.56191100E+04, -.16263300E+05, 0.12750400E+05, -.16505700E+03, 0.19996600E+05, -.15935400E+05, 0.16229600E+05, -.17862900E+05, 0.87974100E+04, 0.32961400E+05, 0.89311100E+04, -.39752900E+04, -.83445100E+04, 0.71552000E+04, -.40005800E+04, 0.11388200E+05, -.85868300E+04, -.60288300E+04, 0.65471000E+04, -.32589600E+04, -.20832000E+04, -.32815000E+04, -.17322700E+04, -.34620000E+04, -.54032000E+03, 0.96731400E+03, 0.29051900E+04, -.38062800E+04, -.17788400E+04, 0.18455700E+05, -.93760000E+04, 0.10163700E+05, -.92277100E+04, -.95933300E+04, -.15762900E+05, 0.45476200E+04, 0.56941700E+04, -.26219000E+04, -.14599200E+05, -.24029000E+04, 0.14493800E+06, -.72134200E+05, -.87369500E+05, -.72469000E+05, -.10291600E+05, 0.31248700E+04, -.18924400E+05, 0.37650100E+05, -.37107600E+05, 0.34768200E+04, -.37482100E+05, -.44557600E+05, 0.22019500E+05, 0.37062200E+05, 0.22278800E+05, 0.11478700E+05, 0.12773500E+04, 0.58155800E+04, -.76845900E+04, 0.13791800E+05, 0.10264100E+04, 0.54323100E+03, -.25482000E+04, 0.13590700E+04, -.12976900E+04, 0.12804200E+04, -.25933800E+04, 0.40669400E+04, -.19673500E+04, -.65958000E+04, -.35161700E+04, 0.63294300E+04, -.96770200E+04, -.16951600E+05, 0.85812000E+04, -.98755000E+04, 0.84751100E+04, 0.77339100E+04, 0.12411300E+05, -.43185000E+04, -.21943700E+04, 0.29615500E+04, 0.10209700E+05, 0.14247700E+05, -.86705500E+05, 0.43090500E+05, 0.67879200E+05, 0.43352800E+05, -.75086800E+03, -.11821500E+05, 0.15571200E+05, -.19588000E+05, 0.30450300E+05, -.11520800E+05, 0.18917400E+05, 0.27545400E+05, -.13801800E+05, 0.35013100E+03, -.13772900E+05, -.16329400E+05, -.17461400E+05, 0.67364900E+04, 0.29817100E+04, -.85576700E+04, -.13026800E+05, -.12887000E+05, -.12416000E+06, 0.61736700E+05, 0.88176100E+05, 0.62080000E+05, 0.13675900E+05, -.46548500E+04, 0.18438300E+05, -.28822700E+05, 0.34189700E+05, -.40959200E+04, 0.23956400E+05, 0.39136200E+04, -.20178200E+04, 0.13226700E+05, -.19572700E+04, -.22051500E+05, -.35445600E+05, 0.10588400E+05, 0.59010500E+04, 0.96770800E+04, -.34543800E+05, 0.23403100E+05, 0.38464300E+05, -.19101300E+05, -.40510100E+05, -.19231900E+05, 0.22025400E+03, 0.69866300E+04, -.70432000E+04, 0.94973000E+04, -.13401400E+05, 0.71858200E+04, -.52356400E+04, -.26155400E+05, 0.12927400E+05, 0.22290200E+05, 0.13077700E+05, 0.20057100E+04, -.25739600E+04, 0.34330500E+04, -.72146900E+04, 0.10040900E+05, -.34641300E+04, 0.43624300E+04, -.10366400E+02, 0.14134100E+02, -.12639100E+05, 0.52495000E+01, 0.10435500E+05, 0.20242600E+05, -.50249300E+04, -.51372100E+02, -.91745300E+04, 0.20225800E+05, -.66968800E+04, -.28031800E+05, 0.14006300E+05, 0.35434500E+04, 0.14015800E+05, 0.10535100E+05, 0.11501300E+05, 0.76785800E+02, -.11803900E+04, 0.10433800E+05, 0.10343200E+05, -.15818300E+04, -.21521100E+04, -.34379200E+03, 0.39895200E+02, -.13972800E+03, -.29546500E+03, 0.26386800E+04, 0.57808700E+03, -.86187700E+03, 0.12002700E+04, 0.65381200E+03, -.40595900E+04, -.64344000E+03, 0.80363200E+04, 0.91375900E+03, -.20317900E+04, 0.99642700E+03, 0.10024800E+05, 0.92919700E+03, 0.19715200E+04, 0.60270600E+04, 0.33307600E+04, -.15773400E+03, 0.73572200E+04, -.20779900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12414600E+01, 0.32893000E+00, 0.25464300E+00, -.62313700E+00, -.11002900E+01, -.31226700E+00, 0.15758600E+00, -.26181200E+00, 0.51859900E-01, -.47555000E-01, -.34976400E+00, -.18041100E+00, 0.95265800E+00, -.25886300E+00, -.22797900E-01, 0.15602200E+00, -.21115000E+00, 0.60503700E-01, -.16803000E+00, -.39986900E+00, 0.29122600E+00, 0.38310700E+00, -.20749300E-01, -.58752200E-01, 0.11917100E+00, 0.50339100E-01, 0.11727300E+00, -.68777300E-01, 0.24565500E-01, 0.45820700E+00, -.40912400E-01, -.12878700E+00, 0.38418300E+00, 0.10582000E+00, 0.65591600E-01, -.35570100E+00, -.22783300E-01, -.29452500E+00, 0.36582100E+00, -.72109600E-01, -.20944800E-01, -.36950700E+00, 0.50648400E+00, -.34034300E+00, 0.12792500E-01, 0.95046200E+00, -.94942700E-02, -.94193100E-01, 0.31644400E+00, 0.31550700E+04, 0.10545000E+03, 0.66957500E+03, -.28170400E+04, 0.36609300E+04, 0.72733000E+03, -.41365100E+04, 0.20670400E+04, 0.10792800E+04, 0.20682100E+04, -.28375700E+03, 0.13781300E+03, 0.16769400E+04, 0.10774100E+04, 0.15913700E+04, 0.25490000E+03, 0.22110500E+03, -.57078900E+04, 0.28442000E+04, 0.10110000E+04, 0.28540300E+04, 0.12033000E+03, 0.10556100E+04, 0.52251000E+03, -.13902300E+04, 0.36532600E+04, 0.47921500E+03, 0.60096200E+04, 0.11249000E+05, -.56269000E+04, -.80139500E+04, -.56245100E+04, 0.32223400E+04, 0.37933100E+04, -.39403700E+04, 0.10915200E+04, -.66544900E+04, 0.36969200E+04, -.73317100E+04, 0.62426300E+04, -.30625300E+04, -.13671300E+05, -.31211500E+04, 0.26784600E+04, 0.38189600E+04, -.30387100E+04, 0.14450600E+03, -.27753500E+04, 0.36188300E+04, -.85147200E+03, -.14800700E+04, 0.74927700E+03, 0.73824300E+03, 0.74332600E+03, 0.56891700E+02, 0.17232700E+04, -.64283800E+02, -.60070800E+03, -.13246000E+04, 0.19238300E+04, 0.90793900E+03, -.51851900E+03, 0.27505100E+03, -.63072700E+04, 0.25918300E+03, 0.48829700E+04, 0.89240200E+04, -.60762100E+04, -.65716400E+04, -.27856800E+04, 0.82176700E+04, -.19777900E+04, -.45983700E+05, 0.22913300E+05, 0.24877600E+05, 0.22991900E+05, 0.26906700E+04, -.14319800E+04, 0.45128600E+04, -.14213300E+05, 0.10368000E+05, -.16291100E+04, 0.16892200E+05, 0.99188400E+04, -.48850300E+04, -.97794300E+04, -.49594300E+04, -.39397900E+04, 0.52140700E+03, -.45393900E+03, 0.27062200E+04, -.29001000E+04, 0.78086800E+03, 0.14971800E+04, 0.27090300E+04, -.13680800E+04, -.10376900E+04, -.13565900E+04, 0.25004700E+03, -.12575500E+03, -.54742500E+03, 0.78452200E+03, -.10333000E+04, 0.20758100E+02, 0.46017400E+04, 0.27376600E+04, -.13694200E+04, 0.49055800E+04, -.13685100E+04, -.33768500E+04, -.68065000E+04, 0.27281000E+04, 0.16545600E+04, 0.89398400E+03, -.65160900E+04, -.31423000E+04, 0.31619200E+05, -.15755200E+05, -.23660100E+05, -.15809600E+05, 0.23191700E+04, 0.47665000E+04, -.58500300E+04, 0.56079000E+04, -.99013700E+04, 0.44500900E+04, -.13977900E+05, -.15988300E+04, 0.79620600E+03, -.45881700E+04, 0.79950600E+03, 0.55920000E+04, 0.10971500E+05, -.76427700E+04, -.57272600E+04, -.36166900E+04, 0.10365300E+05, 0.37945200E+04, 0.33661500E+05, -.16741800E+05, -.24634900E+05, -.16830800E+05, -.36519800E+04, 0.26664800E+04, -.40637800E+04, 0.10034000E+05, -.84169700E+04, 0.25491000E+04, -.90074600E+04, -.75499500E+04, 0.37341100E+04, -.41016300E+04, 0.37752000E+04, 0.97671300E+04, 0.11053200E+05, -.18105200E+04, 0.80711900E+02, -.60998700E+03, 0.98068200E+04, -.12230700E+05, -.94337100E+04, 0.46989000E+04, 0.14008300E+05, 0.47167500E+04, -.13107500E+04, -.31342800E+04, 0.19209900E+04, -.24263200E+04, 0.24069500E+04, -.29876900E+04, 0.37893500E+04, 0.83225100E+04, -.41194000E+04, -.86736100E+04, -.41612500E+04, -.67294800E+03, 0.11063100E+04, -.67339400E+03, 0.23774900E+04, -.22096100E+04, 0.13214100E+04, -.22650500E+04, 0.11131100E+05, -.55640600E+04, 0.13932500E+04, -.55655800E+04, -.45736400E+04, -.45292900E+04, -.27778800E+04, -.38722700E+04, -.19476000E+04, -.42005600E+04, 0.92295900E+03, 0.42626000E+04, -.21039300E+04, 0.33822300E+04, -.21312300E+04, -.46462300E+04, -.71328200E+04, 0.51664400E+04, 0.54926000E+04, 0.58561400E+03, -.64651700E+04, 0.33985400E+04, 0.64517800E+02, 0.14104600E+03, -.17336000E+03, 0.74997700E+02, 0.57368300E+03, -.53077800E+03, -.16687400E+03, 0.49458700E+03, -.15311400E+03, 0.10363700E+03, 0.49356100E+03, 0.70117700E+03, -.34746800E+04, -.23860000E+03, 0.66539000E+03, 0.23742300E+03, -.43628900E+04, 0.10602500E+02, -.10329200E+04, -.22599300E+04, -.20542700E+04, -.26680900E+02, -.25782200E+04, 0.15916600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.63509400E+00, 0.16062000E+00, 0.26815700E+00, -.41710200E+00, -.37825000E+00, -.63759800E-01, 0.55382300E-01, -.33427700E+00, -.52952000E-01, -.46515900E-01, -.18949800E+00, -.19247300E+00, -.48640200E-01, -.52312700E+00, -.38046300E-01, 0.89743600E-04, -.93568800E-01, -.43945300E+00, 0.18793900E+00, -.16955200E+00, -.25502000E+00, -.12559500E+01, -.64314700E+00, -.36115300E-01, -.80499100E-01, 0.10904100E+00, -.28522500E-01, -.12353100E-01, 0.16752200E-01, 0.39632300E+00, -.14843400E-01, 0.14909800E+00, -.68193800E-01, 0.28814400E+00, 0.41193300E-01, 0.18397200E+00, -.42042800E-02, 0.53498300E-01, -.47527900E+00, -.49303400E-01, -.34550500E+00, 0.17746200E+00, 0.80217800E+00, 0.96365000E-01, 0.54409800E-01, -.14174300E+00, -.14570700E+00, 0.17821200E+00, 0.10985300E+00, 0.31468600E+00, -.76830600E+03, 0.34398900E+03, 0.94532900E+03, -.26408400E+03, 0.25943300E+02, 0.93655800E+03, -.47269200E+03, 0.45482400E+03, -.46826200E+03, -.10227400E+03, 0.30604300E+03, -.29820800E+03, 0.21414400E+03, -.43215200E+03, 0.38299000E+03, -.22351700E+03, 0.20080500E+04, -.99066200E+03, -.53271100E+02, -.10040500E+04, 0.36720700E+03, -.39554600E+03, -.19400200E+02, 0.31346000E+03, -.13136100E+04, -.35453100E+03, -.18943700E+04, -.27384600E+02, 0.34241000E+01, 0.83902500E+03, 0.13696100E+02, -.94750000E+03, 0.16793400E+04, -.77594100E+03, -.16642100E+04, -.28230500E+03, 0.15243000E+04, -.18367600E+03, -.38467700E+03, 0.16228500E+03, 0.24104700E+04, 0.19228400E+03, -.70097000E+03, -.14909400E+04, -.37132300E+03, -.15103400E+04, -.59035200E+03, -.96904800E+03, 0.29907700E+04, 0.83989600E+03, -.43542000E+03, -.50891800E+03, -.42154600E+03, -.62610200E+02, -.41163800E+03, -.31367800E+03, 0.55246700E+03, 0.55855000E+03, -.54050800E+03, -.32181600E+03, 0.40895000E+03, -.16414000E+03, 0.24219800E+03, -.20445000E+03, -.52932300E+03, -.31204200E+04, 0.19386300E+04, 0.34553300E+03, 0.17674900E+03, -.28830700E+04, 0.51506300E+03, -.38740900E+04, 0.18956100E+04, 0.31234900E+04, 0.19370400E+04, 0.10891100E+04, 0.88559100E+03, 0.22031500E+04, 0.15231900E+04, 0.26516200E+04, 0.97351900E+03, -.34182600E+04, 0.31091400E+04, -.15485200E+04, 0.84963300E+01, -.15545700E+04, -.12840400E+03, -.75827900E+03, -.10497100E+04, 0.18742800E+03, -.12422800E+04, -.10941600E+04, 0.72835400E+03, 0.12642100E+04, -.65149900E+03, 0.90942900E+03, -.63121700E+03, 0.51324400E+03, 0.15466100E+04, -.47263300E+03, 0.66757100E+03, -.59499300E+03, 0.91767800E+03, -.12933700E+04, -.20077700E+04, 0.95329300E+03, 0.12388500E+03, 0.10037800E+04, 0.12340000E+02, 0.12285200E+04, 0.70997500E+03, 0.78496000E+03, 0.11707700E+04, 0.15482300E+04, 0.10562500E+03, 0.66158900E+04, -.32568000E+04, -.21103400E+04, -.33079400E+04, -.16378700E+04, -.17914700E+04, -.22262800E+04, -.40912200E+02, -.25285000E+04, -.15610400E+04, 0.14349300E+04, 0.79030400E+03, -.37671900E+03, 0.12924500E+04, -.39518300E+03, -.72793000E+02, -.16030300E+04, 0.17086400E+04, 0.10816200E+04, -.26102800E+03, -.18972600E+04, -.83791200E+03, 0.76075500E+04, -.37810200E+04, -.18988800E+04, -.38037700E+04, -.11621800E+04, -.13104600E+04, -.20694400E+04, -.18615000E+03, -.33491700E+04, -.14610900E+04, 0.10849800E+04, 0.90622500E+04, -.44603500E+04, 0.10769500E+04, -.45312000E+04, -.16607600E+04, 0.11493100E+04, -.24279900E+04, -.82204600E+03, -.32179000E+04, 0.10928200E+04, -.31414800E+04, -.11300700E+05, 0.56081000E+04, 0.20306300E+04, 0.56503800E+04, 0.12113900E+04, 0.13854600E+04, 0.26304700E+04, -.60767800E+03, 0.42006200E+04, 0.12770200E+04, 0.25847600E+04, -.71490800E+03, 0.35888800E+03, 0.17061300E+04, 0.35745200E+03, 0.92005600E+02, -.12311800E+03, -.10293900E+04, -.10833200E+04, -.47883700E+03, -.22126300E+03, 0.16961000E+04, -.10393800E+05, 0.52056600E+04, 0.73480300E+03, 0.51969000E+04, 0.15038300E+04, -.29335200E+04, 0.37698300E+04, 0.20241300E+04, 0.44081200E+04, -.27422600E+04, 0.37281700E+04, 0.11617300E+04, -.60929700E+03, -.27705400E+04, -.58088800E+03, 0.38798600E+03, 0.24033600E+04, -.31081200E+04, -.14088900E+04, -.45775500E+03, 0.21076500E+04, 0.37832600E+03, -.30273800E+03, -.10216200E+03, 0.14433900E+03, -.10822300E+03, -.12774800E+03, -.71253000E+02, 0.81155900E+02, -.88970700E+02, -.26676800E+03, -.17448300E+02, 0.94375700E+02, -.28974500E+03, 0.83456300E+03, 0.15824400E+03, -.14832100E+03, 0.67678200E+02, 0.12021500E+04, 0.93883500E+02, 0.27038300E+03, 0.17521400E+03, 0.68031800E+03, -.31327300E+02, -.25736700E+03, -.42286300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13769200E+01, 0.15372300E+00, 0.26551100E+00, -.73023200E+00, -.45443200E+00, -.56854800E-01, 0.11360300E+00, -.18318300E+00, -.17196400E+00, -.17698400E+00, -.65929200E+00, 0.11426500E+00, 0.52455400E+00, 0.19137600E+00, -.42879800E-01, 0.18240700E+00, 0.95534500E-01, 0.58922400E+00, 0.15838300E+00, -.87273500E+00, 0.13913200E+00, 0.89801000E-01, 0.86499900E+00, -.69755500E+00, 0.41132800E-01, -.78611200E-01, -.28692600E+00, 0.15580000E+00, 0.25827600E+00, 0.46524300E+00, 0.21980300E+00, -.25156300E+00, -.64107500E-01, -.35147400E+00, 0.11465600E+00, -.39016200E+00, -.32414500E-01, -.57398400E-01, -.21887300E+00, -.68395300E-01, 0.13070000E+00, 0.50739400E-01, -.47118700E+00, 0.11611000E+00, -.26220600E+00, -.36531300E+00, 0.39890000E+00, -.43819400E+00, -.34650800E+00, 0.26084800E+00, 0.88185100E+00, -.31194200E+04, -.37968300E+03, -.36530700E+02, 0.35238600E+04, 0.43859800E+04, -.21983700E+04, -.26350600E+04, -.21929500E+04, 0.29660000E+02, -.37919300E+03, -.17252400E+04, -.21042900E+04, -.17814800E+04, -.68537100E+03, 0.17677800E+02, 0.88929300E+04, -.44879400E+04, -.26777600E+04, -.44465300E+04, -.32921700E+04, 0.26328500E+03, -.30387200E+04, -.50396700E+03, -.55883800E+04, -.99502500E+02, 0.52918400E+04, -.14170900E+05, 0.71474700E+04, 0.89500200E+04, 0.70854500E+04, -.10721700E+04, -.84534200E+04, 0.76648700E+04, 0.19005400E+04, 0.97651700E+04, -.64713000E+04, -.23789000E+04, 0.18256000E+05, -.91963200E+04, 0.43783200E+04, -.91281200E+04, -.33043000E+03, 0.29952800E+04, -.36432600E+04, 0.40499700E+04, -.41563200E+04, 0.11649700E+04, -.89094500E+04, -.16271800E+04, 0.79360200E+03, 0.81558800E+03, 0.81485500E+03, -.34108400E+02, 0.10980100E+04, -.20265900E+03, -.16863900E+04, -.43341700E+03, 0.11660500E+04, 0.22731200E+04, 0.54437000E+04, -.27737200E+04, 0.81804500E+04, -.27217900E+04, -.12047800E+04, 0.22079100E+04, -.38641900E+04, 0.17189100E+04, -.41405000E+04, 0.26037000E+04, -.24372200E+04, 0.25998000E+05, -.12895600E+05, -.20024400E+05, -.12999000E+05, -.41312100E+04, -.35697100E+04, -.44957200E+04, 0.45868100E+04, -.85838200E+04, -.25395600E+04, -.68897800E+04, -.17402100E+05, 0.86295900E+04, 0.12913900E+05, 0.87010700E+04, 0.58104800E+04, 0.40229800E+04, 0.30008100E+04, -.10916700E+04, 0.51229700E+04, 0.42037600E+04, 0.35622400E+04, 0.36074300E+02, -.97928500E+01, -.34457900E+04, -.17996200E+02, -.32684800E+04, 0.28341200E+03, -.24926300E+04, -.53714600E+04, -.21725000E+04, 0.71886700E+03, 0.80491200E+04, -.94002200E+04, 0.47177600E+04, -.48873300E+04, 0.46998500E+04, 0.45218200E+03, -.13111400E+04, 0.16618600E+04, -.17830000E+04, 0.27577700E+04, -.23931100E+04, 0.32184700E+04, -.14057100E+04, 0.63364800E+03, 0.12554600E+05, 0.70286300E+03, -.68925000E+01, 0.18974300E+04, 0.86792600E+03, -.23734000E+04, -.36861200E+03, 0.76237900E+03, -.24860300E+04, 0.84421400E+04, -.42393400E+04, 0.21673400E+04, -.42211400E+04, -.24764600E+04, 0.46752800E+04, -.67439200E+04, -.44508500E+04, -.78126600E+04, 0.54537400E+04, 0.43406900E+04, -.30517400E+05, 0.15152800E+05, 0.23938700E+05, 0.15258700E+05, 0.60017100E+04, 0.38090500E+04, 0.58775900E+04, -.35691200E+04, 0.99166600E+04, 0.33032700E+04, 0.80123400E+04, -.38271700E+05, 0.19214000E+05, 0.21386700E+05, 0.19135700E+05, -.31749400E+04, -.13099000E+05, 0.11310500E+05, -.14210100E+04, 0.12890100E+05, -.82040600E+04, 0.19804900E+04, 0.81278400E+04, -.40167200E+04, -.11997600E+05, -.40638300E+04, -.10984900E+04, -.14474300E+04, -.20407000E+04, 0.12788500E+04, -.10947100E+04, -.13078900E+04, -.19230200E+03, -.34194300E+04, 0.16751400E+04, 0.65957800E+04, 0.17097100E+04, 0.32016300E+04, 0.41776800E+04, -.53469800E+03, -.12358900E+04, 0.17640400E+04, 0.40510900E+04, -.13757100E+04, 0.29763000E+05, -.14927200E+05, -.16046400E+05, -.14881500E+05, 0.20900100E+04, 0.12043400E+05, -.10233100E+05, 0.42097400E+03, -.13226600E+05, 0.85387500E+04, -.18214300E+04, -.89990100E+04, 0.44877600E+04, 0.20061800E+03, 0.44994500E+04, 0.14044100E+04, -.28262900E+04, 0.58480400E+04, 0.40839700E+04, 0.51258000E+04, -.34460900E+04, 0.39966400E+04, -.12003100E+04, 0.19896100E+03, -.93112800E+02, 0.23636900E+03, -.21458700E+03, 0.14586500E+03, -.38157800E+02, -.81932200E+03, -.38609100E+03, 0.67656400E+03, 0.22674500E+03, 0.87387500E+03, -.16618700E+04, 0.11453800E+04, 0.89563200E+01, 0.54918700E+03, -.14879100E+04, -.72362800E+03, -.19195400E+04, -.51517800E+03, -.29067100E+04, -.16392600E+04, 0.63356100E+03, 0.19705800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.51884300E+01, 0.82219500E+00, 0.23623300E+01, -.34827900E+01, -.39959900E+01, 0.14829300E+01, 0.67323500E+00, -.30939600E+01, 0.48291500E+00, 0.87968100E+00, -.26205600E+01, -.20933800E+01, -.22758200E+01, -.47783000E+01, 0.81497600E+00, 0.55665400E+00, -.14604200E+01, -.11982300E+01, 0.88045000E+00, -.75933800E+00, 0.16482100E+01, 0.71087500E+01, -.11590000E+02, 0.61801300E+01, -.39857800E+00, -.14143800E+01, 0.23493100E+00, -.12579000E+01, -.13697200E+01, -.80689700E+01, 0.96050000E+00, -.12822000E+00, -.44592500E+00, -.97055700E+00, 0.21763900E+00, -.20782000E-01, 0.92521300E-02, -.82877900E+00, -.32238500E-01, 0.28895600E+00, 0.11664000E+01, -.23217500E+01, -.77862200E+01, -.41213500E+00, -.36046200E+00, 0.26091100E+01, -.83890900E+00, -.87549100E+00, -.86664400E+00, -.23114500E+01, 0.59336000E+01, 0.22768700E+01, -.81882800E+04, 0.17557600E+04, -.57105100E+04, -.12508600E+05, 0.63171500E+04, -.21547400E+04, 0.62540900E+04, 0.32529500E+03, 0.13227600E+04, 0.13501600E+04, -.28579100E+04, 0.36592500E+04, 0.17274000E+04, 0.38166800E+04, -.12059200E+05, 0.60226700E+04, 0.53865600E+04, 0.60299000E+04, 0.38193700E+04, 0.25574200E+04, 0.12691600E+04, -.20474600E+04, 0.15756300E+05, 0.54058200E+04, -.56529700E+04, 0.20504700E+05, -.10442200E+05, -.93218900E+04, -.10252400E+05, 0.89591700E+04, 0.30357400E+04, -.63749300E+04, 0.68113000E+04, -.21497700E+05, -.11426500E+04, 0.15555900E+05, -.39505000E+05, 0.20262400E+05, -.59384100E+04, 0.19753100E+05, 0.79451900E+04, -.12553000E+05, 0.13058500E+05, -.10230500E+05, 0.13411100E+04, -.68458700E+04, -.68455600E+04, 0.65203600E+04, -.28708400E+04, 0.17853500E+04, -.32459700E+04, -.11594000E+03, 0.34027200E+02, -.23125000E+04, -.32911200E+04, -.69669100E+04, 0.34054100E+03, -.42368600E+04, 0.29936600E+05, -.15556400E+05, -.30114600E+05, -.14968600E+05, 0.32096500E+03, -.71578400E+04, -.42063100E+04, -.11491700E+05, -.74977200E+04, -.88091600E+04, -.99894800E+04, 0.44819500E+05, -.21743800E+05, 0.16038600E+04, -.22409700E+05, 0.57116600E+03, 0.15980000E+05, -.17272600E+05, -.10451100E+05, -.27502300E+05, 0.10758900E+05, 0.95426200E+04, 0.13420100E+05, -.69194100E+04, -.14159500E+05, -.67101000E+04, -.13580900E+05, -.14244900E+05, 0.10841800E+05, 0.16311600E+05, 0.18371600E+04, -.10960400E+05, -.97764900E+04, 0.41705000E+04, -.16909800E+04, 0.33998400E+04, -.20914500E+04, 0.13762900E+04, -.16162300E+04, 0.56718700E+04, 0.94473400E+04, 0.24869300E+04, 0.58288800E+04, -.27491900E+05, -.37949500E+04, 0.26676800E+04, 0.59678700E+04, 0.18986300E+04, 0.47624900E+04, 0.12119100E+05, -.12714400E+05, -.97782500E+04, 0.22629700E+04, 0.80994900E+04, 0.12832700E+05, -.90465200E+05, 0.44418700E+05, 0.12203600E+05, 0.45232500E+05, 0.16482600E+05, -.61064800E+04, 0.15625600E+05, -.12489400E+05, 0.32140300E+05, -.37111500E+04, 0.59188700E+04, 0.39204100E+05, -.19813600E+05, -.27817900E+05, -.19601700E+05, -.56256100E+04, -.14734900E+05, 0.51126600E+04, 0.76689600E+04, -.33150300E+04, -.68920300E+04, -.28396700E+05, -.44559800E+05, 0.21833300E+05, 0.18247900E+04, 0.22279800E+05, -.39982300E+04, -.17285600E+05, 0.19399200E+05, 0.12469900E+05, 0.23881200E+05, -.11685400E+05, -.93422100E+04, 0.47930600E+05, -.25557200E+05, -.36718900E+05, -.23964500E+05, 0.11657100E+05, 0.25450300E+04, -.92728100E+04, 0.72668600E+04, -.96403800E+04, -.17290200E+05, 0.19493000E+05, 0.51669600E+05, -.25265100E+05, -.12866400E+05, -.25835100E+05, -.69267900E+04, 0.41890400E+04, -.89968800E+04, 0.79554800E+04, -.24268800E+05, 0.43586900E+04, -.76816800E+04, 0.23089300E+05, -.11690200E+05, -.19881200E+05, -.11544600E+05, -.10001600E+05, -.19379500E+05, 0.88800300E+04, 0.10110200E+05, -.70925600E+04, -.17856300E+05, -.10493900E+05, -.21727500E+04, 0.12957000E+04, 0.76062400E+04, 0.10862600E+04, -.10098600E+05, 0.95385200E+03, -.48364600E+04, -.15979600E+05, 0.35027500E+04, 0.11607300E+05, -.28109000E+05, -.20074500E+05, 0.10528600E+05, 0.32232600E+05, 0.10037500E+05, -.73860200E+03, 0.27995500E+04, 0.99120900E+04, 0.60019500E+04, 0.11357500E+04, 0.75909000E+04, -.10172800E+04, -.10173500E+04, -.82738600E+03, 0.47486700E+03, -.13913000E+03, 0.15673100E+04, -.66667500E+03, 0.96799600E+03, 0.19686600E+04, 0.34769600E+04, 0.53384100E+03, 0.23379300E+04, -.30545700E+03, 0.79379200E+04, -.67001900E+04, -.28269700E+04, 0.96437800E+03, 0.66155600E+04, 0.44851000E+04, 0.10081300E+05, 0.38028300E+04, 0.82864100E+04, 0.90145500E+03, 0.30764300E+04, -.38237000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34418500E+01, -.68760400E+00, -.41388600E+00, -.13450200E+01, 0.24053100E+01, -.50531800E+00, -.51686600E+00, 0.79108900E+00, 0.51661000E+00, -.11706000E+01, -.17416400E+01, -.23016800E+00, -.16591100E+00, -.90763800E+00, 0.65945600E+00, -.13842600E+00, -.50387100E+00, 0.51936000E+00, -.43897500E+00, 0.20678300E+01, -.16626600E+01, -.26214300E+01, -.98838500E+00, -.25728900E+00, 0.15588300E+00, 0.85127600E+00, 0.61483200E+00, 0.30413200E+00, 0.82196500E-01, 0.41177200E+01, -.10663800E+00, 0.13629300E+00, 0.15753800E+01, 0.63413600E+00, 0.45945500E-01, -.82266300E-01, 0.54642000E-01, -.98735600E+00, -.28502000E+00, 0.11524200E+00, -.38116900E+00, 0.10111700E+01, -.57876200E+01, 0.95116100E+00, -.15344600E+01, 0.51453500E+00, 0.84054900E+00, 0.34672000E+00, -.91399800E-01, -.81764600E+00, -.16667800E+01, -.85038500E+00, -.16348500E+00, 0.84178900E+03, -.61173700E+03, -.14910700E+04, 0.73842800E+03, -.28510200E+03, 0.74548600E+03, 0.11094900E+04, 0.34386500E+03, -.15078300E+04, -.27059500E+04, 0.24803300E+02, 0.27320700E+03, 0.32200900E+03, -.42766200E+04, 0.21020000E+04, 0.17609300E+03, 0.21383900E+04, 0.81543100E+03, 0.40615400E+04, -.28557200E+04, -.61930600E+04, -.11904200E+04, 0.39838500E+04, -.18950100E+03, 0.28628800E+04, -.14640200E+04, 0.75175800E+03, -.14314500E+04, -.14200800E+03, -.56828200E+04, 0.52473800E+04, 0.10543900E+05, 0.24648800E+04, -.57312400E+04, 0.21078300E+04, -.20971500E+05, 0.10660100E+05, 0.12223400E+04, 0.10485900E+05, 0.52296700E+04, 0.32048100E+04, 0.13005100E+04, -.80121700E+04, 0.15188200E+04, 0.22371100E+04, 0.25885600E+04, 0.26317900E+04, -.11840700E+04, -.85051000E+03, -.13158700E+04, -.46529000E+03, -.22297600E+02, -.14119100E+03, 0.59233300E+03, -.11797700E+03, 0.51755000E+03, -.14271900E+04, -.83792300E+03, 0.25675100E+03, -.22979900E+04, 0.41888800E+03, 0.86275000E+03, 0.95034900E+03, -.21219900E+03, -.42631900E+04, -.32672900E+04, 0.73998100E+03, -.15332400E+04, 0.35811700E+05, -.17768700E+05, -.20662900E+05, -.17905800E+05, -.34889200E+04, 0.51468800E+03, -.68260000E+04, 0.78973600E+04, -.39722700E+04, -.27034200E+03, -.96613700E+04, -.25049800E+05, 0.12519300E+05, 0.13289500E+05, 0.12524900E+05, 0.45940600E+03, 0.53956100E+03, 0.65161200E+04, -.45503300E+04, 0.18323900E+04, 0.19067600E+04, 0.95888000E+04, -.21852100E+03, 0.20115500E+03, -.96164800E+03, 0.10619700E+03, -.14761200E+04, -.21148600E+04, 0.64202000E+03, 0.13478200E+04, 0.24278800E+04, -.93638400E+03, -.13066400E+04, 0.18773400E+04, -.74025700E+03, 0.23379300E+04, -.93836200E+03, 0.89134800E+03, 0.21482400E+04, -.27638800E+04, -.14877300E+04, -.48077300E+03, 0.11596000E+04, -.63881100E+03, -.12814500E+05, 0.62245000E+04, 0.61093000E+04, 0.64072300E+04, 0.39471200E+04, -.25478600E+04, 0.39810500E+04, -.15657300E+04, 0.32532800E+04, -.23416000E+04, 0.26269800E+03, 0.37273700E+03, -.25166200E+03, -.43331100E+04, -.18628100E+03, -.13493200E+04, -.21804700E+04, 0.14604800E+04, 0.13207400E+04, 0.30302200E+04, -.90588900E+03, -.71149100E+03, -.49661700E+05, 0.24753800E+05, 0.27154200E+05, 0.24830900E+05, 0.29204800E+04, 0.36068800E+03, 0.11043300E+05, -.71468900E+04, 0.79098500E+04, 0.16639100E+04, 0.17603900E+05, -.35120800E+04, 0.13002300E+04, -.42739400E+04, 0.17562500E+04, 0.98000900E+03, -.69210500E+04, 0.50332600E+04, 0.53234000E+04, 0.62883500E+04, -.70790200E+04, 0.87713000E+04, 0.16515600E+05, -.81053400E+04, -.52271800E+04, -.82579000E+04, -.25733200E+04, 0.70851200E+02, -.22907200E+04, 0.37071600E+04, -.55216900E+04, 0.26113900E+03, -.64983600E+04, -.21886800E+05, 0.10934100E+05, 0.59298500E+04, 0.10943400E+05, 0.24644200E+04, 0.15319500E+04, 0.31330600E+04, -.64358000E+04, 0.14792100E+04, 0.13958200E+04, 0.80828200E+04, 0.14062600E+04, -.65122300E+03, 0.10433000E+02, -.70316000E+03, -.16440700E+04, 0.57924100E+04, -.44613000E+04, -.63258900E+04, -.35927700E+04, 0.55693200E+04, -.42009500E+04, 0.26105200E+03, 0.40682700E+02, 0.50378200E+04, -.13045600E+03, -.20847700E+03, -.41067100E+03, 0.24508700E+04, 0.30921500E+04, -.49717100E+03, 0.80448800E+02, -.12700700E+04, 0.27850800E+03, 0.23924800E+03, -.19094200E+03, 0.41633500E+03, 0.54030100E+03, 0.13914000E+03, -.25566400E+03, 0.67972800E+03, 0.25136000E+04, 0.32572200E+03, 0.15552600E+02, -.60460800E+03, -.53079400E+03, 0.31193100E+04, 0.24537900E+02, -.16075000E+03, 0.11495700E+04, 0.34418900E+03, -.20261700E+04, 0.10386300E+04, 0.13444800E+04, -.11936800E+04, 0.15940600E+04, -.10967300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13354200E+01, 0.45611500E+00, 0.22063800E+00, -.49356000E+00, -.70513000E+00, 0.49300700E+00, 0.80846500E-01, -.29851100E+00, 0.42503800E-01, 0.28217800E+00, -.11002100E+01, -.13416000E+01, 0.13893500E+00, -.82915100E+00, 0.28670900E+00, 0.10921300E-01, -.54722500E+00, -.27939800E+00, 0.13710400E+00, 0.10760800E+00, 0.39408100E+00, 0.10658900E+01, -.23207600E+01, 0.18513800E+01, 0.27703500E-01, -.37527700E+00, 0.27081400E+00, 0.32692800E+00, -.15406100E+00, -.14797400E+01, -.25826600E-01, 0.40592100E-01, 0.22647300E+00, 0.48650200E+00, 0.82688800E-01, 0.27593300E-01, -.35052100E-01, -.75354600E+00, -.49400800E+00, -.27239800E+00, -.65688400E+00, 0.56848000E+00, 0.30213200E+00, -.15810700E+00, 0.68822100E-01, 0.73758200E+00, 0.43136200E+00, -.45661800E-01, 0.14379500E+00, 0.50295100E+00, 0.69068900E+00, -.15615000E+00, 0.11538500E+00, -.13817100E+00, 0.42773400E+04, 0.29363500E+03, -.15023100E+03, 0.13818600E+03, -.14679800E+03, 0.62118900E+03, -.17087800E+03, -.24938700E+03, -.34376300E+03, -.39385600E+03, -.40332400E+03, -.17693800E+03, -.57198700E+03, 0.26454700E+03, -.77755700E+03, 0.28596400E+03, -.13639400E+04, 0.19956300E+03, -.23063500E+03, -.20216700E+03, -.85526900E+03, -.41324500E+03, 0.30649900E+04, -.17511400E+04, 0.91056400E+03, 0.13408800E+04, 0.87557600E+03, -.91684000E+03, -.30803400E+04, 0.22275500E+04, 0.12640700E+04, 0.31883700E+04, -.21516300E+04, -.22364400E+04, 0.67556000E+04, -.34340700E+04, -.24221000E+04, -.33778600E+04, -.27374700E+03, 0.35586600E+04, -.15365500E+04, 0.40340000E+04, 0.16921800E+04, 0.19981600E+04, 0.51122600E+03, -.15212500E+04, 0.73401500E+03, -.34761900E+02, 0.76014300E+03, -.20318800E+03, 0.22317800E+03, 0.39047600E+03, 0.16069700E+03, 0.27383900E+03, 0.33758600E+03, 0.30217000E+04, -.52266400E+04, 0.26041000E+04, 0.57124500E+04, 0.26133500E+04, -.20442100E+03, 0.39603300E+04, 0.16353700E+03, 0.18058500E+04, 0.20813400E+04, 0.37020900E+04, 0.10603900E+04, 0.19290800E+04, -.93654700E+03, -.58107100E+04, -.96454500E+03, -.85831100E+03, -.30654600E+04, -.94034600E+03, -.13835800E+04, -.20901300E+04, -.25574600E+04, -.18818000E+04, -.10620000E+05, 0.52794000E+04, 0.54074800E+04, 0.53100100E+04, 0.18763000E+04, 0.29863500E+04, 0.70664700E+03, -.24295000E+04, 0.32384500E+04, 0.29005200E+04, 0.37651700E+04, -.24493300E+04, 0.12142100E+04, -.19985000E+04, 0.12241400E+04, -.10389100E+04, -.16173800E+04, -.56946900E+03, -.26543800E+04, -.19492300E+03, -.16344000E+04, 0.55986700E+04, 0.34954900E+04, -.17636400E+04, -.15748500E+04, -.17478600E+04, -.78298100E+02, -.26902700E+04, 0.40156700E+03, -.16661800E+03, -.23077400E+04, -.27194700E+04, -.20147900E+04, 0.62146700E+04, -.31093300E+04, 0.17226500E+04, -.31073300E+04, -.10144700E+04, 0.30523800E+04, -.47868400E+03, 0.28454600E+04, -.13802100E+04, 0.23029400E+04, 0.17749300E+04, -.57402300E+04, 0.28673400E+04, 0.20778800E+04, 0.28700800E+04, 0.16448400E+03, 0.34978500E+04, -.19735600E+04, -.30971300E+04, -.90915600E+03, 0.32638400E+04, 0.49967300E+04, -.98158900E+04, 0.48686400E+04, 0.70016100E+04, 0.49079500E+04, 0.14597700E+04, 0.38226000E+04, 0.13589000E+04, -.13504800E+04, 0.36791400E+04, 0.33285400E+04, 0.48882100E+04, -.18547800E+05, 0.93665800E+04, 0.51062000E+04, 0.92738100E+04, -.66491500E+03, -.26541900E+04, 0.52143300E+04, -.51533400E+03, 0.52049100E+04, 0.43245900E+03, 0.22236900E+04, 0.53263500E+04, -.26638800E+04, -.17534200E+04, -.26631400E+04, -.22237900E+03, -.23676500E+04, -.10293100E+04, -.60268800E+03, -.13077800E+04, -.21863400E+04, -.40270500E+04, -.45841000E+04, 0.22771100E+04, 0.16100500E+04, 0.22920500E+04, 0.15819500E+04, 0.34749000E+04, -.26212800E+03, 0.71013600E+02, 0.31911800E+04, 0.32260500E+04, 0.24304100E+04, 0.12024800E+05, -.60391900E+04, -.28277300E+04, -.60123700E+04, 0.51604600E+03, 0.40222000E+04, -.41871900E+04, -.60368900E+02, -.57326000E+04, 0.20532800E+04, -.91882600E+03, 0.13718300E+04, -.70807600E+03, -.14977900E+04, -.68594200E+03, 0.14497200E+03, -.23806900E+04, 0.26900300E+03, 0.62915700E+03, 0.30479700E+03, -.27550600E+04, 0.10547700E+04, 0.45621300E+03, 0.29513800E+03, -.16715200E+03, 0.20161900E+03, -.15459200E+03, -.19187500E+02, -.30684000E+03, -.30600800E+03, -.15202400E+02, -.20912900E+03, -.23523900E+03, 0.42734300E+03, -.15407000E+04, 0.13116100E+03, 0.37348900E+03, -.14439200E+03, -.23004500E+04, -.62744900E+03, -.94858300E+03, -.70225100E+03, -.21469900E+04, 0.37941600E+03, 0.88050200E+02, 0.81644700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16801700E+01, -.23809200E+00, -.45052000E+00, 0.10339400E+01, 0.11981600E+01, -.11088500E+00, -.28345700E+00, -.10606900E+00, 0.44464000E+00, 0.21357200E+00, 0.80471800E+00, 0.18276600E+00, -.13242200E+00, 0.78750600E+00, -.72785100E-01, -.16353900E+00, 0.45291900E-01, -.50915400E+00, -.46422100E+00, 0.19285800E+00, 0.57323500E+00, 0.36998500E+00, 0.15377100E+01, -.27637300E+00, 0.13095700E+00, -.34556300E-01, 0.46360000E+00, 0.21483400E+00, -.13578500E+00, 0.54379200E+00, -.53852000E+00, 0.10081400E+00, 0.74940900E+00, 0.68739300E+00, -.62046200E-01, -.10220900E+00, 0.69257000E-02, -.26143600E+00, 0.34222800E-01, -.50587200E+00, -.27866000E+00, 0.83877400E+00, -.89133700E+00, -.19991600E+00, 0.40766100E+00, 0.77207600E+00, -.10848400E+00, -.35875500E-02, 0.15885400E+00, -.25465700E+00, 0.20317900E+00, -.67364600E+00, 0.99144000E-01, -.28728800E+00, 0.12400900E+00, -.26018500E+04, 0.12924900E+04, 0.69967700E+03, 0.13009400E+04, 0.10233200E+04, 0.57270300E+02, 0.47889700E+03, -.84808800E+03, 0.48384900E+03, 0.41239700E+01, -.61256800E+03, 0.40794900E+04, -.20855300E+04, -.60863300E+03, -.20397600E+04, -.16356300E+04, 0.37291700E+04, -.25155100E+04, -.17375000E+04, -.35197500E+04, 0.31929600E+04, 0.11215600E+04, 0.43837800E+04, -.21480300E+04, 0.12330900E+04, -.21918800E+04, -.12497800E+04, -.51282700E+04, 0.16381000E+04, 0.14320700E+04, 0.78839100E+03, -.44002600E+04, -.21268900E+04, -.11516900E+04, 0.50693600E+03, 0.97858700E+04, 0.57580600E+03, 0.12628400E+04, 0.39717000E+03, 0.13153900E+04, 0.40042900E+04, 0.19832000E+04, -.62768800E+03, -.20058700E+04, 0.15046800E+04, -.72723800E+03, -.46763600E+03, -.75040300E+03, -.36449400E+03, 0.44104300E+03, -.45749700E+03, 0.17406000E+03, -.34245300E+03, 0.47307700E+03, -.76956500E+03, 0.43129700E+04, -.23000700E+04, 0.94237500E+04, -.21564700E+04, 0.45981800E+02, 0.16775500E+04, 0.16012200E+04, 0.53802600E+04, -.13548900E+03, 0.72343800E+03, -.46652800E+04, 0.25284000E+05, -.12391000E+05, -.25070500E+05, -.12642000E+05, -.26093000E+04, -.89537000E+02, -.68872100E+04, -.45979900E+04, -.84796300E+04, 0.86360600E+03, -.69035900E+04, -.12223400E+05, 0.59442000E+04, 0.12627300E+05, 0.61117200E+04, 0.22788500E+04, -.68434500E+03, 0.39351600E+04, 0.48986800E+04, 0.45662200E+04, -.18796000E+03, 0.41524600E+04, 0.18211700E+04, -.84174300E+03, -.57604000E+04, -.91055800E+03, -.14395200E+04, 0.84504200E+03, -.24914100E+04, -.46579400E+04, -.32161800E+04, 0.21431400E+04, 0.40255300E+04, -.62187600E+04, 0.32082000E+04, -.46767100E+04, 0.31093000E+04, 0.34760300E+03, 0.85605400E+03, -.22350200E+04, -.75482400E+04, 0.14070300E+04, 0.35782500E+03, 0.51890300E+03, -.67179700E+04, 0.31499400E+04, 0.17524900E+05, 0.33589900E+04, 0.13889700E+04, -.55662300E+03, 0.23253300E+04, 0.41889300E+04, 0.27524700E+04, -.20638500E+04, -.14420000E+03, 0.66430400E+04, -.33614800E+04, 0.12082300E+04, -.33215400E+04, -.19799600E+04, -.84231800E+03, 0.78360400E+03, 0.13620300E+04, -.48259900E+04, 0.92103500E+03, -.73297100E+03, -.22277600E+05, 0.10891500E+05, 0.25195800E+05, 0.11138800E+05, 0.26306200E+04, -.83238400E+03, 0.62834400E+04, 0.48787200E+04, 0.75608100E+04, -.83316400E+03, 0.67138500E+04, -.17003600E+05, 0.84215100E+04, 0.72148100E+04, 0.85017500E+04, -.26515100E+04, -.10663200E+05, 0.10524900E+05, 0.83453900E+04, 0.10606600E+05, -.97357400E+04, -.71806700E+02, 0.78640900E+04, -.38018200E+04, -.10684500E+05, -.39320200E+04, -.12311100E+04, -.54066900E+03, -.15047600E+04, -.22099300E+04, -.29918000E+04, 0.49063500E+03, -.24981000E+04, -.68679100E+04, 0.33376100E+04, 0.59079300E+04, 0.34339600E+04, 0.20735500E+04, 0.14234400E+04, 0.11429500E+04, 0.25987700E+04, 0.36939100E+04, 0.10134600E+04, 0.14536600E+04, 0.93145900E+04, -.46677900E+04, -.56818800E+04, -.46572900E+04, 0.16601100E+04, 0.66351500E+04, -.65676100E+04, -.54307900E+04, -.70788000E+04, 0.57398900E+04, -.52938700E+03, -.49603800E+04, 0.25131000E+04, -.14249500E+02, 0.24801700E+04, 0.88821800E+03, -.41774500E+03, -.65701800E+03, -.47309900E+03, 0.70653300E+03, -.40648900E+03, 0.52474600E+04, -.10366800E+04, 0.15466900E+03, -.11704700E+03, 0.26039600E+03, -.86283700E+01, -.42561000E+02, -.22056400E+03, -.34717700E+03, 0.81215000E+03, 0.56644800E+03, -.18122800E+03, 0.13293600E+04, 0.12201800E+04, -.80325200E+03, -.37365200E+03, 0.45182800E+03, 0.34604400E+03, 0.13434600E+03, 0.11325100E+04, 0.46612400E+03, -.11738000E+04, -.75244700E+03, 0.13285700E+04, 0.18366800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34363700E+01, 0.14028100E+01, 0.52970400E+00, 0.24513700E-01, -.27976000E+01, 0.16979500E+01, 0.34028500E+00, -.27616900E+01, 0.89745800E+00, 0.12643000E+01, -.92406700E+00, -.10506700E+01, -.18138100E+00, -.36915600E+01, 0.31321300E+00, 0.37494800E+00, -.13124900E+01, 0.26128800E+00, 0.40071000E+00, -.52706100E+00, -.10129600E+01, 0.32892800E+01, -.85834000E+00, -.31796100E+00, -.11285400E+00, -.22276600E+00, -.16474800E+00, 0.11962700E+00, -.13035700E+00, -.14592500E+01, 0.22552000E+00, -.32548000E+00, 0.36461500E+00, -.30095600E+00, -.63897200E-01, -.77145900E+00, -.44527500E-01, -.12440500E-02, -.65944300E+00, -.12795700E+00, 0.97001900E+00, 0.92781200E+00, -.99160000E+00, -.17235700E+00, -.90028600E+00, 0.19013000E+01, 0.39625200E+00, -.26318400E+00, 0.19481100E+00, 0.22155900E+01, 0.18123300E+01, 0.77217800E+00, 0.36998700E+00, -.10097900E+01, 0.91057800E+00, -.37145900E+00, -.37761500E+02, 0.68281400E+03, 0.63872800E-01, 0.40251600E+03, -.14813500E+03, -.16587700E+04, -.22764700E+04, -.35622500E+03, -.24351900E+03, 0.54010200E+03, 0.26028800E+04, -.13747900E+04, -.27179600E+03, -.13015400E+04, 0.40713700E+03, 0.26752900E+04, -.31807600E+04, -.30804900E+04, -.59758100E+04, 0.18192100E+04, -.57584400E+03, 0.59234200E+04, -.28853600E+04, 0.13683000E+04, -.29616900E+04, -.33075100E+04, -.35165600E+04, 0.36159400E+04, 0.60471800E+04, 0.48076900E+04, -.26753200E+04, -.76985700E+04, 0.45318300E+04, -.23499800E+04, 0.90618900E+04, -.22661300E+04, 0.35094700E+03, 0.25757500E+04, -.47301400E+04, -.64164800E+03, -.58989600E+04, 0.10590200E+04, -.18418300E+04, -.42445500E+03, 0.16727400E+03, -.29453200E+03, 0.20637900E+03, 0.13728600E+02, 0.37035800E+03, 0.88492100E+03, 0.18115300E+04, 0.94688400E+03, 0.49602900E+03, -.42144600E+03, -.65155600E+04, 0.32863400E+04, 0.11838100E+05, 0.32578700E+04, 0.17432700E+04, 0.14303300E+04, -.11132900E+03, 0.47682700E+04, -.27928400E+04, 0.16440400E+04, -.10714500E+04, 0.94836900E+04, -.48065800E+04, -.17404900E+05, -.47418500E+04, -.18659300E+03, 0.89662800E+03, -.76877900E+03, 0.32100100E+04, 0.48861300E+04, 0.15375700E+04, -.10506000E+05, -.16611000E+05, 0.83359000E+04, 0.15251900E+05, 0.83055000E+04, 0.11216000E+04, -.11902100E+04, 0.21195400E+04, -.30449300E+04, 0.18973400E+02, -.15240200E+04, 0.11797000E+05, 0.30114800E+03, -.21713300E+03, -.35576100E+04, -.15013000E+03, -.18614900E+04, -.94707900E+03, -.15889600E+04, -.29623800E+04, 0.19462400E+04, -.23285400E+04, 0.50407400E+04, -.47934100E+04, 0.22941300E+04, -.29669500E+04, 0.23962900E+04, -.12233200E+04, 0.47901500E+03, 0.31093600E+04, -.82537100E+03, 0.34684000E+04, 0.80517800E+03, -.51979700E+03, 0.29177000E+05, -.14468700E+05, 0.14724000E+04, -.14588500E+05, -.49458800E+04, -.62890800E+04, -.62406100E+03, 0.90627200E+04, -.10632800E+05, -.55734300E+04, -.78917800E+04, -.52334500E+04, 0.26211700E+04, 0.68133200E+04, 0.26166100E+04, 0.75444100E+02, -.25212100E+03, -.93839900E+03, 0.20552900E+04, 0.26271900E+04, -.20511800E+04, 0.38964100E+04, -.18990400E+05, 0.95186900E+04, 0.26011900E+05, 0.94952100E+04, 0.14004400E+03, -.52396900E+03, 0.29399400E+04, -.34106000E+04, -.13355700E+04, -.12759500E+04, 0.17916500E+05, -.12379700E+05, 0.64144300E+04, 0.96455800E+04, 0.61895600E+04, -.34988200E+04, -.82873900E+04, 0.87946700E+04, 0.93069000E+04, 0.74427000E+04, -.30146600E+04, -.46343800E+03, -.12776200E+05, 0.63260200E+04, -.25071000E+04, 0.63882500E+04, 0.19519200E+04, 0.21443600E+04, 0.14197400E+04, -.24069100E+04, 0.67992700E+04, 0.17012900E+04, 0.16408000E+04, -.12673900E+05, 0.63607300E+04, 0.97228400E+04, 0.63369500E+04, 0.29011100E+04, 0.36277200E+04, -.17136700E+04, -.44916200E+04, -.97035400E+03, 0.29881000E+04, 0.59029500E+04, -.97725500E+04, 0.48395900E+04, -.16535300E+04, 0.48863200E+04, 0.30927700E+04, 0.32933300E+04, -.52734800E+01, -.28999000E+04, 0.35116500E+03, 0.47598100E+03, 0.10093200E+05, 0.49614400E+04, -.25035500E+04, -.90064800E+04, -.24808100E+04, -.40478100E+03, -.58424900E+03, -.11701400E+04, -.20835600E+04, -.22833900E+04, -.10358000E+04, 0.86648100E+03, -.29207200E+03, 0.19479500E+03, 0.11044100E+03, 0.33762000E+03, -.29554300E+03, -.96178300E+02, -.17649900E+03, -.12611700E+03, 0.73510200E+03, 0.58979900E+03, 0.13804400E+02, -.30076800E+02, 0.52564700E+03, 0.35021000E+04, 0.13801700E+03, -.30653500E+03, 0.98004400E+03, -.69591400E+03, -.16820700E+04, -.69788300E+03, -.22318900E+03, -.25535400E+04, 0.11724200E+03, 0.14682900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.82920800E+00, -.19012100E+00, 0.18435100E-02, 0.34101700E+00, 0.42095600E+00, -.16770200E+00, -.91114400E-01, -.54671000E+00, 0.24428300E+00, -.29036700E-01, 0.26324600E+00, 0.46075700E+00, -.46937700E+00, -.16168500E+00, -.11343500E+00, 0.11399300E-01, 0.11165700E+00, -.54647100E+00, -.39003100E-01, 0.12225600E+00, -.58836600E+00, -.67528600E+00, 0.13742900E+01, -.12322100E+01, -.78359600E-01, 0.18108800E+00, -.19760900E-01, -.23045100E+00, 0.23780300E-01, 0.38312500E+00, -.61033700E-01, 0.12608700E-01, 0.84289500E-01, -.11597300E+00, -.58037800E-01, -.79102800E-01, 0.14680700E-01, 0.11458700E+00, 0.56783500E-01, -.82770700E-01, 0.56485100E-01, -.38474000E-01, -.37113500E+00, 0.57296400E-01, 0.26113700E+00, -.70008500E+00, 0.65202600E-01, -.14137600E+00, -.12548500E-01, -.25301100E+00, 0.12405000E+00, -.32377400E+00, -.42735800E-01, -.33671600E-01, 0.30221600E+00, 0.13019400E+00, -.28395800E-02, -.51295100E+03, -.48115300E-03, -.48351500E+03, -.17647600E+03, 0.71064200E+02, -.14903700E+03, 0.75285700E+02, -.11965800E+03, 0.54335500E+03, 0.27008500E+04, -.13398900E+04, -.22112600E+03, -.13504200E+04, 0.78299500E+02, -.42971100E+03, -.45338000E+03, 0.92493900E+02, -.10293600E+04, -.20033000E+03, 0.10393200E+03, -.17641500E+04, 0.86094100E+03, 0.11877100E+04, 0.88207400E+03, 0.39909400E+03, 0.10750900E+03, 0.24836500E+03, -.52668600E+03, 0.31331300E+03, 0.61876600E+02, -.35103500E+03, 0.32630400E+04, -.15917400E+04, 0.15602100E+04, -.16315100E+04, -.10065700E+03, -.89395900E+03, -.98489000E+03, -.17167800E+04, -.27843400E+04, -.44695500E+03, -.20464600E+04, 0.10068700E+04, -.47447400E+03, 0.17094100E+03, -.50051200E+03, 0.12690300E+03, 0.26481700E+03, -.50042400E+03, -.15181800E+03, -.45232400E+03, 0.20097400E+03, -.48710100E+03, 0.61218900E+04, -.30739500E+04, -.13861800E+04, -.30609500E+04, -.90073700E+02, -.17667500E+04, -.15878400E+04, -.16901800E+04, -.32619900E+04, -.14265100E+04, -.21840600E+04, 0.31084700E+04, -.15434100E+04, -.17519300E+04, -.15542400E+04, 0.42494500E+03, 0.10425300E+04, -.24203200E+03, 0.15826200E+04, -.94015100E+03, 0.86268600E+03, -.17107900E+04, 0.85461500E+03, -.42188300E+03, 0.11565100E+04, -.42730800E+03, -.18680900E+03, -.59748500E+03, 0.36691100E+03, 0.55390600E+03, -.35713900E+03, -.53494900E+03, 0.34183100E+03, 0.20522600E+04, -.10106900E+04, -.30592200E+03, -.10263900E+04, -.17268800E+03, 0.12373900E+04, -.63063400E+03, 0.28085100E+03, -.88240800E+03, 0.12851100E+04, -.75172700E+03, -.52137700E+04, 0.26362100E+04, 0.20771700E+02, 0.26068900E+04, -.24199100E+02, 0.74100000E+03, 0.86449100E+03, 0.56757100E+03, 0.26708100E+04, 0.40613000E+03, 0.24608200E+04, 0.13641000E+03, -.94434500E+02, 0.13950800E+04, -.68204800E+02, 0.35442100E+02, -.12396600E+04, -.65547500E+03, -.22119700E+04, -.25813700E+03, -.90702500E+03, -.14529700E+04, 0.67626300E+04, -.33861700E+04, -.11568000E+04, -.33813100E+04, -.59216900E+03, 0.46506900E+02, -.16054000E+04, -.56783000E+03, -.32283300E+04, 0.39364600E+03, -.17696700E+04, -.17111800E+04, 0.85658100E+03, 0.31757600E+04, 0.85558900E+03, -.16449500E+03, -.10842300E+04, 0.55647500E+03, -.51652800E+03, 0.38099300E+03, -.92656600E+03, 0.78240900E+03, 0.76558300E+02, -.12658900E+03, 0.33959900E+04, -.38273600E+02, -.18182500E+03, -.12802400E+04, -.33335600E+03, -.86100900E+03, 0.25748500E+02, -.15490800E+04, -.22725800E+04, -.28150700E+04, 0.14268300E+04, -.15069700E+04, 0.14075300E+04, 0.53515800E+01, 0.86391700E+03, 0.74066400E+03, 0.81396700E+03, 0.10303500E+04, 0.69509100E+03, 0.22380800E+04, 0.19656800E+04, -.98102200E+03, 0.56474600E+03, -.98284100E+03, -.32943300E+03, -.74483600E+03, -.31834500E+03, -.68821400E+03, -.12210900E+04, -.60296500E+03, -.81915800E+03, 0.12868400E+04, -.62672700E+03, -.30582000E+04, -.64342000E+03, 0.27200200E+03, 0.44156500E+03, -.26674100E+03, 0.22826800E+03, -.15400700E+03, 0.60967700E+03, 0.65069100E+03, -.43188300E+04, 0.21841000E+04, 0.10669000E+04, 0.21594200E+04, 0.25086900E+03, 0.62506100E+03, 0.15836100E+04, 0.14032500E+04, 0.19927400E+04, 0.58042100E+03, 0.19494000E+04, -.75937500E+03, -.10694100E+03, 0.16659800E+03, -.44727500E+02, 0.30569400E+02, -.10951200E+02, 0.18569000E+03, -.55052000E+02, -.29278600E+03, 0.30882200E+03, 0.63441200E+03, -.51605400E+02, 0.49937000E+03, 0.10400900E+03, -.32865200E+03, 0.36955300E+03, 0.66042800E+03, 0.28331200E+03, 0.17917200E+03, -.60288500E+01, 0.13920500E+03, -.56250900E+03, -.21536500E+03, 0.12696900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.66805600E+01, -.16951300E+01, -.49376000E+00, 0.43395300E+01, 0.37317200E+01, -.64101600E+00, -.72119700E+00, -.71073500E+00, 0.30977800E+00, -.18191100E+00, 0.21461400E+01, 0.20655100E+01, -.26374800E+01, 0.17713300E+01, -.84619300E+00, -.34946900E+00, 0.12990300E+01, 0.14734600E+00, -.25546700E+00, -.76409400E+00, 0.11932300E+01, 0.37925900E+00, 0.91985000E+01, -.61081400E+01, -.12381500E+00, 0.16924200E+01, 0.86935700E+00, 0.19740200E+01, 0.25838800E+01, -.28338500E+01, 0.20062100E+00, 0.67285500E+00, -.11051200E+01, -.31656200E+00, -.88142200E-02, 0.35703500E+00, 0.27036900E+00, -.45421700E+00, -.23121900E+01, -.66440500E+00, -.24860000E+00, 0.15023500E+00, 0.57796200E+01, -.14500400E+01, 0.11445000E+01, 0.76388200E+00, 0.61156300E+00, 0.24958100E+00, 0.33106400E-01, 0.11355500E+01, 0.48065400E+00, 0.65133300E+00, 0.33451100E-01, -.11159100E+01, 0.68477800E+00, 0.11128900E-01, 0.10854600E+01, 0.33476300E+01, -.10844100E+02, 0.50422500E+03, 0.17096500E+03, 0.12936500E+04, 0.19621900E+04, -.70641600E+02, 0.37564900E+03, -.13703500E+04, -.22393800E+04, 0.11310500E+04, 0.17078600E+03, 0.11234800E+04, 0.40271100E+03, 0.12919100E+04, 0.11860200E+04, 0.21236500E+04, 0.32960600E+04, 0.15654800E+04, -.58813100E+03, -.17660800E+03, 0.13019100E+03, -.13759500E+04, 0.88513500E+02, 0.69406100E+03, 0.59209600E+03, -.21815200E+04, -.56830800E+04, -.57798800E+04, 0.25269100E+03, 0.30739600E+04, -.46213300E+04, 0.22201000E+04, -.49959700E+04, 0.23213600E+04, -.16961200E+04, -.48250500E+04, 0.62288900E+04, 0.66441600E+04, 0.73581600E+04, -.43610300E+04, 0.44438000E+04, -.19381700E+03, 0.34130200E+02, -.40841700E+03, 0.89952300E+02, -.34058400E+03, -.52917200E+03, -.10823200E+03, -.38955900E+03, 0.34219100E+03, -.54666200E+03, 0.61725400E+02, -.49292000E+03, 0.30147700E+03, -.35462400E+04, 0.24151300E+03, -.12732300E+04, 0.73433900E+02, 0.40128600E+04, 0.27276300E+04, 0.27975400E+04, -.47983900E+02, 0.21106000E+04, -.15707100E+05, 0.78394500E+04, 0.97332900E+04, 0.78543800E+04, 0.91336100E+03, 0.40668300E+04, -.16154900E+04, -.10738900E+05, -.23140000E+04, 0.41643400E+04, 0.92178300E+04, 0.75322200E+04, -.37907800E+04, -.81471700E+04, -.37667300E+04, -.13724900E+04, -.24915700E+04, -.47579700E+03, 0.25255500E+04, 0.18055800E+04, -.31240800E+04, -.22985400E+04, -.15616500E+04, 0.75631300E+03, 0.97135400E+03, 0.78906000E+03, 0.33466200E+04, 0.22833900E+04, -.85514500E+03, -.15183100E+04, -.14217100E+04, 0.20479000E+04, -.95825800E+03, 0.60072600E+04, -.30740700E+04, -.25067300E+03, -.29821900E+04, -.30798200E+03, -.22779100E+04, -.20095100E+04, -.47876400E+03, -.12925000E+04, -.10658100E+04, -.38680200E+04, 0.45158800E+04, -.22294500E+04, -.84877900E+04, -.22565500E+04, -.10828600E+04, -.23461700E+04, 0.19948400E+04, 0.94746600E+04, 0.67128100E+04, -.28113700E+04, -.48324900E+04, -.73599100E+04, 0.37023700E+04, 0.46285600E+03, 0.36856600E+04, 0.37258000E+04, 0.18980500E+04, 0.28801400E+04, -.12070000E+02, -.17030200E+02, 0.14500900E+04, 0.11186800E+04, 0.13541100E+05, -.67719500E+04, -.13785000E+05, -.67711100E+04, -.90674900E+03, -.37909200E+04, -.51225800E+03, 0.56872100E+04, 0.18034900E+04, -.44636300E+04, -.65840500E+04, 0.17496600E+05, -.85215500E+04, -.17143600E+05, -.87338900E+04, -.10224400E+04, 0.30564700E+04, -.30859300E+04, 0.21280100E+04, -.82625400E+04, 0.20726500E+04, -.73386800E+04, -.22712800E+04, 0.11054600E+04, 0.72174900E+04, 0.11273200E+04, 0.20564500E+04, 0.16386400E+04, -.10682700E+04, -.56349600E+04, -.58499800E+04, 0.23313200E+04, 0.23333100E+04, 0.82166300E+04, -.41158800E+04, -.72852500E+04, -.41080600E+04, -.33348800E+04, -.42526300E+04, 0.20168700E+04, 0.58557600E+04, 0.24231900E+04, -.41961500E+04, 0.27879300E+03, -.44412700E+04, 0.21676400E+04, 0.74964100E+04, 0.22178900E+04, -.15731900E+04, -.28813800E+04, 0.12156800E+04, 0.83178000E+03, 0.58206500E+04, -.21020900E+04, 0.97569800E+03, 0.25170300E+04, -.13429500E+04, 0.43943900E+04, -.12546800E+04, -.66351400E+02, -.53777500E+03, -.21858800E+04, -.20913800E+03, 0.72569300E+03, -.99252500E+03, -.24464600E+04, 0.74177100E+03, -.14313000E+03, -.39308800E+03, -.34366900E+03, 0.22527000E+03, -.25793800E+03, 0.68484000E+02, 0.25440700E+03, 0.74201500E+03, -.48202900E+03, -.67452600E+03, 0.24096500E+03, 0.28809700E+04, -.27548700E+04, 0.88705800E+03, -.25836200E+03, 0.63060600E+03, -.24385400E+03, 0.36602900E+04, 0.92430800E+03, 0.87058500E+03, 0.23778800E+04, 0.14438800E+04, -.14519500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13737600E+01, -.35331200E+00, -.81214600E-02, -.43571500E+00, 0.10521100E+01, -.42324000E+00, -.24164100E+00, -.19476600E+00, 0.34621300E+00, -.23294100E+00, -.34029900E+00, 0.66620400E-01, 0.94913800E+00, 0.76468900E+00, 0.30739400E+00, -.49770300E-01, 0.70512900E+00, 0.61049000E+00, -.47839700E+00, 0.15798800E+00, -.66066500E+00, -.26733200E+00, -.63560800E+00, -.27188500E-01, -.19937700E-02, 0.14134700E+00, -.12878200E+00, -.28457400E-01, -.41488100E-01, 0.11266800E+01, -.23947100E-01, -.54287800E-01, -.19121000E+00, -.48865600E+00, -.76779900E-02, -.75294700E-02, 0.29583400E-01, -.19298100E+00, 0.18088700E+00, 0.93159100E-01, 0.18548300E+00, 0.39612100E+00, 0.32318400E+00, 0.33351700E+00, -.72631100E+00, -.44505300E+00, -.45934900E+00, 0.21652500E+00, -.32212700E+00, -.25877200E+00, -.27938200E+00, 0.41682100E+00, -.62128200E-01, 0.14937100E+00, -.40099900E+00, -.57405000E+00, 0.62725600E-01, 0.95073700E+00, 0.13815500E-02, 0.79634100E+03, 0.10714300E+03, -.70813000E+02, -.53252300E+02, -.86488300E+02, 0.14813200E+03, -.13833400E+04, -.23560000E+04, 0.11610500E+04, -.21093400E+03, 0.11780200E+04, -.21755500E+03, 0.18902500E+04, 0.11056300E+03, -.63183500E+03, 0.68435300E+03, 0.17253500E+04, -.13652600E+04, 0.36313600E+04, -.17884800E+04, -.13162200E+04, -.18156800E+04, -.85013000E+03, -.46899900E+03, -.68645400E+03, -.44716800E+02, -.17115000E+04, -.53729900E+03, 0.12153600E+04, -.99993300E+04, 0.49486200E+04, -.28800300E+03, 0.49996900E+04, 0.50673300E+03, -.36915100E+03, 0.32121700E+04, 0.25485900E+04, 0.54817800E+04, -.59109400E+03, 0.58815700E+04, -.69261300E+03, 0.32983700E+03, -.11890700E+03, 0.34134800E+03, -.28479100E+03, -.33205100E+03, 0.51477100E+03, 0.31997600E+03, 0.48852700E+03, -.30503900E+03, 0.49568200E+03, -.61777000E+04, 0.30561000E+04, 0.22640000E+04, 0.30888300E+04, -.19633900E+03, 0.16519200E+04, 0.33238900E+04, 0.34454700E+04, 0.37074200E+04, 0.95436800E+03, 0.22013300E+04, -.19514700E+04, 0.10508400E+04, -.16760000E+04, 0.97573600E+03, -.94870600E+03, -.22297400E+03, -.13401900E+04, -.48086200E+04, -.65290000E+03, 0.21624100E+03, 0.16994300E+04, -.34191400E+01, -.60138300E+02, -.28941300E+03, 0.17073200E+01, 0.19648900E+03, -.51724200E+03, 0.80431300E+03, 0.25040900E+04, 0.13171000E+04, -.61116400E+03, -.32176700E+03, -.19324800E+04, 0.98054400E+03, -.45503300E+03, 0.96764300E+03, 0.45782200E+03, -.49650900E+03, -.15391800E+02, -.14982300E+04, -.35020300E+03, -.18286000E+03, -.24320100E+03, 0.55350700E+04, -.27581700E+04, -.41584900E+03, -.27674800E+04, 0.15581100E+03, -.21722000E+03, -.24653300E+04, -.27612700E+04, -.25213800E+04, 0.34303200E+03, -.29071000E+04, -.26464400E+04, 0.12682000E+04, 0.14583800E+04, 0.13232100E+04, 0.54179100E+03, 0.72220200E+03, 0.15723400E+04, 0.41252600E+04, 0.19227700E+04, -.14195100E+03, 0.28609900E+04, -.70521400E+04, 0.35194900E+04, 0.76481200E+03, 0.35260900E+04, 0.52205400E+03, -.66553600E+03, 0.34377700E+04, 0.18753700E+04, 0.20297200E+04, -.66524800E+03, 0.64607700E+03, 0.17910100E+04, -.97748400E+03, -.68076100E+03, -.89550600E+03, 0.46162300E+03, -.56483900E+02, 0.97417600E+03, 0.42246000E+04, 0.11043600E+04, -.33626000E+03, -.11390400E+04, 0.30873300E+04, -.15052600E+04, -.60953200E+04, -.15436300E+04, -.24096800E+03, 0.51484300E+03, 0.74509100E+03, 0.33032100E+04, -.24030000E+03, -.38381500E+03, 0.24364300E+04, 0.42606600E+04, -.20992400E+04, 0.95238600E+03, -.21303400E+04, -.23979000E+03, -.86582300E+03, -.91875300E+03, -.18452000E+04, -.24963000E+04, -.11939900E+03, -.32146500E+04, -.21459300E+04, 0.10378100E+04, -.15027000E+04, 0.10729700E+04, 0.25418100E+03, -.38669700E+02, 0.94068600E+03, 0.25742300E+04, 0.25198000E+04, -.39429200E+03, 0.20841200E+04, -.28350500E+04, 0.14042900E+04, 0.45686600E+04, 0.14175200E+04, -.10545000E+03, -.67464100E+03, 0.63522700E+03, -.61009600E+02, 0.99933500E+03, -.37238000E+03, -.13117700E+04, 0.47541000E+04, -.23888700E+04, 0.48638900E+03, -.23770400E+04, -.78919700E+01, -.22627500E+03, -.26101900E+04, -.19186900E+04, -.20911100E+04, 0.21239100E+02, -.16788600E+04, 0.66879100E+03, 0.13332100E+03, -.26835300E+03, 0.97181900E+02, 0.47058800E+02, -.18902200E+02, -.19993500E+03, 0.27625000E+02, 0.64615200E+03, -.31037900E+03, -.83188000E+03, 0.37277300E+03, 0.52799000E+03, -.98749900E+03, 0.14571300E+03, -.28376200E+03, 0.41884600E+02, 0.60762400E+02, 0.10108100E+04, 0.45227600E+03, 0.34085600E+03, 0.10024400E+04, 0.73577000E+03, 0.10566700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29107600E+01, -.22003500E+00, -.30413000E+00, 0.10478000E+01, 0.10868600E+01, 0.34340400E-02, -.27362700E+00, 0.16149700E-01, -.57028100E-01, 0.23932900E-01, 0.44812200E+00, -.23373500E+00, -.33155800E+01, -.60081700E+00, 0.54037400E+00, 0.29233000E-01, -.42823700E+00, -.40417900E+00, -.81718600E-02, -.52016500E+00, 0.91998100E+00, -.92808600E+00, -.71069200E+00, 0.10443100E+00, 0.11506400E+00, -.80503400E-01, 0.80100400E-01, -.38116000E+00, -.56273700E+00, 0.31731500E+00, -.26621900E+00, -.48527000E-01, 0.46714400E+00, 0.80358700E+00, 0.71577400E-01, 0.27658400E+00, 0.59322900E-01, -.69116700E+00, 0.21347600E+00, -.85440400E-02, 0.35569000E+00, 0.12234100E-01, -.77546900E+00, 0.32949900E-01, 0.65618100E+00, -.69445200E+00, 0.74648400E+00, -.93076600E-02, -.17897000E+00, -.11548900E+01, -.12591600E+01, -.52428700E+00, -.20463400E+00, 0.42387200E+00, 0.25742600E+00, -.43278200E+00, -.29946000E+00, -.18314100E+01, -.38008000E-02, 0.33820600E+00, 0.96052000E+03, -.10887300E+03, -.69864700E+03, -.38792300E+03, 0.70776200E+03, 0.87011900E+03, 0.99980800E+04, -.50002500E+04, -.10788400E+04, -.49991000E+04, -.15041000E+04, 0.14265400E+04, -.36930000E+04, -.76485700E+03, -.53673200E+04, 0.16685100E+04, 0.36481600E+04, -.53640200E+04, 0.26392700E+04, 0.30257600E+04, 0.26820200E+04, 0.22577100E+02, -.46464300E+04, 0.23568100E+04, -.16372600E+04, 0.35050400E+04, -.42672400E+04, -.20659900E+04, 0.10475400E+05, -.51866400E+04, 0.10184900E+05, -.52377900E+04, 0.94402600E+03, -.20487400E+03, -.31783400E+04, -.11266900E+04, -.45641000E+04, -.61849800E+02, -.98355700E+04, 0.27382000E+04, -.12648500E+04, -.65298300E+02, -.13589400E+04, -.35158200E+02, 0.80369600E+03, -.16472000E+04, -.95720200E+03, -.13584400E+04, 0.78801000E+03, -.13157500E+04, 0.22051900E+05, -.11188400E+05, 0.18207100E+04, -.11025900E+05, 0.19966200E+03, -.59208800E+02, -.81610600E+04, -.36836900E+04, -.95742900E+04, -.23182400E+03, -.10336900E+05, 0.44459000E+05, -.21980800E+05, -.33735400E+05, -.22229500E+05, -.12589000E+04, 0.11046100E+04, -.69807200E+04, 0.46715700E+04, -.15818600E+05, 0.73520600E+03, -.15163200E+05, -.12832300E+05, 0.62825600E+04, 0.14227000E+05, 0.64161300E+04, 0.18931600E+04, -.20547700E+01, 0.22950900E+04, 0.22332400E+04, 0.50041400E+04, 0.22973700E+03, 0.72932300E+04, 0.60269900E+04, -.29103900E+04, -.57365200E+04, -.30149900E+04, -.22506800E+04, 0.30955300E+04, -.28733200E+04, -.24926100E+04, -.50784900E+04, 0.46120200E+04, 0.14402900E+04, -.18826700E+05, 0.95871200E+04, -.21554500E+04, 0.94131900E+04, 0.26884000E+03, -.42147400E+03, 0.37506200E+04, -.17297900E+04, 0.91147500E+04, -.16942300E+04, 0.78371500E+04, -.17527300E+05, 0.85179500E+04, 0.22949200E+05, 0.87636800E+04, 0.14788300E+04, -.16100700E+04, 0.84069900E+03, -.60787400E+04, 0.66041200E+04, -.11090300E+04, -.22464100E+04, 0.25881400E+05, -.12988500E+05, -.41797000E+04, -.12940700E+05, -.35052500E+04, 0.24365000E+04, -.84796800E+04, -.46462000E+04, -.15349700E+05, 0.46372900E+04, -.48629100E+04, -.41901000E+05, 0.20734300E+05, 0.35754300E+05, 0.20950500E+05, 0.28346700E+04, -.80275700E+03, 0.61800600E+04, -.40933900E+04, 0.13936200E+05, -.38916300E+03, 0.14802200E+05, -.23134300E+05, 0.11225200E+05, 0.14516400E+05, 0.11567000E+05, -.45433900E+04, -.13644500E+05, 0.92836600E+04, 0.19027500E+04, 0.12039700E+05, -.13400700E+05, -.49987100E+04, 0.94362700E+04, -.45659100E+04, -.13883900E+05, -.47180800E+04, -.14908100E+04, 0.30593000E+03, -.54847700E+03, 0.24096100E+04, -.35691700E+04, 0.28850800E+03, 0.15612800E+04, -.11695400E+02, -.77213000E+02, 0.55174000E+04, 0.58443400E+01, 0.35447800E+03, -.10607400E+04, 0.37179700E+02, 0.25402100E+03, 0.11545200E+04, -.89168100E+03, -.16149800E+04, 0.18625100E+05, -.92566800E+04, -.12699600E+05, -.93125500E+04, 0.31738500E+04, 0.82742800E+04, -.79825900E+04, -.36765600E+04, -.97238800E+04, 0.83657900E+04, -.41106300E+03, -.18576700E+05, 0.93881900E+04, 0.39529300E+04, 0.92883200E+04, 0.15396200E+04, -.15002300E+03, 0.66182900E+04, 0.55169400E+04, 0.75013000E+04, -.24928200E+02, 0.10661500E+05, -.28840000E+04, -.24043300E+03, 0.30639700E+03, -.87944400E+02, 0.16211700E+03, -.18163000E+03, 0.20265800E+03, -.43861300E+03, -.32756300E+03, 0.12014700E+04, 0.89306400E+03, 0.11512100E+04, 0.13259400E+04, -.22403700E+03, -.12756700E+04, 0.15565800E+04, 0.41420700E+03, 0.93269100E+03, 0.60472200E+03, 0.38185700E+03, -.18791800E+04, -.15362500E+04, 0.85556000E+03, 0.19427500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14704200E+01, 0.46416700E+00, -.72414400E+00, -.34792300E+00, -.77953800E+00, -.24418500E-01, 0.15075300E+00, 0.43325700E+00, -.30376100E+00, -.36479300E-01, -.97413100E+00, -.47370800E+00, 0.32226400E+01, 0.15603000E+01, 0.69197200E-01, 0.76406500E-01, 0.15917300E+00, 0.15450800E+00, 0.15692800E+00, -.26704700E+00, 0.33413000E+00, 0.12462700E+00, -.95223200E+00, 0.12205700E+01, 0.13463900E+00, -.67292900E-02, -.31452400E+00, -.41903400E+00, -.30421800E+00, -.45055200E+00, -.98049600E-02, -.94694000E-01, 0.80802900E-01, 0.22391000E+00, 0.65681600E-01, 0.44934800E+00, -.72088700E-02, 0.83551500E+00, 0.14248800E+00, 0.19929300E-01, 0.21554200E+00, 0.42937800E-01, 0.18483700E+00, -.17258400E+00, -.45862800E+00, 0.11935400E+01, -.12030300E+00, 0.32364300E+00, 0.28712000E+00, 0.81630500E+00, 0.13191200E+01, 0.66735500E+00, 0.16709300E+00, -.61582700E-01, -.14482900E+00, 0.42892900E+00, -.85718500E-01, 0.10712000E+01, -.63230200E-04, 0.59999300E+00, -.28837500E-01, -.64772300E+03, -.77852800E+02, 0.11464200E+03, -.19210900E+03, 0.18252600E+03, -.95561300E+04, 0.47736600E+04, 0.76309500E+03, 0.47780500E+04, 0.15681600E+04, -.19290300E+04, 0.24569200E+04, 0.44130100E+02, 0.43199600E+04, -.23216200E+04, 0.92649000E+03, 0.19378100E+04, -.93498900E+03, -.46461500E+04, -.96890100E+03, 0.11189800E+04, 0.42676600E+04, -.14335800E+04, 0.28242800E+04, 0.17823700E+03, 0.37939000E+04, 0.15602100E+03, -.38161100E+04, 0.18360700E+04, -.11420300E+05, 0.19080200E+04, -.33246200E+03, 0.43024900E+04, -.81808900E+03, 0.86820300E+02, 0.29672200E+04, 0.36894000E+04, 0.33167100E+04, -.37013700E+04, 0.17343700E+04, 0.12378300E+04, 0.18453200E+04, 0.45385100E+03, -.28199000E+03, 0.14351900E+04, 0.28787300E+03, 0.11080700E+04, -.13902900E+03, 0.13736300E+04, -.17494300E+05, 0.89263900E+04, -.35357600E+04, 0.87471800E+04, 0.15450900E+04, 0.53965700E+04, -.42844700E+03, -.17830700E+04, 0.60573500E+04, 0.55829700E+04, 0.66454500E+04, -.30499700E+05, 0.14954400E+05, 0.20611600E+05, 0.15249900E+05, 0.12304100E+04, -.33432500E+04, 0.75124100E+04, 0.13001500E+04, 0.12097600E+05, -.37952300E+04, 0.11565000E+05, 0.58113800E+04, -.27493200E+04, -.10966700E+05, -.29056900E+04, -.13989900E+04, 0.26629300E+04, -.47778700E+04, -.72657000E+04, -.37835400E+04, 0.23122600E+04, -.30081100E+04, -.48362400E+04, 0.22869300E+04, 0.30876800E+04, 0.24166300E+04, 0.10326300E+04, -.43899300E+04, 0.33840700E+04, 0.35155000E+04, 0.51899400E+04, -.55531000E+04, 0.14223100E+04, 0.16074600E+05, -.82378000E+04, 0.42150600E+04, -.80373400E+04, -.11316200E+04, -.39952900E+04, 0.14124200E+04, 0.52552400E+04, -.67213700E+04, -.31445000E+04, -.64901700E+04, 0.97660900E+04, -.45621700E+04, -.16518300E+05, -.48830400E+04, -.17287800E+04, 0.36354900E+04, -.63810200E+03, 0.24365700E+04, -.40653400E+04, 0.46058400E+04, 0.18467600E+03, -.21107400E+05, 0.10604300E+05, 0.14167800E+04, 0.10553700E+05, 0.40156800E+04, 0.30973300E+04, 0.26825400E+02, -.12985200E+04, 0.11371600E+05, 0.81849000E+03, 0.70451900E+04, 0.21901100E+05, -.10703800E+05, -.23752400E+05, -.10950600E+05, -.14411800E+04, 0.48343900E+04, -.76388400E+04, -.43882000E+04, -.91824400E+04, 0.45051400E+04, -.70097000E+04, 0.53245900E+04, -.22748000E+04, -.12765400E+05, -.26623400E+04, 0.47148600E+04, 0.11110500E+05, -.58182900E+04, -.37424700E+04, -.49679800E+04, 0.12223000E+05, 0.29103700E+04, 0.21621900E+04, -.12879200E+04, 0.12196500E+05, -.10810800E+04, 0.69195500E+03, -.21680200E+04, -.11187200E+04, 0.10570300E+03, 0.35441200E+03, -.29825000E+04, -.38460300E+04, -.13860100E+04, 0.78854700E+03, -.54788800E+04, 0.69300600E+03, -.32519800E+03, 0.18716400E+04, -.63797100E+03, -.19847800E+04, -.53407800E+03, 0.20025300E+04, 0.14815100E+02, -.82256700E+04, 0.40614500E+04, 0.11745700E+05, 0.41128400E+04, -.36685400E+04, -.57248800E+04, 0.48899400E+04, 0.21050700E+04, 0.37708700E+04, -.57721700E+04, 0.12562600E+04, 0.14456700E+05, -.73355600E+04, -.30715300E+04, -.72283500E+04, -.21595500E+04, -.30792400E+04, -.91153800E+03, -.15840300E+04, -.51444900E+04, -.32591100E+04, -.71330400E+04, 0.25003400E+04, 0.21721200E+03, -.30491700E+03, 0.76064300E+02, 0.22794500E+02, 0.28370300E+03, -.18185000E+03, 0.51398600E+03, -.24235300E+03, -.93364500E+03, -.42710800E+03, -.81635400E+03, -.34301800E+04, 0.14778100E+04, 0.13371400E+04, -.12035800E+04, -.30290600E+04, -.99326600E+03, -.28224100E+04, -.10380200E+04, -.26651400E+03, 0.13099400E+04, -.13911300E+04, -.10634900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.66514800E+01, 0.23554100E+00, -.14036500E+01, 0.35963300E+01, 0.60410500E+01, 0.18153500E+01, -.14622600E+01, 0.14003800E+01, -.50401700E+00, -.18531200E+00, 0.27522400E+01, 0.28597500E+01, 0.62676100E+01, 0.45527100E+01, 0.86158100E+00, -.95008300E+00, 0.12594000E+01, 0.16739300E+01, 0.70317700E+00, 0.78264400E-01, 0.43435600E+00, 0.18567600E+01, 0.17891300E+01, 0.21013800E+01, -.49526400E-01, 0.11608300E+00, 0.57292300E+00, 0.80158000E+00, 0.71408200E+00, -.69906200E+01, 0.10591600E+01, 0.91958400E+00, -.53734400E+00, -.60189800E+00, -.75178000E+00, 0.10270700E+01, -.22213600E-01, 0.45005100E+00, 0.34567900E+00, -.45206600E-01, 0.53145600E+00, -.32770500E+00, 0.87416900E+00, -.71400300E+00, -.50116300E+00, -.19556500E+00, -.79037900E-01, -.53604900E+00, 0.51197100E+00, -.42900300E+00, 0.10632400E+01, -.23598400E+00, 0.51113000E+00, 0.12527800E+00, 0.11499000E+01, 0.14652500E+01, 0.54774200E+00, 0.29082500E+01, 0.47509000E-02, -.12876100E+01, 0.58566100E-01, -.19823000E+01, 0.29564400E+04, 0.49394200E+03, -.29070500E+03, -.70691300E+03, -.42504800E+05, 0.21303200E+05, 0.40924300E+04, 0.21252500E+05, 0.62598300E+04, -.85426200E+04, 0.13233500E+05, 0.29600600E+04, 0.24316300E+05, -.10370400E+05, 0.66293600E+04, 0.73982000E+04, -.35892100E+04, -.21135800E+05, -.36991100E+04, 0.67720700E+04, 0.24969400E+05, -.11721800E+05, 0.36340000E+04, -.96014300E+04, 0.22578600E+05, -.10249400E+04, -.11362600E+05, 0.53983900E+04, -.59375900E+05, 0.56813600E+04, -.45790200E+04, 0.11383200E+05, 0.27594900E+04, 0.89720600E+04, 0.19929300E+05, 0.10943900E+05, 0.17771400E+05, -.14548600E+05, 0.67972900E+04, 0.38355000E+04, 0.72536000E+04, 0.12756500E+04, -.27549800E+04, 0.55807600E+04, 0.11459500E+03, 0.47390100E+04, -.22045600E+04, 0.57849300E+04, -.73633800E+05, 0.37580800E+05, -.21714900E+05, 0.36816800E+05, 0.40596800E+04, 0.22501400E+05, 0.25353800E+04, -.82563600E+04, 0.32944600E+05, 0.22759800E+05, 0.31261300E+05, -.18440900E+06, 0.91049600E+05, 0.12363200E+06, 0.92204800E+05, 0.89289600E+04, -.14654200E+05, 0.37344800E+05, -.15066000E+05, 0.56531700E+05, -.15534000E+05, 0.73001800E+05, 0.57689700E+05, -.28258100E+05, -.68507800E+05, -.28844900E+05, -.81499900E+04, 0.87240500E+04, -.22574600E+05, -.18276800E+05, -.17041500E+05, 0.67787500E+04, -.28185200E+05, -.19572800E+05, 0.93011000E+04, 0.17126900E+05, 0.97864500E+04, 0.93617500E+04, -.12723500E+05, 0.12129800E+05, 0.13598500E+05, 0.17717600E+05, -.18581800E+05, 0.76380900E+04, 0.73645800E+05, -.37642300E+05, 0.16507600E+05, -.36822700E+05, -.56684700E+04, -.22232200E+05, 0.45442800E+04, 0.20775500E+05, -.31291200E+05, -.16467400E+05, -.31660400E+05, 0.55295500E+05, -.26449300E+05, -.87323900E+05, -.27647800E+05, -.85247900E+04, 0.20896400E+05, -.73803500E+04, 0.15780000E+05, -.17718300E+05, 0.22946100E+05, -.40790900E+04, -.92907900E+05, 0.46688100E+05, 0.60027700E+04, 0.46454000E+05, 0.22997100E+05, 0.19944900E+05, 0.99801800E+03, -.75687600E+04, 0.46641300E+05, 0.92203000E+04, 0.32360700E+05, 0.16256600E+06, -.80309600E+05, -.14800600E+06, -.81282800E+05, -.10044900E+05, 0.19122100E+05, -.40590400E+05, 0.31881400E+04, -.47972900E+05, 0.16857100E+05, -.61399800E+05, 0.48264900E+05, -.22578900E+05, -.63078400E+05, -.24132300E+05, 0.23315700E+05, 0.65420600E+05, -.38070600E+05, -.24762100E+05, -.37499500E+05, 0.65440400E+05, -.86089900E+04, -.98379200E+04, 0.41308900E+04, 0.65210500E+05, 0.49189100E+04, 0.52062600E+04, -.10666200E+05, -.17289900E+04, -.60411100E+04, 0.29709900E+04, -.12904800E+05, -.62538300E+04, 0.17345100E+05, -.83150300E+04, -.36298800E+05, -.86725700E+04, -.47829700E+04, 0.49712300E+04, -.29816400E+04, 0.19001700E+04, -.17313100E+04, 0.58094400E+04, -.84898700E+04, -.33215700E+05, 0.16416300E+05, 0.52352000E+05, 0.16607800E+05, -.17828100E+05, -.35622700E+05, 0.25463400E+05, 0.16704800E+05, 0.23531700E+05, -.33898600E+05, 0.93043700E+04, 0.65529000E+05, -.33241600E+05, -.82816900E+04, -.32764500E+05, -.96675300E+04, -.14614300E+05, -.59241100E+04, -.42423400E+04, -.21536700E+05, -.15301000E+05, -.32590600E+05, 0.10955900E+05, 0.82175500E+03, -.16605800E+04, -.47282000E+02, 0.25030500E+03, 0.99640600E+03, -.75932100E+03, 0.23497800E+04, -.16567200E+04, -.47106400E+04, -.26744200E+04, -.27638300E+04, -.13641700E+05, -.56695500E+02, 0.72149300E+04, -.49210300E+04, -.14413500E+05, -.48603200E+04, -.72234100E+04, -.46639000E+04, -.20339400E+04, 0.88269100E+04, -.75573200E+04, -.53660200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.23306800E+01, 0.41553600E+00, 0.10590800E+01, -.19475200E+01, -.18522100E+01, -.20289300E+00, 0.33387400E+00, -.13494700E+01, 0.10515100E+00, -.26689400E-01, -.51192100E+00, -.66492400E+00, -.17248000E+01, -.14846200E+01, 0.11553700E+00, 0.30142700E+00, -.15494700E+00, -.73145900E+00, 0.15745700E+00, -.85610200E+00, -.96993800E-01, -.15358700E+01, -.18275400E+01, -.19798400E-02, 0.12761900E+00, -.72999100E-01, -.42170800E+00, -.90862500E+00, -.54791500E+00, 0.17967700E+01, -.14693500E+00, -.20317300E+00, 0.10923300E+01, 0.71214900E+00, 0.26657700E+00, -.14037500E+00, -.10371100E-02, 0.25246500E+00, 0.50866600E+00, -.16085200E+00, 0.41199700E-01, -.11314800E+00, -.12035100E+01, 0.19023700E-01, -.96214900E-01, 0.12225700E+01, -.67708100E+00, 0.13498800E+00, 0.47777700E+00, 0.15121100E+01, 0.19802500E+01, 0.24701800E+00, -.11529500E+00, 0.42766500E+00, -.20472200E+00, -.10562400E+00, -.25712100E+00, 0.18828800E+01, -.79848300E-03, 0.11065200E+01, 0.75564500E+00, 0.17132500E+01, -.72545100E-02, 0.32195200E+03, 0.13082600E+03, -.94593700E+03, 0.35378900E+04, -.18016500E+04, 0.54039900E+03, -.17689100E+04, -.11456100E+04, 0.13134100E+04, -.24107500E+02, 0.12054200E+04, -.14759200E+03, 0.14677100E+04, -.27241400E+04, 0.76915800E+04, -.38215700E+04, 0.84930700E+03, -.38458000E+04, -.12611600E+04, -.22938800E+04, -.14099100E+04, -.15685700E+04, -.42845900E+04, -.19727700E+04, 0.63226100E+03, -.34338100E+04, 0.17246800E+04, 0.81305200E+04, 0.17169700E+04, 0.56875800E+03, -.46042300E+04, 0.34521300E+04, 0.89993700E+03, 0.62980400E+03, -.38287600E+04, 0.12192100E+04, 0.59769600E+03, -.25665300E+03, -.66385200E+03, -.29668200E+03, -.21489900E+03, -.12373800E+03, -.55571200E+02, -.24616700E+03, -.53798200E+03, -.24515800E+03, 0.20675800E+03, 0.56933400E+04, -.29714600E+04, 0.33678400E+04, -.28467000E+04, -.13579000E+04, -.49790600E+04, 0.46642900E+04, 0.52654300E+04, 0.78927100E+03, -.58641300E+04, -.12178700E+04, 0.23232100E+05, -.11423200E+05, -.71440400E+04, -.11616100E+05, -.16781100E+04, 0.26171200E+04, -.76229200E+04, -.39669200E+04, -.10626100E+05, 0.27254000E+04, -.86985500E+04, -.62175900E+04, 0.30053200E+04, 0.74249000E+04, 0.31087900E+04, 0.22163100E+02, -.31028400E+04, 0.61909500E+04, 0.76115800E+04, 0.41921100E+04, -.21079300E+04, 0.14646200E+04, 0.13054900E+04, -.58460700E+03, -.57905700E+02, -.65432700E+03, -.29976400E+03, 0.19086300E+04, -.11285300E+04, -.19280200E+04, -.32668800E+04, 0.35283000E+04, -.42295700E+04, -.70283800E+04, 0.36303000E+04, -.33033900E+04, 0.35143200E+04, 0.18810600E+04, 0.65672200E+04, -.54770300E+04, -.80061600E+04, 0.40650300E+03, 0.55474500E+04, 0.31903000E+04, -.14022400E+05, 0.68238700E+04, 0.91902200E+04, 0.70112100E+04, 0.29744800E+04, -.19938400E+04, 0.24405700E+04, -.21256100E+04, 0.37075000E+04, -.33084700E+04, 0.55511300E+04, 0.12062000E+05, -.60715700E+04, -.10392500E+04, -.60309600E+04, -.35476100E+04, -.66638100E+04, 0.46712300E+04, 0.50432400E+04, -.46384000E+04, -.41120600E+04, -.71535700E+04, -.15215300E+05, 0.74395800E+04, 0.11985400E+05, 0.76076500E+04, 0.44742400E+03, -.49831100E+04, 0.83689000E+04, 0.69267700E+04, 0.78217400E+04, -.37189100E+04, 0.29117400E+04, 0.64965600E+04, -.34069800E+04, 0.58671200E+04, -.32481900E+04, -.17911000E+04, -.51751600E+04, 0.19560000E+04, 0.48810000E+04, -.15014900E+02, -.81382600E+04, 0.39537800E+04, 0.60054800E+03, -.17247600E+03, -.96816800E+04, -.30031200E+03, -.11047900E+04, 0.17706900E+04, -.11420500E+03, 0.14461900E+03, 0.30850400E+02, 0.25494900E+04, -.33986600E+02, -.11100700E+03, -.35110300E+01, 0.42586500E+04, 0.55506000E+02, 0.21031100E+03, -.19533800E+04, 0.19122000E+04, 0.30639100E+04, 0.11823900E+04, -.19709500E+04, 0.85527500E+03, -.11050300E+04, 0.55068000E+03, -.59310700E+04, 0.55250600E+03, 0.25228000E+04, 0.29360800E+04, -.22766600E+04, -.33867100E+04, -.47039500E+03, 0.35210100E+04, -.52436300E+04, -.67844500E+04, 0.34486100E+04, 0.13732400E+04, 0.33922600E+04, 0.11014800E+04, 0.32468300E+04, -.21169700E+04, -.23032500E+04, 0.11833600E+04, 0.41414100E+04, 0.31035000E+04, -.11354400E+04, -.15491700E+03, 0.24366700E+03, -.37652600E+02, -.17016000E+03, -.14144700E+03, 0.12682200E+03, -.43564300E+03, 0.51150800E+03, 0.22815900E+03, -.23008500E+03, 0.65155000E+03, 0.34499500E+04, -.27789400E+04, -.13342300E+04, 0.44431400E+03, 0.34341600E+04, 0.99838100E+03, 0.38050700E+04, 0.10377400E+04, 0.19545000E+04, -.22300300E+03, 0.12906300E+04, 0.34493300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.85106700E+00, -.72541700E-01, -.17685800E+00, -.68372700E-01, 0.36267000E+00, 0.41922800E+00, -.70032700E-01, 0.27230300E-01, 0.11194100E+00, -.62259700E-01, 0.23735300E-01, 0.43104000E+00, -.10529600E+01, -.30254400E+00, 0.29050300E+00, -.16237700E-02, 0.43010200E-01, 0.56508600E+00, 0.16317800E-01, -.29973500E+00, -.20050300E+00, 0.70096000E-01, -.10919800E+01, -.14897400E+00, 0.26632500E-02, -.12511200E+00, 0.88093800E-01, 0.93926600E-01, 0.44531800E-01, 0.32091900E+00, 0.15818700E+00, 0.29578800E-01, 0.50764200E-02, -.22621700E+00, 0.71723400E-02, -.10253900E+00, -.10754900E-01, 0.18888100E+00, 0.26727900E+00, 0.49503500E-01, 0.24340300E+00, -.39169200E+00, -.75641800E+00, 0.40918100E-01, -.39566600E+00, 0.37926600E+00, -.20907100E+00, -.11857000E+00, -.88292700E-01, 0.10152500E+00, 0.20818200E+00, 0.28933200E+00, 0.62641600E-01, 0.11703200E-01, -.93663700E-01, -.11098400E-01, 0.30090500E-01, 0.19458700E+00, -.11365000E-02, -.18253100E+00, 0.27712800E-01, 0.31952300E+00, -.51333800E-01, -.16833600E+00, 0.12305000E+03, -.48943500E+03, -.90305300E+03, 0.44707800E+03, 0.30470500E+03, 0.45153000E+03, -.15338900E+02, 0.47407800E+03, 0.81153900E+03, 0.33560200E+03, 0.10652200E+04, 0.47588300E+03, -.52032600E+03, 0.49598400E+04, -.24710900E+04, -.80323800E+03, -.24799200E+04, 0.36015600E+02, 0.68139000E+03, -.17973100E+04, -.71966800E+03, -.29996700E+04, 0.56666600E+03, -.69665600E+03, -.28592400E+04, 0.14226000E+04, -.45184600E+03, 0.14296200E+04, -.12961100E+03, -.15256200E+04, 0.17801800E+04, 0.70799000E+03, 0.16171000E+04, -.11406300E+04, 0.18175200E+04, -.31182700E+03, 0.16051700E+03, -.14728900E+03, 0.15429800E+03, -.53200100E+02, -.23510300E+03, 0.21895400E+03, 0.45293500E+02, 0.16589600E+03, -.28159200E+03, 0.32579000E+03, -.77368300E+03, 0.35729300E+03, -.37453700E+02, 0.38683900E+03, -.40137200E+03, -.10317400E+04, 0.23968900E+04, 0.13480000E+04, 0.15057200E+04, -.13011100E+04, 0.75163500E+03, -.38507100E+04, 0.19785600E+04, 0.35106800E+04, 0.19253500E+04, 0.33703400E+03, 0.11705600E+04, -.12922100E+04, -.37233300E+04, 0.49453000E+02, 0.99433000E+03, 0.25771900E+04, 0.30119100E+04, -.15403200E+04, -.12263300E+04, -.15059600E+04, -.74419200E+03, -.15947100E+04, 0.15365300E+04, 0.32823000E+04, 0.24236900E+03, -.13590000E+04, -.22217600E+04, -.85260500E+02, 0.62236200E+02, 0.64776900E+03, 0.44074100E+02, 0.92220400E+03, 0.82703200E+03, -.19231700E+03, -.29414900E+03, -.61895100E+03, 0.10460700E+04, -.11049000E+04, 0.71420400E+03, -.33089100E+03, -.29967400E+03, -.35709200E+03, 0.29082800E+03, 0.11396200E+04, -.20768500E+04, -.20904500E+04, -.10248400E+04, 0.11988500E+04, -.88526400E+03, 0.37464400E+02, -.74281200E+02, -.96914000E+03, -.18733200E+02, -.30250700E+02, -.55954600E+03, 0.56390100E+03, 0.75523300E+03, -.27030000E+03, -.74408700E+03, 0.30723900E+03, -.26028300E+03, 0.12242100E+03, -.19781700E+03, 0.13014400E+03, 0.44997800E+03, -.13619900E+04, 0.25738500E+04, 0.16781900E+04, 0.33432300E+03, -.88627900E+03, -.69248700E+03, 0.75024500E+04, -.37987700E+04, -.37003500E+04, -.37512300E+04, -.84427800E+03, -.19269300E+04, 0.12329400E+04, 0.47011300E+04, -.93017200E+03, -.14870900E+04, -.47507300E+04, 0.78373300E+04, -.39440700E+04, -.24359200E+04, -.39186600E+04, 0.43142600E+02, 0.13564600E+04, -.17813400E+04, 0.10307100E+04, -.30276100E+04, 0.29311400E+03, -.99075800E+03, -.25041100E+04, 0.12877100E+04, 0.26276800E+03, 0.12520500E+04, 0.53541600E+03, 0.54606300E+03, 0.15995200E+03, -.63846500E+03, 0.65831700E+03, 0.69726600E+03, 0.76608100E+03, 0.14662000E+04, -.75353700E+03, -.11142800E+04, -.73310200E+03, -.40895300E+03, -.73624700E+03, 0.43354300E+03, 0.15778000E+04, 0.37189600E+03, -.74988700E+03, -.33115400E+03, -.48165200E+04, 0.24049100E+04, 0.10579100E+04, 0.24082600E+04, 0.20755900E+03, -.12640800E+04, 0.13580000E+04, -.22350600E+03, 0.22715500E+04, -.89308300E+03, 0.15377100E+03, 0.62930100E+03, -.30846400E+03, 0.87716300E+03, -.31464800E+03, -.52110800E+02, 0.69506100E+03, -.13811600E+04, -.78095800E+03, -.38828100E+03, 0.82563900E+03, -.21014000E+03, 0.55339000E+02, -.42830100E+01, -.38753800E+02, -.19209500E+02, 0.35629000E+02, -.14314100E+02, 0.29716300E+02, 0.25613400E+02, 0.11795300E+03, -.88585200E+02, -.26683600E+03, 0.98233400E+02, 0.10366800E+04, -.12651100E+04, 0.44279200E+02, -.38818000E+02, 0.77452000E+03, 0.99216500E+02, 0.15030400E+04, 0.33110400E+03, 0.68636400E+03, 0.41468000E+03, 0.23477500E+03, -.13939700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21284800E+01, 0.10949700E+00, 0.23048200E+00, -.74652600E+00, -.45620000E+00, 0.30319100E+00, 0.72249300E-01, 0.16065500E+00, -.13170700E+00, -.98236800E-01, -.25098900E+00, -.43759500E+00, -.35077300E+00, -.14184300E+01, 0.56351000E-01, 0.10610600E+00, -.76067600E+00, -.32592200E+00, 0.19021100E+00, 0.36690100E+00, 0.11060300E+00, -.93982800E-01, -.38833000E+00, 0.26728400E+00, -.17523900E-01, -.37133700E-01, 0.99151700E-02, -.19323700E+00, -.22835100E+00, 0.17074800E+00, -.22704100E+00, -.82791700E-01, 0.72626700E+00, 0.49861600E+00, 0.50310700E-01, -.32535400E+00, 0.45927000E-01, -.43968400E+00, -.48038600E-01, -.11122000E+00, -.79249600E+00, 0.50472100E-01, 0.11060600E+01, -.43204900E-01, 0.77890800E+00, -.72840100E+00, 0.44503900E+00, 0.41739700E+00, 0.17488600E+00, -.41938700E+00, -.72917500E+00, -.61058300E+00, -.12410100E+00, -.31989500E-01, 0.34467400E-01, -.15861100E+00, -.40456100E-01, -.36276400E+00, 0.22386500E-02, 0.26576600E+00, 0.46430900E+00, 0.12520700E+00, 0.77176800E-01, 0.53850300E+00, 0.49213000E+00, 0.92271700E+03, 0.43607300E+04, -.21688100E+04, -.16209200E+04, -.21803400E+04, -.14781900E+03, 0.15456000E+04, -.23824400E+04, -.13890500E+04, -.41166200E+04, 0.18218500E+04, -.57115200E+03, -.61188600E+04, 0.30268100E+04, 0.23915800E+04, 0.30594300E+04, -.39056800E+03, -.28291100E+04, 0.35150700E+04, 0.89752200E+03, 0.38669100E+04, -.26092800E+04, -.53739400E+03, -.65144800E+04, 0.33506600E+04, 0.52236500E+04, 0.32572900E+04, 0.12426200E+04, 0.29445200E+02, -.67644400E+03, -.48684200E+04, -.27397000E+04, -.18245700E+03, 0.27366200E+04, 0.24758900E+04, -.11878100E+04, -.48183800E+03, -.12374500E+04, -.23518800E+03, 0.17670600E+03, -.79388700E+03, 0.26123800E+03, -.47745200E+03, 0.13060800E+03, -.12167400E+04, 0.42016600E+04, -.21065200E+04, 0.10984900E+03, -.21008500E+04, 0.22287600E+03, -.14191800E+04, -.12969600E+04, -.12208100E+04, -.55215900E+04, -.93541700E+03, -.16362800E+04, 0.92760500E+04, -.46647700E+04, -.94792400E+04, -.46380200E+04, -.28966300E+02, 0.17662900E+04, -.46666800E+03, 0.61138900E+04, 0.99558600E+03, 0.24302000E+04, -.74061800E+04, -.59324200E+04, 0.30160700E+04, 0.62372600E+04, 0.29662000E+04, 0.10465600E+04, 0.74218500E+02, 0.59295500E+03, -.28748400E+04, -.11585100E+04, -.86211700E+02, 0.48095500E+04, 0.24431700E+04, -.12052200E+04, -.14774800E+04, -.12236300E+04, -.10455900E+04, 0.16283600E+04, -.16831400E+04, -.89560200E+03, -.51198800E+03, 0.10457600E+04, -.30338800E+03, -.50607900E+04, 0.25698200E+04, 0.27705400E+03, 0.25304900E+04, -.21858200E+03, 0.19136900E+03, 0.19895300E+04, 0.23652200E+04, 0.42958200E+04, 0.27322500E+03, 0.26835800E+04, 0.44110900E+04, -.22149000E+04, 0.28120500E+04, -.22055500E+04, -.18902700E+03, -.34743200E+04, -.74933000E+03, -.13584800E+04, -.14767300E+04, -.38108300E+04, -.10446200E+04, 0.42172900E+04, -.21159200E+04, -.29889600E+03, -.21086200E+04, -.15882400E+04, 0.11917400E+04, -.27296500E+04, -.15224200E+04, -.28891800E+04, 0.51063400E+03, -.68018800E+03, -.14047300E+05, 0.70737700E+04, 0.12316700E+05, 0.70236400E+04, 0.64883900E+03, -.12371200E+04, 0.18442500E+04, -.57547700E+04, 0.52528200E+03, -.19075000E+04, 0.98797500E+04, 0.56272200E+03, -.43155100E+03, 0.26379500E+04, -.28129300E+03, -.15963800E+04, -.50659500E+04, 0.21805500E+04, 0.27413900E+04, 0.23875700E+04, -.47885300E+04, -.18832200E+04, -.13162500E+04, 0.67722800E+03, -.19436800E+04, 0.65809800E+03, -.39010900E+03, 0.13200100E+04, 0.85048400E+03, 0.10351700E+04, 0.20837700E+03, 0.18111800E+04, 0.15433500E+03, -.66155000E+04, 0.33353500E+04, 0.41127800E+04, 0.33077500E+04, 0.10363600E+04, 0.27154400E+03, 0.92456600E+02, -.37542800E+04, -.78955400E+03, -.37261400E+02, 0.38934500E+04, -.30370800E+03, 0.17702700E+03, -.17491500E+04, 0.15184600E+03, 0.82680200E+03, 0.26189400E+04, -.13192600E+04, -.88030300E+03, -.57778100E+03, 0.23145100E+04, 0.28066500E+04, -.36544600E+04, 0.18770600E+04, 0.60564400E+03, 0.18272600E+04, 0.67908100E+03, 0.51691600E+03, 0.13307900E+04, 0.91059600E+03, 0.13101500E+04, 0.75555000E+03, 0.71379200E+03, -.78425300E+03, -.17549200E+02, 0.30316700E+01, 0.84913100E+02, 0.10432500E+03, -.86423100E+02, -.45707200E+02, -.13317200E+03, 0.23375800E+03, 0.54079600E+03, 0.35262300E+03, -.17504100E+03, 0.72978500E+03, 0.24621700E+04, -.24146500E+03, 0.39658400E+03, 0.18178300E+04, 0.25441400E+03, -.12283800E+04, 0.44866000E+03, 0.77583400E+03, -.14131000E+04, 0.53297300E+03, 0.22657800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17409100E+01, -.17511600E+00, -.13916600E+01, 0.19922000E+01, 0.11958000E+01, 0.26715400E+00, -.13846800E+00, 0.10866100E+01, -.13707500E+00, 0.23736900E-01, 0.16095300E+00, -.17440200E+00, 0.99010500E+00, 0.12381900E+01, 0.23521300E+00, -.25341800E+00, 0.29874900E+00, -.10016600E+01, -.15834700E+00, 0.17373800E+01, -.45721200E+00, -.75236000E+00, -.25534400E+01, 0.17832100E+01, 0.50725100E-01, 0.17308800E+00, -.34691700E-01, -.50419000E+00, -.52194600E+00, -.35187700E+01, -.22351300E+00, 0.42384300E+00, -.98513700E+00, 0.74724100E+00, -.12242900E+00, 0.15888700E+01, 0.60114600E-01, -.26258700E-01, -.24963200E+00, 0.24538900E+00, -.31913300E-01, 0.65193700E+00, -.28730800E+00, -.37697200E-01, -.38084900E+00, 0.95465600E+00, -.85192000E+00, 0.82227700E+00, 0.82672100E+00, 0.76016800E+00, -.19487000E+01, -.13171900E+01, -.24732800E+00, 0.23291200E-02, -.23860600E+00, -.10430900E+00, -.18321800E+00, 0.90889800E+00, 0.31520600E-02, -.37223700E-01, -.40359100E+00, 0.72300600E+00, -.17544500E+00, 0.81339000E+00, -.65306900E+00, 0.64347900E+00, -.81612100E+04, 0.40918300E+04, 0.17550700E+04, 0.40806000E+04, 0.83795700E+03, -.23061000E+04, 0.27481800E+04, -.54229700E+02, 0.54360200E+04, -.26583600E+04, 0.22379200E+04, 0.75047100E+04, -.37462900E+04, -.30057300E+04, -.37523600E+04, 0.10148900E+04, 0.47224500E+04, -.36806400E+04, 0.55935600E+03, -.49989500E+04, 0.43433400E+04, -.19653100E+04, 0.51464300E+04, -.26014800E+04, -.96171200E+04, -.25732300E+04, -.23627500E+03, 0.16718000E+04, -.45435100E+02, 0.24342700E+04, 0.13233000E+04, 0.18375000E+04, -.22492000E+04, -.24162800E+04, 0.11836300E+04, 0.70959800E+03, 0.12052300E+04, 0.24910400E+03, -.46387200E+03, 0.80111300E+03, -.20741600E+03, 0.69997700E+03, -.35966400E+03, 0.10130700E+04, -.53854600E+04, 0.27122600E+04, -.38227200E+04, 0.26927300E+04, 0.45181700E+03, 0.22309400E+04, -.15379500E+03, -.23610600E+04, 0.41291900E+04, 0.19779700E+04, 0.26349700E+04, -.20202900E+05, 0.10098200E+05, 0.17678700E+05, 0.10101500E+05, 0.17720800E+04, -.25560000E+04, 0.35105600E+04, -.37223400E+04, 0.54731000E+04, -.34150200E+04, 0.98984700E+04, 0.15759300E+05, -.78935400E+04, -.13212400E+05, -.78796300E+04, -.23695500E+04, 0.30664000E+03, -.23948400E+04, 0.26824100E+04, -.34233900E+04, 0.34563500E+03, -.70113700E+04, -.35558300E+04, 0.17802200E+04, 0.26242100E+04, 0.17801500E+04, 0.12423100E+04, -.23767000E+04, 0.22378900E+04, 0.21348700E+04, 0.26536800E+04, -.22727300E+04, 0.45006300E+03, 0.81240700E+04, -.40859800E+04, 0.15598600E+04, -.40620600E+04, -.33682800E+03, -.19720800E+04, -.28750000E+03, 0.11712100E+04, -.39811400E+04, -.17020200E+04, -.34679000E+04, -.33964900E+03, 0.16778700E+03, -.86050700E+04, 0.16982500E+03, -.96683600E+03, 0.42417400E+04, 0.19540500E+02, -.65052700E+02, -.10731200E+04, 0.50018200E+04, -.53626600E+02, -.78486500E+04, 0.39357700E+04, -.97604400E+03, 0.39243200E+04, 0.30611500E+04, 0.87633200E+03, 0.63079900E+03, -.11016500E+04, 0.46235600E+04, 0.61509000E+03, 0.28289300E+04, 0.27659100E+05, -.13831800E+05, -.23655500E+05, -.13829500E+05, -.23416100E+04, 0.22698800E+04, -.45269400E+04, 0.55508100E+04, -.71670900E+04, 0.28972800E+04, -.12822800E+05, -.18844400E+04, 0.10041400E+04, -.51606200E+04, 0.94220600E+03, 0.26562000E+04, 0.80232300E+04, -.41295500E+04, -.70680000E+04, -.41709700E+04, 0.80976800E+04, 0.25870700E+04, -.69882600E+03, 0.34360200E+03, 0.64266500E+04, 0.34941900E+03, 0.88144200E+03, -.18420800E+04, -.62916800E+03, -.39569500E+03, 0.89597400E+03, -.25849700E+04, 0.24990600E+03, 0.69630000E+04, -.34902600E+04, -.66772300E+04, -.34815000E+04, -.62830300E+03, 0.98925600E+03, -.90688000E+03, 0.17783100E+04, -.16268800E+04, 0.11541700E+04, -.34246900E+04, -.40950200E+03, 0.19772300E+03, 0.33340100E+04, 0.20475300E+03, -.13053800E+04, -.41965600E+04, 0.28241200E+04, 0.35522000E+04, 0.26492900E+04, -.41030100E+04, -.15974500E+04, 0.73611900E+04, -.37102600E+04, 0.52205600E+03, -.36806000E+04, -.19485300E+04, -.19295400E+04, -.97284200E+02, 0.11340900E+04, -.14785400E+04, -.20275400E+04, -.33395400E+04, 0.13202200E+04, 0.24009500E+02, -.36743900E+02, -.94748400E+02, 0.87607300E+02, 0.16009300E+03, 0.15414200E+02, 0.51745800E+03, -.18863500E+03, -.59669000E+03, -.45361300E+03, -.47858400E+03, -.21074300E+04, -.12744100E+04, 0.70263200E+03, -.64925400E+03, -.26602400E+04, -.53564400E+03, -.23831600E+03, -.79002700E+03, -.90392600E+03, 0.96368100E+03, -.91629300E+03, -.98150700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10702800E+01, 0.12190200E+00, 0.60040600E+00, -.78433300E+00, -.39086200E+00, 0.45325600E+00, 0.22672900E-01, -.64122300E+00, 0.77382700E-02, 0.22920000E+00, 0.13645300E+00, 0.81777800E-02, -.20055100E+00, -.94443200E-02, -.90724100E-01, 0.32207700E-01, 0.14336200E+00, -.28170000E+00, 0.16663800E+00, -.24760100E+00, 0.34392400E+00, 0.35785100E+00, -.26451900E-02, 0.34411900E-01, -.34265300E-01, -.25774500E+00, -.26197700E+00, 0.34452700E-01, 0.12771200E+00, -.16118100E+01, 0.17390100E+00, 0.38475500E-01, -.44572200E+00, -.11392500E+00, 0.67715300E-01, 0.98795800E-01, -.17858700E-01, 0.44945100E+00, -.20126100E+00, -.11079600E+00, -.39145800E+00, -.57420700E+00, 0.58506700E-01, -.85719600E-01, 0.64789700E+00, -.65167200E+00, 0.23746200E+00, -.22876900E+00, -.22420100E-01, -.35642700E+00, 0.62918600E+00, 0.44007400E+00, 0.67583700E-02, -.13610900E+00, -.29991900E+00, 0.66348500E-01, 0.22510400E-01, -.89826500E+00, 0.15629700E-02, -.30389100E+00, -.14967900E+00, -.57510100E+00, 0.63924100E-01, 0.23885700E+00, -.52649500E+00, 0.40236200E-02, 0.41242100E+00, 0.20123500E+02, -.49845800E+03, 0.16259000E-02, 0.32221000E+03, -.18194100E+02, -.22049000E+03, -.67897300E+03, -.39731900E+03, 0.33608500E+03, -.13312500E+04, -.34715200E+04, 0.17030300E+04, 0.53691200E+03, 0.17357600E+04, 0.32506500E+03, -.36948300E+03, 0.62793700E+03, -.21272700E+03, 0.14167400E+04, -.49256900E+03, 0.27509800E+04, -.67369300E+04, 0.34237800E+04, 0.20678500E+03, 0.33684700E+04, 0.72951900E+03, 0.47069800E+02, 0.75599800E+03, -.28152600E+04, 0.78502500E+03, -.20130900E+03, 0.29280600E+04, 0.16980300E+04, -.83461600E+03, -.21468600E+03, -.84531700E+03, -.58941700E+02, 0.13456400E+03, -.62038000E+03, 0.10406900E+02, -.47595300E+03, 0.83934000E+02, -.53119100E+03, 0.11600200E+04, -.52289400E+03, -.25731800E+04, -.58001000E+03, 0.57928600E+03, -.81821600E+03, -.35137600E+03, -.19465800E+04, -.17162700E+04, -.58727200E+03, -.89422300E+03, 0.20912600E+04, -.11757500E+04, -.20531000E+04, -.10456300E+04, -.78639400E+03, 0.58070700E+03, 0.41418800E+03, 0.41985500E+04, 0.15012800E+04, 0.95197400E+03, -.52934400E+03, -.44846500E+04, 0.23380500E+04, 0.19497000E+04, 0.22423200E+04, 0.12294300E+04, 0.15387400E+04, 0.65532500E+02, -.30741600E+04, 0.74949300E+02, 0.11091800E+04, 0.15881000E+03, 0.85359600E+03, -.46281700E+03, -.21899100E+03, -.42877000E+03, -.45289100E+03, -.47336400E+03, 0.17059200E+03, 0.12005400E+04, 0.75325100E+03, -.44126700E+03, -.19222700E+04, 0.20098300E+03, -.13031800E+03, 0.19614700E+04, -.10048100E+03, -.25980000E+01, 0.81579300E+03, -.75792100E+02, 0.16661700E+04, -.55768000E+02, 0.71488500E+03, 0.81648500E+03, -.18236100E+04, 0.10241900E+04, -.67498300E+03, 0.91180400E+03, 0.12103400E+04, -.13710800E+04, -.34439100E+02, -.21669100E+04, 0.28261700E+03, -.14705100E+04, 0.18240600E+04, -.68282100E+03, 0.35304900E+03, -.10915000E+04, 0.34141400E+03, -.27768600E+03, -.92383300E+03, -.16667900E+01, 0.67077400E+02, 0.16501000E+04, -.76916200E+03, -.98368200E+03, -.76570400E+04, 0.39603500E+04, 0.33065300E+04, 0.38285200E+04, 0.14033000E+04, 0.64703700E+03, 0.29484100E+03, -.48803900E+04, 0.42155300E+03, -.51428600E+02, 0.20295000E+04, 0.32453400E+04, -.16335800E+04, -.47437200E+04, -.16226600E+04, -.92654400E+03, -.21245500E+04, -.81357900E+03, -.82139400E+02, 0.26139200E+03, -.20577200E+04, 0.30755300E+04, 0.23338500E+04, -.12328500E+04, 0.11812600E+04, -.11669300E+04, -.75557400E+03, 0.63554900E+03, 0.24666000E+02, 0.15914700E+04, -.10459300E+04, 0.88697800E+03, -.15626600E+04, -.42612100E+04, 0.21849000E+04, 0.62622600E+03, 0.21306000E+04, 0.11563600E+03, -.58235000E+03, 0.10621900E+04, -.17271200E+04, 0.71601600E+03, -.79016100E+03, 0.13067300E+04, -.48035600E+04, 0.24132700E+04, 0.30975500E+04, 0.24017800E+04, -.11079600E+03, 0.21184800E+03, 0.14656800E+04, 0.35881400E+03, 0.13528100E+04, 0.41326000E+03, 0.23161000E+03, -.12058700E+04, 0.60979500E+03, 0.19047500E+04, 0.60293600E+03, 0.12208600E+03, 0.90953800E+03, 0.75941900E+03, 0.20785800E+03, -.11364200E+03, 0.77295400E+03, -.83787000E+02, -.44196000E+02, -.30935000E+02, 0.41774100E+02, -.21130100E+02, 0.11778800E+03, -.14942900E+01, 0.31613800E+02, 0.11661100E+03, 0.11477600E+03, -.41545700E+02, 0.41232200E+03, -.31737000E+03, 0.10041300E+03, 0.12646900E+04, -.28216200E+03, 0.10130400E+03, 0.11302700E+04, 0.36170100E+03, -.94006400E+03, 0.48031700E+03, 0.11502800E+04, 0.46684700E+01, 0.47147100E+03, -.38828800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36521700E+01, -.84835900E-01, -.10948700E+00, 0.93988900E+00, 0.12135200E+01, 0.13728600E+00, -.33482600E+00, 0.86122300E+00, -.22329100E+00, -.57188300E+00, -.18304100E+00, -.76636900E-01, -.11530900E+01, -.14491800E+01, 0.47565000E-01, -.29865800E+00, -.86628400E-01, 0.29489900E+00, 0.13480400E+00, 0.68122500E+00, 0.39895000E+00, -.13785800E+01, -.23310700E+01, 0.99130500E+00, -.28520500E+00, 0.33160700E-01, -.90222200E-01, -.69397800E+00, -.10929600E+01, -.23569600E+01, -.33718100E+00, 0.32070900E+00, -.70184600E+00, 0.33128100E+00, -.20194500E+00, 0.10213100E+01, 0.18336500E-01, 0.11074700E+01, -.80587000E+00, 0.47615300E+00, 0.88349000E+00, 0.14711900E+01, 0.30090200E+01, 0.36300800E+00, -.36145100E+00, -.57055500E+00, 0.94417600E+00, 0.81235400E+00, 0.97598300E+00, 0.13082100E+01, -.13092200E+01, -.11077600E+01, -.23037200E+00, -.35546200E+00, 0.48043000E+00, 0.51267200E+00, 0.32332100E+00, -.82205100E+00, -.76368500E-03, -.70522500E+00, -.71989100E+00, -.14262100E+00, -.22238500E+00, 0.64172600E-01, -.79758800E+00, -.14801700E+00, 0.10561500E+01, -.14158800E+01, -.31186300E+04, -.14108900E-01, 0.67118100E+03, 0.35292900E+04, -.33455100E+04, -.32691600E+04, -.23109400E+04, 0.38793300E+04, 0.10553700E+04, -.17483900E+05, 0.87165500E+04, 0.44875600E+03, 0.87419300E+04, 0.11919100E+04, -.36238400E+04, 0.62128000E+04, 0.29710800E+04, 0.88802400E+04, -.35366000E+04, 0.63436700E+04, -.15768900E+05, 0.78833900E+04, -.40448300E+04, 0.78844300E+04, 0.44034200E+02, 0.11644800E+04, -.14237800E+01, -.55376600E+04, 0.51063200E+04, 0.58170400E+03, 0.97155100E+04, 0.17448800E+04, -.88503400E+03, -.33155100E+03, -.86403500E+03, -.36601400E+02, 0.49468300E+03, -.91204000E+03, -.31843900E+03, -.72824900E+03, 0.40030100E+03, -.75744800E+03, -.17510900E+04, 0.94170400E+03, -.62208600E+04, 0.87555700E+03, 0.84303400E+03, 0.32769700E+04, -.51529500E+04, -.71062400E+04, -.24119100E+04, 0.37012200E+04, 0.81490700E+03, 0.11304700E+05, -.58108400E+04, -.92442000E+04, -.56523600E+04, -.18888600E+04, -.31765700E+04, 0.44423100E+04, 0.10574600E+05, -.27346300E+04, -.71166600E+03, -.88473700E+04, -.20371800E+05, 0.10285400E+05, 0.64475300E+04, 0.10185900E+05, 0.38973500E+04, 0.66393000E+04, -.31417700E+04, -.11238900E+05, 0.50162200E+04, 0.45790200E+04, 0.84813200E+04, 0.41707400E+04, -.21597700E+04, -.18662000E+04, -.20893400E+04, -.38915100E+03, 0.15844200E+04, -.45898700E+03, 0.14704100E+04, -.63166400E+03, 0.89550200E+03, -.20904000E+03, 0.35427000E+04, -.18346200E+04, 0.61035400E+04, -.17713900E+04, -.57743700E+03, -.39538200E+04, 0.30921800E+04, 0.74181800E+04, 0.77436500E+03, -.34460100E+04, -.15894600E+02, -.54502500E+04, 0.29229100E+04, -.17207100E+04, 0.27251300E+04, 0.16017200E+04, 0.11874900E+04, -.28741000E+04, -.41805800E+04, 0.38906200E+04, 0.15133300E+03, 0.64119500E+04, -.42829500E+04, 0.21518700E+04, -.34239900E+04, 0.21414600E+04, -.12195900E+03, 0.65913400E+04, -.38535300E+04, -.55461600E+04, 0.25238900E+03, 0.57463300E+04, 0.21504900E+04, -.37844700E+05, 0.19055900E+05, 0.11332900E+05, 0.18922300E+05, 0.47011200E+04, 0.71409500E+04, -.22507100E+04, -.15778200E+05, 0.10958000E+05, 0.33020700E+04, 0.19752300E+05, 0.85987800E+04, -.42119300E+04, -.11424500E+05, -.42994100E+04, 0.99105600E+03, -.61494800E+03, -.17138400E+04, 0.27710300E+04, 0.55830800E+03, -.15606500E+04, -.52554000E+04, 0.13775700E+05, -.70167200E+04, 0.48130700E+04, -.68878500E+04, -.17751000E+04, -.17366700E+04, 0.37969400E+03, 0.40129200E+04, -.62451100E+04, -.59202200E+03, -.73360000E+04, -.77350100E+04, 0.39261600E+04, -.15242200E+04, 0.38675000E+04, -.78242400E+03, -.12074700E+04, 0.76884800E+03, -.33389000E+04, 0.35318700E+04, -.18178200E+04, 0.38728400E+04, 0.20126700E+04, -.10037000E+04, 0.86759500E+04, -.10063300E+04, -.26616600E+04, 0.97679200E+03, -.11431700E+04, -.26414100E+04, -.32499700E+04, 0.19095800E+04, 0.14906500E+04, -.13165100E+03, 0.54750300E+02, 0.39489900E+04, 0.65818700E+02, 0.45115300E+03, -.13048100E+04, 0.34998500E+04, 0.31505500E+04, 0.79257100E+02, -.13761600E+04, -.11778800E+04, -.25487900E+02, 0.27618800E+03, -.45521000E+03, 0.17958700E+03, 0.56018300E+03, 0.21529400E+03, -.28340200E+03, 0.27190800E+03, 0.97689900E+03, -.12258100E+03, 0.16872800E+03, -.90999500E+02, -.14587800E+04, 0.33584500E+04, 0.64601100E+03, 0.52541800E+03, -.33477400E+01, 0.37330000E+03, -.33220500E+04, 0.83160300E+03, 0.39704200E+03, 0.99922400E+03, 0.53094300E+03, -.48793700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11224400E+02, 0.30629400E+01, 0.23694000E+01, -.71674100E+01, -.63933800E+01, 0.13209500E+01, 0.11387100E+01, -.24830300E+00, -.15832700E+00, 0.11476600E+01, -.16430900E+01, -.93212000E+00, 0.52212100E+01, -.22098600E+01, 0.86594400E+00, 0.36037000E+00, -.22215200E+01, -.67680600E+00, 0.89631600E+00, -.30764100E+00, -.12577500E+01, 0.38427400E+01, -.14012900E+01, 0.23538800E+01, 0.64992900E-01, -.28247100E+01, 0.52798600E-01, -.35122500E+00, -.56427600E+00, -.13453300E+01, 0.91756800E+00, -.27378500E+00, 0.17555300E+01, 0.60006700E+00, 0.13968400E+00, -.71457700E+00, 0.13427500E+00, -.12823700E+01, 0.22510300E+00, -.86048700E+00, -.20268700E+01, 0.31032800E+00, -.34631400E+01, 0.13438900E+00, 0.34367200E+00, -.30673500E+00, 0.18418800E-01, 0.74046200E+00, -.28811300E+00, -.15472800E+01, -.38867600E+00, -.13334100E+01, 0.43496600E-01, 0.74380600E-01, 0.84004500E+00, 0.14451100E+01, -.66644300E+00, 0.19427900E+01, -.86076500E-02, -.19986700E+01, 0.21214300E-01, 0.26954700E+00, 0.18209800E+00, 0.14863900E+00, 0.20850600E+01, 0.95184300E+00, -.77433500E+00, 0.16672700E+00, -.39980700E+00, 0.78102400E+01, 0.48196300E+03, -.85605200E+02, -.44304000E+03, 0.99973900E+02, -.66301700E+03, -.34106800E+02, -.19987200E+04, 0.36753000E+03, -.20121300E+03, -.22173900E+03, -.18373900E+03, -.21823100E+04, -.53409700E+03, 0.21192200E+03, -.88644000E+03, 0.41659300E+03, -.20341800E+03, 0.11111500E+04, 0.13239400E+04, -.64039600E+03, 0.22308600E+04, -.66220300E+03, -.26195100E+03, -.15438900E+03, -.61299000E+03, 0.11842400E+04, -.73797200E+03, 0.51194100E+02, -.14530800E+03, 0.94710500E+02, -.82700000E+01, -.32504000E+02, -.63953900E+02, -.31428700E+02, 0.18130500E+03, -.14887200E+03, -.90432400E+02, -.63798600E+02, 0.90138500E+02, 0.53392400E+03, 0.58993100E+03, -.34859100E+03, 0.25920100E+04, -.29485400E+03, 0.28953600E+03, -.98242500E+03, 0.19757900E+02, 0.26677900E+04, -.82130800E+03, -.84671700E+03, -.89917700E+03, 0.84426300E+04, -.41308300E+04, -.82790900E+04, -.42213200E+04, 0.26742900E+03, 0.29225600E+03, -.73673800E+03, 0.19009600E+04, -.31232700E+04, -.40469300E+03, -.58101400E+04, -.73814000E+04, 0.36417500E+04, 0.55691500E+04, 0.36907100E+04, 0.87595900E+03, -.28712700E+03, 0.12363400E+04, -.84768800E+03, 0.20506400E+04, -.36251500E+03, 0.46399300E+04, -.10829800E+04, 0.57930900E+03, -.70301800E+03, 0.53166900E+03, -.99223900E+03, -.11197300E+04, 0.65835400E+02, -.44460000E+03, 0.41932900E+03, -.89409500E+03, -.23686100E+04, -.23430500E+04, 0.12271700E+04, -.76486300E+03, 0.11710700E+04, 0.48854000E+03, 0.20714900E+04, 0.51865100E+03, -.11319600E+04, 0.11403800E+04, 0.15163200E+04, 0.22544800E+04, -.18359400E+04, 0.82428600E+03, 0.52835600E+04, 0.91801100E+03, -.13599300E+04, -.34978100E+03, 0.55366100E+03, 0.10838100E+04, 0.91499400E+03, 0.45050000E+03, 0.32495600E+04, 0.20664200E+04, -.10468500E+04, 0.11903700E+03, -.10333400E+04, -.16081500E+04, -.26324000E+04, -.47429300E+03, 0.18590200E+04, -.10265400E+04, -.24518700E+04, -.30065900E+04, -.15407900E+05, 0.76229400E+04, 0.11315500E+05, 0.77039400E+04, 0.75750400E+03, 0.32722500E+03, 0.17640900E+04, -.34251000E+04, 0.44303400E+04, 0.62501500E+03, 0.84335400E+04, -.68996300E+04, 0.33206900E+04, 0.40840000E+04, 0.34494900E+04, -.31454400E+04, -.32128400E+04, 0.28334100E+04, 0.12517200E+04, 0.22327900E+04, -.26934900E+04, 0.79514600E+04, 0.31168000E+04, -.15001600E+04, -.29924100E+04, -.15582600E+04, 0.17567700E+03, -.41154900E+03, -.84504600E+02, 0.34061200E+03, -.67733800E+03, -.79790800E+03, -.28501000E+04, -.17509800E+04, 0.84380000E+03, 0.19401700E+04, 0.87548300E+03, 0.18019100E+03, -.40518900E+03, 0.32969300E+03, 0.12288200E+03, 0.54097800E+03, -.34295600E+03, 0.17788300E+04, 0.22642100E+04, -.11037100E+04, -.31607900E+03, -.11320700E+04, 0.33014600E+04, 0.16202800E+04, -.30185000E+03, 0.18895300E+04, -.38316900E+03, 0.11797800E+04, -.38115100E+04, 0.13530700E+04, -.63945900E+03, -.16605400E+04, -.67664600E+03, 0.15077400E+03, 0.12213500E+04, -.11226800E+04, -.22574900E+04, -.83862100E+03, 0.14700400E+04, -.14869600E+02, -.18649500E+03, -.12509400E+03, 0.23465500E+03, -.11151000E+03, -.17047300E+03, -.18341400E+03, 0.11810700E+03, -.12175300E+03, 0.32887400E+03, 0.30197900E+02, 0.85812200E+02, 0.43716800E+02, 0.53654200E+03, -.19389200E+02, -.92843000E+03, -.29788400E+02, -.16137000E+03, 0.57922200E+03, 0.32684700E+03, 0.11879900E+02, -.34849600E+03, -.49822600E+02, 0.83830900E+03, 0.40730400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.37582900E+01, -.38276500E+00, -.12429600E+00, -.59379000E+00, 0.13739300E+01, 0.15785200E+01, -.40575900E+00, 0.11455400E+01, 0.24262200E+00, -.26676500E+00, -.84237800E-01, 0.65760900E-01, -.23238800E+01, -.17120200E+01, 0.69676400E-01, -.21656200E+00, -.36976400E+00, -.12628300E+01, -.66327700E-01, 0.67238900E+00, -.75087300E+00, -.36746400E+01, -.10684000E+01, 0.69998600E-01, -.26570300E+00, 0.11267500E+01, -.22382100E-01, -.42738600E+00, -.57133100E+00, -.38739600E+00, -.51454200E+00, 0.31526700E+00, -.10528200E+01, 0.91933200E+00, -.14867000E+00, 0.47187500E+00, -.18508200E-01, 0.10755400E+01, -.55707600E+00, -.25686800E-01, 0.68786700E-01, 0.55845100E+00, 0.20420400E+01, 0.12767400E+00, -.14191800E+00, 0.57149900E+00, 0.52093500E-01, 0.50070900E+00, 0.55085700E+00, 0.11071000E+01, 0.20062700E+00, -.35872100E+00, -.19809000E+00, -.12735500E+00, -.13860000E+00, 0.12782700E+00, 0.36404600E-01, 0.82095300E+00, 0.14187700E-02, 0.52797900E+00, 0.31083500E+00, 0.49182600E+00, 0.73417000E-01, 0.81388400E+00, 0.98576700E-01, 0.23544300E+00, 0.44301100E+00, -.32870300E+00, 0.89029400E-01, -.46341000E-03, 0.14155200E+04, 0.93795600E+03, -.81502200E+03, -.38972700E+03, -.98159500E+03, 0.67156600E+03, -.71582400E+03, -.21234100E+04, 0.10503100E+04, 0.40546400E+02, 0.10617100E+04, -.38132800E+03, -.80102900E+03, 0.17140000E+04, 0.21807600E+04, 0.28028300E+04, -.55372600E+03, 0.13195200E+04, 0.72616100E+03, -.36636300E+03, -.10495300E+04, -.36308800E+03, -.10977800E+04, -.68550200E+03, -.80496200E+03, -.32879500E+03, 0.34160300E+03, -.11519500E+04, 0.63608100E+03, 0.13664500E+04, -.70582500E+03, -.97571100E+02, -.68174800E+03, -.11127200E+03, 0.21207300E+02, -.33732100E+03, 0.34718800E+03, -.41398500E+03, 0.49348100E+02, -.70387800E+03, -.18602400E+04, 0.98737500E+03, -.72945600E+03, 0.93012300E+03, 0.43089100E+03, 0.16150600E+02, -.60234900E+03, -.58850800E+03, -.70019500E+03, 0.35021500E+03, 0.68661000E+03, 0.18955600E+04, -.10698900E+04, 0.49059800E+03, -.94778200E+03, -.92565800E+03, -.26005200E+03, 0.20388800E+04, 0.41962000E+04, 0.33741400E+03, 0.59056300E+03, -.21054900E+04, -.14610200E+05, 0.73778200E+04, 0.55825100E+04, 0.73051000E+04, 0.21261700E+04, 0.17209900E+04, -.14809600E+03, -.60605300E+04, 0.32221000E+04, 0.10333300E+04, 0.69062900E+04, 0.47730500E+03, -.29016800E+03, 0.52213500E+03, -.23635900E+03, 0.64535600E+03, 0.55665000E+03, 0.13215000E+03, 0.89547200E+03, 0.34338900E+03, 0.17278200E+03, -.64944700E+02, 0.78005300E+03, -.44916900E+03, 0.64720500E+03, -.39004000E+03, -.34149200E+02, -.14072700E+03, 0.39260100E+03, 0.16590200E+04, 0.43818700E+03, -.36773200E+03, -.42179100E+03, 0.11409100E+05, -.55656900E+04, -.74443100E+04, -.57045600E+04, -.99396900E+03, -.21363600E+04, -.17789800E+04, 0.21024300E+04, -.15990900E+04, -.20583900E+04, -.43704300E+04, -.25899600E+04, 0.13082400E+04, 0.95475700E+03, 0.12949800E+04, 0.58690000E+03, 0.49872400E+03, 0.36683800E+03, 0.66384800E+03, 0.75815000E+03, 0.41909400E+03, 0.41742500E+03, -.16653600E+05, 0.84299900E+04, 0.56820400E+04, 0.83268000E+04, 0.23244900E+04, 0.16894200E+04, -.41146200E+03, -.73739700E+04, 0.36188600E+04, 0.44726500E+03, 0.91404200E+04, 0.10191300E+05, -.50143400E+04, -.52000200E+04, -.50956500E+04, -.46358600E+03, 0.14140900E+04, -.20630900E+04, 0.26086400E+04, -.27541100E+04, 0.21109200E+04, -.51418400E+04, -.51695500E+04, 0.24963000E+04, 0.31172000E+04, 0.25847800E+04, 0.75941900E+03, 0.14301200E+04, 0.82247300E+03, -.66955800E+03, 0.99045800E+03, 0.12461000E+04, 0.19797500E+04, -.33587100E+04, 0.17212700E+04, 0.14548600E+04, 0.16793500E+04, -.57433200E+03, -.51224100E+03, -.14576900E+03, -.19781500E+04, 0.91895500E+03, -.66783600E+03, 0.21708800E+04, -.74289800E+04, 0.37152800E+04, 0.32434200E+04, 0.37144900E+04, -.75192000E+03, -.11660400E+04, 0.12507400E+04, -.26453900E+04, 0.13505700E+04, -.13428900E+04, 0.39753600E+04, 0.25306800E+03, -.14213100E+03, -.37488000E+03, -.12653700E+03, 0.20224900E+03, 0.86757800E+02, 0.60350300E+03, 0.37282600E+03, 0.29982600E+03, -.41757100E+03, 0.67427100E+02, 0.20303200E+03, -.82348400E+02, -.44977600E+02, -.69841500E+02, 0.59184600E+01, -.50524600E+02, 0.88314300E+02, 0.14886600E+03, 0.62944100E+03, -.94983800E+02, 0.36844200E+03, -.31046900E+03, 0.63893400E+02, 0.15928100E+04, 0.40755200E+03, -.15346300E+03, 0.58461300E+03, -.10950100E+03, -.10413100E+04, 0.80275700E+02, 0.53364800E+03, 0.17331100E+03, -.88497300E+02, -.57691400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44613000E+01, 0.12435400E+01, 0.95869300E+00, -.13207000E+01, -.30463700E+01, 0.14165700E+01, 0.45535400E+00, -.21388700E+01, 0.58475400E+00, 0.10901700E+01, -.27936000E+01, -.35562300E+01, -.18513400E+01, -.21864100E+01, -.27343600E-01, 0.58253900E+00, -.87641000E+00, 0.12933800E+00, -.12485500E+00, -.11928500E+01, 0.11446300E+01, 0.43035500E+01, -.21246200E+01, 0.19303800E+01, 0.44054200E+00, -.78637500E+00, 0.20080800E+00, 0.41367500E-02, -.83938300E+00, 0.26810300E+00, -.47357600E+00, -.71401800E+00, 0.21864200E+01, 0.58251300E+00, 0.31032100E+00, -.11522300E+01, -.11179000E+00, -.65271500E+00, 0.53189200E+00, -.83569000E+00, -.31412400E-01, 0.57890000E+00, -.51101900E+00, -.79133800E+00, 0.69011900E+00, 0.30720100E+01, -.88480400E+00, -.90839800E+00, 0.76150300E+00, 0.32234700E+01, 0.37814200E+01, 0.48208000E+00, 0.42380700E+00, -.25170200E+00, 0.17799300E+01, -.44063200E+00, -.24579200E+00, 0.18757900E+00, 0.52939600E-02, 0.10603400E+01, 0.70851400E+00, 0.17845200E+01, -.10506000E+00, 0.73261800E+00, -.91537400E+00, -.57885500E+00, -.68736300E+00, 0.16619900E+01, -.47911900E+00, 0.13183400E-01, -.46648200E+00, 0.22552700E+04, -.12727900E+04, -.80209000E+03, -.11310900E+04, 0.14492100E+04, 0.13551700E+04, -.93743300E+02, 0.13662900E+02, -.14481900E+04, 0.46851700E+02, -.39864400E+03, -.40834900E+03, 0.17480500E+04, 0.25159200E+04, 0.15030000E+04, 0.14139200E+03, -.24283700E+04, 0.66877300E+04, -.32642300E+04, -.15717000E+04, -.33436900E+04, -.12404300E+04, 0.13861000E+03, -.15874500E+04, 0.37499400E+04, 0.44439600E+03, 0.27012900E+02, 0.58061100E+03, -.16353300E+04, 0.87705200E+03, 0.32536300E+03, 0.81915000E+03, 0.17682000E+03, -.28239900E+03, 0.87060700E+03, 0.63341700E+03, 0.89090800E+03, -.14688700E+03, -.72551000E+03, -.59159100E+04, 0.28732800E+04, 0.36414800E+04, 0.29578700E+04, -.95133600E+02, 0.25219300E+04, -.41217800E+02, 0.21430800E+04, 0.23866300E+04, 0.27742800E+04, 0.20137800E+04, -.13313900E+05, 0.67759500E+04, 0.26072600E+04, 0.66569700E+04, 0.36882700E+03, -.22049300E+04, 0.39637000E+04, -.49144400E+04, 0.27690600E+04, -.10336400E+04, -.12749500E+03, 0.12044100E+04, -.64989900E+03, -.26292900E+03, -.60221500E+03, 0.84187600E+02, -.30048900E+03, -.22655500E+04, 0.25737100E+03, 0.61870100E+03, -.85573800E+03, 0.41123900E+04, 0.57831400E+03, -.21094000E+03, -.17979200E+03, -.28544600E+03, 0.14626200E+04, 0.23615500E+04, -.11028900E+04, -.13122800E+04, -.12115000E+04, 0.11093100E+04, 0.41037400E+04, 0.15642000E+04, -.68144100E+03, -.11595600E+04, -.78174500E+03, -.11202300E+04, -.26460000E+04, 0.16146200E+04, -.47307300E+03, 0.60145000E+03, -.19350900E+04, -.37859200E+04, 0.19665900E+05, -.99865700E+04, -.52725800E+04, -.98330000E+04, -.25502800E+04, 0.10988200E+04, -.30281900E+04, 0.79159100E+04, -.42444100E+04, 0.65376300E+03, -.50806400E+04, -.63115800E+04, 0.31328200E+04, 0.38888000E+04, 0.31558900E+04, 0.28553900E+04, 0.46383500E+04, -.66916700E+03, -.52110100E+03, -.69209000E+03, 0.32370000E+04, 0.43766500E+04, 0.94261200E+04, -.48047400E+04, -.31522900E+04, -.47130700E+04, -.18664600E+03, 0.18867700E+04, -.39735600E+04, 0.34529500E+04, -.12001400E+04, 0.62426800E+03, 0.38554800E+04, 0.48303500E+04, -.26766800E+04, 0.20123600E+04, -.24149300E+04, 0.19425000E+04, 0.60014900E+04, -.75364100E+03, 0.42244500E+04, -.29551600E+04, 0.67282000E+04, -.11553300E+05, -.92573300E+04, 0.47337300E+04, 0.43889400E+04, 0.46285600E+04, 0.10601300E+04, -.10051500E+04, 0.16263100E+04, -.40392600E+04, 0.24646400E+04, -.86533200E+03, 0.19636600E+04, 0.33490800E+04, -.17087700E+04, -.12321500E+04, -.16745400E+04, 0.16024900E+03, 0.12363700E+04, -.22834400E+04, 0.11996900E+04, -.14174300E+03, 0.11026700E+04, 0.10296800E+04, 0.11320500E+04, -.51216000E+03, 0.62624500E+03, -.56605600E+03, -.81166000E+03, -.26973600E+04, -.69575300E+03, -.22201400E+04, -.54251100E+03, -.32283100E+04, 0.40126500E+04, 0.57236500E+04, -.27842700E+04, -.47243000E+04, -.28617400E+04, -.56927700E+03, -.22467900E+04, -.87522200E+03, 0.13822800E+03, -.56426200E+03, -.27595300E+04, 0.13915700E+02, 0.24851100E+03, 0.21084500E+03, -.27496900E+03, 0.20084300E+03, -.48687400E+02, 0.47922200E+02, -.22542100E+03, -.30485300E+01, 0.53983900E+03, 0.41870900E+02, -.30591600E+03, 0.36747900E+03, -.73316200E+03, 0.45270600E+02, 0.11340900E+04, -.24577600E+03, -.16471300E+04, -.74400300E+03, -.27222300E+03, -.83352100E+03, -.15145400E+04, 0.17834400E+03, -.98477400E+03, 0.86066800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.31770300E+01, -.54732800E-01, -.45167000E+00, 0.11283200E+01, 0.10320800E+01, 0.12185700E+00, -.27785900E+00, 0.36737000E+00, -.87074500E-01, -.38058500E+00, 0.25027200E+00, -.16645100E+00, -.14471700E+01, -.51872100E+00, 0.16388500E+00, 0.45113300E-01, 0.16436500E-01, 0.41040400E+00, -.22317900E+00, -.14513900E+00, 0.62152200E+00, -.33944600E+00, -.19699300E+00, -.54406400E+00, 0.42267500E-01, -.18421800E+00, 0.38164900E+00, -.35182100E+00, -.56382600E+00, -.11693200E+01, -.27522900E+00, 0.16405900E+00, 0.26494000E+00, 0.72233100E+00, -.59055800E-01, 0.51304800E+00, -.80244200E-02, -.10491600E+01, -.26203300E-01, -.91457400E-01, 0.21886100E+00, 0.80400900E+00, -.21342100E+00, 0.17318000E+00, 0.89738000E-01, -.50453500E+00, 0.20350900E+00, -.37008500E+00, -.31153300E+00, -.17603300E+00, -.42597600E+00, 0.25752900E-01, -.13089800E+00, 0.38959900E+00, -.13675800E+00, -.16110400E+00, -.21389800E+00, -.16708100E+00, -.31346800E-02, 0.48761000E-01, -.76868900E-01, -.34735500E+00, 0.51916800E-01, 0.79216200E-01, -.10719400E+01, -.53956400E+00, 0.44451800E-01, -.89927900E+00, 0.69070700E+00, -.35797600E-02, -.19283800E+00, 0.41637900E+00, 0.11360600E+04, 0.19805900E+03, -.70744700E+03, 0.49237800E+03, -.14885500E+04, 0.88515200E+04, -.44100300E+04, -.35660000E+03, -.44257500E+04, -.77182700E+03, -.18202200E+04, -.26007500E+04, -.17555400E+04, -.27666300E+04, -.20007700E+04, -.80230200E+03, -.95841800E+04, 0.47694700E+04, 0.51315600E+04, 0.47919600E+04, 0.22593900E+04, 0.49358000E+03, 0.22048400E+04, -.30596000E+04, 0.28468600E+03, 0.19740300E+03, -.10125300E+04, 0.95956600E+03, -.48593800E+03, -.26826000E+03, -.48227400E+03, -.57997200E+02, 0.43274300E+03, -.61638600E+03, -.20309100E+03, -.37438200E+03, 0.30140200E+03, 0.49437100E+03, 0.71337000E+04, -.35692800E+04, -.96658300E+02, -.35667900E+04, 0.32886000E+03, -.18927800E+04, 0.13354900E+04, 0.41160700E+03, -.39289300E+04, -.22855300E+04, -.34724600E+04, 0.20509800E+05, -.10251600E+05, -.14601100E+05, -.10254900E+05, -.74584000E+03, 0.48901100E+04, -.86133700E+04, 0.14872000E+04, -.38923200E+04, 0.31308100E+04, 0.54444700E+03, -.37456800E+04, 0.18642200E+04, 0.63089100E+04, 0.18728500E+04, -.29451500E+03, -.25685100E+04, 0.47938500E+04, 0.25320900E+04, -.12488500E+03, -.15813300E+04, -.23654000E+04, -.12537700E+04, 0.61813100E+03, -.13749500E+04, 0.62759700E+03, -.90393400E+03, -.10997400E+04, -.10750800E+03, -.88618700E+03, 0.15509000E+03, 0.33935300E+03, -.36763000E+04, -.30705100E+04, 0.15360400E+04, -.59490800E+03, 0.15350000E+04, 0.12882500E+04, 0.32399200E+04, -.29487000E+04, -.24113000E+04, 0.64586300E+03, 0.23964500E+04, 0.28626800E+04, -.13709100E+05, 0.68544900E+04, 0.11308600E+05, 0.68545700E+04, 0.14080200E+04, -.42386600E+04, 0.51274800E+04, -.37956100E+04, 0.25959200E+04, -.33435500E+04, -.11775800E+04, 0.69142200E+04, -.34593300E+04, -.29862900E+04, -.34571800E+04, -.29203100E+04, -.54713900E+04, 0.21986100E+04, 0.22184100E+04, -.19063500E+04, -.35466600E+04, -.46439100E+04, -.12927800E+05, 0.64622400E+04, 0.15190000E+05, 0.64639000E+04, 0.16717900E+03, -.54512900E+04, 0.79027800E+04, -.14026500E+03, 0.11941500E+04, -.32753600E+04, -.39424400E+04, -.23862800E+04, 0.12406400E+04, -.15958400E+04, 0.11929600E+04, -.37252800E+04, -.94439400E+04, 0.39128300E+04, 0.27265000E+04, 0.36516400E+04, -.94672100E+04, 0.90563800E+04, 0.83605700E+04, -.41804100E+04, -.79185600E+04, -.41802100E+04, -.36318600E+03, 0.20643600E+04, -.27131700E+04, 0.21175300E+04, -.21221600E+04, 0.18685700E+04, -.65483300E+03, -.76389900E+04, 0.38159200E+04, 0.33588700E+04, 0.38194900E+04, 0.85687500E+03, -.48395000E+03, 0.23495000E+04, -.90672900E+03, 0.14157500E+04, -.61230900E+03, 0.14713100E+04, -.51136800E+04, 0.25323200E+04, -.95822900E+03, 0.25568600E+04, 0.25640900E+04, 0.46149600E+04, -.73151300E+03, -.19835500E+04, 0.30068300E+03, 0.45572700E+04, -.18596900E+04, -.77348200E+04, 0.38528400E+04, 0.45568300E+04, 0.38673500E+04, 0.68079000E+03, 0.20716000E+04, 0.27797900E+03, -.49176100E+03, 0.19000500E+04, 0.24146900E+04, 0.21296500E+04, -.41198700E+03, -.20541200E+03, 0.12131400E+03, -.16327100E+03, 0.12627000E+03, -.16567700E+03, 0.21770000E+03, -.26899000E+02, 0.12514100E+03, 0.37221300E+03, 0.21029200E+03, -.72719200E+02, 0.22038000E+04, -.12808800E+03, -.10319600E+04, 0.21692500E+03, 0.22940300E+04, 0.80381500E+03, 0.13540800E+04, 0.12403100E+04, 0.14475700E+04, -.75460300E+03, 0.19916500E+04, 0.11019100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.43697200E+01, 0.55453400E+00, 0.22246700E+01, -.46863400E+01, -.29905900E+01, 0.36430800E-01, 0.49497800E+00, -.14645000E+01, -.12594300E-02, -.25567000E+00, -.21526500E+01, -.44285100E+00, 0.25950900E+00, -.27290200E+01, 0.54742300E+00, 0.53445600E+00, -.13202900E+01, 0.30568700E+00, 0.14443300E+00, 0.62036400E+00, 0.67216300E+00, 0.32360600E+01, -.20407600E+01, 0.12252000E+01, -.47051300E-01, -.38140100E+00, 0.57024300E+00, -.53396600E+00, -.39209400E-01, -.10427900E+01, -.22741600E+00, -.30366800E+00, 0.18873000E+01, -.60863000E+00, 0.66982400E-01, -.24597800E+00, 0.12732700E+00, -.62353800E+00, 0.73934100E+00, -.54862500E-01, -.11248400E+01, -.11759500E+01, -.16570100E+01, -.22313600E+00, -.55403100E-01, -.24809300E+00, -.12568800E+01, 0.75978700E+00, 0.41032900E-02, -.12525200E+01, -.38428000E+00, -.60627000E+00, 0.31052000E+00, -.22403400E+00, 0.36886000E+00, -.44379200E+00, 0.32356000E-01, 0.10499200E+01, -.14970500E-02, -.15869000E+00, 0.43699500E+00, -.50836800E+00, 0.21170100E+00, -.81727500E+00, 0.17261000E+01, 0.12033300E+01, -.95449400E+00, -.20988700E+01, -.10133200E+01, -.49988100E-02, -.62521500E-01, -.36974800E+00, -.83439800E+00, -.26054000E+04, -.18209300E+03, 0.87914100E+03, -.55892500E+04, -.62278100E+04, 0.30948600E+04, 0.21441400E+04, 0.31139200E+04, -.53999600E+02, -.37463600E+04, 0.21421500E+04, 0.12892700E+04, 0.21586600E+04, -.34013800E+04, 0.11871100E+05, -.25368100E+05, 0.12765400E+05, 0.66788900E+04, 0.12683900E+05, 0.49386200E+04, 0.32732100E+03, 0.51199300E+04, -.10659000E+05, 0.17923800E+04, 0.14495200E+02, 0.43020500E+04, 0.50559000E+04, -.24754300E+04, -.10318000E+04, -.25235700E+04, -.14083600E+03, 0.83175000E+03, -.21042100E+04, -.75306300E+03, -.17560700E+04, 0.60082900E+03, -.96104700E+03, 0.10017400E+05, -.49991200E+04, -.64164000E+04, -.50086300E+04, 0.54507200E+03, -.60327400E+04, 0.21958800E+04, -.45162300E+04, -.52587700E+04, -.54866500E+04, -.55883600E+04, 0.43078900E+05, -.21639700E+05, -.22471200E+05, -.21539500E+05, -.47917400E+04, 0.76175000E+03, -.71152000E+04, 0.15029600E+05, -.65006000E+04, 0.13559800E+04, -.73616200E+04, -.15575000E+05, 0.78892400E+04, 0.11608500E+05, 0.77875200E+04, 0.27912200E+04, 0.24638400E+04, 0.57826100E+04, -.39257600E+04, 0.57765300E+03, 0.27719900E+04, -.45582200E+04, 0.21217900E+04, -.10925100E+04, -.44118300E+03, -.10664100E+04, -.28161400E+04, -.23008500E+04, 0.13110300E+04, 0.41954300E+04, 0.27849900E+04, -.33143400E+03, -.96062400E+04, -.22182900E+04, 0.11367600E+04, 0.35739200E+04, 0.11089300E+04, 0.25942100E+04, 0.86278700E+04, -.59011800E+04, -.49635800E+03, -.22767400E+04, 0.65047000E+04, 0.58394900E+04, -.38227400E+05, 0.19202700E+05, 0.16720400E+05, 0.19113700E+05, 0.78879000E+04, -.19045400E+04, 0.48107700E+04, -.13529800E+05, 0.96121600E+04, -.29522700E+04, 0.12956900E+05, 0.93961500E+04, -.47130100E+04, -.62669300E+04, -.46981400E+04, -.52186200E+04, -.10233700E+05, 0.42830600E+04, 0.39347300E+04, 0.44591100E+04, -.66060700E+04, -.95253700E+04, -.41754100E+05, 0.20997900E+05, 0.24175500E+05, 0.20877000E+05, 0.44572200E+04, 0.32966800E+02, 0.93145100E+04, -.11396000E+05, 0.66975100E+04, 0.13844100E+03, 0.27911200E+04, 0.57732700E+04, -.29608800E+04, -.61406500E+04, -.28867800E+04, -.28788500E+04, -.92893000E+04, -.27989200E+03, 0.16177900E+04, 0.47340000E+04, -.11090000E+05, 0.20723700E+05, 0.21396500E+05, -.10737200E+05, -.91000200E+04, -.10698200E+05, -.46686700E+04, 0.53892600E+03, -.17756500E+04, 0.81362300E+04, -.71984600E+04, 0.16960500E+04, -.83518700E+04, -.19223800E+05, 0.96729400E+04, 0.65767400E+04, 0.96119100E+04, 0.23028100E+04, -.12366300E+04, 0.54139100E+04, -.59706900E+04, 0.20233500E+04, -.16450900E+04, 0.25730300E+04, -.45734200E+04, 0.22760100E+04, 0.16958500E+04, 0.22867300E+04, 0.14712900E+04, 0.39673000E+04, -.31107300E+03, -.25717400E+04, -.10057200E+04, 0.47949000E+04, -.11236100E+05, -.91660100E+04, 0.46263100E+04, 0.69928300E+04, 0.45829500E+04, 0.86685200E+03, 0.47748700E+04, 0.16763100E+04, -.31906900E+03, 0.22888100E+03, 0.45366300E+04, 0.78851800E+03, -.55539200E+03, -.22127600E+03, 0.31021400E+03, -.13952500E+03, 0.33210200E+03, 0.30015200E+01, 0.18672000E+03, 0.35575700E+03, 0.14699000E+04, 0.31826400E+03, 0.12114500E+04, -.10089000E+04, 0.75527900E+03, 0.27802700E+04, -.17501500E+04, 0.47838400E+03, 0.41250600E+04, 0.17588200E+04, -.18082500E+04, 0.20157100E+04, 0.32683300E+04, -.11186400E+04, 0.23735000E+04, -.15858700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15863300E+01, 0.39718300E+00, 0.60043400E+00, -.90308200E+00, -.18162700E+01, 0.60624700E-01, 0.10525700E+00, -.77829700E+00, 0.38349500E+00, 0.27853300E+00, 0.63801600E+00, 0.42205600E+00, -.60358600E-02, -.20400000E+00, -.19523900E-01, 0.57474400E-01, -.31821300E+00, -.55414400E+00, -.33369000E+00, 0.12166300E+00, 0.24622300E+00, 0.86934200E+00, 0.21393000E+01, -.81977200E+00, 0.12881000E+00, -.25357300E-01, 0.41373200E+00, 0.29122700E+00, 0.60494900E+00, 0.13730600E+01, -.11104400E+00, -.58075700E-01, 0.58255600E+00, 0.14399400E+00, 0.14534000E+00, -.30757000E+00, 0.24155000E-01, -.51929400E+00, 0.12672000E+00, -.45269600E-01, -.36800300E+00, -.46285900E+00, 0.14712300E+01, -.56498100E+00, 0.41005400E+00, 0.68849200E+00, -.10073300E+00, 0.34408100E+00, 0.24758000E+00, -.44915700E+00, -.76067200E+00, -.35077200E+00, -.33610400E-01, -.80338800E-01, 0.17671600E+00, 0.43601500E-01, -.56950800E-02, 0.50084400E+00, 0.11410300E-02, 0.73283600E-01, 0.33095200E+00, 0.29186900E+00, 0.25453800E-01, 0.19599900E+00, 0.98413500E+00, 0.87270300E+00, 0.30005500E+00, 0.67288100E-01, -.57641100E-01, 0.14328600E-03, 0.21715100E+00, -.89195100E-02, 0.52903000E+00, -.14077600E+00, 0.13989500E+04, 0.31672500E+03, -.99400500E+03, -.69948300E+04, 0.34874300E+04, 0.12849700E+04, 0.34974100E+04, 0.10059600E+04, 0.14601300E+03, 0.17486000E+04, 0.81177000E+03, 0.48414900E+03, -.14808000E+03, 0.41105500E+04, -.40704100E+04, 0.20973800E+04, -.75493700E+03, 0.20352600E+04, -.16428300E+03, -.15961300E+04, 0.20850400E+04, -.98384500E+03, 0.14895700E+04, -.96641300E+03, 0.81226400E+03, 0.40698000E+03, -.18136400E+03, -.33197600E+03, -.20202500E+03, -.98921500E+02, -.12723400E+03, -.11673000E+03, -.18577600E+03, -.59694000E+02, -.15530000E+03, -.19209100E+03, -.11143500E+04, 0.56503300E+03, -.23786300E+04, 0.55714900E+03, -.85094600E+03, -.16043400E+04, 0.15895000E+04, -.98547200E+03, 0.13126000E+04, -.10393100E+04, 0.75044700E+03, -.10193000E+05, 0.50555200E+04, 0.83578700E+04, 0.50965100E+04, 0.28356400E+03, 0.66970400E+02, 0.26321100E+04, -.95575800E+02, 0.14917300E+04, 0.65524500E+03, 0.48381500E+04, 0.37778500E+04, -.18376600E+04, -.42484500E+04, -.18889300E+04, -.70398100E+03, 0.29392600E+03, -.61516700E+03, -.12209600E+04, -.67821700E+03, 0.13985400E+03, -.27132900E+04, 0.94133000E+03, -.46837700E+03, 0.10141900E+04, -.47052300E+03, 0.21068300E+03, 0.52517700E+03, -.66122600E+02, 0.10840300E+04, 0.41864600E+03, 0.50594600E+03, -.15539300E+04, 0.17249000E+04, -.84903600E+03, 0.11249300E+04, -.86233600E+03, 0.43537200E+03, 0.75698300E+03, -.72133700E+03, 0.12120100E+04, -.13878100E+04, 0.57204700E+03, 0.26427600E+03, -.17632600E+04, 0.89756700E+03, -.33123300E+04, 0.88161900E+03, 0.11137200E+04, 0.62427500E+03, -.72136800E+03, -.18574100E+03, 0.19934500E+04, -.24028200E+02, 0.10371500E+04, 0.26987400E+03, -.13848200E+03, -.11226100E+04, -.13490300E+03, -.30113300E+03, 0.24048200E+03, -.45020100E+03, -.55709800E+03, 0.19329300E+04, 0.89260100E+02, -.84628900E+03, 0.58988200E+04, -.28934300E+04, -.81791600E+04, -.29494200E+04, -.55142300E+03, 0.18912000E+03, -.15276900E+04, -.41933700E+03, -.24471000E+03, -.43472500E+03, -.37062800E+04, 0.81019300E+04, -.41207700E+04, -.35449900E+04, -.40508800E+04, 0.19342600E+04, 0.33865500E+04, -.34360600E+04, -.37416800E+03, -.32039200E+04, 0.14950900E+04, 0.32393400E+03, 0.99502000E+03, -.49471100E+03, 0.21900300E+04, -.49754400E+03, -.60055000E+03, -.30905800E+03, 0.73586500E+03, 0.54669000E+03, -.18257600E+04, 0.14147200E+03, -.54722100E+03, 0.28671700E+04, -.14037600E+04, -.22345700E+04, -.14335800E+04, -.97390500E+03, -.13251400E+04, 0.66259300E+03, -.61986400E+02, -.81018000E+03, -.12123100E+04, -.15421500E+04, 0.12777300E+04, -.63142900E+03, 0.11085200E+04, -.63887500E+03, -.20075000E+04, -.15719100E+04, 0.22329100E+03, 0.17653200E+03, 0.89454400E+03, -.45977400E+03, -.23121300E+04, 0.87395000E+03, -.40857500E+03, 0.32867200E+03, -.43694700E+03, 0.33084400E+03, 0.22443300E+03, 0.54303700E+03, 0.20894700E+03, -.45953200E+03, 0.21255800E+03, -.21185600E+04, 0.13539600E+03, 0.59197200E+02, -.42075300E+02, 0.18245300E+02, 0.11109300E+03, 0.11114900E+03, -.73464200E+02, 0.16626000E+03, 0.32606200E+03, -.99420900E+02, -.15444100E+03, -.28241100E+03, 0.20795500E+02, -.11273800E+03, 0.13647600E+03, 0.23954000E+02, 0.31676800E+03, 0.46778700E+02, 0.10448900E+03, 0.14367800E+03, 0.43986600E+03, 0.38732500E+03, -.21407000E+03, -.76946200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10483700E+02, -.25833100E+01, -.12263300E+01, 0.68973100E+01, 0.53443200E+01, -.80233700E+00, -.10455700E+01, -.14649000E+01, 0.75601900E+00, -.29564600E+00, 0.33418700E+01, 0.35946200E+01, -.45054600E+01, 0.36310500E+01, -.14532100E+01, -.10735600E+00, 0.32992100E+01, 0.56304400E+00, -.89989000E+00, -.20987300E+01, 0.26565200E+01, 0.12253600E+01, 0.10803700E+02, -.78028500E+01, 0.36876600E-01, 0.31069000E+01, 0.54349400E+00, 0.68745700E+00, 0.25266100E+01, -.14103500E+01, -.32080500E+00, 0.12720000E+00, -.21069300E+00, -.19304600E+01, -.13892200E+00, -.46624800E+00, 0.79825900E-01, 0.11237100E+01, 0.22739200E+00, -.99602700E-01, 0.27593800E+01, -.12811500E+01, 0.47095500E+01, -.19650400E+01, 0.79669400E+00, 0.16146700E+01, 0.58474000E+00, -.32296600E+00, 0.20309300E+00, 0.15943000E+01, 0.14618200E+01, 0.18454500E+01, 0.10218800E+00, -.82292700E+00, 0.29175900E+00, 0.83846000E+00, 0.11085700E+01, 0.53229000E+01, -.69976800E+00, 0.17218900E+01, 0.59737800E+00, -.19231300E+01, 0.12380700E+01, 0.39540600E+00, -.53355500E-01, -.43152800E+00, -.57328200E+00, -.11389100E+01, 0.33579400E+00, 0.39761400E+00, 0.13247200E+01, 0.44190000E+00, -.13008100E+00, -.10087600E+00, 0.14585200E+01, 0.22595900E+04, -.26874800E+04, 0.16068100E+05, -.79591900E+04, 0.93986100E+03, -.80339700E+04, -.68714000E+03, -.62031400E+04, -.50702700E+04, -.96162700E+04, -.92303400E+04, -.75010000E+04, 0.21253600E+04, -.93114200E+04, 0.45171300E+04, 0.10537500E+05, 0.46640100E+04, 0.40178100E+04, -.37856500E+04, 0.50679200E+04, -.12185400E+04, -.25554000E+02, -.41965500E+04, -.42153800E+04, -.69100200E+03, 0.33125900E+03, 0.11375800E+01, 0.34663600E+03, 0.53885900E+03, 0.17442200E+04, -.11694300E+04, -.78165000E+03, -.17219100E+03, 0.14638900E+04, 0.92963200E+03, 0.30168800E+05, -.15141500E+05, -.48512100E+04, -.15088200E+05, 0.16019900E+04, -.47994000E+04, -.34552700E+04, -.72489800E+03, -.13775100E+05, -.57637300E+04, -.10763800E+05, 0.78572000E+05, -.39107800E+05, -.44246600E+05, -.39285400E+05, -.23260900E+04, 0.15423800E+05, -.24559200E+05, 0.19931700E+04, -.25392400E+05, 0.11241700E+05, -.19421200E+05, -.20101600E+04, 0.85716500E+03, 0.49295100E+04, 0.10045900E+04, -.29073100E+04, -.71869000E+04, 0.66087200E+04, 0.83455800E+04, 0.21625700E+04, -.66594200E+04, 0.18328100E+04, -.32395300E+04, 0.16365000E+04, -.53099300E+04, 0.16417000E+04, -.14902600E+04, -.21002800E+04, -.19552200E+03, -.45715400E+04, -.16347600E+04, 0.12576200E+04, -.10059100E+05, -.14286500E+05, 0.71780600E+04, 0.49744900E+02, 0.71598500E+04, 0.10277000E+04, 0.64280600E+04, -.22745000E+04, -.20994900E+04, 0.84581300E+04, 0.58621300E+04, 0.84253600E+04, -.56038400E+05, 0.27882000E+05, 0.32527400E+05, 0.28020100E+05, 0.47886300E+04, -.14689000E+05, 0.17005100E+05, -.46272600E+04, 0.23895900E+05, -.11580500E+05, 0.48811800E+04, 0.19028200E+05, -.95294700E+04, -.77332900E+04, -.95096600E+04, -.35881100E+04, -.11724500E+05, 0.24146100E+04, -.27853900E+03, -.11932000E+05, -.82168800E+04, -.12355600E+05, -.53854700E+05, 0.26756100E+05, 0.37777600E+05, 0.26926900E+05, 0.83664000E+03, -.15250600E+05, 0.18770700E+05, -.75081600E+03, 0.16372500E+05, -.11912200E+05, 0.11711400E+05, -.25933000E+05, 0.13148600E+05, -.93589100E+04, 0.12977700E+05, -.13628600E+05, -.37178600E+05, 0.20096600E+05, 0.71009100E+04, 0.14666000E+05, -.34012000E+05, 0.27477700E+05, 0.30313800E+05, -.15086800E+05, -.19662800E+05, -.15163300E+05, -.51939900E+03, 0.78086400E+04, -.86735100E+04, 0.21018700E+04, -.15393700E+05, 0.74277300E+04, -.52683800E+04, -.16697300E+04, 0.76285200E+03, 0.68983000E+03, 0.83506900E+03, -.20648500E+04, -.75323000E+04, 0.54607300E+04, 0.37887100E+04, 0.21296700E+04, -.76266500E+04, 0.53669100E+04, -.18651400E+04, 0.83079300E+03, -.22653900E+04, 0.93048200E+03, 0.68863700E+04, 0.17237400E+05, -.65602600E+04, -.37076300E+04, 0.44566700E+03, 0.16874800E+05, -.95305400E+04, -.24072100E+05, 0.11965500E+05, 0.16029700E+05, 0.12039100E+05, 0.46136300E+03, 0.47864100E+04, 0.30992500E+04, 0.23153200E+04, 0.10045700E+05, 0.48990900E+04, 0.70557500E+04, -.19793300E+04, -.71503800E+03, 0.56846500E+03, -.72306400E+03, 0.59011400E+03, -.64944100E+03, 0.81390800E+03, 0.35402300E+03, 0.10106200E+04, 0.78924400E+03, 0.63477700E+03, 0.37786600E+02, 0.85257100E+04, -.20219500E+04, -.34456000E+04, 0.94351600E+03, 0.69060900E+04, 0.23704500E+04, 0.62498700E+04, 0.36575500E+04, 0.46614500E+04, -.56682200E+03, 0.75549100E+04, 0.11266300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.49362400E+01, 0.82347500E+00, 0.21920800E+00, -.37206200E-01, -.24497100E+01, -.18072100E+00, 0.66083200E+00, 0.58920600E+00, -.70709900E+00, 0.49509800E+00, -.13420500E+00, -.65574800E+00, 0.14873000E+01, 0.63191300E+00, -.10637200E+01, 0.13965500E+00, 0.11600600E+00, -.14480700E+00, 0.57015000E-01, 0.65501100E-01, 0.10665000E+00, 0.11180400E+00, 0.39303100E+01, -.90172500E+00, 0.68827500E-01, 0.27040100E+00, -.24737300E+00, 0.41489900E+00, 0.85325700E+00, 0.21318000E+01, -.15415300E+00, -.17729300E+00, -.14071600E+00, 0.15571800E+00, 0.19766300E+00, -.34212200E-01, 0.46699000E-01, 0.73266400E+00, -.51382900E+00, -.20097400E+00, -.86549000E+00, -.74291400E+00, 0.13890600E+00, -.31928100E+00, 0.71703300E+00, 0.73604600E+00, -.12536900E+01, 0.67306300E+00, 0.14276400E+00, -.21192400E+00, -.13755600E+01, -.24258100E+00, -.89310400E-01, -.34507200E+00, -.13929200E+00, -.30728600E+00, 0.51223400E-01, 0.58827400E-01, 0.14930000E-04, -.20511600E+00, 0.45601900E+00, 0.90639500E-01, 0.19715600E-01, -.50422500E+00, 0.30610200E+01, 0.65647700E+00, -.11846200E+01, 0.71892800E+00, -.92988900E+00, -.24571300E-03, -.37438100E+00, -.32095200E+00, -.10989300E+01, -.25345900E+00, -.81427400E-01, 0.13269600E+00, -.43772500E+04, -.31929400E+04, 0.15590000E+04, -.34845800E+03, 0.15964700E+04, -.86276200E+03, -.18799100E+04, 0.23759900E+04, 0.27597400E+04, 0.26955300E+04, -.10954800E+04, 0.75887300E+04, -.14791800E+05, 0.74855100E+04, 0.31285900E+04, 0.73946700E+04, 0.20717800E+04, 0.85675000E+03, 0.21290800E+04, -.58433700E+04, 0.11020600E+03, 0.51354900E+03, 0.38415900E+04, 0.17497600E+04, -.84422600E+03, 0.53863000E+02, -.87635100E+03, 0.37072800E+01, 0.20470600E+03, -.77784900E+03, -.13884700E+03, -.66075400E+03, 0.96976700E+02, -.51728200E+02, -.30965700E+04, 0.15794300E+04, -.19007600E+04, 0.15488500E+04, -.40060700E+03, -.35090800E+04, 0.36219500E+04, 0.10590800E+04, -.68051000E+03, -.31873400E+04, 0.87660500E+03, 0.14842000E+05, -.75591000E+04, -.14893200E+04, -.74211100E+04, -.22779300E+04, -.17882600E+04, 0.38765000E+03, 0.11123700E+05, 0.59177400E+03, -.10772400E+04, -.46396800E+04, -.14707000E+05, 0.74735900E+04, 0.75555200E+04, 0.73535800E+04, 0.18124300E+04, 0.27800000E+04, 0.25513700E+04, -.63867600E+04, 0.10632200E+03, 0.29450000E+04, 0.22407200E+04, 0.10584500E+04, -.55640200E+03, 0.13897800E+04, -.53358600E+03, -.20882000E+04, -.20559600E+04, 0.16898500E+04, 0.43420100E+04, 0.32026600E+04, -.70559100E+03, -.60833200E+04, 0.30742800E+04, -.15383300E+04, 0.18537600E+04, -.15395700E+04, 0.25351700E+04, 0.62486200E+04, -.45046600E+04, -.12173100E+04, -.35629700E+04, 0.41285200E+04, 0.17957400E+04, -.84128100E+04, 0.43302000E+04, -.14434400E+04, 0.42063000E+04, 0.30118900E+04, 0.39064100E+03, 0.16253100E+02, -.57129800E+04, 0.38988500E+03, -.39573900E+03, 0.53569400E+04, 0.25020500E+04, -.12546000E+04, -.28210600E+04, -.12516800E+04, -.44662100E+04, -.60724500E+04, 0.28952700E+04, 0.47714200E+04, 0.49630300E+04, -.35706000E+04, -.48492500E+04, -.26938700E+05, 0.13614400E+05, 0.87849300E+04, 0.13469400E+05, 0.25813100E+04, 0.22540000E+04, 0.31653200E+04, -.11271800E+05, 0.27832800E+04, 0.21646800E+04, 0.72040400E+04, 0.11570000E+05, -.58719600E+04, -.32580900E+04, -.57866500E+04, 0.11647100E+04, 0.81709300E+03, -.31457900E+04, 0.24035400E+04, -.12913000E+04, -.10331100E+04, 0.10130600E+05, 0.63361000E+04, -.32308200E+04, -.13544400E+04, -.31671400E+04, -.23306600E+04, -.87989700E+02, 0.38042500E+02, 0.36973200E+04, -.77048200E+03, 0.21326500E+03, -.45390400E+04, -.13318700E+05, 0.67253400E+04, 0.55194000E+04, 0.66593400E+04, 0.15332200E+04, 0.36581400E+03, 0.26379700E+04, -.52238100E+04, -.11608300E+03, 0.51672300E+02, 0.31747300E+04, -.59578500E+04, 0.30023500E+04, 0.30293000E+04, 0.29792200E+04, -.14059200E+03, 0.16945700E+03, 0.61286600E+03, -.26904000E+04, 0.24508200E+03, 0.36062100E+03, -.69288100E+04, 0.16539000E+04, -.78075600E+03, -.64277000E+03, -.82740600E+03, 0.32079400E+03, 0.24407600E+04, -.12837900E+04, -.32740500E+04, -.25538300E+04, 0.26468500E+04, -.20953500E+04, 0.46241400E+03, -.97239200E+02, 0.44094600E+02, -.22603800E+02, -.78075300E+02, 0.83754700E+02, 0.39704300E+02, -.97936000E+02, 0.97388800E+03, -.16848400E+02, 0.60479900E+03, -.74127600E+03, -.97720900E+03, 0.28866400E+04, -.48372400E+03, -.27361800E+03, 0.14894800E+04, 0.78990800E+03, -.25470300E+04, 0.67685500E+03, 0.17679500E+04, -.10286000E+04, 0.59790600E+03, -.89260300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.28793100E+01, 0.58346900E+00, -.46944900E-01, 0.63666800E-01, -.14729200E+01, 0.21534800E+00, 0.35892800E+00, 0.51246000E+00, -.49300900E+00, 0.25217600E+00, -.16786500E+00, -.40461600E+00, 0.19772000E+01, 0.80821900E+00, -.13645300E+01, 0.19117400E+00, 0.35272000E+00, 0.50957900E+00, -.19469800E+00, 0.22640100E-01, 0.63084600E+00, 0.19359200E+01, 0.13421500E+01, 0.11377000E+00, 0.65560700E-01, -.21971000E+00, 0.15216400E-01, -.48814500E-01, -.15001400E+00, 0.39217800E+01, -.42451600E+00, -.46414300E+00, 0.10842000E+01, -.79071000E+00, -.55829800E-01, -.13556900E+01, -.25264800E-01, 0.30040200E+00, 0.11199600E+01, 0.12678200E+00, 0.44950700E+00, -.10633000E+01, -.18743600E+01, 0.72622600E-01, 0.27604500E+00, -.66131600E+00, -.43934700E+00, -.73483600E+00, -.58386200E+00, -.14633300E+01, 0.19276000E+01, 0.15418600E+01, 0.30991100E+00, 0.24277200E+00, -.59561400E+00, -.40019700E-01, -.23665800E+00, -.46797500E+00, 0.30509700E-02, 0.31879800E+00, -.20333900E+00, -.35093800E-01, 0.23113900E-01, -.23844500E+00, -.50119700E+00, -.64360300E-01, -.26551000E+00, 0.59152400E+00, -.26859400E+00, 0.35456700E-02, -.23018600E+00, 0.20315000E+00, 0.25538400E+00, -.43543400E+00, 0.14531000E-01, 0.16088700E+00, 0.10801700E+00, -.82639800E+04, 0.41128300E+04, -.21825900E+03, 0.41319800E+04, 0.13828400E+04, 0.16849500E+03, 0.19882100E+04, 0.18842300E+04, 0.45441300E+04, 0.18485800E+03, 0.44236200E+04, -.76990700E+04, 0.38930700E+04, -.18092300E+04, 0.38483300E+04, 0.25823500E+03, 0.13837300E+04, -.21253200E+03, -.39538200E+04, 0.18673200E+04, 0.10060700E+04, 0.90729100E+03, 0.21084400E+04, -.10426700E+04, -.68201400E+03, -.10461000E+04, -.22785800E+03, 0.17043900E+02, -.68984100E+03, -.62403800E+02, -.67597000E+03, -.93125900E+02, -.41910800E+03, -.22933200E+04, 0.11710800E+04, -.18912000E+04, 0.11472200E+04, 0.36701000E+03, 0.14978000E+04, -.95091400E+03, -.29939900E+04, 0.15965500E+03, 0.15157900E+04, -.19799000E+03, -.11109300E+05, 0.54661300E+04, 0.29246000E+04, 0.55545500E+04, -.78044600E+03, -.40599200E+04, 0.57376300E+04, 0.48754500E+04, 0.56870500E+04, -.21446900E+04, 0.98273700E+04, -.33965400E+04, 0.17695900E+04, 0.16378300E+04, 0.16983400E+04, 0.13784400E+04, 0.40020700E+04, -.15498500E+04, -.45177800E+04, -.74852600E+03, 0.36231300E+04, -.41937700E+04, 0.97292800E+03, -.50801600E+03, 0.53216100E+03, -.49141200E+03, -.36138500E+03, -.10351700E+04, 0.12761300E+04, 0.29310300E+04, 0.11192500E+04, -.57430500E+03, -.46876900E+03, 0.30245800E+04, -.15228200E+04, 0.15219200E+04, -.15147100E+04, 0.29858200E+02, -.94911600E+03, -.65298300E+03, 0.15344900E+04, -.25291200E+04, -.15506100E+04, 0.34265300E+03, 0.14641400E+04, -.64998700E+03, -.25039300E+04, -.73220700E+03, 0.20589100E+04, 0.39710200E+04, -.44890000E+04, -.53780800E+04, -.20783500E+04, 0.21418000E+04, -.14655700E+04, -.49286300E+03, 0.24717100E+03, -.15513400E+04, 0.24578500E+03, -.53819600E+03, 0.50733700E+03, -.22128400E+02, 0.41638000E+03, 0.28411200E+04, 0.11378600E+04, 0.91851700E+02, 0.26024100E+04, -.12119900E+04, -.23642100E+04, -.13011400E+04, 0.10965800E+04, 0.49701900E+04, -.40388500E+04, -.49422800E+04, -.25772000E+04, 0.34553600E+04, -.76576100E+04, 0.92822200E+04, -.46679700E+04, -.42901500E+04, -.46427300E+04, 0.28777700E+04, 0.71551600E+04, -.59647700E+04, -.15853300E+04, -.16573700E+04, 0.43540400E+04, -.94144800E+03, 0.33247600E+04, -.17073500E+04, 0.25293800E+04, -.16614500E+04, -.15972600E+04, -.26705800E+04, 0.21356500E+04, 0.36703500E+04, -.28566400E+03, -.17058700E+04, -.58964700E+03, -.39349600E+04, 0.20072000E+04, -.98388400E+02, 0.19674500E+04, 0.16848600E+03, 0.12773700E+04, -.19933900E+03, -.33266000E+04, 0.20016000E+03, 0.86992200E+03, -.24172400E+04, 0.26687400E+04, -.13236400E+04, 0.22744300E+04, -.13340700E+04, -.23403400E+04, -.28347500E+04, 0.54262600E+03, -.99743300E+03, -.30413700E+04, -.14572600E+04, -.23872200E+04, -.14578400E+04, 0.74795000E+03, 0.18728700E+04, 0.72848400E+03, 0.46221900E+03, -.51223100E+03, 0.18996100E+04, 0.72791900E+03, -.48596100E+03, -.29633300E+03, -.26707300E+03, 0.34056900E+03, 0.13763400E+02, -.11330600E+03, 0.14148100E+00, 0.13348100E+03, 0.90459400E+02, -.27349100E+02, 0.78640600E+02, -.10863700E+03, -.92126800E+02, 0.13647800E+03, -.18285000E+03, -.26526800E+04, 0.19151100E+04, 0.33570100E+03, 0.29568200E+02, -.93403800E+03, 0.38841100E+02, -.30516700E+04, -.11274900E+03, -.95820600E+03, -.13825200E+03, -.12060800E+04, -.55461200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13714800E+01, -.15314200E+00, -.50438800E+00, 0.63285200E+00, 0.58077000E+00, 0.57726000E+00, -.13023200E+00, -.15164300E+00, 0.41707100E+00, 0.93862500E-01, 0.91657800E+00, 0.22345600E+00, -.46481400E-01, -.23362600E+00, -.59331500E-01, -.21979000E+00, -.62735600E-02, -.50926600E+00, -.27391100E+00, 0.98007900E+00, -.98065200E+00, -.25745700E+00, 0.47198200E+00, -.56675300E+00, -.49320200E-02, 0.87968300E-02, -.23492000E+00, 0.33108200E-01, -.19246000E+00, -.11315000E+01, -.30973100E-01, -.51054900E-01, -.74019100E+00, 0.26504100E+00, 0.87834900E-02, -.27747300E+00, -.49303800E-01, 0.25287300E+00, 0.20383300E-01, -.14930900E+00, -.18972700E+00, 0.92242900E-01, 0.29262200E+00, -.93681200E-01, 0.33857000E+00, 0.19247900E+00, -.65503200E-01, -.30894600E+00, -.59531300E-01, 0.60525600E-01, -.15096500E+00, -.59328200E-01, -.11186400E+00, 0.13275200E-01, -.12011900E-01, 0.31377400E+00, -.28038100E+00, 0.49912400E+00, 0.17565100E-02, -.53664800E+00, -.18495600E+00, 0.56983400E+00, -.18182900E+00, 0.23307500E+00, 0.31389100E+00, 0.18251400E-01, 0.47786500E-01, -.54077700E+00, 0.49619800E+00, 0.50989400E-02, -.21908400E+00, -.12497500E+00, 0.42333700E+00, -.24480000E+00, 0.32766000E+00, -.97812600E-01, 0.17111600E+00, -.48864600E+00, 0.13675600E+02, -.54516700E+03, -.87356100E-02, 0.73699600E+03, 0.20627500E+04, -.10376200E+04, -.91032100E+03, -.38581400E+03, 0.17713200E+04, -.48885400E+03, -.10590900E+04, 0.50475000E+03, -.17101100E+04, 0.53007400E+03, -.64178800E+03, -.65974300E+03, 0.31960500E+03, 0.10266500E+04, 0.17867700E+04, -.77544400E+03, 0.17656100E+04, -.33367600E+03, 0.13734700E+03, 0.21069400E+03, 0.16942900E+03, 0.83780900E+02, 0.47260800E+02, -.73965600E+02, -.44941200E+02, 0.83988600E+02, -.84618200E+01, 0.16183900E+03, -.22435200E+04, 0.11553600E+04, 0.41101300E+03, 0.11215100E+04, 0.61702600E+03, 0.16978700E+04, -.27634000E+03, 0.83958400E+02, 0.41888100E+03, 0.14619000E+04, 0.54597100E+03, -.21794100E+05, 0.10848100E+05, 0.75862900E+04, 0.10897100E+05, 0.22087200E+04, 0.87479000E+02, 0.43852900E+04, -.19396100E+04, 0.65076400E+04, 0.10016800E+04, 0.90306900E+04, 0.34932200E+04, -.17251600E+04, -.18161700E+04, -.17466400E+04, -.16639100E+03, 0.36261000E+03, -.13027100E+04, -.73507700E+03, -.10752800E+04, -.84880000E+02, -.17918700E+04, -.83765800E+03, 0.39455000E+03, -.35677100E+03, 0.41930000E+03, 0.39075000E+03, -.40746700E+03, 0.51827500E+02, -.43790800E+03, -.21695200E+03, -.34148700E+03, 0.41155400E+03, 0.15760800E+04, -.82708100E+03, 0.74271900E+03, -.78698500E+03, -.61848700E+03, -.18171700E+04, 0.89138000E+03, 0.10550500E+04, 0.23127600E+03, -.15557900E+04, -.81797600E+03, 0.12484900E+05, -.61891700E+04, -.63477100E+04, -.62424100E+04, -.15810700E+04, 0.34865400E+01, -.22495600E+04, 0.29223700E+04, -.22877800E+04, -.57352500E+03, -.47408100E+04, -.26510600E+04, 0.13354800E+04, -.10808900E+03, 0.13258200E+04, 0.10841000E+04, 0.14979400E+04, -.11234900E+04, -.13434200E+04, -.47924100E+03, 0.10389100E+04, 0.93495600E+03, 0.16355900E+05, -.81378100E+04, -.65518800E+04, -.81779600E+04, -.14568300E+04, 0.73583900E+03, -.39540100E+04, 0.58391500E+03, -.51618900E+04, -.28704300E+03, -.69416700E+04, 0.27590500E+04, -.12836000E+04, -.50122700E+04, -.13788100E+04, 0.36689500E+03, 0.32200600E+04, -.19760100E+04, -.19123200E+03, -.14278300E+04, 0.24186600E+04, -.26298400E+04, -.50577500E+04, 0.24934600E+04, 0.48805700E+04, 0.25284900E+04, 0.60020900E+03, -.42543600E+03, 0.13399900E+04, -.95266300E+03, 0.65439000E+03, -.67568100E+02, 0.21570700E+04, 0.21438000E+04, -.10577100E+04, -.22768600E+04, -.10718900E+04, -.54788800E+03, -.10446700E+03, -.40862300E+03, 0.44537500E+03, 0.26704900E+03, -.39713700E+03, -.67884600E+03, -.34777800E+04, 0.17198200E+04, 0.33428500E+04, 0.17387700E+04, -.60767800E+03, -.27713100E+04, 0.24329200E+04, 0.16614100E+04, 0.19036900E+04, -.21990400E+04, 0.23713000E+04, 0.19437000E+04, -.10008500E+04, 0.17783100E+02, -.97164400E+03, -.32408700E+03, -.10098800E+04, 0.26125900E+03, 0.76785500E+02, -.64078400E+01, -.84134800E+03, -.12214900E+03, 0.23027800E+03, -.20290500E+02, -.39798900E+02, -.45077600E+02, 0.94462500E+02, -.36853900E+02, 0.40324600E+02, 0.10081000E+03, -.41088500E+03, -.19831700E+03, -.12324800E+00, 0.84512200E+02, -.10818700E+03, 0.10972700E+03, 0.52298300E+02, -.67602900E+02, -.35487600E+03, -.18124300E+02, -.22613600E+03, -.28945500E+03, -.35124700E+03, 0.47220400E+03, -.56943700E+03, 0.23790900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.33959600E+01, 0.13856200E+01, -.20030200E+01, 0.66193000E+00, -.26608200E+01, 0.31199100E+00, 0.46460200E+00, -.12458100E+01, -.15334400E-01, 0.51129600E+00, -.63319100E+00, -.78120500E+00, -.81882200E+00, -.26387400E+01, -.19040300E-01, 0.13842200E+00, -.15410300E+01, -.14343900E+01, 0.63583200E+00, 0.22281100E+00, -.15445100E+01, 0.22178200E+01, 0.40975900E+01, -.19768200E+01, -.45806800E+00, -.20195400E+00, 0.22203700E+00, 0.58345700E+00, 0.76077300E+00, -.77012200E+00, 0.43687500E+00, 0.16582200E+00, 0.73141000E+00, 0.50850900E+00, -.34292100E-01, -.12975800E+01, -.10465700E+00, -.54338100E+00, -.13403300E+01, -.88063100E+00, -.13883600E+01, 0.54507900E+00, 0.12987700E+01, -.37723200E+00, 0.31903100E+00, 0.27584200E+00, -.54348700E+00, -.76332100E+00, -.46263200E+00, 0.56162700E+00, 0.13329000E+01, 0.12644700E+00, 0.18503400E+00, -.38311500E+00, 0.44683700E+00, 0.95071300E+00, 0.13298700E+00, 0.19544500E+01, -.15247300E-02, -.73613500E+00, -.25555200E+00, -.44912000E-01, 0.23514700E+00, -.62931200E+00, 0.23182300E+01, -.38724800E+00, -.13906900E+01, 0.41971600E+00, -.30353400E-01, -.25291700E-02, -.12401900E+00, 0.24892700E+00, -.11001200E+00, -.20448200E+00, -.64129200E+00, 0.16016400E+00, 0.78256800E+00, -.31596500E+00, 0.30138400E+00, -.34443800E+04, -.82156400E-02, -.11433300E+04, -.37683000E+03, -.44749400E+02, -.51006400E+03, 0.18268300E+03, -.16454800E+03, 0.79344500E+03, -.55520600E+04, 0.28197600E+04, 0.68911000E+03, 0.27750300E+04, 0.39776800E+03, 0.61249400E+03, 0.38273400E+03, -.22366900E+04, 0.10122600E+04, 0.13229500E+04, 0.10386500E+04, -.68175300E+03, 0.36389700E+03, -.71261000E+03, 0.34183900E+03, -.14350200E+03, -.28148900E+03, 0.24193500E+03, -.10143300E+03, 0.99368400E+02, -.32809500E+03, 0.75685100E+03, 0.20309200E+04, -.10364200E+04, -.69903600E+03, -.10149900E+04, -.66523400E+03, -.16329600E+03, -.12973600E+04, -.14466500E+04, -.64458200E+03, -.34567000E+03, -.62224100E+03, 0.74493000E+04, -.36828900E+04, -.41792600E+04, -.37247200E+04, 0.15622400E+03, 0.83225900E+02, -.13365600E+04, 0.19205900E+04, -.29906300E+04, -.10595600E+04, -.19363800E+04, -.12897600E+04, 0.64019000E+03, 0.72381900E+03, 0.64494000E+03, -.76335400E+03, -.26818000E+03, 0.10724200E+04, 0.36969400E+03, 0.76901200E+03, 0.15515400E+03, -.46140800E+03, -.33136900E+03, 0.18685000E+03, 0.28176100E+03, 0.16335400E+03, 0.20042300E+03, -.83738000E+01, 0.37217600E+03, 0.97492000E+03, -.37822000E+02, 0.32640400E+03, -.19495100E+04, -.34551300E+03, 0.20953500E+03, 0.79312200E+03, 0.17074700E+03, 0.48987800E+03, 0.40470300E+03, 0.44621400E+03, 0.13732300E+03, -.96367100E+03, 0.31018400E+03, 0.82538500E+03, -.13744800E+05, 0.68084600E+04, 0.72386800E+04, 0.68723100E+04, 0.74878600E+03, 0.16464500E+04, 0.53234900E+03, -.55003500E+04, 0.23633400E+04, 0.19437300E+04, 0.64773800E+04, 0.26218000E+04, -.13195400E+04, -.17566200E+04, -.13114400E+04, -.72285500E+03, -.64140900E+03, -.13007900E+04, -.46310800E+02, -.53142100E+03, -.42925200E+03, -.12462100E+04, -.77722000E+04, 0.38641000E+04, 0.18666300E+04, 0.38861600E+04, -.73833100E+03, -.19100800E+03, 0.20055700E+04, -.97583400E+03, 0.31696400E+04, 0.90702500E+03, 0.97448600E+03, 0.20410300E+04, -.11036000E+04, 0.28198400E+04, -.10218700E+04, -.28246200E+03, 0.67944700E+03, -.16179700E+04, -.14075700E+04, -.40666300E+03, -.11344700E+04, 0.41414900E+04, 0.94402200E+04, -.46706800E+04, -.25437600E+04, -.47193500E+04, -.29442700E+03, -.14046900E+04, -.84728700E+02, 0.34033700E+04, -.20901300E+04, -.12357900E+04, -.49484300E+04, -.19210900E+04, 0.96047200E+03, 0.39619300E+03, 0.96051800E+03, 0.16750600E+02, -.18127800E+03, 0.56865700E+03, -.50897700E+03, 0.77948200E+03, 0.32609500E+02, 0.10257500E+03, 0.49941400E+04, -.24944000E+04, 0.30035500E+04, -.24968200E+04, 0.17159300E+04, 0.10296400E+04, -.11320600E+04, 0.77682700E+03, -.24701500E+04, 0.15444500E+04, -.53222800E+04, -.25905700E+04, 0.13204800E+04, 0.13201100E+04, 0.12949200E+04, 0.55853600E+03, 0.83230300E+03, 0.56473000E+03, -.47377900E+03, 0.26884900E+03, 0.15188500E+04, 0.33642200E+03, -.13187800E+03, -.24305800E+02, 0.30984300E+02, -.10630400E+03, 0.35245000E+02, -.88690900E+02, 0.20094100E+02, -.58364500E+02, 0.20936500E+03, 0.36559200E+02, -.59560600E+03, 0.30784900E+02, -.10311900E+03, -.58675600E+03, -.32570800E+03, 0.17557000E+03, -.10709600E+03, 0.37804200E+03, 0.36937300E+03, 0.38706000E+03, -.13316200E+03, 0.27156200E+03, 0.48841000E+03, -.31001500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.53047100E+01, -.16611500E+01, -.83539700E+00, 0.30772200E+01, 0.35585100E+01, -.85154500E+00, -.58711700E+00, 0.43375000E+00, -.13710600E+00, -.54620200E+00, 0.98481100E+00, 0.11281900E+01, -.15824000E+01, 0.35649100E+01, -.74748400E+00, -.19486200E+00, 0.16670100E+01, 0.97009600E+00, -.65137500E+00, -.52565900E+00, 0.14166100E+01, -.99043800E+00, -.14472000E+00, -.39739700E+00, 0.64417100E-01, 0.14476000E+01, 0.12400600E+00, 0.37219700E+00, 0.23135000E+00, 0.23419100E+01, -.42831800E+00, 0.45370600E-01, -.78171800E+00, -.81222600E+00, -.32525900E-01, 0.11265400E-01, -.75784500E-01, 0.73884700E+00, 0.43543400E+00, 0.63911700E+00, 0.13110300E+01, -.96903600E+00, 0.11357300E+01, 0.14971900E+00, -.41909700E+00, -.40185200E-01, -.92068200E+00, -.64610900E+00, -.30709000E+00, -.40999700E+00, 0.94678500E+00, 0.15140700E+01, 0.18435700E+00, 0.17129000E+00, -.10010600E+01, -.14831700E+01, 0.38310400E+00, -.21846900E+01, 0.11458900E-01, 0.20016800E+01, 0.39128400E+00, -.19598200E+00, -.15048700E+00, -.64599400E+00, -.16386500E+01, -.94209800E+00, 0.20936300E+00, 0.10901700E+00, -.92520400E-01, 0.25523100E-01, -.45712300E+00, 0.16658100E+00, 0.24744900E+00, 0.25795700E+00, 0.12963100E+01, -.16587600E+00, -.46465900E+00, 0.13564400E+00, 0.83684600E+00, -.37450400E+00, 0.79306200E+01, 0.13331900E+03, -.26611000E+04, 0.13348000E+04, 0.16774600E+04, 0.12087800E+04, -.22597800E+04, 0.16454200E+04, -.16536500E+04, 0.83174300E+03, 0.16576000E+03, 0.82729300E+03, 0.61433300E+03, 0.10978400E+04, -.43264000E+03, -.28183300E+04, -.13668800E+04, 0.59366900E+03, -.23759400E+03, 0.29381200E+03, -.16574200E+03, -.10091600E+03, -.13760400E+03, -.64089600E+02, -.16026600E+03, 0.84522500E+02, 0.16782000E+03, -.14925000E+03, -.96001400E+02, -.12785400E+03, 0.21394400E+04, -.10309600E+04, -.27279500E+04, -.10699400E+04, -.10458200E+04, -.18347400E+04, 0.15672800E+03, -.16090200E+04, -.68206500E+03, -.18862700E+04, 0.58614600E+03, 0.22003700E+05, -.11084900E+05, -.31532200E+04, -.11001800E+05, -.31392000E+04, 0.76242000E+03, -.47408800E+04, 0.39862500E+04, -.43256400E+04, -.22008300E+03, -.70892100E+04, -.76705300E+04, 0.38886000E+04, 0.25297400E+04, 0.38352400E+04, 0.70167800E+03, 0.64066200E+03, 0.14280900E+04, -.14463200E+04, 0.11840600E+04, 0.12213000E+04, 0.11124100E+04, 0.68421900E+03, -.37605800E+03, 0.13247800E+04, -.33704000E+03, 0.15143600E+03, 0.46750200E+03, 0.68654400E+03, 0.14867200E+04, 0.62628400E+03, 0.61622400E+03, -.75354300E+03, 0.37485800E+03, -.22186200E+03, 0.17795200E+03, -.18650000E+03, 0.93941400E+03, 0.18932600E+04, -.19663200E+04, -.46803800E+03, -.14116100E+04, 0.15644100E+04, -.19231400E+03, -.11159800E+05, 0.56678200E+04, 0.10300200E+04, 0.55799100E+04, 0.24680900E+04, -.15619200E+04, 0.22240900E+04, -.49823100E+04, 0.65968000E+03, -.10230900E+04, 0.32914900E+04, 0.12160500E+04, -.60071600E+03, -.41784100E+03, -.60777100E+03, -.12173800E+04, -.21234300E+04, 0.31131300E+04, 0.17077500E+04, 0.18051100E+04, -.10164000E+04, -.39140800E+03, -.19113600E+05, 0.96334200E+04, 0.42650200E+04, 0.95567600E+04, 0.22723400E+04, -.13253600E+04, 0.45722800E+04, -.28046700E+04, 0.41722600E+04, -.70583600E+02, 0.53314400E+04, 0.52008300E+04, -.25389200E+04, 0.98917100E+02, -.25997800E+04, 0.63576700E+03, -.37132500E+04, 0.55483400E+03, -.19442100E+03, -.69128400E+03, -.27364900E+04, 0.58439600E+03, 0.47382900E+04, -.24213400E+04, -.34846300E+04, -.23694800E+04, -.59294700E+03, 0.19071500E+04, -.17590800E+04, 0.18977800E+04, -.20101100E+02, 0.15009000E+04, -.14303900E+04, -.55814700E+04, 0.28247200E+04, 0.31451800E+04, 0.27907500E+04, 0.59289900E+03, 0.29625800E+03, 0.77770600E+03, -.18909500E+04, 0.17704100E+03, 0.51579500E+03, 0.17490400E+04, -.30559600E+04, 0.15157900E+04, -.20744900E+03, 0.15278800E+04, -.91711700E+03, 0.32623100E+04, -.18440500E+04, -.37041600E+04, -.89220400E+03, 0.25048900E+04, -.36073500E+03, -.36807900E+04, 0.18274900E+04, 0.17138700E+04, 0.18405800E+04, 0.67033800E+03, 0.14153300E+04, -.32098100E+03, 0.46998100E+03, 0.57871200E+03, 0.12102200E+04, 0.28401100E+02, 0.15728700E+02, 0.22523400E+02, -.78597600E+02, 0.67754300E+02, -.41148900E+02, 0.98925300E+02, -.42923700E+02, -.70314000E+02, 0.48317400E+03, 0.42083200E+02, 0.25697200E+01, -.29440900E+03, 0.24540200E+02, 0.61611700E+03, 0.34312000E+03, -.77458000E+01, 0.13698800E+04, -.10099200E+03, -.38799500E+03, 0.76813000E+03, 0.15739300E+04, -.46167700E+03, 0.79936100E+03, -.73339800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15762400E+01, 0.25395600E+00, -.31016100E-01, -.27381400E+00, -.67457300E+00, -.44565900E+00, 0.15500700E+00, 0.22979100E+00, -.32856400E+00, -.74131600E-02, -.43035800E+00, -.25061600E+00, 0.10030500E+01, 0.28791500E+00, -.36150600E+00, 0.59653700E-01, 0.53660800E-01, 0.12129900E+00, 0.21542600E+00, -.42014000E+00, 0.21028300E+00, -.46787300E+00, -.14563000E+00, 0.29461400E+00, 0.53177000E-01, 0.19522300E+00, -.28119400E+00, -.14566600E+00, 0.73226100E-01, 0.20920000E+00, 0.68917500E-01, -.52358800E-01, 0.11191800E-01, 0.49473300E-01, 0.72205200E-01, 0.26081200E+00, -.59505000E-01, 0.35642000E+00, -.85997200E-01, 0.78398200E-01, 0.91650100E-01, -.22691600E+00, 0.11156100E+01, -.15246400E+00, -.21539900E-01, 0.47466700E+00, -.10894900E+00, -.22519200E+00, -.59096000E-01, 0.10960600E+00, 0.15540500E+00, 0.34350200E+00, 0.41501900E-01, -.37878200E-01, -.13599100E-01, -.38174000E+00, 0.11582800E+00, -.77897700E+00, 0.19212200E-02, 0.50416000E+00, 0.36070400E+00, 0.13048700E+00, -.51982600E-01, 0.14773100E+00, -.39598900E-02, 0.31104700E+00, 0.27957900E+00, 0.54034200E+00, -.89434100E-01, 0.35662400E-02, -.48782700E-01, -.32792900E-01, 0.14762200E+00, -.60421300E-01, 0.48902200E+00, -.12328400E+00, -.33648800E+00, -.19079600E+00, -.22777900E+00, 0.29368500E+00, 0.62159100E-03, 0.85608000E+03, -.11709300E+03, 0.51251300E+02, 0.76137700E+03, 0.77190900E+03, -.61835400E+02, 0.17077200E+04, -.18595400E+04, 0.91213800E+03, -.96336500E+03, 0.93061000E+03, 0.52863300E+03, 0.74398300E+03, -.12009100E+03, -.13846700E+04, -.16602600E+03, 0.19083500E+03, -.60430800E+03, 0.63051100E+03, -.33336100E+03, 0.18965500E+03, -.31220100E+03, 0.50476900E+02, 0.33768900E+03, -.40964000E+03, -.88028700E+02, -.28597000E+03, 0.30649500E+03, -.15229100E+03, 0.57372600E+03, -.25755400E+03, -.17295800E+04, -.28725300E+03, 0.53498300E+03, 0.62919300E+03, -.51214000E+03, -.98612000E+03, -.12830400E+04, 0.62089400E+03, -.47442500E+03, 0.19527600E+04, -.10422300E+04, -.11755100E+03, -.97632100E+03, -.85924400E+03, -.10784700E+04, 0.69012300E+03, 0.29315200E+04, 0.15769400E+04, -.50028800E+03, 0.27956700E+04, -.35145000E+04, 0.17906000E+04, 0.13516900E+04, 0.17572000E+04, 0.47549200E+03, 0.13202200E+04, -.17260100E+03, -.24330900E+04, -.57005900E+03, 0.12134100E+04, -.59129800E+03, 0.69280100E+03, -.37340600E+03, -.13472000E+03, -.34482200E+03, -.49493600E+03, -.72841600E+03, 0.74513900E+03, 0.13551400E+04, 0.67247800E+03, -.83758600E+02, -.50275700E+03, 0.91975600E+03, -.49357800E+03, 0.10670600E+04, -.45819800E+03, 0.26480500E+03, 0.30504600E+03, -.97525500E+03, 0.23289900E+03, -.39554800E+03, -.42322400E+03, -.11299900E+03, 0.70563000E+03, -.27462900E+03, -.26327900E+04, -.35273300E+03, 0.10767900E+04, 0.21208200E+03, -.40643800E+03, -.10362000E+04, 0.95775000E+02, -.10108100E+03, -.33700200E+04, 0.11108400E+04, -.54860300E+03, -.15622100E+04, -.55497000E+03, -.51851700E+03, -.35913300E+03, 0.44350500E+03, 0.27259800E+03, 0.22180100E+03, 0.82527200E+03, -.48129600E+03, -.40113200E+04, 0.20601800E+04, 0.11241700E+04, 0.20056100E+04, 0.97094500E+03, 0.14068700E+04, -.50075200E+03, -.32776200E+04, -.10817900E+04, 0.10303300E+04, -.18600100E+04, 0.17453500E+04, -.80224000E+03, -.36391600E+04, -.87153900E+03, 0.12459100E+04, 0.71970800E+03, -.65073800E+03, 0.78402500E+03, 0.44266300E+03, 0.69276200E+03, -.70385100E+03, 0.88047400E+03, -.49245900E+03, 0.10486500E+04, -.44087300E+03, -.65010000E+03, 0.46923700E+02, -.22123600E+03, 0.46105400E+03, -.49770100E+03, 0.55428100E+02, 0.10146100E+04, -.32537800E+04, 0.16458900E+04, 0.56822800E+03, 0.16269100E+04, 0.15086300E+03, 0.22062300E+03, 0.46894600E+03, -.17285400E+04, -.18728300E+03, 0.43944800E+02, -.18297600E+03, -.13546300E+04, 0.66821100E+03, 0.49371600E+03, 0.67710500E+03, -.13099300E+04, -.43914100E+03, -.23014600E+02, -.19881700E+04, -.55276000E+03, -.37753700E+03, -.45932600E+03, -.50964800E+03, 0.23748800E+03, 0.11602200E+04, 0.25513500E+03, -.33200800E+03, -.42787400E+03, 0.69009000E+03, 0.52750600E+03, 0.38339900E+03, -.74616300E+03, 0.61799300E+03, 0.13999700E+03, -.59076900E+02, -.67808000E+02, -.47319800E+02, 0.11202500E+03, 0.38850300E+02, 0.63189100E+02, 0.76839400E+02, 0.53857700E+02, 0.38761600E+02, 0.31633700E+03, -.12030000E+03, -.91713300E+03, 0.13081700E+04, 0.13880200E+03, -.52118600E+02, -.16550900E+03, 0.90965200E+02, -.14321700E+04, -.85991600E+01, 0.12070000E+02, -.40742600E+03, -.19421000E+03, 0.11167600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20875700E+01, -.22822400E+00, -.60558500E+00, 0.49580900E+00, 0.42595800E+00, 0.92196100E+00, -.18022100E+00, 0.27714200E+00, 0.12528600E+00, -.34837800E-01, -.71571100E-01, -.10659600E+01, -.32216400E+01, -.11644800E+01, -.36188100E+00, 0.10729900E-01, 0.83782700E-01, -.44078500E+00, -.61485400E-01, 0.62468000E-01, 0.21570500E+00, -.13970900E+01, -.44178600E+00, -.18058300E+00, 0.46206600E-01, -.22167700E-01, -.51322100E+00, -.10238600E+00, -.34754500E+00, -.24938300E+00, -.18515200E+00, 0.73323700E-01, -.55736600E+00, 0.47599700E+00, -.44073600E-02, 0.26777300E+00, 0.13480100E-01, 0.24360500E+00, -.70081500E+00, 0.50810200E-02, -.16208100E+00, 0.47010300E+00, 0.14440200E+01, 0.13979400E+00, 0.40626800E-01, 0.14973000E+00, -.33176900E+00, 0.49829900E+00, 0.15507600E+00, 0.62672600E+00, -.10259500E+01, -.52256500E+00, -.19545500E+00, -.16358400E+00, 0.18464300E+00, -.56675000E+00, 0.30700500E+00, 0.13885700E+01, -.74506700E-03, 0.76992600E+00, 0.43797600E+00, -.20777800E+00, 0.85923200E-01, -.68031400E-02, 0.10176400E+01, -.17852500E-01, -.36981300E+00, -.88498000E+00, -.16559700E+00, -.18250900E-02, -.39673400E-01, -.31890300E+00, -.33010700E+00, -.14296400E-01, -.20465500E+00, 0.93558000E-02, 0.36308100E+00, 0.45793900E+00, 0.57662200E+00, -.27836100E+00, 0.11336300E-02, -.85308700E+00, -.19684800E+04, 0.77885900E+03, 0.75127200E+03, 0.57068100E+03, -.15662800E+04, 0.15972800E+04, 0.15218500E+03, -.92975800E+02, 0.25779800E+03, -.75047700E+02, 0.47532800E+03, 0.68575100E+03, 0.13171100E+01, -.11417900E+04, -.83108500E+03, 0.96558100E+02, -.43405300E+03, 0.32335700E+03, -.18699000E+03, 0.25197300E+03, -.16226100E+03, 0.35822900E+02, 0.11402600E+03, -.37220700E+02, 0.99469100E+02, -.13310100E+03, 0.20132400E+03, -.65567200E+03, 0.29849800E+04, -.14382600E+04, -.23833800E+04, -.14929800E+04, -.35406000E+03, -.10335600E+04, -.29887800E+03, -.12834600E+04, -.16705700E+04, -.76465900E+03, -.69737600E+03, 0.19363000E+05, -.97826500E+04, -.52470500E+04, -.96814400E+04, -.23462700E+04, 0.39958500E+03, -.37121800E+04, 0.35090000E+04, -.42956500E+04, 0.12597500E+03, -.79079800E+04, -.74921400E+04, 0.38023300E+04, 0.27546000E+04, 0.37460100E+04, 0.57248200E+03, 0.99222800E+03, 0.66824400E+03, -.24623300E+04, 0.10167900E+04, 0.84363900E+03, 0.40388400E+04, 0.11499600E+04, -.61855300E+03, 0.22134300E+03, -.57258100E+03, -.92154900E+02, 0.36336600E+03, 0.22041000E+03, 0.12070100E+04, 0.42273100E+03, 0.53866300E+03, -.34862400E+03, -.16286900E+03, 0.22924300E+02, 0.72144700E+03, 0.83529000E+02, 0.46442900E+03, 0.10847800E+04, -.95065500E+03, 0.22473500E+03, 0.51504300E+02, 0.66329700E+03, -.43008900E+03, -.45561100E+04, 0.23954500E+04, -.37324400E+03, 0.22781800E+04, 0.14138300E+04, -.18067400E+04, 0.19766900E+04, -.89799200E+03, 0.17579500E+04, -.13621800E+04, 0.74216100E+02, 0.85825700E+03, -.41565700E+03, -.36064200E+03, -.42856800E+03, -.39304800E+03, -.67910600E+03, 0.11634200E+04, 0.43400900E+03, 0.25181900E+03, 0.27013200E+03, -.22609000E+03, -.20326100E+05, 0.10247700E+05, 0.66684700E+04, 0.10163000E+05, 0.19990200E+04, -.12650700E+03, 0.33535100E+04, -.44807500E+04, 0.43439900E+04, 0.23790100E+02, 0.92099400E+04, 0.85874700E+03, -.32669400E+03, -.95835700E+03, -.42796400E+03, 0.16873800E+03, -.32118300E+04, 0.13621500E+04, 0.91190700E+03, 0.58121500E+03, -.17723100E+04, -.69703300E+03, 0.18181500E+04, -.98519800E+03, -.97657200E+03, -.90988000E+03, -.30884200E+03, 0.16228300E+04, -.14617600E+04, -.38753700E+02, -.88625900E+03, 0.13239100E+04, -.33258300E+03, -.47261800E+04, 0.23968400E+04, 0.23648500E+04, 0.23631200E+04, 0.20639000E+03, -.62733800E+02, 0.83298200E+03, -.15674300E+04, 0.37993400E+03, -.11137700E+03, 0.26690200E+04, -.11740500E+04, 0.57678100E+03, -.20331800E+03, 0.58676100E+03, -.55156300E+03, 0.23102700E+04, -.16784900E+04, -.30668700E+04, -.64919200E+03, 0.14981800E+04, -.20297000E+03, -.23251900E+04, 0.11371600E+04, 0.82785300E+03, 0.11629700E+04, 0.17047800E+03, 0.44054900E+03, 0.41113500E+03, 0.96186100E+03, 0.10771400E+04, -.15876300E+03, 0.98669800E+03, -.53641500E+02, 0.16304900E+02, -.42904500E+02, 0.34059600E+02, 0.29609800E+02, 0.69679900E+02, -.21759300E+02, 0.14989200E+01, 0.45937400E+03, 0.81427000E+02, 0.17701300E+03, -.23214500E+03, 0.18388100E+03, 0.10548500E+04, 0.22899900E+03, 0.52401000E+01, 0.78984200E+03, -.20365100E+01, -.52725400E+03, 0.34725800E+03, 0.94272500E+03, -.41179500E+03, 0.61680500E+03, -.14217600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.90047400E-01, -.26630400E+00, 0.16565500E+00, 0.12619300E+00, -.33957300E-01, 0.34682900E+00, -.27414300E-01, -.84998200E-01, 0.11931200E+00, 0.21363500E+00, 0.55758600E+00, 0.38198800E+00, -.57085200E+00, 0.51893500E+00, -.17100900E+00, 0.29615800E-01, 0.21106600E+00, -.63106700E-01, -.65963000E-01, -.46498100E+00, 0.19233300E+00, -.94532500E+00, 0.10871300E+01, -.65076200E+00, 0.52602800E-01, 0.22524200E+00, 0.19243800E-01, 0.94051900E-01, 0.19039600E+00, 0.12406700E+01, 0.31835500E-01, 0.44789800E-01, 0.97638600E-02, 0.98039900E-01, 0.14526600E-01, 0.67435400E-01, -.62768300E-02, 0.34880800E-01, -.49564200E-03, -.29702800E-01, -.11247100E+00, -.59970700E-01, -.30575500E+00, 0.17020000E-01, -.86765200E-01, 0.10783500E+00, -.93327900E-01, -.33351400E-01, -.34948700E-01, -.63149200E-01, -.31872800E+00, -.56495900E-01, -.16890300E-01, 0.11138200E+00, -.32947400E-01, -.96611500E-01, 0.81516800E-02, 0.27995100E+00, -.39832200E-03, -.10232700E+00, -.16727000E+00, -.14233200E+00, 0.26129100E-01, -.27242000E-01, 0.36636900E-01, 0.91245200E-02, -.58692100E-01, -.20024200E+00, 0.60090100E-02, -.20034700E-02, -.88890700E-01, -.63005900E-01, 0.52679600E-01, 0.21887800E-02, -.10954000E+00, -.25515100E-01, 0.57721900E-03, -.56849900E-01, -.14109800E+00, 0.41750300E-01, 0.15906500E-03, 0.37086900E-01, 0.16423700E-01, -.21164500E+03, -.58012100E+03, -.19103000E+03, 0.10461900E+03, 0.37084800E+03, 0.66418900E+03, -.34111100E+03, -.44262100E+03, -.33188500E+03, -.16365100E+03, -.24728800E+03, 0.49193900E+02, 0.25210200E+03, 0.93997800E+02, -.42135600E+03, 0.18648600E+03, 0.23808400E+03, -.12138700E+03, 0.93888700E+02, -.11684900E+03, 0.35153600E+02, 0.80402900E+02, -.16738100E+03, -.24981600E+02, -.11250800E+03, 0.84237600E+02, -.18572900E+03, 0.61209500E+03, -.30356200E+03, 0.18826700E+03, -.30614400E+03, 0.19604900E+03, -.35366600E+02, -.93154500E+02, 0.36624100E+01, -.41676000E+03, 0.31898600E+02, -.36502800E+03, -.81687000E+03, 0.40458500E+03, -.10710400E+04, 0.40845000E+03, 0.71040500E+02, -.24129000E+03, 0.37487300E+03, 0.23039400E+03, 0.24360200E+03, 0.35820000E+01, 0.43681100E+03, -.14442200E+04, 0.72095300E+03, 0.11942500E+04, 0.72209700E+03, 0.52447300E+03, 0.49034800E+03, 0.10894900E+03, -.18478100E+03, 0.56933500E+03, 0.39216600E+03, 0.20631200E+03, 0.42002200E+02, -.24771500E+02, -.44743400E+03, -.20523300E+02, -.47078300E+02, -.11635400E+03, -.27441200E+02, -.44562400E+02, -.14769400E+03, 0.61652600E+02, -.64938500E+02, -.37816800E+03, 0.18395100E+03, 0.19769900E+03, 0.18950200E+03, 0.55783200E+02, 0.13238100E+03, -.70760600E+02, 0.77168100E+02, 0.35853200E+03, -.92135100E+02, -.65682900E+02, 0.21052400E+04, -.10426100E+04, -.30673700E+03, -.10526000E+04, -.11261500E+03, 0.10865700E+03, -.70020500E+03, -.31169900E+02, -.33176500E+03, -.10059800E+03, -.99373000E+03, 0.25681300E+03, -.12757900E+03, -.20359900E+03, -.12829400E+03, -.39558900E+02, -.18307200E+03, -.75761200E+02, -.15307000E+03, -.56238400E+03, 0.20718200E+03, -.19303600E+03, -.90967800E+03, 0.45516900E+03, 0.15940700E+04, 0.45482700E+03, 0.36084700E+03, 0.55156100E+03, -.24016400E+03, -.56737000E+03, 0.30922100E+03, 0.28429300E+03, 0.10926800E+02, -.33348400E+03, 0.18165700E+03, -.10414400E+04, 0.16702400E+03, -.52536800E+03, -.50369300E+03, -.31637000E+02, -.29429900E+02, 0.10833700E+03, -.81094000E+02, -.28635100E+03, -.87207900E+02, 0.35360400E+02, 0.27761200E+03, 0.43446600E+02, -.47024800E+02, -.13133200E+03, 0.28729100E+03, 0.15786800E+03, -.28938400E+03, -.41241000E+02, 0.93675100E+02, 0.10255100E+03, -.52010500E+02, -.27921900E+03, -.51270200E+02, -.30971500E+02, -.14012700E+03, 0.14821100E+03, 0.21129700E+03, 0.40024500E+03, -.17421700E+03, -.72382600E+02, -.58622600E+02, 0.27955500E+02, 0.16751700E+03, 0.29260000E+02, 0.23254800E+03, 0.12359500E+03, 0.15071600E+03, 0.22300200E+03, 0.16214100E+03, -.20668500E+03, -.44725700E+02, -.31491500E+03, 0.15311700E+03, 0.28994300E+03, 0.15753600E+03, -.98499600E+02, 0.21636300E+02, 0.23836000E+03, 0.24967300E+03, 0.26960900E+03, -.20217700E+03, 0.59975400E+03, -.30955200E+02, -.15250000E+02, 0.10626400E+02, -.15500900E+02, 0.38488400E+02, -.62948200E+01, 0.27584000E+02, 0.25597000E+02, 0.44943800E+02, -.22990500E+01, 0.13260900E+03, -.27557300E+02, -.23706100E+02, 0.20605900E+02, -.68579700E+02, -.21475100E+01, -.17573300E+02, 0.70358400E+02, -.11325700E+03, 0.19095500E+02, -.14241800E+03, 0.66998400E+02, 0.14207100E+03, 0.10843200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.76876500E+01, -.23304200E+01, -.14092900E+01, 0.10003900E+01, 0.47979300E+01, -.26706800E+01, -.66402800E+00, 0.49846400E+01, -.13877500E+01, -.22226000E+01, 0.22743100E+01, 0.47012300E+01, 0.75119100E+01, 0.68101200E+01, 0.12969200E+01, -.66377800E+00, 0.30935200E+01, 0.33976900E+01, 0.31784500E+00, -.17157300E+01, 0.16860500E+01, 0.26832300E+01, -.54320600E+01, 0.12121900E+01, 0.12895900E+00, -.58870300E+00, 0.16378000E+00, -.20023000E+00, 0.33654800E+00, -.45418000E+01, 0.15910000E+01, 0.57698200E+00, 0.76479700E+00, -.14787600E+01, -.56913800E-01, -.60657900E+00, 0.33508500E-01, 0.99803800E+00, 0.26160900E+01, 0.50559500E+00, 0.27157700E+01, -.12138800E+01, -.44130800E+01, -.11270800E+00, -.10840400E+01, 0.15184600E+01, -.28420100E+00, -.47635300E+00, -.57845500E+00, -.88418400E+00, 0.23694000E+01, 0.21705400E+01, 0.21394600E+00, 0.75742800E+00, -.80510600E+00, 0.13761000E+01, -.64836200E+00, 0.19932600E+01, -.76291300E-03, -.28168000E+00, -.52172600E+00, 0.26433000E+01, -.36585900E+00, -.79305600E+00, 0.21274500E+01, -.33009900E+00, 0.75500700E+00, -.15082200E+00, 0.75365700E+00, 0.88695700E-02, 0.88664500E-01, 0.66581600E+00, 0.85313800E-01, -.65389400E+00, 0.83955300E+00, 0.46390800E+00, -.16150700E+00, 0.14171500E+00, -.10194500E+01, 0.75214900E+00, -.44123800E-02, 0.73433200E+00, -.19946400E+01, 0.55663000E+01, 0.24743500E+04, 0.18333800E+04, -.56038300E+03, 0.17776600E+03, -.12717800E+05, 0.63388900E+04, 0.43157900E+04, 0.63564900E+04, 0.21814900E+04, 0.22741700E+04, 0.12892500E+04, -.33147700E+04, 0.39043900E+04, 0.17921600E+04, 0.19725400E+04, 0.32314900E+03, -.22627100E+03, -.54186800E+03, -.17663900E+03, -.14179100E+03, -.34842800E+02, 0.32287200E+03, -.30137000E+03, -.23712200E+03, -.46019700E+01, 0.46313100E+03, -.76571900E+03, 0.51080800E+03, -.42372800E+04, 0.38396100E+03, 0.91966000E+02, 0.33310000E+04, -.22194800E+04, -.36417000E+04, 0.17963300E+04, 0.17959200E+04, 0.41751500E+03, 0.23406700E+05, -.11942000E+05, -.77070500E+03, -.11703500E+05, -.43023900E+04, -.11134700E+04, -.47954800E+04, 0.30567600E+04, -.56222300E+04, -.62349100E+03, -.41482600E+04, -.60988100E+04, 0.31867100E+04, -.32338400E+03, 0.30495500E+04, -.27003000E+03, 0.19964300E+04, -.85390200E+02, -.23798000E+04, 0.32991300E+03, 0.17768400E+04, 0.24940000E+04, 0.55287400E+03, -.38074900E+03, 0.10566200E+04, -.28757400E+03, -.15034000E+04, -.12310400E+04, 0.93776500E+03, 0.10134400E+04, -.26995200E+03, -.30945400E+03, 0.33294900E+02, 0.34890300E+04, -.18790600E+04, 0.10760700E+04, -.17492700E+04, 0.20700100E+03, -.26445700E+04, -.13677000E+03, 0.16695200E+03, -.25268600E+04, -.18357600E+04, 0.18237900E+04, -.19449200E+05, 0.99823800E+04, -.14767300E+03, 0.97243800E+04, 0.49573500E+04, -.62089800E+02, 0.47738200E+04, -.31935100E+04, 0.49878800E+04, -.46339000E+03, 0.29191100E+04, 0.20309800E+04, -.98176100E+03, -.26210100E+04, -.10167700E+04, -.18312200E+04, 0.14712900E+04, -.53701200E+03, -.93640200E+03, 0.11984800E+04, 0.15062400E+04, -.12600000E+04, -.18574100E+05, 0.94922700E+04, 0.11769500E+04, 0.92872000E+04, 0.18838900E+04, 0.75054600E+03, 0.33908300E+04, -.30930600E+04, 0.35915400E+04, 0.75384600E+03, 0.42495400E+04, -.30770500E+04, 0.17512300E+04, -.55835000E+03, 0.15353200E+04, 0.35288700E+04, 0.60792200E+02, 0.19320700E+04, -.36468100E+03, 0.49802100E+04, -.32995200E+04, -.30239000E+03, 0.52443600E+04, -.27852600E+04, -.90386500E+03, -.26203700E+04, -.22088200E+04, 0.94156800E+03, -.30536100E+04, 0.27216600E+03, -.48149400E+03, 0.13162500E+04, 0.16223800E+04, -.94618300E+04, 0.48118100E+04, 0.48759600E+04, 0.47308600E+04, 0.97965000E+03, 0.14619200E+04, 0.10521300E+04, -.20305700E+04, 0.15931800E+04, 0.77818300E+03, 0.18191600E+04, -.96170500E+03, 0.46612800E+03, 0.32893300E+03, 0.48144100E+03, -.23564400E+04, 0.22415000E+03, -.13124300E+04, -.33179900E+04, -.30885000E+04, 0.23791200E+04, 0.22172800E+04, -.34569200E+04, 0.16746400E+04, 0.18703900E+04, 0.17275800E+04, 0.10879900E+04, -.67941300E+03, 0.10462200E+04, 0.10461800E+04, -.72421800E+02, 0.61688300E+03, 0.18385100E+03, 0.42091400E+02, 0.13638500E+02, -.61679100E+02, 0.52350800E+02, -.73547200E+02, 0.50361800E+02, -.88235100E+02, -.19410700E+03, -.41151200E+03, -.37112500E+03, -.21368400E+03, 0.58894000E+03, -.45334200E+03, 0.10061500E+04, -.19306100E+03, 0.44338200E+03, 0.10157300E+04, 0.29484700E+03, -.81563100E+03, 0.10986000E+03, 0.17902700E+04, -.65969400E+01, -.96387700E+03, -.51512700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15271200E+01, 0.60481300E+00, 0.50416100E-01, -.49918300E+00, -.13034100E+01, -.22479600E-01, 0.19579200E+00, -.77036800E+00, 0.21390200E+00, 0.19043100E+00, -.54749400E-01, -.39337100E+00, -.45928000E+00, -.17164200E+01, 0.11905800E+00, 0.11264200E+00, -.60795600E+00, -.20081600E+00, 0.11717100E-01, -.13938600E-01, -.83814600E+00, 0.18001700E+01, 0.18413000E+01, -.11175600E+01, -.62252300E-01, -.16470000E+00, 0.18074100E+00, 0.25863500E+00, 0.58446600E+00, -.36981100E+00, 0.29753000E+00, -.62765500E-01, 0.43691800E+00, -.38748100E+00, 0.30273100E-01, -.56873700E+00, -.61312700E-02, -.21425300E+00, -.11757200E+00, -.29561300E+00, -.15899500E+00, -.26376400E+00, 0.16166200E+01, -.40786400E+00, 0.95123900E-01, 0.40769500E+00, 0.73908700E-01, -.36420600E-01, -.10651000E+00, 0.27621100E+00, 0.10297600E+01, 0.46627300E+00, 0.12020500E+00, -.22236500E+00, 0.37980800E+00, 0.55588300E-01, 0.99711000E-01, 0.14173500E+01, -.72752500E-03, 0.50349600E+00, 0.21478300E+00, 0.30687500E+00, 0.56074400E-01, -.19620300E+00, 0.89442200E+00, -.27082100E+00, -.46663000E+00, 0.85040500E+00, -.10853000E+00, -.25332700E-04, 0.11549500E+00, 0.69216100E-01, 0.21495100E+00, -.11704800E+00, -.29764300E+00, 0.45465600E-01, -.23384900E-01, 0.26473900E+00, -.60189300E+00, 0.26125600E+00, -.74293600E-03, 0.46166900E+00, -.89126800E+00, -.58286900E+00, 0.17735200E+00, -.48684000E+03, 0.85900500E+02, -.18511800E+03, 0.51327000E+04, -.25811300E+04, -.15630200E+04, -.25647500E+04, -.94895900E+03, -.11029400E+04, -.19337500E+02, 0.23802200E+04, -.20034900E+03, -.11552600E+04, -.13869500E+03, -.10781800E+04, 0.52584500E+03, 0.63671600E+03, 0.53729500E+03, 0.18782900E+03, -.99685600E+02, 0.35582300E+03, 0.17134600E+03, 0.40535800E+03, -.56043100E+01, -.57667900E+03, -.95416800E+03, 0.49366700E+03, 0.57372600E+03, 0.47634000E+03, -.47814000E+03, -.69265000E+03, 0.53023700E+03, 0.12194500E+04, 0.13435900E+03, -.12776100E+03, 0.78510400E+03, -.50527700E+04, 0.25072600E+04, 0.42348200E+04, 0.25265000E+04, 0.15373000E+04, 0.11678400E+04, 0.11742700E+04, -.87254000E+03, 0.72666000E+03, 0.11770800E+04, -.41273600E+04, 0.13948200E+04, -.69071800E+03, -.20493300E+04, -.69750500E+03, -.73611800E+03, -.56196700E+03, -.12530200E+04, -.12015200E+04, -.10465100E+03, -.10906300E+04, 0.42953400E+04, 0.23561000E+02, -.19131000E+02, -.80720600E+02, -.59957100E+01, 0.88956600E+03, 0.10168000E+04, -.37655700E+03, -.27692300E+03, 0.10494900E+03, 0.43570400E+03, 0.82762600E+03, 0.79893600E+03, -.42105100E+03, 0.12305700E+03, -.39626800E+03, -.70217700E+02, -.54584800E+02, 0.80936400E+03, 0.12149400E+04, 0.10270600E+04, 0.92383800E+02, -.19066500E+04, 0.10119700E+05, -.50300100E+04, -.58050000E+04, -.50597200E+04, -.24320500E+04, -.19843300E+04, 0.60535600E+02, 0.51296000E+04, -.36399300E+03, -.14285100E+04, -.21583300E+04, -.30904800E+04, 0.15507300E+04, 0.14904700E+04, 0.15461000E+04, 0.11191800E+04, 0.12292000E+04, -.55717200E+03, -.11571200E+04, -.42777100E+03, 0.62340400E+03, 0.17344200E+04, 0.80767600E+03, -.39290800E+03, -.27193300E+04, -.40392700E+03, -.10713300E+04, -.66757400E+03, -.12335800E+04, -.11601800E+04, 0.14080600E+03, -.12285100E+04, 0.70867300E+04, 0.21643100E+04, -.10418700E+04, -.22549700E+04, -.10799900E+04, -.43887400E+03, 0.12192600E+02, -.35420900E+03, 0.12075600E+04, -.22757900E+04, 0.15600000E+04, -.32679500E+04, -.60433400E+04, 0.29990600E+04, 0.34988300E+04, 0.30204600E+04, 0.14593700E+04, 0.13155900E+04, 0.18381600E+03, -.25244700E+04, 0.44796500E+03, 0.92803700E+03, 0.75528200E+03, 0.31272500E+04, -.15590700E+04, -.14783700E+04, -.15635800E+04, -.78370800E+03, -.70480700E+03, -.62944900E+03, 0.57330500E+03, -.53906900E+03, -.68846500E+03, 0.22354700E+04, -.33171700E+04, 0.16574400E+04, 0.16585900E+04, 0.16581900E+04, -.34708600E+03, -.21596600E+03, 0.93461400E+03, -.34642300E+03, 0.22951300E+04, -.90926700E+03, 0.20843500E+04, 0.30421900E+04, -.15334200E+04, -.21752100E+04, -.15205000E+04, -.23373700E+03, -.41240400E+03, -.51118700E+03, -.22039200E+03, 0.19553800E+03, -.96591600E+03, -.73501800E+03, 0.20821400E+03, 0.94264000E+02, -.70878400E+02, 0.75814700E+02, 0.30447700E+02, 0.70770700E+02, -.81320800E+02, 0.95100700E+02, 0.15306500E+03, -.46864700E+02, -.72788400E+02, -.24750500E+03, 0.80588700E+03, 0.88172500E+02, 0.50146700E+03, -.25148600E+03, 0.40729000E+02, -.34459500E+03, 0.53539000E+03, -.93254800E+02, 0.20074600E+03, 0.22314700E+03, 0.24834000E+03, 0.12030000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22380400E+01, -.74051400E-01, 0.43887200E+00, -.10072100E+01, -.55198400E+00, 0.34885200E+00, 0.90951000E-01, -.59099100E-01, -.47699000E-01, 0.34646400E+00, 0.11353100E+00, -.73690800E+00, -.38478100E+00, -.10367200E+01, 0.12966900E+00, 0.49437500E-01, -.88195900E+00, -.91639700E+00, 0.24979400E+00, 0.37559700E+00, -.61603200E+00, -.42045100E+00, 0.10393700E+00, 0.85981700E-01, 0.21056400E-01, 0.10185600E-01, -.16728500E-01, -.14153500E+00, -.19588600E+00, 0.85862100E+00, -.23800100E+00, -.11364600E+00, 0.69196900E+00, 0.54032000E+00, 0.41145900E-01, -.34256400E+00, 0.63705400E-01, -.60372600E+00, -.33542400E-01, -.12688000E+00, -.77475100E+00, -.51611100E-01, 0.14027500E+01, -.15870000E+00, 0.10380800E+01, -.70050900E+00, 0.71460500E+00, 0.51086200E+00, 0.25656900E+00, -.56695300E+00, -.79961500E+00, -.80141000E+00, -.12949400E+00, -.12645900E-01, 0.20034900E+00, -.70957400E-01, -.11936400E+00, -.69634900E+00, 0.23208600E-02, 0.13844200E+00, 0.47784100E+00, 0.28881400E-02, 0.84179300E-01, 0.56454900E+00, 0.16764300E+00, 0.10718200E+01, 0.30498800E-01, -.32230200E-01, -.51288200E-01, -.55951100E-04, 0.11606300E+00, 0.16981600E+00, 0.11708500E-01, 0.25078500E-01, 0.14235300E+00, -.43863400E-02, -.13845400E+00, -.84798100E-01, 0.86438400E-01, 0.16775600E+00, 0.61926900E-03, 0.44104300E+00, -.20494600E+00, 0.95622300E+00, 0.10443100E+00, -.91710600E-01, -.25361300E+03, -.72871300E+03, -.24698000E+03, 0.11870400E+03, 0.85845000E+03, 0.12338200E+03, 0.18243200E+03, 0.24253400E+03, -.24108400E+03, -.15199800E+03, -.40085700E+03, 0.43434600E+03, 0.38574500E+03, -.27189200E+03, 0.13505600E+03, 0.13567300E+03, 0.13293300E+03, -.11567600E+02, -.11656200E+03, 0.15963900E+03, 0.21996000E+02, 0.98913700E+02, -.84495600E+02, 0.90871400E+02, -.72562400E+03, 0.36422400E+03, 0.34287500E+03, 0.36286200E+03, -.35893700E+01, 0.27816500E+01, -.74064600E+02, 0.81328500E+02, 0.28762500E+03, -.17090900E+03, 0.40968600E+03, 0.34269300E+04, -.17115600E+04, -.78741000E+03, -.17134700E+04, -.69765500E+02, 0.61298700E+03, -.89943400E+03, -.51563800E+02, -.12639600E+04, 0.17497300E+03, -.36801700E+04, 0.14292700E+04, -.71768000E+03, -.99365000E+03, -.71462700E+03, -.39764200E+03, -.39640100E+03, -.26293900E+03, 0.48056800E+03, -.26931900E+03, -.35199300E+03, 0.11452000E+04, -.64846400E+02, 0.31287600E+02, 0.27931600E+03, 0.32025000E+02, 0.77618300E+02, 0.13467800E+03, -.66297800E+02, -.10951200E+03, 0.15095400E+03, -.16676300E+03, 0.89229900E+02, 0.20880400E+02, -.13787500E+02, -.25944200E+03, -.10653600E+02, -.23967600E+03, -.25534700E+03, 0.46710100E+03, 0.16570900E+03, 0.12938300E+03, 0.24872500E+03, -.16306100E+03, -.20325100E+04, 0.10175000E+04, 0.95885800E+03, 0.10162600E+04, -.94626900E+02, -.56298400E+03, 0.84733400E+03, 0.11023100E+03, 0.27711700E+03, -.16937700E+03, 0.21665500E+04, -.74526500E+03, 0.37367800E+03, 0.66653100E+03, 0.37257200E+03, 0.35023200E+03, 0.27740900E+03, -.13100200E+03, -.40715300E+02, 0.43362600E+03, -.42653700E+03, 0.48313500E+03, -.21249000E+04, 0.10583800E+04, 0.32158200E+03, 0.10624500E+04, -.11076800E+03, -.69962700E+03, 0.59195700E+03, 0.17287800E+03, 0.89727400E+03, -.39984900E+03, 0.34515700E+04, -.89686500E+03, 0.45519000E+03, 0.11692000E+04, 0.44828600E+03, -.16978500E+03, -.74088000E+03, 0.44102700E+03, -.15162800E+03, 0.18228800E+03, -.74710000E+03, 0.78728400E+03, -.22972700E+03, 0.11263000E+03, -.31434800E+03, 0.11493300E+03, 0.20665800E+03, 0.40551100E+03, -.33192800E+03, -.27212100E+03, 0.34272800E+03, 0.27433600E+03, -.67059300E+03, 0.48966900E+03, -.24647500E+03, 0.73476400E+02, -.24483800E+03, -.11910100E+03, -.94599300E+02, -.18472100E+03, 0.25134000E+03, -.23951700E+03, -.22761600E+02, 0.81382500E+03, -.16249800E+02, 0.88684600E+01, -.21418500E+03, 0.81461900E+01, 0.15469500E+03, 0.38247700E+03, -.33090800E+01, 0.25880500E+03, 0.92663400E+02, 0.59286400E+03, 0.27111400E+03, 0.33960400E+03, -.17239300E+03, -.49442300E+03, -.16985000E+03, -.41482200E+02, 0.41108300E+02, -.20502500E+03, -.28895800E+03, -.32870800E+03, 0.29677900E+03, -.42553000E+03, -.11057700E+02, 0.40985100E+02, 0.62667600E+01, 0.43073700E+02, -.60515700E+02, 0.22505500E+02, -.47203000E+02, -.35872200E+02, -.13607700E+03, 0.33823400E+02, -.60534200E+02, 0.11819500E+02, 0.30337000E+03, -.17945300E+03, 0.23955000E+02, 0.17938300E+01, 0.19640300E+03, -.10038600E+03, 0.31926000E+03, 0.55637600E+02, 0.28433300E+03, -.12853400E+02, 0.61097800E+02, -.69985600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30181100E+01, 0.60113700E+00, -.29107700E+01, -.80094300E+00, -.26146900E+01, -.61384600E+00, 0.65957900E+00, -.47207800E+00, -.80030000E+00, -.86981500E+00, -.48120300E+01, -.10248200E+01, 0.18544200E+01, 0.80429500E+00, 0.31440900E+00, 0.76256700E+00, -.29411800E-01, -.14314700E+00, 0.20091700E+00, 0.49528000E+00, -.46668800E+00, 0.26969900E+00, 0.62507500E-01, -.13526500E+00, -.43412400E-01, -.27706700E+00, -.31901900E+00, -.44863400E-01, 0.22139600E+00, -.26298500E+00, 0.33441500E+00, -.66580700E-01, 0.85276600E-01, -.16586000E+00, 0.44226800E-01, 0.65163000E-01, -.32104400E-01, 0.14045300E+00, -.27896700E+00, 0.84780300E-01, 0.26786100E+00, 0.93391100E-01, -.18354900E+01, 0.24483900E+00, -.47752500E+00, 0.22409400E+00, 0.35848400E+00, -.31202700E+00, -.37148900E+00, 0.15788900E+00, -.97505200E+00, 0.54196000E+00, -.20309200E+00, 0.59747700E-01, -.13753700E+00, -.75906900E+00, 0.12810400E+00, -.18718500E+00, -.18632100E-02, -.12896300E+00, -.41946900E-01, 0.39760000E+00, -.19546900E+00, 0.84250700E-04, 0.25470800E+01, 0.99124000E+00, 0.51258200E+00, -.98995600E-01, 0.10097400E+00, -.49225900E-02, -.60783200E-01, -.13611800E+00, -.30493400E+00, -.29743300E+00, 0.55584200E+00, -.20073500E-02, -.79199900E-01, -.47767700E+00, -.11358200E+01, 0.99315500E+00, 0.93019600E-03, 0.17946400E+01, -.30777800E+00, 0.34116400E+01, 0.44274700E+00, -.91751700E+00, -.70304100E+00, -.20168500E+04, 0.80438500E+04, -.40572400E+04, -.40458900E+03, -.40205800E+04, -.16350000E+04, -.16610300E+04, -.21380900E+03, 0.47971400E+04, 0.20493400E+01, -.20530400E+04, -.69603700E+03, -.12338700E+04, 0.59801600E+03, 0.13410800E+04, 0.61721200E+03, 0.32148900E+03, 0.13230700E+03, 0.95879400E+02, -.45424400E+02, 0.23064800E+03, 0.80407600E+02, -.43563800E+03, -.40607600E+04, 0.20451700E+04, 0.43625300E+04, 0.20297600E+04, 0.49520600E+03, 0.21241100E+03, 0.10820800E+04, 0.33612000E+04, 0.13254500E+04, 0.20117700E+03, 0.12277200E+04, -.20443600E+05, 0.10204500E+05, 0.75468800E+04, 0.10221900E+05, 0.34684500E+04, 0.21158800E+04, 0.34960900E+04, -.34779100E+04, 0.42400000E+04, 0.26465000E+04, 0.66736800E+03, -.66704300E+03, 0.32932200E+03, 0.23934600E+04, 0.33344300E+03, -.20647200E+03, -.65119300E+03, -.63267100E+03, -.60073800E+03, 0.10187700E+04, -.13174100E+04, 0.42012600E+04, -.13728900E+04, 0.67097200E+03, -.69246800E+03, 0.68978100E+03, 0.53339600E+03, 0.14248700E+03, -.74845800E+03, -.18876900E+04, 0.41264200E+03, -.58864000E+03, 0.15566000E+04, 0.62737600E+03, -.34031100E+03, -.17626100E+04, -.31100000E+03, -.70261400E+03, -.36990600E+03, 0.11564400E+04, 0.33098100E+03, 0.69296100E+03, 0.20481800E+03, -.18532400E+04, 0.21274800E+05, -.10599800E+05, -.78066500E+04, -.10637200E+05, -.46486800E+04, -.27174400E+04, -.13765700E+04, 0.72573000E+04, -.37469300E+04, -.26260000E+04, -.32869300E+04, -.54617800E+04, 0.27372700E+04, 0.37197800E+04, 0.27316100E+04, 0.12412100E+04, 0.10432600E+04, -.12079600E+04, -.74455000E+03, 0.72591100E+03, -.51275000E+03, 0.24252100E+04, 0.95116300E+04, -.47536300E+04, -.17651700E+04, -.47558900E+04, -.20184300E+04, -.11699600E+04, -.25484700E+04, 0.39371300E+03, -.18513200E+04, -.21835200E+04, 0.40467700E+04, -.13416400E+03, 0.12846100E+03, -.29087500E+04, 0.68891100E+02, -.17006300E+04, -.98246700E+03, 0.23435300E+03, 0.14910000E+04, -.20385800E+04, 0.20591400E+03, 0.39275800E+02, -.93768500E+04, 0.46564700E+04, 0.37630900E+04, 0.46873900E+04, 0.20773800E+04, 0.12932700E+04, 0.59713700E+03, -.31626900E+04, 0.17328700E+04, 0.11429900E+04, 0.67318100E+03, 0.43020200E+04, -.21545900E+04, -.10563700E+04, -.21509800E+04, -.86318100E+03, -.63376200E+03, -.58160000E+03, 0.17371200E+04, 0.13532400E+03, -.86721600E+03, 0.18068400E+04, -.48354700E+04, 0.24171800E+04, 0.19353700E+04, 0.24173900E+04, 0.22290100E+03, 0.14970500E+03, 0.17357300E+04, 0.44940600E+03, 0.28971700E+04, -.24641700E+03, 0.34278700E+04, 0.40125900E+04, -.20261400E+04, -.32899800E+04, -.20058100E+04, -.61206200E+03, -.11704800E+04, -.35323500E+03, -.11080400E+04, -.62926600E+03, -.86884900E+03, -.15387000E+04, 0.27342600E+03, 0.80626700E+02, -.40757800E+02, 0.67790000E+02, -.80609800E+02, 0.66467200E+02, -.56069400E+02, 0.75338700E+02, -.94690800E+02, -.62326900E+02, 0.15342900E+03, -.82960300E+02, 0.14689500E+04, -.42789600E+03, 0.29283800E+03, -.35867100E+03, 0.23587100E+03, -.53774400E+03, 0.11477900E+04, -.13580400E+03, -.13011400E+02, 0.20592500E+03, 0.34625200E+03, 0.38230300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45655200E+01, -.57638100E+00, 0.14361300E+01, -.29948500E+01, -.55001500E+01, -.20323700E+01, 0.13533000E+01, -.12526000E+01, 0.58118100E+00, 0.15225600E+00, -.30389600E+01, -.26739900E+01, -.60598900E+01, -.63956000E+01, 0.77436700E+00, 0.66956700E+00, -.21192700E+01, -.21558300E+01, -.12254900E+00, 0.33273200E+00, -.12537600E+01, 0.23750100E+01, 0.41777200E+00, 0.11932300E+00, -.13886700E+00, 0.23157900E-01, 0.25831600E+00, -.31357700E+00, -.48786200E+00, -.47771300E-01, -.39483100E+00, -.47398200E+00, 0.17201900E+01, 0.26323400E+00, 0.62097400E-01, -.14536600E+01, -.19944400E-01, -.13909200E+00, 0.12393600E+00, -.34210300E+00, -.19288800E+00, 0.13505800E+00, -.10471600E+01, -.16264200E+00, 0.73833100E+00, 0.10167600E+01, -.12731700E+00, -.20537200E+00, -.75454300E-01, 0.70138100E+00, 0.12962800E+01, -.40970100E+00, 0.69111500E-01, -.44451200E+00, 0.92898700E+00, 0.16303900E-01, -.33079200E+00, 0.10385600E+01, 0.43352000E-03, 0.76813800E+00, 0.10270500E+01, 0.29365700E+01, -.57607400E+00, -.43020600E+00, 0.25749100E+01, -.70295100E+00, -.83476000E+00, 0.17132600E+01, -.11739900E+00, 0.18409800E-01, -.94487600E+00, 0.44784300E+00, 0.93408100E-01, -.51798000E+00, 0.53379700E+00, -.14609100E+00, -.76872600E-01, -.12009400E+00, -.41964900E+00, -.20363400E+00, -.45910700E-03, 0.11892500E+01, -.46417500E+00, -.39788100E+01, -.30227300E+00, 0.14613900E+01, -.88225100E+00, 0.38746600E+00, -.18643800E+05, 0.93728500E+04, 0.43127500E+04, 0.93196500E+04, 0.18224000E+04, 0.71797000E+03, 0.28126000E+04, -.67906900E+04, 0.35094800E+04, 0.47937700E+03, 0.28308300E+04, 0.25768600E+04, -.13161600E+04, -.15134200E+04, -.12925200E+04, -.36534900E+03, 0.27281700E+02, -.85234000E+03, -.77921800E+03, -.12307800E+04, -.98631000E+02, 0.88546700E+03, 0.38291400E+04, -.18030700E+04, -.40601200E+04, -.19135200E+04, -.47162300E+03, 0.16128100E+04, -.14098800E+04, -.53163200E+04, -.19232300E+04, 0.14263900E+03, -.15586800E+04, 0.14609900E+05, -.75525300E+04, -.71074300E+03, -.73051000E+04, -.22714800E+04, -.13594400E+04, -.34836200E+04, 0.48304400E+04, -.25579400E+04, -.44419300E+03, 0.54252900E+04, -.10593700E+05, 0.54752300E+04, 0.47816700E+04, 0.52970100E+04, 0.75883000E+03, 0.29508000E+04, 0.33119200E+04, -.17159000E+04, 0.10409500E+04, 0.33596700E+04, -.12541000E+04, 0.49099200E+03, -.35989100E+03, 0.14003200E+03, -.25605500E+03, -.17652000E+04, -.14112200E+04, 0.24612800E+03, 0.79132800E+03, -.38024500E+03, 0.30520200E+03, -.22053600E+04, 0.17164300E+04, -.94332800E+03, 0.99332800E+03, -.86276300E+03, 0.13257600E+04, -.16832200E+04, -.13760100E+04, 0.76336500E+03, -.18046900E+04, -.19331400E+04, 0.53390100E+04, -.13734300E+05, 0.71036300E+04, -.48503800E+03, 0.68669100E+04, 0.41565900E+04, 0.15503900E+04, 0.35624500E+03, -.90394300E+04, 0.13174700E+04, -.29899400E+03, -.18118400E+04, 0.73074800E+04, -.36361000E+04, -.53821800E+04, -.36549600E+04, -.41603900E+04, -.24670800E+03, -.92971600E+03, -.10871100E+04, -.45599600E+03, 0.10442300E+04, -.43768100E+04, -.17358700E+05, 0.89226900E+04, 0.52361100E+04, 0.86794900E+04, 0.12691900E+04, 0.14045000E+04, 0.49366900E+04, -.40963400E+04, 0.26432300E+04, 0.15049300E+04, -.42448000E+04, 0.42397500E+04, -.19962300E+04, -.34359500E+04, -.21229400E+04, 0.10447000E+04, 0.88967900E+03, -.14106100E+04, -.33841100E+04, 0.18432400E+04, -.33838600E+04, 0.35264800E+03, 0.72293800E+04, -.37468200E+04, -.20648400E+04, -.36129600E+04, -.21713200E+04, -.49999800E+03, -.49319200E+03, 0.45650300E+04, -.10302400E+04, 0.67800400E+03, 0.27220800E+04, -.12005500E+05, 0.61108900E+04, 0.51033300E+04, 0.60027000E+04, 0.10889200E+04, 0.14950200E+04, 0.24142700E+04, -.32833900E+04, 0.22639900E+04, 0.86651700E+03, -.24533700E+03, 0.22854800E+03, -.13063100E+03, 0.12892900E+04, -.11370900E+03, -.86951700E+03, 0.29246400E+03, -.87197800E+03, 0.44812000E+03, -.17204800E+04, 0.16947400E+04, 0.86680100E+03, -.84891600E+04, 0.42274300E+04, 0.63799500E+04, 0.42437400E+04, 0.17023400E+04, 0.34693700E+03, 0.26099200E+04, 0.26567300E+04, 0.15378200E+04, 0.18859300E+04, 0.82892500E+03, -.17378500E+03, -.14103400E+03, 0.48823500E+02, -.98727200E+02, 0.75983700E+02, -.21221400E+02, 0.92480800E+02, -.15196900E+03, -.13976500E+03, -.22134400E+03, -.10181700E+02, 0.22040700E+03, -.57357400E+03, 0.81571500E+03, -.70452200E+03, 0.67638100E+03, 0.14080900E+04, 0.82551400E+03, -.96700000E+03, 0.53071300E+03, 0.11166700E+04, -.22354400E+03, -.35248700E+03, -.10279800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.61141500E+01, -.31448400E+00, -.16844800E+01, 0.19371700E+01, 0.50715700E+01, 0.70084800E+00, -.99837400E+00, 0.21319400E+01, -.24573600E+00, -.76543300E+00, 0.36394100E+00, 0.57048600E+00, 0.12039600E+01, 0.21691500E+01, 0.16699400E+00, -.38536800E+00, 0.95605200E+00, 0.36458300E+00, -.21182100E+00, 0.71961500E+00, -.19990500E+01, -.50110700E+01, -.80215500E+00, 0.54168200E+00, 0.83077400E-01, 0.20811800E+01, 0.29856500E+00, -.66045100E+00, -.14982500E+00, 0.21762100E+01, -.10815000E+00, 0.31218700E+00, 0.20713600E-01, -.61334600E-01, -.42468600E+00, 0.16656200E+01, -.20125800E-02, -.44214000E+00, 0.69741800E+00, 0.67395200E+00, 0.14265900E+01, 0.11662200E-01, -.37658900E+01, 0.73095800E+00, -.21478800E+01, 0.16151000E+01, 0.20211500E-02, -.18632700E-01, -.10024300E+00, 0.47908500E+00, 0.93120000E+00, 0.81779100E+00, 0.83858300E-01, 0.91630200E+00, -.56992800E-01, -.19004400E+01, -.43035100E-01, -.12652800E+01, 0.11652700E-02, 0.21535900E+01, 0.12998900E+01, 0.21538700E+01, -.44628000E+00, -.28275500E-01, 0.18189500E+01, -.79647800E-01, 0.29053900E+00, 0.20919500E+01, -.45315000E+00, 0.12445900E-01, 0.10061000E+00, 0.49932200E+00, 0.18654000E+00, -.63052100E-01, 0.44390900E+00, -.38986600E+00, -.13063200E+01, -.30665400E+00, -.33281500E+01, 0.57014700E+00, -.63782900E-04, 0.43918800E+01, -.25752000E+01, -.10674900E+01, -.24722200E+00, 0.27549900E+00, 0.39205900E+00, 0.62895700E+00, 0.69202500E+00, -.75927600E+02, 0.51871100E+03, 0.26557100E+01, -.16041900E+03, -.11469500E+03, 0.82723500E+03, 0.16013800E+04, 0.17928900E+04, -.10440500E+04, 0.27165400E+04, -.10170300E+04, 0.42094000E+03, 0.11124600E+04, 0.50905100E+03, 0.33807800E+03, -.13522500E+03, 0.58189500E+03, 0.41641700E+03, 0.35406700E+03, 0.88499400E+02, -.13719900E+04, -.16985800E+04, 0.97653900E+03, -.17749700E+04, 0.84805200E+03, -.16784600E+03, 0.84574100E+03, -.33542000E+03, -.66301900E+03, 0.59304600E+03, 0.94074800E+03, 0.14372200E+04, 0.21247500E+04, -.12648700E+04, 0.38333300E+04, -.10621900E+04, 0.11318900E+03, 0.13370800E+04, -.25141300E+03, 0.10278300E+04, 0.28995900E+03, 0.26514000E+04, -.63565600E+04, 0.12184000E+03, 0.30926900E+02, -.19262700E+04, -.61078300E+02, -.32551600E+03, 0.16782200E+04, -.25951600E+04, -.25290200E+04, -.26549500E+03, 0.32405500E+03, 0.55887500E+04, 0.75764800E+03, -.46184700E+03, -.10093700E+03, -.37410200E+03, 0.82220200E+03, 0.11363000E+04, -.36352500E+03, 0.12399600E+03, -.15349100E+03, 0.80667300E+03, 0.20399000E+04, 0.28497000E+04, -.15797200E+04, 0.94585700E+03, -.14195400E+04, -.41144500E+03, -.19933200E+04, 0.99844200E+03, 0.24881400E+04, 0.57837400E+03, -.12422800E+04, -.30828600E+04, 0.11625700E+05, -.55605100E+04, -.10453700E+05, -.58126000E+04, -.85083300E+03, -.42688100E+04, 0.11283200E+04, 0.49088400E+04, -.48482700E+03, -.43709500E+04, -.51546300E+04, -.53860600E+04, 0.27323600E+04, 0.16290400E+04, 0.26944600E+04, 0.15724700E+04, 0.26040400E+04, -.27277700E+03, -.18367100E+04, 0.36733400E+03, 0.21475800E+04, 0.29669700E+04, -.51932100E+04, 0.27459800E+04, -.13966800E+04, 0.25964500E+04, -.37085200E+03, -.13751700E+03, -.85690600E+03, -.33673400E+04, 0.52156400E+03, -.18965100E+04, 0.10034800E+05, 0.38499000E+04, -.16567900E+04, -.70888200E+04, -.19213600E+04, 0.69749100E+03, -.14003000E+04, 0.26166300E+03, 0.11829400E+04, -.64191900E+03, -.14571600E+02, -.79870400E+04, -.10337000E+05, 0.50086000E+04, 0.66574400E+04, 0.51665000E+04, 0.92242300E+03, 0.30336800E+04, -.54422900E+03, -.32983400E+04, 0.16949700E+04, 0.31801300E+04, 0.43629000E+04, -.75963500E+03, 0.43304800E+03, 0.14593300E+03, 0.37988600E+03, -.43091700E+03, 0.17606000E+03, -.48417600E+03, -.96119100E+02, 0.80794900E+03, -.51439500E+03, 0.44002600E+04, -.95972900E+04, 0.47806300E+04, 0.40684300E+04, 0.47979900E+04, -.19480100E+04, -.56349100E+03, 0.14263300E+04, -.20609100E+04, 0.28877100E+04, -.10187900E+04, 0.74411000E+04, 0.23814000E+03, -.19485900E+03, -.99668300E+03, -.11807700E+03, 0.18075600E+03, -.84283200E+03, 0.52793100E+03, 0.14075900E+04, 0.11165900E+04, -.15311000E+04, 0.43787500E+03, 0.29664900E+03, 0.12187300E+03, -.19000400E+03, 0.12168000E+03, 0.49813900E+02, 0.82858400E+02, -.12104300E+03, 0.73367300E+02, 0.96951500E+02, -.20961600E+03, 0.26334900E+03, -.12594900E+03, 0.10878700E+04, 0.10323800E+04, 0.84327200E+03, -.13960900E+03, 0.13897700E+04, -.45791600E+03, -.97538700E+02, 0.14467600E+03, 0.15739000E+04, 0.17523000E+03, -.31773400E+02, -.10273600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20363500E+01, -.31152900E+00, -.33178600E+00, 0.77688400E+00, 0.36537500E+00, 0.24219500E+00, -.16369500E+00, 0.29656500E+00, -.81864600E-01, 0.23557700E-01, -.12693900E+00, -.44289400E+00, -.10976800E+01, 0.30080400E+00, -.18405900E+00, 0.51328300E-01, 0.45635400E+00, -.65438700E+00, -.10800400E+00, -.21222900E+00, 0.83219900E+00, -.44017200E+00, -.14334000E+00, 0.35266700E+00, -.23027200E-01, -.91063800E-01, -.36326600E+00, -.30209500E+00, -.19852300E+00, -.16537100E+01, -.15051500E+00, 0.91645400E-01, -.72115700E+00, 0.21899600E+00, -.63407700E-01, 0.44492800E+00, -.32051800E-02, 0.46661700E+00, -.16994100E+00, 0.49482500E-01, 0.63151400E-01, -.21218800E+00, 0.20986500E+01, -.28542300E+00, 0.54923400E+00, 0.13042500E+00, -.40133600E+00, 0.20759400E+00, 0.10045400E+00, 0.38599800E+00, 0.22841100E+00, 0.59052300E-02, -.18941900E-01, -.22091500E+00, -.13298300E+00, -.39507300E+00, 0.11582000E+00, 0.25125200E+00, -.57366900E-03, 0.29438400E+00, 0.22275400E+00, -.52084100E+00, 0.16233800E+00, 0.37207000E+00, -.27708400E+00, -.83776800E-01, -.14384600E+00, -.15087600E+00, 0.91792600E-01, -.35582300E-02, 0.16641600E+00, 0.90849500E-01, 0.39487600E+00, -.17789500E+00, -.56096600E-02, 0.31169100E-01, 0.23057600E+00, 0.16034000E+00, 0.82134600E+00, -.10104800E+00, 0.12130400E-02, -.42307500E+00, 0.55956900E+00, -.11248100E+01, -.70469100E-01, -.53064300E+00, 0.10746000E+00, -.20707300E-01, -.16703900E+00, 0.37272000E-02, 0.11432100E+04, -.21536300E-01, 0.17429100E+03, 0.19629400E+03, 0.45028800E+02, 0.42681700E+03, 0.44006800E+02, 0.30585900E+03, -.10864900E+04, 0.27423200E+02, -.20811200E+02, 0.17853900E+03, -.16657700E+02, 0.70137600E+02, 0.27337000E+02, 0.40607200E+02, 0.29227800E+02, -.59447400E+02, 0.61406900E+02, -.26521100E+03, -.21631100E+03, 0.13485100E+03, 0.44114200E+03, 0.10816500E+03, -.60313300E+02, -.23812500E+02, -.12843200E+02, 0.53065500E+03, 0.47383500E+03, 0.17339100E+03, -.84117400E+02, -.19112700E+03, 0.46902700E+02, 0.86953400E+03, 0.95563400E+02, 0.44096000E+02, -.37949600E+03, 0.25821000E+03, -.14858300E+03, 0.39801200E+03, -.36239500E+03, 0.38595300E+03, 0.19120400E+04, -.92499900E+03, -.13728200E+04, -.95601800E+03, -.27429300E+03, 0.18091300E+03, -.79269100E+03, -.13933500E+03, -.65445900E+03, 0.64757600E+01, -.53499200E+03, 0.36084000E+03, -.20188400E+03, -.31437200E+03, -.18004200E+03, -.22938100E+02, 0.33775300E+03, -.28560300E+03, -.37776600E+03, 0.21544300E+03, 0.18592300E+03, 0.31144700E+03, 0.40612900E+03, -.22956500E+03, -.30964000E+03, -.20310600E+03, 0.10282300E+03, 0.15627500E+03, 0.27973600E+03, 0.42645500E+03, -.45970300E+03, 0.14834200E+03, 0.34459600E+03, 0.41656100E+03, -.15631200E+03, -.63804300E+03, -.20827200E+03, -.11137600E+03, 0.14152500E+03, 0.36247100E+03, 0.12042100E+04, -.16356300E+03, 0.36444100E+03, -.12250400E+04, -.30343700E+03, 0.15816300E+03, 0.39986000E+03, 0.15170500E+03, -.23788700E+03, 0.14493200E+03, -.35488600E+03, -.34141600E+03, 0.10377100E+04, -.54327800E+02, 0.16281700E+03, 0.13056800E+04, -.60952600E+03, -.14533800E+04, -.65283900E+03, -.18911900E+03, 0.37629800E+03, -.71425600E+03, -.10537400E+03, -.62342900E+03, 0.21062900E+03, -.27177700E+03, -.55394200E+03, 0.31718400E+03, -.82747300E+03, 0.27694100E+03, -.42082700E+02, -.67739700E+02, 0.22770000E+03, 0.71815500E+03, 0.29225800E+03, 0.36970900E+03, 0.16523900E+03, -.20012400E+03, 0.67374600E+02, 0.32983600E+03, 0.10007000E+03, -.19458100E+02, 0.13138700E+03, -.25724700E+03, -.56450700E+03, 0.27406900E+03, -.85337000E+02, 0.61109300E+03, -.10630100E+03, 0.72151200E+02, 0.31452800E+03, 0.53149400E+02, 0.15227700E+03, 0.33654200E+03, -.31960400E+03, -.14920500E+03, -.20741500E+03, 0.35881200E+03, -.17234700E+03, -.90276100E+03, 0.44956200E+03, 0.65526700E+03, 0.45138200E+03, -.34469800E+03, -.97221500E+02, 0.21430800E+03, -.18909400E+03, 0.33702800E+03, -.32846100E+03, 0.70881100E+03, -.11007800E+03, 0.45800600E+02, -.16986500E+03, 0.55026100E+02, 0.34469000E+03, 0.35284700E+03, -.17821500E+03, -.57008200E+03, -.65378900E+03, 0.16696800E+03, -.72772900E+03, 0.56926900E+02, 0.41094700E+02, -.25534100E+02, 0.52700300E+02, -.18510400E+00, 0.47829500E+02, -.48482000E+02, 0.36703000E+02, 0.43845500E+02, 0.61998800E+02, 0.10128200E+03, -.16228900E+02, -.27114900E+03, 0.17887400E+03, 0.15818800E+03, -.26004800E+02, -.36587700E+03, -.12870900E+03, -.23046000E+03, 0.32853800E+01, -.12099400E+03, -.11803100E+03, 0.64985500E+02, -.78796800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11369200E+02, -.25249400E+01, -.18001500E+01, 0.83310900E+01, 0.55394600E+01, 0.24612700E+00, -.11784500E+01, -.25651300E+01, 0.11305300E+01, 0.93907700E-01, 0.56396600E+01, 0.37451000E+01, -.90190500E+01, 0.17442700E+01, -.10025300E+01, -.46083600E+00, 0.31721100E+01, -.18677700E+01, -.12662400E+01, -.11012500E+00, 0.15251500E+01, -.22993400E+01, 0.76401000E+01, -.55715500E+01, -.38549700E+00, 0.51182800E+01, 0.83363600E+00, -.33778200E+00, 0.20474200E+01, -.11002400E+01, -.13170400E+01, 0.40968500E+00, -.14886000E+01, -.25836000E+01, -.49799200E+00, 0.97543300E+00, 0.28537900E+00, 0.88933400E+00, 0.76047400E+00, 0.80929600E+00, 0.33375100E+01, -.10888700E+01, 0.21334100E+01, -.11371900E+01, -.14315300E+01, 0.96491200E+00, 0.69580000E+00, 0.17398100E+01, -.48896900E+00, -.14550500E+01, -.47973400E+00, 0.16870500E+01, -.29010700E-01, -.15608700E+00, -.40275400E+00, -.25105000E+00, 0.11109300E+01, 0.80803000E+01, -.64482800E-01, 0.30314900E+01, 0.19545100E+00, -.22991000E+01, 0.93569100E+00, 0.48905500E+00, -.24578800E+01, -.11116800E+01, 0.62824900E+00, -.15887200E+01, 0.70721700E+00, -.17325700E+00, 0.18643100E+01, 0.10712800E+01, 0.10434500E+01, -.18327100E+00, 0.17826200E+01, 0.81707800E+00, -.17266800E+00, -.36455600E+00, -.39480900E+00, 0.16020200E+00, -.13969800E+00, 0.21424300E+01, -.14879900E+01, -.76398000E+00, 0.53396900E+00, -.12963200E+01, -.45992800E-01, 0.11178300E+01, -.15348200E+00, 0.21438800E+00, 0.58147300E+00, -.14274800E+02, -.38342200E+03, 0.36731100E+03, -.66489400E+03, -.11090000E+04, -.43016400E+03, 0.11404600E+04, -.47067700E+03, 0.79723900E+03, -.36929900E+03, -.71624400E+03, -.41929900E+03, -.33374500E+03, -.53384400E+03, 0.26385900E+03, 0.19067300E+03, -.99993900E+02, -.44176000E+03, -.11713000E+03, -.69650900E+03, 0.30880300E+03, 0.99291400E+03, 0.35525200E+03, -.99363800E+03, -.22016000E+04, 0.17509500E+04, 0.10978000E+04, 0.30486900E+04, -.12874800E+04, 0.47032900E+03, 0.18487600E+04, -.84846200E+03, -.13594600E+04, -.92581600E+03, -.26247400E+03, -.68702700E+03, 0.34286600E+03, 0.42652200E+03, 0.83729600E+03, -.16876100E+04, -.28808500E+03, 0.38819300E+04, -.19854500E+04, -.38468900E+04, -.19400400E+04, 0.75444700E+02, 0.46848400E+03, -.11789600E+04, 0.66153600E+03, -.68058800E+03, 0.11323400E+04, -.48488100E+04, 0.65008200E+03, -.30264100E+03, 0.40822000E+03, -.31863700E+03, 0.45798000E+03, 0.10167300E+04, -.90831600E+02, -.46700000E+03, -.97687700E+02, 0.39864200E+03, 0.34631600E+02, -.38787500E+03, 0.23430900E+03, -.59443700E+03, 0.16459200E+03, 0.84139300E+03, 0.18780200E+04, -.59561300E+03, -.37369800E+03, -.20710300E+04, 0.14503800E+04, 0.12784000E+04, -.10718400E+05, 0.52874900E+04, 0.69556600E+04, 0.53548300E+04, 0.14340000E+04, 0.19461700E+04, -.46352000E+03, -.40023200E+04, -.19809200E+04, 0.22832300E+04, 0.56306200E+04, 0.14382300E+04, -.73028900E+03, -.48476900E+02, -.72663700E+03, -.95003400E+03, -.18615900E+04, 0.24349700E+04, 0.60489600E+03, 0.28085400E+04, -.16884100E+04, -.51419800E+03, 0.44586500E+04, -.22977600E+04, -.35218600E+04, -.22284200E+04, -.26549300E+03, 0.40564100E+03, -.11227300E+04, 0.12800300E+04, -.95772200E+03, 0.13047900E+04, -.40081400E+04, 0.20231000E+04, -.10651000E+04, 0.33640900E+04, -.10308000E+04, -.63075900E+03, -.11957600E+04, 0.11341400E+03, -.27412000E+03, -.95760600E+02, 0.53115200E+02, 0.17242900E+04, 0.60094100E+04, -.29638400E+04, -.38530400E+04, -.29912500E+04, -.18672900E+03, -.66660000E+03, 0.55680900E+03, 0.28545100E+04, 0.12419200E+04, -.96681100E+03, -.30751600E+04, 0.10021000E+04, -.52513100E+03, -.24243700E+03, -.50135700E+03, 0.25261500E+03, 0.87715200E+03, -.11410100E+04, -.12704500E+03, -.14929200E+03, 0.15833200E+04, -.21384000E+04, -.14584500E+04, 0.73222800E+03, 0.81085700E+03, 0.73383700E+03, 0.46335800E+03, 0.93358300E+03, 0.12952700E+03, 0.20745000E+03, -.39549200E+03, -.57296200E+00, -.42860100E+03, 0.35450100E+03, -.16294600E+03, 0.23755200E+02, -.18085500E+03, 0.11942000E+04, 0.23125000E+04, -.27273400E+04, -.24504100E+04, -.30076500E+04, 0.16085600E+04, -.20006500E+04, -.10441500E+03, 0.11950500E+03, 0.60358200E+02, 0.13193700E+03, -.54231600E+02, 0.64029000E+02, -.12259900E+03, -.28241200E+02, 0.13791000E+02, 0.62131900E+01, -.39925100E+03, -.88611600E+01, -.77362600E+03, -.71313500E+03, 0.10114300E+03, 0.77085000E+02, -.22120500E+03, -.14286100E+03, -.22337900E+03, 0.31938800E+03, -.29821900E+02, 0.34511100E+03, 0.32563900E+03, -.68220500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19093800E+01, -.10573200E+00, 0.47185100E+00, -.15370200E+01, -.15634200E+01, -.68703100E+00, 0.38983800E+00, 0.46331400E+00, -.16950100E+00, -.13888100E+00, -.16104400E+01, -.11987200E+01, -.31621200E+01, -.21629800E+01, 0.64455400E+00, 0.27074600E+00, -.56050100E+00, -.85992200E+00, 0.67808900E-01, -.81486200E+00, 0.20005200E+00, -.29289700E+01, -.32221200E+01, 0.10452700E+01, -.61833600E-01, 0.40811100E+00, 0.54923600E-01, -.31027600E+00, -.49071400E+00, 0.34335800E+01, -.31913500E+00, -.38228900E-02, 0.57903100E-01, 0.81617200E+00, 0.30281500E+00, 0.61680900E+00, 0.33605900E-01, -.22940400E+00, -.64331400E+00, 0.24992200E+00, -.21410800E+00, 0.29758700E+00, 0.31068700E+00, 0.40013000E+00, -.43836800E+00, -.48830700E+00, 0.40193500E+00, 0.53321800E+00, -.27103400E+00, -.91681200E+00, -.75936300E+00, -.32099700E+00, -.61118900E-01, 0.14030400E-01, 0.11159900E+00, -.33767600E+00, -.38432700E-01, -.83539100E+00, -.36819100E-02, 0.30180500E-01, -.71890200E-01, -.21364300E-01, -.21635100E+00, -.38921900E+00, 0.48943000E+00, 0.19211600E+00, 0.40320100E+00, 0.98951400E+00, -.12338300E+00, -.44884300E-02, 0.89666400E-02, 0.35655600E+00, 0.63704500E-01, -.17764600E+00, 0.38546200E+00, -.70792300E-01, -.31699600E+00, -.18466400E+00, -.10668900E+01, 0.23753700E+00, 0.17642700E-02, 0.11855700E+01, -.65055300E+00, 0.96489500E+00, 0.13455900E+00, -.25337700E+00, 0.29593600E-01, 0.18625500E+00, 0.11649400E+00, 0.21456300E+00, -.18921800E+00, -.18989700E-01, -.49493800E+03, -.36352000E+03, 0.11456700E+03, 0.20550300E+03, 0.38237200E+03, -.11948800E+03, -.44353500E+03, -.37228200E+03, 0.22671200E+03, 0.10748600E+03, 0.18034300E+03, 0.12255000E+02, 0.65745400E+02, -.49668800E+02, -.29274000E+03, -.12803100E+03, 0.25806100E+02, 0.36782300E+03, -.28757100E+03, 0.10334400E+03, 0.87536100E+03, 0.14379300E+03, -.44750800E+03, -.43219200E+03, 0.45342100E+03, 0.55194500E+03, 0.46984300E+03, -.37180600E+03, 0.33193600E+03, -.11459000E+04, 0.64685300E+03, 0.61916800E+03, 0.57294600E+03, 0.13913000E+04, 0.36622800E+03, 0.38712800E+03, 0.26083000E+03, -.29890200E+03, 0.18150900E+03, 0.15514100E+03, -.83816600E+03, 0.37489400E+03, 0.27304800E+03, 0.41908500E+03, -.41120200E+03, -.32951500E+03, 0.23888600E+03, -.49064500E+03, 0.29819200E+03, -.25046400E+03, -.81517700E+02, -.42053400E+03, 0.23554800E+03, -.72101000E+02, 0.21132700E+03, 0.18596900E+03, 0.69849700E+02, 0.82512000E+02, -.39073900E+03, 0.16534800E+03, 0.33859800E+02, -.31951700E+03, 0.39374000E+03, -.15568700E+03, -.40413000E+03, -.19687900E+03, 0.47824200E+03, 0.39871900E+03, -.18933900E+03, 0.34059100E+03, -.42059400E+03, 0.29368800E+03, 0.67519200E+03, -.16186800E+04, 0.73576800E+03, 0.87631800E+03, 0.80932100E+03, -.11057600E+04, 0.13791600E+03, 0.87199900E+02, -.98638600E+02, 0.79871500E+03, 0.30597700E+03, 0.94700200E+03, 0.42478200E+03, -.22347300E+03, -.19378600E+03, -.21239300E+03, -.67662800E+03, -.65289800E+03, 0.39542000E+03, -.35696000E+03, 0.28484900E+03, -.73386900E+03, -.36940900E+03, -.74827900E+03, 0.30902900E+03, 0.19779200E+03, 0.37414200E+03, -.10536600E+04, -.27071400E+03, 0.58391600E+01, -.76905900E+03, 0.46174700E+03, -.17521400E+03, 0.26133600E+03, 0.11609200E+04, -.63969100E+03, -.67071600E+03, -.58046300E+03, -.66504200E+03, -.19670100E+02, -.37713900E+03, 0.10682500E+03, -.58730400E+03, -.11005800E+03, 0.11796900E+04, 0.18017800E+04, -.85898700E+03, -.81171600E+03, -.90086600E+03, 0.59916000E+03, -.19969500E+03, 0.12685200E+03, 0.60869500E+03, -.57824900E+03, -.30706000E+03, -.90219400E+03, 0.20094800E+03, -.12635500E+03, -.10084200E+03, -.10047400E+03, -.35421300E+03, -.22684300E+03, -.71492100E+02, -.13768000E+03, 0.11295100E+03, -.10476600E+03, -.90273200E+02, -.50638300E+03, 0.25705800E+03, 0.83628500E+03, 0.25320000E+03, 0.20720400E+03, 0.10443200E+03, 0.33224500E+03, 0.26981800E+03, 0.19522700E+03, 0.14151900E+03, -.45882800E+03, 0.27240500E+03, -.12124400E+03, 0.51273100E+01, -.13618700E+03, 0.34226400E+03, 0.39063600E+03, -.52274800E+03, -.70302900E+03, -.42860800E+03, 0.50818200E+03, -.11110000E+04, 0.68818900E+02, 0.46018100E+01, 0.15309600E+01, -.66870400E+01, 0.32066000E+01, 0.29625300E+02, 0.32356100E+01, 0.27116200E+02, 0.26795400E+02, -.17848400E+02, -.13033300E+03, -.67571500E+02, 0.28610600E+03, -.25000500E+03, 0.24627800E+02, -.14249000E+02, -.13798600E+03, -.38147600E+02, 0.35987300E+03, 0.13867900E+03, -.24265700E+03, 0.18322900E+03, 0.22070400E+03, -.21357900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.76261500E+00, 0.42079400E+00, 0.49942100E-01, -.10703700E+00, -.63876600E+00, -.91784200E-01, 0.10600000E+00, -.13307400E+00, -.81275700E-01, 0.80994900E-01, 0.56216400E+00, 0.28086500E+00, -.23262300E+00, 0.70824000E-01, -.17716100E+00, -.55953600E-01, 0.87268900E-01, -.55132200E+00, 0.92766400E-01, -.27824000E-01, -.12731300E+00, -.13296100E+01, 0.14320700E+01, -.52951900E+00, -.55107600E-01, 0.26795100E+00, -.22208300E+00, -.18021700E+00, 0.35829200E+00, -.24972500E+00, 0.72790200E-01, 0.55504100E-01, -.38132100E-01, -.74771400E-01, -.14587900E-01, 0.77698500E-01, -.36335000E-02, 0.31349700E+00, 0.12793000E+00, 0.85288600E-02, -.23695100E+00, -.30156100E+00, 0.12626700E+01, -.22696400E+00, 0.14037900E+00, -.71265800E-01, 0.35745700E+00, 0.15025900E+00, 0.17965800E+00, 0.15146000E+00, 0.39596900E+00, 0.19336500E+00, 0.48072900E-01, -.17214200E-01, -.72943100E-01, 0.39104700E-01, 0.35764100E-01, 0.21623500E-01, 0.15992400E-03, 0.96413200E-01, -.98976200E-01, -.34294900E+00, 0.80402300E-01, -.18602100E-01, -.55002800E+00, -.11343600E+00, -.41067400E-01, 0.19957700E-01, -.11957300E-01, -.12611200E-02, 0.12163200E+00, 0.32760900E-01, 0.64058000E-01, -.10953400E-01, -.15517400E+00, -.88527000E-02, -.46779100E-01, -.85055700E-01, 0.24837300E+00, 0.38487300E-01, 0.35456200E-03, 0.16602400E+00, 0.10180600E+00, -.28546300E-01, 0.45855600E-02, -.37932000E+00, 0.24889300E+00, -.16032000E+00, -.16107600E+00, 0.38404000E-01, 0.17806400E+00, 0.21215600E-02, 0.44762300E+00, -.47046400E+03, 0.21059700E+03, 0.21499400E+03, 0.27213500E+03, -.51449200E+03, 0.45126100E+03, 0.19800400E+03, -.11504600E+03, -.99713800E+02, -.96712700E+02, 0.13439400E+02, -.90220200E+02, 0.16321600E+02, 0.70935500E+02, -.16630800E+02, -.76997700E+02, -.23970800E+03, -.27988400E+03, 0.15834300E+03, -.12445800E+03, 0.13993800E+03, 0.86191500E+02, -.45007300E+02, 0.10739800E+02, -.11487500E+02, 0.21689000E+03, -.10734000E+03, 0.14661400E+03, -.94518400E+03, 0.43857600E+03, 0.16792300E+04, 0.47259400E+03, -.11025900E+03, -.95010500E+02, 0.56680400E+03, 0.64298700E+02, 0.89629700E+02, 0.21162600E+03, -.62845600E+03, -.55282400E+03, 0.29811100E+03, -.10367900E+03, 0.27641100E+03, 0.15494600E+03, 0.31193500E+03, -.13718400E+03, -.31256700E+02, 0.39053900E+03, 0.20164800E+03, 0.72674100E+03, 0.24578000E+03, -.13859700E+03, -.40093000E+02, -.12352400E+03, -.26010500E+02, 0.80352500E+01, 0.95002900E+02, 0.18769000E+03, -.15069600E+03, 0.69521300E+02, -.46822100E+02, -.49298100E+02, 0.76028500E+01, 0.13864000E+03, 0.24655000E+02, -.63270500E+02, 0.92714000E+01, 0.42146000E+02, 0.11136900E+03, 0.84110700E+02, 0.37924700E+02, -.69716000E+01, 0.73843400E+03, -.33216200E+03, -.13613400E+04, -.36920000E+03, 0.24663200E+03, -.12970600E+03, -.42660400E+03, -.46167000E+02, -.12838900E+03, -.42159300E+03, 0.24188300E+03, 0.45773900E+02, -.18993000E+02, -.21711100E+02, -.22886900E+02, 0.12071800E+03, 0.16060500E+03, -.16848000E+03, -.17017600E+03, -.19207300E+03, 0.17109300E+03, 0.76193200E+02, 0.11759700E+03, -.28433300E+02, -.10246300E+04, -.58799600E+02, 0.96260800E+02, 0.15180800E+03, -.32159900E+03, 0.44552800E+02, 0.24970400E+03, -.10216000E+03, 0.84084600E+03, 0.71194800E+03, -.32714100E+03, -.85606000E+03, -.35597300E+03, -.16789400E+03, -.40438600E+02, -.31187400E+03, -.18852100E+03, -.18594900E+03, -.18796000E+03, -.50333800E+03, -.12634200E+04, 0.60984500E+03, 0.73796700E+03, 0.63169400E+03, -.92079300E+02, 0.21110200E+03, 0.29414300E+03, -.11508600E+03, 0.34734400E+03, 0.35381900E+03, 0.27783700E+03, 0.45265700E+03, -.21289600E+03, -.12173700E+03, -.22632800E+03, -.76065300E+02, -.14497000E+03, -.37437500E+02, 0.17523500E+03, 0.58812500E+02, -.20290700E+03, 0.93874800E+02, -.11091100E+04, 0.55250400E+03, 0.40911000E+03, 0.55454600E+03, -.87377900E+02, -.14713300E+03, 0.32925900E+03, 0.15563000E+02, 0.37412300E+03, -.76198500E+02, 0.50299700E+03, -.10252400E+03, 0.44568400E+02, 0.25590500E+02, 0.51250400E+02, 0.20979100E+02, 0.44918600E+02, 0.10091500E+03, 0.60510900E+02, 0.92344600E+02, 0.34837700E+02, 0.17236600E+03, -.15800900E+02, -.62416800E+01, 0.79404000E+01, -.29576100E+01, 0.29303100E+01, -.74358000E+01, 0.32828900E+01, -.28861700E+01, -.37834600E+01, -.47045500E+02, 0.49312800E+02, -.24824100E+01, 0.83772600E+02, -.25714300E+02, -.12891200E+02, 0.70011100E+01, 0.29646100E+03, 0.13419600E+02, 0.29731100E+02, 0.48732100E+02, 0.27455700E+03, 0.81409600E+02, 0.20615500E+00, -.22423600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.97315800E+00, 0.11451900E+00, 0.41666100E+00, -.67577600E+00, -.37708100E+00, 0.24816900E+00, 0.38814600E-01, -.28175400E+00, -.10767200E+00, -.12555200E+00, -.33344600E+00, 0.48503000E-01, -.70745200E-01, -.49277500E+00, -.43574600E-01, 0.86617000E-01, 0.16401600E+00, 0.15594300E+00, 0.19489100E+00, -.38006400E+00, 0.46933900E+00, 0.42902100E+00, -.55722400E+00, 0.20187000E+00, -.93322600E-01, -.19550100E+00, -.28794200E+00, -.54272800E-01, 0.53024500E-01, -.17622800E+01, 0.24261900E+00, 0.27370600E-01, -.46632100E+00, -.32213400E+00, 0.14701500E-01, 0.78595300E-01, -.24297800E-01, 0.51764800E+00, -.16606200E+00, 0.39171800E-01, 0.60210600E-02, -.32017500E+00, 0.56926600E+00, 0.11668000E-01, 0.34130800E+00, -.63126500E+00, 0.19352400E+00, -.20990200E+00, -.50611600E-01, 0.64067800E-01, 0.44885100E+00, 0.38116900E+00, -.57393600E-01, -.57174400E-01, -.20693400E+00, -.10048700E-01, -.10242500E-01, -.11355900E+00, 0.37556600E-03, 0.43531600E-02, -.13197500E+00, -.23767800E+00, 0.17984200E-01, 0.21877300E+00, -.80820300E+00, -.91258600E-01, 0.36407300E+00, 0.25362500E+00, 0.19129700E-01, -.98323000E-03, -.85451700E-02, 0.87206500E-01, -.11090600E+00, -.97662400E-02, 0.87939300E-01, 0.37764100E-01, 0.38882700E-01, -.42481200E-01, -.12001700E-01, -.71383800E-01, 0.65868300E-04, 0.35987900E-01, 0.15026900E+00, 0.12347000E+01, 0.68291800E-01, 0.60393300E-01, 0.24738400E+00, 0.15827200E+00, 0.20367100E+00, -.10396700E+00, -.14661600E+00, 0.18273100E-01, -.12871200E+00, -.45446200E+00, -.28106000E+03, -.20707300E+03, -.37425800E+03, 0.23414700E+03, 0.39613600E+03, 0.10049400E+03, -.45796900E+02, -.21988200E+03, -.49090100E+02, -.56241200E+02, -.11647400E+03, 0.86743700E+02, 0.10825200E+03, 0.52916600E+02, -.12149900E+03, -.34407900E+02, -.67186600E+03, 0.31816000E+03, 0.27853500E+02, 0.33592600E+03, -.55699800E+02, -.55957800E+03, 0.28360000E+03, 0.40933900E+03, 0.79287000E+03, -.35618300E+03, 0.37131200E+03, 0.72529400E+02, -.17809400E+01, -.18720300E+03, -.36257000E+02, 0.14287400E+03, 0.28495300E+03, 0.24682100E+03, 0.35331900E+03, 0.46062300E+03, 0.84852100E+01, -.95668700E+03, 0.95183900E+03, -.49739200E+03, -.79684300E+03, -.47592100E+03, 0.51381900E+02, -.30895400E+03, -.15609300E+03, 0.34665700E+03, -.11594200E+03, 0.21123200E+02, -.11647900E+04, 0.49285800E+02, -.92744900E+01, 0.33842300E+03, -.24635600E+02, 0.34674200E+03, 0.26531400E+03, 0.11761300E+03, 0.16513700E+03, 0.86204300E+02, -.59831700E+02, -.15511200E+03, -.47569000E+03, 0.25509000E+03, 0.35259600E+01, 0.23786000E+03, -.82188300E+02, 0.58600300E+03, 0.47254000E+02, -.22413100E+03, -.30418900E+03, 0.65730300E+03, -.18597300E+03, -.26117900E+04, 0.12692700E+04, 0.14711300E+04, 0.13059600E+04, 0.10950800E+03, -.17586300E+03, 0.97160800E+02, -.65428500E+03, -.59255400E+02, -.28860200E+02, 0.25243800E+04, -.44936000E+03, 0.22058900E+03, 0.42860300E+03, 0.22467700E+03, 0.54008000E+03, -.55697200E+03, 0.55566900E+03, 0.49688000E+03, 0.88666700E+03, -.77230800E+03, 0.29062500E+03, 0.20560400E+04, -.10589500E+04, -.11309100E+04, -.10280200E+04, -.19933900E+03, -.42599200E+03, -.28844800E+03, 0.65107600E+03, -.53231400E+03, -.45794700E+02, -.80246000E+03, 0.91799400E+03, -.48598100E+03, 0.35068300E+03, -.45899700E+03, -.38952900E+03, -.38348000E+03, -.16526400E+03, 0.18326700E+03, 0.39243600E+02, -.20739000E+03, 0.10149900E+04, 0.20746100E+03, -.79800300E+02, -.36917300E+03, -.10378200E+03, 0.95823100E+02, 0.10905500E+03, 0.23351700E+03, 0.36747200E+03, 0.46208800E+03, 0.44572300E+02, -.86242700E+03, 0.53657400E+03, -.28119300E+03, -.17046800E+03, -.26828800E+03, -.13471800E+02, -.17131800E+03, -.22770900E+03, 0.70833500E+02, -.16928300E+03, 0.12152300E+03, -.36542500E+03, -.14775700E+04, 0.73941600E+03, 0.41623800E+03, 0.73876400E+03, 0.30435100E+03, -.13056800E+03, 0.48216700E+03, 0.78531500E+02, 0.33701700E+03, -.10810300E+03, -.10545100E+03, 0.47514200E+03, -.23144800E+03, -.17865500E+03, -.23760400E+03, 0.72622300E+02, 0.63277200E+03, -.64934900E+03, -.79482100E+03, -.76213300E+03, 0.51044100E+03, -.42564100E+03, -.40219100E+02, -.68400500E+01, 0.27560100E+02, -.75325400E+01, -.22204400E+02, -.36336900E+02, 0.71169100E+01, 0.52381200E+00, 0.66595900E+01, 0.11819400E+02, -.48914400E+02, -.10904000E+02, 0.46469400E+02, -.27416500E+03, 0.18066400E+02, -.22559600E+02, 0.21094400E+03, -.55226000E+02, 0.98459600E+02, 0.12679000E+03, 0.22219000E+03, 0.13126400E+03, 0.10372400E+03, -.11018600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10592900E+01, 0.21713700E+00, 0.63715900E-01, -.56551700E+00, -.11313200E+01, -.17152300E+00, 0.14036000E+00, 0.57660800E-01, -.10008100E+00, -.19967400E+00, -.81875000E+00, -.15946800E+00, 0.35595200E+00, -.89446600E+00, 0.23849000E+00, 0.90421900E-01, -.33313000E+00, 0.55934600E-01, 0.15310500E+00, -.40021600E-01, 0.33344900E-01, 0.10358900E+01, -.17935700E+01, 0.93058100E+00, -.91895200E-01, -.10266500E+00, 0.12584700E+00, -.41487000E+00, -.44144500E+00, 0.17249300E+00, 0.29879400E-01, 0.50710500E-02, 0.46015300E+00, -.18388500E+00, -.47579000E-01, -.33779200E+00, 0.18640200E-01, -.69008700E-01, 0.26947900E+00, 0.19760300E+00, 0.58221700E+00, 0.26389100E+00, 0.77899600E+00, -.87903100E-01, 0.22307900E+00, -.28706100E-02, -.83685100E-01, 0.11656400E+00, 0.27062600E+00, -.82467100E-01, -.11619600E+01, -.87621400E+00, -.11891400E+00, -.22720700E-01, 0.11238100E-02, 0.56727100E-01, 0.37526300E-02, 0.13243300E+00, 0.59941400E-03, 0.16179900E+00, 0.18550200E+00, 0.49820300E-01, 0.19715700E-01, 0.29962400E+00, -.42209300E+00, 0.93414800E-01, 0.27158100E+00, -.27267500E+00, 0.55046300E-01, 0.74340300E-03, -.19559200E+00, -.33375000E-02, -.26569100E+00, 0.11165400E+00, 0.11341000E+00, 0.63361600E-01, 0.13206400E+00, 0.20785400E-01, 0.50785400E+00, -.22299500E+00, -.14059300E-03, -.61353900E+00, 0.69806700E+00, -.67742700E+00, -.33915600E-01, 0.74358600E-01, -.33494400E+00, 0.26682900E+00, 0.17955500E+00, -.19299500E+00, -.20614600E-01, 0.41793100E-01, 0.21871300E+00, -.27256400E+00, 0.57440400E-01, -.49576100E+03, -.58317700E+03, -.31154700E+02, -.82697200E+02, 0.17639100E+03, -.10525000E+03, -.29537300E+03, -.83049700E+02, -.99567900E+02, -.94011800E+02, 0.78619400E+02, 0.26031800E+03, 0.16431300E+03, -.64920700E+02, -.16096000E+02, 0.10367000E+03, -.37948100E+02, -.79778900E+03, -.51852300E+02, 0.19186400E+02, -.97133900E+02, -.26719200E+03, -.56672800E+03, -.17701100E+03, -.43327200E+02, -.26016500E+03, 0.35231400E+03, -.19977800E+03, -.48530500E+03, -.17614100E+03, -.80106500E+03, 0.22520700E+03, -.31076600E+03, -.13827800E+03, 0.58735100E+03, 0.15709300E+03, 0.11784300E+04, 0.16698700E+04, -.82188500E+03, -.10646700E+04, -.83494100E+03, 0.28723800E+03, -.17585900E+03, -.21282600E+03, 0.52552900E+03, -.51565700E+03, -.98327400E+02, -.18770900E+04, 0.38505400E+03, -.19615100E+03, 0.19330900E+03, -.19336500E+03, 0.64951400E+02, 0.10294900E+03, -.20267700E+02, 0.38146500E+03, 0.54498200E+02, 0.30460300E+02, 0.27729500E+03, -.30712600E+03, 0.13793100E+03, 0.11955400E+03, 0.15359600E+03, -.10857000E+03, -.29742300E+02, 0.28326500E+02, -.29421200E+03, -.18081200E+03, 0.58069600E+02, -.54055700E+03, 0.45206700E+03, -.20504800E+03, 0.11174300E+03, -.22591100E+03, 0.58402700E+03, -.36469800E+03, -.19594100E+03, -.66555400E+03, -.91046000E+03, -.39268100E+03, -.44738000E+03, -.33429200E+03, 0.17200200E+03, 0.28317400E+03, 0.16714100E+03, 0.42154000E+03, 0.12758600E+03, -.51711700E+02, 0.66358600E+03, 0.64244600E+03, 0.23104800E+03, 0.36509300E+03, 0.27306000E+04, -.13453300E+04, -.11706800E+04, -.13653100E+04, 0.55807100E+03, -.39139500E+03, -.18230500E+03, 0.97343800E+03, -.10004500E+04, -.27342500E+03, -.26499500E+04, 0.12139000E+04, -.58736800E+03, 0.62999000E+03, -.60695100E+03, 0.49262300E+03, -.48739400E+02, -.31861700E+03, -.65056300E+02, -.17648600E+03, 0.17302000E+03, -.11120400E+04, -.11304100E+04, 0.55590200E+03, 0.17521700E+03, 0.56509700E+03, -.16456700E+03, 0.22880200E+03, 0.81328700E+02, -.71619300E+01, 0.64165000E+03, 0.29958400E+03, 0.58791200E+03, 0.59718500E+02, -.22547200E+02, 0.10549300E+03, -.29861100E+02, 0.17587600E+03, -.11788000E+02, 0.18902500E+03, 0.10790200E+03, -.18388400E+03, 0.22624200E+02, -.82265200E+03, -.66767700E+03, 0.33097700E+03, -.42276900E+03, 0.33379300E+03, -.51735100E+02, -.53342900E+02, 0.45620800E+02, -.15071200E+03, 0.15330900E+03, -.19098200E+03, 0.69617500E+03, -.37402200E+03, 0.18161200E+03, -.27249200E+02, 0.18693900E+03, -.12214100E+03, 0.31497800E+02, 0.31811700E+03, 0.34106100E+03, 0.42657100E+02, -.17092300E+03, 0.57158200E+03, -.47928400E+02, 0.49344600E+01, -.12978400E+02, 0.24958200E+01, -.18819800E+02, -.32528700E+02, -.85019900E+01, -.23766800E+02, -.15541400E+02, 0.11802200E+02, -.55314700E+02, 0.49933000E+01, -.43830100E+02, 0.36798300E+02, 0.94562400E+02, 0.10213400E+02, 0.30605600E+03, -.38532600E+02, -.10644700E+03, 0.40573100E+01, 0.26457900E+03, -.96571000E+02, -.10735400E+03, 0.19413900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16615300E+01, -.96036800E+00, -.64480200E-02, 0.11741800E+00, 0.18975000E+01, -.42964400E+00, -.13237100E+00, -.38420900E-01, 0.38794500E+00, 0.48815700E-01, 0.78776700E+00, 0.39990400E+00, 0.30302000E+00, 0.13339000E+01, -.18065800E+00, -.55325800E-01, 0.49881100E+00, 0.17512900E+00, -.42683400E+00, 0.68490800E-01, 0.30053800E+00, -.72938900E+00, 0.17501500E+01, -.84542600E+00, 0.14225400E+00, 0.19611700E+00, 0.13003500E+00, 0.80284000E+00, 0.54154900E+00, 0.15256300E+01, -.11491100E+00, -.28734500E-01, 0.28746000E-02, 0.77448700E+00, 0.10137700E+00, -.41428300E+00, -.74972200E-01, -.68441200E+00, 0.20080700E+00, -.18727400E+00, -.55055600E+00, -.25868300E+00, -.14760600E+01, -.15690700E+00, -.36668100E+00, 0.12753000E+01, -.74188500E+00, -.57093700E+00, -.35920200E+00, 0.18945000E+00, 0.13329200E+01, 0.92426600E+00, 0.57451300E-01, 0.57561100E+00, -.63488200E+00, -.46789800E+00, -.27978100E+00, 0.89304700E+00, 0.24079100E-02, 0.67218600E+00, 0.74073200E+00, 0.14254200E+01, 0.28193700E-01, 0.14105000E+00, 0.20256700E+01, 0.18191400E-01, -.45168500E+00, 0.68190200E-01, -.10514200E+00, 0.81660500E-02, 0.26794800E+00, 0.31304400E+00, 0.17246700E+00, -.18251900E+00, 0.49135500E-01, 0.91934900E-03, 0.15960100E+00, -.27555600E+00, 0.32241000E+00, -.27152200E+00, -.12281200E-02, -.10291300E+01, 0.11100700E+01, 0.95524600E-01, -.13335400E+00, -.77067700E+00, -.25116000E+00, -.18518300E+00, 0.29020500E+00, -.72787500E-01, 0.38812000E+00, -.80808800E-01, 0.71312800E+00, 0.19032600E+01, 0.29084900E+00, -.22551300E+00, -.15089900E+04, -.11768200E+03, -.47905200E+03, -.29143700E+02, 0.28079500E+02, 0.13603800E+03, 0.21705500E+02, -.46451000E+02, 0.74162100E+02, -.63414700E+02, 0.41779000E+03, 0.25001000E+03, 0.33557600E+02, 0.36319900E+02, -.11041600E+04, 0.51064000E+03, 0.99122400E+03, 0.55211200E+03, 0.82042500E+03, 0.28198300E+03, 0.22985800E+03, 0.12785000E+04, -.84266500E+03, 0.17668100E+03, 0.12462600E+03, -.43604600E+04, 0.22657600E+04, -.37860700E+03, 0.21801900E+04, 0.52065400E+03, 0.64056900E+02, 0.50936900E+03, 0.68198400E+01, 0.20333400E+04, 0.40293900E+03, 0.26922700E+04, 0.30735100E+04, -.15928100E+04, -.56065800E+03, -.15367500E+04, 0.65071500E+02, -.66967300E+03, 0.37370900E+03, 0.12974100E+04, -.10742300E+04, -.45324300E+03, -.28845400E+04, -.72316200E+03, 0.41380300E+03, 0.21114800E+03, 0.36464600E+03, -.23244900E+03, -.47886400E+03, -.10248400E+03, -.16875300E+03, 0.60836200E+03, -.44656700E+03, -.92232100E+02, 0.14424700E+03, -.35391900E+02, -.51465800E+03, -.72193600E+02, -.42841600E+03, 0.38565900E+03, -.12428900E+03, -.54478800E+03, 0.13614300E+03, 0.36690600E+03, -.12901800E+04, 0.22641600E+04, -.12276600E+04, 0.75942900E+03, -.11323600E+04, -.39581800E+03, 0.73967300E+02, -.52333500E+03, -.23330700E+03, -.38628200E+03, -.42408600E+03, -.29321600E+03, -.11843600E+04, 0.58515800E+03, 0.70684200E+03, 0.59219800E+03, 0.30742000E+03, -.23201600E+03, -.67148500E+03, 0.93730200E+03, 0.39010100E+03, -.35764800E+03, 0.42556600E+03, 0.76443100E+04, -.38999900E+04, -.17699200E+04, -.38221500E+04, -.44668400E+03, -.43515300E+03, -.59672800E+03, 0.16266200E+04, -.25275900E+04, -.39394100E+03, -.50236100E+04, -.40314000E+03, 0.13220000E+03, 0.14551600E+04, 0.20157400E+03, 0.93506900E+03, 0.66218600E+03, -.38599900E+03, 0.12868200E+04, 0.40357200E+03, 0.29422900E+03, 0.20957700E+04, -.49053600E+03, 0.30619500E+03, -.25377600E+03, 0.24551200E+03, -.89035100E+02, -.51656900E+03, 0.41272400E+03, -.70875000E+02, -.29308100E+03, -.20459900E+03, -.52001700E+03, 0.12852100E+04, -.67735000E+03, -.57700800E+03, -.64260100E+03, 0.18681400E+03, -.13331300E+03, 0.31535000E+03, 0.39101000E+03, -.91891000E+03, -.13043100E+03, -.11309300E+04, 0.26867500E+04, -.13397700E+04, -.19619400E+04, -.13432700E+04, 0.35098900E+01, -.53614100E+02, -.41418600E+03, -.48058300E+03, -.85573100E+03, 0.14291100E+02, -.22973800E+04, 0.89056000E+03, -.43085300E+03, -.42018300E+03, -.44512500E+03, -.74152900E+03, -.59514000E+03, 0.15606600E+03, -.89415300E+03, -.29974000E+03, -.33891100E+03, -.24602200E+02, 0.14198900E+03, 0.89425000E+00, -.65293200E+02, -.58418500E+01, 0.14226900E+01, -.29350800E+02, 0.55738200E+01, 0.30778000E+02, 0.60825400E+01, 0.15722700E+03, -.15528000E+02, -.72467200E+02, -.13829400E+03, 0.14712400E+03, 0.14756300E+02, -.22018000E+03, -.35424700E+02, -.10458100E+03, -.21321800E+03, -.10991200E+03, -.35779300E+03, -.48035100E+03, -.11129000E+03, 0.39447700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.55441500E+00, 0.32603200E-01, 0.64696300E+00, -.29791200E+00, -.15065000E+00, -.11740200E+00, 0.61849900E-02, 0.37734300E-01, -.65369300E-02, 0.63282600E-02, 0.80088100E-01, -.19899900E-01, -.45796400E+00, -.69738800E+00, 0.11088000E-01, -.12849100E-01, -.26937400E+00, 0.44487900E-01, 0.73416800E-01, -.14025100E+00, 0.26447700E+00, 0.56730500E+00, -.23754300E+00, 0.19883800E+00, -.79630100E-01, -.27181500E+00, 0.83778200E-01, -.91714500E-02, -.14338100E+00, -.12580000E+00, 0.69843600E-01, 0.61446800E-02, 0.12455100E+00, 0.73014200E-03, -.17965600E-01, -.22498400E+00, 0.21149800E-03, 0.10863800E+00, -.34107800E-01, -.26666400E-01, 0.17736600E+00, 0.15680900E+00, -.12392000E+00, 0.78103300E-01, 0.35977400E-01, 0.15391700E-01, 0.92197000E-01, -.21712300E-01, 0.31287400E-01, 0.15232800E+00, 0.18223000E+00, -.96290000E-01, -.28724000E-01, 0.66719700E-01, 0.93864200E-01, 0.46637700E-01, -.22608600E-01, 0.37808500E+00, -.36892700E-03, 0.11911100E+00, 0.73509200E-01, 0.12343900E+00, 0.17548200E-01, 0.11069000E+00, -.16882900E+00, -.31067000E+00, -.17191600E+00, 0.14631400E+00, 0.64425200E-01, 0.32929500E-03, -.24810600E-01, 0.63018100E-01, -.50391200E-03, -.57872700E-01, -.51598300E-01, -.10865700E-01, 0.47032900E-01, -.10571400E+00, -.31365200E-01, -.17145300E-01, 0.26334800E-04, 0.17174100E+00, -.13382100E-02, -.28851200E+00, -.41795000E-01, -.13420600E-01, 0.14242500E-01, 0.22240800E-01, 0.45222200E-01, 0.29745000E-01, -.41226700E-01, 0.11086000E-01, 0.17740600E-01, -.10114100E+00, -.31163100E+00, -.47883300E+00, 0.11367900E+00, 0.15910200E+03, 0.28324100E+02, 0.20178700E+02, -.18153400E+02, -.20132200E+03, -.82807400E+01, -.42674800E+02, -.10926100E+03, 0.87267800E+02, 0.67526200E+02, 0.88190700E+02, -.94012300E+02, 0.11209500E+02, -.23967600E+03, 0.12303000E+03, -.34421300E+03, 0.11981900E+03, -.18150400E+03, -.21255900E+03, -.53735500E+02, -.55090500E+02, 0.51015500E+03, -.27166600E+02, -.20161900E+02, 0.16737100E+04, -.84215200E+03, -.63300000E+03, -.83683600E+03, -.34232100E+03, 0.39137700E+03, -.29770100E+03, 0.76025000E+02, -.30823500E+03, 0.57936800E+02, -.48408500E+03, 0.89785700E+03, -.44556800E+03, -.80375500E+03, -.44893300E+03, 0.13794700E+03, -.24418300E+03, -.30220100E+03, 0.15008600E+03, -.50533800E+02, -.12263200E+03, -.88043100E+03, -.12633000E+02, 0.49869900E+01, 0.16103500E+03, 0.50988200E+01, 0.29371900E+03, 0.16137300E+03, 0.63698700E+02, 0.13732500E+03, 0.26561700E+02, -.25365400E+02, 0.53041000E+02, -.26102800E+03, 0.12734200E+03, 0.18736300E+03, 0.13055200E+03, -.27266400E+02, 0.12294300E+03, 0.16751400E+03, -.18805200E+03, -.25772100E+03, 0.19378500E+03, -.22529900E+03, -.23364800E+04, 0.11732000E+04, 0.93167100E+03, 0.11683900E+04, 0.22598100E+03, -.39011100E+03, 0.44641500E+03, -.17033200E+03, 0.13060200E+03, -.10507800E+03, 0.12729500E+04, -.46056600E+03, 0.23114400E+03, 0.21844400E+03, 0.23027600E+03, 0.49262600E+03, -.95336800E+02, 0.11238500E+03, 0.28874800E+03, 0.61728300E+03, -.17254200E+03, 0.32971500E+03, 0.32853000E+03, -.15982700E+03, -.32857400E+03, -.16427100E+03, 0.28997200E+03, -.43527500E+03, -.35345300E+02, 0.32682200E+03, 0.50936300E+02, -.17189000E+03, -.57464800E+03, 0.25738700E+03, -.12308700E+03, 0.16862400E+02, -.12869400E+03, -.27239500E+03, -.55335900E+03, 0.14486500E+03, 0.10833100E+03, 0.88615200E+02, -.26574700E+03, 0.12402500E+03, 0.10144000E+03, -.52147800E+02, -.92818300E+02, -.50849000E+02, 0.36914900E+02, 0.28729700E+03, -.80934600E+02, 0.16913500E+02, 0.33894300E+03, 0.17322000E+03, -.23071300E+03, 0.30748100E+03, -.15170800E+03, -.13054500E+03, -.15374300E+03, 0.76428700E+01, -.13919900E+03, -.75636400E+02, 0.17963400E+03, 0.61876100E+02, 0.21519600E+02, -.34415400E+03, -.12343700E+04, 0.61516700E+03, 0.47388200E+03, 0.61713300E+03, 0.21655200E+03, 0.11358800E+03, 0.27107100E+03, 0.13330300E+03, 0.34056400E+03, 0.49273900E+02, 0.53924900E+03, 0.58126000E+01, -.42449700E+01, -.89156600E+02, -.29889300E+01, 0.12640000E+03, 0.36661900E+03, -.15231700E+03, -.20686200E+03, -.27777900E+03, 0.15911000E+03, 0.69995900E+02, -.28787400E+02, 0.54637500E+01, 0.14831600E+02, 0.39030900E+01, -.12991200E+02, -.22758100E+02, -.67824400E+01, -.73364500E+01, 0.10628900E+00, -.20639300E+02, -.48105400E+02, 0.24901500E+02, 0.11048900E+03, -.19047400E+03, 0.44453100E+02, 0.54976900E+01, 0.18758200E+03, -.25830800E+02, 0.12917100E+03, 0.79997000E+02, 0.28291800E+03, 0.16069900E+03, 0.98292500E+02, -.49083500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29663500E+01, -.34617700E+00, -.48649200E+00, 0.21620700E+00, 0.11501200E+01, 0.90979400E+00, -.31420400E+00, 0.23075900E+00, 0.22604400E+00, -.15388900E+00, -.20409500E+00, 0.30264700E-01, -.19868900E+01, -.86698000E+00, 0.12585600E+01, 0.28181200E-01, 0.51597000E+00, 0.28542700E+00, -.93104200E-01, -.85283100E-01, 0.16843000E+00, 0.63380700E+00, -.99822100E+00, 0.40756900E+00, 0.15097700E-01, -.12131100E+00, -.46311800E-01, -.18333300E+00, -.38778700E-01, -.89158600E+00, 0.13948600E+00, -.60023000E-01, -.28330500E-01, -.60754500E+00, -.47336500E-01, 0.16205800E+00, 0.21539100E-01, 0.10107400E+00, 0.40977700E+00, 0.21389200E+00, 0.78739600E+00, -.25648600E-01, -.19586000E+01, 0.17801100E+00, -.26753700E+00, -.27402100E+00, 0.38833900E-01, -.21747000E+00, -.26045800E+00, -.31756300E+00, 0.42769700E+00, 0.43745700E+00, 0.77070100E-01, 0.15567100E+00, -.75812800E-01, -.20402000E+00, 0.43448600E-01, -.16507500E+01, -.87642900E-03, -.30132500E+00, 0.64946400E-01, -.24602400E+00, -.29240300E-01, -.42473100E-01, -.12375500E+00, -.12159700E+00, 0.41596700E+00, 0.35904800E+00, 0.34441300E+00, 0.97815600E-03, 0.10276600E-01, 0.22782100E+00, 0.28182100E+00, 0.27527100E-01, 0.33675500E+00, -.30601000E-01, -.27196900E+00, -.46534600E+00, 0.52950300E+00, 0.45355000E+00, 0.60362400E-03, 0.75581900E+00, -.27545400E+00, -.61199200E+00, 0.16432500E+00, -.24431800E+00, 0.32037800E+00, -.15102700E+00, -.23121500E+00, 0.11201400E+00, 0.32826500E+00, 0.34256000E-01, -.28043800E+00, -.38206500E+00, 0.73451000E+00, 0.12687300E+01, -.37922300E+00, -.14208300E+01, -.11895500E+04, -.36279800E+02, 0.39321200E+02, 0.47979900E+03, 0.17247300E+02, 0.16543200E+03, 0.25367200E+03, -.38966600E+03, -.43361400E+03, -.33059200E+03, 0.17831900E+03, 0.17789300E+03, -.48831800E+03, 0.22713000E+03, 0.13346800E+04, 0.24416000E+03, 0.96977200E+02, 0.21809800E+03, 0.18372600E+03, 0.71817600E+03, -.11652100E+03, 0.22592500E+03, 0.86271100E+02, -.34591000E+04, 0.17575200E+04, 0.10115600E+04, 0.17295500E+04, 0.87439600E+03, -.86185100E+03, 0.13320200E+04, 0.44825200E+03, 0.50340200E+03, -.82963700E+03, 0.17286300E+04, -.15292400E+03, 0.60670000E+02, 0.12709800E+04, 0.76462400E+02, 0.36904300E+01, 0.31203400E+03, 0.19910200E+03, 0.18775900E+03, 0.25053200E+03, 0.48937200E+03, 0.24288500E+03, -.64306200E+03, 0.32625100E+03, -.32179200E+03, 0.32083300E+03, -.50935200E+03, -.42581700E+03, -.43767900E+02, -.63041400E+03, 0.74349300E+02, -.10351600E+03, -.70221800E+03, 0.49016900E+03, -.22590200E+03, -.51222900E+03, -.24508200E+03, 0.48622800E+03, 0.40295200E+03, -.19487500E+03, 0.10335500E+03, -.68809800E+02, -.52750900E+02, 0.11680500E+04, -.40318600E+03, 0.17702700E+03, 0.41330200E+03, 0.20161400E+03, -.32178100E+03, 0.15743600E+04, -.10398200E+04, -.11127900E+04, -.24536600E+03, 0.12950300E+04, -.42741600E+03, 0.16620400E+04, -.83707500E+03, -.81088500E+03, -.83102200E+03, -.13585300E+04, -.21905100E+03, -.93530500E+03, -.70456300E+03, -.98198800E+03, -.70589100E+01, -.10686600E+04, 0.15697600E+04, -.80917400E+03, 0.37709700E+03, -.78488200E+03, -.41169500E+03, 0.73974300E+03, -.65332600E+03, -.33678500E+03, -.46055600E+02, 0.85611200E+03, -.10316600E+04, -.14789600E+04, 0.71614500E+03, -.49062100E+03, 0.73947700E+03, -.32484100E+03, 0.45838400E+03, -.22221500E+03, 0.13835700E+03, 0.37331600E+02, 0.40074200E+02, 0.23961800E+04, 0.19857300E+04, -.98165400E+03, -.84049100E+03, -.99287700E+03, -.23310000E+03, -.90304700E+03, 0.40006800E+03, 0.79155100E+03, -.34561700E+03, -.90191600E+03, -.60807500E+03, 0.92195700E+03, -.46989400E+03, -.51235600E+03, -.46097900E+03, 0.22647800E+02, 0.18838600E+03, -.19106600E+03, 0.41553000E+02, -.20116200E+03, 0.21616300E+03, -.57910000E+03, 0.19722800E+04, -.98252200E+03, -.68964100E+03, -.98614800E+03, 0.11915300E+03, 0.22647900E+03, -.14145900E+03, 0.24914500E+03, -.48449000E+03, 0.23010800E+03, -.16908600E+04, 0.13424500E+03, -.59993100E+02, 0.19935300E+03, -.67130700E+02, 0.44086100E+01, -.32655300E+03, 0.31700700E+03, -.25969000E+03, 0.27826900E+02, -.86207900E+02, -.62742100E+03, 0.10430500E+03, 0.28939300E+01, -.31025700E+01, 0.15451500E+02, 0.26182400E+02, 0.90362200E+02, 0.46673400E+01, 0.25941100E+02, 0.23512900E+02, 0.53110900E+02, 0.22203500E+03, -.43895900E+02, -.49313900E+03, -.11884600E+03, -.19869600E+03, -.45556000E+02, -.61207500E+03, 0.11275300E+03, -.23074500E+03, -.52832000E+02, -.63329400E+03, -.10046600E+03, 0.99324600E+02, 0.55971500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21802200E+01, 0.70724600E+00, 0.63967200E+00, -.15573500E+01, -.18323800E+01, 0.40932900E-01, 0.31944900E+00, -.10505300E+01, 0.12884700E+00, 0.15088300E+00, -.17897000E+00, -.56206500E+00, -.25772800E+00, -.23840600E+01, 0.26030700E+00, 0.85442600E-01, -.87711000E+00, -.64139500E+00, 0.15219900E+00, 0.89122000E+00, -.17974500E+01, 0.16471100E+01, 0.20689300E+00, -.36313100E+00, -.10849400E+00, -.21124200E+00, -.16396800E+00, -.36868100E+00, -.71617900E-02, 0.13485900E+00, -.17579300E+00, -.29318400E+00, 0.68071400E+00, -.63796800E+00, -.64542900E-01, -.64021500E+00, 0.20811500E-01, 0.10833500E+00, 0.55627500E+00, -.88971900E-01, -.16545600E-01, -.75869800E-01, 0.59850200E-02, -.71519300E-01, -.67598800E+00, 0.44622200E+00, -.74107200E+00, 0.24184800E+00, -.16000500E+00, 0.60455000E+00, 0.20970500E+01, 0.10062100E+01, 0.25279000E+00, -.30469000E+00, 0.90670800E-01, 0.13986800E+00, 0.82397200E-01, 0.16845300E+01, -.81898000E-03, 0.10061100E+00, 0.15595900E+00, 0.99433900E+00, 0.22969500E-01, 0.31266000E+00, 0.14885600E+01, 0.66860500E+00, -.19221000E+00, 0.63045200E-01, -.13703700E+00, -.39703500E-02, 0.49321600E+00, -.19896200E+00, -.23395600E+00, -.13592400E-02, 0.42786000E+00, 0.99927900E-01, 0.11673800E+00, -.30502800E+00, -.50376900E+00, 0.14876900E+00, -.12694200E-02, -.51512700E-01, -.46124700E+00, -.61589500E-01, 0.20847800E+00, 0.49170800E+00, -.46800100E+00, 0.97322400E-01, -.15724700E+00, -.25843100E-01, -.36325800E+00, 0.66186900E-01, 0.18254400E+00, -.22724000E+01, -.81156500E+00, -.14026000E+01, 0.12791800E+00, -.89416600E+00, 0.12971100E+00, 0.12786400E+04, -.71771500E+03, -.11805800E+04, -.62470500E+03, -.19661500E+03, -.27640400E+03, 0.68782800E+02, 0.52832500E+03, 0.19971900E+03, -.24269100E+03, -.43514600E+03, -.38811500E+03, 0.25332000E+03, -.12881200E+04, 0.19397100E+03, -.14282000E+03, -.97361300E+02, -.52318500E+03, -.77023700E+03, 0.10096400E+04, 0.11496100E+03, -.73242800E+03, -.66334900E+04, 0.32062300E+04, -.10286100E+04, 0.33168300E+04, -.23702200E+04, 0.82520300E+03, 0.85426100E+03, -.17629600E+04, 0.38918500E+04, 0.52348600E+03, 0.74074100E+04, 0.55399500E+04, -.27050600E+04, -.13729900E+04, -.27700000E+04, 0.14301200E+04, 0.27171600E+02, -.11174600E+04, 0.20696000E+04, -.98239800E+03, 0.39790900E+03, -.70417100E+04, 0.58314700E+03, -.33061600E+03, -.67526700E+02, -.29746200E+03, 0.49315200E+03, -.61485200E+01, 0.33095300E+03, 0.95421200E+03, -.10021100E+03, -.30835400E+03, 0.74762900E+03, -.12590000E+04, 0.56764600E+03, 0.18693200E+03, 0.62967200E+03, -.54861700E+03, -.11644500E+03, 0.11565100E+03, -.13164900E+04, -.67999100E+03, 0.17003600E+03, -.93483800E+03, 0.20698700E+04, -.92985000E+03, 0.14438700E+04, -.10343100E+04, 0.17674100E+04, -.10646100E+04, -.88419800E+03, -.93674500E+03, -.35571900E+04, -.11017300E+04, -.13079600E+04, -.14903900E+04, 0.76245000E+03, 0.10489700E+04, 0.74516600E+03, 0.17641200E+04, -.19188500E+03, 0.64182200E+03, 0.19197500E+04, 0.20501600E+04, -.18689000E+03, 0.13039800E+04, 0.13737900E+05, -.67726400E+04, -.20128200E+04, -.68689600E+04, 0.19874600E+04, -.90508100E+03, -.18028900E+04, 0.41651300E+04, -.42939300E+04, -.38342100E+03, -.11565500E+05, 0.15205600E+04, -.66962500E+03, 0.20217800E+03, -.76028300E+03, -.21399200E+03, -.10118000E+04, -.24881800E+03, -.94725900E+03, -.24108100E+03, -.65985500E+03, -.96176500E+03, -.31154300E+04, 0.15041900E+04, 0.58404700E+03, 0.15571500E+04, -.67084300E+03, 0.51275700E+03, 0.46675600E+03, 0.16424600E+03, 0.25092100E+04, 0.67796700E+03, 0.18625200E+04, 0.14876100E+04, -.70635200E+03, -.62960900E+03, -.74381400E+03, 0.54265500E+03, 0.25606200E+03, -.16841700E+03, 0.98958400E+03, 0.25787600E+03, 0.37296900E+03, -.33956300E+04, -.44009800E+04, 0.21950200E+04, 0.57693400E+03, 0.22002600E+04, 0.45018300E+03, -.47658100E+01, 0.96998400E+03, 0.62682900E+03, 0.15330000E+04, -.10425000E+03, 0.27089500E+04, -.16359900E+04, 0.79497900E+03, 0.35303500E+03, 0.81763200E+03, 0.32986100E+03, 0.89004500E+03, 0.27797700E+03, 0.21707300E+03, -.28578300E+03, 0.35515800E+03, 0.15315900E+04, -.15370200E+03, 0.73392800E+01, 0.24851300E+02, 0.59109900E+01, -.38918400E+02, -.10636800E+03, -.12064100E+02, -.50470600E+02, -.38422800E+02, -.51920900E+02, 0.73135900E+02, 0.15372300E+03, -.22537900E+03, -.47263100E+03, 0.11888300E+03, 0.50419300E+02, 0.76422500E+03, -.72942900E+02, -.25359700E+03, 0.19722400E+03, 0.69918300E+03, 0.19834500E+03, 0.66599300E+02, -.58765000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14660900E+01, -.17443200E+00, -.23657700E+00, 0.95440400E+00, 0.13282000E+01, 0.26478100E+00, -.21505300E+00, 0.19302400E+00, -.76195000E-02, 0.35693700E+00, 0.84081100E+00, -.29000300E-02, -.22610200E+00, 0.15748700E+01, -.18663700E+00, -.17850200E+00, 0.53949500E+00, -.25910500E+00, -.15191700E+00, 0.28001700E+00, -.36940600E+00, -.60463200E+00, 0.12832200E+01, -.64753800E+00, 0.36979600E-01, 0.24662200E-01, -.14050200E+00, 0.21743300E+00, 0.18734300E+00, -.17675600E+01, -.76124500E-01, 0.17414900E+00, -.61574700E+00, 0.79924000E+00, 0.43416300E-01, 0.66524600E+00, -.63535500E-01, -.32923300E+00, -.68966200E+00, -.16701700E+00, -.53968700E+00, 0.70635400E+00, 0.10875600E+01, -.14648100E+00, -.40599800E+00, 0.70978900E+00, 0.39878700E+00, -.87221100E-01, 0.92224600E-01, 0.74010200E+00, -.95551800E+00, 0.22992100E+00, -.92725600E-01, -.14835800E+00, -.53199600E-01, 0.74142600E-01, 0.20156900E+00, -.25268100E-01, 0.86956800E-03, -.15557900E+00, -.29619800E-01, 0.37342000E+00, -.57739700E-01, 0.40813300E-01, 0.15268000E+01, 0.53277400E+00, 0.57123800E+00, -.14347300E+00, 0.34675000E+00, 0.10577000E-02, 0.40739700E+00, -.13439500E+00, -.24930300E+00, -.24163500E+00, 0.26726400E+00, 0.73439400E-01, 0.34647200E+00, -.55153800E+00, -.22245000E+00, 0.28250700E+00, -.14174400E-02, 0.54174300E+00, -.53315500E+00, 0.68239100E+00, 0.59653400E-01, -.22618000E+00, 0.76785500E-01, 0.43276600E-01, -.57760300E-01, 0.32282800E-01, 0.27636200E+00, 0.19575500E-01, 0.85714400E+00, 0.16316900E+01, 0.61983500E+00, 0.74133200E-01, -.12871700E-01, -.20667700E+01, -.24698500E+00, -.19133400E+00, -.36420100E+02, -.58179600E+03, 0.10968200E+02, -.11558400E+03, -.29756100E+02, 0.16593000E+03, 0.35302700E+03, 0.41069400E+03, -.39132400E+02, 0.12250900E+03, 0.37183200E+03, -.15880500E+03, -.57695900E+03, -.18597100E+03, 0.40529800E+03, 0.57003700E+03, -.71176700E+03, -.65770400E+03, 0.94981500E+02, 0.62956100E+03, -.69038300E+03, -.64032600E+04, 0.31561300E+04, -.52046600E+03, 0.32016800E+04, -.16583300E+04, 0.62387800E+03, 0.44452400E+03, -.19804400E+04, 0.26725200E+04, 0.36062900E+03, 0.70490500E+04, 0.35775100E+04, -.17646200E+04, -.98406200E+03, -.17887700E+04, 0.52819100E+03, -.79878000E+03, -.18305000E+03, 0.15966800E+04, -.63757700E+03, -.41241700E+03, -.45953900E+04, -.34055100E+03, 0.15903300E+03, 0.10609300E+03, 0.16454300E+03, 0.17634200E+02, -.21459500E+03, -.10464300E+03, -.26063100E+03, -.46363600E+03, -.23530300E+03, 0.41995000E+03, -.11212700E+04, 0.52881400E+03, -.80291400E+02, 0.56074500E+03, -.59077500E+03, -.37103600E+03, 0.26996200E+03, -.10339000E+04, -.76821300E+02, -.27112300E+03, -.43018800E+03, 0.19036100E+04, -.91365400E+03, 0.16320900E+04, -.95140100E+03, 0.13194300E+04, -.52960200E+03, -.26390600E+03, -.19700800E+03, -.18826200E+04, -.59351500E+03, -.16539800E+04, -.46605200E+03, 0.24342600E+03, 0.59957700E+03, 0.23300700E+03, 0.87956000E+03, 0.15276200E+03, -.16454100E+03, 0.91600000E+03, 0.15713300E+03, 0.18509100E+03, 0.59571000E+02, 0.10632800E+05, -.52781800E+04, -.17933900E+04, -.53164000E+04, 0.11802600E+04, -.92827900E+03, -.99601600E+03, 0.32857000E+04, -.30263400E+04, -.42394100E+03, -.92847600E+04, 0.63158900E+02, 0.47479100E+01, 0.15615600E+04, -.31580300E+02, 0.75129400E+03, -.23075100E+03, 0.40624100E+03, 0.31895800E+03, 0.35896500E+03, -.38312800E+03, -.25630100E+03, -.77029500E+03, 0.36606800E+03, -.38005500E+03, 0.38478300E+03, -.53674100E+03, 0.17761700E+03, -.21697800E+03, -.12772200E+03, 0.79796900E+03, 0.28724900E+03, 0.91576200E+03, 0.11253400E+04, -.54967100E+03, -.56545200E+03, -.56267800E+03, 0.35082300E+03, 0.11066100E+03, -.29788400E+02, 0.64526700E+03, 0.81594500E+02, 0.17657000E+03, -.19819700E+04, 0.83803100E+03, -.41939700E+03, -.91755600E+03, -.41916400E+03, 0.13309100E+03, 0.38201300E+03, -.66967900E+03, -.29812100E+03, -.35604300E+03, 0.43807700E+03, 0.13597200E+03, -.15073100E+04, 0.74298800E+03, 0.33249100E+03, 0.75342100E+03, -.17204000E+03, -.28252100E+03, 0.75531500E+03, 0.64030900E+03, 0.42327700E+03, -.39111800E+03, 0.13473400E+04, -.17012700E+03, -.20223800E+02, 0.28221200E+02, -.22390500E+02, -.15215500E+02, -.12131000E+03, 0.13788100E+02, -.32522900E+02, -.45909400E+02, 0.63865300E+01, -.11148000E+03, 0.19659300E+03, -.76686600E+02, -.39207500E+03, -.18468500E+03, 0.74365500E+02, 0.37134200E+03, 0.75358700E+02, 0.31474600E+02, -.90484000E+02, 0.27766300E+03, 0.70007200E+02, -.13798500E+03, 0.24248800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.63609400E+01, 0.66358200E+00, 0.24121400E+01, -.45211800E+01, -.50089100E+01, 0.19581900E+00, 0.99550900E+00, -.19178200E+01, -.18131600E+00, -.19499400E-01, -.19237400E+01, -.14446600E+01, -.24662700E+01, -.52144700E+01, 0.33342000E+00, 0.57314200E+00, -.98177400E+00, -.95352500E+00, 0.10599600E+01, -.36825600E+00, -.16140000E-01, 0.17635500E+01, -.47529900E+01, 0.25513000E+01, -.49422400E+00, -.31116100E+00, -.34371600E+00, -.11688800E+01, -.62689000E+00, -.28162100E+01, 0.70400500E+00, -.51262000E-01, 0.53036800E+00, -.16241000E+01, -.40869600E-01, -.20450300E+00, 0.83028800E-01, 0.85438900E+00, 0.91682300E+00, 0.31492600E+00, 0.87313900E+00, -.13259800E+01, 0.43991100E+00, 0.16985900E+00, 0.12673800E+01, -.26454800E+01, -.57679200E+00, -.14833700E+00, 0.13783200E+00, -.60963800E+00, 0.36490000E+01, 0.26898200E+00, 0.40683100E+00, 0.18485400E+00, 0.13286000E+00, -.26204300E+00, 0.15199100E+00, -.18134800E+01, 0.27488600E-02, -.81571800E+00, -.11733800E+00, -.22035700E+01, 0.43574400E+00, 0.50132800E+00, -.47870700E+01, -.14985900E+01, -.14946400E+00, 0.87229600E+00, 0.38388500E-01, 0.32218100E-02, -.95317400E+00, 0.60911900E+00, -.27645800E-01, 0.13678300E+00, -.73567600E+00, -.14208300E-01, 0.10978700E+00, 0.42205000E+00, 0.25824500E+01, -.99505600E+00, 0.30505000E-02, -.22436300E+01, 0.25960200E+01, -.31001500E+01, -.20662500E+00, -.11638100E+01, 0.37460200E+00, -.83350400E+00, -.33389500E+00, -.10277700E+01, 0.11281900E+01, -.19021000E+00, 0.17179800E+01, 0.25541300E+01, -.11168300E+01, 0.12910100E+00, 0.10768700E+00, -.18650300E+01, -.19928800E+01, -.36128700E+00, 0.26340700E+01, 0.26388000E+04, -.23163900E+02, 0.62592400E+03, 0.18544800E+03, -.82837400E+03, -.13586900E+04, -.15062700E+04, 0.22555700E+03, -.67637900E+03, -.48286000E+04, 0.25131800E+04, 0.16560400E+04, 0.24144400E+04, -.15257600E+04, -.17937800E+04, 0.16834800E+04, 0.25077300E+04, 0.17105900E+04, -.98045400E+03, 0.35268200E+04, 0.29171000E+05, -.14784600E+05, -.62728300E+03, -.14585600E+05, 0.37835900E+04, -.19592300E+04, -.69727200E+03, 0.10707100E+05, -.96434300E+04, -.19936900E+04, -.25471700E+05, -.12968700E+05, 0.66226200E+04, 0.44508100E+04, 0.64843600E+04, 0.29298200E+03, 0.35904300E+04, -.10095000E+04, -.52504700E+04, 0.40108400E+04, 0.30543800E+04, 0.14587500E+05, -.54315000E+02, -.69651900E+02, 0.42207500E+03, 0.44161400E+02, 0.67195900E+03, 0.12311500E+04, -.13338800E+02, 0.50530900E+03, 0.12395700E+04, 0.77550700E+03, -.17791700E+04, 0.40355000E+04, -.20980300E+04, 0.95074200E+03, -.20180300E+04, 0.22926600E+04, 0.15757200E+04, 0.41326600E+03, 0.34037600E+04, 0.23323300E+03, 0.99554900E+03, -.55827500E+03, -.82294700E+04, 0.43522700E+04, -.68004300E+04, 0.41137000E+04, -.32343000E+04, 0.27980700E+03, 0.45337800E+03, -.16709300E+04, 0.38378000E+04, 0.10824400E+04, 0.60475000E+04, -.28377700E+03, 0.15304100E+03, -.11920900E+04, 0.14193800E+03, -.20465300E+04, 0.38025100E+03, -.19771100E+04, -.31320300E+04, -.35767600E+03, 0.27668600E+03, 0.90115800E+03, -.40063400E+05, 0.20226500E+05, 0.86005300E+04, 0.20031800E+05, -.13873700E+04, 0.31644700E+04, 0.21928100E+04, -.12545600E+05, 0.12353100E+05, 0.25835300E+04, 0.30841600E+05, 0.28483000E+04, -.12543100E+04, -.88253300E+04, -.14241400E+04, -.33342900E+04, -.14942500E+04, -.18460900E+04, 0.55618300E+03, -.10499500E+04, 0.52988100E+03, 0.67241500E+03, -.18121900E+04, 0.76437600E+03, 0.35500500E+04, 0.90702200E+03, 0.12495200E+04, 0.11441400E+04, 0.95054700E+03, 0.46415300E+03, 0.60651400E+03, 0.31914600E+03, -.15811300E+04, -.22881400E+04, 0.12319900E+04, 0.11604500E+04, 0.11440900E+04, -.67566600E+03, -.71280800E+03, -.45401700E+03, -.92438300E+03, 0.91379500E+03, -.25025500E+03, 0.56686200E+04, -.11002200E+05, 0.54637900E+04, 0.54358800E+04, 0.55014700E+04, -.22251200E+03, -.79371700E+03, 0.42318400E+04, 0.56302700E+03, 0.35731300E+04, -.17761500E+04, 0.30179500E+04, 0.53187200E+04, -.26895900E+04, -.20001400E+04, -.26587700E+04, 0.64470000E+03, 0.10915500E+04, -.13522500E+04, -.20796300E+04, -.18560500E+04, 0.41283400E+03, -.35843000E+04, 0.72340500E+03, 0.14949500E+03, -.14662300E+03, 0.20049500E+03, 0.39332100E+02, 0.47894400E+03, -.12664800E+03, 0.11677100E+03, 0.21746600E+03, -.60286500E+02, 0.10099400E+04, -.70192500E+03, 0.48622400E+02, 0.52661500E+03, 0.66628600E+03, -.47432800E+03, -.28300600E+03, -.31794000E+03, -.38082000E+03, 0.58099300E+03, 0.47813600E+03, 0.39627300E+03, 0.83518200E+03, -.69320200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.62710900E+01, 0.14072300E+01, 0.83872000E+00, -.39618400E+01, -.37304200E+01, 0.19076300E+00, 0.70756800E+00, 0.79329700E+00, -.49098100E+00, 0.17708100E+00, -.21078500E+01, -.20855300E+01, 0.48118700E+01, 0.37636000E-02, 0.92447600E+00, 0.25190400E+00, -.40562800E+00, 0.57450300E+00, 0.59018400E+00, -.10239300E+01, 0.59484900E+00, 0.13858100E+01, -.64532500E+01, 0.48818000E+01, 0.41279700E+00, -.17876700E+01, -.89809800E+00, -.90763800E+00, -.13762300E+01, -.79517800E+00, 0.38944900E+00, -.43577400E+00, 0.11267400E+01, 0.97732100E+00, 0.31545700E+00, -.16768600E+00, 0.20361400E-01, 0.23440500E+00, 0.99471600E+00, -.23156800E+00, -.45778500E+00, 0.10457400E+00, -.35482200E+01, 0.27107700E+00, -.46072600E+00, 0.26193700E+01, -.13352200E+01, 0.25987200E+01, 0.35866500E+00, 0.93728800E+00, 0.12852300E+01, 0.19893800E+00, -.18579000E+00, 0.64177600E+00, -.49723300E+00, 0.26537500E+00, -.96804100E+00, 0.20527500E+01, -.12412400E+00, 0.96645200E+00, 0.10951000E+01, 0.28149200E+01, -.13711000E+00, 0.64483500E+00, 0.20334800E+01, -.24542000E+00, -.91581300E+00, 0.22638400E+01, -.50968300E+00, -.18731400E+00, 0.39687300E-01, 0.80275700E+00, -.76436000E+00, -.34168200E+00, -.45126000E+00, 0.27056100E+00, 0.23177600E+00, 0.45655200E+00, -.12814400E+01, 0.54821700E-01, 0.39113100E+00, -.13123700E+00, -.21173200E+01, 0.15364400E+01, 0.43482700E+00, 0.17569500E+01, -.18324200E+00, 0.12947700E-03, 0.42395800E+00, -.10649600E+00, 0.14310700E+00, -.22348200E+00, -.99498100E+00, -.27431100E+01, -.73056900E-01, 0.34435000E+00, 0.24184100E+00, -.12927900E+00, 0.34049500E+00, 0.77226600E+00, -.19557100E+01, -.27508000E+00, -.35755200E+02, -.11095400E+03, 0.73013200E+02, 0.44052700E+02, -.84698700E+02, 0.71308800E+02, 0.36238600E+02, 0.43061600E+03, 0.19668800E+03, -.79890700E+02, -.15600100E+03, -.99081800E+02, 0.32886500E+03, 0.19686300E+03, 0.19708500E+03, 0.39391000E+02, -.13483700E+03, 0.55201300E+03, 0.10688700E+03, 0.23001300E+04, -.11839600E+04, -.83231200E+03, -.11491300E+04, 0.45924000E+03, 0.22817700E+03, 0.75386700E+03, 0.19160500E+04, -.42042800E+03, 0.64119400E+02, -.98862500E+03, -.30463000E+04, 0.15465300E+04, 0.94624200E+03, 0.15228800E+04, -.16932200E+03, -.86456200E+02, 0.10139600E+03, -.13115900E+04, 0.46236200E+03, 0.68923100E+02, 0.22857600E+04, -.26609800E+03, 0.12051900E+03, -.74585400E+01, 0.12704400E+03, -.57791000E+03, -.35339100E+03, -.17333000E+02, -.55193200E+03, -.26261300E+03, -.10718300E+03, -.11627200E+04, -.62612300E+03, 0.29627500E+03, 0.43606000E+03, 0.31537200E+03, 0.23519700E+03, 0.70043800E+02, 0.38964400E+03, 0.53517200E+03, 0.10117500E+04, -.51019800E+03, 0.12616200E+04, -.18321700E+04, 0.95411400E+03, 0.48298600E+03, 0.91713100E+03, -.34649500E+02, -.44416900E+03, 0.29137700E+03, 0.37478200E+03, 0.11114200E+04, -.35306900E+03, -.12826000E+03, 0.29334700E+04, -.14635200E+04, -.14916900E+04, -.14670600E+04, -.81550500E+03, 0.22445600E+03, -.10425500E+04, -.14109900E+04, -.20462900E+04, 0.48431500E+03, -.15881000E+04, -.59576800E+04, 0.30124700E+04, 0.22739900E+04, 0.29783900E+04, -.29534500E+03, 0.82258500E+01, 0.22343700E+02, -.26093900E+04, 0.12544600E+04, 0.22106000E+03, 0.27726600E+04, -.21078400E+04, 0.10813000E+04, -.37179000E+03, 0.10552000E+04, -.30955800E+03, -.93911300E+03, 0.14255700E+04, 0.15319800E+04, 0.17789000E+04, -.92023400E+03, 0.13140400E+04, 0.84251700E+03, -.44310300E+03, 0.37537500E+02, -.42276300E+03, 0.30387700E+03, 0.34953700E+03, -.12012400E+03, 0.14270600E+03, -.42243500E+03, 0.21177400E+03, -.21970200E+03, -.74966500E+03, 0.38837000E+03, -.25590200E+02, 0.37463300E+03, -.40476800E+03, -.32727900E+03, -.98042000E+02, -.59219400E+03, -.48800000E+02, -.18190200E+03, 0.96863900E+03, 0.12718600E+04, -.64528100E+03, 0.56022900E+03, -.63794900E+03, 0.28212500E+03, 0.52081300E+03, -.78205700E+03, -.75072700E+03, -.87463500E+03, 0.61365000E+03, -.11059500E+04, 0.79192700E+03, -.39985900E+03, -.37902000E+03, -.39606600E+03, -.11633900E+03, -.63231000E+03, 0.61538300E+02, 0.17090100E+03, 0.16501500E+03, -.78148400E+03, -.31340700E+03, -.12761200E+03, -.42053200E+02, 0.72554000E+02, -.43942900E+02, 0.33572600E+02, -.67913600E+02, 0.30099600E+02, 0.13323500E+02, 0.13269100E+02, 0.22262900E+02, -.68537700E+02, 0.50018100E+02, 0.56579100E+02, 0.26048400E+03, -.43578600E+03, 0.99804000E+02, 0.65295300E+02, 0.27266300E+03, -.15819200E+03, -.11695300E+03, 0.64303000E+02, 0.47531500E+02, 0.68731000E+02, 0.20833500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44057200E+01, 0.73075800E+00, 0.21102200E+01, -.29708400E+01, -.32721700E+01, 0.98170300E+00, 0.57115000E+00, -.25247000E+01, 0.34854700E+00, 0.66934200E+00, -.27389700E+01, -.16860400E+01, -.13374700E+01, -.36699300E+01, 0.76931200E+00, 0.50164100E+00, -.98727200E+00, -.38376700E+00, 0.81359000E+00, -.43670300E+00, 0.70925400E-01, 0.37576300E+01, -.76999400E+01, 0.36377800E+01, -.29620600E+00, -.72071800E+00, -.30024000E+00, -.10305000E+01, -.96472800E+00, -.41164900E+01, 0.69863300E+00, -.27448600E+00, -.66047500E+00, -.90482200E+00, 0.11447100E+00, 0.37635000E+00, 0.15639700E-01, -.98643100E+00, -.47920200E+00, 0.48372500E+00, 0.14435300E+01, -.99023000E+00, -.44891100E+01, -.15582500E+00, -.14147300E+01, 0.19936400E+01, 0.39917800E+00, -.37034000E+00, -.43248300E+00, -.46500200E-01, 0.42676800E+01, 0.26326500E+01, 0.70557900E+00, -.16631400E+00, -.71978500E-01, -.61910600E+00, 0.46926300E+00, -.53678200E+00, -.90967700E-03, 0.33544800E+00, 0.10655300E+00, -.42392000E+00, 0.16210700E+00, 0.28450000E-01, 0.23979600E+00, -.22345800E+00, -.11879300E+00, 0.63639700E+00, -.15131100E+00, -.35703200E-02, 0.10977000E+01, 0.34912800E+00, 0.85176600E-01, 0.20341300E+00, -.19409400E+00, 0.19471800E+00, -.21351700E+00, -.28231200E+00, -.40871200E+00, 0.47431800E+00, -.20877000E-02, 0.53194300E+00, -.99130000E+00, -.41388000E+01, -.11488100E+00, -.74110600E-01, -.92102500E+00, 0.23089900E+00, -.16216600E+00, 0.36945800E+00, 0.23973900E+00, 0.14291600E+00, -.45627400E+00, 0.67260500E+00, 0.14243700E+01, 0.25881300E+01, -.46219800E+00, -.33847300E+01, 0.14457200E+01, 0.62232900E+00, -.18704000E+01, -.20779100E+00, -.59037100E-01, -.21504400E+03, -.10966400E+02, 0.92575300E+02, 0.22072600E+03, 0.17147300E+03, 0.15578000E+02, 0.21913300E+03, 0.13666400E+04, -.66050900E+03, 0.24231100E+03, -.68342300E+03, 0.67603800E+03, 0.11193100E+04, -.95758700E+03, -.92880600E+03, -.10241900E+04, 0.11320100E+04, -.99457500E+03, 0.12908900E+04, -.67872800E+03, -.21999900E+04, -.64532200E+03, -.15019600E+04, -.71371500E+03, -.34794900E+03, -.34821900E+03, -.68912600E+03, -.66878900E+03, 0.27194700E+04, -.26579400E+04, 0.13459200E+04, 0.14822500E+04, 0.13289400E+04, 0.43295600E+03, 0.13905600E+03, 0.56887600E+03, 0.21498900E+03, 0.87075300E+03, 0.34458900E+03, 0.24529100E+04, -.64488000E+03, 0.32140700E+03, -.17897900E+02, 0.30992400E+03, -.57612600E+03, -.50747400E+03, -.23377900E+03, -.47362700E+03, -.80390000E+03, -.73586900E+02, 0.25656000E+03, -.12924200E+04, 0.61786900E+03, 0.17925000E+03, 0.64647900E+03, -.40765900E+03, -.85230200E+03, 0.17545500E+03, -.82306400E+03, 0.12083000E+04, -.11951500E+04, -.78384100E+02, 0.77001800E+03, -.35780000E+03, 0.15141000E+04, -.38444600E+03, 0.11764700E+04, 0.67832800E+03, -.60319000E+02, -.26026200E+03, -.66886500E+02, 0.34117800E+03, -.25601200E+04, 0.15328500E+04, -.75657200E+03, -.41011700E+03, -.76647100E+03, -.26015200E+03, 0.63882000E+03, -.66768200E+03, 0.14113400E+03, -.25284800E+04, 0.11112100E+04, -.10392400E+04, -.20356500E+04, 0.10479500E+04, 0.21783600E+04, 0.10177800E+04, 0.13496300E+04, 0.68452800E+03, 0.38342700E+03, 0.16761300E+03, 0.82556600E+03, 0.85105600E+03, -.75182400E+03, -.27376400E+04, 0.13917500E+04, 0.38476600E+04, 0.13688900E+04, 0.12681800E+04, 0.90324200E+03, 0.95518100E+03, 0.43810900E+03, 0.15238200E+04, 0.21215300E+03, -.86375500E+03, 0.74400600E+03, -.39164400E+03, -.95499700E+03, -.37253400E+03, -.61713500E+03, -.32452900E+03, -.63370500E+03, -.35817800E+03, -.56768800E+03, -.19692200E+03, 0.66765900E+03, -.76747400E+01, 0.12019300E+02, -.40945800E+01, 0.38168600E+01, 0.32122000E+02, 0.25109300E+03, -.62724500E+01, 0.18450100E+03, 0.38865800E+03, 0.21090100E+03, 0.57170900E+03, 0.79780800E+04, -.39878500E+04, -.32597000E+04, -.39893400E+04, 0.17272600E+03, 0.94525400E+03, -.26808500E+04, -.86298400E+03, -.29983900E+04, 0.98234800E+03, -.25997500E+04, -.18449500E+04, 0.91505100E+03, 0.16236000E+03, 0.92218500E+03, -.35517400E+03, -.11130100E+04, 0.11555200E+04, 0.12651400E+04, 0.11628100E+04, -.10104500E+04, 0.23329200E+04, -.21781900E+03, 0.21259700E+02, 0.32092100E+02, 0.12075600E+02, 0.18850500E+02, -.38958600E+02, -.16732300E+02, -.57638700E+02, -.87571100E+02, 0.86365900E+02, -.22224300E+03, 0.21784700E+03, -.33571700E+03, -.66469900E+02, -.40793100E+03, 0.12299200E+03, -.24838200E+03, 0.28120900E+03, -.18835900E+03, -.39566000E+03, -.36488900E+03, -.49470400E+02, -.39890300E+03, 0.51642100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26115500E+01, 0.22148700E+00, 0.64494200E+00, -.42050800E+00, -.75555300E+00, -.12253300E+01, 0.21099800E+00, 0.12162200E+00, -.46211300E+00, 0.88049900E-01, -.59425600E+00, -.75787300E+00, 0.26115900E+01, 0.49488400E+00, -.12681000E+00, 0.16684900E+00, -.32131400E+00, 0.26141600E+00, 0.22966500E+00, -.21234300E+00, 0.43648900E+00, 0.15351900E+01, 0.54953000E+00, 0.82242400E+00, -.25186900E-01, -.73008200E-01, 0.17273000E+00, 0.49149500E-01, 0.76540700E-01, -.45782900E+00, 0.54461800E-02, -.16005500E+00, 0.55563800E+00, 0.63168200E-01, 0.35927400E-02, -.46421200E+00, 0.32045900E-01, -.48663200E+00, -.16397900E+00, -.17444700E+00, -.22523800E+00, 0.18560300E+00, -.77153900E+00, -.14792000E+00, 0.61097300E+00, -.44644100E+00, 0.31675000E+00, -.94176200E-01, 0.10410600E+00, -.22769900E+00, -.36871500E+00, -.33194200E+00, 0.46071700E-01, -.14340000E+00, 0.26266400E+00, 0.11430700E+00, 0.74166100E-01, -.32561100E+00, 0.12485600E-02, -.79196100E+00, -.17947400E+00, -.54765400E+00, 0.10508200E+00, -.73194500E-01, -.35845100E+00, 0.34088200E+00, -.19773300E+00, -.32967700E+00, -.20265100E-01, 0.43438500E-04, -.16327400E+00, 0.20411700E+00, -.23320900E-01, 0.12252900E+00, 0.39853100E+00, -.21488900E-01, 0.91700300E-02, -.48602900E+00, 0.14130100E+00, 0.27438500E-01, 0.20726100E-03, 0.19963300E+00, 0.15414300E+00, 0.10751500E+01, -.37763400E-01, -.74619500E+00, 0.23019500E+00, 0.65974300E-01, 0.18516400E-01, 0.27675600E-01, -.82592800E-01, 0.29957800E-02, 0.37980100E+00, -.31386000E+00, 0.41730500E+00, -.40743700E+00, 0.20682700E+00, -.79906200E+00, -.10554100E+00, 0.83681800E-02, 0.90126500E+00, 0.14332900E+00, 0.11155800E+00, 0.21352600E+00, -.32175100E+03, 0.18165900E+03, 0.51598100E+02, -.20392900E+01, -.25620500E+03, -.20169200E+03, -.11999600E+03, 0.52714700E+02, -.25794300E+03, 0.60102300E+02, -.53213100E+03, -.31285400E+03, 0.24691700E+03, 0.91569100E+02, 0.13811600E+03, -.58496900E+03, 0.23222800E+03, 0.13831200E+04, -.67519000E+03, 0.23392900E+04, -.69168800E+03, 0.17072100E+03, -.23443000E+03, -.47567300E+03, -.71613500E+03, -.92468700E+03, -.74065300E+02, -.29635900E+04, 0.21088100E+04, -.10631100E+04, -.18345900E+04, -.10543700E+04, -.56843500E+03, 0.30527700E+03, -.52759000E+03, 0.26324300E+03, -.59694300E+03, -.13814400E+03, 0.57221600E+03, 0.58648800E+03, -.29158700E+03, -.66992100E+02, -.29009500E+03, 0.11935900E+03, 0.25847600E+03, 0.20241100E+03, 0.45214900E+03, 0.35669300E+03, 0.26408300E+03, 0.98854200E+02, 0.90362700E+03, -.44245800E+03, 0.28610900E+02, -.45212700E+03, 0.16768100E+03, 0.62206800E+01, -.21092400E+03, 0.31037500E+03, -.57282800E+03, 0.27290800E+03, 0.19693200E+03, -.58424600E+02, 0.16677600E+02, -.20166100E+04, 0.28976800E+02, -.35865300E+03, 0.25992600E+03, 0.45961700E+02, 0.41286700E+03, -.24857800E+02, 0.26939800E+03, 0.85386000E+03, -.27557100E+03, 0.13491600E+03, -.13437300E+03, 0.13783100E+03, -.21882700E+03, 0.10636100E+03, 0.41316600E+03, -.99744700E+02, 0.83530900E+03, 0.25984900E+01, 0.41898800E+03, -.73252000E+03, 0.34911200E+03, -.21970000E+04, 0.36632000E+03, -.46729100E+03, 0.12476900E+03, 0.17179100E+03, 0.35127300E+03, 0.48764100E+03, -.28104100E+03, 0.29331500E+04, 0.28371500E+03, -.15109300E+03, -.71980900E+03, -.14201600E+03, 0.64359000E+02, 0.27234100E+03, -.39792900E+03, -.87534700E+03, -.93053500E+03, 0.28404300E+03, -.51935800E+03, -.92998800E+03, 0.47071800E+03, 0.71560800E+03, 0.46527300E+03, 0.15943500E+03, -.41058700E+02, 0.28535700E+03, -.21365400E+03, 0.46340500E+03, -.15408300E+02, 0.52935300E+02, 0.24573600E+03, -.12666000E+03, 0.15013400E+03, -.12284200E+03, -.10184400E+03, 0.20029400E+03, -.16006200E+03, 0.35553500E+02, -.47764500E+03, -.35570900E+01, 0.44304200E+03, -.13535600E+04, 0.68153100E+03, 0.61405900E+03, 0.67706700E+03, -.26301600E+03, -.28926100E+03, 0.67607800E+03, 0.72422800E+03, 0.79049100E+03, -.33834000E+03, 0.70109000E+03, 0.47272600E+03, -.23461800E+03, -.11013500E+03, -.23629100E+03, 0.35200600E+03, 0.47306200E+03, -.57287100E+03, -.29292200E+03, -.20841200E+03, 0.58918900E+03, -.64145000E+03, 0.86877900E+02, 0.62156100E+02, -.34726800E+02, 0.72771000E+02, -.16247700E+02, 0.81066200E+02, -.75356900E+02, -.17564300E+02, -.24987700E+02, -.71665700E+02, -.12668200E+03, -.44792600E+02, -.51201600E+01, 0.14424900E+03, 0.26582300E+03, 0.24200700E+01, -.98851700E+02, -.98947400E+02, 0.76374700E+02, 0.72887400E+02, 0.67707100E+02, -.10101100E+03, 0.33120100E+02, -.24784200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18424700E+01, -.52960200E+00, -.56602400E+00, 0.87321500E+00, 0.20456100E+01, 0.21206500E-01, -.21232700E+00, 0.43009600E+00, -.50572900E-01, -.12360600E+00, -.83729800E+00, -.66874700E+00, -.35523200E-02, 0.50718600E-01, 0.19607300E+00, -.89272400E-02, 0.27090400E+00, 0.13152800E+01, -.62249600E-02, -.25250800E+00, -.19266700E+00, -.28405000E-01, -.29211900E+01, 0.82610700E+00, -.27791200E-01, -.90904300E-01, -.54706600E-02, 0.68382700E-01, -.90093300E+00, 0.18062400E+00, -.88874100E-01, -.85923200E-01, -.13746200E+00, 0.55672500E-01, -.76052200E-01, 0.11077000E+00, -.16279500E-01, -.44031500E-02, -.64858000E-01, 0.23536600E-01, 0.36859300E+00, 0.38846800E+00, -.17818700E+01, 0.65938900E+00, -.46808500E+00, -.91172600E+00, -.22304400E+00, -.47104700E+00, -.28803400E+00, 0.29806000E+00, 0.52023000E+00, 0.26527000E+00, 0.84661100E-01, 0.19463900E-01, 0.12529900E+00, -.47336000E+00, 0.15011100E+00, -.14752900E+01, -.24716500E-04, -.13688200E+00, 0.16152400E+00, 0.16314400E+00, -.74814400E-01, -.26417000E+00, 0.19432500E+00, -.24003300E+00, -.24152300E+00, -.40709700E-01, -.12566800E+00, 0.40667800E-02, -.13981400E+00, -.27554600E-02, -.41829000E+00, 0.21032000E+00, -.33356200E+00, -.30213700E-01, 0.14953000E-01, 0.11605000E-01, 0.12902800E+00, -.11508000E+00, -.18852100E-03, -.78963700E+00, 0.50719900E+00, -.57530800E-01, 0.47589400E-01, -.10431400E+00, -.25477300E+00, -.15792400E+00, -.13387000E+00, 0.40530600E-01, 0.18881300E+00, -.24458900E-01, -.15661400E-01, 0.60756700E+00, 0.42760100E+00, 0.37584500E-01, 0.91647200E-01, -.37439600E+00, 0.32115900E+00, 0.11966600E+00, -.48666500E+00, -.66434400E-01, -.14982500E+00, 0.12892300E+00, -.66392800E+00, -.11399500E+03, -.23950000E+03, -.97903500E+02, -.61554700E+01, 0.30647200E+03, -.26493200E+02, -.55831400E+00, 0.29969500E+03, 0.13217800E+02, -.10625300E+03, -.39126900E+01, 0.29679500E+02, -.25972800E+02, -.18271300E+02, -.22425400E+03, -.47403900E+02, 0.22723400E+04, -.11149400E+04, -.11081400E+04, -.11361300E+04, -.61223200E+02, 0.10920800E+03, -.89802000E+03, -.48385000E+03, -.11623700E+04, -.15946500E+03, -.87301700E+03, -.24908200E+03, 0.11200200E+03, 0.58077700E+03, 0.12452800E+03, -.40924200E+02, -.32182500E+03, 0.53339800E+03, 0.66226500E+03, 0.31209300E+03, -.28368800E+03, -.40216200E+03, -.32342400E+03, 0.16443500E+03, -.21577200E+02, 0.16342000E+03, -.53122600E+02, -.16840700E+03, 0.99872600E+02, 0.11556400E+02, 0.86676300E+02, -.20215100E+02, -.16672900E+03, -.20828200E+03, 0.11980500E+03, -.23800600E+02, 0.10424600E+03, 0.47389000E+02, -.97274100E+02, 0.17367200E+03, -.22522000E+03, 0.12011100E+03, -.53336400E+02, 0.84111000E+02, -.13123500E+04, 0.63599000E+03, 0.72407000E+03, 0.65610700E+03, -.19198300E+03, 0.85680100E+02, 0.36826200E+03, -.77680800E+02, 0.24799400E+03, 0.27266400E+03, 0.10641900E+04, 0.51541100E+03, -.26247100E+03, -.29446500E+03, -.25771800E+03, -.26317600E+03, -.16679000E+03, -.95770600E+02, 0.18606900E+03, -.10951300E+03, -.32039400E+02, -.20112000E+03, -.23633200E+04, 0.11628000E+04, 0.14879200E+04, 0.11816400E+04, 0.14747600E+03, -.26268400E+03, 0.98430500E+03, 0.51065200E+03, 0.10730900E+04, -.51039800E+02, 0.43168600E+03, -.71699600E+03, 0.34158800E+03, 0.27309400E+03, 0.35857600E+03, -.94164500E+02, -.25296800E+03, 0.17919500E+03, -.55558700E+03, -.44571300E+02, -.30503000E+03, 0.59270900E+03, 0.10578000E+04, -.51562000E+03, -.55589100E+03, -.52887600E+03, -.30997200E+02, -.61555900E+02, -.22213300E+03, 0.11670000E+03, -.26648000E+03, -.13320500E+03, -.63328100E+03, -.29110500E+03, 0.13847900E+03, 0.20696600E+03, 0.14554300E+03, 0.90722800E+02, -.13167100E+03, 0.30332100E+03, 0.36515500E+03, 0.14748200E+03, -.13821100E+03, -.11297100E+03, 0.47833600E+03, -.23770100E+03, -.27857700E+02, -.23924200E+03, 0.11831400E+03, 0.24223900E+03, 0.51239100E+02, 0.74289700E+03, -.58403400E+02, 0.22673200E+03, -.26850000E+03, 0.49304200E+03, -.24196200E+03, -.13052300E+03, -.24645600E+03, -.72183200E+02, 0.46161400E+02, -.68824100E+02, 0.15558300E+03, -.52927600E+01, 0.18827800E+03, -.64044300E+01, -.16685900E+02, -.63531700E+01, 0.58477300E+01, 0.65051800E+01, -.55010700E+01, 0.69059300E+01, -.44389500E+01, -.18377800E+02, -.35180100E+02, -.21196200E+02, 0.21161100E+02, 0.15047700E+02, 0.15944500E+03, -.25897300E+03, -.37775300E+02, 0.63814700E+01, -.22600000E+02, 0.39420400E+02, 0.31983000E+03, 0.23058200E+02, 0.29639800E+02, 0.14923600E+02, 0.42394800E+02, -.57074400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15287500E+01, -.28624400E+00, -.58568700E+00, 0.79319300E+00, 0.88456000E+00, -.60212600E+00, -.11766700E+00, 0.81392600E+00, -.48608500E-01, -.60157800E+00, -.40447000E+00, 0.23095000E+00, 0.17413300E+00, -.51841200E+00, 0.89241900E-01, -.52197800E-01, -.30230500E-01, 0.41905100E+00, -.15775600E+00, 0.68847400E+00, -.30308500E+00, -.46845700E+00, -.10280800E+00, 0.89395500E-02, -.61089300E-01, 0.26675300E+00, -.10165800E+00, 0.15124800E-01, -.14037200E-01, 0.72904300E+00, -.99025800E-02, -.10138100E+00, -.11492700E+00, -.14998300E+00, -.97280900E-01, -.12611900E+00, -.20551700E-01, -.68183900E-01, -.34161500E-01, 0.19434900E+00, 0.42860700E+00, 0.67936300E+00, -.37668700E+00, 0.34104600E+00, -.89924700E+00, 0.19640900E+00, 0.68444300E+00, -.63696900E-02, -.77251100E-01, 0.60999600E+00, -.12456200E+01, -.22387200E+00, -.18061800E+00, 0.24273700E+00, 0.27650100E+00, -.14037300E+00, -.87545600E-02, 0.44288300E+00, -.26365800E-02, 0.11291400E+00, -.49993500E-01, 0.53411400E+00, -.16147500E+00, -.99141500E-01, 0.14806300E+00, -.36359900E+00, -.15728200E+00, -.43865400E+00, 0.24449700E+00, -.82479700E-03, 0.13355500E+00, -.19652000E+00, 0.75457600E-01, -.15801100E+00, 0.12221000E+00, -.61492700E-01, -.21417300E-01, -.43461300E+00, 0.35495300E+00, 0.54388000E-01, 0.22938100E-03, -.32842300E+00, 0.37066700E+00, -.42400400E+00, -.83446400E-01, -.30963300E+00, -.17330300E+00, -.12038100E+00, -.67118200E-01, -.16404600E+00, 0.20019600E+00, -.37796600E-01, -.35560900E+00, -.39614800E+00, -.13787400E+01, -.84718300E+00, 0.32151800E+00, 0.10156400E+01, -.65953400E+00, 0.14344100E+00, -.76860000E+00, -.26869700E-01, -.17674800E+00, -.19869400E+00, -.30151100E+00, 0.28708400E+00, 0.15868800E+03, 0.14466300E+03, -.22423200E+02, -.21035500E+03, -.85893800E+03, 0.42692700E+03, 0.45573900E+03, 0.42933100E+03, 0.50506500E+03, 0.43561900E+03, -.28201400E+02, 0.24515700E+03, 0.29664800E+03, 0.67414400E+03, -.22865200E+03, -.56693600E+04, 0.28463900E+04, 0.34985000E+03, 0.28348500E+04, 0.38109200E+02, 0.72371100E+03, 0.14196400E+04, 0.28398300E+01, 0.22462800E+04, 0.71193800E+03, 0.23228500E+04, 0.13360500E+04, -.67747200E+03, 0.51383600E+02, -.66807300E+03, 0.17926500E+03, 0.19562600E+03, -.49836000E+03, 0.28529800E+03, -.26118400E+03, 0.45934800E+03, -.99876600E+02, -.25604000E+03, 0.13952500E+03, -.10756300E+03, 0.12221600E+03, -.21487100E+03, -.24900200E+03, 0.77912500E+02, -.22688200E+03, -.16349000E+03, -.21241900E+03, 0.10603600E+03, -.32692200E+03, 0.16262200E+03, -.17539600E+03, 0.16385500E+03, -.16552200E+03, 0.63647000E+02, -.24201100E+02, -.29959600E+03, 0.88160400E+02, -.15802600E+03, 0.19668800E+03, 0.18950800E+04, -.96430200E+03, 0.64798100E+03, -.94707300E+03, 0.38667600E+03, -.53179100E+03, -.79690300E+03, -.41502600E+03, -.11613800E+04, -.83440100E+03, -.57515300E+03, 0.23660900E+03, -.11643100E+03, 0.70467800E+02, -.11836500E+03, 0.14710600E+03, 0.18746800E+03, -.35176300E+03, 0.13783800E+01, -.54053900E+03, 0.22143800E+03, -.19186000E+03, 0.59207100E+04, -.29717700E+04, -.74695400E+03, -.29604300E+04, -.67276600E+02, -.47161700E+03, -.12897500E+04, 0.65073300E+03, -.17520700E+04, -.25988800E+03, -.22439500E+04, -.34524200E+03, 0.16214300E+03, 0.12050100E+03, 0.17279000E+03, 0.40816100E+02, -.33211200E+03, 0.13251500E+03, 0.91580700E+03, 0.68189300E+03, -.52748100E+03, 0.51436700E+03, -.14422700E+04, 0.73371000E+03, 0.23307500E+03, 0.72064600E+03, -.26917200E+02, 0.16022500E+03, 0.52245500E+03, 0.85799400E+02, 0.67336000E+03, 0.37894500E+03, 0.14467900E+03, 0.13864200E+04, -.70001000E+03, -.76955800E+03, -.69324100E+03, -.10247800E+03, 0.13519400E+03, -.42756000E+03, 0.10822800E+03, -.12914000E+03, 0.21316700E+03, -.23990300E+03, 0.23757500E+03, -.11479200E+03, -.57171600E+03, -.11917500E+03, 0.24764000E+03, 0.34472700E+03, -.33403700E+03, -.93083800E+03, -.45620000E+03, 0.39815400E+03, -.34876600E+03, -.31943600E+03, 0.16114300E+03, -.12684200E+03, 0.15952100E+03, -.21083700E+03, -.55824100E+03, 0.49064900E+03, 0.62607000E+02, 0.16782300E+03, -.62975200E+03, 0.58584000E+03, -.54404500E+02, -.22674500E+01, 0.19813400E+02, -.93117200E+01, 0.15571700E+02, -.33061300E+02, 0.13902500E+02, 0.28131900E+01, -.18973800E+01, 0.37491000E+02, 0.15959700E+02, 0.84439100E+02, -.24165100E+02, -.10856500E+03, -.13714800E+03, 0.16745400E+02, 0.31982800E+03, 0.73712800E+02, -.17255300E+03, -.65707500E+02, 0.73457000E+02, 0.33925400E+02, -.25982000E+02, 0.28610000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.23604200E+01, 0.22328900E+00, 0.12986900E+01, -.12622700E+01, -.36894400E+00, -.11469900E+01, 0.14872700E+00, 0.13224700E+00, -.48902700E+00, -.41665800E-01, -.88714700E+00, 0.50674900E+00, 0.38763500E+01, 0.10951100E+01, 0.21836300E+00, 0.86439200E-01, -.44065000E+00, 0.29243400E+00, 0.46231200E+00, -.57319900E+00, 0.26351100E+00, 0.98434300E+00, 0.97025800E+00, 0.62390200E+00, -.17185000E+00, 0.40482700E+00, 0.38870400E+00, -.34839800E-01, 0.40805700E+00, -.69970000E+00, 0.34776600E-01, -.70479500E-01, 0.33797300E+00, -.14083200E+00, -.71927300E-01, -.46465300E+00, -.20866500E-01, 0.19657800E+00, 0.21606100E+00, -.26082700E+00, -.18456600E+00, -.34360600E+00, 0.45304400E+00, -.43535800E+00, 0.53932200E+00, -.83727100E-01, 0.29009900E-01, -.36772500E+00, 0.31466100E+00, 0.75894600E+00, 0.17151300E+01, 0.30144100E+00, 0.22641300E+00, -.32355000E+00, 0.14334200E+00, 0.41190400E+00, 0.43850800E-01, -.97253700E+00, 0.26810600E-02, -.10200900E+01, -.23170700E+00, -.37375700E+00, 0.23511800E+00, 0.43193800E+00, -.58234100E+00, 0.67759700E+00, -.24608900E+00, 0.35112800E+00, -.31336800E-01, -.15433100E-02, -.20069100E-01, 0.15827900E+00, 0.17791700E+00, 0.13234500E+00, -.16373300E+00, -.81916900E-01, -.26908200E+00, -.29245100E+00, -.21934800E+00, -.88776200E-02, 0.23240400E-03, 0.11678400E+00, -.11737700E+00, 0.12879000E-01, -.12778200E+00, -.12180600E+01, -.20897400E+00, -.38603700E+00, -.47846500E+00, 0.18923100E+00, 0.54757000E+00, -.48097300E-01, 0.94114900E+00, 0.17802900E+01, -.13292400E+01, -.11578200E+01, 0.39809900E+00, 0.76079100E+00, -.28627900E+00, -.23038800E+00, 0.12247800E+01, 0.18750500E+00, 0.13002100E+00, 0.12917700E+00, 0.28475300E+00, 0.84756900E+00, 0.18229400E+00, -.98061500E+02, -.34768800E+01, -.13849800E+03, 0.69809300E+03, -.34555400E+03, -.28377800E+03, -.34890600E+03, 0.84787700E+01, -.27960200E+03, 0.26296100E+02, -.11416200E+03, -.64367500E+03, -.36575200E+03, -.57861800E+02, -.17089700E+04, 0.84872300E+03, 0.10544100E+04, 0.85431200E+03, 0.85218500E+03, 0.62793500E+03, 0.12544400E+03, 0.63633300E+03, 0.79845700E+03, 0.71367100E+03, -.99192800E+03, -.20781200E+04, 0.10430100E+04, 0.71443300E+03, 0.10391100E+04, -.92807800E+02, 0.55559700E+03, 0.11072000E+03, -.12878100E+04, -.83257400E+02, 0.39091900E+03, 0.23997700E+04, 0.31344500E+03, -.16360200E+03, 0.13606100E+03, -.15087900E+03, 0.24670500E+03, 0.36535000E+03, -.14790400E+03, 0.32142800E+03, 0.15241500E+03, 0.38469800E+03, -.10543300E+03, -.32111600E+02, 0.12694900E+02, 0.34471200E+02, 0.15627800E+02, -.38036700E+02, -.26656500E+01, -.39931100E+02, 0.38651600E+03, 0.22061900E+03, 0.59970400E+02, -.72606200E+02, 0.50914100E+04, -.25391200E+04, -.24448900E+04, -.25459600E+04, -.93951700E+03, -.88459100E+03, -.19309000E+03, 0.11807500E+04, -.84412700E+03, -.75824800E+03, -.20251300E+04, 0.77617500E+01, -.31128300E+01, -.50791600E+02, -.38211400E+01, 0.19818100E+03, 0.85643800E+02, 0.88957500E+01, -.15201400E+02, -.10474800E+03, -.27342800E+02, 0.11909500E+03, -.34012500E+04, 0.17042100E+04, 0.95455200E+03, 0.17007100E+04, -.45324800E+03, 0.47784900E+02, 0.36041600E+03, -.20143000E+04, 0.26772200E+02, -.17461100E+03, 0.35617300E+04, 0.12107300E+04, -.59941200E+03, -.70525500E+03, -.60559100E+03, -.40588800E+03, 0.82200000E+02, -.47758200E+03, -.23990800E+03, -.83543900E+03, -.74407000E+02, -.53652700E+03, -.21399500E+04, 0.10634900E+04, 0.10808200E+04, 0.10703000E+04, 0.55989000E+03, 0.31946900E+03, 0.30553300E+03, -.22467200E+03, 0.36809800E+03, 0.28672600E+03, 0.78388900E+03, -.94352700E+03, 0.47464500E+03, 0.37003900E+03, 0.47180000E+03, -.23589200E+03, 0.69111800E+02, 0.42083700E+02, -.66115800E+03, 0.86745100E+02, -.99650800E+01, 0.13245600E+04, -.11116100E+04, 0.55813000E+03, 0.62921100E+03, 0.55618900E+03, 0.12359300E+03, -.13759100E+03, 0.35436800E+03, 0.48525600E+02, 0.52409000E+03, -.10221300E+02, 0.54805700E+03, -.14662000E+03, 0.71460500E+02, 0.47608200E+03, 0.73367500E+02, 0.73941600E+02, 0.18672200E+03, -.35338800E+02, -.98675400E+02, 0.15917800E+03, 0.34766900E+03, -.26334700E+03, 0.12513400E+02, -.20197500E+02, -.63884900E+01, -.44618000E+02, 0.27855300E+02, -.74849200E+01, 0.34025900E+02, 0.28535500E+02, 0.27503000E+02, 0.41565400E+02, -.80406900E+02, -.98627300E+02, 0.22411800E+03, 0.39163300E+03, 0.13548400E+03, -.17537700E+02, 0.48198100E+02, -.45735700E+02, -.11715700E+03, 0.10545400E+03, -.27176100E+02, -.74935800E+02, 0.11951300E+03, -.90198700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.15554100E+01, 0.16057800E+00, 0.42287900E+00, -.71237400E+00, -.37336900E+00, -.82255300E+00, 0.13221700E+00, 0.25802800E+00, -.50905600E+00, -.23705200E+00, -.13100500E+01, 0.60399600E-01, 0.13233800E+01, 0.87556200E+00, 0.12851000E+00, 0.30178900E+00, 0.10728800E+00, 0.10654100E+01, 0.22425700E+00, -.12692200E+01, 0.45601000E+00, 0.99831200E+00, 0.94443300E+00, -.49971900E+00, 0.94523600E-01, -.14445700E+00, -.49995000E-01, -.23116100E-01, 0.16992300E+00, 0.12021800E+01, 0.15421600E+00, -.30234200E+00, 0.88738200E+00, -.34697300E+00, 0.73188200E-01, -.21243200E+00, -.85052800E-02, -.47462900E+00, 0.12672900E+00, 0.15622900E+00, 0.79815800E+00, 0.49380500E+00, -.20819000E+01, 0.14209300E+00, -.79140000E+00, 0.24595900E+00, 0.49872700E+00, -.39330900E+00, -.10712600E+00, 0.46981400E+00, -.39240000E+00, 0.45433100E+00, 0.37442900E-01, -.38315000E-01, 0.27347000E+00, -.16800700E+00, 0.20993200E+00, -.67197200E+00, -.44610200E-03, -.18425700E+00, 0.20176200E-01, 0.42093000E+00, -.14331600E+00, -.23352300E+00, 0.74368100E+00, 0.30264900E+00, 0.23085700E+00, -.52790000E+00, 0.17059000E+00, 0.20419100E-02, -.46132800E+00, -.45390300E-01, -.16654400E+00, 0.20754100E+00, 0.16842300E+00, -.30391500E-01, -.90804700E-01, -.28891000E+00, -.31106800E+00, 0.20813500E+00, -.65835200E-03, 0.28295800E+00, -.25242700E+00, -.22253900E+00, 0.27559800E-01, -.19922400E+00, -.25481400E+00, 0.12791200E+00, -.75591800E-01, 0.15886300E+00, -.14336200E+00, 0.10105300E-01, -.80400100E-01, 0.12679700E+01, 0.12094000E+00, 0.27112700E+00, -.11862400E+00, 0.10578900E+00, 0.55065700E+00, -.20992800E+00, 0.16717000E+00, -.51890100E-01, -.11356500E-02, 0.15911700E+00, -.16073100E+00, 0.75007500E-01, 0.29109200E+00, 0.37435000E+00, 0.45691500E+02, 0.90869000E+02, -.17066800E+03, 0.91080500E+02, -.23538400E+03, 0.85367700E+02, -.48326200E+03, -.41585200E+03, 0.62268500E+02, 0.65092500E+02, 0.21228600E+03, -.46216600E+03, 0.28623600E+03, 0.58839600E+04, -.29574800E+04, -.18051600E+04, -.29420200E+04, -.42869600E+03, -.11667000E+03, -.16613300E+04, 0.65676300E+02, -.16764200E+04, -.23567200E+03, -.18018800E+04, 0.22022100E+02, -.16771200E+01, -.56514400E+03, -.11002200E+02, 0.87376700E+02, -.27888900E+03, 0.45750100E+02, -.83420900E+02, 0.21869600E+02, -.53581800E+03, -.12447300E+04, 0.63327100E+02, -.36121200E+02, 0.10660100E+03, -.27060900E+02, 0.43113000E+03, 0.26848200E+03, -.83592700E+02, 0.11451200E+03, 0.36429200E+03, -.47348700E+02, 0.47848500E+03, 0.65763600E+03, -.33458000E+03, 0.13411000E+03, -.32889400E+03, 0.66669800E+02, 0.35597400E+01, 0.91987400E+02, 0.18940500E+03, -.44185900E+03, 0.37301800E+03, -.10437600E+04, -.10025900E+04, 0.51635100E+03, -.26021800E+03, 0.50104400E+03, -.37432700E+03, -.34551100E+03, 0.99363900E+03, 0.59620700E+03, 0.72333000E+03, 0.11811700E+03, 0.30556600E+03, -.20395200E+04, 0.10210000E+04, 0.76180300E+03, 0.10197800E+04, 0.39570400E+03, -.15095700E+03, 0.42428100E+03, 0.33691600E+03, 0.16452800E+04, -.35572100E+03, 0.10692700E+04, -.40099500E+04, 0.20196500E+04, 0.73778600E+03, 0.20049900E+04, 0.43439700E+03, 0.14452800E+02, 0.94655900E+03, -.22662800E+03, 0.11847100E+04, -.14046000E+03, 0.97150800E+03, 0.17476200E+04, -.86299700E+03, -.50838000E+03, -.87381400E+03, 0.14760800E+03, -.35368200E+02, -.38465300E+03, -.22407200E+03, -.77705000E+03, 0.75497700E+03, -.12356400E+04, 0.71954800E+03, -.36909400E+03, 0.80650500E+02, -.35955000E+03, 0.83684300E+02, 0.21852000E+03, -.55446500E+03, -.32842400E+03, -.50906200E+03, 0.29364700E+02, -.17962400E+03, -.10270200E+04, 0.51882200E+03, 0.64124500E+03, 0.51351600E+03, 0.38599800E+03, -.17898200E+03, 0.40839500E+03, 0.17758800E+03, 0.27064500E+03, -.22298200E+03, -.37645100E+03, -.24935500E+04, 0.12447100E+04, 0.10010300E+04, 0.12468800E+04, -.27294500E+03, -.35786300E+03, 0.81830400E+03, 0.45789500E+03, 0.10654900E+04, -.72047200E+03, 0.14230600E+04, 0.68566700E+03, -.34507200E+03, -.37811600E+03, -.34269500E+03, 0.64581900E+02, 0.50329400E+03, -.37990700E+03, -.23218500E+03, -.59864800E+03, 0.32886900E+03, -.47770800E+03, 0.12685500E+03, 0.34541400E+02, -.47774600E+02, 0.41042500E+02, -.23036800E+02, 0.38424100E+02, -.40094100E+02, 0.10560400E+02, 0.16505500E+02, -.53344400E+02, 0.38178900E+02, -.96249600E+02, 0.21299300E+03, 0.40749100E+02, 0.28861200E+03, -.95912200E+02, 0.37480200E+01, -.20983200E+03, 0.20553600E+03, 0.71920500E+02, 0.19537300E+03, 0.36782000E+02, 0.21707500E+02, -.23249800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24984900E+01, -.56369800E+00, -.18855400E-01, 0.46108000E+00, 0.13197900E+01, -.47071300E+00, -.30704300E+00, -.10215300E+01, 0.61965300E+00, -.18369000E+00, 0.35659400E+00, 0.89136300E+00, -.15689000E+01, -.82773600E+00, 0.43950800E+00, -.11170600E+00, -.25860800E+00, -.12638000E+01, -.20025700E+00, 0.81903000E+00, -.10191500E+01, -.18071400E+01, 0.88310000E-01, -.10847300E+01, -.17878100E+00, 0.13204200E+00, 0.25276400E+00, -.14506800E+00, 0.71342100E-02, 0.43312700E-01, 0.35538900E-01, 0.24791700E+00, -.26062100E+00, 0.13421100E+00, -.98947800E-01, 0.11434100E+00, 0.63426700E-01, -.26812400E+00, -.84226600E-01, 0.14507400E-01, -.47693100E+00, -.67083100E+00, -.80088100E+00, 0.26052300E+00, 0.21672500E+00, -.13961900E+01, 0.85333000E+00, 0.25072800E+00, -.85991700E-01, -.11601700E+01, -.10561500E+01, -.11250000E+01, -.19525700E+00, 0.96700300E-01, 0.64595000E+00, -.77020400E-02, 0.16255800E+00, 0.14969100E+01, -.48524300E-02, -.44029100E-01, 0.24579900E+00, -.65304100E+00, 0.15621300E+00, 0.21984700E+00, -.75439300E-01, 0.79020000E+00, 0.45240900E+00, -.13414200E+01, 0.10655600E+00, -.11805500E-01, 0.33537600E+00, -.47380400E+00, 0.21905800E+00, 0.32503200E+00, 0.31309300E+00, -.41732100E-01, -.27015600E+00, 0.11600700E+00, 0.43375800E+00, -.15683000E+00, 0.14593200E-02, -.58989300E+00, 0.89633300E+00, 0.28427800E+00, 0.18821200E+00, -.51591500E+00, -.22451000E+00, 0.22481000E-01, -.40235000E+00, 0.25731200E-01, -.97225100E-01, 0.36881900E-01, 0.81325800E+00, -.17940400E+00, 0.80264900E+00, 0.21341100E+00, -.35019200E+00, -.13520000E+01, 0.64516100E+00, 0.40226100E+00, 0.53813100E+00, 0.13757600E+00, 0.13765500E-02, 0.25828700E+00, 0.38114900E+00, 0.77671400E+00, -.20554100E+00, -.21655400E+00, 0.27081400E+00, -.32009600E+03, 0.95694700E+03, -.49112200E+03, -.38242900E+03, -.47844900E+03, 0.74514400E+02, 0.79670400E+02, -.24051600E+03, -.38574500E+03, -.72874200E+03, 0.47344200E+02, -.28601300E+03, -.33505700E+04, 0.17019800E+04, 0.18627900E+04, 0.16752600E+04, 0.86615600E+03, 0.39138700E+03, 0.72921400E+03, 0.37667400E+03, 0.93167000E+03, 0.63598300E+03, 0.82232800E+03, -.72114800E+03, 0.34351600E+03, -.26941000E+03, 0.36058200E+03, -.99079900E+02, 0.24172600E+03, 0.11264500E+03, -.82724700E+03, -.90655600E+02, 0.15338900E+03, 0.11993500E+04, 0.39662900E+03, -.18710800E+03, -.79137800E+02, -.19600100E+03, 0.12217300E+03, 0.16339600E+03, -.14759500E+03, 0.25760800E+03, -.10373300E+03, 0.28354200E+03, 0.97067900E+02, -.12720100E+03, 0.75089500E+02, 0.76274800E+02, 0.63530300E+02, 0.10886100E+02, -.12057500E+03, -.14310000E+03, 0.11538500E+03, 0.13226100E+03, -.16797200E+03, -.32178500E+02, 0.18417500E+04, -.95069700E+03, -.10578600E+04, -.92094500E+03, -.63605300E+03, -.31023900E+03, -.20977700E+03, 0.26546800E+03, 0.13987300E+02, -.44268100E+03, -.11284500E+04, 0.16727900E+03, -.85910800E+02, -.12782500E+03, -.83628700E+02, 0.25987300E+03, 0.27931600E+03, -.15290500E+03, -.93386900E+02, -.52201400E+03, 0.28871100E+03, -.63727800E+01, 0.46741300E+03, -.25862900E+03, -.10105900E+04, -.23369300E+03, -.53783800E+03, -.53877700E+02, -.24513500E+03, -.10734100E+04, -.43154600E+03, -.30150200E+03, 0.71013000E+03, 0.26836300E+03, -.15507900E+03, -.22329900E+03, -.13421300E+03, -.24635300E+03, 0.11634600E+03, -.15040300E+03, 0.12403100E+03, -.19002600E+03, -.17518900E+03, -.96078800E+03, -.39642000E+03, 0.21628800E+03, 0.49824900E+03, 0.19828800E+03, 0.41977700E+03, 0.71961500E+02, 0.69778500E+02, 0.17702600E+02, -.21250000E+03, 0.13403800E+03, 0.34263900E+03, 0.17920900E+03, -.10003100E+03, -.24172800E+03, -.89598400E+02, -.33913700E+03, -.48770700E+02, 0.34784400E+01, -.39962500E+03, -.15790700E+03, -.92368700E+02, 0.53022300E+03, 0.89975100E+03, -.44691800E+03, 0.11825700E+03, -.44980800E+03, 0.48252400E+01, 0.29259300E+02, -.31314600E+03, -.28461000E+03, -.38679300E+03, 0.22601000E+03, 0.17387900E+02, -.31303100E+03, 0.16042400E+03, 0.41961500E+03, 0.15654300E+03, -.58297100E+02, -.25843100E+03, 0.31801500E+03, 0.24296200E+03, 0.53024500E+03, -.17643000E+03, 0.12876200E+03, -.19843400E+02, -.29981200E+02, 0.59846000E+01, -.60807100E+02, 0.17946400E+02, -.23684800E+02, 0.49389900E+02, 0.16250000E+02, 0.14953800E+02, 0.34259100E+02, -.58597500E+02, -.28667400E+02, 0.10656300E+03, 0.26328800E+03, 0.50411600E+02, 0.19887300E+02, 0.85056900E+01, 0.86299800E+01, -.96140000E+02, 0.22546800E+02, -.10669200E+03, -.54389900E+02, 0.25447100E+02, 0.69977100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16635400E+01, -.14183100E+00, 0.10252600E+00, 0.39082400E+00, 0.62504200E+00, -.15602100E+00, -.14027500E+00, -.35133800E-01, -.13240100E-02, 0.41648100E-01, 0.16547500E+00, -.12428200E+00, -.26922300E+01, -.56086800E+00, 0.52576400E+00, 0.80382200E-01, -.35720800E+00, -.40815000E+00, -.11923600E-03, -.67087200E+00, 0.43166400E+00, -.19358700E+01, 0.70549500E-01, -.23037900E+00, 0.59148100E-01, 0.33122800E+00, -.64876900E-01, -.43395500E-01, -.22314500E+00, 0.14535000E+01, -.18559600E+00, -.56928200E-01, 0.66654900E-01, 0.81644900E+00, 0.74570500E-01, 0.20821000E-01, 0.15221600E-01, -.55368800E+00, -.18842800E+00, -.30704300E-01, 0.42766500E-01, 0.80655900E-01, 0.26210900E+00, -.15804200E-01, 0.25126200E+00, -.20202900E+00, 0.62812800E+00, -.10400500E-01, -.26697400E-02, -.98784300E-01, -.67578300E+00, -.12404800E+00, -.13556700E+00, 0.20077700E+00, 0.82318100E-01, -.31724900E+00, -.91292100E-01, -.11097200E+01, -.13467500E-02, 0.15955300E+00, 0.29337200E+00, -.24113400E+00, -.28815300E-01, 0.58475100E-01, -.78271600E+00, -.34417200E+00, -.36980700E-01, 0.34723400E+00, -.20814900E-01, 0.42095700E-03, 0.17808500E-01, 0.17253900E+00, 0.93344800E-01, -.54976800E-01, 0.18393100E+00, -.45242600E-01, -.92627200E-01, -.36177500E+00, -.24243300E+00, 0.18083600E+00, 0.19098800E-03, 0.83191600E+00, -.50829200E+00, 0.68547300E+00, -.41737100E-01, -.15508000E-02, 0.26969600E+00, 0.32017000E+00, 0.21309300E+00, 0.22077600E-02, -.17743800E+00, 0.15974100E-01, -.39343700E+00, -.54331000E+00, 0.46165100E+00, 0.17913600E+00, 0.30787700E-01, 0.44524400E+00, -.41470400E+00, 0.41031100E-01, -.65648800E+00, -.20587200E-01, -.30033000E-02, 0.60373400E-01, 0.18817100E+00, -.38628000E+00, 0.35992700E+00, 0.36895800E-01, 0.14121800E+00, -.38993000E+00, 0.11085200E+04, -.55332500E+03, -.30322700E+03, -.55425900E+03, 0.31065300E+02, 0.97388500E+02, -.24575300E+03, -.21092100E+03, -.57322500E+03, -.14807900E+02, -.33376800E+03, 0.11655500E+04, -.58198700E+03, 0.33266400E+03, -.58277800E+03, -.48898400E+03, -.83171700E+03, -.38504500E+01, -.17022700E+03, -.72593500E+03, -.71544800E+03, -.23118200E+03, 0.60198400E+03, -.30142700E+03, -.64154500E+03, -.30099100E+03, -.13307400E+01, -.19626900E+03, 0.18889400E+03, 0.42401000E+03, -.61952200E+02, -.28565600E+03, -.16277600E+03, 0.20170400E+02, -.12685500E+02, 0.60621200E+02, -.10812100E+02, -.10145200E+03, 0.45749700E+02, -.95034500E+02, -.12868200E+03, -.22844700E+03, 0.11511300E+03, -.32081100E+03, -.14902000E+03, 0.73261500E+02, -.36810500E+02, 0.74503300E+02, -.28324700E+02, -.56021900E+02, -.64720100E+02, -.38295000E+02, 0.25333400E+03, -.62152600E+02, 0.53008800E+03, -.26722400E+04, 0.13357800E+04, 0.83585300E+03, 0.13361300E+04, 0.53406000E+03, 0.92984700E+03, 0.73475400E+02, -.45744300E+03, 0.99949900E+03, 0.84553800E+03, 0.10001200E+04, 0.52426100E+03, -.26162600E+03, -.15785000E+03, -.26213000E+03, -.17523500E+03, 0.11378800E+03, -.10440800E+03, -.21368200E+03, -.69077300E+03, 0.82967500E+02, -.54832400E+03, -.55448400E+02, 0.26297100E+02, -.84070000E+03, 0.27725700E+02, 0.34806400E+03, 0.47321600E+03, 0.52637100E+02, 0.41701400E+03, 0.30031300E+03, 0.38164700E+03, -.20939700E+03, -.57849000E+03, 0.28980000E+03, 0.87928500E+03, 0.28923900E+03, 0.22352400E+03, 0.64935700E+03, 0.19808900E+02, -.95243300E+02, -.34462300E+02, 0.28825700E+03, 0.24125800E+03, 0.14295200E+04, -.71693300E+03, -.66050600E+03, -.71476800E+03, -.23324300E+03, -.35756000E+03, -.19848100E+03, 0.68238300E+02, -.56642600E+03, -.38204600E+03, -.36145100E+03, 0.46353500E+03, -.23171300E+03, -.16479700E+03, -.23176700E+03, -.46035100E+02, -.31781100E+02, -.23307500E+02, 0.22962000E+02, -.31481500E+03, -.12493700E+03, -.15760900E+03, 0.20991200E+04, -.10471000E+04, -.47383200E+03, -.10495600E+04, -.57452200E+02, -.59634700E+02, -.54093800E+03, -.33862300E+02, -.63378000E+03, 0.11972200E+03, -.10205500E+04, -.72915100E+03, 0.36414000E+03, 0.42810700E+03, 0.36456600E+03, 0.73612200E+02, -.16227600E+03, 0.24982700E+03, 0.25894200E+03, 0.52887200E+03, -.31579900E+01, 0.23912300E+03, -.44486200E+02, -.18982800E+02, 0.23706600E+02, -.11905400E+02, -.74334500E+01, -.12749400E+02, 0.13906900E+02, -.13245700E+02, -.82482400E+01, 0.36501800E+01, 0.11127400E+01, 0.29865300E+02, -.26404800E+03, 0.64106000E+02, -.12531000E+03, 0.51250900E+02, -.26596900E+03, 0.10073000E+03, -.85989300E+02, -.90982900E+02, -.19179900E+03, -.85654100E+02, -.88448000E+02, 0.53919900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.10434700E+02, 0.31552500E+00, -.25926200E+01, 0.59471600E+01, 0.87780400E+01, 0.28718000E+01, -.21545900E+01, 0.15489400E+01, -.43357000E+00, -.26037900E+00, 0.44083900E+01, 0.47890900E+01, 0.12741200E+02, 0.92498400E+01, 0.46670400E+00, -.11696900E+01, 0.35198900E+01, 0.35717300E+01, 0.60881700E+00, -.23170000E+00, 0.17651700E+01, 0.60586900E+01, 0.10223900E+01, 0.35155700E+01, 0.21689500E+00, -.35597300E+00, -.20633100E+00, -.15511700E+00, 0.37936800E+00, -.11553300E+02, 0.14760700E+01, 0.57098800E+00, -.31828800E+00, -.25140500E+01, -.11652800E+01, 0.16498500E+00, -.46553300E-01, 0.22119500E+01, 0.33182400E+01, 0.31889700E+00, 0.29837300E+01, -.17114300E+01, -.25855200E+01, -.10426100E+01, -.77005000E+00, 0.36902000E+00, -.62015300E+00, -.16143500E+01, 0.70372200E+00, 0.38625700E+00, 0.34023900E+01, 0.13302900E+01, 0.82802900E+00, 0.47294700E+00, 0.59850200E+00, 0.32935300E+01, -.11705600E+01, 0.16953200E+01, 0.71915700E-03, -.32906900E+01, -.83049700E+00, 0.28926800E+01, 0.56114300E-01, -.51206200E+00, 0.27680600E+01, -.36121200E+00, 0.20867700E+00, 0.12674300E+00, 0.39286900E+00, 0.10725900E-01, 0.76796900E+00, 0.96912100E+00, -.14291000E+01, 0.48120200E+00, -.64135400E+00, 0.27504400E+00, -.49210300E+00, -.11927400E+01, -.10993000E+01, 0.11267600E+01, -.42498900E-02, 0.68296500E+00, -.36206600E+01, 0.18845100E+01, 0.29425300E+00, 0.16818300E+01, -.57588900E+00, 0.10000700E+01, 0.11572300E+01, -.85874900E-01, -.20615600E-01, 0.30973900E-01, -.49154100E+01, -.45764300E+01, 0.93805000E+00, 0.11176700E+01, 0.61150800E+00, 0.21365600E+01, 0.15424300E+01, -.46246200E+00, -.95603100E+00, -.46127100E+00, 0.46629400E+00, -.55338600E+00, -.56489800E-01, -.42078200E-01, -.51478900E-01, -.12227700E+01, 0.28827700E+01, 0.14248000E+01, -.13313300E+01, 0.16995800E+03, -.10207900E+04, 0.35060000E+00, 0.11387300E+04, 0.22552200E+03, -.13793700E+03, -.57301500E+03, -.10259000E+04, 0.76507900E+03, -.96592200E+03, -.10083900E+05, 0.47655600E+04, 0.40013000E+04, 0.50415300E+04, -.72881700E+03, 0.59763700E+03, 0.36805600E+04, 0.80246400E+03, 0.43466800E+04, 0.54790400E+03, -.34656800E+03, -.31721100E+04, 0.17544000E+04, 0.12105600E+04, 0.15862000E+04, -.31751900E+03, 0.15577000E+04, -.10439600E+04, -.19352800E+04, -.10932100E+03, 0.12834800E+04, 0.83516000E+04, 0.15421300E+04, -.87403600E+03, -.77042200E+02, -.78219700E+03, -.12029800E+04, -.28697300E+03, 0.60190200E+03, 0.10716000E+04, 0.35193100E+03, -.78821700E+01, -.19146100E+04, -.13612700E+04, 0.49556200E+03, 0.41786900E+03, 0.67947400E+03, -.24833400E+03, 0.38602900E+03, 0.15313900E+03, 0.10148100E+04, 0.14866600E+04, -.39115300E+03, 0.31016700E+04, 0.11182100E+05, -.53088400E+04, -.47683800E+04, -.55907500E+04, 0.15724600E+04, -.15782300E+04, -.19663300E+04, 0.20855100E+04, -.41131400E+04, -.14866900E+04, -.48948000E+04, 0.45323500E+04, -.22152200E+04, -.17275400E+04, -.22660400E+04, -.32470800E+03, 0.68746100E+03, -.11775900E+04, -.12923200E+04, -.21082900E+04, 0.83828900E+03, -.19280500E+04, -.19871800E+04, 0.12336100E+04, 0.11389300E+04, 0.99383000E+03, 0.50857500E+03, 0.94467800E+03, -.18276400E+04, -.26654000E+04, -.11492100E+04, 0.76196300E+03, 0.76462400E+04, -.38172200E+03, 0.41454100E+03, -.18407900E+04, 0.19007600E+03, -.54299700E+03, -.11702300E+03, -.27028300E+03, 0.55975700E+03, 0.10668700E+03, -.65607500E+03, 0.16435200E+04, -.85445900E+04, 0.40902000E+04, 0.33718600E+04, 0.42724000E+04, 0.11341900E+03, 0.12987400E+04, 0.13548300E+04, -.10138800E+04, 0.34195600E+04, 0.11649100E+04, 0.30684400E+04, 0.76871000E+03, -.28517400E+03, -.87712700E+03, -.38425400E+03, -.14348900E+04, 0.20535900E+03, -.12125000E+04, -.14161400E+04, -.93133700E+03, 0.51257000E+02, 0.31809400E+04, -.23529900E+04, 0.11821300E+04, 0.49523600E+03, 0.11773800E+04, 0.56024300E+03, -.27012400E+03, 0.28875300E+03, -.12940400E+04, 0.10290100E+04, 0.21021600E+03, 0.13927700E+03, -.14264900E+04, 0.66235800E+03, 0.60843700E+03, 0.71279700E+03, 0.13056600E+03, -.61332200E+03, 0.11722100E+04, 0.62478600E+03, 0.71114900E+03, -.73619700E+03, 0.54800900E+03, -.29316600E+03, -.52195600E+02, 0.12209300E+03, -.52395200E+02, 0.65652500E+02, -.80391800E+02, 0.51278700E+02, 0.17138600E+01, 0.20154400E+02, 0.12692100E+03, 0.95655600E+02, 0.33523900E+01, -.45930600E+03, 0.95743600E+03, -.41073600E+03, 0.23888400E+03, 0.33606200E+03, 0.41222300E+03, -.10165800E+04, -.13030200E+03, 0.43588200E+03, -.19827100E+03, 0.37688400E+02, 0.30539600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.53731600E+01, -.93097000E+00, -.18953500E+01, 0.29974000E+01, 0.43075800E+01, -.16620600E+01, -.70329600E+00, 0.32970500E+01, -.63354300E+00, -.11294200E+01, 0.28256700E+01, 0.24714000E+01, 0.31177500E+01, 0.44785800E+01, -.84010500E+00, -.74451800E+00, 0.20165600E+01, 0.51901200E+00, -.39020300E+00, 0.18414700E+01, -.18303000E+01, -.90422400E+01, 0.94080200E+01, -.47168000E+01, 0.59465400E-01, 0.17803000E+01, -.13820100E+01, 0.47933800E+00, 0.13676000E+01, 0.69040700E+01, -.49198200E+00, 0.27566100E+00, -.20664100E+01, 0.62945500E+00, -.26518400E+00, 0.10788600E+01, -.14377700E-01, 0.14662300E+01, -.96068300E+00, 0.56120300E+00, -.53388200E+00, 0.17633700E+01, 0.77265600E+01, 0.83934900E+00, -.48558100E+00, -.25292800E+01, 0.22197800E+01, 0.13081800E+01, 0.82391800E+00, 0.22232300E+01, -.53364100E+01, -.82752000E+00, -.94950900E+00, 0.13755400E+00, -.11905800E+01, -.40585100E+00, 0.49192200E+00, -.33398000E+01, 0.21808000E-02, -.68210000E-01, -.42845100E+00, -.20536000E+00, -.14280600E+00, -.50529300E+00, 0.33736300E+00, -.56847000E-04, 0.90088300E+00, 0.12215200E+01, 0.46074300E+00, 0.50868200E-02, 0.29527800E+00, 0.20125300E+00, 0.92360200E-01, -.27329900E+00, -.18838800E+00, 0.23904000E-01, -.12612700E+00, -.81432000E-01, -.20749000E+00, 0.13782500E+00, -.93535000E-03, -.49643900E+00, 0.28174400E+00, -.24615900E+00, -.25339400E+00, -.12375700E+00, 0.24950500E+00, -.94661600E+00, 0.56138400E-01, -.11877400E+00, 0.69309300E+00, -.94906400E-01, 0.16033100E+01, 0.29476300E+01, -.81297100E+00, -.33084700E+00, 0.15637700E+00, -.40632500E+01, -.23661900E+00, 0.48264400E+00, 0.68046500E+00, 0.18653300E+00, -.16923900E+00, 0.85841900E+00, 0.31046200E+00, 0.80943400E+00, 0.13566500E+01, 0.12783100E+01, -.79540700E+00, -.98504700E+00, -.79956200E+00, -.21403000E+00, -.21652200E+04, 0.86733500E-01, -.76409600E+03, -.13209400E+04, 0.47556200E+03, -.10510300E+03, -.18112900E+03, -.11614400E+04, 0.17232100E+04, 0.25429900E+04, -.12714900E+04, 0.22105900E+04, -.12715900E+04, 0.59125100E+03, 0.10749000E+04, -.79499700E+03, 0.83167600E+03, -.96443200E+03, 0.56947000E+03, -.97638800E+03, -.18837200E+04, 0.94086100E+03, -.18819800E+04, 0.94188400E+03, -.35598100E+03, -.15445400E+04, 0.39668400E+03, -.20267800E+04, -.55040000E+02, -.20116000E+04, 0.11953000E+04, 0.73632900E+03, -.35563900E+03, 0.70549000E+03, -.36032000E+03, 0.94447200E+03, 0.70109800E+03, -.26998300E+03, 0.36792100E+03, 0.41122600E+03, -.36947200E+02, -.37540700E+03, 0.59422500E+03, -.29908300E+03, 0.60144100E+03, -.29730300E+03, 0.22914000E+03, 0.72335100E+03, 0.18778800E+03, 0.89706700E+03, -.34471400E+03, 0.13097100E+04, -.16836500E+04, -.53861700E+04, 0.26897500E+04, -.79522900E+03, 0.26924300E+04, -.56897300E+03, -.13593000E+04, 0.21738400E+04, 0.79216900E+03, 0.25309000E+04, -.17836900E+03, 0.10289300E+04, -.29327100E+04, 0.14671600E+04, 0.98837400E+03, 0.14663900E+04, 0.15561200E+04, -.37293400E+03, 0.14943800E+03, -.46543300E+03, 0.17522400E+04, -.10832400E+04, 0.17359900E+04, -.50653500E+04, 0.25301400E+04, -.25555000E+04, 0.25327100E+04, -.38229000E+03, -.11099000E+04, 0.90776600E+03, -.20871000E+04, 0.12275500E+04, -.12971200E+04, 0.37002800E+04, 0.23967700E+04, -.12007000E+04, -.23824900E+04, -.11983900E+04, -.48604900E+03, -.13887500E+04, 0.88093200E+01, 0.55474600E+03, -.81991100E+03, -.50119400E+02, -.12375900E+04, 0.85370000E+03, -.42227500E+03, 0.85792400E+03, -.42626100E+03, 0.68971900E+03, 0.10022000E+04, -.86548700E+03, -.62596500E+03, -.83080700E+03, 0.44806500E+03, -.24911400E+03, -.21667400E+04, 0.10816200E+04, 0.11432000E+04, 0.10833800E+04, -.19576900E+03, -.12691100E+04, 0.83771200E+03, -.74025200E+03, -.17139500E+03, -.11656300E+04, 0.40038000E+03, -.71861000E+04, 0.35831300E+04, 0.29526300E+04, 0.35933000E+04, -.32763700E+03, -.12374700E+04, 0.20717900E+04, 0.16891200E+03, 0.28726300E+04, -.12167500E+04, 0.27642700E+04, 0.22251800E+04, -.11112100E+04, -.59159000E+03, -.11122200E+04, -.20671000E+03, 0.74994200E+03, -.69794500E+03, -.49289200E+03, -.58548500E+03, 0.42592900E+03, -.18967800E+04, 0.15598800E+03, -.38037600E+02, -.10522800E+02, -.57513900E+02, -.63866500E+02, -.19490800E+02, 0.49155400E+02, 0.42703000E+02, 0.84543000E+02, -.13377700E+03, 0.16616000E+03, -.29036300E+03, 0.69105700E+03, 0.58161700E+03, 0.25072600E+03, -.15752200E+03, 0.35044300E+03, -.29164900E+03, 0.44516700E+03, 0.25859800E+03, 0.81404100E+03, 0.14085700E+03, 0.22492700E+03, -.40962100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.85440000E+01, 0.17554600E+01, 0.39143000E+01, -.61607100E+01, -.45841300E+01, 0.77689200E+00, 0.69323600E+00, -.26746700E+01, 0.65639100E+00, 0.12022200E+01, 0.17365100E+01, 0.47927700E+00, -.57466600E+00, -.29470200E+01, -.24541600E+00, 0.32525800E+00, -.18800200E+01, -.13260400E+01, 0.55361000E+00, -.91768100E+00, -.98976400E+00, 0.14140500E+01, 0.52706100E+01, -.23113300E+01, -.55548700E-01, -.95443400E+00, 0.88295400E-02, -.42109200E+00, 0.42591300E+00, 0.15180400E+01, 0.17432000E+00, -.51821100E+00, 0.17318700E+01, 0.96682100E-01, 0.15835400E+00, -.93947700E+00, -.75423200E-02, -.82470500E+00, -.20340900E+00, -.76055500E+00, -.15161100E+01, 0.33271600E+00, 0.45926000E+01, -.73347100E+00, 0.50307100E+00, -.45584600E+00, 0.14652900E+01, 0.29525900E+00, 0.38754900E+00, 0.42315700E+00, 0.28185700E+00, -.40633600E+00, 0.20760600E-01, -.40836400E+00, 0.16404000E+01, 0.43436300E+00, 0.15376400E+00, 0.13338800E+01, -.62964800E-02, -.50955600E+00, 0.92279700E+00, 0.52763900E+00, 0.19676800E+00, -.10762400E+00, 0.46462800E+01, 0.12561000E+01, -.10348400E+01, -.33428000E+00, -.89059900E-01, -.10107400E-01, 0.86535900E+00, -.66643700E+00, -.79071100E+00, -.12648500E-01, -.33362600E+00, -.81604900E-01, 0.12690000E+00, -.88007600E+00, -.78835300E+00, 0.50478600E+00, 0.35684200E-03, 0.11522300E+01, -.13515400E+01, -.34803600E+00, -.13724000E+00, -.33371800E+00, 0.10891700E+01, -.53382200E+00, -.21422200E+00, 0.30589300E+00, 0.12936100E+01, -.61755600E-01, 0.16279700E-01, 0.22936600E+01, -.33232300E+01, -.13172600E+01, 0.44931600E+00, 0.12565400E+01, -.11718900E+01, -.46177600E+00, -.64064300E+00, -.17823500E+00, -.34149700E+00, -.27572200E+00, -.13548900E+01, 0.16022000E+01, 0.34230300E+00, -.89912500E+00, -.15060700E+01, 0.13172200E+01, -.20235300E+01, 0.15085700E+00, -.72753200E-02, 0.79393600E+01, -.36005600E+03, -.12090300E+03, -.27700500E+03, 0.28917300E+03, 0.19761200E+03, -.19795700E+03, 0.89857400E+02, 0.62044700E+04, -.31119800E+04, -.42084200E+04, -.31022300E+04, -.12089900E+04, -.81456900E+03, -.15146500E+04, 0.15648000E+03, -.13769300E+04, -.85357600E+03, -.13626900E+04, 0.23539700E+04, -.11701800E+04, 0.13346300E+02, -.11769900E+04, 0.66469300E+03, -.30241900E+03, -.14827700E+03, 0.12908000E+04, -.36715100E+03, -.15178900E+03, -.34434200E+04, -.34492800E+03, 0.16757000E+03, 0.13074600E+03, 0.17352900E+03, 0.42555100E+03, 0.48913600E+03, -.33400600E+03, -.39890000E+03, -.25101900E+03, 0.16259600E+03, 0.87616000E+01, 0.40301300E+03, -.19936400E+03, -.39474900E+03, -.20149900E+03, -.95719400E+02, -.62842200E+02, 0.22261400E+03, -.10105400E+03, -.97510900E+02, 0.34027800E+03, -.25773900E+03, -.48166800E+03, 0.25232700E+03, 0.10913900E+04, 0.24090900E+03, -.71529500E+02, 0.30376400E+03, 0.26902500E+03, -.40193000E+02, 0.13017800E+03, 0.38786000E+03, 0.83709600E+03, -.11130400E+04, 0.55492300E+03, 0.58772200E+03, 0.55651500E+03, 0.15908300E+03, 0.13061200E+03, -.16702300E+03, 0.34152200E+03, 0.26374800E+03, -.21880700E+03, 0.28822200E+03, -.92981100E+03, 0.47455000E+03, 0.23158600E+04, 0.46490500E+03, 0.12068200E+04, 0.26555900E+03, 0.54361100E+03, 0.98083000E+03, 0.23364300E+03, 0.48130600E+03, -.18684500E+04, 0.11287700E+04, -.55585600E+03, -.54950800E+02, -.56439300E+03, 0.40522900E+02, 0.39645800E+03, -.45170700E+03, -.20536800E+03, -.85611600E+03, 0.47391500E+03, 0.19729000E+03, -.94905100E+02, 0.35135300E+02, -.59048600E+03, 0.47392600E+02, -.17605800E+03, -.41382200E+03, 0.18064000E+03, 0.68950000E+02, 0.10688400E+03, -.36671500E+03, -.64868600E+01, 0.20969300E+03, -.10030800E+03, 0.19404700E+03, -.10484700E+03, 0.73999100E+03, 0.75884800E+02, 0.36347300E+02, 0.55243000E+03, 0.22495100E+03, 0.76104400E+02, -.15083500E+04, -.20741900E+04, 0.10342800E+04, 0.20809900E+02, 0.10370800E+04, 0.15588400E+03, -.41552000E+03, 0.80452800E+03, 0.51241600E+03, 0.10356000E+04, -.45673500E+03, 0.59743600E+03, -.69347300E+03, 0.34595600E+03, 0.36191600E+03, 0.34669400E+03, 0.25330400E+03, 0.51117400E+03, -.49469300E+02, -.21124100E+03, 0.25352500E+02, 0.58060900E+03, 0.24675900E+03, 0.70769800E+02, 0.40159200E+02, -.31973700E+02, 0.61459300E+02, -.18536800E+02, 0.34835900E+02, -.52084200E+02, -.57708100E+01, 0.53818100E+01, -.16425700E+02, -.75587400E+02, 0.60470600E+01, -.38764000E+02, -.30191700E+03, 0.60022300E+02, -.51712200E+02, -.48541700E+02, -.39523200E+02, 0.61686800E+02, 0.40739600E+02, -.10561600E+03, 0.36992400E+02, 0.19362200E+02, -.85659900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22249100E+01, -.62204200E+00, -.80801400E+00, 0.19338100E+01, 0.19691300E+01, -.43423700E+00, -.31816500E+00, 0.16944800E+01, -.20572600E+00, -.12578600E+00, -.17516600E+00, 0.58499000E+00, 0.42637800E+01, 0.26301800E+01, -.43907800E+00, -.32430700E+00, 0.54225400E+00, 0.89926300E+00, 0.22500500E+00, 0.10731400E+00, 0.56848000E-01, 0.20249800E+01, 0.81152400E+00, -.67740200E-01, -.40573900E-01, -.36125900E+00, 0.32153700E+00, 0.70585600E+00, 0.42855900E+00, -.24245500E+01, 0.12850500E+00, 0.23838300E+00, -.30742400E+00, -.71250500E+00, -.29396700E+00, -.13517800E+00, -.38023200E-02, 0.13938800E+00, -.30062600E+00, -.18807200E+00, -.75814900E-01, -.12566600E+00, 0.16840400E+01, -.29827300E+00, 0.52225300E+00, -.16617600E+00, -.64667000E+00, -.84820200E-01, 0.38979400E+00, 0.95844700E+00, 0.20875600E+01, 0.89319000E-01, 0.17374600E+00, -.25523200E+00, 0.51329700E+00, 0.26691100E+00, -.14158900E-01, 0.88035000E-01, 0.29697300E-02, -.54316100E+00, -.14162800E-01, -.13424600E+00, 0.15934300E+00, 0.30664000E+00, 0.27615500E-01, 0.52836000E+00, 0.77956900E-01, -.96624800E+00, -.79517700E-01, 0.13912000E-02, 0.60334800E+00, 0.55630400E-01, -.16658100E+00, 0.10570300E+00, -.78658400E-01, 0.15145600E+00, 0.48731400E-01, 0.45857400E+00, 0.75992300E-01, 0.87914700E-01, -.94889600E-03, -.89099500E+00, 0.41621600E-01, 0.13927300E+01, 0.16751900E+00, -.32097600E+00, -.23425000E+00, 0.34316800E+00, -.20868400E+00, -.25125900E+00, -.24926300E+00, -.30666600E-01, -.64439800E+00, -.14484200E+01, -.73979500E+00, -.43240200E+00, -.29833900E+00, 0.21905800E+00, -.97496900E-01, 0.45435500E+00, -.14689700E+00, 0.20442400E+00, -.38262100E-01, 0.10209700E+00, 0.10944500E+00, -.92739500E+00, -.52357700E+00, -.70702200E+00, 0.73190900E+00, 0.51352700E+00, -.12632200E+01, 0.19297900E-01, 0.11150300E+00, -.87677800E-02, 0.67805200E+03, 0.35085100E+03, 0.50302600E+02, -.68333000E+02, -.37233800E+03, 0.26130800E+03, -.52707700E+03, -.85796200E+04, 0.43048900E+04, 0.19397900E+04, 0.42898900E+04, 0.20858600E+03, 0.75363100E+03, 0.12466200E+04, -.14889300E+04, 0.27130800E+04, 0.68925800E+03, 0.24423200E+04, 0.33933600E+04, -.17078000E+04, -.12349200E+04, -.16967100E+04, -.80115600E+03, -.60773500E+03, 0.10319200E+03, 0.90119700E+03, -.10724100E+04, -.47887300E+03, -.62599100E+03, 0.13096000E+03, -.64654800E+02, 0.19836400E+03, -.67589100E+02, -.38756900E+03, -.48140800E+02, -.20351600E+02, 0.43733700E+02, 0.28028400E+02, 0.10118700E+03, -.48286500E+03, -.59648100E+03, 0.29378700E+03, -.87503100E+02, 0.29843500E+03, -.47459300E+03, 0.11663400E+02, 0.28632300E+03, -.14533300E+03, 0.88965900E+02, -.83236200E+02, 0.77037500E+03, 0.32515100E+04, -.16450900E+04, -.40947900E+01, -.16255700E+04, 0.31851400E+03, -.47373200E+03, -.34691200E+03, 0.11289700E+04, -.10156000E+04, -.61167100E+03, -.53388800E+02, 0.11024800E+04, -.54783600E+03, -.25895700E+03, -.55126600E+03, 0.17350300E+03, 0.29033000E+03, -.53392200E+03, -.73871400E+02, -.49636800E+03, 0.23069600E+03, -.76044400E+03, 0.77582900E+04, -.38988700E+04, -.19896700E+04, -.38791800E+04, -.67608600E+03, -.80222700E+03, -.68312100E+03, 0.17114600E+04, -.23920200E+04, -.59009100E+03, -.24087600E+04, -.41632200E+03, 0.19897300E+03, 0.89005800E+03, 0.20825100E+03, 0.47318200E+03, 0.23767600E+03, 0.23193900E+03, 0.60210400E+03, -.12776200E+03, -.33394600E+03, 0.15300200E+04, -.13030700E+04, 0.66029700E+03, 0.43450400E+03, 0.65132200E+03, 0.21338700E+02, 0.14456300E+03, 0.24241300E+03, -.29423100E+03, 0.47372000E+03, 0.24169300E+03, -.44389000E+03, 0.11979300E+04, -.60575500E+03, -.82337500E+03, -.59898000E+03, -.32988100E+03, 0.44066300E+02, -.17175100E+03, -.12411700E+03, -.78744500E+03, -.14589000E+02, 0.18779000E+03, 0.17341600E+04, -.85296200E+03, -.60945400E+03, -.86726500E+03, 0.18000600E+03, 0.23600000E+03, -.67672000E+03, -.39343400E+03, -.65549800E+03, 0.56839000E+03, -.14783600E+04, 0.41947200E+03, -.21010900E+03, 0.22482800E+02, -.20981200E+03, -.38503000E+03, -.64300100E+03, 0.18452000E+03, 0.99118200E+02, 0.43433800E+03, -.38957500E+03, 0.41534900E+01, -.12813700E+03, -.26411500E+02, 0.34560800E+02, -.33531900E+02, 0.19967400E+02, -.27237400E+02, 0.23340400E+02, 0.72329900E+01, -.27403500E+02, 0.45393700E+02, 0.63601400E+01, 0.74335000E+02, 0.83211200E+02, -.45192200E+02, -.17795500E+03, 0.78203800E+02, 0.17272400E+03, 0.13694100E+03, 0.84754700E+02, -.10400300E+03, 0.11118700E+03, -.15490200E+03, -.35923600E+02, 0.24495600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.16107400E+01, -.70497900E+00, -.31814500E+00, 0.45238500E+00, 0.17920400E+01, -.92816700E-01, -.14288700E+00, 0.22941200E+00, 0.12933800E+00, -.20607800E-01, 0.18656700E+00, 0.64743300E+00, 0.32575500E+00, 0.92431100E+00, 0.11434300E+00, -.89387100E-01, 0.79272200E+00, -.28816500E+00, 0.74424400E-01, -.52383000E-01, -.51025500E+00, -.15437500E+01, 0.20313300E+00, -.12568600E+00, -.12465300E+00, 0.39689400E+00, -.37342000E+00, -.14217400E+00, 0.14274600E+00, 0.12050700E+01, 0.12081000E+00, 0.13079200E-01, -.41875300E+00, -.52267700E+00, -.90315000E-01, 0.84106200E-02, 0.13161200E-01, 0.10611700E+01, 0.12280500E+00, 0.27612000E+00, 0.13285800E+00, -.80712700E+00, -.10073900E+01, 0.32574900E+00, -.39756400E+00, -.55735000E+00, -.24769100E+00, 0.12521900E+00, -.35024300E+00, -.82648500E+00, 0.13047600E+01, 0.63465600E+00, 0.16889100E+00, -.13294500E-01, -.13607500E+00, -.22200700E+00, 0.71144400E-01, 0.38942700E+00, 0.86010100E-03, 0.51868800E+00, 0.21441900E+00, 0.47197700E+00, -.47422200E-01, -.40607000E+00, 0.13048300E+01, -.24143500E-01, -.30704300E+00, 0.22435100E+00, -.20267200E+00, 0.38003800E-02, 0.90098800E-01, -.11049000E+00, -.80453500E-01, -.60314700E-01, 0.23398000E+00, -.10255300E+00, -.86572200E-01, -.19474200E+00, 0.28898300E-01, -.14235300E-01, 0.29888100E-03, 0.33614200E+00, 0.19047700E+00, -.40656200E+00, 0.44276300E-02, -.40180300E+00, -.25606700E+00, -.10105500E+00, -.35703500E-01, -.13833600E-01, 0.25379900E+00, -.59579800E-01, 0.63633300E-01, 0.21790200E+00, -.69851500E+00, -.49516700E+00, 0.15030600E+00, 0.47703000E+00, -.20276600E+00, 0.23579300E+00, -.68940200E+00, -.26727200E-01, -.17503500E+00, -.14699800E+00, -.39598500E+00, 0.29722800E+00, 0.15006000E+00, 0.10841700E-01, -.21361000E+00, 0.29722400E+00, -.58782400E+00, 0.59718100E-01, -.20708700E+00, -.99207100E-02, -.34514600E+00, -.42397500E+03, 0.55511800E+03, 0.50910200E+03, 0.19641800E+03, -.37684400E+03, 0.40609500E+03, -.34952900E+04, 0.17563900E+04, 0.10752600E+04, 0.17477700E+04, -.55778600E+02, -.23527200E+03, 0.76791300E+03, -.76902500E+03, 0.11144600E+04, -.30801600E+03, 0.14376800E+04, 0.35351100E+04, -.17729700E+04, -.19909600E+04, -.17675900E+04, -.51941300E+03, -.85052400E+03, -.29007200E+03, 0.78428300E+03, -.92718900E+03, -.80727600E+03, -.18906700E+04, -.25504200E+03, 0.13242700E+03, 0.27809200E+03, 0.12654500E+03, 0.18172800E+02, 0.15839500E+03, -.20928600E+03, -.56688200E+03, 0.23542600E+01, 0.10503400E+02, -.40224300E+03, 0.16945400E+03, -.86229000E+02, -.31640600E+03, -.84395000E+02, -.48791900E+02, 0.53488700E+03, -.49254100E+02, -.30810400E+02, -.28864000E+03, 0.57107100E+03, 0.15730000E+03, -.23148000E+04, 0.11494800E+04, 0.16394800E+04, 0.11574100E+04, 0.54060400E+03, 0.53279400E+03, 0.15790100E+03, -.18688700E+03, 0.10221500E+03, 0.52627300E+03, 0.15304800E+04, -.35086900E+03, 0.17647600E+03, 0.29095300E+03, 0.17539300E+03, 0.22243200E+01, -.37752900E+03, 0.20745400E+03, -.33460700E+03, 0.27536000E+03, -.56732200E+03, -.22327900E+03, 0.56763900E+04, -.28489700E+04, -.27661100E+04, -.28382600E+04, -.38528000E+03, -.29388900E+03, -.87206300E+03, 0.13518100E+04, -.14053700E+04, -.20011100E+03, -.25258100E+04, 0.14894300E+03, -.76150400E+02, 0.82517500E+03, -.74263700E+02, 0.54014600E+03, -.75044800E+02, 0.40469400E+03, 0.64568800E+03, -.19510200E+03, -.20815400E+02, 0.15242100E+04, 0.16647700E+04, -.82912500E+03, -.78226200E+03, -.83249000E+03, -.18960700E+03, -.18943000E+03, -.17188400E+03, 0.20302700E+03, -.16157700E+03, -.22981900E+03, -.12221700E+04, 0.61180400E+03, -.30794100E+03, -.38001000E+03, -.30593100E+03, 0.90998100E+02, -.19926700E+02, -.12321600E+03, 0.47412800E+02, -.55570200E+03, -.20113500E+02, -.35494400E+03, 0.37768700E+03, -.18950100E+03, -.91640700E+01, -.18911100E+03, -.15469800E+03, 0.10683400E+03, -.25072100E+03, -.23085600E+03, -.12553700E+03, 0.10985900E+03, -.10980000E+04, 0.63814300E+03, -.31940200E+03, -.11464000E+03, -.31900200E+03, -.13204200E+03, -.84711400E+00, -.52048200E+03, -.43431700E+03, -.17417900E+03, 0.91611300E+02, -.92305100E+03, 0.15110500E+02, 0.47407300E+01, 0.13583100E+02, 0.14030600E+02, -.16795700E+02, 0.49642100E+01, -.11687400E+02, 0.11929700E+02, 0.12740100E+02, -.20153000E+02, 0.43509000E+02, -.34254300E+02, -.97477000E+02, -.68123700E+02, -.10316400E+03, -.29602300E+02, -.15435000E+02, -.11112900E+02, 0.70286100E+02, -.17866500E+02, 0.94267600E+02, -.62741200E+02, 0.36479500E+02, -.48186500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.45379100E+01, -.70840300E+00, -.91422000E+00, 0.12199000E+01, 0.20512800E+01, 0.23929800E+00, -.60905600E+00, -.18886000E+01, 0.11099600E+01, -.40472800E-01, -.11712800E+01, -.79988300E+00, -.42680500E+01, -.21163500E+01, 0.31776200E+00, 0.18631500E+00, -.13315400E+00, -.32402500E+01, -.34400500E+00, 0.93108100E+00, 0.24123100E+00, -.48722700E+01, 0.17170900E+01, -.11427900E+00, -.14737800E+00, 0.11411200E+01, -.71650000E+00, -.88257300E+00, 0.15684500E+00, -.78525800E+00, -.89869700E+00, -.14041300E+00, -.24599500E+00, 0.35474400E+00, -.24300500E+00, 0.44368700E+00, 0.30100900E-01, 0.14125200E+00, 0.12834400E+00, 0.41164400E+00, -.21649000E+00, -.40456200E+00, -.34425900E+01, 0.52036500E+00, 0.39464800E+00, -.20009400E+00, 0.18053700E+01, 0.30617600E+00, -.14693100E+00, -.89079600E+00, -.44265000E+00, -.14162600E+00, -.12482700E+00, 0.33948600E+00, 0.41588000E-01, -.77061900E+00, 0.82585400E-02, -.57927900E+00, -.19415600E-02, 0.78198100E+00, 0.94647400E+00, -.66327300E+00, 0.25687900E+00, 0.22845800E+00, 0.26294400E+00, -.23396200E-01, -.64117800E+00, 0.94229200E+00, -.40297100E+00, -.38906600E-02, 0.17723600E+00, 0.10723300E+00, -.17963000E+00, 0.28099300E+00, -.70743600E+00, 0.39123300E-01, -.10113400E+00, 0.28673100E+00, 0.21610200E+00, 0.40005500E-01, 0.65194000E-03, -.34687400E+00, 0.21904500E+00, -.35814500E+01, -.11012100E+00, 0.34617600E+00, -.43187400E+00, 0.40634600E-01, -.19291600E+00, 0.73275500E-01, 0.12554100E+01, 0.64059700E-01, 0.13125400E+00, -.14914800E+01, 0.40839000E+00, 0.28189100E+01, -.84672300E+00, -.41363900E+01, 0.64324800E+00, 0.12838300E+00, 0.35826300E+00, 0.69280700E-01, -.97241800E-01, 0.18730600E+00, 0.17838300E-01, 0.14303300E+01, 0.27867500E+00, -.31006700E-01, -.82431300E+00, 0.20912300E-01, -.12296400E+00, -.56967800E-01, 0.78266800E-01, 0.77830900E-02, -.36934100E-01, -.13317200E+01, 0.34583300E+03, 0.36521000E+03, 0.11498400E+03, 0.19900300E+03, 0.70016200E+02, -.42697700E+03, 0.22172800E+03, 0.11612000E+04, 0.21358400E+03, 0.83320100E+03, -.83783800E+03, 0.84509300E+03, 0.67698200E+03, 0.84942300E+02, -.56484000E+03, 0.12915500E+02, 0.16455600E+04, -.82591900E+03, -.21184700E+04, -.82281300E+03, -.62986100E+03, -.51033700E+03, -.23485800E+03, -.48521200E+03, -.57601700E+03, -.51841000E+03, -.12439600E+04, -.27518900E+02, 0.22542200E+02, -.13141500E+03, 0.14879200E+02, -.84219800E+01, -.12616500E+03, -.26839000E+03, -.50997000E+03, 0.82142000E+02, -.16868700E+03, -.13652700E+03, 0.10732800E+03, -.53045900E+02, 0.22969700E+02, -.53406700E+02, 0.38225500E+02, 0.24706500E+03, 0.17067700E+03, -.10097700E+03, -.46623300E+03, 0.15337700E+03, 0.30866900E+01, -.51116300E+04, 0.25500700E+04, 0.11437400E+04, 0.25557000E+04, -.85301700E+02, 0.98399000E+03, 0.36848900E+03, -.48375700E+03, 0.17070300E+04, 0.81522800E+03, 0.24219600E+04, -.13989500E+03, 0.69527700E+02, -.13513200E+03, 0.69919700E+02, 0.23448100E+03, 0.39562000E+02, -.59386700E+03, -.46020900E+03, 0.23703600E+03, 0.67831100E+01, -.12792400E+03, 0.17937500E+04, -.90662400E+03, -.28538800E+04, -.89692800E+03, -.10447100E+04, 0.35129200E+03, -.79913300E+03, -.49884300E+03, -.31902200E+03, 0.11595200E+03, -.66550400E+03, -.13808000E+04, 0.68885800E+03, -.64819600E+03, 0.69058000E+03, 0.74981500E+00, -.47163500E+03, 0.89856900E+03, 0.11352400E+04, 0.75220000E+03, -.14095300E+03, 0.56500900E+03, 0.33152100E+04, -.16585700E+04, -.47355900E+03, -.16575900E+04, 0.11462700E+03, -.43400600E+03, -.22607300E+03, 0.47665200E+03, -.10771100E+04, -.42412400E+03, -.17491500E+04, 0.47401700E+03, -.23818500E+03, -.33103500E+03, -.23703100E+03, -.15347900E+03, -.31789900E+03, 0.64243900E+02, -.25187900E+03, -.60573300E+03, -.23204800E+03, -.64902600E+03, 0.77522000E+02, -.45072700E+02, 0.93697800E+03, -.38948700E+02, -.14270200E+03, -.16492800E+03, -.10621000E+03, -.24554700E+03, -.12806600E+03, -.17359900E+03, -.29622400E+03, 0.15794500E+04, -.78876200E+03, -.29692400E+03, -.78960000E+03, -.27489000E+03, -.39547400E+03, -.32900200E+03, -.36805100E+03, -.15533300E+03, -.54703500E+03, -.76216100E+03, 0.13713300E+02, -.12851900E+02, 0.33434600E+02, -.37976100E+02, -.80464600E+01, 0.11268200E+02, 0.25945100E+02, 0.25675300E+02, 0.10224400E+02, -.51753500E+02, 0.29327800E+02, 0.23425400E+02, -.12941200E+03, 0.10333100E+03, -.11278900E+03, -.16647500E+02, -.18313300E+03, 0.75414300E+01, -.25218000E+02, -.91246600E+02, -.36672700E+02, 0.90760600E+01, 0.18192700E+02, 0.15395800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.47399300E+01, 0.88416200E+00, 0.65984400E-01, -.34913300E+00, -.23277400E+01, 0.43790300E-01, 0.57867500E+00, 0.83881400E+00, -.72838900E+00, 0.43468500E+00, -.28968700E+00, -.59057000E+00, 0.31336100E+01, 0.93500800E+00, -.16084700E+01, 0.18583700E+00, 0.16470600E+00, -.19800600E-01, -.18383200E+00, 0.19023400E+00, 0.59663900E+00, 0.10072500E+01, 0.28914100E+01, 0.47220500E-01, 0.52546100E-01, 0.45295400E-01, -.34266600E-01, 0.20322100E+00, 0.27355300E+00, 0.44928600E+01, -.46686000E+00, -.40109800E+00, 0.42352300E+00, -.31110400E+00, 0.33010800E-01, -.97860100E+00, -.48157500E-01, 0.66497200E+00, 0.35621700E+00, 0.14093400E+00, -.46389600E+00, -.16473100E+01, -.15117000E+00, -.11347800E+00, 0.74946800E+00, -.49152900E+00, -.72365900E+00, -.42586700E+00, -.15711500E+00, -.10507700E+01, 0.27415600E+00, 0.41422400E+00, 0.17520400E+00, -.14524900E+00, -.28018000E+00, -.67793800E+00, -.26052700E-01, -.15935200E+01, 0.30034400E-02, 0.14039300E+00, -.88999300E-01, -.76304600E+00, 0.11429400E+00, 0.13580400E+00, -.83028900E+00, 0.10477800E+01, -.49668000E+00, 0.28447300E+00, -.71652000E+00, -.36071000E-02, -.49033200E+00, 0.35330400E-01, 0.51202400E-01, -.13619100E+00, 0.20975000E+00, -.30987300E-01, -.10672800E+00, 0.66334300E+00, -.83668000E+00, -.30416400E-01, 0.18139700E-02, 0.11574500E+01, 0.11662200E+00, 0.67576700E+00, -.97022000E-01, -.84559000E+00, -.13688100E+00, 0.29687200E+00, -.13689500E+00, 0.31555100E-01, -.94690900E-01, -.23745400E-01, 0.15083200E+01, 0.18740100E+00, -.79012100E+00, -.11867600E+01, 0.17214500E+00, 0.43861900E-01, -.74587500E+00, 0.30655900E+00, 0.12925400E+01, 0.31014600E+00, 0.50995800E-02, 0.60714800E-01, 0.83665100E+00, 0.56104100E+00, 0.10785400E+01, 0.52760600E+00, 0.82355900E+00, 0.26125600E-01, 0.15857200E+01, -.19412700E-01, 0.73358100E-01, 0.82267800E-03, -.14489800E-01, 0.71055200E+00, -.38394500E+00, -.43874000E+03, -.20881100E+03, 0.24612400E+03, -.20709800E+03, 0.81571600E+03, -.42161500E+03, 0.59535000E+02, -.40791900E+03, 0.15006500E+04, 0.72098700E+03, 0.78606300E+02, 0.17579500E+04, -.74504900E+02, 0.74955200E+03, -.16532600E+04, -.53174100E+04, 0.26705100E+04, 0.16676100E+04, 0.26587200E+04, -.21498300E+02, 0.77479700E+03, 0.47628800E+03, -.22669600E+04, 0.94708800E+03, 0.82808700E+03, 0.38257100E+04, 0.44403100E+03, -.22753100E+03, -.36882600E+03, -.22044800E+03, -.58782600E+02, -.19543800E+03, 0.14109600E+02, 0.60777000E+03, 0.16660200E+03, 0.14333300E+03, 0.11917300E+03, -.64627200E+03, 0.32919900E+03, 0.67372400E+03, 0.32299600E+03, 0.22481600E+03, -.27353100E+03, 0.34471800E+03, 0.29317400E+03, 0.34627200E+03, -.67965900E+03, -.31951300E+03, 0.28138700E+04, -.13876300E+04, -.21092200E+04, -.14071000E+04, -.12840400E+04, -.91258400E+03, -.28702600E+02, 0.81539700E+03, -.62812400E+02, -.85278800E+03, -.16761200E+04, 0.12948900E+04, -.65177400E+03, -.94078400E+03, -.64742100E+03, 0.50794500E+02, 0.24169500E+03, -.72701200E+03, -.10639400E+03, -.54931900E+03, 0.74385000E+03, -.53005700E+00, -.76349400E+04, 0.38326200E+04, 0.25205200E+04, 0.38175000E+04, -.75492200E+03, 0.15762300E+03, 0.81203100E+03, -.33585400E+04, 0.14851700E+04, 0.49504300E+02, 0.47556700E+04, -.13172200E+04, 0.66543000E+03, -.14576400E+04, 0.65854800E+03, -.10976800E+04, -.11109900E+04, 0.41245900E+03, -.18904400E+03, 0.83485100E+03, -.82573300E+03, -.10136300E+04, -.76636300E+03, 0.37012800E+03, 0.11757300E+04, 0.38335600E+03, 0.67714900E+03, 0.39831900E+03, 0.13634600E+03, 0.22818300E+02, -.19117700E+03, 0.35569300E+03, 0.46428700E+03, -.11706000E+04, 0.59194900E+03, 0.28526400E+03, 0.58531100E+03, -.54287700E+03, -.22395100E+03, 0.19285400E+03, -.67854600E+03, 0.38152000E+03, -.51818100E+02, 0.14089000E+04, -.78570400E+02, 0.27828800E+02, 0.64083100E+03, 0.39423500E+02, 0.22519200E+03, 0.27716300E+03, 0.58376900E+02, 0.30313300E+03, -.13907900E+03, 0.22193400E+03, 0.10429600E+04, 0.69670400E+03, -.34703600E+03, -.13392800E+03, -.34828100E+03, -.49383200E+02, -.17603800E+02, 0.14984600E+03, 0.22190400E+03, 0.33459800E+01, -.32892300E+03, 0.25559300E+03, -.50481600E+02, -.25744700E+02, 0.12974300E+02, -.63683100E+02, 0.45239400E+02, -.11480600E+02, 0.50729300E+02, 0.19913200E+02, 0.12422400E+02, 0.28623000E+02, -.47978000E+02, -.39451400E+02, 0.29477300E+03, 0.29268900E+03, 0.53462100E+02, 0.15149800E+02, 0.59160600E+02, 0.30736400E+02, -.64592800E+02, 0.10259800E+03, -.13412300E+02, 0.10640900E+03, 0.16301700E+03, 0.54440700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10698700E+02, 0.33303700E+01, 0.16648600E+01, -.30030800E+01, -.78436400E+01, 0.17592100E+01, 0.12357400E+01, -.40246100E+01, 0.10289500E+01, 0.19854500E+01, 0.16940500E+01, -.11108000E+01, -.26368500E+01, -.76186000E+01, -.22667800E+00, 0.38887600E+00, -.28087700E+01, -.34727600E+01, 0.80740300E+00, 0.77082500E+00, -.20209300E+01, 0.17490700E+01, 0.99675400E+01, -.44271400E+01, -.23378900E+00, 0.13520500E+00, 0.36059800E+00, -.38294300E+00, 0.16027400E+01, -.40886000E+01, -.44862200E-01, -.41852000E-01, 0.18988800E+01, 0.98728500E+00, 0.47761000E-01, -.91009300E-01, 0.32346900E-01, -.10349900E+01, -.10972600E+01, -.17551300E+01, -.20991800E+01, 0.15593900E+01, 0.33308100E+01, -.20275800E+01, 0.97232800E+00, 0.16733600E+01, 0.21615300E+01, 0.36574600E+00, 0.12790600E+01, 0.26680000E+01, -.52308100E+00, -.19853100E+01, -.14787500E-01, -.10858900E+01, 0.22557900E+01, 0.33913600E+01, 0.21037300E+00, 0.67526100E+01, -.71611800E-02, -.32123400E+01, -.11328200E+01, -.12329700E+01, 0.86668200E+00, 0.12687800E+01, 0.87409200E+00, 0.14033200E+01, -.66361300E+00, -.10103800E+01, 0.19692400E+00, -.33702500E-01, 0.11262700E+01, -.46157800E+00, -.72044900E-01, -.34830500E+00, -.20838800E+01, 0.34176400E+00, 0.86028600E+00, -.10314200E+01, -.11231100E+01, 0.54531600E+00, 0.31646300E+00, 0.20259300E+00, -.22887400E+01, 0.11438600E+01, -.35139200E+00, -.74924100E-01, -.56970200E+00, -.46949500E+00, -.15016700E+00, 0.46179600E+00, 0.23007000E+01, 0.14335000E+00, -.62098700E+00, 0.35829200E+01, -.20485200E+01, 0.65118400E+00, 0.31657700E+00, 0.63679400E+01, -.22552800E+00, -.73002900E+00, -.34822700E+01, -.63674300E+00, 0.70293400E-01, 0.18683200E+00, -.38263000E+01, 0.11247800E+01, -.98819400E+00, -.13385100E+01, -.29415200E+01, 0.17314500E+01, -.98556900E-01, 0.22954400E+00, 0.55035000E-01, 0.54249600E-01, -.88471700E+00, 0.69698900E+00, -.57727500E+00, -.19869600E+01, -.16439600E+04, -.49136700E+03, -.21384200E+04, 0.80315500E+04, -.40410200E+04, -.72753900E+04, -.40164000E+04, 0.18545600E+04, 0.15783900E+04, -.36051700E+04, 0.10116600E+04, -.28145000E+04, 0.21519500E+04, -.80826900E+04, -.77277200E+04, 0.38847800E+04, 0.45863800E+04, 0.38640400E+04, -.73481700E+03, 0.15941000E+04, 0.12759000E+04, -.37708900E+04, 0.30345800E+03, 0.47412500E+03, 0.43317400E+04, 0.13652200E+04, -.69850700E+03, -.81147400E+03, -.66237900E+03, 0.28474500E+03, -.56361600E+03, 0.47753000E+02, 0.23761100E+04, 0.20343300E+04, -.55059100E+03, 0.83280700E+03, -.52789400E+03, 0.27292300E+03, 0.12597900E+04, 0.26243200E+03, -.10022800E+04, -.59949100E+03, 0.68741300E+03, -.65129800E+03, -.71676700E+03, 0.14719000E+03, -.23787400E+04, 0.16050400E+05, -.79943700E+04, -.62613600E+04, -.80261700E+04, -.40538600E+04, -.30494100E+04, 0.30267500E+03, 0.56457600E+04, -.64849600E+03, -.25800300E+04, -.30629100E+04, -.24830600E+04, 0.12355100E+04, 0.43590200E+03, 0.12417500E+04, 0.22971900E+04, 0.74702900E+03, -.15549400E+04, 0.22180100E+04, 0.32659500E+04, 0.43085900E+03, 0.24489500E+04, -.21727800E+05, 0.10885700E+05, 0.11591800E+05, 0.10864200E+05, -.99405600E+03, 0.77931400E+03, 0.40745900E+04, -.59109200E+04, 0.41686900E+04, -.62827400E+03, 0.13689900E+05, -.17000300E+04, 0.85308500E+03, -.22491900E+04, 0.84922200E+03, -.91096900E+03, -.42035900E+03, -.71882500E+03, -.13475400E+04, -.99263700E+03, -.37006700E+02, -.18507600E+03, -.61306200E+04, 0.30356900E+04, 0.45548800E+04, 0.30665100E+04, 0.12403500E+04, -.12858400E+03, 0.11805400E+04, -.15323700E+04, -.26755800E+03, 0.29153900E+03, 0.15121500E+03, -.47064400E+04, 0.23618500E+04, 0.24817700E+04, 0.23533500E+04, -.19233600E+03, -.50677200E+03, 0.17048900E+04, -.10554400E+04, 0.94760200E+03, -.10350900E+04, 0.17822900E+04, -.42533400E+04, 0.21330400E+04, 0.13690500E+04, 0.21280400E+04, 0.94936700E+03, -.14772400E+04, 0.26871700E+04, 0.30936500E+04, 0.28387100E+04, -.12183300E+04, 0.22259800E+04, 0.34564600E+04, -.17251100E+04, -.10433000E+04, -.17280000E+04, -.66801400E+03, 0.26647000E+03, 0.88063000E+02, -.45450000E+03, -.72724200E+03, 0.38802400E+03, 0.72519100E+03, 0.96115600E+01, 0.57327900E+02, -.18014900E+02, -.33957400E+02, 0.32569400E+02, 0.90945700E+02, -.25919900E+02, 0.15559100E+02, -.10232500E+03, -.31764700E+02, -.26984500E+03, -.41284200E+02, 0.13835100E+04, 0.93435300E+03, 0.51096800E+03, -.91174600E+02, 0.10749400E+03, -.20472200E+03, 0.36067000E+03, -.38125200E+02, -.17227600E+03, -.14143600E+03, 0.15545300E+02, 0.23165700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23696400E+01, -.15468100E+00, 0.85514800E-01, 0.23406900E+00, 0.57030400E+00, 0.21895200E+00, -.16845700E+00, 0.34027100E+00, 0.75092700E-01, 0.84240800E-01, 0.49452300E-01, -.12790800E+00, -.72155200E+00, 0.33047100E+00, 0.67467200E-01, -.12734700E+00, 0.37347700E+00, -.36619200E+00, 0.23845200E-03, 0.84905600E-02, -.25178500E+00, -.12923200E+01, -.52125100E+00, 0.20603800E+00, -.68906500E-01, 0.26355400E+00, -.21846600E+00, -.29488200E+00, -.35918700E+00, 0.50732700E+00, -.94698900E-01, 0.16611400E+00, -.50760500E+00, 0.17196500E+00, -.11517200E+00, 0.21961300E+00, 0.13475600E-02, 0.92064900E-01, 0.10329400E+00, 0.10066800E+00, 0.60151900E+00, 0.47969200E+00, 0.50931200E+00, 0.17342800E+00, -.10278600E+00, 0.36094500E-01, -.15655900E+00, 0.93744800E-02, 0.12544200E+00, 0.52123500E+00, -.47515500E-01, -.22408800E+00, -.14545000E+00, 0.24892100E+00, -.36198400E+00, -.16351500E-02, -.19788200E+00, -.25940700E-01, 0.85237700E-03, 0.25690200E+00, -.61935400E-01, 0.19586100E+00, -.17647600E-01, 0.52939600E+00, -.14007400E+01, -.52684800E+00, 0.26357000E+00, 0.38191300E-01, 0.34968500E+00, 0.16702700E-02, 0.23838700E+00, 0.23964800E+00, 0.37878800E+00, -.58958000E-01, 0.21144300E-01, -.39458500E-01, -.11684700E+00, -.27671200E+00, 0.11770100E+00, -.35718200E-01, -.27238400E-03, 0.23140900E+00, -.97914700E-01, -.79006700E+00, -.12858300E+00, -.44854200E+00, 0.24118000E+00, 0.87881900E-01, -.16503300E-01, 0.53681400E-01, 0.31814500E+00, 0.47137700E-03, -.11173300E-01, -.27574300E+00, -.39962800E+00, -.42526700E+00, 0.17047300E+00, 0.13850800E+00, -.68230800E+00, 0.25424900E+00, -.62378500E+00, -.29352700E-01, -.87364400E-01, -.70390600E-01, 0.44821400E-01, 0.39557100E+00, 0.87446300E+00, 0.26879300E+00, 0.51180400E+00, -.21808000E+00, 0.29772000E+00, 0.47178000E-01, -.21261900E-01, -.40288000E-02, -.92718000E-01, -.34450100E+00, 0.40999200E+00, -.15644300E+00, -.93433100E-01, 0.19473400E+03, 0.64554300E+02, 0.11798300E+03, -.62696800E+02, 0.13162700E+03, -.59010600E+02, -.14479100E+03, -.26941000E+03, 0.35621700E+03, 0.37906700E+03, -.72744400E+02, -.27078700E+03, -.32664300E+03, -.36141600E+03, 0.18449100E+03, -.21294800E+02, 0.18071300E+03, -.28480800E+02, 0.63107600E+02, -.91372900E+02, -.31325400E+03, 0.11041100E+03, 0.15664000E+03, 0.10918100E+04, -.23701400E+03, 0.11202400E+03, 0.17494800E+03, 0.11723200E+03, 0.70923400E+01, -.71964200E+02, -.74635300E+02, -.17514000E+02, -.19573900E+03, -.18355700E+02, -.39007300E+03, -.28859900E+03, 0.14681900E+03, 0.34124600E+03, 0.14425000E+03, -.48881300E+02, 0.62061600E+01, 0.23821000E+03, -.16742300E+02, 0.25517400E+03, -.16912600E+03, -.22737100E+03, -.61804900E+03, 0.31605200E+03, 0.22673700E+03, 0.30906000E+03, 0.24037300E+03, 0.24561300E+03, -.61864700E+02, 0.13670400E+03, 0.18328900E+03, 0.16868000E+03, 0.57244200E+02, 0.36715900E+03, -.18518100E+03, -.23511300E+03, -.18357200E+03, 0.94093800E+02, 0.28337100E+02, -.43224700E+03, -.19698500E+03, -.63620700E+03, 0.14406200E+03, -.24670700E+03, -.41853600E+03, 0.21320100E+03, -.10715500E+03, 0.20927800E+03, 0.99464500E+02, 0.25079800E+03, -.20655300E+03, -.39745600E+03, 0.18148600E+03, 0.30623400E+03, 0.66322700E+03, -.11184100E+04, 0.56191700E+03, 0.47454200E+03, 0.55916800E+03, -.68515700E+02, -.12112300E+03, 0.35732100E+03, 0.16660800E+03, 0.37928200E+03, -.10804400E+03, 0.64555300E+03, 0.25825900E+03, -.13592800E+03, 0.40030600E+01, -.12914600E+03, -.13860800E+03, -.11962000E+03, 0.75560400E+02, -.14158000E+02, -.24156100E+01, -.12369400E+03, -.17093200E+03, 0.14097400E+03, -.67902000E+02, -.21651200E+03, -.70482000E+02, -.97967500E+02, 0.21034700E+02, -.14543800E+03, -.11733600E+03, -.63789100E+02, 0.10368600E+03, 0.45808700E+03, 0.13283800E+04, -.66518300E+03, -.39334900E+03, -.66415500E+03, 0.16782100E+03, 0.20778400E+03, -.32395000E+03, 0.13114800E+03, -.41629100E+03, 0.22339600E+03, -.74301900E+03, 0.10003600E+03, -.49954100E+02, -.17833400E+03, -.50054500E+02, -.13684900E+01, -.13983400E+02, 0.39609800E+02, -.26645000E+02, 0.12427800E+03, -.14690900E+03, 0.27388400E+03, -.27513800E+02, 0.18826700E+02, 0.14037300E+02, 0.17156300E+02, 0.13521500E+02, 0.16487400E+02, -.17693900E+02, -.10569200E-01, 0.29825800E-01, 0.12042000E+02, -.16090500E+02, 0.10681700E+02, -.13848200E+03, 0.24894100E+02, -.14852100E+03, -.55947800E+01, -.86792900E+02, 0.80538600E+02, -.11243500E+03, -.35758300E+02, -.42859800E+02, 0.36203500E+02, 0.34179200E+02, 0.91671800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24271300E+01, 0.27684200E+00, 0.95482800E+00, 0.89422000E+00, -.12125000E+01, -.10270400E+01, 0.22579800E+00, -.10993200E+01, -.35457700E+00, 0.50088200E+00, 0.70368600E+00, 0.76364000E+00, -.34171800E+00, 0.16482200E+01, 0.55485600E-01, 0.14229400E+00, 0.18646600E+00, -.12844600E+00, 0.15514600E+00, -.93618500E+00, 0.19736800E+01, 0.18594400E+01, 0.18101900E+01, -.62246400E-01, -.27539400E-01, -.10403200E+01, 0.26925400E+00, 0.36771400E-01, 0.46064100E+00, 0.18549600E+00, 0.64389200E-01, 0.84977000E-01, 0.27242900E-01, -.35497600E+00, 0.37013900E-02, 0.35751800E+00, 0.33950400E-01, 0.43428600E+00, 0.13796200E+00, -.84951100E-01, -.20211500E+00, -.10454100E+01, -.25208800E+00, -.21729800E+00, -.58380700E-01, 0.36509000E+00, -.24868800E+00, 0.27439300E+00, -.29596500E+00, -.58683600E+00, 0.14615500E+01, 0.89544500E+00, 0.22048400E+00, 0.10531900E+00, -.39736900E+00, -.23111700E+00, 0.47945900E-01, -.39446600E+00, -.38441700E-02, 0.12145200E+00, -.24545600E-01, -.89474100E+00, 0.18292200E+00, -.45402200E+00, -.14209500E+00, -.52322700E+00, -.39938400E+00, 0.75532100E+00, -.12370400E+00, -.67502000E-02, 0.25565100E+00, 0.33500800E+00, 0.67254500E+00, 0.21886100E-01, 0.88372900E-01, -.67945800E-01, -.38595300E+00, -.19829200E+00, -.21517100E+00, 0.45188000E+00, 0.16041900E-02, 0.13645000E+01, -.46646100E+00, -.57913000E+00, -.67325600E-01, 0.17254100E+00, 0.74967400E+00, -.30436000E+00, 0.66648700E-01, 0.11831500E+00, 0.10481700E+01, 0.19316300E-01, 0.32678300E-01, -.54253200E+00, -.20687400E+00, 0.47135100E-01, 0.14601200E+00, -.14416200E+01, -.70727200E+00, 0.38603100E+00, -.98561400E+00, -.60367300E-01, -.13915500E+00, -.27486100E+00, -.30641400E+00, 0.10434000E+01, 0.69772800E+00, -.64157500E-02, -.10637100E+01, -.32814000E+00, 0.64771500E+00, 0.91257700E-01, 0.80177800E-01, -.26352800E-02, -.58219500E+00, -.45891900E-01, 0.24941500E+00, -.43334200E-01, -.17294600E+00, 0.34160700E+00, -.58727400E+03, -.22453800E+04, 0.11230200E+04, -.10300400E+04, 0.11226400E+04, 0.68067300E+02, 0.34767700E+03, -.15005500E+03, -.69284000E+03, 0.80800700E+03, 0.20534100E+03, 0.88694400E+03, -.23953800E+03, 0.11883100E+03, 0.55245900E+03, 0.11978600E+03, -.33826000E+02, 0.16886400E+02, 0.19614700E+03, -.26391900E+03, -.14751100E+03, 0.13950600E+03, -.60787800E+03, 0.12408300E+02, -.41030000E+01, -.10862000E+03, -.48309100E+01, 0.19391900E+03, -.14470100E+03, -.43250900E+02, 0.34391100E+03, 0.23585900E+03, -.15883200E+03, 0.32731300E+03, -.38440300E+03, 0.19173700E+03, 0.14344200E+02, 0.19206300E+03, -.22998900E+03, -.24563600E+02, 0.95785600E+02, -.73223500E+03, -.47497600E+03, 0.69564000E+02, -.71543800E+03, 0.26209000E+04, -.13129700E+04, 0.13428400E+01, -.13103500E+04, -.17813900E+03, -.95979100E+02, -.34697700E+03, 0.42839700E+03, -.11205600E+04, -.10986900E+03, -.19170900E+03, -.79577800E+03, 0.39868600E+03, 0.37422700E+03, 0.39790600E+03, 0.68362400E+03, -.12085600E+03, -.14943100E+03, 0.83257800E+03, 0.86595200E+03, -.60271700E+02, 0.51371000E+03, 0.77517000E+03, -.38975200E+03, 0.10225800E+04, -.38755600E+03, -.27765500E+02, -.10690300E+03, 0.18126900E+03, 0.13618600E+03, -.54057100E+03, -.22277200E+00, -.67506400E+03, -.24076100E+03, 0.11759800E+03, -.60370100E+01, 0.12027600E+03, 0.10048200E+03, -.99109600E+02, -.99959500E+02, -.37159300E+03, -.29484200E+03, 0.12740600E+01, 0.30002200E+03, -.38243200E+03, 0.18860700E+03, 0.26981300E+03, 0.19117200E+03, 0.35691800E+02, -.26818100E+03, 0.25421600E+03, 0.16671200E+02, 0.17552900E+03, -.13010600E+03, -.48598200E+03, -.51544400E+03, 0.25607500E+03, 0.31290600E+03, 0.25773500E+03, 0.10359100E+03, 0.12031400E+02, 0.31483600E+03, 0.33152500E+02, 0.23512900E+03, 0.46038000E+02, -.15425800E+03, 0.13676900E+03, -.64018600E+02, -.29845400E+03, -.68288300E+02, 0.23488700E+03, 0.11991500E+02, 0.15286400E+03, 0.66054400E+03, 0.21262300E+03, -.20755500E+02, -.26431800E+02, 0.49684200E+03, -.24870700E+03, -.50896200E+02, -.24851900E+03, -.20800200E+03, 0.26408900E+02, 0.19700200E+02, -.94759400E+02, -.18085800E+03, -.26083700E+02, 0.38346000E+03, -.25012800E+02, 0.98540400E+01, 0.47005700E+01, -.85173600E+01, -.27619500E+01, 0.14316400E+02, 0.22105600E+01, -.95515900E+01, -.36370200E+02, -.13897400E+02, -.33160400E+02, 0.48922500E+02, 0.93856200E+02, -.98945800E+02, 0.52439200E+02, -.23460500E+02, 0.10633500E+02, -.37125800E+02, 0.73734700E+02, -.10276300E+02, -.36205700E+02, 0.44644000E+02, 0.12567500E+02, 0.92524100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20226500E+01, 0.44338100E+00, 0.20176300E+00, 0.99512300E-01, -.21911900E+00, -.83905700E-01, 0.18810200E+00, 0.60260700E+00, -.49108700E+00, 0.62036700E-01, 0.48710400E+00, 0.37479400E+00, 0.12864800E+01, 0.40982400E+00, 0.21271300E+00, -.14146400E+00, -.28322600E-01, -.19589200E+00, 0.10840200E-01, 0.71665200E+00, -.56277800E+00, 0.35743000E+00, -.51433900E+00, 0.54079500E+00, -.14858800E-01, 0.10070200E+00, 0.21899200E+00, 0.49396800E-03, 0.20109800E+00, -.93638200E+00, 0.12610500E+00, 0.17915200E+00, -.64990900E-01, 0.38921400E-01, 0.10619700E-01, 0.52659100E+00, 0.23265100E-01, -.38027700E-01, 0.42378300E-02, -.27694800E-01, -.14841800E+00, -.53659000E-01, -.13815400E+01, 0.30263200E-01, -.27451600E+00, 0.50016500E+00, -.35784300E+00, 0.17635300E+00, 0.25639900E+00, 0.15381700E-02, -.11935900E+00, -.18735400E+00, 0.58887400E-01, 0.52106000E-01, -.10010400E+00, 0.36304200E+00, -.56380800E-01, -.49500600E+00, 0.13397200E-02, -.33615800E+00, -.25800900E+00, 0.46450900E+00, -.16489600E+00, -.87841900E-01, -.58504500E-01, 0.30596100E+00, 0.45331900E+00, 0.33420400E+00, -.15206500E+00, 0.26530000E-02, -.23301700E+00, -.21839200E+00, -.25945300E+00, -.42535100E-01, 0.84728500E-01, -.28214400E-01, 0.42501900E-01, 0.36340300E-01, 0.42235800E-01, -.12393700E+00, -.10047300E-03, -.55421600E+00, 0.23691100E+00, 0.41478500E+00, 0.16606500E-01, 0.17719300E+00, -.53585600E+00, -.11229100E+00, 0.99449300E-03, -.10299400E+00, -.28113400E+00, -.32744500E-01, -.34615000E+00, 0.17358500E+00, 0.73519900E+00, 0.95998900E+00, -.39234900E+00, -.24268800E+00, 0.39774900E+00, -.22784600E+00, -.17934100E+00, -.37400500E-01, 0.56380500E-02, -.69421700E-01, -.35244000E+00, -.20568000E+00, -.46715100E+00, -.34907100E+00, -.21919400E+00, 0.99521300E-01, 0.85525000E-01, -.30146700E-01, -.87794500E-02, 0.60705300E-02, 0.70683200E-01, -.22268200E+00, 0.58434200E-02, 0.11100000E+00, 0.13715400E+00, -.73290100E+00, -.65994800E+00, -.34891000E+04, 0.17516800E+04, -.46559300E+03, 0.17445600E+04, -.47940400E+03, 0.33977900E+03, 0.33469000E+03, -.10213800E+04, 0.12445000E+04, 0.13240400E+03, 0.24142500E+04, 0.17166900E+04, -.86433400E+03, 0.12118000E+03, -.85834500E+03, -.19920000E+02, -.30799500E+03, -.15353400E+03, 0.59542700E+03, -.43269300E+03, -.16347300E+03, -.10670200E+04, -.47128700E+03, 0.24067500E+03, 0.20980200E+03, 0.23525800E+03, 0.16222600E+03, -.77085600E+02, -.35839100E+02, -.10519700E+03, -.42660700E+02, -.11980400E+03, 0.13257900E+02, -.32000600E+03, 0.15692000E+03, -.18548900E+03, 0.16002000E+03, -.24151000E+03, 0.42125000E+02, -.29092000E+02, -.57632400E+03, -.25778800E+02, 0.10156700E+03, -.50502100E+03, 0.12549300E+04, -.63820100E+03, 0.10305700E+04, -.62738100E+03, 0.45419900E+03, -.97041400E+02, -.22217400E+03, 0.65200900E+02, -.10072300E+04, -.11658200E+03, -.48500600E+03, -.66958700E+03, 0.33720300E+03, 0.46322300E+03, 0.33479000E+03, 0.44406200E+03, -.25630600E+03, 0.25229400E+03, 0.47151600E+03, 0.76892900E+02, -.25570200E+03, 0.20150700E+03, 0.46782900E+04, -.23478500E+04, -.15967700E+03, -.23391500E+04, 0.23557400E+03, -.42581600E+03, -.52261500E+03, 0.12895700E+04, -.13873300E+04, -.17272000E+03, -.28292100E+04, 0.30459700E+02, -.18935500E+02, 0.11646000E+04, -.15233900E+02, 0.51602900E+03, 0.94691800E+02, 0.67723500E+02, -.46451500E+02, -.25109000E+03, -.16479100E+02, 0.68156100E+03, -.35842900E+03, 0.18372000E+03, -.27997900E+03, 0.17914100E+03, -.21312900E+03, -.84452800E+02, 0.33853500E+02, -.61066100E+02, 0.37736400E+03, -.65707300E+01, -.87781200E+02, 0.11563500E+03, -.61469600E+02, -.64285000E+02, -.57818300E+02, 0.19262300E+03, 0.18542600E+03, -.34878800E+02, 0.15676600E+03, 0.42061100E+02, 0.17232300E+03, -.12408000E+03, 0.90781100E+03, -.44869900E+03, -.74416300E+03, -.45393100E+03, 0.16671300E+03, 0.26887100E+03, -.29803400E+03, 0.11752200E+03, -.18559900E+03, 0.26624400E+03, -.69600100E+03, -.17002600E+03, 0.83993700E+02, -.35330300E+02, 0.84962500E+02, -.15571600E+03, -.10800900E+03, 0.11234500E+03, 0.23819700E+03, 0.21201600E+03, -.59999600E+02, 0.27258200E+03, -.24764300E+02, 0.20456100E+02, 0.85594500E+00, 0.16349200E+02, -.34611800E+01, 0.68282700E+01, -.17395500E+02, -.10706700E+02, -.21290600E+02, 0.75554300E+01, 0.24565200E+02, 0.29343800E+02, -.16284800E+02, -.17454000E+03, -.61569700E+02, -.25391600E+02, 0.89034700E+02, 0.88896800E+00, 0.39374100E+02, -.36208200E+02, 0.34319000E+02, -.87882800E+01, -.18945000E+02, 0.46238700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12813200E+01, 0.17828200E+00, 0.57905600E+00, -.86766800E+00, -.75456200E+00, 0.29705400E+00, 0.11248400E+00, -.45872500E+00, -.51058800E-01, 0.48468900E-01, -.24824100E+00, -.18360300E+00, -.49487900E+00, -.64895400E+00, -.70749500E-02, 0.94718600E-01, 0.12602900E+00, -.13747400E+00, 0.19473000E+00, -.45796900E+00, 0.40231700E+00, 0.66561700E+00, -.74145900E+00, 0.34875000E+00, -.11343400E+00, -.22412200E+00, -.10284900E+00, -.21334400E+00, -.26474600E-01, -.14687600E+01, 0.23057000E+00, 0.15579300E+00, -.13094600E+00, -.30211000E+00, -.63804400E-02, -.36203300E-01, 0.23249800E-02, 0.48326500E+00, 0.14310800E+00, -.78125600E-02, 0.15166800E+00, -.58139900E+00, 0.91571400E+00, -.12758200E+00, 0.63846500E+00, -.43192700E+00, -.42404100E+00, -.88876800E-01, 0.46709100E-01, -.10747900E+00, 0.10251500E+01, 0.19335400E+00, 0.60738000E-01, -.10696900E+00, -.21550800E+00, 0.44888300E-01, -.41385900E-01, -.25175900E-01, 0.11277100E-02, 0.17493500E+00, 0.90122900E-01, -.16722800E+00, 0.10898400E+00, 0.14929200E+00, -.47649700E+00, -.86887500E-01, 0.13670900E+00, 0.37090800E+00, -.75835600E-01, 0.72929400E-03, -.10436600E-01, 0.16996700E+00, -.14999100E+00, 0.66751300E-01, -.25887200E+00, 0.60814500E-01, 0.15507900E+00, 0.14814000E+00, 0.13421500E-02, -.13676200E+00, -.33507000E-03, -.86102200E-01, 0.16368500E+00, -.13457600E+00, -.45896400E-01, 0.19161900E+00, 0.32919700E+00, -.12112000E+00, 0.10817900E+00, 0.42828900E-01, 0.15675200E+00, 0.31135500E-01, 0.50634300E+00, 0.67015100E+00, 0.10400400E+01, 0.89078600E-01, -.12308400E-01, -.62107100E+00, 0.10956400E+00, 0.44208300E-01, 0.18619200E+00, -.16674400E-01, -.25888000E-01, 0.75697600E-01, -.33454600E+00, 0.38922500E+00, -.20558400E+00, -.60557100E-01, -.20762500E+00, 0.67604000E-02, -.14117700E+00, 0.69737100E-02, 0.85517100E-02, 0.26975600E-02, -.17891900E+00, 0.16557800E+00, -.57245800E-01, 0.35083800E-01, -.55318800E-02, -.16344600E-01, 0.23600900E-01, 0.45378500E+00, -.47975400E+01, 0.93090600E+03, -.32861300E-01, 0.20924800E+03, -.14576200E+03, 0.64163300E+01, 0.28207700E+03, 0.51670100E+02, -.11448900E+03, -.33115900E+03, -.32790500E+03, 0.16721800E+03, -.36015100E+03, 0.16396100E+03, -.11591000E+03, 0.49439200E+02, 0.42629600E+02, -.28779300E+03, 0.53690100E+02, -.23521100E+02, 0.27463800E+03, 0.12894500E+03, -.68663600E+02, -.36021300E+02, -.63143800E+02, -.71493900E+02, 0.25941900E+02, -.70732400E+02, -.40555900E+02, -.31079300E+01, 0.67995600E+02, -.97400900E+02, 0.18755700E+03, -.92143300E+02, 0.12356300E+03, -.93856300E+02, 0.62969700E+02, -.25792100E+02, 0.83398900E+02, 0.23676500E+03, -.12210700E+03, -.52477600E+02, 0.11801200E+03, 0.75028600E+03, -.36849500E+03, -.11124300E+04, -.37521700E+03, -.25546100E+03, -.26407100E+02, -.11619300E+02, 0.27663500E+03, 0.16852900E+02, 0.44933800E+02, -.31597100E+03, 0.26936100E+03, -.13588600E+03, -.20590900E+03, -.13466900E+03, -.19189900E+03, 0.12677900E+03, -.31673000E+03, -.21962300E+03, 0.34994100E+02, 0.12981800E+03, -.12331700E+03, -.91153300E+03, 0.45998100E+03, -.67847900E+03, 0.45578100E+03, -.16232700E+03, 0.22263400E+03, 0.90375500E+02, -.48857500E+03, 0.16781300E+03, 0.14886900E+03, 0.64208100E+03, 0.25263100E+02, -.10372300E+02, -.76871900E+03, -.12668200E+02, -.17378400E+03, -.80630600E+02, -.42526900E+02, 0.52918900E+02, -.66950200E+02, -.45518400E+01, -.16085200E+03, -.16825600E+03, 0.79450800E+02, 0.34696500E+03, 0.84209000E+02, 0.81436700E+02, 0.53812600E+02, 0.44847100E+02, -.63881500E+02, -.42482600E+02, -.16426000E+02, 0.17190900E+03, 0.54027400E+02, -.25061500E+02, -.70902100E+01, -.27007100E+02, -.92596500E+02, -.66011700E+02, -.96325000E+01, -.80111900E+02, -.98327800E+02, -.61603600E+02, 0.44016900E+02, -.71326500E+03, 0.35555000E+03, 0.32599900E+03, 0.35670600E+03, -.10629500E+03, -.15663400E+03, 0.26582400E+03, 0.70910900E+02, 0.32589800E+03, -.15331700E+03, 0.44359200E+03, 0.87582200E+02, -.43380400E+02, 0.23031900E+02, -.43764200E+02, 0.10096100E+03, 0.87291600E+02, -.27816600E+02, -.14456300E+03, -.10011900E+03, 0.71123500E+02, -.12904000E+03, 0.13052000E+02, 0.90279400E+00, -.24551900E+01, 0.22398500E+01, 0.20086000E+01, 0.79400600E+01, -.20731400E+01, 0.65432700E+01, 0.64079900E+01, -.62426900E+01, -.22066900E+02, -.83536300E+01, -.30400200E+02, 0.81577600E+02, 0.27078000E+01, 0.83366100E+01, -.72601000E+02, 0.49847800E+01, -.26935900E+02, 0.16802300E+02, -.31220400E+01, -.13334900E+01, 0.22724200E+02, -.16830300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.48940600E+00, 0.56539700E-01, 0.65968900E-01, -.28774700E+00, -.25872600E+00, 0.97762900E-01, 0.45626900E-01, 0.17722200E+00, -.67177100E-01, -.15805300E-01, -.14116300E+00, -.12292500E+00, -.79808700E-01, -.79145700E-01, 0.79929600E-01, -.91402200E-02, -.27710100E-01, -.14794100E-03, 0.80915300E-01, -.72692000E-02, 0.19994700E+00, 0.42797900E-02, -.41957300E+00, 0.64301900E+00, 0.35103300E-02, 0.69166200E-02, -.32216700E-02, 0.17664000E-01, 0.15170100E-01, -.12358200E+00, 0.43785200E-02, 0.34016400E-01, 0.36334600E-01, 0.62849000E-01, -.50516100E-02, 0.65055300E-01, -.55627300E-02, 0.52363900E-01, -.35303000E-01, -.18258700E-01, -.58622600E-01, 0.13035500E+00, 0.17827700E+00, 0.29538900E-02, -.90862600E-01, 0.92506700E-01, -.33334100E-02, 0.36954200E-01, 0.16654700E-01, 0.16543400E+00, -.48147600E-01, 0.79149200E-02, -.94307000E-02, 0.75520300E-01, -.22209400E-01, 0.20383700E-02, 0.77391700E-02, 0.13996100E+00, -.61035000E-03, -.10725500E+00, -.12168900E+00, -.24917600E+00, 0.57420400E-01, 0.16778200E-01, -.32023000E+00, -.20854700E+00, -.12019700E+00, -.18978900E+00, 0.78512800E-01, -.16940900E-02, -.23464400E-01, -.16621200E-02, 0.99745900E-01, 0.19634600E-01, -.11047200E+00, 0.68919400E-03, 0.41234400E-01, -.43207400E-01, 0.20305200E+00, -.31335300E-01, 0.13754500E-03, -.14822500E+00, 0.73575900E-01, -.16163500E+00, -.28641800E-01, -.12970000E+00, 0.61970800E-01, -.34339400E-01, -.60387500E-01, 0.32435600E-01, 0.12676000E+00, 0.67966000E-02, 0.88475700E-02, 0.25896600E+00, 0.76329600E-01, 0.25823400E+00, -.73167200E-01, -.25375300E+00, -.32257900E-02, -.25571000E-01, -.16202000E+00, -.20815700E-01, -.90868800E-02, 0.13203200E-01, -.17014400E+00, 0.87138800E-01, 0.10163500E+00, 0.24960100E-01, 0.17471500E+00, 0.58866400E-01, 0.16316100E+00, -.15947700E-01, -.36469600E-01, 0.24402700E-02, 0.17550900E-02, 0.10117500E-01, 0.15910500E-01, -.46472200E-01, 0.28317300E-01, 0.10267000E+00, 0.13736000E-01, 0.21467700E+00, 0.46160500E-01, 0.57119200E+03, -.11289200E-01, 0.10437800E+03, -.53035200E+02, 0.25222900E+03, 0.24866400E+03, -.20393500E+02, 0.65457900E+01, -.42010300E+03, 0.29730100E+03, -.14835700E+03, -.23123000E+03, -.14864600E+03, 0.19307900E+02, 0.11491300E+03, -.17186100E+03, 0.75999000E+02, -.31205900E+02, 0.93925300E+02, 0.31127600E+03, 0.10996900E+03, -.54321400E+02, -.68662800E+02, -.55526300E+02, -.67675200E+02, 0.11431500E+02, 0.68202100E+02, 0.63725000E+02, -.39768200E+02, 0.60123300E+02, -.12141200E+03, 0.28047500E+02, -.13672300E+02, 0.53264400E+01, -.14054200E+02, 0.68688400E+02, -.12557400E+02, -.12857400E+02, 0.15121200E+03, 0.12976400E+03, -.54859000E+02, 0.29023000E+03, -.48267600E+03, 0.24214200E+03, -.18953500E+03, 0.24135000E+03, -.84135900E+01, 0.55210800E+02, -.12299900E+03, -.24679600E+03, 0.99878100E+02, 0.24616800E+01, 0.24766600E+03, 0.45109100E+03, -.22590900E+03, -.22170000E+03, -.22554200E+03, -.17653000E+03, 0.67823000E+02, -.46036500E+02, -.17771300E+03, -.31910200E+03, 0.94215000E+02, -.19264000E+03, 0.74545100E+02, -.36975700E+02, -.41232800E+03, -.37266100E+02, -.52100200E+02, 0.37042900E+02, -.17955900E+03, -.78687200E+02, 0.38422200E+02, 0.26706200E+01, 0.43801400E+03, -.12543900E+03, 0.63308900E+02, -.32958500E+03, 0.62698100E+02, -.18575400E+03, -.64508600E+02, -.93414300E+01, -.61780100E+02, 0.60843100E+02, -.18034700E+03, -.11647400E+01, -.28327900E+03, 0.14223300E+03, 0.10301300E+03, 0.14163900E+03, 0.44703700E+02, 0.37496100E+02, 0.13400900E+03, 0.52027800E+02, 0.15211400E+03, 0.47954900E+02, 0.12381600E+03, 0.47103900E+03, -.23514900E+03, -.23943100E+03, -.23551700E+03, -.10989100E+03, -.15081800E+02, -.16346700E+03, 0.17804300E+02, -.13959600E+03, -.25801900E+02, 0.25838000E+01, -.20687000E+03, 0.10194200E+03, 0.10595900E+03, 0.10345700E+03, 0.22346600E+02, -.82243700E+01, 0.48562400E+02, -.87987000E+02, 0.22038600E+02, 0.63846700E+02, 0.88050200E+02, -.13182300E+03, 0.66277400E+02, 0.67862200E+02, 0.65897700E+02, 0.58550200E+02, 0.64399000E+01, -.10594800E+00, -.17607000E+02, 0.91173100E+02, 0.24141000E+02, 0.37410600E+02, -.74620700E+01, -.53202000E+01, 0.42300800E+01, -.24380200E+01, 0.32677000E+01, -.41785100E+00, 0.43788900E+01, -.18896700E+01, 0.38794600E+01, 0.30349700E+01, -.45179500E+01, -.14869300E+01, -.44179600E+02, 0.30795100E+02, -.12065200E+02, 0.18508700E+02, 0.10120300E+02, 0.30886800E+02, -.57268100E+02, 0.22901100E+02, -.10214100E+01, -.87629100E+01, 0.24486000E+02, 0.14020600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.67788200E+01, -.10581000E+01, -.18040900E+01, 0.47588200E+01, 0.50383800E+01, -.65800300E+00, -.92558500E+00, 0.13573900E+01, 0.20825400E+00, -.18005500E+00, 0.19983600E+01, 0.11279100E+01, -.52940300E+00, 0.36512800E+01, -.46748200E+00, -.69978200E+00, 0.12904700E+01, 0.95910400E-01, -.85657100E+00, 0.17487900E+01, -.73893000E+00, -.26300600E+01, 0.38596800E+01, -.21358800E+01, 0.12617800E+00, 0.11766200E+01, -.23777700E+00, 0.95323500E+00, 0.93627300E+00, 0.17545100E+01, -.31415100E+00, 0.18225100E+00, -.17335200E+01, 0.67919900E+00, -.33953600E-01, 0.17667400E+00, -.13177000E+00, 0.30222300E-01, -.99513800E+00, 0.10515700E+00, 0.25936800E+00, 0.10695900E+01, 0.13094200E+01, -.46567500E-01, -.13976000E+01, 0.18980500E+01, 0.18102200E+01, -.25852400E+00, -.13864800E+00, 0.10750600E+01, -.36343600E+01, 0.78883700E+00, -.49236800E+00, -.78892100E-01, -.62340600E+00, 0.19759200E-01, 0.33416500E+00, -.15258700E+00, 0.39359600E-02, 0.54211300E+00, -.42658200E+00, 0.10472300E+01, -.34279800E+00, -.32874000E-01, 0.24922800E+01, 0.74230300E+00, 0.12305400E+01, 0.98786200E+00, 0.77962000E+00, 0.53560200E-02, 0.85102200E+00, -.19691600E+00, 0.72523800E+00, -.89212900E+00, 0.13755000E+01, 0.22406200E-01, 0.27704100E+00, -.97231000E+00, 0.22465600E+00, 0.76053400E+00, -.15116500E-02, 0.18374900E+00, 0.11939200E+00, 0.18076000E+01, 0.28370300E+00, -.55060100E+00, -.32574600E+00, -.18831300E+00, -.44878200E+00, -.21829000E+00, -.33500300E+00, -.22670300E-01, 0.78553400E+00, 0.16647600E+01, -.56550500E+00, -.97520200E+00, -.61804300E-02, -.31455700E+01, -.60498800E+00, 0.11437900E+00, 0.61867100E+00, -.26307500E-01, -.26500800E+00, -.19603500E+00, -.92091000E-02, 0.24274000E+00, 0.14594700E+01, 0.59376100E+00, 0.67326800E+00, -.21207900E+00, 0.20224000E+00, -.11569000E+00, -.16684700E+00, -.95342800E-02, -.37360200E-01, 0.11510500E+01, -.69796500E+00, 0.77172200E+00, -.35298600E-01, -.32173700E+00, -.91633400E-01, 0.18046000E+01, 0.81733200E+00, 0.39742600E+01, 0.80273700E+01, 0.81419600E+03, -.84534700E+03, -.21015300E+03, -.23483700E+03, -.74920400E+03, -.45006400E+03, 0.38155700E+03, 0.18874100E+03, -.95055600E+02, -.79068200E+03, -.94397100E+02, -.48544200E+03, -.45186800E+03, 0.31371400E+03, -.48205300E+03, -.21927100E+03, -.65094100E+03, -.15781900E+04, 0.62268300E+03, -.30478700E+03, -.45800100E+03, -.30951500E+03, -.73422500E+02, -.52436400E+01, -.12200600E+03, -.15959100E+03, 0.27150400E+03, -.10654500E+03, 0.60232500E+03, 0.31024700E+03, -.15712600E+03, -.15018400E+03, -.15490600E+03, 0.15313500E+03, 0.80358100E+02, -.12950800E+03, 0.27219400E+03, -.58526400E+03, 0.15223300E+03, 0.53142200E+02, -.30244300E+04, 0.15078300E+04, 0.69602000E+03, 0.15122300E+04, -.24907700E+03, 0.11451300E+04, 0.44927100E+03, -.45832200E+03, 0.16808300E+04, 0.10588700E+04, 0.11176600E+04, -.52467400E+03, 0.26361400E+03, 0.14365800E+03, 0.26231000E+03, -.20548400E+02, -.97207200E+02, 0.19107900E+03, 0.19447600E+02, 0.12378200E+04, -.16979900E+03, 0.34565900E+03, 0.32436400E+02, -.13341400E+02, -.53309100E+03, -.16262400E+02, -.83031200E+03, 0.53009900E+03, 0.12017500E+03, -.31888300E+03, 0.24046200E+03, 0.26689800E+02, -.65130900E+03, -.71401200E+03, 0.35105800E+03, -.58031000E+03, 0.35714100E+03, 0.10819700E+03, 0.15159000E+03, 0.83884300E+02, -.45762700E+01, 0.39050800E+03, 0.49489300E+03, -.84350700E+03, 0.27439000E+04, -.13667500E+04, -.62778800E+03, -.13720300E+04, 0.27506200E+01, -.66704100E+03, -.33680200E+03, 0.51163100E+03, -.12371400E+04, -.68640600E+03, -.68927000E+03, -.27201200E+02, 0.11151800E+02, 0.49550200E+02, 0.13581900E+02, -.94732300E+02, -.31441600E+03, 0.29544700E+03, -.22561000E+03, -.20714700E+03, -.36284200E+03, -.93074800E+03, -.27111800E+02, 0.14652400E+02, 0.23286100E+03, 0.13379900E+02, -.46321300E+03, -.57778100E+03, 0.17580500E+03, 0.15063900E+03, 0.18870400E+03, -.65753200E+03, 0.60714900E+03, 0.34458400E+03, -.17144800E+03, 0.12455400E+03, -.17225000E+03, -.19011800E+02, 0.10742400E+03, -.11655100E+03, -.26735600E+03, -.55370600E+03, 0.14472200E+02, -.59250000E+03, 0.36292900E+02, -.19257600E+02, -.13764700E+02, -.28815300E+02, -.70603600E+01, -.19732600E+02, 0.25177000E+02, 0.25915400E+02, 0.18470000E+02, -.17436700E+02, 0.49047200E+02, -.23523300E+02, -.28790400E+02, 0.15483100E+03, 0.14908900E+03, 0.20561000E+01, -.37937400E+03, -.12539400E+03, 0.95355000E+02, -.37374000E+02, -.31853100E+03, -.38835800E+02, -.98618300E+02, -.68935900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26745600E+01, 0.17848500E+00, 0.67105400E+00, -.12232200E+01, -.17769000E+00, 0.15583800E+00, 0.27674800E-01, 0.39771500E+00, -.24681000E+00, 0.25006800E+00, 0.84127100E+00, 0.37186900E+00, 0.27238900E+01, -.18118600E+01, 0.39722600E+00, -.25092600E+00, -.84608600E+00, 0.15307700E+01, 0.54743000E+00, 0.13880300E+00, -.22377600E+00, 0.21726100E+01, -.47856800E+01, 0.20551100E+01, -.24919000E+00, -.36709800E+00, 0.17453900E+00, -.32364200E+00, -.86615900E+00, -.83726500E+00, -.27894600E-01, -.14289600E+00, -.57180100E+00, -.30459200E+00, 0.54570500E-01, 0.41497000E+00, 0.78798400E-01, 0.21072900E+00, -.44501400E-01, 0.49996300E+00, 0.61832100E+00, 0.31941200E+00, 0.40909700E+00, 0.10609700E+00, 0.18130300E+00, -.27518200E+00, 0.10444200E+01, 0.79398300E+00, 0.67743600E+00, -.18732900E+00, -.14809900E+01, -.11191900E+01, -.15007500E+00, -.20160800E+00, 0.80830800E+00, 0.32375900E+00, 0.53504900E-01, -.10190000E+01, 0.17002100E-02, -.96458600E+00, -.50250500E+00, -.14251300E-01, -.18625700E+00, -.30946100E-01, -.92366100E-01, 0.63161400E+00, 0.44742800E+00, -.69725400E+00, 0.45192100E+00, 0.22968500E-02, -.47301000E+00, -.51557200E-01, -.58336200E+00, 0.21461100E+00, -.23251600E+00, 0.26420000E-01, -.16961100E+00, -.59205500E-01, -.58235200E+00, 0.98930700E-01, -.10164500E-02, 0.27806700E+00, -.81610700E+00, 0.18868200E+01, 0.27100900E+00, 0.38877200E+00, 0.79750900E+00, -.47664300E-01, -.50502200E-01, 0.24980700E-01, -.77421100E+00, -.79372300E-02, 0.31376400E+00, 0.26867600E+00, -.41415300E+00, 0.12246300E-01, -.71033600E-01, -.67903900E+00, -.16162700E+00, 0.39719000E+00, -.57682200E+00, 0.11128400E-01, -.94785100E-01, 0.25270100E+00, -.19595500E+00, 0.50625500E+00, 0.40508600E+00, -.67926200E+00, 0.17952100E+00, 0.65858800E+00, 0.39232500E+00, 0.51542600E-01, 0.75416500E-01, 0.10815600E-01, -.25411300E+00, 0.46963000E+00, -.56304000E+00, -.17461100E+00, 0.12521400E+00, 0.57839200E+00, -.66888400E+00, 0.68749200E+00, 0.69664400E+00, -.16098700E+01, -.63307400E-02, 0.12712200E+04, 0.94869100E+03, 0.11851700E+03, 0.95988300E+03, 0.48747200E+03, 0.91057400E+03, -.13509700E+04, 0.31746700E+03, -.15695100E+03, -.32308500E+03, -.15871900E+03, -.91473900E+02, 0.36638000E+01, -.30045200E+03, -.44779500E+03, -.36989600E+03, 0.78484300E+02, 0.33689200E+03, 0.16543100E+03, -.79382200E+02, -.27678400E+03, -.78052800E+02, 0.87908400E+02, 0.21878300E+03, -.10002000E+03, -.11304700E+03, 0.60537300E+02, 0.35378500E+03, 0.14215000E+02, -.57121700E+02, 0.30463900E+02, -.26720700E+02, 0.28439800E+02, 0.15281900E+03, -.29676300E+03, 0.45790000E+03, 0.59575400E+03, 0.33087000E+03, -.28653300E+03, 0.50773700E+03, 0.15794600E+04, -.78740600E+03, -.13346300E+04, -.78982200E+03, -.11962200E+04, -.10157300E+04, 0.13589300E+03, 0.81329300E+03, 0.68849900E+02, -.89354000E+03, -.34486600E+03, 0.95083000E+03, -.47690800E+03, -.61498900E+03, -.47539700E+03, -.10102900E+03, 0.58052900E+03, -.77350300E+03, -.53778100E+03, -.60059800E+03, 0.53980900E+03, -.16055100E+03, -.17077900E+04, 0.85324200E+03, 0.89564400E+03, 0.85391800E+03, -.78221700E+03, -.74547100E+03, 0.70656100E+02, -.13216900E+04, -.98997900E+02, -.66308100E+03, 0.17876500E+04, 0.19244400E+03, -.94465900E+02, -.23975400E+04, -.96283100E+02, -.10168900E+04, -.10601600E+04, 0.34051400E+03, 0.39643000E+03, 0.24319900E+03, -.93381200E+03, -.69541000E+03, -.11113800E+04, 0.55382000E+03, 0.84807600E+03, 0.55579900E+03, 0.74938100E+03, 0.45168900E+03, 0.32909900E+03, 0.50726700E+01, 0.15169800E+03, 0.43999900E+03, 0.29235600E+03, 0.44771000E+03, -.22242400E+03, -.39675600E+03, -.22384500E+03, -.26003100E+03, -.25821800E+03, -.15224900E+03, -.17789600E+03, -.19203900E+03, -.18281100E+03, 0.14498000E+03, -.31178700E+04, 0.15529600E+04, 0.16322600E+04, 0.15590400E+04, 0.18343400E+03, -.61976500E+01, 0.69494000E+03, -.12339000E+03, 0.82866700E+03, 0.19766700E+02, 0.17986100E+04, 0.48828700E+03, -.24332100E+03, 0.30410600E+03, -.24411700E+03, 0.63328100E+02, 0.29126000E+02, -.60510400E+02, -.55035800E+02, 0.11942100E+03, 0.84705900E+01, -.43183500E+03, -.90843600E+01, -.35810200E+02, 0.92409800E+01, -.49529900E+02, 0.27030100E+02, -.20512000E+02, 0.45963700E+02, 0.28955200E+02, 0.22828400E+02, 0.24168400E+00, -.56784700E+02, -.22683700E+02, 0.39397500E+03, 0.11878600E+03, 0.90435600E+02, 0.26571800E+02, 0.22839500E+03, 0.34211300E+01, 0.75054400E+02, 0.14781700E+03, 0.12731000E+03, 0.37978800E+02, 0.21465300E+03, -.20612500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.43964100E+01, 0.84960800E+00, -.18594300E+01, -.13723200E+01, -.33060700E+01, -.34990800E+00, 0.73405900E+00, -.11705800E+01, -.34574400E+00, -.33142400E+00, -.30731800E+01, -.55644400E+00, 0.18392500E+01, 0.20382600E+00, 0.16942500E+00, 0.74512700E+00, 0.29669300E+00, 0.11235200E+01, 0.65735300E+00, -.19172300E+01, 0.80262600E-01, 0.16213200E+01, -.29517700E+00, -.28077400E+00, 0.14432800E+00, -.51017600E+00, -.66394100E+00, -.44724000E+00, 0.49400600E+00, 0.13247200E+01, 0.79911200E+00, -.52567400E+00, 0.94463900E+00, -.14667700E+01, 0.24336100E+00, -.62007800E+00, 0.29090000E-01, -.19948000E+00, 0.48963300E+00, -.43582700E-01, 0.78380300E-01, -.15703700E+01, -.19146600E+01, 0.20390600E-02, 0.13468300E+00, -.12259600E+01, 0.33922600E+00, -.55432400E+00, -.11066800E+01, -.15973900E+01, 0.12446400E+01, 0.14017400E+01, 0.11222300E+00, 0.24216500E+00, -.99379200E-01, -.29098700E+00, -.11273200E+00, -.51303100E+00, -.36824800E-02, -.17198800E+00, 0.30653400E+00, -.14047900E+01, 0.24121400E+00, -.32886600E+00, -.43707000E+00, -.12960200E-01, -.51534200E+00, 0.48175200E+00, -.62276500E+00, -.80024500E-02, -.59235700E+00, -.99013600E-01, -.34101000E+00, -.68401700E-01, -.57962800E+00, 0.21759300E+00, 0.20120500E+00, 0.12217200E+01, 0.44872500E+00, 0.25591000E-01, 0.17549600E-02, -.56963200E+00, 0.43833600E+00, -.14480100E+01, 0.98507200E-01, 0.81658100E+00, -.96953000E+00, 0.56624200E+00, 0.10700200E+00, -.19935300E+00, 0.16208600E+01, 0.85750100E-01, -.23490900E+00, -.18137500E+01, 0.96193400E+00, 0.25782600E+01, -.91262500E+00, -.25080200E+01, -.28220600E+00, 0.61161800E-01, -.52757100E+00, -.24731500E-01, -.55066100E-01, 0.17827600E+00, -.42739600E+00, 0.66764600E+00, -.74169300E+00, -.11199400E+01, -.13339200E+01, -.28579900E+00, 0.95997300E+00, -.55346700E-01, 0.63278600E+00, 0.11079100E-01, 0.41129300E+00, -.14705500E+01, 0.10936100E+01, -.41914200E+00, 0.39510300E-01, -.20038300E+00, 0.92062900E+00, -.91256500E+00, 0.45229400E+00, -.54766400E+01, -.77155600E-02, -.43433600E+00, 0.13835100E+04, 0.11174500E+04, 0.13252000E+04, 0.77350900E+03, 0.12746600E+04, -.21179500E+04, 0.94357900E+03, -.47073700E+03, 0.11598900E+04, -.47175800E+03, 0.10275500E+04, 0.15325900E+04, -.16073100E+04, 0.81323800E+03, -.86689900E+02, 0.16215300E+04, 0.31087800E+04, -.76866300E+02, 0.39957700E+02, -.12793500E+03, 0.34760000E+02, -.33659100E+03, -.65153900E+02, 0.69983400E+03, 0.50851400E+03, -.25422400E+03, 0.38677300E+03, -.64864100E+03, -.20860000E+03, 0.10542100E+03, -.24558800E+03, 0.10405700E+03, 0.36901400E+03, -.18549600E+03, -.44386900E+03, 0.31103100E+03, 0.14166300E+04, -.54109100E+03, 0.16954500E+04, 0.30927500E+04, -.15429000E+04, -.11300500E+04, -.15460800E+04, -.81164100E+02, -.13496900E+04, -.13099800E+04, -.89569000E+03, -.19324000E+04, -.15686600E+04, -.16567400E+04, 0.30734200E+04, -.15382600E+04, -.14229300E+04, -.15366900E+04, -.11476700E+04, 0.27319900E+03, 0.40898900E+03, -.49304100E+03, -.27138900E+04, 0.67569900E+03, -.11208600E+04, -.31675700E+03, 0.16120300E+03, 0.21191100E+04, 0.15843200E+03, 0.70337400E+03, -.74973700E+03, -.10991700E+04, -.54478400E+03, -.34799700E+03, -.46519500E+03, 0.28539700E+04, 0.20741500E+03, -.97964800E+02, -.30754100E+03, -.10391000E+03, -.97889100E+03, -.71301500E+03, -.17208600E+02, -.46759700E+03, 0.17799100E+03, -.16010500E+04, -.76312900E+02, -.48049400E+04, 0.24110300E+04, 0.80773500E+03, 0.24023100E+04, 0.32091400E+03, 0.87120400E+03, 0.11207500E+04, -.53947300E+01, 0.21912300E+04, 0.10364200E+04, 0.20998000E+04, 0.18584300E+04, -.92685600E+03, -.87467800E+03, -.92919400E+03, -.30753000E+03, 0.49708600E+03, -.12169500E+04, 0.32546600E+03, 0.18175500E+02, 0.38825600E+03, 0.12213400E+04, -.80709200E+03, 0.39522600E+03, -.36120300E+03, 0.40369400E+03, 0.70358500E+03, 0.10248100E+04, -.20212200E+03, -.75579100E+03, -.22826600E+03, 0.12032400E+04, 0.30418900E+03, -.16994200E+04, 0.85092900E+03, 0.57308800E+03, 0.84948100E+03, 0.37925100E+03, -.32791500E+01, 0.11323500E+03, 0.34863400E+03, 0.84867300E+03, 0.14513700E+03, 0.78593000E+03, -.66419500E+02, -.12189300E+02, 0.13465400E+02, 0.13541400E+02, 0.38922000E+02, -.11249600E+02, 0.29421800E+01, -.44324600E+02, -.47928600E+01, 0.61024400E+02, -.31802500E+02, 0.15380900E+02, 0.12279100E+02, 0.51799100E+02, -.60606700E+02, 0.94953500E+02, 0.51001400E+03, 0.22261800E+03, -.45583300E+03, 0.18142400E+03, 0.13842100E+03, -.14957700E+02, 0.23684900E+03, 0.15367500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.26105000E+00, -.30157900E+00, -.14763600E+00, 0.13191200E+01, 0.10876500E+01, -.11015400E+01, -.13552300E+00, 0.37400600E+00, -.27355700E+00, -.21905600E+00, -.63380700E+00, 0.25494000E+00, 0.23700300E+01, 0.17641700E+01, -.33329900E+00, -.37628800E-01, 0.14524300E+00, 0.31909000E+00, 0.68894100E-02, 0.36414700E+00, -.30473700E+00, 0.47163500E-01, 0.15141500E+01, -.58027200E+00, 0.26041400E-01, 0.59579800E-01, -.12403700E+00, 0.79095700E-01, 0.51991800E-01, -.33329400E+00, -.38922100E-01, 0.55665000E-01, -.70121200E-01, 0.93365400E-02, -.10781900E+00, 0.99076500E-01, -.68682300E-01, 0.47648600E+00, -.19987200E+00, 0.39267100E-01, -.14595200E+00, 0.12548300E+00, 0.19906900E+01, -.16144400E+00, 0.13831900E+00, 0.75804400E-01, 0.25656600E-01, -.17797800E+00, 0.57632200E-01, 0.86466000E-01, -.23571700E+00, -.26815200E-01, 0.15064000E-02, -.21411600E-01, 0.18940500E+00, 0.22455000E+00, 0.81040700E-02, 0.97979700E+00, 0.14785100E-02, -.52643600E-01, -.14966900E+00, -.58952300E-01, 0.86229500E-01, 0.54769300E-01, 0.52221900E-01, -.78608200E-01, -.16329900E+00, -.19423300E+00, 0.38461800E-01, 0.75570500E-03, 0.24617700E-01, -.98110400E-01, -.60062700E-01, -.48520200E-01, -.13070700E+00, 0.95901000E-01, 0.16345000E+00, 0.19091300E+00, 0.14915300E+00, -.62288000E-01, -.10230000E-02, -.34498400E+00, -.31405300E-01, -.49252900E+00, -.14861300E-01, 0.12983500E+00, -.93074400E-02, -.35998200E-01, -.49561500E-01, 0.55963300E-01, 0.20587400E+00, 0.35864100E-01, -.31109800E+00, -.96057100E-01, 0.16150400E+00, 0.21724500E+00, -.74439200E-01, -.38301800E+00, 0.48480900E-01, 0.42412900E-01, -.37586000E+00, -.74539600E-01, -.77215700E-01, 0.73789700E-01, -.37274300E+00, 0.22002000E+00, -.21360300E+00, -.45119800E+00, -.20606900E+00, 0.26118400E+00, -.74836700E-01, 0.21546400E-01, 0.12290400E-01, 0.53665100E-03, -.15601300E+00, -.15490400E-01, 0.60876900E-01, -.18729200E+00, 0.92499400E-01, 0.17131900E+00, 0.65587600E-01, 0.23406300E+00, 0.10718600E-01, 0.19137200E+01, 0.92273300E-02, 0.12438100E+00, 0.15342500E+00, -.36923400E+03, -.28058500E+03, 0.14406700E+02, -.89453500E+02, 0.22214500E+03, -.36050200E+03, 0.17968200E+03, -.11595600E+03, 0.18022300E+03, -.23045100E+03, -.28010900E+03, 0.32731000E+03, -.24901500E+03, -.22567800E+02, -.29802400E+03, -.36800300E+03, -.96833000E+02, 0.43603200E+02, 0.17797600E+03, 0.49310700E+02, 0.11956700E+03, 0.99362800E+02, -.15445300E+03, -.13689400E+03, 0.93124700E+02, -.10665900E+02, 0.14752600E+03, 0.19267800E+03, -.96906800E+02, 0.36284100E+02, -.96106200E+02, -.62142000E+02, 0.12914400E+02, 0.79272000E+02, -.11467400E+02, -.31328500E+03, 0.74059200E+02, -.37779600E+03, 0.68028200E+03, -.34168700E+03, -.26258400E+03, -.34007700E+03, -.12855700E+03, -.84695100E+02, 0.31284000E+03, 0.59964800E+03, 0.75974100E+02, 0.61964100E+02, -.18215700E+03, -.76856300E+03, 0.38491700E+03, 0.35241500E+03, 0.38425100E+03, 0.17061700E+03, -.52741300E+02, 0.56203600E+01, 0.99715900E+02, 0.69130700E+03, -.14269000E+03, 0.24333100E+03, -.37565900E+03, 0.18700600E+03, -.18892700E+03, 0.18778300E+03, -.12420000E+03, -.97735800E+01, 0.33100500E+03, -.80576100E+02, 0.10159500E+02, 0.47130700E+01, -.14576800E+03, 0.79084800E+03, -.39567000E+03, 0.22468100E+03, -.39528800E+03, 0.32077800E+03, 0.26844800E+03, -.15882600E+03, 0.25597500E+03, -.34491000E+03, 0.52121400E+03, -.25097700E+03, 0.59391400E+03, -.29883300E+03, 0.44260700E+01, -.29707800E+03, 0.46231400E+02, 0.31063900E+02, -.29153600E+03, -.14884900E+03, -.37682800E+03, -.56225600E+02, -.34085700E+03, -.75089700E+03, 0.37494900E+03, 0.35422000E+03, 0.37542900E+03, 0.12365400E+03, -.14480900E+02, 0.26789700E+03, -.12859500E+03, 0.77143500E+02, 0.41233900E+01, 0.12111800E+03, 0.60325100E+02, -.25645000E+02, 0.19033000E+03, -.30358800E+02, -.15120100E+03, -.59199000E+02, -.24180400E+02, -.41940000E+00, 0.40233100E+02, -.18978500E+03, -.31574200E+02, 0.35977900E+03, -.18091900E+03, -.16005600E+03, -.17987700E+03, -.34806100E+02, -.12372000E+02, -.68035000E+02, -.90665000E+02, -.26909300E+03, -.31784600E+02, -.23630500E+03, 0.32608200E+02, 0.96071800E+01, -.12908500E+02, 0.74859100E+01, -.36301400E+01, 0.21926400E-01, -.11112200E+02, 0.13791000E+02, 0.42897300E+01, -.67170100E+01, 0.24347100E+02, -.13928800E+02, 0.69214300E+02, 0.79215100E+01, 0.56735400E+02, -.28902100E+02, -.56374700E+02, -.66015200E+02, 0.10844900E+03, -.32042100E+02, 0.29410200E+02, -.77431300E+01, -.32491500E+02, -.31626200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46495500E+01, 0.12501500E+01, -.23567300E+01, -.62731700E+00, -.26150700E+01, -.36338200E+00, 0.51266900E+00, 0.45780800E+00, -.79473600E+00, -.30888500E-01, -.29869900E+01, -.15588500E+01, 0.52392400E+01, 0.20726400E+01, -.25249400E+00, 0.21148200E+00, -.76478900E+00, -.28021100E+00, 0.38868800E+00, -.44732400E+00, 0.48755500E+00, -.39032400E+00, -.19943100E+00, 0.18394300E+01, 0.51945800E-01, 0.30949900E+00, -.80827600E-01, 0.13682400E+00, -.64277200E-01, 0.17283800E+00, -.20941600E+00, -.12460300E-01, 0.52346200E+00, 0.10752100E+01, 0.13962900E+00, 0.45943200E+00, -.11838700E+00, 0.49090200E+00, -.70679500E+00, -.21757300E+00, -.10365900E+01, 0.15175600E+00, 0.19785400E+01, -.34873000E+00, 0.21452200E-01, 0.16245200E+01, 0.81612100E-01, -.60665000E-01, 0.44667900E+00, 0.12153600E+01, 0.10068100E+01, -.10639000E+00, 0.30703800E+00, -.66435500E+00, 0.48631600E+00, 0.83517700E-01, 0.32519600E+00, -.28967000E+01, 0.61057000E-02, 0.22917300E+00, 0.19174000E+00, 0.69644000E+00, -.27686800E+00, -.70572100E-01, -.72169700E+00, 0.78811200E+00, 0.44801400E+00, 0.19738500E+01, -.47400400E+00, 0.11831000E-01, -.75405100E+00, -.26121000E+00, 0.20736100E+00, -.21910000E+00, 0.10474100E+01, -.44956600E+00, -.80666700E+00, -.11283700E+00, -.69002200E+00, -.22694000E+00, 0.21718700E-02, 0.79852000E+00, 0.11518400E+01, -.12165400E+01, -.44574800E+00, 0.34897800E+00, -.11086800E+01, -.42152200E+00, 0.33895800E+00, -.17533300E+00, -.10979200E+00, -.94204500E-01, 0.88403200E+00, 0.20727300E+01, -.92082900E+00, -.17209200E+01, 0.74260400E+00, 0.19967400E+01, -.86600900E+00, -.10639000E+00, -.27930900E-01, -.18545100E-01, 0.41758600E-01, -.39907500E+00, -.72128800E+00, 0.57740800E+00, -.50833000E-01, 0.86374500E+00, -.12656900E+00, -.32703600E+00, 0.10764700E+01, -.37128700E-01, -.29845000E-02, -.21863100E-02, 0.56269700E-01, -.19695900E+01, 0.63165800E+00, -.90000700E-01, -.72763900E-01, -.11208400E+01, -.69351900E+00, 0.15205800E+01, 0.20499700E+01, -.37388300E+01, 0.14239700E-01, -.17707300E+00, -.11000200E-02, -.19206600E+01, -.80276800E+03, -.82495900E+03, -.92851300E+02, -.12031400E+04, 0.12917700E+04, -.64360700E+03, -.77689800E+03, -.64596500E+03, -.67786000E+03, -.70114000E+03, 0.51972300E+02, 0.73448500E+03, -.15823000E+03, -.54074300E+03, 0.92408200E+03, -.34723800E+03, 0.17325900E+03, 0.33767100E+03, 0.16570200E+03, -.68879800E+02, 0.39892000E+02, 0.23029300E+02, -.10746700E+03, 0.38982600E+02, 0.59293100E+02, -.12398300E+03, 0.56268000E+02, -.26045200E+02, -.37431000E+02, -.27451400E+02, -.72989500E+01, 0.12207800E+03, 0.21685100E+02, -.25424800E+03, -.10810500E+03, 0.90939500E+02, -.12258600E+03, -.15691700E+04, 0.78999900E+03, 0.11736200E+04, 0.78506800E+03, 0.26723600E+03, 0.35630500E+03, 0.23511600E+03, -.81301100E+02, 0.24145000E+03, 0.23138400E+03, 0.14209500E+04, -.83458200E+02, 0.40100100E+02, 0.15816700E+03, 0.41632200E+02, -.23233500E+02, -.27072600E+02, 0.35141900E+02, -.79811500E+02, -.12281600E+03, 0.44167300E+01, -.13130400E+03, 0.90615500E+03, -.45280200E+03, -.55551000E+03, -.45320900E+03, -.34728500E+03, -.43765400E+03, 0.44124300E+02, 0.10453500E+04, 0.53263700E+03, -.27582900E+03, 0.12180300E+04, -.43597300E+03, 0.22272500E+03, 0.20563000E+04, 0.21833500E+03, 0.87308300E+03, 0.30510700E+03, 0.21837900E+03, 0.20815300E+03, 0.16924500E+02, 0.15470600E+03, 0.93530200E+03, 0.76274000E+03, -.38365700E+03, -.29260200E+03, -.38195700E+03, -.10718600E+03, -.11004500E+03, -.35404900E+03, -.16488800E+03, -.92769300E+02, -.55690000E+02, -.11255100E+04, 0.54004800E+01, 0.58261100E+00, -.14005800E+03, -.27577400E+01, -.41237000E+02, -.16913700E+02, 0.53606700E+02, 0.21033000E+03, -.18249100E+03, 0.46106700E+02, 0.92353200E+03, 0.37466300E+04, -.18836600E+04, -.12232800E+04, -.18739400E+04, -.27604400E+02, 0.58318900E+03, -.10893000E+04, -.95493700E+01, -.13701100E+04, 0.55899900E+03, -.21982200E+04, 0.36947700E+03, -.18531000E+03, -.40049700E+03, -.18488000E+03, -.21240100E+03, -.28412500E+03, -.11257400E+03, -.43209200E+02, 0.55371800E+02, -.18881900E+03, -.21088900E+02, -.18744600E+02, 0.25529600E+02, -.79174900E+01, 0.42989300E+02, -.18130300E+02, 0.77125500E+01, -.37196100E+02, -.24722000E+02, -.39766900E+02, -.10887300E+02, 0.77920100E+02, 0.32409500E+02, 0.12049100E+03, -.26474700E+03, -.45001400E+02, 0.70817100E+01, 0.31352800E+02, 0.28616900E+02, 0.31935200E+03, -.79632700E+02, 0.92788300E+02, -.19537700E+01, -.60430600E+02, 0.74333100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.80459000E+01, 0.11447400E+01, -.28979100E+01, 0.54405300E+01, 0.97060800E+01, 0.42291200E+01, -.25312700E+01, 0.22840400E+01, -.62655500E+00, -.15354300E+00, 0.53057800E+01, 0.32747800E+01, 0.68009500E+01, 0.61271200E+01, -.13092300E+01, -.11060400E+01, 0.20811700E+01, 0.38372300E+01, 0.29081400E+00, -.54580000E+00, 0.21562900E+01, -.53675600E+00, 0.80230100E+00, -.90525500E+00, 0.11515200E+00, -.93568000E+00, 0.20542400E+00, 0.13137000E+01, 0.11344000E+01, -.35250100E+01, 0.15336500E+01, 0.10975100E+01, -.23511800E+01, -.65571200E-01, 0.37697000E+00, 0.22977000E+01, 0.40627300E-01, 0.17206600E+01, -.47390400E+00, -.19313100E+00, -.13661000E+00, -.46158700E+00, 0.72946400E+01, -.11556800E+01, 0.10189200E+01, -.10607800E+01, -.12147200E+01, 0.60279500E+00, 0.10118600E+01, -.25819600E-01, 0.11394500E+00, -.78210800E-01, -.10888200E+00, 0.14158100E-01, -.18832000E+01, 0.13071900E+01, 0.69301600E-01, 0.57113600E-01, 0.68322000E-02, -.60455200E+00, -.19504400E+01, -.33694700E+01, 0.62483500E+00, 0.12141300E+01, -.80472900E+01, -.74167300E+00, 0.13920300E+01, -.81494700E+00, 0.64452500E+00, -.93254200E-02, 0.63150700E+00, -.29630000E+00, 0.11072000E+01, 0.47655000E+00, -.38397200E+00, -.70261200E-01, 0.16131200E+00, -.79773500E+00, 0.27166300E+01, -.66320800E+00, -.24123600E-03, -.77302600E+00, 0.14210300E+01, -.12051000E+01, -.36892700E+00, -.13094100E+01, 0.12914800E+01, -.67286600E+00, -.76063900E+00, 0.28709400E+00, 0.36819700E+00, 0.20651700E+00, 0.19916600E+00, 0.27028600E+01, 0.22318600E+00, -.40790000E+00, -.31436700E+00, 0.72528800E+01, 0.14396800E+01, -.21952700E-01, -.31573100E+01, -.80338500E+00, -.24190100E+00, 0.45163300E+00, -.92456000E+00, 0.17274500E+00, 0.21354300E+00, 0.17654800E+01, -.98825900E+00, -.17126800E+01, -.49356400E-01, -.90588300E-01, 0.41955400E+00, -.21722800E-01, -.25472100E+00, -.10889000E+01, 0.51972100E+00, -.59906100E+00, -.15577500E+00, -.15989600E+01, -.57627300E+00, 0.28356500E+00, 0.46722800E+00, -.33022600E+01, 0.13491900E-01, -.10074500E+01, 0.14798200E+00, -.57447700E+00, 0.33475900E+00, -.11341700E+04, 0.88967900E+02, 0.41400900E+03, 0.18282900E+04, -.90954400E+03, -.84489500E+03, -.91416000E+03, 0.16663100E+03, -.53344700E+03, 0.44698100E+03, 0.12222000E+04, 0.58982700E+03, -.20429300E+03, -.23362900E+04, -.41468000E+03, 0.23778900E+03, 0.40478900E+03, 0.21517100E+03, 0.18973800E+03, 0.22640000E+03, -.73674800E+03, 0.12983200E+02, -.75156800E+03, 0.49913100E+03, -.82626100E+03, -.84260400E+03, 0.42699300E+03, 0.51601800E+03, 0.42140500E+03, -.29262300E+03, -.30658700E+03, 0.95863100E+03, -.45699900E+03, 0.34978400E+03, -.30202200E+03, -.11328100E+04, -.32238000E+03, 0.16928500E+03, -.30572700E+02, 0.16092600E+03, -.76022000E+02, 0.18743100E+03, -.38826400E+03, 0.26795600E+03, 0.81749400E+03, -.12081000E+03, 0.12022600E+04, 0.11300100E+04, -.56853000E+03, -.50014300E+03, -.56500400E+03, 0.51106100E+03, 0.73356900E+03, -.21692600E+04, 0.28247800E+03, -.16845900E+04, 0.88213400E+03, -.49059800E+03, 0.99486600E+03, -.49104500E+03, -.44805200E+03, -.49745900E+03, 0.12933800E+03, -.48334600E+03, 0.50052800E+03, 0.11346700E+04, 0.12200500E+04, -.14717200E+03, -.30729400E+04, -.18137200E+04, 0.92234200E+03, -.21342300E+03, 0.90697000E+03, -.26156000E+03, -.69040900E+03, 0.47359700E+03, 0.10208000E+03, 0.61427400E+03, -.10820300E+04, 0.99653900E+03, -.84235300E+03, 0.41582500E+03, 0.53364600E+03, 0.42134500E+03, -.22295900E+03, -.42580600E+03, 0.80903800E+03, 0.10979900E+03, 0.15352400E+03, -.20891600E+03, -.14004200E+03, 0.26064000E+04, -.12996600E+04, -.14121600E+04, -.13032100E+04, -.93931000E+02, -.56266700E+03, -.22611900E+02, 0.95482000E+03, -.13862800E+03, -.37350200E+03, -.15173900E+04, -.49799100E+02, 0.26647700E+02, -.10819200E+03, 0.24860900E+02, 0.10872200E+03, -.22687700E+03, 0.38043900E+03, 0.87084200E+03, -.33121500E+02, 0.13422900E+03, -.30486500E+02, 0.40431600E+03, -.20098200E+03, 0.88038700E+01, -.20198600E+03, 0.13050100E+02, 0.24178400E+03, 0.20008500E+03, -.73867200E+01, 0.71058100E+03, 0.13649300E+03, 0.10013600E+04, -.85123800E+02, 0.34551700E+02, -.58977400E+01, 0.43548800E+02, 0.78556500E+01, 0.39428100E+02, -.32306200E+02, -.20450300E+02, -.31865000E+02, 0.22060800E+02, -.61547100E+02, 0.65165400E+02, 0.86301100E+02, -.53912300E+03, -.26941000E+03, -.21604800E+02, 0.14834800E+02, 0.17423900E+03, 0.34122200E+03, 0.96914600E+02, -.84648800E+02, 0.14950200E+03, 0.54363600E+02, 0.20976900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.38659200E+01, 0.10238300E+00, 0.76121700E+00, -.18378500E+01, -.12786600E+01, -.35524200E+00, 0.34725700E+00, -.34671600E+00, -.20127200E+00, -.12711300E+00, -.84923900E+00, 0.22731100E+00, 0.12066300E+01, 0.18878800E-01, -.69183800E-01, 0.36946600E+00, -.15034400E+00, 0.10047700E+01, 0.23434800E+00, -.17468900E+01, 0.80352800E+00, 0.22902100E+01, -.55775800E-01, -.12228000E+00, 0.30560300E-01, -.47998900E+00, -.23199500E+00, 0.29149100E+00, 0.20732200E+00, 0.69147700E+00, 0.36350200E+00, -.55305100E+00, 0.20941200E+00, -.88488400E+00, 0.11532500E+00, -.12815000E+01, -.62137600E-01, -.64096900E+00, 0.25928400E+00, -.30116000E-01, 0.69733200E+00, 0.49841700E-01, -.89370900E+00, 0.84897100E-01, -.32002400E+00, -.33777400E+00, 0.48114200E+00, -.99225200E+00, -.84835400E+00, -.92546900E-01, 0.11502300E+01, 0.11711400E+01, 0.87174300E-01, -.78328300E-01, 0.32824800E+00, -.31411000E+00, 0.10442500E-02, 0.21806000E+00, -.13586000E-02, 0.53149400E+00, 0.33743800E+00, 0.32599100E+00, -.72933100E-01, 0.58921900E-01, -.29717700E+00, -.25700600E+00, -.32652300E+00, 0.18926400E+00, 0.59777200E-01, 0.73308600E-03, 0.86230300E-01, 0.42489300E-01, 0.34510000E+00, -.68868100E-01, 0.76200500E+00, -.14915900E+00, -.26999900E+00, -.78152500E+00, 0.10807200E+00, 0.28118700E+00, 0.78490600E-03, 0.10445900E+01, -.16126800E-01, -.22886000E+00, -.90008100E-01, -.63457500E+00, 0.51885200E+00, 0.76535600E-01, -.49548300E-02, 0.46100600E-01, 0.25148300E+00, 0.56203500E-05, -.10042500E-01, -.10104300E+01, -.82230900E+00, -.18303100E+01, 0.31081100E+00, 0.65254900E+00, -.13078200E+01, 0.34213000E+00, -.55603500E+00, 0.46173900E-02, -.25900700E+00, -.24674900E+00, 0.15163000E-01, 0.10293700E+01, 0.18875300E+01, -.11742400E+00, 0.48646900E+00, -.52007300E-01, 0.11057200E+01, 0.69741400E-01, -.32596500E-01, 0.13966400E-02, -.34350100E+00, 0.36568200E-01, 0.47520000E-01, 0.41750100E-01, -.31065900E-01, 0.58016800E+00, -.14758200E+00, 0.88936000E+00, 0.16648600E+01, 0.54295100E+00, 0.53679500E-02, 0.45931600E+00, -.31922300E+00, -.11077300E+01, 0.32713300E+00, 0.34811100E-01, 0.22493500E+03, 0.56830200E+03, -.40445400E+03, 0.20204600E+03, 0.33839500E+03, 0.20221400E+03, 0.32059400E+03, 0.40357500E+03, -.12130400E+03, -.19730200E+03, 0.11132600E+03, 0.30910200E+03, -.28147600E+03, -.67605900E+01, -.41514500E+01, 0.43169000E+02, 0.30628000E+01, 0.80687000E+02, -.11889700E+02, 0.11246300E+03, 0.20275300E+03, 0.64362900E+02, -.51823900E+02, 0.25177000E+03, 0.27792700E+03, -.13945700E+03, -.21346500E+01, -.13884900E+03, 0.59674200E+02, -.14914100E+02, -.25201600E+03, -.20761100E+02, -.23379700E+02, -.42071000E+02, -.19076300E+03, 0.13381800E+04, -.67094800E+03, -.34901800E+03, -.66899300E+03, -.21551900E+03, -.97600500E+02, -.15156500E+03, 0.89120600E+02, -.34931700E+03, -.21890800E+03, -.90450300E+03, -.41107100E+03, 0.20613700E+03, 0.85807000E+02, 0.20551800E+03, -.41985300E+02, -.14823800E+03, 0.42825200E+03, 0.13838600E+03, 0.33178500E+03, -.13528300E+03, 0.25828400E+03, 0.19928900E+03, -.98051800E+02, 0.88941900E+02, -.99666200E+02, 0.16925800E+03, 0.15937600E+03, -.19718100E+03, -.18493400E+03, -.11267200E+03, -.68723000E+02, -.71021000E+03, 0.81259400E+03, -.40578200E+03, 0.25899500E+03, -.40624000E+03, 0.31526100E+02, 0.39711100E+03, -.31765400E+03, -.20256300E+03, -.34584100E+03, 0.42343200E+03, -.61889100E+03, -.34583100E+02, 0.17833900E+02, -.27091400E+02, 0.17183300E+02, 0.18108200E+02, -.31357900E+02, -.60372600E+02, 0.41717800E+02, 0.68296500E+01, 0.12394500E+02, 0.20923500E+03, -.25341000E+03, 0.12663400E+03, 0.87563200E+02, 0.12669500E+03, 0.15399600E+03, 0.19238200E+03, 0.53044500E+02, 0.34734100E+02, 0.24489700E+03, 0.12899700E+03, -.97223300E+02, 0.49718400E+03, -.24447800E+03, -.77315200E+02, -.24869900E+03, 0.43089400E+02, 0.15228100E+03, -.21458000E+03, -.98584800E+02, -.21747900E+03, 0.10233200E+02, -.15509700E+03, -.58740800E+01, 0.14531900E+01, -.18231200E+02, 0.29067100E+01, 0.35227200E+00, 0.33259800E+02, -.18525200E+03, -.10150500E+03, -.26761000E+03, 0.34156500E+02, 0.42047100E+02, 0.57924700E+02, -.44085700E+01, -.17034600E+02, -.85863000E+01, 0.90035700E+01, -.62359600E+01, 0.35855900E+01, 0.94041700E+01, 0.13894500E+02, 0.15955700E+02, -.42407900E+01, -.33167800E+02, -.20309700E+01, 0.60535500E+02, 0.97180300E+02, -.36890900E+02, -.14295300E+02, -.60462500E+02, -.92248400E+02, 0.23584000E+01, -.77954800E+02, -.18726500E+02, 0.66455500E+01, -.56911100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36068300E+01, -.14929400E+01, 0.25326100E+01, -.45898600E+00, 0.25646300E+01, -.44636600E+00, -.42046500E+00, 0.10881000E+01, 0.31233700E-01, -.39428900E+00, 0.13888700E+01, 0.65833600E+00, -.11617100E+01, 0.18440800E+01, -.12677600E+00, -.13510500E+00, 0.14462700E+01, 0.23140000E+01, -.54475400E+00, -.10662500E+01, 0.15071200E+01, 0.74155700E+00, -.47120000E+01, 0.17169600E+01, 0.35485600E+00, -.22086700E+00, 0.31327600E-01, 0.45991900E+00, -.54121300E+00, 0.15626000E+01, 0.14324900E+00, -.23190200E+00, -.58028600E+00, -.91442400E+00, 0.51748900E-01, 0.24947800E-01, -.29484000E-01, -.70282800E+00, 0.15669400E+01, 0.64508000E+00, 0.23821000E+01, -.23451000E+00, -.45511300E+01, 0.72669100E+00, -.12500300E+01, 0.10545000E+01, -.11915400E+01, -.93479400E+00, -.70649900E+00, -.19834400E+00, 0.23031600E+01, 0.23551200E+01, 0.15556600E+00, 0.90543300E+00, -.15133700E+01, -.10946700E+01, -.40461300E+00, -.15150300E+01, 0.44726700E-02, 0.23241900E+01, 0.69966100E+00, 0.22251300E+01, -.53473000E+00, 0.30304000E-01, -.22177400E+01, -.18173700E+01, 0.59547300E+00, 0.21742700E+01, -.61106100E-01, 0.22719100E-01, -.26187700E+00, 0.29709000E+00, 0.50240300E+00, -.89981600E-01, 0.12209900E+01, -.25899100E+00, -.82846400E+00, -.38563600E+00, -.92642100E+00, -.88298600E+00, -.29823300E-02, 0.10675000E+01, -.11377900E+01, -.23528200E+01, -.28789300E+00, 0.55053400E+00, -.94414100E+00, 0.32148800E-01, 0.66264900E+00, 0.11378200E+00, -.12129100E+01, -.54871900E-01, 0.24160300E+00, -.86083300E+00, 0.51588300E+00, -.86884200E+00, 0.43859400E+00, -.45801600E+00, -.10604300E+01, -.60164400E-01, 0.12256800E+01, 0.28673800E+00, 0.54556600E-01, -.27055800E+00, 0.16010800E+01, -.10178100E+01, 0.13839500E+01, 0.10018400E+01, 0.14933800E+01, -.81535900E+00, 0.16711500E+01, -.35058800E-02, -.40766000E+00, -.15815000E-01, 0.13069500E+00, -.81816900E+00, 0.13773900E+00, 0.38983700E+00, -.12829500E+00, 0.63105900E+00, -.84530900E+00, 0.86948800E+00, 0.33046700E+00, 0.26572600E+01, 0.23798800E-01, 0.78888900E-01, -.24541500E+00, 0.99288600E+00, 0.84571900E+00, -.33932200E+00, -.10461600E+01, 0.16300600E+04, -.23856400E+04, 0.11926700E+04, 0.10506900E+04, 0.11928400E+04, 0.77721300E+03, 0.12550700E+03, 0.14399300E+03, -.99033700E+03, 0.72736500E+03, 0.72188400E+02, -.11564400E+04, 0.65211900E+00, 0.15112900E+02, -.27516100E+03, 0.53029100E+01, 0.44470400E+03, -.35257900E+03, 0.89683800E+02, 0.50588600E+03, 0.16410600E+03, -.54937700E+03, 0.38418600E+03, -.93465500E+02, 0.46228400E+02, 0.33035700E+03, 0.46517700E+02, -.21747500E+03, -.92715200E+02, 0.19748200E+03, -.15563100E+03, -.30755300E+02, 0.15067700E+03, -.10944600E+04, -.66968200E+03, 0.33237300E+03, 0.17299400E+03, 0.33440300E+03, -.22300100E+03, 0.12368900E+03, 0.52059200E+02, 0.59505100E+02, 0.16680300E+03, 0.22214300E+03, 0.16598700E+02, -.15699100E+04, 0.78557500E+03, 0.44154800E+03, 0.78498900E+03, 0.98729900E+03, -.26616400E+03, -.64372700E+02, 0.24007800E+03, 0.82335700E+03, -.49899800E+03, 0.10914600E+04, -.86129300E+03, 0.43326000E+03, -.58458000E+02, 0.43068500E+03, 0.36585200E+03, 0.70300400E+02, -.52813600E+02, -.50565200E+03, 0.23075300E+03, -.31153800E+02, -.18310100E+04, 0.38723500E+03, -.19127400E+03, -.14023200E+04, -.19367800E+03, -.65430600E+03, -.64582000E+02, 0.20906300E+02, 0.12690200E+02, 0.69789100E+02, 0.35915600E+03, -.56505300E+03, 0.14401900E+04, -.72130100E+03, 0.87925400E+02, -.71967700E+03, -.74728800E+01, -.17808500E+03, -.15706200E+03, 0.22165200E+03, -.52036200E+03, -.21414200E+03, -.59037100E+03, -.79941600E+03, 0.39866400E+03, 0.35045400E+03, 0.39972400E+03, 0.19204700E+03, -.33125800E+03, 0.51165000E+03, 0.13928100E+03, 0.65821000E+03, -.26036900E+03, -.11654000E+04, -.22271700E+04, 0.11157600E+04, 0.19904300E+04, 0.11138200E+04, 0.24791700E+03, -.32655200E+03, 0.56870700E+03, 0.10642700E+03, 0.76478000E+03, -.46523300E+03, 0.81518000E+03, 0.11903100E+04, -.59533800E+03, -.36231700E+03, -.59492600E+03, -.31152200E+03, 0.12191500E+03, -.30951800E+03, -.29191900E+03, -.50233900E+03, -.11793400E+02, -.84599600E+02, 0.85928500E+02, -.40314100E+02, 0.30091600E+02, -.79854400E+02, 0.11291500E+02, -.95026500E+01, 0.57649200E+02, 0.45394900E+02, 0.44782100E+02, -.20980000E+02, -.54812400E+02, -.71665500E+02, -.24998000E+02, 0.55507500E+02, 0.25673500E+02, -.11069700E+03, -.11489500E+03, -.12533500E+03, -.40354300E+02, 0.44614200E+01, -.27123900E+02, 0.14120600E+03, 0.98677400E+02, -.39854200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.46110900E+01, -.90049500E+00, -.14414100E+01, 0.18310100E+00, 0.35665300E+01, -.11419300E+01, -.51691400E+00, 0.36467900E+01, -.79894800E+00, -.15363300E+01, 0.10808300E+01, 0.18881100E+01, 0.52236100E+01, 0.36116400E+01, -.10460500E+00, -.47087700E+00, 0.18800900E+01, 0.89603200E+00, 0.13806100E+00, 0.58085700E+00, -.17578200E+01, -.82646800E+01, 0.64636500E+00, -.89121000E+00, 0.33253500E-01, 0.25065800E+01, -.86612900E+00, -.10139400E+01, 0.40671300E+00, 0.38093100E+01, -.36736600E-01, 0.41355400E+00, -.18616400E+01, 0.17130500E+00, -.10046000E+00, 0.28227600E+01, 0.90774700E-01, 0.81791900E+00, -.14243000E+00, 0.10565500E+01, 0.87710000E+00, 0.17237000E-01, -.83942400E+00, 0.90582100E+00, -.15033200E+01, -.45948800E+00, 0.30512400E+00, 0.11209700E+01, 0.26390000E+00, -.14929100E-01, -.49359100E+00, 0.48135700E+00, -.14773600E+00, 0.81828500E+00, -.13510200E+01, -.16708700E+01, 0.52210800E+00, -.29260400E+01, 0.54035900E-02, 0.38949200E+00, -.13997700E+00, -.16069000E+01, 0.12418500E+00, -.18271000E-01, -.23555600E+01, -.16731400E+00, 0.64504600E+00, 0.38263000E+00, -.58070400E-01, 0.54954000E-02, -.23891000E+00, 0.44613300E+00, 0.58084500E+00, 0.25358300E+00, -.95808400E-02, -.29152300E+00, -.10257500E+01, -.57661000E-01, -.87339200E+00, 0.13811600E-01, 0.10913200E-02, 0.26901200E+01, -.56453200E+00, 0.83535100E+00, -.18969000E+00, -.57500200E+00, 0.19852200E+01, -.30055500E+00, 0.27445300E+00, 0.71166800E+00, 0.49906300E+00, 0.23553000E-01, 0.13348800E+01, 0.63552700E+00, 0.11493900E+01, -.38050700E-01, 0.38032100E-01, -.14006200E+01, 0.23790900E+00, 0.68407100E+00, 0.24039100E+00, 0.26128400E+00, -.34087100E-04, 0.55588500E+00, 0.61737700E+00, 0.32537300E+00, -.61676100E-01, 0.66727200E-01, -.10804700E+01, -.58949500E+00, 0.14159000E+00, 0.44986300E-01, 0.55007500E+00, -.33645500E-02, -.80023700E+00, 0.15812700E+00, 0.17015700E+00, 0.24999500E+00, 0.70896600E-01, -.15313000E+01, -.11389400E+01, 0.19426000E+01, 0.29790200E+01, -.33703500E+01, 0.92023600E-02, -.13245800E+00, 0.88904000E-01, -.15200700E+01, 0.60792300E+00, 0.50883500E+00, -.13491500E+00, -.92350700E+00, -.47339500E+04, 0.23645300E+04, 0.23020600E+04, 0.23669900E+04, 0.10857600E+04, 0.42726800E+03, 0.64786800E+03, -.20201800E+04, 0.88742900E+03, 0.35658100E+03, 0.68581000E+03, 0.31310000E+03, -.18168000E+03, -.31807000E+03, -.15345100E+03, 0.70395400E+03, -.38079100E+03, 0.36721900E+03, 0.96595400E+03, 0.17400100E+03, -.76947500E+03, 0.52653000E+03, -.46306200E+02, 0.21160700E+02, 0.64443300E+03, 0.23016300E+02, -.18063500E+03, -.15054800E+02, 0.24140700E+01, -.12880900E+02, -.13937500E+02, 0.19209400E+03, -.11706200E+04, -.16031900E+04, 0.79327600E+03, 0.10231500E+04, 0.80154600E+03, -.23696100E+03, 0.29647700E+03, 0.34033200E+03, 0.24110300E+03, 0.76736600E+03, 0.54580400E+03, 0.24127400E+01, -.22476500E+04, 0.11265500E+04, 0.62496000E+03, 0.11238400E+04, 0.11333600E+04, -.70530200E+03, 0.61173400E+03, 0.21439600E+03, 0.13031800E+04, -.11236700E+04, 0.14910500E+04, -.23402200E+04, 0.11670100E+04, 0.11313900E+04, 0.11701400E+04, 0.59917100E+03, 0.30975700E+03, 0.24296100E+03, -.13881200E+04, 0.98329400E+02, 0.93532300E+02, 0.74570600E+03, 0.20095600E+04, -.10136600E+04, -.13105700E+04, -.10048600E+04, -.90848000E+03, 0.85981300E+03, -.68188800E+03, -.39242200E+03, -.79813400E+03, 0.13429200E+04, -.14733100E+04, 0.31598700E+04, -.15938100E+04, -.59946600E+03, -.15798500E+04, 0.63113200E+02, -.29932900E+03, -.55539300E+03, 0.40906600E+03, -.13320400E+04, -.47002900E+03, -.85597700E+03, -.20852000E+04, 0.10386400E+04, 0.77392200E+03, 0.10426100E+04, 0.25959200E+03, -.25325100E+03, 0.86388400E+03, -.41794100E+03, 0.85634900E+03, -.18250800E+03, -.33497300E+03, -.15094900E+04, 0.77606200E+03, 0.25348700E+04, 0.75486000E+03, 0.45181500E+03, -.40378700E+03, 0.33246600E+03, 0.80125300E+02, 0.60490800E+03, -.56460700E+03, 0.41224400E+03, 0.11770900E+04, -.59109500E+03, -.46599800E+03, -.58854000E+03, -.31158600E+03, 0.11908100E+03, -.45609800E+03, -.58232500E+03, -.78910200E+03, 0.44782700E+02, -.42070400E+03, 0.14661900E+03, -.76575200E+02, 0.35838100E+02, -.13365100E+03, 0.32983600E+02, -.32051500E+02, 0.96059200E+02, 0.77065000E+02, 0.64684300E+02, 0.48482400E+01, -.10147200E+03, -.12888700E+03, -.55060200E+02, 0.33484100E+03, 0.97109600E+02, -.15662900E+03, -.28306400E+03, -.20305900E+03, -.20814700E+03, -.65498700E+01, -.18888300E+03, 0.10614300E+03, 0.13142800E+03, -.12293300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.55152600E+01, 0.50591800E+00, 0.21926100E+01, -.40361300E+01, -.42881100E+01, -.36747100E+00, 0.90858400E+00, -.14303200E+01, -.28044600E+00, -.12028700E+00, -.22224000E+01, -.14081900E+01, -.31924700E+01, -.44377800E+01, 0.40160200E+00, 0.55300200E+00, -.94317300E+00, -.90815400E+00, 0.86241000E+00, -.79731500E-01, -.93038700E+00, 0.63657100E+00, -.24464500E+01, 0.11043200E+01, -.35303900E+00, -.91418400E-01, -.33745800E+00, -.90181900E+00, -.20445400E+00, -.85619000E+00, 0.66051800E+00, -.17768200E+00, 0.57328400E+00, -.11863300E+01, 0.24340600E-01, 0.33207600E-01, 0.30929600E-01, -.12903600E-02, 0.41865800E+00, 0.20992300E+00, 0.11825900E+01, -.33634200E+00, -.25159700E+00, 0.11542400E+00, -.90847300E-01, -.10187900E+01, 0.46920000E+00, -.34761100E+00, -.10227600E+00, 0.30864300E+00, 0.17691900E+01, 0.87787800E+00, 0.12063700E+00, 0.18475000E+00, 0.26565400E+00, -.82580200E-01, 0.95472300E-01, -.19379400E+00, -.42858500E-03, -.66863700E+00, 0.52331400E-01, -.88851500E+00, 0.24190600E+00, -.13284600E+00, -.64453500E+00, -.92088700E+00, -.24540600E+00, 0.88663000E+00, -.92691100E-02, 0.14204700E-02, -.10809800E+00, 0.46871300E+00, -.41255300E+00, -.10283300E+00, -.55039200E+00, 0.13790100E+00, 0.23621900E+00, -.90210600E-02, 0.10504000E+01, -.20583600E+00, 0.59124200E-03, -.87885000E+00, 0.84767700E+00, -.22524300E+01, 0.11116300E+00, -.52399900E+00, -.67505400E+00, -.77544000E-01, -.79176100E-01, -.78906000E+00, 0.53165200E+00, -.11568100E+00, 0.10979400E+01, 0.25959700E+01, -.86843300E-01, 0.15170700E+01, -.10890800E+00, -.31920700E+01, -.11339600E+01, -.37283000E+00, 0.16356400E+01, 0.61937000E+00, 0.51571400E-01, 0.16304400E+00, 0.11506300E+00, -.64318400E+00, -.47634700E+00, -.41350900E+00, 0.26631100E+00, 0.53164800E+00, -.20886300E+00, 0.48884500E-01, -.34938800E+00, -.53391300E-03, 0.18201100E+00, 0.56571400E+00, -.39272900E+00, 0.96778300E-01, 0.24846000E-01, 0.23297000E+00, -.88405800E-01, 0.68935200E-01, -.67726700E-01, -.18311700E+01, -.53912300E-02, 0.54920400E+00, -.30684900E+00, -.16010400E+01, -.46138800E-01, -.14887500E+00, -.32372800E+00, 0.12894900E+00, -.47604200E-01, 0.12156200E+02, 0.15425000E+03, -.42937900E-01, 0.14938000E+02, 0.17972300E+03, -.97559200E+02, 0.20007200E+03, 0.40668700E+02, 0.10737900E+03, -.10215400E+03, 0.60248300E+02, -.29602700E+02, 0.16820600E+02, -.31604100E+02, -.77085800E+02, -.68229200E+01, 0.11968800E+03, 0.62754100E+02, 0.58271900E+02, 0.39662400E+02, 0.10972400E+03, 0.16929600E+03, -.85192900E+02, -.11052200E+03, -.84282900E+02, 0.12289100E+03, 0.54957500E+02, -.26937300E+03, 0.34117300E+02, -.35328300E+02, -.54387200E+02, 0.17839400E+03, -.88976200E+02, 0.42853600E+02, 0.15621900E+03, 0.44702100E+02, 0.82996900E+02, 0.48690400E+02, -.17637300E+03, -.64846400E+03, -.11536700E+03, 0.54908000E+02, -.12804900E+03, 0.10252100E+03, -.50830200E+02, -.17858500E+02, -.51312800E+02, -.32703600E+03, -.20336400E+03, 0.47265600E+03, 0.12665400E+03, 0.18162100E+03, -.29067500E+02, -.75440400E+02, 0.55421700E+03, -.28429000E+03, -.78969400E+02, -.27717900E+03, -.50290400E+02, 0.59956100E+02, -.13527800E+03, 0.19842200E+03, -.12766200E+03, 0.73868200E+01, -.12135100E+03, 0.79536700E+03, -.39595100E+03, 0.53293300E+03, -.39748900E+03, 0.25200600E+03, 0.32561500E+03, -.39183500E+03, -.14001500E+03, -.24229200E+03, 0.26720200E+03, -.57827400E+03, -.66957600E+02, 0.37995000E+02, -.13520100E+03, 0.33202700E+02, 0.41416900E+01, 0.72666800E+02, -.21447400E+02, 0.13526400E+03, 0.30058500E+02, 0.46761700E+02, 0.22469500E+03, 0.46838300E+02, -.23898600E+02, 0.67598900E+02, -.23450600E+02, 0.20692600E+02, 0.11664600E+03, -.86904500E+02, 0.28267400E+02, 0.34651200E+02, 0.43540300E+02, -.43474500E+02, 0.62407400E+03, -.31107200E+03, -.38246100E+03, -.31236300E+03, -.12222400E+03, 0.15077500E+03, -.20364300E+03, -.23904900E+03, -.24952200E+03, 0.89677500E+02, -.11837500E+03, -.53132500E+03, 0.26523000E+03, 0.10982900E+03, 0.26561700E+03, 0.10202500E+03, -.34259700E+02, 0.74141600E+02, 0.94331800E+02, -.46431100E+02, -.51363300E+02, 0.93027300E+02, 0.16079800E+02, -.44406700E+00, -.16645000E+02, 0.98320900E+01, 0.71336800E+00, -.16785200E+02, -.76436800E+01, -.28684400E+01, 0.46617300E+01, 0.14609100E+02, 0.79611400E+02, -.10920600E+02, -.70401600E+02, 0.20166800E+02, 0.69753000E+02, 0.16869100E+01, -.19365000E+02, -.18786600E+02, -.62929900E+02, 0.17422100E+01, -.64649900E+02, -.47922200E+02, -.46902800E+02, -.36897800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15954900E+01, -.64080300E+00, -.12924600E+00, 0.54504900E+00, 0.12899900E+01, 0.22486200E-01, -.16912700E+00, 0.73820700E+00, -.18568400E+00, -.13357600E+00, -.24607700E-02, -.96165800E-01, -.10142300E+01, 0.10025400E+01, -.24964500E-01, -.74317300E-01, 0.29866900E+00, 0.12781900E+00, 0.18834100E-01, -.15646800E-02, 0.11862500E+00, -.53740600E+00, -.19480000E+01, 0.76954400E+00, 0.43809100E-02, -.28135200E-01, -.12142000E+00, -.23908800E-01, -.46611900E+00, -.89496700E+00, -.29296700E-01, 0.78548500E-01, -.40861600E+00, 0.11167700E+00, -.43662300E-01, 0.41243500E+00, -.21364000E-01, 0.48481300E-01, -.18932000E+00, 0.20225900E+00, 0.24735000E+00, 0.50061200E+00, -.39388000E-01, 0.39375500E+00, -.35817500E+00, -.25246200E+00, -.37665000E+00, -.59579800E-01, -.37254700E-01, 0.28934400E+00, -.32775400E+00, 0.19335500E+00, -.34001100E-01, 0.43872300E-01, -.28974600E+00, -.54670700E+00, 0.15632500E+00, -.11364000E+01, 0.19253800E-02, 0.41583500E+00, 0.22758000E+00, 0.49244900E+00, -.19470500E+00, -.18117800E+00, 0.57355100E+00, 0.60001300E-01, 0.29745400E+00, -.49062200E+00, 0.91731300E-01, 0.73231000E-02, -.84496700E-01, -.29117900E+00, -.58196600E+00, 0.16295200E+00, 0.52533300E+00, -.99650000E-01, 0.65288000E-01, -.50443100E+00, 0.49060300E+00, -.19077300E+00, -.30888200E-03, -.15015500E+00, 0.67736100E+00, -.10392100E+01, -.22107300E+00, -.99216700E+00, -.13093100E+00, -.17022800E+00, -.87092800E-01, 0.55671600E-01, -.21201800E+00, -.33459800E-01, 0.37684000E+00, 0.28786200E+00, -.10117900E+01, -.92245600E+00, 0.46834500E-01, -.33498600E+00, -.40197100E+00, -.74418900E-01, 0.95842500E+00, 0.15315700E+00, -.11580600E+00, -.10653000E+00, 0.33054100E+00, -.11190000E+00, 0.43800500E+00, 0.18946300E+00, 0.15435900E+00, -.23995000E-01, -.49327300E+00, -.40443100E-01, -.75488000E-01, -.98720800E-02, 0.17433900E-01, 0.20413900E+00, -.23510700E+00, -.10143800E-01, -.12015500E+00, 0.72518700E-01, 0.18859100E+00, -.40816100E+00, 0.56405600E+00, -.98152600E+00, 0.50967200E-02, 0.13612500E+00, -.13156300E+00, -.37218200E+00, 0.10088700E+00, -.16041500E+00, -.18122300E+00, 0.11916600E+00, -.11366700E+00, 0.49909500E-01, 0.28453500E+03, -.17187600E-01, 0.25447100E+03, 0.36308800E+02, 0.11856300E+03, 0.18202900E+03, 0.15072000E+03, 0.12593400E+03, -.31243900E+03, -.78174000E+02, 0.39081600E+02, 0.95521800E+02, 0.40420000E+02, 0.11169300E+03, 0.36886400E+02, -.29259700E+02, 0.15239200E+03, -.83903500E+02, 0.34803300E+02, -.11518700E+03, -.13873800E+03, 0.69582000E+02, 0.43106600E+02, 0.69507700E+02, -.56531700E+02, -.52251800E+02, 0.85310400E+02, -.10479500E+03, 0.13841800E+03, -.62260500E+02, -.19733000E+03, -.13909400E+03, 0.69360700E+02, 0.68547000E+02, 0.69549900E+02, -.10073400E+03, 0.35886700E+02, -.39610000E+02, 0.30328900E+02, 0.55146300E+02, 0.13159100E+01, 0.23823700E+03, 0.50632100E+02, -.25497800E+02, -.41469200E+02, -.25332700E+02, 0.16126000E+03, -.50638700E+00, -.11256800E+03, 0.14762100E+03, -.21654000E+03, 0.87485300E+01, 0.21326600E+02, 0.57031300E+03, -.28483500E+03, 0.32613100E+02, -.28518500E+03, 0.12553700E+03, -.85862200E+02, 0.46465000E+02, 0.26445500E+03, -.53940800E+02, -.13658400E+01, -.62999100E+03, 0.24471000E+03, -.12061400E+03, -.43656000E+02, -.12226800E+03, -.18745300E+03, 0.97421800E+02, -.12700500E+03, -.37341600E+02, -.14493500E+03, 0.27890600E+02, 0.11923300E+02, -.81817500E+02, 0.37231500E+02, -.38934600E+02, 0.40863700E+02, 0.44673700E+02, -.31940500E+02, 0.83685200E+02, 0.28501300E+02, 0.39973000E+02, -.25352400E+02, -.16030200E+02, 0.23478400E+03, -.11708200E+03, -.13355500E+03, -.11740400E+03, 0.47607600E+02, -.19477300E+02, 0.21972000E+02, 0.12651800E+03, 0.83299600E+02, 0.21737500E+02, -.23342600E+03, -.32468100E+03, 0.16468300E+03, 0.19103200E+03, 0.16222900E+03, 0.15069600E+03, -.20801100E+02, 0.10059800E+03, -.62556200E+01, 0.70481700E+02, 0.24607900E+02, 0.65832000E+02, 0.10814400E+03, -.54060600E+02, -.12699200E+02, -.54043900E+02, 0.45976100E+00, 0.43612900E+02, -.39013600E+02, 0.70514200E+01, 0.55282000E+02, 0.40972500E+02, 0.14393900E+03, 0.41750500E+01, -.14018100E+01, -.13824300E+01, -.64371800E+01, 0.80623900E+01, 0.92681700E+00, 0.47733800E+01, 0.56476600E+01, 0.75659500E+01, 0.13316700E+02, -.83968100E+01, -.61991700E+01, -.12219100E+02, -.90122400E+02, -.16155900E+02, -.20548800E+02, -.17877000E+02, 0.10639800E+02, 0.13071200E+02, 0.24521500E+02, -.41540600E+02, 0.25490400E+02, 0.38984700E+02, 0.35856000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.55447700E+01, 0.83377700E+00, 0.20375100E+01, -.38682200E+01, -.39845900E+01, 0.56746300E-01, 0.79314400E+00, -.14006700E+01, -.33992500E+00, -.29865500E-01, -.17688100E+01, -.11735000E+01, -.23740100E+01, -.40558700E+01, 0.30910400E+00, 0.49486600E+00, -.93531400E+00, -.75758000E+00, 0.94098100E+00, -.10188100E+00, -.96336300E+00, 0.78309800E+00, -.19848800E+01, 0.66506100E+00, -.33756200E+00, -.39279300E+00, -.31661600E+00, -.71187800E+00, 0.32070400E-02, -.13113800E+01, 0.84073300E+00, -.10754100E+00, 0.41687100E+00, -.10784900E+01, 0.40041300E-01, 0.20334800E+00, 0.22993700E-01, -.23203000E+00, 0.77927400E-01, 0.11448900E+00, 0.94255900E+00, -.19134400E+00, 0.23663400E+00, 0.46114500E-01, -.21917300E+00, -.88175000E+00, 0.64963900E+00, -.29226200E+00, -.91956900E-01, 0.54008500E+00, 0.18530800E+01, 0.10352100E+01, 0.12873300E+00, 0.16471900E+00, 0.29135000E+00, -.41866100E-02, 0.50887900E-01, -.17670300E+00, -.38844200E-02, -.83639800E+00, -.70478600E-01, -.74200200E+00, 0.19932500E+00, -.28516000E+00, -.31794200E-01, -.73453800E+00, -.28922100E+00, 0.27721400E+00, 0.54871700E-02, -.44647800E-02, 0.30627700E+00, 0.21771500E+00, -.59825000E+00, 0.42201400E-02, -.87223500E+00, 0.17793800E+00, 0.28385000E+00, -.50183300E-01, -.29174300E+00, 0.14338200E+00, -.69933900E-03, 0.25768700E+00, -.89454500E+00, -.58627800E+00, -.19818000E-01, 0.87993200E-01, -.77392300E-01, 0.21845500E+00, 0.17642600E+00, 0.14979200E+00, 0.12725700E+00, 0.46513800E-01, -.26853500E+00, 0.13511500E+01, 0.11068500E+01, 0.16546300E+01, -.21605200E+00, 0.75735100E-02, 0.57394500E+00, -.32990700E+00, -.55122000E+00, -.13163100E+00, 0.18718400E+00, 0.41715700E+00, -.43229800E+00, -.77483600E+00, -.12611900E+01, -.23971100E+00, -.52051000E+00, 0.19991500E+00, -.35710500E+00, 0.34575100E-01, -.54159700E-01, 0.78959100E-02, 0.15670000E+00, -.33742600E+00, 0.26626700E+00, -.41238200E+00, 0.91605100E-01, -.95648600E+00, -.20500800E-01, -.83294300E+00, -.15413300E+00, -.35478800E+01, -.11737100E-01, -.77552400E+00, 0.80295900E+00, 0.18628500E+01, 0.26294000E+00, -.77463600E-01, -.41897300E+00, 0.40238600E+00, -.23039400E+00, 0.97143000E-01, -.62670000E+00, 0.80124200E+01, 0.21874000E+03, -.18942500E+03, 0.24280100E+03, 0.31771000E+03, 0.20116100E+03, -.13564500E+02, -.64480300E+03, 0.23667400E+03, -.12216000E+03, -.15842100E+03, -.11370000E+03, 0.60180500E+02, 0.64800100E+02, -.21724400E+03, 0.87939700E+02, -.35792300E+03, 0.13109100E+03, -.33630800E+03, -.64114900E+03, 0.32324400E+03, 0.21645400E+03, 0.31998200E+03, -.15967200E+03, -.23659200E+03, 0.62256900E+03, 0.82008000E+02, 0.46923100E+03, -.18147500E+03, -.13315300E+02, -.16032700E+04, 0.80440200E+03, 0.43284900E+03, 0.80127100E+03, 0.74389900E+00, 0.10045300E+03, 0.40871500E+02, 0.13883000E+02, 0.56965200E+03, 0.59335200E+02, 0.94709100E+03, 0.83755500E+03, -.42028000E+03, -.39670700E+03, -.41869300E+03, 0.29773600E+03, 0.41272900E+03, -.97332500E+03, -.82580600E+02, -.99362500E+03, 0.39818000E+03, -.20877100E+03, 0.50351600E+03, -.25358900E+03, -.11971100E+03, -.25164400E+03, 0.46576400E+02, -.24958300E+03, 0.23485600E+03, 0.56413700E+03, 0.41002200E+02, -.73403400E+02, -.93669100E+03, -.12701700E+04, 0.63270600E+03, -.12529700E+04, 0.63477400E+03, -.84061600E+03, -.60997500E+03, 0.36047000E+03, -.28088400E+03, 0.43770800E+03, -.71454300E+03, 0.28842600E+03, -.31648200E+03, 0.14825700E+03, 0.63806000E+02, 0.15870300E+03, 0.20677700E+02, -.12564000E+03, 0.43968900E+03, 0.63834700E+02, 0.56944300E+02, -.59808200E+02, 0.21201100E+03, 0.10149100E+04, -.50702500E+03, -.57585700E+03, -.50740500E+03, -.12338100E+03, -.31470400E+03, -.58582900E+02, 0.18288800E+03, -.20022300E+03, -.19513400E+03, -.95280900E+03, -.18339700E+04, 0.91932200E+03, 0.49047200E+03, 0.91751500E+03, 0.25242400E+03, -.45608200E+03, 0.71363700E+03, 0.46616500E+03, 0.67945600E+03, -.16694700E+03, 0.97000700E+03, 0.10402100E+03, -.50623500E+02, 0.26333600E+03, -.51925600E+02, 0.14065500E+02, 0.16410800E+03, 0.11217700E+03, 0.10658400E+03, 0.45687400E+03, 0.89229600E+02, 0.30300400E+03, -.62974400E+02, -.21430100E+02, 0.22622100E+02, -.26663500E+02, 0.77302400E+01, 0.93593400E+01, 0.28033300E+02, 0.25093500E+01, 0.33243000E+01, 0.36112700E+01, -.11122300E+03, 0.20791600E+02, -.12007400E+02, -.10450100E+03, -.13182000E+03, 0.13913000E+02, 0.15354100E+02, 0.89011800E+02, 0.46067100E+02, 0.74462600E+02, -.30033300E+02, 0.63264100E+02, 0.74158200E+02, 0.70312700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14330800E+01, 0.18844500E+00, -.85066600E-01, -.47768400E+00, -.56155100E+00, 0.53769200E+00, 0.73633400E-01, 0.70849700E-01, -.11863700E+00, 0.26178500E+00, 0.12909700E+00, -.15855600E+00, 0.58316300E+00, 0.29857000E+00, -.10546700E+00, -.11417900E+00, 0.26959200E+00, 0.77829700E-01, 0.30076000E+00, -.12288000E+00, 0.55124800E+00, 0.11754700E+01, -.73931900E+00, 0.15053000E+01, 0.19350900E-01, -.24308700E+00, -.27566000E+00, -.11455800E+00, 0.11847900E+00, -.75427000E+00, 0.23130600E+00, -.78348700E-01, 0.64501000E-01, -.53432300E+00, 0.49845500E-01, 0.12066400E+00, 0.26644600E-02, 0.99718300E+00, 0.24078300E+00, 0.79154700E-01, 0.34957400E+00, -.36348200E+00, 0.39216800E-01, -.12072000E+00, 0.33540300E+00, -.16763000E+00, 0.23250700E+00, -.65963200E-02, 0.10320500E+00, -.38360500E+00, -.11117800E+00, -.17681500E+00, -.16250400E-01, -.12220800E+00, 0.14884300E+00, 0.24355200E-01, -.10375600E+00, -.81471900E+00, 0.94915200E-03, 0.21259200E+00, 0.35903600E+00, 0.57713200E+00, -.14329200E+00, 0.13678200E+00, -.59122500E-01, 0.35662600E+00, 0.41710600E+00, 0.57541200E+00, -.11179000E+00, 0.40181300E-02, 0.11475700E+00, 0.16812900E+00, -.64477700E-01, -.21577100E-01, 0.42228800E+00, -.32161000E-01, -.21831300E+00, -.13756000E+00, -.26835500E+00, 0.14632800E+00, 0.77033700E-04, 0.58987900E+00, -.25605600E+00, 0.60888000E-01, 0.36502300E-01, 0.22104800E+00, 0.62446500E-01, 0.97685200E-01, 0.15850000E+00, -.37624200E-01, -.30446300E+00, 0.42605400E-02, 0.60175200E-01, -.33198100E+00, 0.22723500E+00, -.35311200E+00, 0.14811400E+00, 0.16482800E+00, 0.24017000E-01, 0.20206900E+00, -.23130900E-01, 0.13726400E-01, 0.17619400E-01, 0.76511100E-01, 0.44771100E+00, -.19504000E+00, -.70035500E-01, -.28677000E+00, 0.41059200E+00, 0.54842500E-01, 0.11568400E+00, 0.41170600E-01, -.62323900E-02, -.30648500E-02, 0.31478700E+00, -.14140800E+00, -.16532500E-01, 0.99826300E-01, -.10430000E+00, 0.22844900E+00, -.41462300E-01, -.51642400E+00, 0.22751500E+00, -.27833400E+01, -.61753400E-02, 0.21705500E+00, 0.51504300E-01, -.35144800E+00, 0.30747100E-01, 0.74514900E-01, -.29567200E-01, 0.13403800E+00, 0.13289300E+00, -.26380500E-01, 0.61300300E+00, 0.10618700E-02, -.37136300E+03, 0.25897400E+02, -.20712200E+03, -.62048500E+02, -.22051500E+03, -.61427000E+02, 0.76077500E+03, 0.23310300E+02, -.98007400E+01, -.27853900E+02, -.14485900E+02, -.18168300E+03, -.12572100E+02, 0.51391900E+02, -.23558500E+03, 0.99786800E+02, 0.10483500E+02, 0.13467700E+03, 0.12670500E+03, -.64132600E+02, -.27628200E+03, -.63413000E+02, 0.99225000E+02, 0.97517200E+02, -.29240600E+03, -.48529300E+02, -.13828800E+03, 0.59201800E+02, 0.32484800E+03, 0.64460800E+03, -.32223500E+03, -.27574900E+03, -.32220400E+03, 0.13911700E+03, -.62660000E+02, -.85069100E+02, -.27363400E+03, -.36474700E+03, -.65756000E+02, -.49608400E+03, 0.10115800E+03, -.50236800E+02, 0.89740900E+02, -.50575600E+02, -.30997600E+03, -.12575600E+03, 0.44613500E+03, 0.41857800E+02, 0.18150900E+03, -.35178800E+02, -.15219400E+03, -.63008600E+03, 0.31498500E+03, 0.17855600E+03, 0.31505700E+03, -.18527300E+03, 0.12817500E+03, -.10740300E+03, -.23926200E+03, 0.22209600E+02, 0.42471900E+02, 0.10687200E+04, -.30842800E+03, 0.15272600E+03, 0.50660600E+03, 0.15415900E+03, 0.42853200E+03, -.34953900E+02, 0.45366400E+02, -.76939900E+02, 0.14782300E+03, -.94985100E+02, 0.59467500E+02, -.72302300E+03, 0.36768300E+03, 0.44214400E+02, 0.36145300E+03, 0.23764100E+01, 0.96333900E+02, -.16413100E+02, -.11740300E+03, 0.29948400E+03, 0.11448400E+03, 0.35358200E+03, -.32778300E+03, 0.16376900E+03, 0.27362300E+03, 0.16389600E+03, -.73990900E+02, 0.14896700E+03, -.15989000E+03, -.19054900E+03, -.86244300E+02, 0.74317600E+02, 0.51135000E+03, 0.80806000E+03, -.41016700E+03, -.86951200E+03, -.40399800E+03, -.17090200E+03, 0.98415400E+02, -.21830400E+03, -.10424400E+03, -.20013400E+03, 0.89185800E+02, -.23956500E+03, -.50518300E+03, 0.25261600E+03, 0.13207700E+03, 0.25252000E+03, 0.49673700E+02, -.69611100E+02, 0.11017900E+03, 0.14119200E+03, -.33310800E+02, -.24951000E+02, 0.30924900E+02, -.24907400E+02, 0.11791900E+02, -.64491500E+01, 0.25970200E+02, -.15172400E+02, -.73557000E+01, -.17091400E+02, -.20608600E+02, -.18388800E+02, -.72358600E+01, 0.66197600E+02, 0.29190300E+02, 0.10414500E+02, 0.73544700E+02, 0.23297300E+02, 0.40076500E+02, 0.50997800E+02, 0.79828300E+00, -.15176900E+02, -.31980000E+02, 0.31385800E+02, -.52929400E+02, -.84891900E+02, -.52375400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21439400E+01, 0.39318200E+00, 0.31986500E+00, -.82406800E+00, -.16004900E+01, 0.49710700E+00, 0.36418900E+00, 0.17372100E+00, -.48944200E+00, 0.22808700E+00, -.48325200E+00, -.30584800E+00, 0.11773500E+01, -.28837300E+00, 0.14680900E+00, 0.23409100E+00, 0.47453000E-01, 0.36068000E+00, 0.67898500E+00, -.16446100E+01, -.94311500E+00, 0.64115000E-01, -.16142900E+01, 0.25417400E+00, -.17116600E+00, 0.22053000E+00, -.41251300E+00, -.62459000E+00, -.15897400E+00, -.21598300E+01, 0.37480000E+00, 0.24356700E-01, -.30083200E+00, -.72215400E+00, -.54624300E-01, -.36974600E-01, 0.11763000E-01, 0.58411000E+00, 0.56015400E+00, 0.31511300E+00, 0.15501900E+00, -.90869200E+00, 0.21179400E+01, -.30567000E-01, 0.49231500E+00, -.11280100E+01, -.10057100E+01, 0.47410700E-01, 0.14932000E+00, 0.19804100E+00, 0.27674500E+00, -.11214400E+00, 0.31948700E-01, -.16844000E+00, 0.82054900E-01, -.72905900E+00, -.80987500E-01, 0.31016100E+00, 0.39495300E-02, 0.26468300E-01, 0.19776300E+00, 0.40786900E+00, -.38341100E-02, 0.34330200E+00, 0.72481700E-01, 0.62230900E+00, 0.14876000E+00, -.74982600E+00, -.75981300E-01, 0.52027000E-02, -.22440700E+00, -.22688000E+00, -.34009100E+00, 0.39543000E+00, -.37808900E+00, -.68255200E-01, 0.59167200E-02, -.23403000E-01, 0.33317900E-01, -.23145300E+00, -.12413800E-02, 0.64854000E-02, -.12373800E+00, -.12308000E+01, -.20557500E+00, -.75396800E-01, 0.53308100E+00, -.38703500E+00, -.15193600E+00, 0.30075100E+00, 0.20876500E+00, 0.82495000E-02, 0.47630600E+00, 0.13649400E+01, 0.92376900E-01, -.48511500E+00, -.30271500E-01, -.16316800E-02, 0.40690400E+00, -.38777000E-01, 0.62025700E+00, 0.32003300E-01, -.27133000E-01, 0.26407200E+00, -.41889600E+00, 0.62028000E+00, -.27292100E-01, 0.34415800E+00, 0.27591000E-01, 0.27979300E-01, -.10711800E+01, 0.56430700E-02, 0.10185400E+00, 0.30788000E-02, -.31208800E+00, -.96563600E-01, 0.19662800E+00, -.12180900E+00, 0.10063400E-01, -.43893000E+00, -.15135000E+00, -.37259800E-01, 0.10343100E+01, 0.73875500E+00, 0.15605200E-02, -.35899500E+00, 0.19994400E+00, 0.83034400E+00, -.86078500E-01, 0.19234800E+00, -.12374100E+00, -.25177400E+00, -.97996800E-01, 0.43119300E-01, -.29380100E-01, 0.26118700E-02, -.28887700E+00, -.35353500E+03, 0.10763100E+03, -.20177100E+03, -.55819400E+02, -.27609100E+03, -.29946000E+03, -.19495000E+03, 0.85463800E+02, 0.90474200E+02, 0.98068700E+02, 0.24501500E+03, -.57593900E+02, 0.54319200E+02, 0.13813500E+03, 0.91691400E+02, -.21658500E+03, 0.19307600E+02, 0.39111600E+02, -.19183300E+02, 0.19630000E+03, -.19751200E+02, -.14647300E+03, -.22816200E+02, 0.15389300E+03, 0.28901700E+02, -.63521000E+01, 0.10289100E+03, -.39591700E+03, -.27811200E+02, 0.14122800E+02, 0.17601000E+03, 0.13780400E+02, -.23172400E+03, -.11442700E+03, 0.38193700E+03, 0.78758000E+03, 0.48176100E+03, -.44143400E+02, 0.31198400E+03, -.91668900E+03, 0.45845000E+03, 0.32795000E+03, 0.45837200E+03, 0.45740100E+03, -.17546900E+03, 0.10261700E+03, -.34576000E+02, 0.41569900E+03, -.41482100E+03, 0.37022900E+03, 0.72483300E+03, -.36475400E+03, -.37500000E+03, -.36237900E+03, -.23232600E+02, -.19695100E+03, -.54211300E+02, 0.28301600E+02, -.23115600E+03, -.14143800E+03, -.44100600E+03, 0.35404500E+03, -.17885400E+03, -.89353800E+02, -.17712500E+03, -.60097200E+02, 0.28850900E+03, 0.52847300E+02, 0.25823300E+03, -.13560500E+03, 0.35753600E+03, 0.34227800E+03, 0.62855200E+03, -.32180600E+03, 0.27444200E+02, -.31411900E+03, 0.79696600E+02, -.25491200E+02, -.26484900E+03, -.17946000E+03, -.37276400E+03, -.76936900E+02, -.59778300E+03, -.45387700E+03, 0.22738400E+03, 0.61640400E+02, 0.22695500E+03, 0.78221500E+02, -.12442200E+03, 0.21609700E+03, -.69979600E+02, 0.69412700E+02, -.58583200E+02, -.35467200E+02, 0.21302800E+03, -.10462700E+03, 0.56511800E+03, -.10633800E+03, 0.16719700E+03, -.29643100E+02, -.12935900E+03, -.39438400E+02, -.73789700E+02, -.92671800E+01, -.52893200E+03, 0.70899900E+03, -.35572200E+03, -.35278100E+03, -.35446700E+03, -.15878600E+03, 0.48844900E+01, -.27303900E+03, -.22623600E+03, -.24383100E+03, 0.54943700E+02, -.20726900E+03, 0.34634700E+02, -.13217400E+02, 0.15019300E+02, -.26779800E+02, 0.52030000E+01, -.10875100E+02, 0.15645400E+02, 0.24085500E+02, 0.18025000E+02, -.51652800E+01, -.23937200E+02, -.28843800E+02, 0.85493400E+02, -.14928600E+02, -.76353300E+01, -.39547200E+02, -.32098700E+02, -.42561800E+02, 0.77146800E+02, -.26778000E+02, 0.21654400E+02, 0.35790600E+02, 0.45856100E+02, -.27772900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11109800E+02, -.65643700E+00, 0.41236800E+01, -.77063700E+01, -.10367900E+02, -.34443500E+01, 0.25228400E+01, -.23254600E+01, 0.92593200E+00, 0.59621700E+00, -.51084200E+01, -.32224000E+01, 0.14170400E+01, -.38060700E+01, 0.85077100E+00, 0.56671900E+00, -.18354100E+01, -.24235000E+01, -.11305800E+00, 0.18659100E+01, -.10132500E+01, 0.56759900E+01, -.12257600E+01, 0.12144700E+01, 0.33820300E-01, -.14783200E+01, -.32381200E+00, 0.26493300E+00, -.16201600E+00, -.45548100E+01, -.26862900E+00, -.59370600E+00, 0.69008200E+00, 0.19726300E+00, 0.45572900E+00, -.21888800E+01, 0.81704100E-01, -.33178800E-01, -.47920900E+00, -.12186700E+01, -.22777400E+01, 0.70258900E+00, -.34918000E+00, -.25925200E+00, 0.32925100E+01, -.24625300E+01, -.35032700E+00, -.28278900E-01, 0.79865100E-01, -.17108700E+00, -.74412700E-01, -.14472300E+01, -.95190300E-01, -.11203300E+01, -.39784700E-01, 0.23783000E+01, -.44858800E+00, -.98206600E+00, 0.49570400E-02, -.45872300E+01, -.20330600E+01, -.26221700E+01, 0.45019300E+00, 0.96734600E+00, -.30696800E+01, 0.33710300E+00, -.86197700E+00, 0.15740300E+01, 0.14649600E+00, -.88742500E-02, -.17358600E+01, 0.67312600E+00, -.15609300E+00, -.12354300E+00, -.43040200E+00, 0.29834300E+00, 0.10890800E+01, 0.15616000E+00, 0.35111000E+01, -.96242400E+00, 0.32333900E-02, -.49285800E+01, 0.33618300E+01, 0.25349700E+00, 0.76218700E+00, -.47720600E+00, -.10968600E+01, -.96821800E+00, -.11743500E+01, -.87884400E+00, 0.27041700E+00, 0.46653700E-02, 0.18700700E+01, -.66660300E-01, -.48151100E+00, -.21060400E+00, 0.65956900E+00, -.56465400E+00, 0.20563400E+01, 0.83461100E+00, 0.14033600E+01, 0.29390500E+00, 0.52588600E+00, 0.10092700E+01, -.53276000E-01, 0.28721500E+01, -.48023600E+00, 0.20999500E+01, 0.75990300E-01, -.38707100E+00, 0.71312700E+00, -.20902100E+00, 0.56867100E+00, 0.38355900E-01, -.47011600E+00, -.56680600E+00, 0.21470500E+00, 0.20926300E+00, 0.57891000E+00, 0.25985100E+01, -.61645500E+00, 0.29262100E+01, 0.36400400E+01, 0.18977900E+01, 0.26796400E-01, 0.11936900E+00, 0.58066000E+00, -.25034700E+01, 0.11331000E+01, -.46792200E-01, -.26397500E+00, 0.12399400E+01, -.33991400E+00, -.26504400E+00, -.19481300E+01, -.15824500E-01, 0.62676000E+00, 0.32197000E+01, 0.12482600E+04, 0.77329200E+03, -.14190700E+02, -.13355800E+03, -.26745600E+04, 0.18310200E+04, -.93390800E+03, -.69879600E+03, -.91933900E+03, -.82147000E+03, 0.89919800E+03, 0.65380100E+01, -.67356500E+03, -.22789800E+03, 0.93263100E+03, 0.44315700E+03, 0.91291400E+03, -.47692700E+03, -.15926700E+04, -.45472400E+03, 0.12957700E+04, 0.56861700E+03, -.16272700E+04, 0.12213400E+04, -.26758600E+03, -.94045000E+02, 0.36854500E+04, -.31007600E+04, 0.15430900E+04, 0.15896200E+04, 0.15512900E+04, 0.10494100E+04, 0.22676500E+03, -.15111100E+03, -.26663900E+04, 0.15483000E+04, 0.41912100E+03, 0.78161100E+02, 0.25472900E+04, -.12676900E+04, -.46223600E+03, -.12738900E+04, -.26510600E+04, -.85491700E+00, 0.17904300E+04, -.41037100E+03, 0.59057400E+02, 0.41723700E+03, -.17441400E+04, 0.10116300E+04, -.50768200E+03, 0.17808100E+04, -.50615100E+03, -.10930400E+03, 0.10999000E+03, 0.62455300E+03, 0.51457500E+03, -.34987100E+03, 0.38286300E+02, -.19148600E+04, 0.63144600E+04, -.31633000E+04, -.74008900E+03, -.31562900E+04, 0.13261300E+03, 0.15097700E+04, -.29776900E+04, -.47254300E+03, -.17190000E+04, 0.15460300E+04, -.43219100E+04, 0.49129900E+03, -.21515200E+03, -.19917500E+04, -.24687800E+03, 0.28196100E+03, 0.69078700E+03, -.38714000E+03, 0.99166100E+03, -.89281700E+03, 0.32653300E+03, 0.22984000E+04, 0.16448500E+04, -.82703600E+03, -.71874900E+03, -.82257300E+03, -.24268900E+03, 0.23756700E+03, -.42742700E+03, -.69557100E+03, -.85864900E+03, -.21702200E+02, -.10012300E+04, -.28660000E+04, 0.14700400E+04, 0.60462000E+03, 0.14314700E+04, -.15574200E+04, -.77086900E+03, 0.52533200E+03, -.20442200E+04, 0.43201600E+03, -.97772900E+03, 0.30769400E+04, -.43177100E+04, 0.21653500E+04, 0.20233900E+04, 0.21587000E+04, 0.10853300E+04, -.30751400E+03, 0.13817000E+04, 0.10746100E+04, 0.83741000E+03, -.38402200E+03, -.73146800E+03, 0.22806800E+02, -.98575600E+02, -.86680100E+02, -.34135600E+02, -.57282800E+01, -.13164900E+03, 0.75675700E+02, 0.39151900E+00, 0.72043400E+02, 0.12523700E+03, 0.26667500E+03, -.64959200E+02, -.21678600E+03, 0.26460300E+03, 0.39929500E+03, 0.16922700E+03, -.21362300E+02, -.44407400E+02, -.21535600E+03, 0.13541500E+03, -.36707000E+03, -.37981300E+03, -.28653000E+03, -.26674700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12644900E+02, 0.37019400E+01, 0.30122200E+01, -.33021600E+01, -.79506200E+01, 0.35687000E+01, 0.11739500E+01, -.78381300E+01, 0.15188900E+01, 0.31539600E+01, -.61285600E+01, -.48187000E+01, -.66946600E+01, -.79358100E+01, 0.13880900E+01, 0.12957700E+01, -.46809200E+01, -.15863900E+00, 0.90592000E+00, -.24982400E+01, 0.75601500E-01, 0.10672500E+02, -.62042700E+01, 0.22950000E+01, -.99029400E-01, -.28887700E+01, 0.98919400E+00, 0.85745600E-01, -.20604400E+01, 0.57529000E+00, -.45773400E+00, -.13960300E+01, 0.49171800E+01, -.53767500E+00, 0.32597200E+00, -.52127900E+01, 0.68201300E-01, -.23050700E+01, 0.13191300E+01, -.12021600E+01, 0.22557900E+00, 0.10714900E+00, -.42590500E+01, -.35003600E+00, 0.75821400E+00, 0.80997400E+00, -.76030900E+00, -.93234400E+00, -.82643800E+00, -.82171800E+00, 0.37481400E+01, 0.10859900E+01, 0.64546600E+00, -.11555100E+01, 0.18792000E+01, -.18458700E+01, 0.22241800E+00, 0.24854800E+01, 0.21186000E-02, 0.21476100E+01, 0.16815900E+01, -.90811600E-01, 0.32396700E+00, 0.23389100E+01, 0.43736400E-01, 0.13629100E+01, -.86319600E+00, -.19075500E+01, 0.63101600E+00, -.67013200E-02, 0.13390300E+00, 0.79185600E+00, 0.23063000E+01, 0.54828900E-01, 0.24843200E+01, -.24719400E+00, 0.98110700E+00, -.18743800E+01, 0.45569600E+01, 0.61537500E-01, 0.57932100E-02, -.16900700E+01, 0.42996200E+01, -.36904900E+01, 0.11791300E+00, -.37965400E+01, 0.25239600E+00, 0.14929100E+00, -.18321200E+01, -.26432800E+00, 0.58692400E+00, 0.71863500E-01, 0.49450800E+01, 0.15288400E+01, -.51037900E+00, -.29409500E+01, -.43499200E+00, -.10126900E+02, -.98309900E+00, 0.23199100E+01, 0.21301600E+01, 0.29181800E+00, -.40689200E+00, 0.30341800E+00, 0.10318200E+01, 0.18176100E+01, 0.45414300E+01, 0.13470600E+01, 0.50736000E+01, 0.22055100E+00, 0.31604500E+01, -.31346600E+00, -.20232700E+00, 0.68553600E-02, 0.80399700E+00, -.61778300E+00, -.54782300E+00, -.89418900E-01, -.72332400E+00, 0.66870200E+01, 0.27640600E+01, -.21768800E+01, -.24229600E+01, 0.52185900E+01, -.24708400E-01, 0.21159900E+01, -.71668200E+00, 0.15737200E+01, 0.65628700E+00, -.41401300E+00, 0.26769300E+01, 0.31976700E+01, -.26792400E+01, -.20141100E+00, 0.16716400E+01, 0.18314200E-01, 0.26708500E+01, -.22974600E+01, 0.13385200E+00, -.15354000E+04, -.72199900E+03, -.20580900E+03, -.91806600E+03, 0.61088900E+03, -.38574700E+03, -.88384200E+03, -.29957800E+03, 0.37767100E+03, -.69923400E+03, 0.44433300E+03, 0.80610200E+03, 0.15574900E+03, -.85114800E+03, -.23897200E+03, -.89173900E+03, 0.44766700E+03, 0.14095100E+04, 0.44413900E+03, -.56048100E+03, -.17478600E+03, 0.90195000E+03, 0.49316400E+03, 0.31431200E+03, -.15027700E+03, -.46883300E+03, -.36199700E+04, 0.18079200E+04, 0.17779100E+04, 0.18088100E+04, 0.22395100E+03, 0.13473900E+03, 0.61047700E+03, 0.10713200E+04, 0.24010900E+04, 0.58537700E+03, -.45942100E+02, -.71227000E+03, 0.35657900E+03, -.27183500E+03, 0.35638500E+03, 0.10303600E+04, -.52948700E+03, -.25551800E+03, -.29941300E+03, 0.61631600E+03, -.85865500E+03, 0.78353400E+03, 0.28978000E+04, -.14695700E+04, -.76965400E+03, -.14485600E+04, -.33011600E+03, 0.41778300E+02, -.21126500E+03, -.42184100E+03, -.17669700E+04, -.19649700E+03, -.17376900E+04, -.24427300E+04, 0.11950700E+04, -.23234000E+04, 0.12204700E+04, -.13823200E+04, 0.25336200E+03, 0.17809600E+03, -.14119000E+04, 0.26270900E+03, 0.37919200E+03, 0.99732800E+03, 0.20782400E+04, -.10812700E+04, -.99028900E+02, -.10376800E+04, -.46951500E+03, -.30305000E+03, -.29053900E+02, -.12776600E+03, -.11510700E+04, -.58648500E+03, 0.94757400E+03, -.36162400E+03, 0.17842200E+03, -.36291900E+03, 0.18096000E+03, -.28587400E+03, -.29066100E+03, 0.31484400E+03, -.77210100E+03, -.24497400E+03, -.36193800E+03, -.71906200E+03, -.10522600E+04, 0.55361500E+03, 0.21930600E+04, 0.52770000E+03, 0.50553000E+03, -.91242600E+03, 0.83665500E+03, 0.14224400E+04, 0.84451300E+03, -.55175100E+03, 0.58000300E+03, 0.21258700E+03, -.10650700E+03, 0.10717200E+03, -.10597800E+03, -.99592600E+02, 0.42711300E+03, -.17602600E+03, -.23920100E+03, 0.18562700E+03, 0.33568600E+03, -.44542300E+03, 0.87862400E+01, -.83529000E+02, 0.77229700E+02, -.14544100E+03, 0.75190300E+02, -.13933100E+02, 0.87205400E+02, 0.86286400E+02, 0.58870100E+02, 0.10001700E+02, -.32506800E+03, -.80002700E+02, -.22544600E+03, 0.55266000E+03, -.12851100E+03, -.73965800E+02, -.47594200E+03, -.26999700E+02, -.34896200E+03, -.24686000E+02, -.32623200E+03, -.29668100E+02, 0.12244900E+03, -.62210900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.37240400E+01, 0.13073400E+01, -.56499700E+01, 0.83857300E+00, -.25820700E+01, -.19729400E-01, 0.52663100E+00, -.27113600E+01, 0.40687600E+00, 0.15392000E+00, -.15685200E+01, 0.54313900E+00, 0.21346500E+01, 0.34956300E+01, -.34588800E+00, 0.69590300E+00, 0.80973100E+00, -.44711800E-01, -.23279000E+00, -.73748800E+00, -.97392000E+00, -.15406100E+01, 0.75772300E+01, -.42393100E+01, 0.37409700E+00, 0.35705300E+00, -.34903800E+00, 0.30467500E+00, 0.16043400E+01, 0.54163000E+01, 0.16845500E+00, -.35081300E+00, 0.86935100E+00, 0.48562100E+00, 0.43135900E+00, -.67295000E+00, -.89320200E-01, -.15904500E+01, -.58147300E+00, -.10314100E+01, -.22928500E+01, -.53972200E-02, 0.23008400E+01, -.76601400E+00, -.39390900E+00, 0.59443800E+00, -.11956000E+01, -.60235500E+00, -.96031600E+00, 0.22304300E+00, 0.71486500E+00, 0.15994000E+01, 0.23597800E-01, -.33896300E-01, -.64562200E+00, -.86851100E+00, 0.14923600E+00, -.86397300E+00, 0.13574600E-02, 0.69314700E-01, 0.67103700E+00, -.32350300E+00, 0.16455100E+00, -.15861200E+00, 0.46578400E+01, 0.10704900E+01, -.31156300E+00, 0.49035800E+00, -.25176000E+00, -.73348100E-03, 0.75622800E+00, -.27210200E+00, 0.19100400E+00, -.39463200E+00, -.46714500E+00, 0.28041300E-01, 0.52775000E+00, 0.14356000E+00, 0.95321200E+00, 0.30346100E+00, 0.65182800E-03, -.77379300E+00, 0.80343300E+00, -.12009800E+01, -.75916100E-01, -.69573100E+00, 0.41967200E+00, -.84142400E+00, -.41229000E+00, 0.11909900E+00, 0.14369400E+01, -.96574300E-01, 0.25005500E+00, 0.42003800E+01, -.47635100E+00, 0.82776200E+00, 0.34279900E+00, -.69889000E+00, 0.85546300E+00, -.55834800E+00, -.28212600E+00, -.85956700E-01, -.84435000E-01, 0.45190100E-01, -.13627500E+01, -.70771600E+00, -.77655300E+00, -.31101500E+00, -.17697500E+00, 0.32309800E+00, -.96327400E+00, -.16765300E+00, -.38708000E+00, 0.99324000E-02, 0.56621100E+00, -.48693500E-01, -.56939000E+00, 0.11312300E+00, 0.70841700E-01, -.82716400E+00, -.34331600E+00, 0.10851900E+01, 0.66379800E+00, 0.44999500E+01, 0.18234100E-03, -.40104400E-01, -.16576300E+00, 0.18645700E+01, 0.37189800E+00, -.70400200E-01, 0.27467100E+00, 0.60242200E+00, -.36141900E+00, -.61930600E-01, -.12795000E+01, 0.67068300E-02, -.13164700E+01, -.21815600E+00, -.23316700E+00, 0.16667200E-01, -.43413600E+03, -.30122700E+02, -.41840000E+03, 0.11622100E+04, -.58667500E+03, -.51647700E+03, -.58280500E+03, -.35522900E+03, 0.18290400E+03, -.33531700E+02, -.27129400E+03, -.28072400E+03, 0.19469600E+03, 0.15432900E+03, -.28163600E+03, 0.13393800E+03, -.77372600E+03, 0.14067900E+03, 0.27095900E+03, 0.74857200E+02, -.43624700E+03, 0.16175200E+03, 0.13716800E+03, 0.13362100E+02, 0.12624900E+04, -.21281900E+04, 0.10603100E+04, 0.69704800E+03, 0.10641600E+04, 0.48157100E+03, 0.22147000E+03, -.17284900E+03, -.15059700E+04, 0.26530300E+03, 0.30556700E+03, 0.55024900E+02, 0.14282900E+04, -.71188200E+03, -.23532400E+03, -.71413100E+03, -.56991300E+03, 0.82914900E+02, 0.60822800E+03, 0.13912900E+03, -.40237500E+03, 0.29400100E+03, -.57251600E+03, -.34452000E+03, 0.16814000E+03, 0.56657300E+03, 0.17228900E+03, -.28401600E+02, 0.40847900E+01, 0.30694900E+02, -.11876100E+03, -.27260300E+03, -.85326000E+02, 0.63019800E+03, 0.20905500E+02, -.18173400E+02, -.76385700E+03, -.10550900E+02, -.13850600E+03, -.45217500E+03, -.34730000E+03, -.63007100E+03, 0.10016700E+03, -.48398200E+03, -.15874100E+04, -.11198200E+04, 0.56849400E+03, -.47772900E+03, 0.55990500E+03, 0.18934600E+03, 0.10266000E+03, 0.36026800E+03, 0.26262900E+03, 0.42066900E+03, 0.95001900E+02, 0.14774400E+04, 0.46149100E+03, -.23333700E+03, -.84267200E+01, -.23073400E+03, -.16849600E+03, -.13932500E+03, -.26483000E+03, -.36489700E+03, -.35214500E+03, -.21367600E+03, -.90204800E+03, -.29731500E+04, 0.14901100E+04, 0.12992300E+03, 0.14866800E+04, -.31433700E+03, -.69584400E+03, 0.93738700E+03, -.25605400E+03, 0.11852300E+04, -.46944500E+03, 0.22283300E+04, -.13283500E+04, 0.66740000E+03, 0.10457900E+04, 0.66411100E+03, 0.19867400E+03, -.62570600E+02, 0.45801000E+03, 0.50332400E+03, 0.25789200E+03, -.13418100E+03, 0.56458900E+02, -.10322600E+03, -.26499800E+02, -.83237500E+01, -.60252000E+01, -.19241300E+02, -.34790000E+02, 0.23626600E+02, -.30894200E+02, -.17290000E+02, 0.20918400E+02, 0.84456100E+02, 0.60077000E+02, -.71530600E+02, 0.20997800E+03, 0.21003900E+02, 0.11532100E+03, 0.42931600E+02, 0.26362700E+02, -.13318000E+03, 0.54058400E+02, -.97854000E+02, -.86793000E+02, -.13307500E+03, 0.86540600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.77145600E+01, -.21396500E+01, -.33653400E+01, 0.13978400E+01, 0.50027900E+01, -.29980000E+01, -.63774700E+00, 0.61719900E+01, -.16349900E+01, -.27045600E+01, 0.34069500E+00, 0.18443600E+01, 0.80187600E+01, 0.50414800E+01, -.56086000E+00, -.44925700E+00, 0.24026800E+01, 0.28746700E+01, 0.64050700E-01, -.15973600E+00, 0.28205600E+01, -.16419100E+01, -.34057200E+01, 0.26813700E+01, 0.19911200E-01, -.48483800E+00, -.67667100E+00, -.17525300E+00, -.14923100E+00, -.33210400E+01, 0.69568300E+00, 0.58640200E+00, -.26610600E+01, 0.77225700E+00, -.54984200E-03, 0.20489100E+01, -.58963900E-01, 0.57178200E+00, -.61514200E+00, 0.70686900E+00, 0.68721600E+00, 0.59456600E+00, -.34844800E+01, 0.47426500E+00, -.72816300E-01, 0.11888300E+01, 0.17422300E+00, -.11770600E+00, 0.20416100E+00, -.50192800E-01, -.11479800E+01, -.70390500E+00, -.35297200E+00, 0.60319900E+00, -.59694500E+00, 0.55808300E+00, -.32195700E+00, -.14734500E+01, 0.40757000E-02, -.84325200E+00, -.64797600E+00, 0.76011100E+00, -.36466900E+00, -.87315300E+00, 0.35848900E+00, 0.12090800E+00, 0.96357000E+00, -.44729300E+00, 0.45606800E+00, 0.13767900E-01, -.13438200E+01, 0.10036400E+00, -.85855700E+00, -.31441500E+00, -.76752800E+00, 0.78945900E-01, 0.29980700E+00, 0.87171400E+00, -.33493200E-01, -.94746900E+00, -.11429100E-02, -.17581800E+01, 0.11390300E+01, 0.47310000E+01, 0.27678700E+00, 0.28014200E+00, -.67578700E+00, -.46576800E+00, 0.71534100E+00, -.33986700E+00, -.37975300E+00, -.17401100E+00, 0.95638900E+00, 0.13883600E+01, 0.27265600E+01, 0.15202500E+01, -.16422000E+00, 0.15028500E+00, 0.11322800E+01, -.86458900E+00, 0.19539800E+01, 0.20779800E+00, 0.20249600E+00, 0.18744100E+00, 0.11095800E+01, -.10418500E+01, -.16286800E+01, -.58531900E+00, -.74737300E+00, 0.46402400E+00, -.10177900E+01, -.14682400E+00, 0.33683700E+00, 0.49149800E-02, 0.54868000E+00, 0.33270000E+00, 0.17923400E+00, 0.42314100E+00, 0.55769000E+00, -.96578100E+00, -.26512500E+01, 0.21497000E+01, 0.65693900E+00, -.24925700E+01, 0.65318800E-02, 0.37003900E+00, 0.14489300E+00, -.59536300E+00, 0.71274200E+00, -.15331400E+00, -.85533300E+00, 0.35973200E+00, 0.21242900E+00, -.25234600E+00, 0.23001600E+01, 0.31441700E-02, -.10594300E+00, -.57585900E+00, -.23640100E+00, -.73110000E-01, 0.47383200E+00, -.38219300E+03, -.53470900E+03, 0.28722800E+03, -.15874600E+03, -.41645000E+03, -.14864800E+03, -.34914500E+03, -.51669800E+02, 0.42110900E+03, -.30740000E+03, 0.22003600E+03, -.26628600E+02, 0.49289200E+03, 0.10683700E+04, -.53843200E+03, -.40102000E+03, -.53413300E+03, 0.67264500E+03, 0.11921400E+03, -.87049900E+03, 0.11706000E+04, -.15693500E+03, -.70235400E+02, 0.21258900E+04, 0.12305700E+04, -.62209400E+03, -.21305600E+03, -.61497700E+03, 0.11783700E+03, 0.14680400E+02, -.12654400E+03, -.21743800E+03, 0.58138600E+03, 0.28066900E+03, -.13205100E+04, 0.32955000E+03, -.16169800E+03, -.25953500E+03, -.16479500E+03, -.14934100E+04, -.45278000E+03, 0.12927100E+04, -.87924700E+03, 0.70019500E+03, -.46722900E+03, -.54305500E+03, 0.27913600E+03, -.13748600E+03, 0.50944500E+03, -.13957300E+03, 0.88956800E+02, 0.29940100E+03, -.15160100E+03, -.18914800E+03, -.28701200E+03, 0.40989700E+02, -.51358500E+03, 0.27004700E+04, -.13582000E+04, -.12039800E+04, -.13502500E+04, -.22627100E+02, 0.12312900E+04, -.12887800E+04, -.22790400E+03, -.88985700E+03, 0.13628900E+04, -.16893100E+04, 0.78584500E+03, -.37597000E+03, -.70987600E+03, -.39317400E+03, 0.16951200E+03, 0.14023900E+03, -.39167100E+03, 0.23223100E+03, -.94021300E+03, -.11432700E+03, 0.64917000E+03, 0.52342500E+03, -.26619500E+03, -.37410100E+03, -.26171800E+03, -.12439300E+03, 0.14434700E+03, -.26852500E+03, -.18923500E+03, -.25099000E+03, -.11138300E+03, 0.11544400E+03, 0.40327500E+03, -.18812900E+03, 0.10838700E+03, -.20173200E+03, -.65871800E+03, -.18382400E+03, -.20443500E+03, -.71964300E+03, -.63159200E+02, -.46039200E+03, 0.33816800E+03, -.16681500E+04, 0.83288200E+03, 0.54313600E+03, 0.83390800E+03, 0.46749900E+03, 0.25659200E+02, 0.25914300E+03, 0.42191700E+01, -.19951400E+03, 0.33432700E+02, -.74542400E+03, 0.11190700E+03, -.68859800E+02, -.27702800E+01, -.37921500E+02, 0.17402600E+02, -.79947500E+02, 0.47982500E+02, 0.36422900E+02, 0.70358200E+02, 0.30667000E+02, 0.66187900E+02, -.93804300E+02, -.16323300E+03, 0.35226800E+03, 0.19897400E+03, 0.66531600E+02, -.27920600E+03, -.58349000E+02, -.22874100E+03, -.28476400E+02, -.37575700E+03, -.16536600E+03, -.83502000E+02, -.23119100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.78835700E+01, -.23278700E+01, 0.39816600E+01, -.18166400E+00, 0.48320800E+01, -.36182700E+00, -.98321400E+00, 0.16921400E+01, 0.20012800E+00, -.62162400E+00, 0.15166800E+01, 0.15930100E+01, -.30884200E+01, -.23277100E+01, 0.23010300E+01, -.69440800E+00, 0.62833600E+00, 0.47979100E+00, 0.25498900E+00, -.46311100E+00, 0.86229200E+00, -.63726200E+00, -.69179200E+01, 0.18948800E+01, -.18727400E+00, -.29982400E+00, 0.61223000E+00, 0.60508300E+00, 0.13146600E-01, -.54453500E+01, 0.48226500E+00, 0.65308900E+00, -.14070400E+01, -.25302200E+00, -.18586300E+00, 0.29761400E+00, 0.11081300E+00, -.15401500E+01, -.29704900E+00, 0.36809900E+00, 0.45846300E+00, 0.41608100E-01, 0.19309800E+01, 0.33051900E+00, 0.93211900E+00, -.10364800E+01, 0.69975100E+00, 0.68395800E+00, 0.26457900E+00, 0.38740300E+00, -.13250200E+01, -.17246200E+01, -.44617100E+00, -.56155200E-01, 0.94236000E+00, -.32506800E+00, -.12922100E+00, -.14418700E+01, 0.20460800E-03, 0.19594600E+00, 0.12470400E+01, 0.98580400E+00, -.20858800E+00, 0.92664200E+00, 0.10899600E-01, 0.93449900E+00, 0.90625600E+00, -.20564300E+00, -.33650500E+00, 0.46956500E-02, 0.10396700E+01, -.22271500E+00, -.80300000E+00, 0.80645800E-01, 0.40286900E+00, 0.24377700E+00, -.24400800E+00, 0.87378000E+00, -.74895200E+00, -.27593800E+00, -.24772200E-02, -.17591600E+01, -.15025400E+00, 0.31387900E+01, 0.48695300E+00, 0.69000700E+00, -.58525900E+00, 0.67948100E+00, -.93525000E-01, -.35077400E+00, -.11189400E+01, 0.27737600E-01, -.37768700E+00, -.33529300E+01, -.45797400E+00, -.60242500E+00, -.45536500E+00, 0.62802000E+00, 0.14377300E+00, 0.10262200E+01, -.46642700E+00, 0.27578300E+00, 0.60202300E-02, 0.63680800E+00, 0.38931900E+00, -.14656600E+01, -.13721100E+01, -.98193600E+00, 0.27027600E+00, -.10252700E+00, -.44736300E+00, -.31118600E+00, 0.57239900E+00, 0.34933600E-03, 0.16812100E+01, -.14872900E+01, 0.50886800E+00, -.16408400E+00, -.14390500E-01, -.55035200E+00, -.10516200E+01, 0.77049500E+00, 0.16125800E+01, -.25819800E+01, -.91586400E-02, 0.39395500E+00, 0.36097500E-01, -.13530900E+01, 0.39028400E+00, -.15207600E+00, 0.10276300E+01, -.11241200E+01, 0.64630600E+00, 0.65239400E-01, -.73316100E+00, 0.41139100E-02, 0.26991200E+00, -.15690400E+00, 0.11771400E+00, -.24419600E+00, -.77054500E+00, -.28027100E+00, -.17149000E+04, 0.73964300E+03, -.36134900E+03, -.31926500E+03, -.36288300E+03, -.13592800E+03, -.70451600E+02, 0.75245100E+02, 0.13099500E+03, -.14534700E+03, -.10022700E+03, -.47947900E+03, -.50888900E+03, 0.25088500E+03, -.30953000E+03, 0.25342700E+03, -.86944300E+01, -.36362000E+02, 0.14306300E+03, 0.39961700E+03, 0.21009900E+03, 0.75215000E+02, 0.96778300E+03, -.76080100E+03, 0.37772800E+03, 0.21092000E+03, 0.37972100E+03, 0.38553300E+03, 0.69172600E+02, -.25197000E+03, -.17872200E+03, 0.66432700E+03, 0.12206800E+03, 0.17255600E+03, 0.13932200E+04, -.69537000E+03, -.41130700E+03, -.69646600E+03, 0.76659500E+01, -.29501700E+02, -.12692800E+03, 0.30465100E+02, -.37307200E+03, -.61830700E+02, -.54713400E+03, 0.53248800E+03, -.26788500E+03, -.40843100E+03, -.26604700E+03, -.22898500E+03, -.25218700E+02, 0.90438500E+02, 0.46743200E+03, -.23288600E+03, 0.68345000E+00, -.14822600E+04, -.62971200E+03, 0.30901400E+03, -.21905600E+04, 0.31433000E+03, -.66926100E+03, -.96008000E+02, -.47690900E+03, -.67714100E+03, 0.27217800E+03, -.20598700E+03, 0.28694100E+03, -.14901100E+04, 0.74332900E+03, 0.38902000E+03, 0.74589500E+03, 0.11283400E+03, -.86505200E+02, 0.67780000E+03, -.44916700E+01, 0.24742800E+03, -.20026100E+02, 0.12864500E+04, 0.98452100E+03, -.49501900E+03, -.45615600E+03, -.49217500E+03, -.30291500E+03, -.35167100E+03, -.23675000E+03, -.79815600E+02, -.19780500E+03, -.35692400E+03, -.13857300E+04, -.38127800E+04, 0.19166600E+04, 0.15393800E+04, 0.19073100E+04, -.97280100E+02, -.13221500E+04, 0.15634300E+04, 0.36724900E+03, 0.15314000E+04, -.88212300E+03, 0.17642000E+04, -.35002800E+03, 0.17872400E+03, 0.85895600E+03, 0.17520000E+03, 0.15959800E+03, 0.13951800E+03, 0.34473100E+03, 0.31679500E+03, 0.26329600E+03, 0.35618400E+01, -.35871300E+03, -.86424800E+02, -.42372800E+02, 0.26801500E+02, -.33477200E+02, 0.71621900E+01, -.19598000E+02, 0.42845200E+02, 0.11263800E+02, 0.30041000E+02, 0.29146700E+02, -.83271300E+02, 0.19620900E+02, -.15903800E+03, 0.70400000E+02, -.12649200E+03, 0.81848200E+02, -.11151600E+03, 0.65747600E+02, -.10888800E+03, 0.40176400E+02, -.21444000E+03, 0.12601800E+02, -.74776800E+02, -.91098500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34164900E+01, -.97630500E+00, -.15444900E+01, 0.29548100E+01, 0.25913400E+01, -.62802200E+00, -.39386700E+00, 0.22673300E+01, -.16755900E-01, -.12608800E+00, -.54166500E-01, 0.12480200E+01, 0.62471800E+01, 0.46750100E+01, -.58339300E+00, -.19798700E+00, 0.17635400E+01, 0.15857000E+01, -.16064000E+00, -.26950900E+00, 0.91052700E+00, 0.35535600E+01, 0.58251900E+00, 0.30068400E+00, 0.20941100E+00, -.34584700E+00, -.18392100E+00, -.10990300E+00, -.23786400E-01, -.23705200E+01, 0.18480800E+00, -.14396200E+00, -.13722300E+00, -.14127100E+01, -.33207600E+00, -.42348400E+00, 0.16057200E-01, 0.14698000E+01, 0.14812500E+01, 0.24098000E+00, 0.15747500E+01, -.14564900E+01, -.13623800E+01, -.48199900E+00, 0.43583900E+00, 0.11281000E+01, -.74579800E+00, -.27466000E+00, 0.57350000E+00, 0.98014300E+00, 0.18130800E+01, 0.48680900E+00, 0.71464900E-01, 0.10928100E+00, -.28329600E+00, 0.89101800E+00, -.49058900E+00, 0.61868100E+00, 0.48883700E-02, -.29228800E+00, 0.59769300E-04, 0.23117500E+01, -.15019400E+00, 0.15232700E+01, -.10344600E+01, 0.22652900E+00, 0.11613200E+01, 0.10923800E+01, 0.36390400E+00, 0.79585000E-02, 0.55797400E+00, 0.78463100E+00, 0.83338900E-01, -.16794400E+00, 0.45299800E+00, 0.23443000E+00, -.47082700E+00, -.63866700E-02, -.64055400E+00, 0.47855600E+00, -.23947400E-02, 0.11872800E+00, -.11442500E+01, 0.15629700E+01, 0.14887500E+00, 0.67469300E+00, 0.80149500E-01, 0.22985400E+00, 0.38130700E+00, -.63009200E-01, -.14379300E+00, 0.69824000E-01, -.10662500E+01, -.29714200E+01, -.19801800E+00, -.66998600E+00, 0.62588300E+00, 0.78324800E+00, 0.53370900E+00, 0.52290200E+00, -.47627400E-01, 0.33757000E-01, 0.26719300E+00, -.39597100E+00, -.29220700E-01, -.18739400E+00, -.13404200E+00, -.14426800E+01, 0.98676900E+00, 0.64532600E+00, 0.14693500E+00, 0.17581800E+00, 0.20982300E+00, 0.24890200E-01, 0.28798800E+00, -.51799900E+00, 0.52614100E+00, 0.10118700E+01, 0.79329800E-01, -.18015800E+01, -.30616100E+00, 0.15099100E+01, 0.57826700E+00, 0.38029200E+01, -.19425600E-01, -.70787500E+00, 0.32789400E+00, 0.30080700E+01, 0.67303500E+00, -.14494300E+00, 0.71904500E+00, -.96458300E+00, 0.72554500E+00, 0.18625600E+00, -.22834700E+00, 0.26621300E-01, 0.37991600E+00, 0.82921900E+00, -.27579500E+00, -.25639800E+00, -.49458800E-01, -.14223200E+00, 0.28780900E+00, 0.80434900E+03, -.38462100E+03, -.71890600E+03, -.39639600E+03, -.35097400E+03, 0.10003200E+03, -.11504600E+03, -.10981500E+03, -.29944600E+03, 0.30423000E+03, -.19571100E+03, -.30375300E+03, 0.15025900E+03, 0.64718200E+01, 0.15060700E+03, 0.69005500E+02, -.31734000E+03, 0.31518600E+03, 0.87890300E+03, 0.54401900E+03, -.37410300E+03, 0.13010800E+04, 0.19736000E+03, -.96051700E+02, -.69900200E+03, -.99291200E+02, 0.28480700E+03, 0.84429000E+02, -.35867200E+03, 0.14434500E+03, 0.68984600E+03, 0.12996100E+03, -.76671900E+03, 0.20437600E+04, -.10224000E+04, -.90588800E+03, -.10217000E+04, -.54919500E+03, 0.76914900E+03, -.83631900E+03, -.61539300E+03, -.12692500E+04, 0.80514800E+03, -.67251300E+03, -.20355600E+03, 0.10550600E+03, 0.91596600E+03, 0.10202600E+03, -.10381900E+03, 0.48030500E+01, 0.15232600E+03, 0.26028100E+02, -.20704600E+03, 0.73415800E+02, -.48766600E+03, -.17282300E+04, 0.86183900E+03, -.29273600E+04, 0.86341800E+03, -.14257900E+04, -.71793000E+03, 0.14676100E+03, -.77252600E+03, 0.79769100E+03, -.76135700E+03, -.35925400E+03, -.20872200E+04, 0.10510100E+04, 0.39795200E+03, 0.10444700E+04, -.15851500E+03, -.14259400E+02, 0.79775300E+03, -.87677600E+02, 0.33496100E+03, -.64459300E+02, 0.20614800E+04, 0.17487600E+04, -.87568400E+03, -.85239900E+03, -.87426900E+03, -.50649800E+03, -.22871900E+03, -.57293000E+03, -.20852400E+03, -.56038400E+03, -.23553000E+03, -.68793800E+03, -.42465100E+04, 0.21367000E+04, 0.70625900E+03, 0.21243700E+04, -.19551900E+03, -.10312500E+04, 0.14804600E+04, 0.39426900E+03, 0.16586700E+04, -.78789000E+03, 0.28805600E+04, -.17680800E+04, 0.88855900E+03, 0.10777400E+04, 0.88411900E+03, 0.64059800E+03, 0.54578100E+03, 0.47835200E+03, 0.27595200E+03, 0.79885900E+03, 0.37611400E+03, 0.22130400E+03, -.69364300E+02, -.29677800E+02, 0.12225700E+02, -.20058200E+02, 0.24498300E+02, 0.14289500E+02, 0.33054900E+02, 0.82289000E+01, 0.36939800E+02, 0.34477500E+02, -.19038900E+03, 0.35016400E+01, -.17003500E+03, 0.17605700E+03, -.47117900E+02, 0.97194500E+02, -.16989100E+03, 0.10138000E+03, -.17420600E+03, 0.12827000E+03, -.26904200E+03, -.36422300E+02, 0.42414300E+02, -.31768300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.25779300E+01, -.13762100E+01, -.20294800E+00, 0.51622700E+00, 0.19187000E+01, -.18162700E+00, -.27787900E+00, 0.11073000E+01, -.15649500E+00, -.49360000E+00, -.54888900E+00, -.81489300E-01, 0.46762700E+00, 0.12371900E+01, -.36830100E-01, -.18384300E+00, 0.38551100E+00, 0.13470000E+01, -.88980500E-01, 0.24357600E+00, 0.11235800E+01, -.28234400E+00, -.32468300E+01, 0.15555300E+01, 0.10323700E+00, -.42463400E+00, 0.22194900E+00, 0.28693600E+00, -.79615600E+00, -.83546500E+00, -.16106400E+00, 0.15400400E+00, -.29312000E+00, 0.55430000E+00, -.40769300E-01, 0.46719000E+00, -.11387900E-01, -.22579400E+00, -.26756500E+00, 0.21466100E+00, 0.41305100E-01, 0.67988700E+00, -.24976100E+01, 0.58936900E+00, -.39082800E+00, -.17143900E+00, -.75641400E+00, -.14925300E+00, -.11195700E+00, -.49005600E-01, -.48072500E+00, -.32289300E+00, -.75921700E-01, 0.28084100E+00, -.53349600E+00, -.34661700E+00, -.41413300E-01, -.25040600E+00, 0.93036900E-03, 0.45996100E+00, 0.24435300E+00, 0.71780500E+00, -.19089700E+00, 0.15327700E+00, 0.14270500E+00, 0.33513200E-01, 0.30673000E+00, -.42077500E+00, -.61037000E-02, 0.45289600E-02, -.15016700E+00, -.16206200E+00, -.23658600E+00, -.44433100E-02, 0.25182500E+00, -.13678200E+00, 0.52668700E-01, -.25929000E+00, 0.55764700E+00, -.58314400E+00, 0.59246900E-03, -.70016500E+00, 0.13308400E+01, -.69248300E+00, -.31043200E+00, -.82102300E+00, -.62797400E+00, -.69110900E-01, 0.29603800E+00, 0.26547900E-01, -.11654000E+00, -.41759500E-01, -.37058100E+00, -.71342200E-01, -.50401700E+00, -.68642300E+00, 0.51501600E+00, 0.25880400E+01, 0.20908400E+00, -.20839200E+00, -.40999200E+00, -.12227500E+00, -.10386000E-01, -.26384500E+00, -.20338600E+00, -.11845700E+00, -.64086600E+00, -.38179300E+00, -.89323500E+00, 0.46093900E+00, -.12757300E+01, 0.80463000E-01, -.24665100E+00, -.33964700E-02, -.48470400E+00, 0.92824600E+00, -.30327800E+00, -.10230100E+00, 0.17420700E+00, 0.17290100E+00, -.62904900E+00, 0.41550800E+00, -.88317700E+00, 0.82492000E+00, 0.47680700E-02, 0.13445300E+00, -.24108400E+00, 0.45422600E+00, -.24529100E+00, -.76776400E-01, -.59219300E+00, 0.24264300E+00, 0.26461700E-02, -.24042400E-01, -.18906100E+00, -.40305000E-02, -.17393000E+00, -.12454700E+00, 0.44173900E-01, -.12894200E+00, 0.51238600E-01, -.13768800E+00, 0.14015200E-01, 0.75181900E-01, -.18250700E+02, -.13150400E+02, -.32532000E+01, 0.10989300E+03, 0.37872200E+01, 0.21063200E+03, 0.13826800E+03, 0.13419100E+03, -.10687200E+03, 0.24053600E+03, 0.31694500E+03, -.15732700E+03, 0.49672500E+02, -.15840700E+03, 0.49971600E+02, 0.61150900E+02, -.19777100E+03, 0.13249800E+03, -.12711400E+03, 0.76119800E+02, 0.96502500E+02, -.40283800E+03, 0.20012800E+03, 0.51019200E+03, 0.20165200E+03, -.10829000E+03, 0.38378100E+02, 0.14755600E+03, -.11192800E+03, 0.50715900E+02, 0.65366800E+02, 0.36030100E+02, -.57848800E+03, 0.28944200E+03, 0.17542600E+03, 0.28922900E+03, -.78092600E+02, -.25311300E+03, 0.62789400E+03, -.38808900E+02, 0.53326900E+03, -.36011600E+03, 0.17889000E+03, 0.62045900E+03, -.31172000E+03, -.26631500E+03, -.31023900E+03, 0.16463500E+02, 0.88084200E+01, -.10499600E+03, 0.82030200E+02, -.15203800E+03, -.15466800E+02, -.14559800E+03, 0.62915300E+03, -.31664500E+03, 0.10086600E+03, -.31457400E+03, 0.18682300E+02, 0.39399500E+03, -.95244600E+02, 0.11850400E+02, -.29794500E+03, 0.41882400E+03, -.22098500E+03, 0.89314400E+03, -.45101100E+03, -.37263400E+03, -.44677500E+03, 0.37596700E+02, -.44272800E+02, -.23257200E+03, 0.17516900E+03, -.24016400E+03, -.96536300E+02, -.29777900E+03, -.26724700E+03, 0.13342200E+03, 0.11086400E+03, 0.13361800E+03, 0.41196400E+02, 0.66486600E+02, 0.77757800E+02, -.95249800E+00, 0.53545900E+02, 0.62562500E+02, 0.12688100E+03, 0.91873300E+03, -.45759400E+03, -.11265100E+03, -.45945700E+03, 0.49655200E+02, 0.18720700E+03, -.34665400E+03, -.85247800E+02, -.33520200E+03, 0.10512700E+03, -.50368100E+03, 0.21148200E+03, -.10761500E+03, -.17799200E+03, -.10586700E+03, -.68464500E+02, -.47291600E+02, -.22451300E+03, -.24069300E+03, -.26634600E+03, 0.89999400E+01, -.31280400E+03, 0.48138700E+02, -.17945300E+02, -.19229900E+01, -.22670400E+02, 0.61349700E+01, -.97512500E+01, 0.14548400E+02, 0.15747900E+02, 0.18754100E+02, 0.21237000E+01, -.25584900E+02, -.33919400E+02, 0.24999000E+00, -.76653400E+01, 0.94794800E+02, -.17735100E+02, -.29737300E+02, -.56521400E+02, -.15525100E+01, -.14070700E+02, -.38159100E+02, -.11426500E+02, 0.26173400E+02, -.49654500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24117000E+01, 0.27658600E+00, 0.11670700E+01, -.14749500E+01, -.59566500E+00, 0.21882000E+00, 0.14266600E+00, -.82994200E+00, 0.45762000E-01, 0.30457600E+00, 0.35632600E+00, -.13841100E+00, -.79728100E+00, -.15151100E+01, 0.76707000E-01, -.65494400E-01, -.73262000E+00, 0.27102100E+00, 0.53686300E+00, -.30638000E+00, -.35871600E+00, 0.86826100E-01, -.85136700E+00, 0.16260400E+00, -.15361900E+00, -.60239900E-01, -.11805200E+00, -.28579500E+00, -.52305500E+00, 0.10638000E+01, -.10237000E+00, -.28695700E+00, 0.31112500E+00, -.28010300E+00, -.42468100E-01, -.80463000E+00, 0.90004600E-02, -.34298700E+00, -.36000600E-01, -.19790300E-01, 0.29020600E+00, 0.58479600E+00, 0.41378500E+00, 0.31200100E+00, 0.84425500E-02, -.11472400E+01, 0.68111300E+00, -.18849800E+00, 0.11277700E+00, 0.38460300E+00, 0.76866400E+00, 0.13582800E+00, -.12739900E-01, 0.45485600E-01, 0.32253900E+00, -.43319500E-01, -.41584300E-02, -.76995800E+00, 0.17541700E-02, 0.23058900E-01, 0.41998300E+00, 0.36314100E+00, 0.17364600E-01, 0.17959500E+00, 0.80519500E+00, -.60208800E-01, -.34973000E+00, 0.82928400E-01, 0.12330600E+00, 0.55815800E-02, 0.19913000E+00, 0.27897100E+00, -.48860400E+00, 0.21559300E+00, -.60579400E+00, -.66870800E-01, -.18396700E+00, -.53900800E+00, -.26765000E+00, 0.22782300E+00, -.62894500E-03, 0.73052700E+00, -.40915300E+00, -.21135400E+00, -.12476700E+00, -.71673600E+00, 0.10691100E+01, -.69637200E-01, 0.92154500E-01, 0.16038700E+00, -.60844400E-01, -.54197200E-01, 0.86323100E+00, 0.16327100E+01, -.12286700E+01, -.34506100E+00, 0.47497000E+00, -.78469900E+00, -.62612700E+00, 0.52264700E-01, 0.20650100E+00, 0.10539600E+00, -.77329000E-01, 0.28410200E-01, 0.31789800E+00, 0.26316000E+00, 0.97849900E+00, -.38868900E+00, 0.43346000E+00, 0.50010500E+00, -.78904100E-01, 0.31807700E-01, 0.41023600E-01, 0.58469700E-02, -.72007100E-01, 0.51853300E+00, -.45257000E+00, -.13008700E+00, -.26117900E-01, 0.91691800E+00, 0.29717000E+00, -.42061900E+00, 0.38600800E-01, -.15000100E+01, -.10315400E-01, 0.70432300E+00, -.23469300E+00, -.15847200E+01, -.33874900E+00, -.81473100E-01, -.42792000E+00, -.23457300E+00, -.55551100E-01, 0.39663000E-01, 0.45296900E+00, -.52898100E-02, 0.46191800E+00, 0.35648100E+00, -.95843900E-02, 0.13511600E+00, -.19838400E+00, -.68663900E-01, 0.12276900E+00, -.16541400E-01, -.35127100E+00, 0.20976400E+03, -.28714100E+01, 0.17654400E+03, 0.30265200E+03, -.13159900E+02, 0.14118300E+03, 0.27122200E+02, 0.22503900E+03, 0.31869300E+03, 0.43967600E+03, -.22127400E+03, -.22913100E+03, -.21903600E+03, 0.11305400E+03, 0.97048400E+01, -.24407800E+03, -.28185100E+02, -.10947000E+03, -.38613900E+02, -.23010600E+03, 0.84838700E+03, -.42616000E+03, -.48606600E+02, -.42369900E+03, -.17245900E+03, 0.10182200E+02, -.62201100E+02, -.21516400E+03, -.42335500E+03, 0.12835000E+00, -.24187300E+03, -.51280800E+03, 0.25718400E+03, 0.27847100E+03, 0.25629000E+03, -.16881200E+03, -.17361300E+03, 0.59876800E+03, 0.19451200E+03, 0.41766300E+03, -.13195600E+03, 0.16684700E+03, -.46830900E+03, 0.23810800E+03, 0.18290900E+03, 0.23399900E+03, 0.12012200E+03, 0.42999600E+02, -.44057500E+02, -.26173900E+03, 0.14556700E+03, 0.21142200E+02, 0.19983400E+03, 0.20130100E+04, -.99911500E+03, 0.77848300E+03, -.10060800E+04, 0.39341600E+03, 0.57241900E+03, -.56555500E+03, -.30137700E+02, -.84259000E+03, 0.62830200E+03, -.11663500E+04, 0.42613300E+03, -.20895100E+03, -.30542900E+03, -.21369600E+03, 0.16287900E+03, 0.78445600E+02, -.24400200E+03, 0.17647500E+03, -.90226100E+02, 0.25483000E+02, -.37175900E+03, -.11701800E+03, 0.59149400E+02, 0.10231800E+03, 0.58440700E+02, 0.11990400E+03, 0.15408400E+03, -.27782500E+02, -.23480600E+02, 0.54618600E+02, 0.12080600E+03, 0.28018500E+03, 0.10079300E+04, -.50165500E+03, -.31610700E+03, -.50468400E+03, -.12891500E+03, 0.42362200E+03, -.52404800E+03, -.43795300E+03, -.44510000E+03, 0.19476900E+03, -.37652000E+03, -.15888100E+03, 0.77318400E+02, -.61850300E+02, 0.79321900E+02, -.17529000E+01, -.11368900E+03, -.12824300E+03, -.99667000E+02, -.25589200E+03, -.43458000E+02, 0.82302700E+02, 0.65877900E+02, 0.42407400E+01, -.38374900E+02, 0.10822600E+02, 0.86459900E+01, -.10687400E+02, -.10278100E+02, 0.10960100E+02, 0.14574200E+02, 0.29259100E+02, 0.78192300E+02, -.37655300E+02, 0.28709700E+02, -.17921700E+01, 0.17935300E+03, -.42159200E+02, 0.10555300E+01, -.87231800E+02, 0.55846400E+01, 0.28045500E+02, -.25883000E+02, -.58852600E+02, 0.15096400E+02, -.62193900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13160400E+02, -.35117700E+01, -.14824300E+00, 0.91243000E+01, 0.63340700E+01, -.74597000E+00, -.13630600E+01, -.30550600E+01, 0.15314900E+01, 0.11960000E+00, 0.77219800E+01, 0.29009300E+01, -.13170200E+02, 0.12141200E+01, -.43650900E+00, -.10414300E+01, 0.26016500E+01, -.49346700E+01, -.14772800E+01, 0.20790900E+01, 0.68290200E+00, -.79429600E+01, 0.83635800E+01, -.51512200E+01, -.43093800E+00, 0.60717500E+01, 0.55987100E+00, -.14301100E+00, 0.19614300E+01, 0.13000900E+00, -.23819700E+01, 0.10310900E+01, -.24615500E+01, 0.96741100E+00, -.22843000E+00, 0.13200900E+01, -.12890000E+01, 0.32372900E+01, -.66538000E+00, -.25734400E+00, 0.15713400E+01, 0.10350100E+01, 0.15345300E+02, -.23083500E+01, -.48096400E-01, 0.33325400E+01, -.13302900E+01, -.60113600E+00, 0.30349500E+01, 0.58888600E+01, 0.32451500E+01, 0.28892900E+00, -.15430500E+00, 0.18787000E+00, -.17166000E+01, 0.10226400E+01, 0.43971600E+00, 0.18527400E+01, 0.72900000E-01, 0.23673300E+01, -.27546500E+00, 0.43179700E+00, 0.50344400E+00, 0.19215700E+01, -.58630600E+01, -.17169600E+01, 0.19886300E+01, -.66619000E+00, 0.10139600E+01, 0.40245700E+00, 0.17598100E+01, 0.37119500E+00, 0.10451500E+01, 0.86595500E-02, -.61589800E+00, -.35195300E+00, -.28249700E+00, -.15458200E+01, 0.22047900E+01, -.12487800E+01, -.60562700E-01, 0.13784000E+00, 0.24226500E+01, -.37293700E+01, -.15044200E+01, -.29731800E+01, 0.14579200E+01, -.11300200E+01, 0.41484200E+00, 0.69836600E-01, 0.13962900E+01, -.56844100E+00, 0.24438900E+01, 0.11759000E+02, -.84803100E+00, 0.64963500E+00, 0.30526800E+00, 0.99983700E+01, -.11353300E+01, -.24842000E+01, -.41265700E+00, -.10141600E+00, -.68248400E+00, 0.14848800E+00, -.18202100E+01, -.21067800E+01, 0.10846200E+01, 0.26652200E+01, -.44609700E+00, -.20706400E+01, -.62956000E+00, -.39754100E+00, -.60938400E+00, 0.44419500E+00, 0.84009100E+00, 0.27861400E+01, -.68001600E+00, 0.76065600E+00, 0.21947600E-01, -.49378900E+01, -.25545300E+01, 0.91608000E+00, 0.25851300E+01, -.86305500E+01, -.15090400E+00, -.11753500E+01, -.66320200E+00, -.44054100E+01, 0.51447600E+00, 0.12381400E+01, 0.12430800E-01, -.18242100E+00, 0.89383500E+00, -.72779200E-01, 0.33532400E+01, 0.58786200E-01, 0.19334600E+01, -.33438200E+01, -.34746800E+00, 0.27551300E+00, 0.46501000E+00, 0.55466600E+00, -.92451900E+00, 0.48587100E+00, 0.18718100E+01, 0.22162600E+01, 0.66893600E+02, -.56722800E+03, -.10375400E+04, 0.63426900E+02, 0.11772100E+03, -.12485000E+03, -.64692400E+03, -.13846300E+04, -.18192200E+04, 0.90485100E+03, 0.23885500E+03, 0.89181500E+03, -.41844100E+03, -.97751600E+02, 0.71139000E+03, -.73794800E+03, 0.37529300E+03, 0.18953800E+03, -.56484800E+03, -.21035600E+04, 0.10552500E+04, -.37488100E+03, 0.10573600E+04, 0.68026400E+03, 0.10049600E+03, -.21570000E+03, 0.63110400E+03, 0.99422700E+03, -.14309700E+02, 0.12897800E+04, 0.18962900E+04, -.94868900E+03, -.66275300E+03, -.94741200E+03, 0.13561300E+04, 0.56829600E+03, -.20951500E+04, 0.43939400E+03, -.15448300E+04, 0.76956200E+03, -.23118800E+03, 0.68345000E+03, -.35691100E+03, -.11514600E+04, -.34090500E+03, -.50723500E+03, -.41741400E+03, 0.25759300E+03, 0.92037200E+03, 0.25364200E+02, -.28567400E+03, -.30501300E+03, -.52241500E+04, 0.25860600E+04, -.11490600E+04, 0.25996900E+04, -.65243400E+03, -.21951200E+04, 0.10504800E+04, 0.13465900E+03, 0.24248400E+04, -.21363700E+04, 0.28246800E+04, -.20274200E+04, 0.10037000E+04, 0.13944400E+04, 0.10141300E+04, -.69656500E+02, -.41396700E+03, 0.12617900E+04, -.50069000E+03, 0.52938500E+03, 0.32075100E+02, 0.91168300E+02, 0.24580800E+03, -.12442600E+03, -.63399300E+02, -.12189400E+03, -.25987800E+03, -.56674800E+03, 0.57558900E+02, 0.53466100E+02, -.69584100E+02, -.42514500E+03, -.12018000E+04, -.48019000E+04, 0.23892200E+04, 0.16491000E+04, 0.24058500E+04, 0.38112800E+03, -.14796200E+04, 0.22285800E+04, 0.10890600E+04, 0.18071500E+04, -.78820500E+03, 0.15989900E+04, 0.19060400E+04, -.94263100E+03, -.17892400E+03, -.95750700E+03, -.29963800E+03, 0.10682600E+03, 0.57728200E+03, 0.61955800E+03, 0.36584300E+03, -.28494200E+03, 0.31602600E+03, -.27455300E+03, 0.51341700E+02, 0.89239200E+02, 0.36133600E+02, -.63722200E+02, 0.45831100E+02, -.14879500E+02, -.86878400E+02, -.10770700E+03, -.94811500E+02, -.14361200E+02, 0.19556000E+03, -.54173500E+02, -.10361500E+02, -.62533900E+03, 0.12378700E+03, 0.92648700E+02, 0.27197100E+03, 0.45264800E+02, -.42190700E+02, 0.12908700E+03, 0.21527700E+03, -.12007500E+03, 0.31286000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19429600E+01, 0.28102700E+00, 0.24506700E+00, -.10782800E+01, -.18572200E+01, -.19405800E+00, 0.24432600E+00, -.80609700E+00, 0.31144200E+00, -.23712900E+00, -.36026300E+00, 0.22856900E+00, -.27687400E-01, -.17508600E+01, 0.50948000E-01, 0.18930900E+00, -.79066800E+00, 0.67634900E+00, -.71724300E-02, -.39183500E+00, 0.76539400E+00, 0.18423900E+01, 0.32655300E+00, -.19195900E+00, 0.31465300E-01, -.31624700E+00, 0.29355200E+00, 0.22523000E+00, 0.14686900E+00, 0.19092500E+01, 0.89204200E-01, -.27483800E+00, 0.10717800E+01, -.52180000E+00, 0.78738700E-01, -.14021500E+01, 0.27934400E-01, -.37182300E+00, 0.25766300E+00, -.46241000E-01, -.15831500E+00, -.43458100E+00, -.17851000E+01, 0.18304600E+00, 0.21437600E-01, -.27642300E+00, -.31835000E+00, -.96926500E-01, -.26037200E+00, -.75138600E+00, 0.53154700E+00, 0.13165900E+00, 0.10724100E+00, 0.17843100E+00, -.16092600E-01, -.24258100E+00, -.35204000E-01, 0.68757600E+00, 0.14449400E-03, 0.56334400E+00, 0.57060000E+00, 0.18064900E+00, 0.89871800E-01, -.42201400E+00, 0.78364300E+00, -.11758900E+00, -.75463700E+00, -.18554200E-01, -.50791700E+00, 0.33215300E-02, -.18091500E-01, -.77451000E-01, -.67922600E-01, 0.40577200E+00, 0.16516800E+00, -.13654600E+00, -.17397400E+00, -.13064800E+00, -.31147500E+00, -.47667300E-01, -.17157400E-03, 0.47053600E+00, -.84942300E-01, -.50106700E+00, -.13015100E+00, 0.30729200E+00, 0.28387200E+00, -.86804700E-01, 0.16428400E+00, 0.38262300E-01, -.62626300E+00, -.25981800E-01, -.28700800E-02, -.59457900E+00, -.10516500E+01, -.17030500E+01, 0.29563900E+00, 0.15611900E+01, -.28314100E+00, 0.11624600E+00, 0.23175700E+00, 0.33482100E-01, -.73998600E-01, -.51274200E-01, 0.49586800E+00, 0.47131200E-01, 0.32134000E+00, 0.49094800E+00, -.46875400E-01, -.28540600E+00, -.81291000E+00, 0.14371000E-01, 0.80243400E-01, -.16266500E-01, -.21463100E+00, 0.45968700E+00, -.36201800E+00, 0.24974800E-01, -.13573200E+00, 0.41899900E+00, 0.13473700E+00, -.32464800E+00, -.37615700E+00, 0.10852500E+01, 0.11007900E-01, 0.99333800E-01, -.43585800E+00, -.92441100E+00, -.85230500E-01, -.81438400E-01, -.23844200E+00, 0.39950700E-01, -.13262900E+00, -.18023000E-01, -.98194000E-01, -.68501900E-02, -.59552700E+00, -.29695700E+00, -.92339300E-02, 0.37572900E-01, -.11901200E+00, -.33580600E-01, 0.16376400E+00, -.97429800E-01, 0.38308600E+00, 0.33726100E+00, -.73879400E-03, -.12476800E+03, -.69307500E+00, -.96489500E+02, -.22199400E+03, -.36463100E+02, 0.23408700E+02, -.43020900E+02, 0.87385900E+02, -.45037700E+02, -.50116500E+02, -.43536100E+02, 0.93340100E+02, 0.87582000E+02, -.16459500E+03, -.41903300E+02, -.79423600E+02, 0.34211200E+02, 0.81873500E+02, -.64888200E+02, 0.32046800E+02, -.63069500E+01, 0.32568500E+02, 0.12731600E+02, -.19638200E+02, 0.14675000E+03, 0.58848100E+02, 0.11290600E+03, -.20977800E+02, -.72287700E+02, 0.10889000E+03, -.53947100E+02, -.33513500E+02, -.54467600E+02, -.17144500E+03, 0.67719700E+02, -.48537900E+02, -.66061800E+02, -.77331900E+02, 0.10954000E+03, -.11903100E+03, 0.17241600E+03, -.86628700E+02, 0.85914600E+02, -.86240500E+02, 0.95422500E+01, 0.48328500E+01, -.70023500E+02, -.41850400E+02, -.43226700E+02, -.76920300E+00, -.34936700E+02, -.35267700E+02, 0.15989400E+02, 0.32940000E+03, 0.17711200E+02, 0.27282500E+03, 0.29685900E+02, 0.52260900E+02, 0.30447500E+03, 0.82727300E+02, 0.23233500E+02, 0.50002600E+02, -.16238700E+03, 0.84059200E+02, -.64544000E+02, 0.81046000E+02, 0.14858100E+01, 0.16431700E+02, -.33063600E+02, -.52614900E+02, -.25634500E+02, 0.20077100E+02, 0.14724100E+03, -.11363000E+03, 0.56301400E+02, 0.83144100E+02, 0.56801800E+02, 0.46876300E+02, 0.17049500E+02, 0.30034800E+02, 0.12037400E+02, 0.20249400E+02, 0.13062300E+02, 0.83135000E+02, 0.29863100E+03, -.14861100E+03, -.37891100E+03, -.14946600E+03, -.85739600E+02, 0.27581100E+02, -.12634100E+03, -.18608700E+03, -.89855600E+02, 0.63021800E+01, -.73598400E+02, -.15607900E+03, 0.78496300E+02, -.41146700E+01, 0.77999000E+02, 0.59159400E+02, -.34531800E+02, 0.70943000E+02, 0.84710700E+02, 0.47043700E+02, -.38825600E+02, -.37233200E+02, -.31698300E+01, 0.12437800E+02, -.77039100E+01, 0.13518600E+02, -.89977600E+01, 0.50896100E+01, -.10288000E+02, -.11017100E+02, -.10842400E+02, -.58639700E+01, 0.31582400E+02, 0.96420400E+01, 0.11922200E+02, -.13389400E+02, -.21737500E+02, 0.11953000E+02, 0.68517800E+00, 0.15554800E+02, 0.63381700E+01, -.31190800E+02, -.11305900E+02, 0.28269800E+01, -.43232900E+02, 0.43703100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24081700E+01, -.23512300E-01, 0.74458900E-02, 0.31802100E+00, 0.58512800E+00, 0.18360300E+00, -.17207900E+00, 0.57200300E+00, 0.34396700E-02, -.34280300E+00, -.30022200E+00, 0.76844200E-01, -.10131200E+01, -.39175100E+00, 0.37651900E-01, -.73607300E-01, 0.44980600E+00, 0.39619600E-01, -.42700300E-03, -.31959300E-01, 0.21043700E+00, -.12722100E+01, -.13375700E+01, 0.45829900E+00, -.14653900E+00, 0.29722500E+00, -.24974600E+00, -.45257800E+00, -.50300200E+00, 0.45950600E-01, -.69048800E-01, 0.18681500E+00, -.46491700E+00, 0.15966900E+00, -.11924300E+00, 0.21734000E+00, -.24270700E-01, 0.22842300E+00, 0.14517900E+00, 0.12994900E+00, 0.78517200E+00, 0.71932100E+00, -.50883300E+00, 0.40738800E+00, -.40762300E+00, 0.11739600E+00, -.33194300E+00, -.21096300E+00, -.18822500E-01, 0.62078700E+00, -.20504100E+00, -.15513300E+00, -.19382200E+00, 0.28972500E+00, -.46554800E+00, -.13469200E+00, -.15161300E+00, 0.37774200E+00, 0.72297600E-03, 0.59661300E+00, 0.76363200E-01, 0.48001200E+00, -.80259100E-01, 0.46329200E+00, -.12897200E+01, -.82990300E+00, 0.28435200E+00, -.17275700E+00, 0.35701600E+00, 0.40830700E-02, 0.16714700E+00, 0.22732600E+00, 0.28610000E+00, 0.87069500E-02, -.51992300E-01, -.91739800E-01, 0.43955100E-01, -.38920100E+00, 0.27302000E+00, -.21722900E+00, -.30695000E-03, 0.30969400E-01, 0.35368600E+00, -.66430700E+00, -.23527500E+00, -.23966400E+00, 0.25513500E+00, 0.11075500E+00, 0.22523700E+00, -.79077200E-01, 0.72878800E-01, -.14663400E-01, 0.18840500E+00, 0.43438200E-01, -.13170700E-01, -.32438500E+00, 0.16913900E+00, -.42246000E-01, -.76673500E+00, 0.13678200E+00, -.42005400E+00, -.37092800E-01, -.11186500E+00, -.13895600E+00, 0.80766500E-01, 0.19814900E+00, 0.97589900E+00, 0.11165600E-02, 0.43395700E+00, -.20794100E+00, 0.23144600E+00, 0.22115400E-01, 0.30388000E-01, 0.11057200E-03, -.18217000E+00, 0.22549400E+00, 0.13644000E+00, -.12823200E+00, -.62096100E-01, 0.80670900E+00, -.21338500E+00, 0.11810600E+00, -.82686400E-02, -.32782700E+00, -.98249300E-02, 0.30178700E+00, -.18067900E+00, -.44010500E+00, -.81498800E-01, 0.55320700E-01, 0.51716900E-01, -.13129400E+00, 0.10087800E+00, -.11602600E-01, 0.48638400E+00, 0.20132000E-02, 0.63180000E+00, -.47573700E+00, -.32042400E-01, 0.96455200E-01, -.19541500E+00, 0.17770500E-01, -.39038100E-01, 0.18468000E+00, 0.12648900E+00, 0.73966100E+00, 0.20048900E-01, 0.53273500E+00, -.22528200E+03, 0.12086500E+03, 0.15305300E+03, -.10935700E+01, -.21508400E+03, -.16057800E+03, -.35362200E+03, 0.17692800E+03, 0.11388300E+03, 0.17668600E+03, -.12453800E+03, 0.60936500E+01, 0.93821200E+02, -.15209200E+03, 0.42973200E+02, 0.86959900E+02, -.12142400E+03, -.45389800E+03, 0.22708800E+03, 0.83276100E+02, 0.22651800E+03, 0.75221300E+02, 0.10292300E+02, -.16258500E+02, 0.31976900E+02, 0.13141700E+03, 0.76837600E+01, 0.23850600E+03, 0.45955600E+02, -.23112200E+02, -.89212100E+01, -.22923700E+02, 0.34986300E+03, -.64306700E+02, -.94949700E+02, 0.14493500E+03, -.83843900E+02, -.92772200E+02, 0.68643200E+02, 0.36450000E+03, -.18451100E+03, -.30951200E+03, -.18217200E+03, -.70591700E+02, -.55078700E+02, 0.38403000E+02, 0.24734800E+03, -.71083700E+02, -.44357800E+02, -.13853700E+03, -.87205200E+03, 0.43254500E+03, -.15806100E+03, 0.43602500E+03, -.22132100E+03, -.23082700E+03, 0.11970500E+03, -.15741600E+03, 0.30347600E+03, -.24157300E+03, 0.61611400E+03, -.10383700E+03, 0.49560000E+02, 0.22979300E+03, 0.52307100E+02, -.15762200E+02, -.54393800E+02, 0.89885400E+02, -.68653300E+02, 0.53180800E+02, -.85792100E+01, -.61567600E+02, -.19890700E+02, 0.95123400E+01, -.31535000E+02, 0.99660400E+01, -.60269500E+02, -.94253800E+02, 0.39847000E+02, 0.33278800E+01, 0.10829000E+02, -.73547200E+02, -.18195400E+03, -.36185800E+03, 0.17876800E+03, 0.40153100E+03, 0.18126900E+03, 0.14549400E+03, -.20010500E+03, 0.29119300E+03, 0.32226800E+03, 0.18778000E+03, -.63249000E+02, -.54492000E+02, 0.41873500E+03, -.20835700E+03, -.33016200E+02, -.20919200E+03, -.11273000E+03, 0.15240500E+02, 0.91945100E+01, 0.88650000E+01, 0.22583000E+02, -.32128900E+02, -.22606700E+02, -.41328800E+02, -.60962300E+01, 0.25494900E+02, -.12877700E+02, -.66224100E+01, -.21250600E+01, 0.10844800E+02, -.79854400E+01, -.12982700E+02, -.13131400E+02, -.16892100E+02, 0.26351700E+02, -.24650600E+02, 0.37459000E+01, -.10215000E+03, 0.12337700E+02, 0.14239000E+01, 0.31171600E+02, -.47616700E+01, -.14155300E+02, 0.24086000E+02, 0.36151900E+02, -.25934000E+01, 0.53557800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45291400E+01, 0.99425400E+00, 0.49894000E+00, 0.62312600E-01, -.22039900E+01, 0.42348300E+00, 0.54468800E+00, 0.29932800E+00, -.80505700E+00, 0.59786000E+00, 0.16829600E+01, 0.72156100E+00, 0.12709100E+01, 0.10976500E+01, -.19951600E+00, -.13589200E+00, 0.15985300E+00, 0.59196800E+00, 0.50858100E+00, -.66341800E+00, -.15902400E+01, 0.29922500E+00, 0.85024100E+00, -.10889200E+01, -.26684900E-01, 0.73706000E+00, 0.11466700E+00, -.77806600E-01, 0.34971200E+00, 0.46593800E+00, 0.18293300E+00, 0.23111300E-01, -.80522800E+00, -.98379300E+00, -.46958000E-01, 0.79334500E+00, 0.13151600E-01, 0.37224700E+00, 0.69503100E-01, 0.20973600E-01, 0.33669100E+00, -.51054100E+00, 0.20695500E+01, -.97450400E-01, -.77854900E+00, -.51918100E+00, -.11059700E+01, 0.28686200E-01, -.11603500E+00, 0.26462000E+00, -.32030200E-01, 0.33677900E+00, 0.23014100E+00, -.57102900E+00, 0.53587700E+00, -.39172600E+00, 0.44200200E+00, 0.10351100E+00, 0.36780100E-03, -.40542400E+00, -.59929200E+00, -.14814600E+00, -.93809200E-01, -.49415700E+00, 0.10902000E+00, 0.75277900E+00, 0.41063000E+00, -.45251300E+00, -.21251600E+00, -.27264300E-02, 0.22213400E+00, -.50123300E+00, 0.14933600E+00, 0.30539000E+00, 0.71607400E+00, -.17134800E+00, -.45778000E+00, -.40108300E+00, -.13305900E+01, 0.36566000E+00, -.69273600E-03, 0.96178900E+00, -.11644600E+01, 0.33231900E+01, 0.17587000E+00, -.14550400E+00, 0.56103200E+00, -.27495800E+00, -.44573900E+00, 0.22489800E+00, -.59849000E+00, -.48578700E-01, -.72819700E-01, 0.73392800E+00, -.12573100E+01, -.22917300E+01, 0.45132300E-01, 0.11837300E+01, -.10015400E+01, 0.40655300E+00, -.91944600E+00, -.38774400E-01, -.23014200E+00, -.19294200E+00, -.10582600E+01, 0.64568800E+00, 0.80016100E-01, -.76329700E-01, -.38960500E-01, 0.46606700E+00, -.23126000E+00, 0.99467100E-01, -.97145300E-01, -.11656300E-01, -.47357300E+00, 0.62084500E+00, -.77163700E+00, -.14748500E+00, -.34561200E-01, -.73772900E+00, -.33879400E+00, 0.86889900E+00, 0.50450300E+00, 0.98447500E+00, 0.12804700E-01, 0.22336800E+00, -.48598600E+00, -.50460100E+00, 0.46858200E+00, -.21355600E+00, 0.40751500E+00, -.66240200E+00, 0.42438000E-01, 0.13447700E+00, 0.30327100E+00, 0.39900900E-02, -.94775300E+00, -.20011000E+00, -.96413300E-01, -.14145900E+00, -.22140100E+00, 0.48332500E-01, 0.44778400E+00, 0.26396100E+00, 0.62545400E+00, 0.36918100E+00, 0.60657600E-01, -.12875900E+00, 0.16786400E-02, -.29278100E+03, -.13857500E+03, -.12009200E+03, 0.53943700E+01, -.10486100E+03, -.12218700E+03, 0.61586200E+02, 0.16053300E+03, 0.62155100E+02, -.10431500E+03, -.12854300E+02, 0.20329400E+03, -.21073500E+03, -.10163800E+03, 0.14624000E+02, -.52430000E+03, -.25221400E+03, 0.12920000E+03, -.21511600E+03, 0.12556900E+03, -.34315600E+02, -.11058600E+03, 0.45296600E+02, 0.11432800E+03, -.43256300E+02, -.11061600E+03, 0.43742000E+03, 0.49468400E+02, -.25365500E+02, -.78261900E+02, -.24769300E+02, 0.18442900E+03, 0.18094700E+03, -.64234100E+03, 0.76192600E+02, -.17221800E+03, 0.22676200E+03, 0.71429400E+02, -.30949200E+03, 0.15201900E+03, 0.77561500E+02, 0.15469600E+03, 0.25306700E+02, 0.31728800E+01, 0.14341300E+02, -.75879200E+02, 0.11396300E+03, 0.11714000E+02, 0.28826500E+03, -.79423100E+03, 0.39762700E+03, 0.62416200E+03, 0.39788800E+03, 0.32487000E+03, -.44273200E+03, 0.50915000E+03, 0.34490500E+03, 0.35543300E+03, -.45559500E+03, 0.37233000E+03, -.64916900E+02, 0.27181300E+02, 0.24667000E+03, 0.32591700E+02, -.14223800E+03, 0.49373600E+01, 0.11543900E+03, -.58599600E+02, 0.11568900E+03, 0.58921500E+02, -.34678600E+03, -.46616700E+03, 0.23415300E+03, 0.29610800E+03, 0.23302400E+03, 0.14443000E+03, -.37255100E+02, 0.17064000E+03, 0.59819300E+02, 0.17213800E+03, -.63829400E+01, -.87199200E+02, 0.14050200E+03, -.72462000E+02, -.23579500E+03, -.70502300E+02, 0.57852100E+02, 0.15138400E+03, -.14655200E+03, -.24856600E+02, -.99914800E+02, 0.21034100E+03, -.17445200E+03, 0.35469700E+03, -.17687900E+03, -.19403400E+03, -.17696300E+03, -.10230200E+03, 0.13693000E+02, -.10040900E+03, -.85730600E+02, -.40420200E+02, 0.18489100E+02, 0.27239900E+03, -.24557000E+02, 0.28452700E+02, 0.76639000E+00, 0.22632500E+02, -.12939000E+02, 0.24057700E+02, -.24628200E+02, -.16539500E+02, -.29252300E+02, -.27436700E+02, 0.20626300E+02, 0.31261500E+02, 0.74324300E+02, -.73338000E+02, -.84982800E+02, -.66868600E+01, 0.91189600E+02, 0.32550300E+02, 0.76217100E+02, -.19065800E+02, 0.15255100E+03, 0.52933800E+02, -.14491300E+02, 0.66490900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.84814200E+01, 0.14176800E+00, 0.46757200E+01, -.64400500E+01, -.62854500E+01, -.13184900E+01, 0.12926200E+01, -.35123200E+01, 0.11056500E+01, 0.93087200E+00, 0.12789400E+00, -.58676200E+00, 0.20245200E+00, -.28518800E+01, 0.21795500E-01, 0.22635200E+00, -.15700300E+01, -.18594300E+01, 0.22942100E+00, 0.80586700E+00, -.91982700E+00, 0.33852200E+01, 0.40262600E+01, -.16629400E+01, -.45539500E-01, -.42104000E+00, -.30592000E+00, -.41432600E-01, 0.70811200E+00, -.26503500E+01, -.21128400E+00, -.57029100E+00, 0.81829200E+00, -.22193900E+00, 0.40197400E+00, -.14337300E+01, 0.35292800E-01, 0.24384200E+00, -.22165500E+00, -.10645800E+01, -.18829400E+01, 0.40740000E+00, 0.64621100E+01, -.11783100E+01, 0.24826900E+01, -.21572700E+01, 0.93164000E+00, 0.24524600E+00, 0.80412400E+00, 0.60606500E+00, -.29804700E+00, -.90609500E+00, -.87275700E-01, -.10309000E+01, 0.83479600E+00, 0.17689900E+01, 0.20106400E+00, -.48982700E-01, 0.61798300E-02, -.32390000E+01, -.97718700E+00, -.26928900E+01, 0.72330000E+00, 0.82322200E+00, -.54804000E+00, 0.76790500E+00, -.96064900E+00, 0.29081700E+00, 0.39515700E+00, -.57958900E-02, -.55953700E+00, -.11757800E+00, -.46337200E+00, 0.32263700E-01, -.45640900E+00, 0.93591500E-01, 0.85090200E+00, -.88828000E+00, 0.24306600E+01, -.17511600E+00, 0.99527100E-03, -.16034300E+01, 0.13593500E+01, -.90166800E+00, 0.26376700E+00, -.12022100E+01, 0.11707500E+01, -.10692400E+01, -.11708000E+01, -.66711800E+00, 0.10489500E+01, -.68723200E-01, 0.18526500E+01, 0.32531600E+01, -.42174100E+01, -.18853800E+01, 0.48253300E+00, 0.79786800E+00, -.11057600E+01, -.12620900E+00, 0.14203900E+01, 0.39403000E+00, -.20195400E+00, 0.22844700E+00, -.72062600E+00, 0.20948400E+01, 0.10938500E+01, 0.83691700E+00, 0.10925300E+00, 0.33052600E+00, -.55513500E+00, 0.79168900E-01, 0.19928100E+00, -.47204400E-02, -.50069600E+00, -.39579400E+00, -.43896000E+00, -.13293400E+00, -.12498500E-01, 0.13183800E+01, -.60801800E-01, 0.17653900E+01, -.32622900E+01, 0.60842800E+01, 0.15656100E-01, 0.11702700E+01, -.10411800E+01, -.33664000E+00, -.12191100E+01, 0.66508400E+00, -.34691300E+00, -.15118000E+01, 0.46235800E+00, 0.19938500E+00, -.81959000E+00, -.13304600E-01, -.13658700E+01, -.11632400E+00, -.56054300E+00, -.24509200E+00, 0.76570400E+00, 0.54292000E+00, 0.27888000E+00, -.49839800E+00, 0.10866800E+01, -.20006600E+01, -.58235600E-01, 0.30169500E+01, -.17565000E+01, -.21589200E+01, 0.67309600E+03, 0.10831100E+03, 0.12333200E+03, -.37602300E+01, 0.36935800E+03, -.16917100E+03, -.41397200E+02, -.18151300E+03, -.86845200E+02, 0.23936100E+02, 0.77417400E+02, -.25650100E+03, -.24453100E+03, -.17728800E+03, -.68584400E+03, 0.44998500E+04, -.22310200E+04, -.22375500E+04, -.22509700E+04, -.35343600E+03, -.48196000E+03, -.95327100E+03, 0.15840500E+03, -.14203800E+04, -.49142300E+03, -.82878100E+03, 0.47511200E+03, -.24831600E+03, -.36348000E+03, -.23777800E+03, -.14366400E+03, -.16302100E+03, -.37740500E+03, 0.33879500E+03, 0.43278500E+02, 0.17230400E+03, 0.23111200E+03, -.12449500E+04, 0.62167300E+03, 0.61746500E+03, 0.62213500E+03, 0.69615900E+02, 0.29283900E+02, 0.13487900E+03, -.38762700E+03, 0.21308000E+03, 0.10517800E+03, 0.23195000E+03, 0.16127800E+04, -.79088500E+03, 0.20214700E+04, -.80419200E+03, 0.34703900E+03, 0.12385500E+03, -.58468200E+03, -.64375000E+03, -.74890300E+03, 0.43639700E+02, -.83215900E+02, -.57389500E+03, 0.28654000E+03, 0.98529100E+03, 0.28689100E+03, -.32229200E+03, 0.53406300E+03, -.22695800E+03, -.23398400E+03, 0.39455200E+03, 0.40610700E+03, -.61470800E+03, -.54532900E+03, 0.28320100E+03, 0.38062200E+03, 0.27244700E+03, 0.18268200E+03, 0.28675600E+03, -.88091000E+00, -.14361100E+03, 0.29560800E+03, 0.23335700E+03, 0.31638800E+03, 0.16031600E+04, -.82156400E+03, 0.53071500E+03, -.80301800E+03, -.30994800E+02, 0.12013800E+04, -.92397100E+03, -.52387000E+03, -.10111100E+04, 0.92851600E+03, -.13220300E+04, -.56351800E+03, 0.28871400E+03, 0.44889100E+01, 0.28279400E+03, -.51069200E+02, 0.47955700E+02, -.33020900E+03, -.28664900E+03, -.10244200E+03, 0.19723100E+03, 0.92981700E+03, 0.74912900E+02, 0.19184000E+02, -.31690700E+02, 0.25892600E+02, 0.20407400E+02, 0.65760100E+01, -.36591000E+02, 0.13943600E+01, 0.22424600E+01, 0.34733100E+02, 0.99012100E+02, -.35780100E+02, 0.73288200E+02, -.58524700E+02, 0.55696500E+02, -.82631600E+02, 0.10239300E+03, -.26820300E+02, 0.63309800E+02, 0.87888500E+02, 0.26188100E+03, -.68475200E+02, 0.12732800E+03, -.17547200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.43501400E+01, -.83292600E+00, 0.29565600E+01, 0.11148700E+01, 0.38261800E+01, 0.21137700E+00, -.82354200E+00, 0.84032000E+00, 0.60967200E+00, 0.53887700E+00, 0.47141400E+01, 0.59127500E+00, -.45098500E+01, -.21440100E+01, -.28677500E+00, -.95324000E+00, 0.20792400E+00, -.13490800E+00, -.66888800E-01, 0.13473700E+01, -.66886100E+00, -.85630600E+00, -.96156500E+00, 0.20667200E+00, -.56754300E-01, 0.63769600E-01, -.28972900E+00, -.23587200E-01, 0.23294400E+00, -.14608000E+01, 0.50308300E+00, 0.10290100E+00, -.11534600E+01, -.44382700E+00, -.68454500E-02, 0.12097000E+01, -.12436300E-01, 0.60585700E+00, -.79869200E-01, 0.39977700E+00, 0.89519200E+00, -.28819900E+00, 0.11218400E+01, -.11452100E+00, -.47173400E+00, 0.48850800E+00, 0.22424300E-01, 0.97304900E-01, 0.75655000E-01, 0.11891000E+01, 0.12212400E+01, 0.14715700E+01, 0.46332300E-01, -.12991100E-01, -.47378800E+00, -.11174700E+01, 0.47078100E+00, 0.47404000E+00, 0.17254600E-02, 0.65093400E+00, 0.36186100E-01, 0.10140000E+00, 0.10806400E+00, 0.89485000E+00, -.46335900E-01, 0.29550700E+00, 0.52717500E-01, 0.13291500E+01, -.17689300E+00, -.46438600E-02, 0.13867100E+00, -.21337400E+00, -.11100200E+00, -.21499700E+00, 0.51553900E+00, -.15807700E+00, -.47540400E+00, -.43479200E+00, -.15140900E+01, 0.34327000E+00, 0.10126400E-02, 0.29723900E+01, -.13472200E+01, 0.89866700E+00, -.11689800E-01, -.69993300E+00, 0.40449800E+00, 0.31529200E+00, -.20959400E+00, 0.48367100E+00, -.63050500E+00, 0.75504000E-01, 0.87116500E+00, -.12441800E+01, -.30185800E+01, -.33667500E+01, 0.18035900E+00, 0.22955800E+01, -.55514900E+00, -.67250200E-01, 0.27098000E+01, 0.37444300E+00, 0.15184100E+00, -.18767800E+00, 0.15685900E+01, -.51515400E+00, -.31988400E+00, 0.56890600E+00, -.20806500E+00, -.45963400E+00, -.26150800E+00, -.42816500E-01, 0.14008500E+00, -.22564200E-01, 0.15193800E+00, -.38668000E+00, -.31368900E+00, 0.31195500E+00, -.93919300E-01, 0.65520700E-01, -.77170000E+00, 0.12639300E+01, 0.18749600E+01, 0.12480600E+01, 0.34381700E-01, 0.34519300E+00, -.22284100E+00, -.93450900E+00, 0.11453300E-01, 0.28132100E+00, 0.16096500E+00, -.11252000E+00, 0.70661500E+00, -.31279200E+00, 0.59636100E+00, -.13305100E-01, 0.74976000E+00, -.14585200E+00, 0.67190300E-01, -.92811200E-01, 0.44285500E+00, -.32998000E+00, 0.15793600E+00, -.60261900E+00, -.73123700E+00, -.10704700E+01, -.15164500E+00, 0.41543200E+00, -.14351000E+01, -.11029300E+01, 0.43681000E-01, 0.20496800E+03, -.84840100E+02, 0.16027100E+03, 0.23768400E+03, -.12138100E+03, 0.21250300E+03, -.11972800E+03, -.79516000E+01, 0.58773300E+02, 0.36684300E+02, 0.22937700E+03, -.19904500E+03, 0.19205900E+03, 0.78188900E+02, 0.46285300E+03, -.23567400E+03, -.28362700E+03, -.23076100E+03, -.38238600E+02, 0.34093500E+02, 0.22357300E+03, 0.69399900E+03, 0.65906800E+02, 0.16942600E+02, 0.43989600E+03, -.62441600E+03, 0.31423400E+03, 0.16037900E+03, 0.31222300E+03, 0.10258100E+03, 0.91481000E+02, -.18300400E+02, -.22669700E+03, 0.52126600E+03, -.12595200E+03, 0.98259800E+02, -.42113600E+03, 0.20503500E+03, 0.74654600E+03, 0.21058500E+03, 0.10586000E+03, -.38284100E+02, 0.13929600E+03, -.77024200E+02, 0.10970700E+03, 0.23636100E+02, 0.44082600E+02, 0.18039200E+03, -.99022200E+02, 0.82641100E+03, -.90880600E+02, 0.26976000E+03, 0.28694200E+03, 0.41020000E+03, 0.73256700E+03, 0.18293900E+03, 0.38285800E+03, 0.53248400E+03, 0.14147700E+04, -.70714100E+03, -.11126500E+03, -.70767700E+03, -.14448600E+03, -.98073300E+02, -.39442500E+03, 0.16330700E+03, -.41502900E+03, -.12527700E+03, -.12986800E+04, -.78916600E+03, 0.39064200E+03, 0.25571900E+03, 0.39463000E+03, 0.19482000E+03, 0.10766700E+03, 0.18992500E+03, -.26531400E+02, 0.23117600E+03, 0.12547500E+03, 0.31039600E+03, 0.17151400E+04, -.85468300E+03, 0.21638400E+03, -.85747200E+03, 0.11596800E+02, 0.35224600E+03, -.72672700E+03, -.11667400E+03, -.76085000E+03, 0.18712300E+03, -.12485900E+04, 0.94888500E+03, -.47396500E+03, -.50917900E+03, -.47487500E+03, -.13627600E+03, -.66318800E+01, -.38682600E+03, -.48224900E+03, -.42389200E+03, 0.21826900E+02, -.52290600E+03, 0.16188500E+02, 0.78322700E+01, 0.20345500E+02, -.11724000E+01, -.97806800E+01, 0.32735000E+01, -.45271000E+01, 0.11902100E+01, -.92673800E+01, -.25002600E+02, -.14008500E+02, -.82908300E+01, 0.10298800E+02, -.13826300E+02, 0.10926400E+02, 0.11157900E+02, -.34732400E+02, -.63846700E+01, 0.44131600E+01, -.78584300E+02, 0.85871300E+02, 0.31748300E+02, 0.91736800E+01, -.13297100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.27935600E+01, -.26617200E+00, -.30196600E+00, -.68992000E+00, 0.96215800E+00, 0.13416500E+01, -.27355300E+00, 0.10058800E+01, 0.23752200E+00, -.25858300E+00, -.41632400E+00, -.27795000E+00, -.94235100E+00, -.88830800E+00, -.23690200E+00, -.19542200E+00, -.18343600E+00, -.62669000E+00, -.45242500E-01, 0.70637200E+00, -.43019500E+00, -.19902100E+01, -.14480200E+01, 0.56010000E+00, -.70923700E-01, 0.72180300E+00, -.25940300E+00, -.87850900E-01, -.52105100E+00, -.68661100E+00, -.29980000E+00, 0.16929900E+00, -.52888800E+00, 0.47252600E+00, -.13335500E+00, 0.44669500E-01, -.17871000E-01, 0.28123800E+00, -.36628600E+00, 0.12005200E+00, 0.12543900E+00, 0.78415300E+00, 0.25110600E+01, 0.70212600E-01, -.50552500E-01, -.74893800E-01, 0.79482600E-01, 0.29474400E+00, 0.54271200E+00, 0.11678100E+01, -.23326000E-01, -.48042900E+00, -.84503800E-01, -.29049800E+00, -.44750900E-01, 0.21056100E+00, 0.15958800E+00, 0.59713400E+00, 0.27314400E-02, 0.77482800E+00, 0.69670700E-01, 0.29663800E+00, 0.95862400E-01, 0.82830600E+00, -.12899400E+01, 0.62144600E+00, 0.61012400E+00, -.20435600E+00, -.25271200E+00, -.23502600E-02, 0.61675500E+00, -.31323700E+00, -.45350600E+00, 0.45944800E-01, -.13286900E+00, 0.91473800E-01, -.36212500E-01, 0.62618800E+00, -.25391300E+00, -.44736000E+00, -.43429600E-03, -.10024200E+01, 0.50612600E+00, 0.60183000E+00, 0.14640700E-02, -.26504000E+00, -.43717400E+00, 0.18703500E+00, -.14333500E+00, -.17045000E+00, -.35380100E+00, -.41994900E-02, -.35567500E+00, 0.72193900E+00, -.20852200E+00, -.71672700E+00, -.27821500E-01, 0.28542900E+01, -.29806300E-01, -.52390100E+00, 0.37755600E+00, -.42379600E-01, 0.98995700E-01, -.16530900E+00, -.32126700E+00, -.63536000E+00, -.60024900E+00, 0.60931400E+00, 0.35020100E+00, -.26521000E+00, -.36510100E+00, -.60463800E-01, -.15259500E-01, -.66505700E-02, 0.44717300E+00, -.34848800E+00, 0.43774700E-01, 0.34226700E-01, 0.96071300E-02, -.58107500E+00, -.51111700E+00, 0.27786000E+00, -.88929400E-01, 0.22370400E+00, 0.46139700E-02, -.15895300E+00, -.19002700E+00, -.90629800E+00, 0.10075900E+00, -.45340500E-01, 0.17226100E+00, -.77387200E-01, -.13379400E+00, -.38499200E-01, 0.51458500E+00, -.77958900E-03, -.50904100E+00, -.90771600E+00, -.63243200E-01, 0.12730500E+00, 0.57370700E-01, 0.20782100E+00, -.10762000E+00, -.21780600E+00, -.24870600E+00, 0.73456900E+00, 0.34015100E-01, 0.31079200E+00, 0.27711400E+00, 0.17721800E+00, -.90341400E-01, -.12076800E-01, -.70110500E+02, -.10857700E+03, -.36899400E+02, 0.20573600E+02, 0.75680600E+02, 0.18339900E+02, -.10851500E+03, -.65541400E+02, 0.17417900E+03, 0.15339300E+03, 0.90402000E+02, 0.32716000E+02, 0.79035400E+02, 0.61365600E+03, -.30421600E+03, -.35259800E+03, -.30724000E+03, 0.12031700E+03, -.22326600E+02, -.94469500E+02, 0.38737600E+03, 0.23754300E+01, -.39374500E+02, -.18434500E+03, -.24462400E+02, 0.11088400E+02, 0.42011900E+02, 0.12293000E+02, 0.13534400E+03, 0.19245100E+03, -.19576500E+03, -.11235700E+03, -.47888600E+02, -.22035800E+02, 0.10523300E+02, -.19244800E+03, 0.95219000E+02, 0.17792600E+03, 0.96318100E+02, -.62581000E+02, -.42940200E+01, 0.86786700E+02, 0.27711900E+02, 0.12857000E+02, 0.25825200E+02, 0.59140900E+02, -.34937400E+03, 0.17213500E+03, -.39713200E+03, 0.17469300E+03, -.32882800E+03, -.31150500E+02, 0.12976200E+03, -.26726900E+02, 0.21412500E+03, -.29516200E+02, 0.50007100E+03, -.48910900E+03, 0.24302000E+03, 0.32207100E+03, 0.24492400E+03, -.14140600E+03, -.30681200E+02, 0.15875500E+03, -.87332800E+02, 0.16209100E+03, -.15614000E+02, 0.17863600E+03, -.21256400E+01, 0.12145600E+01, -.28732700E+02, 0.10864000E+01, -.15499100E+02, -.49315300E+01, -.40325900E+02, -.32754300E+02, 0.89253400E+01, 0.59111200E+01, -.88001300E+02, -.76629400E+03, 0.38600700E+03, 0.50131900E+03, 0.38353000E+03, 0.88061500E+02, -.20609700E+03, 0.26230900E+03, 0.15326400E+03, 0.25138500E+03, -.15550800E+03, 0.10027800E+03, 0.12965700E+03, -.63537500E+02, 0.25612200E+01, -.64683900E+02, 0.52874000E+02, 0.13562800E+03, -.96254500E+02, -.14399600E+03, -.31790200E+02, 0.13727800E+03, -.87516500E+02, -.11582500E+02, -.22803500E+01, 0.11263200E+02, -.42751400E+01, 0.55295700E+00, 0.42285900E+01, 0.34805100E+01, 0.48630700E+01, 0.10810600E+02, 0.24124400E+00, -.71640000E+02, 0.57430100E+00, -.21791900E+02, 0.16893200E+02, -.39128200E+02, 0.10759800E+02, -.20881000E+02, 0.77630100E+01, -.13630100E+02, 0.43995400E+01, 0.79708700E+01, 0.11459600E+02, 0.24569900E+02, -.81606100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.65617400E+01, 0.15761800E+01, 0.40406400E+01, -.34408100E+01, -.37901600E+01, 0.21059900E+01, 0.45352100E+00, -.48699800E+01, 0.14028300E+01, 0.19797300E+01, 0.16072400E+00, -.20959300E+01, -.93783600E+01, -.59758900E+01, 0.52214500E+00, 0.45360400E+00, -.28794100E+01, -.98936600E+00, 0.26235300E+00, -.77635700E+00, -.30167600E+01, 0.35536200E+01, 0.31733900E+01, -.33088300E+01, -.53108500E-01, -.41944700E+00, 0.10921100E+01, 0.42343300E+00, -.61342200E+00, 0.36572300E+01, -.23008000E+00, -.59543100E+00, 0.29989600E+01, -.96160200E+00, -.14109600E-01, -.19079600E+01, 0.56591100E-01, -.60031700E+00, -.34751700E+00, -.11638900E+01, 0.43374400E+00, 0.16413600E+01, 0.69312900E+01, -.24558400E+00, -.54447400E+00, -.17216900E+01, 0.93140300E-01, 0.44720400E-01, 0.45168400E+00, 0.23069500E+01, 0.34371200E+00, -.58073800E-01, 0.20218500E+00, -.12073000E+01, 0.18820500E+01, -.67617400E+00, 0.91439000E+00, 0.38110900E+00, -.43444800E-02, 0.19830500E+00, 0.57751700E+00, -.33170100E+00, 0.10303400E+00, 0.40608700E+00, 0.17420600E+01, 0.46626400E+00, -.35188700E+00, -.14172300E+01, 0.17140200E+00, -.91004600E-02, 0.12469100E+01, -.68770800E+00, -.38728800E+00, 0.26291500E+00, 0.38973000E+00, -.12709400E+00, 0.97252300E-01, -.12151800E+01, 0.13743200E+00, 0.48611800E+00, 0.42301200E-03, 0.10801300E+01, -.30059500E+00, -.29831700E+01, -.25129700E+00, -.18888200E+01, 0.77178900E+00, -.18552600E+00, -.10143300E+01, 0.32047800E+00, 0.10112900E+01, 0.18756800E-01, -.34113200E-02, 0.24606300E+01, -.38456000E+01, -.20303400E+01, -.28648600E-02, 0.29549500E+00, -.15597800E+01, 0.95475600E-01, -.12878300E+01, -.16115900E+00, -.53083300E+00, -.23129600E+00, -.13993600E+01, 0.15978800E+01, 0.15426200E+01, -.32424000E+00, -.13482200E+00, 0.85042700E+00, -.11166400E+01, 0.12063700E+00, -.11147900E+00, -.13413800E-01, -.31490200E+00, -.53517600E+00, -.55497200E+00, -.13250400E+01, -.30188300E+00, 0.25145700E+01, 0.10944000E+01, -.12226200E+01, 0.26606200E+00, -.50024600E+01, 0.87000300E-02, 0.14292600E+01, -.94734800E+00, -.43526500E+01, -.75802500E+00, -.25469300E+00, 0.66473100E+00, -.58383000E+00, -.79287100E+00, 0.10932700E+00, 0.11156500E+01, -.17816700E-01, -.74153200E+00, -.30075500E+00, -.20372900E-01, 0.26915600E+00, -.11974200E+00, -.65278500E-01, 0.37464900E+00, -.82712900E+00, -.11617100E+01, 0.30908700E+00, -.81757200E-01, -.12948500E+01, -.10979800E+01, -.37800100E+00, 0.34475700E-01, 0.45130200E+00, 0.18236900E+01, 0.36876800E+03, 0.31456900E+03, -.16313900E+03, -.24913500E+03, -.15705700E+03, 0.17040700E+03, 0.20675400E+03, -.63705600E+03, -.38867000E+03, -.35629400E+03, 0.67341600E+02, -.11003100E+03, -.98720500E+03, 0.49257600E+03, 0.60406300E+03, 0.49470100E+03, -.22150200E+03, -.21091200E+02, 0.18581600E+03, -.88085800E+03, -.15709300E+03, -.39300100E+02, 0.49875900E+03, -.31262200E+03, 0.15820800E+03, 0.10824500E+03, 0.15616700E+03, -.20493900E+03, -.31182600E+03, 0.62067000E+03, 0.35926800E+03, 0.26385800E+03, -.41369300E+02, 0.16805600E+03, 0.59602500E+03, -.29524400E+03, -.42888100E+03, -.29822500E+03, 0.63776300E+02, -.73319600E+01, -.23473300E+03, -.49209400E+02, -.48248000E+02, -.75582100E+02, 0.20280300E+03, 0.10685800E+04, -.52431300E+03, 0.11244300E+04, -.53434700E+03, 0.57784800E+03, 0.20540900E+03, -.35917200E+03, 0.12704700E+03, -.52017300E+03, 0.16047800E+03, -.88352900E+03, 0.11793500E+03, -.54212500E+02, -.35217400E+03, -.59931700E+02, 0.25619300E+03, 0.15247900E+03, -.19399700E+03, 0.11389400E+03, 0.17144300E+01, 0.15533400E+03, -.13276500E+03, -.23516400E+03, 0.11968200E+03, 0.28825700E+03, 0.11753000E+03, 0.94100100E+02, 0.49936100E+02, 0.10507700E+03, 0.15869400E+02, 0.45065000E+02, 0.36232500E+02, -.34063200E+01, 0.12558400E+04, -.63229600E+03, -.85511500E+03, -.62881500E+03, -.65573400E+02, 0.46904900E+03, -.56460000E+03, -.59748500E+03, -.46954600E+03, 0.39596900E+03, -.33836900E+03, -.68424900E+03, 0.33946200E+03, 0.14797900E+03, 0.34169500E+03, -.18270400E+02, -.11559100E+03, 0.45678800E+02, 0.64016700E+02, 0.88773700E+01, -.10597900E+03, 0.46423800E+03, 0.43547800E+02, 0.10159900E+02, -.21507100E+02, 0.93417200E+01, -.10953900E+02, -.33648300E+01, -.10406100E+02, -.14813600E+02, -.14968100E+02, -.10457900E+02, 0.15242200E+03, -.20557100E+01, 0.82894600E+02, -.67168200E+02, 0.87380700E+02, -.22641200E+02, 0.11391700E+03, -.37763000E+02, 0.67185600E+02, -.16339400E+02, 0.40229400E+02, -.16008200E+02, -.41450500E+02, 0.17508900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40489100E+01, 0.57373600E+00, 0.18762800E+01, -.29645800E+01, -.30040200E+01, 0.45831700E+00, 0.54785900E+00, -.20577900E+01, 0.84911000E-01, 0.24762300E+00, -.41818200E+00, -.86788800E+00, -.29403400E+01, -.34688800E+01, -.76983900E-01, 0.31916100E+00, -.68093500E+00, -.14287000E+01, 0.29288800E+00, 0.11641300E+01, 0.45741000E+00, 0.11625400E+01, -.12823900E+01, 0.10800700E+01, -.23170300E+00, -.47075100E+00, -.84646300E-01, -.44865000E+00, 0.48987400E-01, -.20489600E+01, 0.52340700E+00, 0.24805200E-01, 0.13186100E-01, -.58067800E+00, 0.88252200E-01, 0.59121100E+00, 0.40212500E-01, 0.23411500E-01, -.13923700E+00, 0.72810900E-01, -.26549800E+00, -.12265500E+01, 0.10161600E+01, -.18891900E+00, 0.82972300E+00, -.14548400E+01, -.31884200E-01, -.11138700E-01, -.15779700E-01, -.68682200E+00, 0.22951300E+01, 0.86214600E+00, 0.46646300E+00, -.24994900E+00, 0.83166400E-01, -.80481600E+00, 0.51927600E+00, -.22778100E+01, 0.43500900E-03, -.22937300E+00, 0.54612900E-01, -.18724400E+01, 0.30426600E+00, -.29463700E+00, -.16668100E+01, -.65397200E+00, -.15606000E+00, 0.84275800E+00, -.22494500E+00, -.20976100E-03, -.13399800E+00, 0.23326900E+00, 0.33554700E-01, 0.35078800E+00, -.31998100E+00, -.11247900E+00, -.24067400E+00, 0.46180400E-01, -.29118800E+00, -.14520200E+00, 0.78760600E-03, 0.55344900E+00, -.26922800E+00, -.44595100E+00, -.32767200E+00, -.51491500E+00, 0.11922500E+01, -.46355800E+00, -.92470800E-02, 0.28434300E+00, -.16978300E-01, -.45426100E-01, -.10581700E-01, 0.14215800E+01, 0.42138800E+00, -.14625600E+00, -.16800100E-01, -.98316000E-01, 0.70977900E-01, -.52478300E+00, 0.96239900E+00, 0.15117300E+00, 0.18377100E+00, 0.10038400E+00, 0.42287400E+00, -.47287900E+00, -.35183700E+00, 0.32617700E+00, -.39299700E+00, -.22620700E+00, -.48853100E+00, 0.27097400E-01, 0.15473800E+00, -.19371900E-03, -.43572600E+00, -.21330800E+00, 0.23187800E+00, -.65779400E-01, -.66304900E-01, -.16283000E+01, 0.39720300E+00, -.47069100E+00, -.95614600E+00, 0.23810500E+01, -.18230500E-02, -.97658000E+00, 0.47071300E+00, 0.31978600E+01, 0.21207200E+00, 0.22775300E+00, 0.33675900E+00, -.24569200E+00, -.13644800E+00, 0.17941400E+00, -.43310300E+00, 0.15590400E-01, -.83625100E+00, 0.85537500E+00, -.39687200E-01, -.13501900E+00, -.18263200E+00, -.92269800E-01, 0.16610000E+00, 0.54763600E+00, 0.11063700E+01, -.14780400E+00, 0.18575200E-01, 0.62406300E+00, 0.18644700E+00, 0.72463400E+00, -.14416200E-01, -.35168500E+00, -.21171100E+00, -.15539400E+00, -.35962100E+03, 0.17919600E+03, -.95023700E+02, 0.17883300E+03, -.95627300E+02, 0.84681600E+01, 0.14559200E+03, -.19499100E+03, 0.10496200E+03, 0.47867900E+02, 0.17288900E+03, -.21929400E+03, 0.10993700E+03, -.75637600E+01, 0.10994100E+03, 0.50832800E+02, 0.64158200E+02, 0.41981800E+02, -.91771200E+02, -.31101800E+03, 0.34202400E+02, 0.48423000E+03, 0.87849400E+02, -.43910800E+02, 0.27292000E+02, -.43882300E+02, 0.17728100E+03, 0.90802500E+01, -.22171000E+02, 0.11623800E+03, -.11573600E+03, -.19699000E+02, -.43631900E+02, -.11110500E+04, 0.55161700E+03, 0.46158000E+03, 0.55557900E+03, 0.12489100E+03, 0.41435000E+02, 0.21669200E+03, -.13452400E+03, 0.39405100E+03, 0.36280000E+02, 0.39749400E+03, -.50718200E+03, 0.25039000E+03, 0.40104000E+03, 0.25291400E+03, -.17171200E+03, -.21875500E+03, 0.16206300E+03, -.29463000E+03, -.63939600E+01, -.25962800E+03, 0.49254000E+03, 0.33605300E+03, -.16891400E+03, -.12194100E+03, -.16798900E+03, 0.24033000E+02, 0.48997000E+02, -.17749800E+03, 0.68714800E+02, 0.93312200E+02, 0.51541300E+02, -.39582400E+03, 0.24292400E+03, -.12152700E+03, -.14624300E+03, -.12140600E+03, -.20222300E+02, 0.40753700E+02, -.84346900E+02, 0.10414000E+01, -.62315900E+02, 0.29042500E+02, -.49661100E+02, 0.64901200E+03, -.33163100E+03, 0.49190000E+02, -.32421400E+03, 0.17622500E+03, 0.22507900E+03, -.15384000E+03, 0.27725800E+03, -.18271900E+03, 0.23574200E+03, -.43674700E+03, 0.14483900E+03, -.71445900E+02, 0.89185800E+02, -.72662100E+02, -.16445800E+03, -.99103400E+02, 0.51943300E+02, 0.85388000E+02, 0.12858700E+03, -.38846600E+02, 0.17958000E+02, -.39171400E+02, -.91111700E+01, 0.20154100E+02, -.13754800E+02, 0.69833600E+00, -.31088700E+01, 0.10611100E+02, -.75311500E+01, -.12756100E+02, -.48741300E+01, -.18253000E+02, 0.24212900E+02, 0.35349000E+01, 0.98351500E+01, -.43444500E+02, 0.13443000E+02, 0.54279000E+02, 0.27643100E+02, 0.19152100E+01, 0.11121900E+01, 0.10068800E+03, -.14224400E+02, 0.46067800E+02, 0.40642600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13118200E+02, 0.70312200E+00, -.21341400E+01, 0.64119000E+01, 0.11619500E+02, 0.45997500E+01, -.30007300E+01, 0.26571200E+01, -.50443100E+00, -.19324800E+00, 0.77668500E+01, 0.42224800E+01, 0.33214700E+01, 0.57081100E+01, -.13968300E+01, -.11634600E+01, 0.21860600E+01, 0.10109600E+01, 0.13471700E+00, -.52279800E+00, 0.10330400E+01, -.38042700E+01, 0.40626200E+01, -.28359500E+00, -.16596700E+00, 0.17367000E+01, 0.21940800E+00, -.11712500E+00, 0.44649500E+00, -.20997700E+01, 0.22653000E+00, 0.10379400E+01, -.16400400E+01, 0.80160000E+00, -.89730800E+00, 0.15183300E+01, -.25476300E+00, 0.29838600E+00, -.42819000E-01, 0.10114800E+00, 0.15819500E+01, 0.12519100E+01, 0.14196400E+01, -.58908900E+00, -.32397100E+01, 0.56850900E+01, -.10710100E+01, -.81181600E+00, 0.13082400E+01, 0.45927700E+01, 0.26648500E+01, 0.96688900E+00, 0.14659100E+00, 0.95967100E+00, -.27605700E+00, -.78401700E+00, 0.24196500E+00, 0.25747900E+01, 0.27131200E-02, 0.35125500E+01, 0.19528300E+01, 0.41967800E+01, -.15369500E+00, 0.23178800E+00, 0.38011400E+01, -.69717100E+00, 0.55553700E+00, 0.37573200E+00, -.32865200E+00, 0.18768500E-01, 0.17849900E+01, 0.40952500E+00, -.55078200E+00, -.24850000E+00, -.69401700E+00, -.30950100E+00, -.24414800E+00, -.83312900E+00, -.20143900E+01, -.41095300E+00, -.23101700E-02, 0.22412300E+00, 0.39224100E+00, 0.51104200E+00, -.87047600E+00, -.23448200E+01, -.77527200E+00, -.49106000E+00, 0.10187600E+01, 0.11893800E+01, 0.18483200E+00, -.19498500E+00, 0.58774800E+00, 0.78729200E+01, 0.79028600E+00, 0.10237300E+01, 0.17674300E+01, 0.86582200E+01, 0.21589100E+01, -.24390800E+01, 0.83923400E+00, -.28968700E+00, 0.39832900E+00, -.26332400E+00, -.16512300E+01, -.17565100E+01, -.19839100E+01, 0.11290900E+01, -.12835800E+01, 0.55159200E+00, -.21642400E+01, -.23874600E+00, -.10503800E+01, 0.33622300E-01, -.26786400E+00, 0.27580400E+01, -.30314100E+00, 0.59887500E+00, 0.10951900E+01, -.46571900E+01, -.37138500E+01, 0.32216100E+01, -.23990800E+01, 0.76577000E+01, -.23545000E-01, -.11980400E+01, -.49119900E+00, 0.46873800E+01, 0.68631500E+00, -.33207600E+00, -.10067000E+01, 0.27921400E+00, 0.84834600E+00, 0.69453100E-01, 0.13363800E+01, 0.32930100E-01, -.53569700E-01, -.19043000E+01, -.25014100E+00, -.57566400E+00, 0.61319300E+00, 0.97415500E-01, -.80873800E+00, 0.20590700E+01, 0.27518700E+01, 0.11270200E+01, 0.15413400E+00, 0.22151700E+01, 0.46765400E+01, -.44935200E-01, 0.73151000E+00, -.11110400E+01, 0.30313200E+00, -.36669400E+00, -.35375100E+00, -.25156000E+02, 0.24079300E+03, -.28191200E+01, 0.25816200E+03, 0.21979800E+02, 0.74945200E+02, 0.67196200E+02, 0.52505600E+02, 0.35174900E+02, 0.24338100E+03, -.87599600E+03, 0.42571600E+03, 0.10162000E+04, 0.43921300E+03, -.19446400E+03, 0.28346100E+03, 0.60190600E+03, 0.10002300E+04, 0.25315600E+03, 0.27096800E+03, 0.34788900E+03, -.22129000E+03, 0.12176300E+03, -.11087600E+03, 0.11078300E+03, -.14937400E+03, -.20309400E+03, 0.68558100E+02, -.26708000E+03, 0.74015500E+02, -.28644700E+03, -.22155400E+03, -.92314400E+03, 0.45267600E+03, 0.20966400E+03, 0.46177500E+03, 0.25990000E+03, 0.78298400E+02, 0.11495500E+03, -.18422800E+03, 0.39824300E+03, 0.78847100E+02, 0.28196900E+02, -.72372700E+03, 0.36849200E+03, -.27362900E+03, 0.35985200E+03, 0.21297700E+03, 0.38137800E+03, 0.46865800E+03, 0.46934700E+03, 0.18143900E+02, 0.39744300E+03, 0.25776900E+03, 0.22148000E+04, -.11360500E+04, -.13872700E+04, -.11075800E+04, 0.26327100E+03, -.58932900E+03, -.39948000E+02, 0.38922400E+03, -.72395900E+03, -.49316600E+03, -.12221400E+04, -.34124000E+03, 0.16517700E+03, 0.50438100E+02, 0.17079300E+03, 0.11703300E+03, 0.81683400E+02, 0.85423700E+02, 0.14398000E+03, 0.29067000E+02, 0.12619100E+03, 0.21260300E+03, 0.30742100E+04, -.15200700E+04, -.17695100E+04, -.15361800E+04, 0.23775400E+03, 0.54039000E+02, -.77624900E+03, 0.35219500E+03, -.85947900E+03, 0.18611500E+02, -.13669100E+04, 0.15650400E+04, -.79630200E+03, -.70551800E+03, -.78349700E+03, -.39546500E+03, -.13929600E+03, -.31055300E+03, -.37546600E+03, -.51882500E+03, -.74284000E+02, -.51846300E+03, 0.41829100E+01, -.18561600E+02, 0.22253600E+02, -.78619900E+01, -.15940300E+02, -.21537900E+00, 0.19802300E+02, -.14093400E+02, -.22562200E+02, -.44809500E+02, -.11214600E+03, 0.12978500E+02, 0.20295500E+02, -.24962300E+02, -.19976700E+02, 0.23614100E+02, -.12972700E+03, 0.56935600E+02, 0.15031900E+02, -.10746200E+03, -.20346100E+03, 0.54378100E+02, -.23502700E+02, 0.32421100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.26871000E+00, 0.53048500E-01, 0.97952100E+00, -.13136500E+01, -.14421300E+00, 0.45019800E-01, 0.18768200E-02, -.20833400E+00, -.21853500E-01, -.21547400E+00, -.38829000E+00, -.68642100E-01, -.71732400E+00, -.11041600E+01, 0.55900500E-01, 0.46075200E-01, -.22357000E+00, -.11727200E-01, -.19168800E-01, 0.48133700E+00, 0.98996800E-01, 0.25948400E+00, 0.76151700E-01, -.60872100E-01, -.86509300E-01, -.20491900E-01, 0.27956300E-01, -.28109200E-02, 0.69129700E-01, -.51372500E+00, 0.52152900E-01, 0.11289100E-01, 0.73546400E-01, -.38027100E-01, 0.17124800E-02, -.17211100E-01, -.66243400E-02, 0.99237000E-01, -.99114300E-01, -.16566300E-01, -.75370800E-02, 0.23680500E-01, 0.33104900E+00, -.14827300E-01, -.70680000E-01, 0.92321400E-02, 0.12583400E+00, 0.37356600E-02, 0.90902200E-01, 0.33018700E+00, 0.15521000E-01, 0.75228100E-01, -.32383100E-01, -.26668500E-01, 0.62067100E-01, -.58609200E-02, 0.76812300E-02, 0.29427800E+00, -.11026500E-03, 0.44755700E-01, 0.30387100E-01, 0.16561700E+00, -.44879100E-02, -.17334800E-01, 0.28425000E+00, -.28997800E-01, 0.64549700E-02, -.13080700E+00, 0.69368000E-01, 0.46298200E-03, 0.56917600E-01, 0.43120800E-01, -.43699700E-01, 0.16906900E-01, -.73605100E-01, 0.13237400E-01, 0.10975500E+00, -.99246600E-01, -.35335300E-01, 0.69615600E-02, -.36001700E-03, -.18605600E-01, -.76722300E-01, -.33003100E-01, -.29325000E-01, 0.13463300E+00, 0.15660400E+00, -.83587300E-01, 0.63642000E-01, 0.26600500E-01, -.51064200E-01, 0.35790600E-02, 0.10678400E+00, 0.49562100E+00, 0.12966900E+00, -.21978700E+00, 0.85629900E-01, 0.14996100E+00, 0.24187200E-01, -.66629400E-02, -.45244800E-01, -.33988800E-01, -.31801400E-01, 0.52793900E-01, -.18329600E+00, -.20640300E-01, 0.11355500E+00, 0.11898600E+00, 0.14767800E+00, -.43780600E-01, -.54418600E-01, -.11077400E-01, -.35561000E-01, 0.23450100E-03, 0.60732800E-01, 0.84352300E-01, -.51587800E-01, -.22306200E-01, -.10617800E-01, -.51573800E-01, -.11978600E-01, -.10142500E+00, 0.20220000E+00, -.17268600E+00, -.19615200E-02, -.39966900E-01, -.12647800E-01, 0.66500400E-01, 0.13050800E+00, -.29254800E-01, 0.10962900E+00, 0.10672600E+00, -.64384100E-01, -.21083400E-02, 0.16527900E+00, 0.24924400E-02, 0.46168600E-01, -.55284300E-01, -.29381800E-01, 0.17397900E-01, 0.66082700E-01, 0.40125300E-01, 0.24470800E-02, 0.18812300E-01, -.54342100E-01, -.10282500E+00, 0.13599500E-01, -.18271100E+00, -.14404700E-01, 0.78779800E-01, -.11950200E-02, -.36297800E-01, -.17791700E+00, 0.62065700E-01, 0.60238900E-01, -.17848200E-01, 0.47075900E+02, 0.15887500E+00, -.12411600E+01, -.15611600E+02, 0.23630900E+02, 0.38728900E+02, 0.18358000E+02, -.59170900E+01, -.28741600E+02, 0.11748000E+03, -.59141100E+02, -.45054700E+02, -.58859800E+02, 0.18449200E+02, 0.12971200E+02, -.35547100E+01, 0.12058600E+03, 0.55976400E+02, 0.10056700E+02, -.10096100E+03, -.12304900E+02, 0.62559900E+01, -.15682200E+00, 0.61582300E+01, 0.64196200E+01, 0.31536000E+02, -.26182200E+02, -.20417700E+02, 0.22175700E-01, 0.12750000E+01, 0.56074300E+01, 0.47557500E+02, -.23643500E+02, 0.41821700E+02, -.23765500E+02, -.90934900E+01, -.35943700E+01, 0.10271700E-01, 0.76204600E+01, -.30190100E+02, 0.71661800E+01, -.80887000E+02, -.14791600E+03, 0.73210200E+02, -.65717900E+02, 0.74082000E+02, -.45131800E+02, -.29023200E+01, 0.68274700E+02, 0.43890900E+02, 0.10705900E+03, 0.18495900E+02, 0.36139200E+02, -.19384500E+02, 0.94698100E+01, -.56631700E+01, 0.97465400E+01, -.23101900E+02, -.39957800E+02, 0.34628800E+02, 0.10896000E+01, -.19439300E+02, -.38884200E+02, 0.50516300E+02, -.22597700E+02, 0.10778000E+02, 0.50166400E+00, 0.11293900E+02, -.29105400E+01, 0.51006700E+01, -.74536000E+01, -.10423900E+02, 0.81245200E+01, 0.75109700E+01, 0.30441400E+02, -.15269600E+02, 0.10206600E+02, -.30443000E+02, 0.76661100E+01, 0.10697500E+01, -.33377100E+02, 0.12807500E+02, 0.40393600E+02, 0.30175600E+01, -.45703100E+02, 0.28976400E+02, 0.66959000E+02, -.33503100E+02, -.50532600E+02, -.33419700E+02, 0.14213300E+02, 0.24848200E+02, -.77592200E+01, -.25816500E+02, -.15974500E+02, 0.15188700E+02, -.54250100E+02, -.37047300E+00, 0.26326300E+00, -.46112300E+00, 0.13681800E+00, 0.43560000E+00, 0.20454600E+01, 0.38657300E+00, 0.99803500E+00, 0.19300400E+01, 0.55197600E+00, -.19292500E+02, -.13611200E+01, -.13609400E+02, 0.93529700E+01, 0.17834000E+01, 0.48420500E+00, -.24378900E+02, -.14803500E+01, -.12645500E+02, -.16887500E+01, -.28114800E+02, 0.41926000E+01, 0.43571400E+00, -.29897700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11421900E+02, -.24749500E+01, -.31242400E+01, 0.88270900E+01, 0.59866100E+01, -.53927200E+00, -.11403400E+01, -.15503500E+01, 0.94106400E+00, -.38415200E+00, 0.66012600E+00, -.34800800E+00, -.81840500E+01, 0.36261900E+00, 0.74210400E+00, -.46307000E+00, 0.16930900E+01, -.13663400E+01, -.10585000E+01, 0.17344000E+01, 0.78740900E+00, -.39323800E+01, -.12060200E+01, -.25968300E+00, -.15573000E+00, 0.41653200E+01, 0.65824200E+00, -.13291200E+00, 0.29502200E+00, -.14718900E+01, -.16243700E+01, 0.56242300E+00, -.74186100E+00, 0.87870000E-01, -.18804800E+00, 0.12242300E+01, 0.86062000E-01, 0.52933300E+00, 0.85129000E-01, 0.25987200E+00, 0.18750000E+01, 0.73655900E+00, -.61535100E+00, -.14565200E+00, -.99407400E+00, 0.16329400E+01, -.52675800E+00, 0.45006000E+00, 0.71764400E+00, 0.15630900E+01, -.12068000E+01, -.76442700E-01, -.15960400E+00, 0.21159800E+00, -.10085000E+01, -.68541900E+00, 0.38930700E+00, -.22416300E+00, 0.13257900E-01, 0.12722600E+01, -.12278600E+00, -.89322900E+00, 0.16001200E+00, 0.86898100E+00, -.47961200E+01, -.10956100E+01, 0.10254900E+01, -.66302200E+00, 0.28077300E+00, 0.18753600E-01, 0.16948800E+00, 0.83033500E+00, 0.77826500E+00, 0.49093600E-01, 0.48820800E+00, 0.11244100E+00, 0.42039200E+00, -.34568600E+00, 0.13655300E+01, -.65961600E+00, -.38039900E-02, -.95729600E+00, 0.17480600E+01, -.13680900E+01, -.22868400E+00, -.26121900E+01, -.11110100E+01, 0.45464800E+00, -.35687800E+00, 0.67310400E-01, -.35011200E+00, 0.60742300E-01, 0.11154800E+01, 0.25092100E+01, 0.29902300E+01, 0.13301800E+01, -.55481900E+00, 0.24115700E+01, 0.11483600E+01, -.52175400E+00, 0.88978800E+00, 0.17690600E+00, 0.30959600E+00, 0.49061300E+00, 0.67437100E+00, -.20016300E+01, 0.18692200E+00, 0.19400900E+01, 0.20599300E+01, -.15517600E+01, 0.13890400E+01, -.33304400E+00, -.49915000E+00, 0.11158000E-01, 0.10314000E+01, 0.33746300E+00, 0.52763300E+00, 0.13469900E+01, 0.28626800E-01, -.31701400E+01, -.17940400E+01, 0.18471900E+01, 0.17616000E+01, 0.21262800E+01, -.35227300E-01, -.14771800E+01, -.13654100E+00, 0.11954700E+01, 0.12077600E+01, 0.37507700E+00, 0.11161500E+01, 0.12447300E+00, 0.47728000E+00, -.61073000E-01, 0.15487200E+01, 0.33473200E-01, 0.38638900E+00, -.24750900E+01, -.46579300E+00, 0.30236400E+00, 0.65982100E+00, 0.51613600E+00, -.47513100E+00, 0.20861200E+00, -.46401600E+00, 0.33741500E-01, 0.33283900E+00, -.13649000E+01, -.14710300E+01, -.44548000E+00, -.30315800E+00, 0.21594700E+00, 0.20791700E+01, 0.44338500E+00, 0.38512100E+00, 0.23712600E-01, -.39200600E+01, 0.15187900E+02, 0.13548700E+03, 0.97900100E+02, -.22002800E+03, 0.41958000E+02, 0.22771200E+01, 0.71312000E+02, -.21068000E+03, -.18311600E+03, 0.93419000E+02, -.10902100E+03, 0.87466700E+02, 0.22340200E+03, 0.12957500E+02, 0.13260600E+03, 0.23721600E+03, 0.35723200E+03, -.32838600E+01, -.10099700E+01, -.71064600E+02, 0.34421800E+02, 0.69847800E+02, 0.35408800E+02, -.30376100E+02, -.61210900E+02, 0.14138800E+03, 0.74037100E+02, -.12529200E+02, -.42108500E+02, -.28888600E+02, 0.76315400E+03, -.37999200E+03, 0.78502900E+01, -.38168700E+03, -.65260800E+02, -.74038100E+02, -.13190500E+03, 0.90840100E+02, -.25717600E+03, -.49720300E+02, -.42867900E+03, -.28432600E+03, 0.14092700E+03, 0.16851600E+03, 0.14752800E+03, 0.14929500E+03, 0.21810500E+02, 0.11869600E+03, 0.42186100E+03, 0.53140600E+03, 0.65651700E+02, 0.14761200E+03, -.18579100E+03, 0.99341300E+02, -.12437100E+03, 0.94184700E+02, -.14488300E+03, 0.30533900E+00, -.45685600E+01, -.10047100E+03, -.34367100E+02, -.10520800E+02, 0.58262500E+02, -.26094600E+03, 0.13047900E+03, 0.20842100E+03, 0.13010800E+03, -.34129400E+02, 0.43568900E+02, -.43540700E+02, -.12599200E+03, 0.89750100E+02, 0.42701200E+02, 0.26928600E+03, -.12450300E+03, 0.67947400E+02, -.45436200E+03, 0.61292100E+02, -.20074300E+03, -.68175900E+02, -.57442700E+02, -.33623700E+03, -.98013200E+02, -.11576600E+03, 0.12384000E+03, -.17212500E+03, 0.89108100E+02, -.46385900E+02, 0.88719800E+02, 0.13890100E+03, 0.92620500E+02, 0.72997000E+02, 0.19794400E+02, -.70747800E+02, 0.62146200E+02, -.37122700E+02, -.10703400E+02, 0.65051800E+01, -.77877700E+01, 0.20618300E+02, -.11159600E+02, -.11740900E+02, -.47463800E+01, -.11842100E+02, 0.10536300E+01, 0.58738500E+00, 0.46780100E+02, -.12112300E+01, -.22282300E+02, 0.19548100E+02, 0.81241600E+01, 0.76223800E+01, -.30146300E+02, -.45225900E+01, -.24315200E+02, -.15788900E+02, -.24649100E+02, 0.18471800E+02, -.60625300E+02, -.27238900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.59603500E-01, 0.58533800E+00, 0.94570500E-01, -.24235700E+00, -.60127400E-01, -.18287900E+00, 0.37683000E-01, -.65795500E-01, 0.77704400E-01, 0.35720500E+00, 0.31872900E-01, -.27316600E+00, -.59724000E-02, 0.54642600E+00, 0.17060600E+00, -.56570900E-01, -.77327800E-02, -.66314000E+00, -.32605500E-01, 0.10061800E+00, -.16251700E+01, -.12694800E+01, 0.11631500E+01, -.76541400E+00, 0.41948500E-01, 0.29698600E+00, -.80043200E-02, 0.91865600E-01, 0.20332200E+00, 0.13976300E+01, 0.89830900E-01, 0.42294500E-01, -.12693900E+00, 0.75941500E-01, -.30879000E-02, 0.27677000E+00, -.67248100E-02, -.35219500E-01, -.10729500E+00, -.32658900E-02, 0.19924200E+00, 0.20558700E+00, -.88555200E+00, 0.22666700E-01, -.54373500E+00, 0.67436300E+00, 0.26109200E+00, -.25857200E-02, 0.53034700E-01, 0.31244600E+00, -.40060500E+00, -.51959500E-01, -.16925100E-01, 0.11817700E+00, 0.20374500E+00, 0.21204000E+00, 0.72666500E-02, -.42458600E-01, -.16645100E-02, -.65298600E+00, -.43288400E+00, -.23729800E+00, -.22614700E-01, -.29005700E+00, -.73710600E-02, -.34294800E+00, -.59638700E-02, -.12123600E+00, 0.82538800E-01, -.20107800E-02, 0.12804100E+00, -.84698600E-01, -.99683900E-02, 0.32494900E-01, -.38577800E-01, 0.32388900E-01, -.60626300E-01, -.58267300E-01, -.32527600E+00, 0.18277900E+00, -.59454600E-03, 0.17179800E+00, -.64974000E+00, 0.27279800E+00, 0.86567200E-01, 0.84083700E-01, -.78052700E-01, -.27225200E-01, -.19606700E+00, 0.11926500E+00, -.30948400E+00, 0.17998200E-01, -.55581200E+00, -.26773500E+00, 0.33429500E-01, 0.46505900E+00, -.20281400E+00, -.49072200E+00, 0.16273200E+00, 0.36712000E-01, -.45360100E+00, -.28337700E-01, 0.22163500E-01, 0.51613000E-01, -.10927700E+00, -.32808100E-01, -.26154900E+00, -.44659800E-01, 0.11107000E+00, 0.18307500E+00, -.19656000E-01, 0.52367100E-01, -.11798700E+00, -.38453000E-02, 0.30139100E-01, -.40924600E+00, 0.88525700E-01, -.30479300E+00, -.43691600E-01, 0.31266500E+00, 0.25593500E+00, -.50519400E+00, -.37652700E+00, 0.22036100E+00, 0.57769600E-02, -.93998100E-01, 0.16424400E+00, 0.94377400E+00, -.57197600E-02, -.13397000E+00, -.24847100E+00, 0.17920200E+00, -.22201300E+00, 0.41162700E-01, -.20450400E+00, 0.25474600E-05, -.48998700E+00, 0.13498500E+00, 0.32032200E-02, 0.14577800E-01, 0.96548600E-01, -.19564000E-01, -.35162200E-01, -.15015900E+00, -.27682000E+00, -.39350200E+00, -.28930000E-01, -.32389600E+00, -.38853200E+00, 0.12671200E+00, -.42039700E-01, 0.10403400E+00, 0.84598600E-01, 0.70171500E-01, -.18314700E-01, -.37844800E-01, -.85138900E+00, -.18754600E-01, 0.43082800E+02, 0.15515700E+02, -.25806300E+02, 0.21540900E+02, -.10155800E+02, 0.28343300E+01, 0.90114900E+02, 0.13747800E+03, -.68481100E+02, -.28008400E+01, -.68753900E+02, 0.48783300E+01, 0.66568400E+01, 0.44469700E+02, 0.14967500E+03, 0.58706700E+02, 0.20175000E+02, -.12588400E+03, -.22262000E+02, 0.11000100E+02, -.10327400E+02, 0.11152100E+02, -.19968500E+02, -.23070200E+02, 0.51802100E+02, 0.17415900E+02, 0.44186500E+02, -.35593700E+02, -.42689100E+02, 0.67136900E+02, -.32655900E+02, 0.50849700E+02, -.33534400E+02, 0.56740900E+01, 0.16964600E+02, -.11227600E+02, 0.28403300E+01, -.30631700E+02, 0.11067800E+02, -.10492100E+03, -.11070400E+03, 0.56336700E+02, -.86275400E+02, 0.55260700E+02, -.13453600E+03, 0.26361100E+02, -.11197100E+02, -.63017700E+02, 0.20544400E+02, 0.98815500E+02, 0.69115400E+02, 0.10226100E+02, -.59842100E+01, -.10294300E+03, -.50566200E+01, 0.28271600E+02, -.19236000E+02, -.12532900E+01, 0.17311600E+02, -.31839600E+02, -.39893500E+02, 0.10970400E+03, 0.41497000E+02, -.20801400E+02, -.50858900E+02, -.20734800E+02, -.31528700E+02, 0.16182600E+02, -.40555000E+02, -.23969900E+02, -.15346600E+02, 0.17055000E+02, 0.44545600E+02, 0.11142700E+03, -.52900000E+02, -.38351000E+02, -.55580000E+02, 0.33947400E+02, 0.95886300E+01, 0.16520600E+02, 0.11465600E+03, 0.60050800E+01, -.21308300E+02, 0.13209500E+02, -.39848000E+02, 0.19741400E+02, 0.59422500E+02, 0.19895000E+02, 0.32373100E+02, 0.53237000E+02, 0.96233300E+01, -.34635600E+02, -.34808900E+02, 0.33224800E+02, -.88627200E+02, 0.39306000E+01, -.78310100E+01, 0.13924000E+01, -.45371900E+01, -.70148700E+00, -.35690500E+01, 0.81774700E+01, -.45963400E+00, 0.31611200E+01, 0.26326200E+01, -.19369100E+02, -.38016800E+01, -.15856900E+02, 0.13371200E+02, 0.27524600E+01, 0.20694300E+01, -.35482600E+02, 0.24348700E+01, -.17624500E+02, 0.82607700E+00, -.46624300E+02, 0.12178200E+01, 0.17945600E+02, -.12398700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42896300E+01, 0.84562500E+00, 0.85229600E+00, -.19759400E+01, -.28918700E+01, 0.66948400E+00, 0.50833600E+00, -.21705900E+01, 0.17495000E+00, 0.52844200E+00, -.42042800E+01, -.20701300E+01, -.13061900E+01, -.26810300E+01, 0.98550700E+00, 0.64094000E+00, -.14815600E+01, 0.60160900E+00, 0.52333800E+00, -.14609600E+01, 0.16971300E+00, 0.54389800E+01, -.58159100E+01, 0.24514400E+01, -.97498000E-01, -.11691900E+01, 0.18275300E+00, -.25390200E+00, -.11764800E+01, -.59426000E+00, 0.18558800E+00, -.67496100E+00, 0.17439000E+01, -.71699000E+00, 0.14229700E+00, -.23663600E+01, -.63327700E-02, -.12080500E+01, 0.59275600E+00, -.15258300E+00, 0.13873400E+01, -.74810000E-01, -.53676300E+01, 0.20346200E+00, -.69976200E+00, 0.10149100E+01, -.14446600E+00, -.11000000E+01, -.60301000E+00, -.19930200E+00, 0.19673300E+01, 0.11705800E+01, 0.25774200E+00, 0.17089700E-01, 0.77520800E+00, -.96592200E+00, -.23853100E-01, 0.81230200E+00, 0.65506000E-03, 0.10939400E+01, 0.86746500E+00, 0.42773200E+00, 0.71598900E-01, 0.15903900E+01, -.36119900E+00, 0.34419100E+00, 0.12616700E+00, -.40913900E+00, 0.15343300E+00, -.29807000E-02, 0.55079200E+00, 0.46794500E+00, 0.65018600E+00, 0.62428400E-01, 0.58018500E+00, 0.13885600E+00, 0.34462900E+00, -.87078200E-01, 0.18746500E+01, 0.16031300E+00, 0.13066100E-02, -.13030400E+01, 0.14302500E+01, -.43902600E+01, 0.24845600E-01, -.77836400E+00, -.80769500E+00, 0.61377300E+00, -.66035200E+00, 0.12481500E+00, 0.39698700E+00, 0.18573200E+00, 0.39619300E+00, -.90881500E+00, 0.31370400E+00, 0.10954300E+01, -.20966600E+00, -.23072500E+01, 0.10727400E+01, 0.89248500E+00, -.67129000E+00, -.12034400E+00, -.10409500E+00, 0.44642300E+00, -.32433700E+00, 0.42119900E+00, 0.38901400E+00, 0.13588600E-01, 0.15890400E+01, 0.73412000E-01, 0.64471300E+00, -.60975700E-01, -.23428400E+00, 0.26946500E-02, 0.74213300E+00, -.99372100E+00, 0.73246200E+00, 0.16688100E+00, -.22156800E+00, -.11046000E-01, 0.81916400E+00, -.95319800E+00, 0.74575100E+00, -.64564700E-01, -.10483700E-01, -.76837100E+00, 0.40946400E+00, 0.83995500E+00, 0.64878900E+00, 0.15705700E+00, 0.87352000E+00, 0.64786400E+00, -.41502100E+00, -.96305100E-01, -.39065500E+00, 0.11890500E-01, 0.49735800E+00, -.37600600E+00, -.84181500E-01, 0.31625100E+00, 0.43003600E+00, -.11808500E+00, -.18508200E+00, 0.78376300E-01, -.18084500E+00, 0.53309600E-01, 0.41361900E-01, 0.85944300E+00, -.61848000E+00, -.87953600E+00, 0.39634700E-01, 0.10879100E+00, 0.74668300E-01, -.28866100E+00, -.29914500E+00, 0.76345900E-01, -.34348700E+01, 0.11729800E+00, -.96274400E+00, -.16786200E+03, 0.15532000E+03, 0.28064400E+03, 0.80569300E+02, -.90334500E+02, 0.17455000E+03, -.12562300E+04, 0.62663900E+03, 0.26840500E+03, 0.62737800E+03, 0.13989900E+03, 0.15600900E+03, 0.50982700E+02, 0.11426900E+03, 0.50494800E+03, 0.76188000E+02, 0.70543700E+03, 0.29574700E+03, -.14751900E+03, -.20800900E+03, -.14784100E+03, 0.22102900E+02, 0.20462000E+03, -.24968200E+03, -.94081400E+02, -.17306100E+03, 0.10752900E+03, -.11876100E+03, 0.69187400E+02, -.33707600E+02, -.64140900E+02, -.34522500E+02, -.52893800E+02, -.47650400E+02, 0.41544000E+02, 0.79072100E+02, -.43626300E+02, -.11991800E+02, -.30407000E+03, -.15324800E+04, 0.76431300E+03, -.34117100E+03, 0.76688100E+03, -.48697200E+03, -.54100400E+03, 0.52699300E+03, -.37564300E+02, 0.70489600E+03, -.46136700E+03, 0.63215700E+03, 0.30272800E+03, -.15554800E+03, -.17794400E+03, -.15097400E+03, 0.26431600E+02, -.17841400E+03, 0.26988500E+03, 0.14200100E+03, -.10859200E+03, -.97057800E+02, -.11905800E+03, 0.55344900E+02, -.29217600E+02, -.64394800E+02, -.27697100E+02, -.13251500E+03, -.13669800E+02, -.11868600E+03, -.97636800E+02, -.74020500E+01, 0.19997000E+02, 0.22220800E+03, -.54749800E+03, 0.28535100E+03, 0.33056400E+02, 0.27394600E+03, 0.76323800E+02, -.43087000E+02, 0.21028400E+03, 0.24018400E+03, 0.15332000E+03, 0.27546400E+02, 0.39750200E+03, 0.19300000E+03, -.96556400E+02, 0.82782500E+02, -.96116300E+02, 0.86020300E+02, 0.21030700E+03, -.76538500E+02, -.14949500E+03, -.64780700E+02, 0.16705100E+03, -.11699500E+03, -.37541600E+01, 0.18444400E+01, 0.45882800E+01, 0.34686800E+01, 0.71697100E+01, 0.14054900E+02, 0.30074800E+01, 0.92640100E+01, 0.18674200E+02, -.46063300E+01, -.87461800E+02, -.38828900E+01, -.46257900E+02, 0.37062700E+02, 0.20302500E+01, 0.19478500E+02, -.36012200E+02, 0.96801800E+01, -.35153900E+02, 0.48246600E+02, -.71320300E+02, 0.41662100E+02, 0.72863400E+02, -.17540500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.52851100E+01, -.15553900E+01, 0.23118800E+01, -.10004900E+00, 0.30843800E+01, -.18300700E+00, -.57594500E+00, 0.10871100E+01, 0.22065800E+00, -.43165500E+00, 0.11499100E+01, 0.10253600E+01, -.38769000E+00, 0.46755800E-01, 0.14927700E+01, -.36950300E+00, 0.12753200E+01, 0.12599500E+01, 0.13653200E+00, -.69449500E+00, 0.67792500E+00, 0.16211300E+01, -.20663100E+01, -.26519700E+00, 0.27379900E+00, -.85498800E+00, -.11675900E+00, 0.42525600E+00, 0.28980800E+00, -.41727300E+01, 0.77053300E+00, 0.23590200E+00, -.44459000E+00, -.34610300E-01, 0.14824000E+00, -.17186400E-01, 0.77880800E-01, -.14604500E-01, -.11585800E-01, -.30518200E+00, 0.53242000E+00, 0.17447900E-01, -.49199300E+00, -.32550400E+00, 0.77527800E+00, 0.14131700E+01, 0.47588500E+00, 0.49313800E+00, 0.35535900E+00, 0.10091000E+01, 0.55697400E+00, 0.29254300E+00, -.34665000E+00, 0.51556800E+00, -.38383900E+00, 0.52734400E+00, -.85499100E+00, 0.74033200E+00, -.35493500E-02, 0.36900300E+00, 0.16773100E+00, 0.20905800E+01, -.34441300E+00, 0.32072400E+00, -.14028100E+00, -.12326800E+01, -.18243100E-01, 0.91624500E+00, 0.31316200E+00, 0.38361100E-02, 0.46556000E+00, 0.82997800E+00, -.16238300E+00, -.35748000E+00, -.28765200E+00, 0.31651900E+00, 0.14026100E+00, -.38978400E+00, -.10120500E+01, 0.53504900E+00, -.33460900E-02, 0.40626400E+00, -.19304400E+01, 0.32662300E+01, 0.16403300E+00, 0.94223900E+00, 0.38622900E+00, 0.52586500E+00, 0.81536000E+00, -.21301900E+00, -.15784500E+00, 0.25820200E-01, -.18907300E+01, -.23200500E+01, -.90300800E-01, -.31668100E+00, 0.48106900E+00, 0.18048100E+01, -.11044400E+01, 0.30255100E+00, -.21713500E+01, -.12419200E+00, 0.17814100E-01, -.16599800E+00, -.32238700E+00, -.80434000E+00, 0.65752000E+00, -.92613700E+00, 0.16189800E+00, -.41240400E+00, 0.44643900E+00, 0.89039200E-01, 0.12633900E+00, 0.15084800E-01, 0.13914400E+00, 0.73213700E-01, 0.17562100E+00, -.75438300E-01, 0.10173700E+00, 0.43793600E-01, 0.42259400E+00, 0.11752500E+01, 0.47969800E+00, 0.69486400E+01, -.36191200E-02, 0.13992100E+00, -.16772500E+00, 0.24049800E+01, 0.35639500E+00, 0.36755200E-01, 0.77019300E+00, -.20777500E-01, 0.35085700E+00, -.19311700E-01, 0.25245700E+00, 0.14542000E-01, 0.38167900E+00, 0.47845800E+00, -.14306700E+00, -.20765300E+00, 0.39895900E+00, 0.59978400E-01, -.88316300E-01, 0.19388000E+00, -.16737500E+00, -.16240800E+01, -.71307900E-01, -.59636700E-01, -.74053100E+00, -.83822900E+00, 0.35540000E+00, 0.58749900E-01, -.10981000E+00, 0.17337500E+00, 0.29027800E+00, 0.21825800E+00, 0.36675200E+01, -.46369900E-01, -.21027000E+00, -.62994500E+00, -.16933900E+03, 0.72949800E+02, -.59288600E+01, -.28162100E+02, -.80485400E+02, -.16307500E+04, 0.81259200E+03, 0.53560800E+03, 0.81492500E+03, 0.16525100E+03, 0.96988900E+02, 0.19390600E+03, -.37021800E+03, 0.61722600E+03, 0.10530200E+03, 0.55438300E+03, 0.14732300E+03, -.72646500E+02, -.46671300E+02, -.73616000E+02, -.57063100E+02, -.17571100E+02, 0.11159300E+03, 0.87256700E+02, -.75036500E+02, 0.44557700E+02, -.46401800E+02, 0.98093200E+03, -.48647900E+03, -.42009900E+03, -.49039700E+03, -.75115100E+02, -.52531200E+02, -.16193300E+03, 0.15087400E+03, -.31643900E+03, -.65734100E+02, -.51592700E+03, -.59216000E+03, 0.29378200E+03, 0.32230700E+03, 0.29622500E+03, 0.71688200E+02, -.18708000E+03, 0.14293600E+03, 0.51993700E+02, 0.34123200E+03, -.22953800E+03, 0.22509200E+03, 0.92027600E+02, -.42079700E+02, -.13231900E+03, -.45673000E+02, -.83287200E+02, -.24479400E+02, 0.12405000E+02, 0.85763500E+01, -.12773900E+03, -.18847000E+02, 0.23960500E+03, 0.74568400E+02, -.38250000E+02, 0.77229800E+02, -.37275200E+02, -.61643100E+02, 0.83807500E+01, -.91514600E+02, -.10720400E+03, -.49919200E+02, 0.56422300E+01, 0.20772100E+03, -.42790200E+03, 0.21982800E+03, -.20814000E+03, 0.21422600E+03, -.44913200E+02, -.28386900E+02, 0.11531700E+03, -.12610500E+03, 0.18429300E+03, 0.82634600E+02, 0.40614200E+03, -.55681900E+03, 0.27856900E+03, 0.10032500E+03, 0.27860600E+03, 0.20942400E+03, 0.11731500E+03, 0.15631800E+03, 0.11885800E+03, 0.91447400E+02, 0.86238500E+02, 0.86069000E+02, -.60609000E+01, 0.20523000E+02, -.15707700E+02, 0.31908600E+02, 0.73478100E+01, 0.15307000E+02, -.18974500E+02, 0.34180300E+01, 0.12121200E+02, 0.92874000E+01, 0.46428800E+01, -.53418500E+01, -.26404000E+02, 0.21312700E+02, 0.20267600E+02, 0.52314700E+01, -.18464600E+02, -.78389700E+01, -.25367200E+02, 0.23749100E+02, -.39406500E+02, -.15055700E+01, -.17239700E+01, -.31734700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.63687700E+01, -.11134100E+01, -.54552400E+00, 0.10951800E+01, 0.34323000E+01, -.14211800E+00, -.94394700E+00, -.10701500E+01, 0.14365600E+01, -.49161400E+00, 0.68645000E+00, -.76812700E-02, -.40855700E+01, -.10741200E+01, 0.14980000E+00, -.20074500E+00, -.16605000E-01, -.18364400E+01, -.86161900E+00, 0.22545500E+01, -.80467900E+00, -.19350800E+01, 0.32905400E+01, -.18405600E+01, 0.33974800E-01, 0.89947200E+00, 0.53939800E+00, -.10657200E+00, 0.54377400E-01, 0.53879500E+00, -.57977800E+00, 0.47418500E+00, 0.12654200E+01, 0.11650200E+01, -.11551400E+00, 0.43857100E+00, -.24865000E-01, 0.10427800E+00, -.69957800E+00, -.72266100E+00, -.45804800E+00, 0.22265200E+01, 0.31446100E-01, -.19454200E+00, -.63839200E+00, 0.13309500E+01, 0.29080600E+00, 0.17465000E+00, 0.10873300E+01, 0.17685100E+01, -.82703200E+00, -.15982200E+01, -.16313000E+00, 0.61543700E-01, 0.42046400E+00, 0.14431900E+01, 0.15645100E+00, 0.31701800E+00, -.33684700E-03, -.13770700E+01, -.50129500E+00, -.57219900E+00, 0.27609200E+00, 0.34027800E-01, 0.66275900E+00, -.74566900E+00, 0.33565300E-01, -.88255200E-01, 0.25227900E+00, -.16265800E-02, 0.41677400E+00, -.26218100E+00, -.12406600E+01, 0.22964200E+00, -.17860200E+01, 0.16278400E+00, 0.42903100E+00, 0.11014500E-01, -.20115800E+00, -.33121900E+00, -.24683100E-02, -.74410800E+00, -.26117400E+00, -.29929600E+01, -.44065700E+00, -.70262900E+00, -.72680400E+00, -.67526400E+00, -.14231600E+00, 0.35016600E+00, 0.47008500E+00, -.94741300E-02, 0.55741400E+00, 0.49400300E+01, -.29391800E+01, -.36718200E+00, 0.74956300E+00, 0.36622900E+01, 0.39382400E+00, -.11651300E+01, 0.82446400E+00, -.17489700E-01, 0.16036400E+00, 0.24431100E+00, -.98355200E+00, -.15374900E+00, -.12458300E+01, 0.50450600E+00, -.13114700E+01, 0.72970500E+00, -.20896100E+01, 0.21885000E-01, -.33165000E-01, 0.86995200E-03, -.25214200E+00, 0.62672700E+00, -.63968300E+00, -.39728300E+00, 0.10436500E+00, -.48943400E+00, 0.90748700E+00, -.91084400E+00, -.59582200E+00, -.14316100E+01, 0.54135000E-02, -.21378600E+00, 0.10092600E+00, -.22853300E+00, -.49677300E+00, -.22032000E+00, -.13283900E+01, 0.18108300E-01, -.49370800E+00, 0.10094900E+00, -.12780000E+00, -.88882400E-02, -.99499500E+00, 0.84838800E+00, -.17795700E-01, 0.12087100E+00, 0.43382800E+00, 0.21117500E-01, -.30003100E-01, -.52208000E+00, -.88463400E+00, -.37432300E-01, 0.77690800E-02, 0.27123600E+00, -.82293300E+00, -.83434200E+00, 0.17878000E+00, -.50270000E+00, 0.43320600E+00, 0.46035600E+00, -.50999000E+00, -.55448200E-01, 0.71939800E+01, -.10536900E+00, -.15051300E+01, 0.27083600E+00, -.11009200E+01, 0.18314100E+03, -.68017800E+02, 0.27831200E+02, 0.45565300E+03, -.21470100E+04, 0.10723500E+04, 0.78823300E+03, 0.10736200E+04, 0.53739900E+02, 0.20899800E+03, 0.21805700E+03, -.72333800E+03, 0.24053000E+03, 0.21792800E+03, 0.14929800E+04, 0.75556100E+01, -.26261900E+01, -.70378300E+02, -.36880600E+01, -.93604300E+02, 0.39834900E+02, -.28816100E+02, -.75519500E+02, 0.32263000E+02, 0.99024300E+02, -.20378600E+03, 0.15127000E+03, -.74138300E+02, 0.78103900E+02, -.75516500E+02, 0.64033000E+02, -.64483800E+02, 0.20494600E+02, 0.34258500E+02, -.40573900E+01, -.87048200E+02, -.13316700E+03, 0.32579600E+03, -.16244200E+03, 0.47233200E+03, -.16366200E+03, -.16502500E+03, -.76084900E+02, 0.21805400E+02, -.70712100E+02, -.31992100E+03, -.12300100E+03, 0.32843600E+03, 0.16963200E+04, -.85021500E+03, -.53835700E+03, -.84792300E+03, -.82611600E+02, -.22915300E+02, -.32417600E+03, 0.40897100E+03, -.39887200E+03, -.58226400E+02, -.93416100E+03, 0.13456600E+03, -.67132000E+02, -.21257000E+02, -.67203500E+02, 0.11901500E+02, 0.65239900E+02, -.78707900E+02, -.90012300E+02, -.15122100E+03, 0.58951400E+02, 0.17083200E+02, 0.10177100E+03, -.53900200E+02, 0.31341300E+03, -.50318700E+02, 0.13685800E+03, 0.25160400E+03, -.54416900E+02, 0.12662300E+03, 0.92725200E+02, 0.32742600E+03, -.15080300E+03, -.38703900E+03, 0.19225500E+03, 0.22366900E+03, 0.19330500E+03, 0.10800800E+03, 0.70783400E+02, 0.46429500E+02, -.83097600E+02, -.45569000E+01, 0.75461500E+02, -.76613200E+02, -.17515000E+01, -.11747600E+01, 0.14129700E+02, 0.12361000E+02, 0.35982400E+01, 0.61202700E+01, -.24079400E+01, 0.62221600E+00, 0.20988800E+01, -.68160100E+01, -.23752800E+01, -.45718400E+01, 0.19805900E+01, 0.21197100E+02, -.22184900E+02, 0.22098700E+02, 0.55061200E+02, 0.32968700E+02, -.91943800E+01, 0.17641900E+02, 0.10259200E+03, -.29079700E+02, 0.77715400E+02, -.22244800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13147100E+01, 0.14490200E+00, 0.65938700E+00, -.90012400E+00, -.47315600E+00, -.54762100E+00, 0.11057700E+00, 0.28239200E+00, -.45632500E+00, -.18726700E+00, -.11769000E+01, -.42707900E+00, -.67502000E+00, -.28663500E+00, 0.16864500E+00, 0.22358100E+00, -.24181200E+00, 0.40163100E+00, 0.31919400E+00, -.93593300E+00, 0.29897000E+00, -.53165000E+00, -.34296300E+00, 0.10813200E+00, -.45473800E-01, 0.15036900E+00, 0.32145700E+00, 0.10650600E+00, 0.19994600E+00, 0.13589600E+01, 0.10546600E+00, 0.20125800E+00, 0.92401900E+00, -.22940100E-01, -.30392200E-01, 0.21624700E+00, 0.22790700E-01, -.59461000E-01, -.14946000E+00, 0.99048700E-01, 0.20086300E-01, 0.11206800E+00, 0.52730000E+00, 0.98666000E-01, -.17138100E+00, -.17485800E+00, 0.36142000E-01, 0.27676200E+00, 0.17511700E+00, 0.19499300E+00, 0.10326800E+00, -.17102000E+00, 0.61074300E-01, 0.45977900E-03, 0.24560800E-01, -.11499500E+00, 0.20283400E+00, -.27624200E+00, -.69063000E-03, 0.26394800E+00, 0.87047700E-01, -.45739500E+00, 0.17433500E+00, 0.27477100E-01, -.52732300E+00, -.76876700E-01, -.46409200E-02, 0.37202400E+00, -.24221300E+00, -.34831200E-02, 0.31570200E+00, 0.76184900E-04, -.24378700E+00, 0.16001500E+00, -.30302500E+00, 0.54670000E-01, -.23150400E-01, 0.19050800E+00, -.29207200E+00, -.13596800E+00, -.17778300E-03, -.29558200E+00, 0.16401800E+00, -.58744100E+00, -.11309300E+00, -.17052200E+00, 0.25811400E+00, -.20516700E+00, -.12806900E+00, 0.39856200E-01, 0.13589800E+00, 0.11420200E-01, 0.61682700E-01, 0.41969100E+00, -.56373500E-02, -.13307500E+00, -.66785600E-01, 0.42517700E-01, 0.14333800E+00, -.13513400E+00, 0.23530700E+00, -.24211100E-01, -.37546900E-02, -.27652100E-01, -.12391500E+00, 0.35411400E-01, -.62340500E-01, 0.38896500E-01, -.16109400E-01, 0.54313700E-01, -.15229600E+00, -.24621300E-01, 0.35075600E-01, 0.14340400E-03, -.31805500E-01, -.18010800E+00, 0.37661500E-02, 0.10103900E-01, 0.19984000E-01, -.34735000E+00, -.24780100E-02, 0.13536300E+00, -.11454400E+00, 0.12245700E+01, 0.46591700E-02, -.28641500E+00, 0.37308400E-01, 0.23608800E+00, 0.65005600E-01, -.13340600E-01, 0.62669800E-01, -.12391500E+00, -.10122500E+00, 0.24364400E-01, -.57929400E-02, 0.11964900E-02, -.44577000E+00, 0.13157500E+00, -.45956900E-01, 0.39060200E-01, 0.14177500E-01, 0.71817800E-01, 0.36382200E-01, 0.13154500E+00, -.10320500E+00, 0.40965000E+00, 0.87471800E-02, 0.87341900E-01, 0.14200700E+00, 0.32895400E+00, -.11083500E+00, 0.10461400E+00, 0.63820300E-01, -.33983000E-01, 0.54064400E-01, -.91852000E-01, -.11788700E+01, 0.12551500E-01, 0.67032500E+00, -.18541000E+00, -.20389000E+00, -.19202200E+00, -.37158800E+02, 0.22372000E+02, -.12583600E+02, -.81715300E+03, 0.40773900E+03, 0.22737200E+03, 0.40838200E+03, 0.27618000E+02, 0.95183000E+02, 0.32836300E+02, -.19605500E+03, 0.10146000E+03, 0.62075400E+02, 0.46564000E+03, 0.89249700E+02, -.44269700E+02, -.50718100E+02, -.44613900E+02, -.18038400E+02, 0.15411700E+02, -.44602300E+02, 0.99579600E+01, -.34975200E+02, 0.22214000E+02, -.42259400E+02, -.41548300E+02, 0.21276200E+02, -.74321000E+02, 0.20793600E+02, 0.48572100E+02, -.18995400E+02, -.34619400E+01, -.14834000E+02, 0.28015400E+02, -.13979200E+02, -.71261500E+02, -.40353500E+03, 0.20226200E+03, 0.14999000E+03, 0.20189300E+03, -.64033300E+01, -.22770800E+03, 0.24829700E+03, 0.12737500E+03, 0.18558200E+03, -.24444000E+03, 0.19109000E+03, 0.43233200E+03, -.21831800E+03, -.19105400E+03, -.21604600E+03, -.17384700E+02, -.78637800E+02, 0.32254400E+02, 0.12918300E+03, -.60763700E+02, -.43432300E+02, -.23142000E+03, -.38330000E+02, 0.19038500E+02, 0.92247200E+02, 0.19161800E+02, -.30404700E+01, 0.20330200E+02, -.21566000E+02, -.13850600E+02, -.15088500E+02, 0.29724100E+02, 0.87582100E+02, -.13359100E+03, 0.67194000E+02, -.10730600E+03, 0.66862700E+02, 0.43991700E+02, 0.66139100E+02, -.46255200E+01, -.23058300E+02, 0.28132800E+02, 0.10255900E+03, 0.80247400E+02, 0.75936500E+02, -.38865200E+02, -.78712700E+02, -.37869300E+02, 0.45044200E+01, 0.15749400E+02, -.10573600E+02, -.35491700E+02, -.32721700E+02, 0.26833700E+02, -.28675200E+02, -.53238000E+01, 0.94192400E+01, 0.25968000E+00, 0.12336500E+02, -.40897500E+00, 0.12789700E+02, -.76708000E+01, -.22229400E+01, 0.60980600E-01, -.88723300E+01, -.17283100E+02, 0.49774900E+01, 0.12849900E+02, -.88619600E+01, -.41945800E+01, 0.52230300E+01, 0.27327900E+02, 0.63254600E+01, 0.12084400E+02, 0.85352600E+01, 0.22402100E+02, 0.94208100E+01, 0.19509600E+02, 0.28154700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44677900E+01, 0.74949000E+00, 0.40530300E+01, -.43203300E+01, -.32977300E+01, -.46433600E+00, 0.56754700E+00, -.19200800E+01, 0.10437200E+00, 0.23503300E+00, 0.15606000E+01, 0.83297900E+00, -.30527700E+01, -.20050100E+01, -.53545400E+00, 0.30969900E+00, -.64702800E+00, -.23806200E+01, 0.66109000E-01, -.70384300E+00, 0.27577000E+00, -.17667800E+01, 0.66551100E+01, -.26730800E+01, -.93692400E-01, 0.70142800E+00, -.92863700E-01, -.46893500E+00, 0.13639200E+01, 0.26435100E+01, -.34739600E+00, -.31882900E+00, 0.15567200E+01, -.26929100E+00, 0.54261600E-01, -.11951700E+01, -.52517400E-01, 0.90193200E+00, 0.96836400E+00, -.59802300E+00, -.11957100E+01, -.83619500E+00, 0.24876100E+01, -.48061000E+00, 0.12923700E+01, -.41084300E+00, 0.97231900E-01, -.16719800E+00, -.36799900E+00, -.79522600E+00, -.25053100E+00, -.55949400E+00, -.18272000E+00, 0.45776600E-01, 0.35604900E+00, 0.48498600E+00, -.23279200E+00, 0.18893900E+01, -.44288600E-02, 0.24097800E+00, 0.69098200E+00, 0.28706300E+00, 0.11727700E+00, -.30114700E+00, 0.14259700E+01, -.47776800E+00, -.13337900E+01, 0.81756600E+00, -.56645100E+00, -.31633100E-02, -.45337400E+00, -.24299900E+00, -.79292700E+00, -.17044200E+00, -.33633300E+00, -.49937300E-01, 0.11769100E-01, 0.18763600E+00, -.71146500E+00, 0.12114500E-01, 0.16056400E-02, 0.82206800E+00, -.32669000E+00, 0.12606500E+01, -.16513400E+00, 0.95933400E+00, 0.12113700E+00, 0.31044500E+00, 0.88897300E+00, -.19044800E+00, 0.79108000E+00, -.37432300E-01, -.79016800E+00, -.18573800E+01, -.15102300E+01, -.10562000E+01, 0.64045500E+00, 0.39715900E+01, -.11371600E+01, -.97210100E+00, 0.11519700E+01, 0.12458300E+00, 0.17215300E+00, -.57185700E+00, -.20451500E+00, 0.47414000E+00, -.31490300E+00, -.68131400E+00, -.13039100E+01, 0.64675200E+00, -.35563300E+00, 0.10007200E+00, 0.12892100E+00, 0.17331600E-01, -.49326800E+00, 0.52210100E+00, -.62234600E-01, 0.27129200E+00, 0.20485700E+00, -.10961100E+01, 0.43032000E+00, 0.36769800E+00, 0.78927100E+00, -.20134200E+01, -.60376200E-02, -.35034400E+00, 0.11924600E+00, -.16301600E+01, -.12322800E+00, -.97920700E-01, -.51042100E+00, -.96459100E+00, 0.55426500E+00, 0.16570100E+00, -.30532600E+00, -.33330000E-02, -.61651200E-01, 0.11199800E+01, 0.33863300E-01, -.23150800E+00, -.12671800E+00, 0.10196600E+00, -.73999200E-01, 0.36774100E+00, -.35012000E+00, 0.10907600E+01, 0.87876100E-01, 0.74331100E-01, 0.11042800E+01, -.19050400E+00, 0.73817300E-01, -.56172400E-01, -.13354800E-01, -.42404500E+00, -.88213600E+00, -.46488200E-01, 0.71367700E+00, 0.57503800E-02, -.16189600E+01, -.15397800E+00, -.78995700E+00, -.20372600E+00, 0.22345700E+01, -.12761500E+03, 0.35544900E+03, -.95832500E+03, 0.47957800E+03, 0.83535600E+03, 0.47950300E+03, -.17530400E+03, -.26335100E+02, 0.39967500E+03, -.17035900E+03, 0.17973800E+03, 0.60030800E+02, 0.27558000E+03, 0.59730900E+02, -.29688800E+02, -.13320700E+03, -.29851400E+02, -.14231800E+03, -.52520200E+02, 0.85977300E+02, 0.44150700E+02, 0.62435300E+02, 0.17096300E+02, -.97536400E+02, 0.47787800E+03, -.23759500E+03, -.49586100E+02, -.23892300E+03, -.28035200E+02, 0.40752900E+02, -.58569800E+02, 0.65730000E+02, -.95646000E+02, -.25462500E+02, -.17157400E+03, -.68122300E+02, 0.39264100E+02, 0.31624600E+03, 0.33648500E+02, -.23410600E+03, 0.21361000E+03, -.21055100E+03, -.62933100E+03, -.49206200E+03, 0.22882100E+03, 0.18062700E+03, 0.34638500E+03, -.17756700E+03, -.33702600E+03, -.17331600E+03, 0.12940000E+03, 0.11232400E+03, -.25670600E+03, 0.45796100E+02, -.13677100E+03, 0.47983100E+01, 0.22384200E+03, 0.27415300E+03, -.13565500E+03, -.26861700E+03, -.13704600E+03, -.23001500E+02, 0.43808800E+02, -.75436800E+02, -.63467700E+02, -.12206200E+03, 0.21591400E+02, -.16132800E+02, 0.12274200E+04, -.61429600E+03, -.30533500E+03, -.61361900E+03, 0.18334200E+03, 0.27948700E+03, -.22826800E+03, 0.34772200E+03, -.14393700E+03, 0.27632600E+03, -.40273800E+03, -.47040800E+03, 0.23374600E+03, 0.43659000E+03, 0.23497200E+03, 0.25082400E+02, -.34036400E+01, 0.65545500E+01, 0.72905200E+02, 0.17999000E+03, 0.66552000E+01, -.40874700E+02, 0.29890100E+02, -.21578700E+02, -.44088900E+01, -.23723400E+02, 0.13560500E+02, 0.14539500E+01, 0.16889500E+02, 0.11340000E+02, 0.10969000E+02, 0.21331300E+02, -.37517000E+02, -.25367700E+02, -.32027500E+02, 0.32004900E+02, 0.23653000E+02, -.17286200E+02, -.54858600E+02, 0.85792000E+00, -.36786200E+02, 0.13351100E+02, -.73793000E+02, -.46908200E+02, 0.83013300E+02, -.29021600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12693700E+01, 0.16393800E+00, 0.26624200E+00, -.84112200E+00, -.11035300E+01, -.26605900E+00, 0.20712600E+00, 0.63065600E-01, -.16226900E+00, -.40418700E+00, -.98158500E+00, -.19205600E+00, -.20394900E+00, -.17625300E+01, 0.21759500E+00, 0.16092700E+00, -.43044300E+00, 0.16326200E+00, 0.24531600E+00, -.10765900E+00, 0.25975100E-01, 0.45010300E+00, -.19118200E+01, 0.86058700E+00, -.13595600E+00, 0.14008000E-01, -.38028600E-01, -.26124400E+00, -.13588200E+00, 0.82307700E+00, 0.28036700E+00, -.93787400E-01, 0.21468700E+00, -.99395900E+00, -.90410200E-01, -.50638400E+00, 0.46994700E-01, 0.34834100E+00, 0.55870400E+00, 0.29864000E+00, 0.89158700E+00, -.50480700E+00, -.50990700E+00, 0.21109100E+00, 0.17225700E+00, -.69695300E+00, -.20029000E+00, 0.22041600E-01, -.88698700E-01, -.27068600E+00, 0.95650100E+00, 0.15415100E+00, 0.89938200E-01, 0.68157600E-01, -.23132300E-01, -.20751200E+00, -.30819300E-01, -.37746600E+00, 0.65808300E-04, 0.13734200E+00, -.72417700E-01, -.13105400E+00, -.89754300E-02, 0.11409600E+00, -.10600700E+01, -.19993900E+00, -.13248300E+00, 0.16461200E+00, -.93957600E-01, -.52387500E-03, -.21632100E+00, -.21389700E-02, 0.24680500E+00, 0.51982500E-01, -.18720300E-01, -.11746100E+00, -.21817600E+00, 0.11602200E+00, 0.21121900E+00, -.17922100E+00, 0.12794600E-02, -.41200700E+00, 0.59162400E+00, -.17429000E+00, -.13467300E+00, -.42889200E+00, 0.68616200E-01, -.28602000E+00, -.12760500E+00, 0.49462800E-01, -.31372600E-01, -.48013800E-01, -.27424800E+00, -.28294700E+00, -.11074700E+01, -.97237100E+00, 0.15891900E+00, 0.19972100E+01, -.55999800E-01, 0.96762300E-01, -.47757900E+00, 0.28245700E-01, -.53585200E-01, -.92419100E-01, -.28878100E+00, 0.15250900E+00, 0.27976000E+00, 0.34514100E+00, -.45350200E-01, -.19953800E+00, -.10501400E+00, -.41883700E-01, 0.63614800E-01, -.67391600E-03, 0.19610400E-01, -.14423400E+00, 0.10823200E-01, -.15020300E-01, 0.69239000E-02, -.28112300E+00, 0.21115200E-01, 0.11913100E+00, 0.71525500E-01, 0.15424500E+01, 0.50555000E-02, -.23367000E+00, -.62039100E-01, 0.31487200E+00, 0.16185900E+00, -.30211500E-01, -.16155700E-01, 0.59603300E-01, -.51051800E-01, 0.72564700E-02, 0.26680100E-01, 0.17157400E-02, -.23824200E+00, -.14179200E-01, -.92478400E-02, 0.26662400E-02, 0.17700400E-01, -.62107000E-01, 0.59247000E-01, 0.75572300E-02, 0.13350900E+00, -.25966800E-01, 0.78150100E-02, 0.18503800E+00, -.18861000E+00, 0.34180100E-01, -.44558700E-02, 0.47387100E-01, 0.79333900E-01, -.29994000E-01, 0.46904500E-01, 0.10774400E-01, -.73065700E+00, 0.18993500E-01, 0.60773400E-01, 0.49453000E-01, 0.13927900E+00, -.19698500E-01, -.10255300E+00, -.11592800E+00, 0.10912900E+03, 0.43666200E+03, -.21889200E+03, -.14582500E+03, -.21835900E+03, -.39680300E+02, -.88685800E+01, -.35492700E+02, 0.16659900E+03, -.45019500E+02, -.14690400E+02, -.16719100E+03, -.34741100E+01, 0.18160900E+01, -.97083700E+01, 0.17378600E+01, -.11124000E+02, -.73443800E+01, 0.22179900E+02, 0.38801400E-01, 0.27146300E+02, -.33790800E+02, -.28373000E+02, -.21344600E+03, 0.10709100E+03, 0.14760600E+03, 0.10672600E+03, 0.20604300E+02, 0.59821300E+01, 0.64260400E+02, -.26375900E+02, 0.53995800E+02, 0.19770900E+02, 0.23871100E+02, 0.10070900E+03, -.50141900E+02, -.29458200E+02, -.50326800E+02, -.48647700E+02, 0.95802100E+02, -.51934400E+02, -.24440700E+02, -.86207200E+02, 0.10239500E+03, -.32605200E+02, -.10812500E+03, 0.54207200E+02, 0.36454800E+02, 0.54076300E+02, 0.21804800E+02, -.53682900E+01, 0.11884200E+02, -.26588800E+02, 0.75424300E+00, -.12355700E+02, 0.73396200E+02, 0.53560300E+02, -.26993600E+02, -.57890700E+02, -.26781400E+02, -.19351900E+01, 0.85368700E+01, -.15200600E+02, 0.98102700E+01, -.11759200E+02, 0.26772900E+01, -.14262300E+02, 0.11845000E+03, -.58725800E+02, 0.39616500E+02, -.59218200E+02, 0.31597400E+02, -.85857400E+01, -.10760800E+02, 0.48061900E+02, -.16586700E+02, -.31709600E+02, -.61091200E+02, 0.79710200E+01, -.42300400E+01, 0.35026500E+02, -.39705100E+01, -.36676600E+01, 0.17202500E+02, -.25756300E+02, -.33547900E+02, 0.45284200E+01, 0.20786700E+02, -.37741500E+02, 0.16311100E+01, -.46190700E+01, 0.37398200E+01, -.45489900E+01, 0.18553600E+01, -.30259600E+01, 0.37898400E+01, 0.81583700E+00, -.34267100E-01, 0.19465100E+01, -.38593200E+01, 0.85666400E-01, -.11594000E+02, 0.98347700E+01, -.42044600E+01, 0.26041000E+01, -.23882400E+02, 0.54738800E+01, -.11004900E+02, -.80859900E+01, -.27626700E+02, -.63022300E+01, 0.30883700E+01, 0.17008200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11406000E+02, 0.35970300E-01, -.43070700E+01, 0.65195700E+01, 0.92835900E+01, 0.26829300E+01, -.21316600E+01, 0.25331100E+01, -.42252300E+00, -.73761800E+00, -.26063700E-01, 0.30863100E+00, -.35869500E+01, 0.91890500E+00, 0.12416800E+00, -.60808000E-01, 0.92468500E+00, 0.18780300E+01, -.24886300E+00, -.16820000E+01, 0.86789300E+00, -.48108300E+01, -.35229200E+01, 0.13737500E+01, -.48046700E-01, 0.44517900E+00, 0.52472000E+00, -.53448300E+00, -.16640400E+01, 0.47710600E+01, -.81371200E-01, 0.36621000E+00, 0.64653400E+00, 0.65503600E+00, -.73685800E+00, 0.99607500E+00, -.73076000E-01, -.11546900E+01, 0.88576600E-02, 0.10483400E+01, 0.26049600E+01, 0.99143700E+00, -.62016800E+01, 0.16048800E+01, -.37336200E+01, 0.27280400E+01, 0.45306700E+00, -.38912500E+00, -.33593200E+00, 0.13540500E+01, 0.43214900E+00, 0.69052000E+00, 0.17285000E-01, 0.11472100E+01, 0.46821700E+00, -.31083400E+01, 0.27723800E+00, -.24176000E+00, -.93339800E-02, 0.49664000E+01, 0.30640600E+01, 0.48613600E+01, -.89540100E+00, -.67728100E+00, 0.52424800E+01, -.93007200E-01, 0.86380500E+00, -.87713300E+00, -.35190200E+00, 0.11945000E-01, 0.16755800E+01, -.45043100E-01, -.12349700E+00, -.12672400E+00, 0.48370000E+00, -.28398400E+00, -.87220500E+00, 0.21144300E+00, -.31338000E+01, 0.24723500E+00, -.10950600E-02, 0.19173700E+01, -.11200800E+01, -.64261300E+00, -.53442900E+00, -.71028600E+00, -.14575300E+01, 0.78720400E+00, 0.10193200E+01, 0.93312300E+00, 0.26177200E+00, -.12543900E+00, -.12589500E+01, 0.30671100E+00, 0.27157000E+01, 0.16227400E+01, 0.38357200E-01, -.11863100E+01, 0.12328100E+00, -.66597700E+00, -.81432700E+00, -.26292800E+00, -.11853000E+00, -.67131700E+00, -.15024500E-01, -.11918700E+01, -.52804000E+00, -.13149800E+01, -.42558300E+00, 0.76871800E+00, -.16590400E+01, 0.53300900E-01, -.85026800E+00, -.11222300E-02, 0.28576000E+00, 0.11550900E+01, 0.26913700E+00, -.51483500E+00, 0.22118100E+00, 0.39627400E+00, -.67308600E+00, -.17479100E+01, -.18532800E+01, 0.11389300E+01, -.15530200E-01, 0.20260300E+00, -.37128100E+00, 0.25491300E+01, -.79196200E-01, -.89757700E+00, -.49994200E+00, 0.14048500E+01, -.32164600E+00, 0.27647200E-01, 0.21073600E+01, 0.12140700E-01, 0.11330800E+01, -.21725700E+01, 0.65548200E-01, -.83864000E-02, -.22509500E+00, -.39862800E+00, -.55585300E+00, 0.56875900E+00, 0.95449600E+00, 0.13606000E+01, 0.54671000E-02, -.94810000E-01, 0.27591900E+01, 0.91818000E+00, -.16190200E+00, -.42262700E+00, 0.23030400E+00, -.10851400E-01, 0.57802600E-01, -.54182100E+00, 0.60139800E+01, -.33344000E+00, 0.85016700E+01, -.25108900E+00, -.28653600E-01, -.69364200E+00, -.50623900E+00, -.56950900E+00, 0.32854900E+01, -.60785400E+04, 0.30308800E+04, 0.25949300E+04, 0.30402500E+04, -.86677100E+02, 0.33502900E+03, 0.75709000E+03, -.19418400E+04, 0.74527000E+02, 0.27883000E+03, 0.35981800E+04, 0.23483200E+03, -.10955200E+03, -.17285700E+03, -.11737100E+03, -.23099200E+03, -.13308000E+03, -.19149100E+03, -.41561900E+03, -.40553400E+03, 0.19376900E+03, -.14635700E+03, -.99600700E+01, -.68417800E+01, -.84579600E+03, 0.49923100E+01, 0.18441600E+03, -.13370600E+03, -.82195300E+02, 0.15707500E+02, 0.32433500E+03, -.22061000E+03, 0.47689300E+03, 0.57633800E+03, -.29331300E+03, 0.12846800E+04, -.28985200E+03, 0.12933300E+04, -.64263400E+02, 0.29211400E+03, 0.47128900E+03, -.66751200E+03, -.81356600E+03, 0.30665000E+03, 0.37446600E+04, -.18975900E+04, -.11307000E+04, -.18724900E+04, -.10603500E+02, -.11660700E+03, -.66903400E+03, 0.59919200E+03, -.68272600E+03, 0.55636400E+02, -.29398000E+04, -.71294900E+03, 0.35521900E+03, 0.53688700E+03, 0.35659000E+03, 0.30930100E+03, 0.55851300E+02, 0.32024200E+03, 0.11579600E+03, 0.34885700E+02, 0.81984000E+02, 0.17160900E+03, 0.22973600E+04, -.11672000E+04, -.11673700E+04, -.11483600E+04, -.85266800E+02, 0.40927300E+03, -.10232500E+04, -.70018800E+03, -.79625800E+03, 0.86194500E+03, -.15887500E+04, 0.67785600E+03, -.34514000E+03, -.47298400E+03, -.33957100E+03, -.45494900E+03, -.56667500E+03, -.20891400E+03, 0.10328800E+03, -.60766000E+02, -.32123500E+03, 0.42759700E+03, -.20799900E+02, 0.42131200E+02, 0.13379000E+02, 0.48762900E+02, -.73083600E+01, 0.23066500E+02, -.52487200E+02, -.99535200E+01, -.37160700E+02, -.61977300E+02, 0.12043800E+03, 0.26805300E+02, 0.19779700E+03, -.14327000E+03, -.43144900E+02, 0.19874700E+02, 0.34388700E+03, 0.52404500E+02, 0.18944700E+03, -.48498700E+02, 0.43004700E+03, 0.86275800E+01, -.84784200E+02, 0.78357000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.98478800E+01, 0.24205000E+00, -.22027100E+01, 0.42656500E+01, 0.85310900E+01, 0.34259500E+01, -.21323700E+01, 0.26357100E+01, -.46970900E+00, -.40146800E+00, 0.38247400E+01, 0.10723000E+01, -.11778400E+01, 0.12348800E+01, -.51370300E+00, -.79883600E+00, 0.69052800E+00, 0.10612400E+01, 0.85705600E-01, 0.14927600E+00, 0.44908000E+00, -.34032600E+01, -.11669100E+01, 0.14575200E+01, -.41186700E-01, 0.10513000E+01, 0.31536100E+00, -.18231000E+00, -.72855800E+00, -.82563500E+00, 0.43795300E-01, 0.58817300E+00, -.23112100E+00, -.15638400E+00, -.59980500E+00, 0.11187600E+01, -.11933700E-01, 0.83198300E+00, 0.82872500E+00, 0.69360400E+00, 0.17869900E+01, 0.23057700E+00, 0.21709300E+01, 0.12414800E+00, -.66819200E+00, 0.10131200E+01, 0.11941500E+00, 0.34351100E+00, 0.11241100E+01, 0.12919400E+01, 0.63303000E-01, -.85411600E+00, -.92422900E-01, 0.48048400E+00, 0.28991700E+00, -.83045700E+00, -.41619300E+00, -.83017000E+00, 0.38405800E-02, 0.27821200E+01, 0.11913200E+01, 0.34108900E+01, -.72897000E+00, 0.18935300E+00, -.58530200E+00, -.17460700E+00, 0.11085700E+01, 0.74643300E+00, -.93902200E-01, 0.21133600E-01, 0.18822700E+00, 0.72086600E+00, 0.26995900E-01, 0.52886900E-01, 0.76418200E+00, -.40894400E+00, -.12457500E+01, -.72565500E+00, -.71535700E+00, -.10196300E+00, 0.83531900E-03, 0.20371400E+01, -.11260900E+00, -.16348900E+01, -.36326500E+00, -.68840300E+00, -.41476700E+00, 0.55324700E+00, 0.88241400E+00, 0.29873000E+00, 0.83052500E-01, -.58155400E-01, -.15492700E+00, 0.28304400E+01, 0.13613700E+01, 0.13818800E+01, -.14402300E+00, 0.25851300E+01, 0.57581100E+00, -.78999700E+00, -.95923400E+00, -.22145700E+00, -.13415500E+00, -.77535200E-01, -.53672500E+00, -.29331900E+00, 0.30683700E+00, 0.10013700E+00, 0.87752500E+00, -.38052800E-01, -.55507000E+00, -.13313100E+00, -.30577800E+00, 0.55046300E-02, 0.53261200E+00, 0.15278900E+01, -.10950300E+01, 0.49732700E-01, 0.35778600E+00, 0.15884700E+01, -.12983700E+01, 0.23829700E+00, -.24041500E+01, 0.48523000E+01, -.23780600E-02, 0.63620900E+00, -.10784300E+01, -.14514800E+01, -.89967300E+00, -.16110300E+00, -.12230300E+01, 0.10705100E+01, 0.12257100E+00, -.36601900E+00, 0.52030800E+00, -.17636000E-01, 0.18664000E+01, -.19498100E+01, 0.23548500E+00, -.19690500E+00, -.58630200E+00, -.28738700E+00, 0.60172300E-01, 0.10930500E+00, 0.17202400E+01, 0.13627400E+01, 0.33927100E-01, 0.21911300E+01, 0.19365200E+01, 0.67686500E+00, 0.32751000E+00, 0.28997200E+00, -.26914300E+01, -.84597100E+00, -.55546600E+00, 0.26669400E+00, -.13663800E+01, -.10312400E+00, -.78814500E-01, 0.77813700E+00, 0.70903400E+00, -.97844700E+00, -.19988200E+00, 0.33312400E+00, 0.50676800E+01, -.18545300E+00, 0.24342000E+02, 0.23138900E+02, 0.61072900E+00, 0.18128700E+03, -.99909000E+02, -.11309200E+03, -.10967700E+04, -.96006100E+03, 0.10473100E+03, -.24310200E+03, -.10337100E+03, 0.54393800E+02, 0.20871800E+03, 0.51886500E+02, -.21432900E+02, 0.27461800E+03, -.22737100E+03, -.15489200E+03, -.21645700E+02, 0.33472200E+03, 0.18538300E+03, 0.42999000E+03, -.23142600E+03, -.19170400E+03, -.21473500E+03, -.83081400E+02, -.82437500E+02, -.24683600E+03, -.48630300E+02, -.26722900E+02, -.19921900E+03, 0.43426700E+03, 0.28972100E+04, -.14831000E+04, -.11842800E+04, -.14506600E+04, -.23434200E+03, -.44357200E+02, -.67770700E+03, -.21544300E+03, -.12031900E+04, -.44478000E+02, -.10316400E+04, 0.62879900E+03, -.35190200E+03, -.46010900E+02, -.31404400E+03, -.21809800E+03, 0.27474900E+03, -.41228800E+03, 0.33420300E+03, 0.26976500E+03, 0.12628800E+03, -.16882600E+03, -.27679500E+03, 0.13772600E+03, 0.16442600E+03, 0.13859700E+03, 0.80613300E+02, 0.34219500E+02, 0.12190100E+03, -.41339400E+02, -.76554600E+02, 0.59929300E+02, -.22476200E+03, -.31056500E+04, 0.15429100E+04, 0.15492100E+04, 0.15541000E+04, -.86900000E+02, -.31093500E+03, 0.78835000E+03, -.16279500E+02, 0.12399300E+04, -.21669100E+03, 0.13006400E+04, -.66168700E+03, 0.33906500E+03, 0.16877100E+03, 0.33014100E+03, 0.17693600E+03, -.15543900E+02, 0.18137700E+03, 0.30609000E+02, -.63095000E+02, -.42776700E+02, 0.24003000E+03, -.29158200E+01, -.16174900E+02, 0.37299500E+01, -.34878100E+01, -.17088200E+02, -.33206700E+02, 0.77050800E+01, -.77814000E+01, -.64385600E+01, -.11533900E+02, 0.22883100E+02, 0.39611400E+01, 0.11990600E+03, -.34772600E+02, 0.74776500E+01, -.14326100E+01, 0.22689600E+03, -.29084000E+02, 0.84857000E+02, 0.81886800E+02, 0.34595700E+03, -.20591400E+02, 0.46249900E+02, -.24657600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.63911300E+01, 0.13380300E+01, -.41316800E+01, 0.15443600E+01, -.58828300E+01, 0.31955800E-01, 0.11151200E+01, -.35062700E+01, 0.23034500E+00, 0.73519800E+00, -.12844000E+01, 0.15749600E+00, 0.24074500E+01, 0.30580500E+01, -.91071000E+00, 0.99046800E+00, 0.65662100E+00, 0.11224000E+01, -.52245600E+00, -.24281100E+01, 0.47207500E+01, 0.73630500E+01, 0.54342800E+01, -.14555600E+01, 0.53737300E+00, -.23354700E+01, 0.42912600E-01, 0.12680300E+01, 0.95286800E+00, -.65075300E+00, -.13598000E+00, -.58656300E+00, 0.11986300E+01, -.85021100E-01, 0.33632700E+00, -.20887500E+01, -.76659500E-01, -.20721500E+01, -.16266400E+00, -.89672600E+00, -.15857300E+01, -.58556400E+00, -.67665800E+00, -.84265100E+00, 0.56318900E+00, 0.60080000E+00, -.63280700E+00, -.10776900E+01, -.12098900E+01, -.17329400E+01, 0.10719800E+01, 0.11995600E+01, 0.46624700E+00, -.65706300E+00, 0.16625200E+00, 0.12594300E+01, -.20908000E+00, 0.31239900E-01, -.43333900E-02, -.28776400E+00, 0.44361100E+00, 0.19860000E+00, -.30379700E-01, -.20936300E+01, 0.26195300E+01, 0.89603600E-01, -.53792100E+00, -.70953100E+00, -.34385200E+00, 0.43572500E-02, 0.31551300E+00, 0.12156200E+00, 0.51064000E+00, 0.11362000E+00, 0.99256200E+00, 0.16079000E+00, 0.46362200E+00, -.11023300E+00, 0.15568400E+01, -.72706800E-02, -.12714700E-02, -.26255500E+01, 0.15953300E+01, -.10548800E+01, 0.52234800E-01, 0.66179100E+00, -.12120300E+01, -.43819400E+00, 0.22145300E+00, -.85378400E+00, 0.71042200E+00, -.97798300E-01, 0.35672600E+00, 0.15472900E+01, 0.24597900E+01, 0.20445200E+01, 0.24877000E+00, -.39153600E+01, -.70710700E+00, 0.90452000E-01, -.15253100E+01, -.24640100E+00, -.23638600E+00, -.26683500E+00, -.81425200E+00, 0.86727000E+00, 0.96940300E+00, 0.19193400E+00, -.43829900E+00, -.49993000E+00, 0.89715700E+00, -.17270300E-01, -.85429100E-01, 0.30577200E-02, -.64026100E-01, 0.16010300E+00, -.17209400E+00, -.12289600E+00, -.11464900E+00, 0.67947500E+00, 0.68180200E+00, -.49525700E+00, -.14488100E+01, 0.38069000E+01, -.75215500E-02, -.15331300E+00, -.52517100E+00, 0.24562500E+00, 0.85255000E-01, -.27404700E+00, -.27957400E+00, 0.82114200E+00, -.30877000E+00, 0.19127400E+00, -.14945200E+01, 0.33633700E-03, -.37347500E+00, -.18053100E+01, 0.86648800E-01, 0.25086800E+00, -.59445900E+00, -.40271800E+00, 0.14452400E-01, 0.91565900E-01, 0.68095600E+00, 0.72628100E+00, 0.13949500E-01, 0.17051000E+01, 0.10703600E+01, -.18471300E+00, -.12279900E-01, -.16227600E+00, -.40263300E+00, -.16605900E+00, -.44705400E+00, -.10660400E-01, -.33398100E+01, -.28165200E-01, -.80631100E+00, 0.94022100E+00, 0.48718400E+00, -.32218000E+00, -.46734300E+00, -.22223900E+00, 0.37421100E+01, -.22062400E-01, 0.22445600E+00, 0.49244500E+03, 0.34774100E+00, -.73613100E+02, -.26064800E+02, 0.12613500E+03, -.17267700E+02, -.38361700E+03, 0.31741200E+02, 0.21161800E+03, -.16652100E+03, 0.81763900E+02, 0.60234500E+02, 0.83312200E+02, 0.72597100E+02, -.16784000E+02, 0.32266600E+02, -.65651200E+02, 0.31542700E+01, 0.31518200E+02, 0.44491100E+02, -.21324000E+02, 0.13281100E+02, -.42286000E+02, 0.10724000E+02, 0.63732900E+02, 0.64519300E+02, -.85705700E+02, -.53970600E+02, 0.33165000E+02, 0.18457900E+02, 0.19328700E+03, -.73915400E+02, 0.47189800E+02, 0.26662600E+02, 0.36217100E+02, 0.14341100E+03, 0.22693800E+02, 0.14154700E+02, -.12160600E+03, -.12992000E+03, 0.59986400E+02, 0.11260200E+03, -.12086500E+03, 0.67802000E+02, -.15254100E+03, 0.60444000E+02, 0.38521700E+02, -.16572600E+02, -.80821300E+02, -.67922700E+02, 0.20024200E+03, -.33986300E+02, -.28740900E+03, -.11416300E+03, 0.60572300E+02, 0.27602400E+01, 0.57145000E+02, 0.90795600E+02, 0.96074200E+01, 0.58380500E+02, 0.11035600E+02, 0.33079400E+02, 0.19536600E+02, -.18593200E+03, 0.62990200E+03, -.32668900E+03, -.60896500E+03, -.31462000E+03, 0.10192000E+03, 0.10981300E+03, -.17085000E+03, 0.86918900E+02, -.88793200E+02, 0.82297400E+02, -.40453700E+03, 0.18904700E+03, -.96954700E+02, -.38292500E+02, -.94819000E+02, -.12458900E+03, -.11989600E+03, -.74608400E+01, 0.31636400E+02, -.69695800E+02, -.11837300E+03, 0.93674300E+01, -.57197300E+01, -.50884000E+01, 0.16749000E+01, -.63455600E+01, -.10004500E+02, 0.15036300E+01, 0.82352600E+01, -.91985100E+01, -.14469600E+02, -.69926400E+01, -.68872600E+01, 0.71959800E+01, 0.43855400E+02, -.35432700E+02, -.87621000E+01, 0.68600000E+01, 0.28576500E+02, 0.10553900E+02, 0.34559100E+02, -.18789900E+02, 0.37035100E+02, 0.75811300E+01, 0.34047600E+01, 0.20491300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.95565500E+01, 0.16338600E+01, 0.23495100E+01, -.85643900E+01, -.57744400E+01, 0.43466500E+00, 0.10708800E+01, 0.19831000E+01, -.10341300E+01, -.63729700E-01, -.53875500E+01, -.20743000E+01, 0.95415200E+01, -.15921200E+01, -.80373700E+00, 0.12606200E+01, -.22517800E+01, 0.46651400E+01, 0.93367700E+00, -.41845400E+01, 0.46105600E+01, 0.12012300E+02, -.58963300E+01, 0.47528000E+01, 0.23248400E+00, -.59269200E+01, -.76410300E-01, 0.42273100E+00, -.20172300E+01, -.36589300E+01, 0.14148200E+01, -.10398100E+01, 0.19746500E+01, -.33877000E+00, 0.17976100E+00, -.27842500E+01, 0.13495900E+00, -.13750400E+01, 0.31974700E-01, -.38631300E+00, -.12596400E+01, -.10089100E+01, -.49667800E+01, 0.44056700E+00, 0.19866000E+01, -.17366300E+01, -.10532600E+01, -.21276700E-01, -.12192000E+01, -.26207500E+01, 0.10120200E+01, -.52173400E+00, 0.36950800E+00, -.69088400E+00, 0.90872000E+00, -.35866600E+00, -.21537800E+00, 0.64294600E+00, -.21006100E-02, 0.85594900E-01, 0.13270500E+01, 0.24652300E-01, 0.33518000E-01, -.14925200E+01, 0.29200700E+01, -.14185200E-01, -.23701400E+01, -.14136500E+01, -.11573000E+01, 0.77833800E-02, -.11121300E+01, 0.29199000E+00, -.89884300E+00, 0.67999000E+00, 0.47753300E+00, -.37246300E-01, 0.26683500E+00, 0.47781700E+00, 0.57954900E-02, -.32119100E+00, 0.12944600E-02, -.45167900E+00, 0.11719400E+01, 0.19179100E+01, 0.20130300E+00, 0.76182000E+00, 0.34540600E-02, 0.43602000E+00, 0.80517600E+00, -.35123800E+00, -.91223300E+00, -.72267700E-01, 0.39165200E+00, -.39376100E+01, 0.33600600E+00, -.18651500E+01, 0.10690100E+01, 0.14004900E+01, 0.12589200E+00, 0.43753500E+00, 0.12123300E+01, 0.22332000E+00, 0.34792400E+00, -.39120500E+00, 0.15700500E+01, 0.10258700E+00, -.23212600E+00, -.65875000E+00, -.25637700E+00, 0.23598400E+00, 0.24375800E+00, 0.22698500E-01, 0.16988100E+00, 0.17604900E-01, -.26458700E+00, 0.74760600E+00, -.37077000E+00, 0.79838500E+00, -.19877500E-01, 0.12949500E+01, 0.25862600E+00, 0.12210400E+00, -.20868800E+01, 0.49000100E+01, -.19999600E-01, 0.87713700E-01, -.19590600E+00, 0.21028300E+01, -.11096400E+00, -.57027400E+00, -.48313800E+00, 0.28969700E+00, 0.25148500E+00, 0.13994800E+00, -.15834800E+01, 0.62915700E-02, -.59586700E+00, -.10492300E+01, 0.30622100E-01, 0.24872500E-02, -.35982000E+00, -.45685700E+00, 0.11515800E+00, 0.29094700E+00, 0.43779700E-01, 0.21375100E-01, -.28082700E+00, 0.16986000E+01, 0.72659200E+00, -.75319800E+00, -.10947400E+00, 0.64566900E-01, 0.28697900E+00, -.10135400E+00, -.13489900E+00, -.38896900E-01, -.62375900E+01, -.22776100E+00, 0.11792000E+01, 0.77940800E+00, 0.11202500E+00, -.25290900E+00, -.17969100E+00, -.50492400E+00, 0.57068700E+00, -.12396900E+00, 0.11825500E+00, 0.65227300E+00, 0.83082500E+01, -.44494600E+02, 0.24639700E+02, 0.59552100E+02, 0.15209900E+03, -.10442000E+03, -.29435600E+02, 0.18718200E+03, 0.16983900E+03, -.84084500E+02, -.87237300E+02, -.84817300E+02, -.99650700E+02, -.30727400E+02, -.75209900E+02, -.87846100E+01, -.56411900E+02, -.40201300E+02, -.82664200E+02, -.17620100E+03, 0.86229000E+02, 0.17298300E+03, 0.88203400E+02, 0.33928700E+02, -.50345900E+02, 0.70488500E+02, -.14707500E+02, 0.70477000E+02, -.56494700E+01, -.34100900E+02, -.22778800E+02, 0.10556300E+02, 0.44076500E+03, 0.10001500E+02, 0.31484300E+03, 0.19126100E+03, 0.63862600E+02, 0.14815800E+03, -.10401700E+03, -.26367000E+02, 0.17161000E+03, 0.35182900E+03, -.18283100E+03, -.10246300E+03, -.17564700E+03, -.98009000E+02, -.74255400E+02, -.56828000E+02, -.10276400E+02, -.72225400E+02, -.15931000E+02, -.38657100E+03, -.15727800E+03, 0.78650800E+02, 0.15499900E+03, 0.78759400E+02, 0.10968700E+03, 0.78676100E+02, 0.13946600E+02, 0.53846300E+01, 0.46977800E+02, 0.56648700E+02, 0.63677600E+02, 0.82541300E+03, -.41263400E+03, -.38788700E+03, -.41205500E+03, 0.32444000E+01, 0.90752900E+02, -.33095600E+03, -.13245200E+03, -.28633200E+03, 0.14274900E+03, -.52040700E+03, 0.33353100E+03, -.16659400E+03, -.12901600E+03, -.16713600E+03, -.12955400E+03, -.13850900E+03, -.81583400E+02, 0.15107000E+02, -.22353900E+02, -.32599900E+02, -.76750200E+02, -.74912300E+01, 0.10871200E+02, 0.10552300E+01, 0.13702500E+02, 0.30966400E+01, 0.98271300E+01, -.14746900E+02, -.23853200E+01, -.70505300E+01, -.61979600E+01, -.65018200E+01, 0.59768900E+01, 0.88944900E+01, -.11877600E+02, -.92473400E+01, 0.49664400E+01, 0.95162600E+01, 0.12410600E+02, 0.13220700E+02, -.37913300E+02, 0.26730400E+02, -.10977000E+02, -.34731600E+02, 0.98116100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.35354700E+01, -.92708200E+00, -.12748700E+01, 0.34113500E+01, 0.24768900E+01, 0.12963100E+00, -.46309600E+00, 0.12412700E+01, 0.27352300E+00, 0.17112100E+00, 0.21499600E+01, -.19835900E+00, -.94534000E+00, 0.70529100E+00, -.27568800E+00, -.59555600E+00, 0.22034700E+00, 0.12913000E-01, -.24420900E+00, 0.73184100E+00, 0.30782100E+00, -.37623800E+00, -.25058700E+01, 0.12956800E+01, 0.33896100E-01, -.18942200E+00, 0.29678200E+00, 0.40756400E+00, -.70333900E+00, -.22759100E+01, -.52474700E-01, 0.37809400E+00, -.92814700E+00, 0.27016800E+00, -.17257900E+00, 0.48133000E+00, 0.34218000E-01, 0.32101000E+00, -.21122400E+00, 0.17860700E+00, 0.57989200E+00, 0.33373500E+00, 0.13722400E+01, 0.97108100E-01, 0.69551600E+00, -.55130800E+00, -.89441300E-01, 0.27020900E+00, 0.68515400E+00, 0.14396900E+00, -.27256500E+00, -.11543500E+01, -.13479400E+00, 0.13202000E+00, 0.16412100E+00, 0.51493200E+00, -.18442500E+00, -.37095600E+00, 0.20949900E-02, -.69553500E-01, 0.26536400E+00, 0.24248800E+00, 0.50904900E-01, 0.36838600E+00, -.88820600E+00, -.28432600E+00, 0.36536400E+00, 0.27164200E+00, 0.56504100E-01, 0.56285200E-02, 0.12436500E+00, 0.26083800E+00, -.39776700E+00, 0.82743400E-01, -.14901100E+00, 0.10940500E+00, 0.21627500E+00, 0.18321800E+00, 0.50841800E+00, -.33912500E+00, -.76006600E-03, -.81788500E+00, 0.29504400E+00, -.44564300E+00, 0.11958700E+00, 0.10046700E+00, 0.52689200E-01, 0.19240300E+00, 0.47649500E-01, -.15746200E+00, -.62756900E+00, 0.12472500E-01, 0.23665400E+00, 0.99514500E-01, 0.59304000E+00, 0.71286600E+00, -.44546400E+00, 0.50274100E+00, 0.89284600E+00, -.29725000E-01, 0.44774700E+00, 0.69590300E-01, 0.22871500E-01, 0.41123900E+00, 0.43657600E+00, -.10959600E+01, -.77691500E+00, 0.29858800E-01, 0.50870600E+00, -.17263600E+00, -.85196400E+00, -.14827400E+00, 0.15561400E+00, -.72206700E-02, 0.82981300E+00, 0.32376700E+00, -.40864000E+00, -.37004200E-01, -.38148200E-02, 0.30182500E+00, 0.96480200E-01, -.13463400E+01, -.22213500E+01, 0.79230200E+00, -.53390800E-02, 0.72068100E-01, -.78072300E-01, 0.17193300E+00, -.49584700E+00, 0.22218800E+00, -.42761800E+00, 0.19627200E+00, -.12790500E+00, -.75141500E-01, 0.68283800E+00, -.26175100E-02, 0.64589400E+00, -.29802500E+00, -.32410300E-01, 0.56448300E-01, -.48175500E-01, 0.12094500E+00, 0.14178300E-02, -.11649100E+00, 0.49073300E+00, -.11945600E+00, 0.28153600E-01, 0.15266500E+01, 0.62272300E-01, -.35392900E+00, 0.24923900E+00, 0.20620100E+00, -.12583500E+01, -.29825400E+00, -.11427400E+00, 0.10288000E+00, -.17869700E+01, 0.43058200E-01, -.18588000E+01, 0.39389700E+00, 0.20319300E+00, -.20567100E+00, 0.10674000E+00, 0.97464300E-01, 0.12623200E+01, -.31574400E-01, 0.12965100E+00, 0.21358800E+00, -.50278800E-01, 0.19278300E+03, 0.70723600E+02, -.83607400E+02, -.61020800E+02, 0.19563400E+03, 0.73750100E+02, -.36982400E+03, -.16979800E+02, 0.82246400E+01, 0.58092600E+02, 0.85549600E+01, 0.14139700E+02, 0.82911200E+02, -.47410800E+01, 0.70159300E+02, 0.61123200E+02, 0.52424000E+01, 0.27422400E+02, 0.19404800E+03, -.95122200E+02, -.39526000E+02, -.96918900E+02, -.87105900E+02, 0.38715400E+02, -.19589700E+02, 0.25921500E+02, -.10465800E+03, 0.33260300E+02, -.14102500E+03, -.76029700E+02, 0.40840000E+02, -.55913700E+03, 0.38048200E+02, -.38977100E+03, -.47441800E+02, -.17396500E+02, -.21579300E+03, 0.93770300E+02, 0.62149500E+02, -.84114200E+02, 0.17409400E+03, -.88120500E+02, -.18848300E+03, -.86697200E+02, -.10212300E+03, -.67556300E+02, 0.52914700E+02, 0.13894100E+03, -.12788700E+03, -.90544000E+02, 0.36329000E+03, 0.23778500E+03, -.11878500E+03, -.10492400E+03, -.11886900E+03, -.87382100E+02, -.60643100E+01, -.10272700E+03, -.43916000E+02, -.90463200E+02, -.54764000E+01, -.61156300E+02, -.66890100E+03, 0.34238200E+03, 0.29696700E+03, 0.33485400E+03, 0.14911600E+02, -.15286600E+03, 0.29755100E+03, 0.28979000E+03, 0.29567900E+03, -.18736200E+03, 0.45521100E+03, -.27870800E+03, 0.13916500E+03, 0.12163500E+03, 0.13948200E+03, 0.13238500E+03, 0.10174000E+03, 0.12652900E+03, 0.77363800E+01, 0.62151300E+02, 0.52310100E+02, -.73922100E+02, 0.76837400E+01, -.15412900E+02, -.37345800E+01, -.12170600E+02, 0.67752900E+00, 0.58987500E+00, 0.16304300E+02, 0.55074500E+01, 0.14340500E+02, 0.10419000E+02, -.71545500E+02, -.10242500E+02, -.45651800E+02, 0.34580100E+02, 0.17615000E+02, -.82686600E+01, -.42237700E+02, -.19933400E+02, -.41832700E+02, 0.32399200E+02, -.73085100E+02, -.83022500E+01, 0.35873800E+02, -.25355000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.38332400E+01, -.10012000E+01, -.19494200E+01, 0.35811500E+01, 0.25817700E+01, 0.24098200E-01, -.41642600E+00, 0.17831900E+01, 0.23118800E+00, 0.10050500E+00, 0.11592800E+01, 0.10724100E+01, 0.29116200E+01, 0.29773400E+01, -.41327400E+00, -.36100600E+00, 0.15265800E+01, 0.93746400E-01, -.55191900E+00, 0.12205700E+01, 0.30680700E+00, 0.12895600E+01, 0.58141900E+00, 0.57731900E+00, -.18164400E-01, 0.25887400E+00, -.41179700E-01, 0.13246100E+00, 0.18403400E+00, -.31783700E+01, 0.30200900E+00, 0.22685500E+00, -.18542500E+01, -.10903100E+01, -.28777600E+00, 0.92268600E+00, 0.88559400E-01, 0.12026200E+01, 0.30018700E+00, 0.62105800E+00, 0.11903900E+01, -.93526700E+00, -.81777100E+00, -.19868200E+00, -.20963200E+00, 0.22318900E+00, 0.19357100E-01, 0.58658900E+00, 0.13454500E+00, -.75363700E+00, -.14557600E+00, 0.43551500E+00, 0.21978500E-01, 0.69857600E-01, -.94642800E+00, 0.50615700E+00, -.20803900E+00, -.15032700E+00, 0.11866500E-02, -.49224100E+00, -.67590100E+00, 0.48462000E+00, -.14970100E+00, -.15100400E+00, -.34118000E+00, -.57963800E+00, 0.89235000E+00, 0.18054200E+01, 0.42228700E+00, 0.40219800E-02, 0.13368000E+00, 0.10276000E+01, 0.35390300E+00, -.28296300E+00, 0.83863900E+00, 0.11610200E+00, -.38506600E+00, -.88739800E+00, -.83301200E+00, 0.53970400E+00, -.13293700E-02, 0.23897400E+01, -.18930800E+01, 0.68244700E+00, 0.20901500E+00, 0.33562800E+00, 0.79976600E+00, 0.35965800E+00, 0.69280200E+00, 0.14552800E+00, 0.52892300E+00, 0.76814100E-01, -.35823700E+00, -.18163600E+01, 0.13460000E+01, 0.29961800E-01, 0.70693200E+00, -.16376800E+00, 0.57412900E-01, 0.51928500E+00, -.10509400E+01, -.12661800E+00, 0.54510200E-01, -.19137100E+00, 0.20471700E+00, 0.30977500E+00, 0.36630600E+00, -.34091900E+00, 0.22812400E+00, 0.11097100E+00, 0.71700400E+00, 0.18584500E+00, -.70159700E-01, -.80659200E-03, -.52236800E+00, 0.96073100E-01, 0.36781300E+00, 0.37687400E-01, -.26618300E-01, 0.10047600E+01, 0.93641600E-01, 0.27904900E+00, 0.83444400E-01, -.18246600E+00, 0.84508300E-03, 0.29411300E+00, 0.31096900E+00, 0.18957000E+01, 0.47035100E+00, 0.49328100E-01, -.23912900E+00, 0.20011100E+00, 0.27694200E+00, -.82306400E-01, -.62861500E-01, 0.78614100E-02, 0.51225600E+00, 0.13087600E+00, -.58246700E-01, -.24732800E+00, 0.39532900E+00, 0.33138100E+00, -.33679200E+00, 0.30855800E+00, 0.42915200E+00, -.62666400E+00, 0.20585300E-01, -.77573500E-01, 0.33578800E+00, -.18599400E+00, 0.22884200E+00, -.23314800E+00, 0.35729300E-02, -.38624200E+00, -.11211900E+00, 0.21591800E+00, -.95090500E+00, 0.13464100E-01, -.94235700E+00, -.14671800E+00, 0.28680200E+00, -.11929700E+00, -.16684800E+01, 0.28397700E+00, -.13250600E+01, 0.29124200E+00, -.59323200E-01, -.17862700E+00, -.46278600E-01, 0.28769000E+00, 0.13219900E+03, -.71102500E+02, 0.15201600E+03, 0.10134300E+03, 0.67673900E+02, 0.47669000E+02, 0.91754000E+02, -.46904700E+02, -.66832700E+02, -.45871100E+02, -.58364700E+01, 0.66805800E+02, 0.12995600E+02, 0.13342400E+03, 0.24430800E+02, 0.94067100E+01, -.72752700E+02, 0.38239500E+02, -.14968700E+02, 0.10450900E+03, -.19091900E+02, 0.74610700E+02, -.15086200E+02, 0.18909000E+02, -.23372700E+02, -.52173800E+02, 0.19769200E+02, -.43798700E+03, -.97721200E+03, 0.48875700E+03, 0.66018000E+02, 0.48903200E+03, -.42709000E+03, -.25396400E+03, 0.30975800E+03, -.82609300E+02, 0.45416300E+03, -.12773200E+03, 0.46954500E+03, -.51426100E+02, 0.24840500E+02, -.18104300E+03, 0.25757500E+02, -.97142900E+01, -.13393600E+03, 0.18591500E+03, 0.11329300E+03, 0.60990100E+02, -.12826700E+03, 0.27262400E+03, 0.17185100E+03, -.86647900E+02, -.11693500E+02, -.85947600E+02, -.94682100E+02, 0.74445600E+02, -.18121800E+03, -.10451700E+03, -.72998100E+02, 0.70654000E+02, 0.14707900E+03, -.26814300E+03, 0.14197600E+03, -.65785200E+02, 0.13408700E+03, 0.13496000E+03, 0.11865400E+03, 0.12438900E+03, 0.21472900E+03, 0.80034700E+02, 0.52934900E+02, 0.27931300E+03, -.16871300E+03, 0.84954600E+02, 0.10808600E+03, 0.84485000E+02, 0.17179800E+03, 0.12173200E+03, 0.13315700E+03, 0.62019600E+02, 0.22209000E+02, 0.10340100E+03, -.20295700E+03, -.57857900E+00, 0.74201700E+01, -.28159200E+01, 0.30508500E+01, 0.58656900E+01, 0.27089400E+02, 0.19233600E+01, 0.95109300E+00, 0.13249800E+02, 0.83016300E+01, -.99843800E+02, -.49937500E+01, -.45459200E+02, 0.36986400E+02, 0.50781300E+01, -.16878800E+01, -.66565700E+02, 0.83385000E+00, -.46048100E+02, 0.22532600E+02, -.11058500E+03, -.66673200E+01, 0.64990400E+02, -.44212300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26020000E+01, 0.24300100E+00, 0.43352400E+00, -.10946600E+01, -.24883300E+00, -.34685500E-01, 0.67810700E-01, 0.63671200E+00, -.33079100E+00, -.25366000E+00, 0.29844600E+00, 0.63355000E+00, 0.28768700E+01, -.17623500E+01, 0.27143900E+00, -.13053500E+00, -.56573500E+00, 0.20192800E+01, 0.37508800E+00, 0.16436900E+00, -.10659700E+00, 0.21754900E+01, -.36922100E+01, 0.13136300E+01, -.23007900E+00, -.30340800E+00, 0.28670900E+00, -.12255700E+00, -.69024200E+00, -.85331800E+00, -.20955200E-01, -.89117800E-01, -.82354900E-01, -.34223500E+00, -.22251200E-02, 0.68496500E-01, 0.31341200E-01, -.43107100E-01, -.13585800E+00, 0.42848600E+00, 0.18490300E+00, 0.74658500E+00, -.27250100E+00, 0.57824400E+00, -.16839700E+00, -.13576300E+01, 0.51705300E+00, 0.28889300E+00, 0.30848500E+00, 0.11163800E+00, -.13758600E+01, -.82781000E+00, -.12426400E+00, -.15799200E+00, 0.61722900E+00, 0.10228000E+00, 0.14452800E+00, -.23895400E+00, 0.12771200E-02, -.60085500E+00, -.36497500E+00, 0.63187100E+00, -.27062300E+00, -.27958100E+00, 0.10568500E+01, 0.66196800E+00, 0.32260700E+00, -.83429100E+00, 0.28423700E+00, 0.37745800E-02, -.60943800E+00, -.32240600E+00, -.70160800E+00, 0.22267200E+00, -.10641700E+00, -.55764300E-01, -.18887400E-01, -.12296300E+00, -.10385000E+01, -.66386800E-01, -.14127400E-02, -.56876700E-01, -.34794700E+00, 0.27020000E+01, 0.23449900E+00, 0.31656400E+00, 0.59633900E-02, -.50343400E-01, -.40276000E-02, -.54042900E-01, -.12821400E+01, -.63082000E-01, 0.46468400E+00, 0.37006900E+00, -.84076500E+00, -.10359500E+01, 0.22938300E+00, 0.52931600E+00, -.31506000E+00, 0.25523700E+00, 0.81293300E-01, 0.75448700E-01, -.66358800E-01, -.24098400E-03, -.20137900E+00, 0.30629500E+00, 0.15516100E+00, -.24681300E+00, 0.32815100E+00, 0.58139500E+00, -.34333500E+00, 0.37435400E-01, 0.71930800E-02, 0.19018400E-02, -.19772400E+00, 0.60252200E+00, -.53806600E+00, -.12800400E-01, 0.53387100E-01, 0.50612800E+00, -.51824600E+00, 0.47451500E+00, -.14468100E-01, -.79329500E+00, -.33557100E-02, 0.54587300E+00, -.14928300E+00, -.81562600E-01, 0.54350200E-01, -.91339900E-01, 0.32558400E-01, -.12158200E+00, -.53723700E-01, 0.30241300E-01, -.11453200E+00, 0.10074000E-02, -.35104400E+00, -.72732400E-01, -.16671400E-01, -.30606900E-01, 0.18177400E-01, 0.78869200E-01, 0.30838600E-01, 0.44428700E-01, 0.12128700E+00, -.15924100E+00, 0.16725600E-01, 0.18716800E+00, -.10462600E+00, 0.75997800E-01, 0.11728000E-01, -.38717700E-01, 0.28443500E+00, -.57171500E-02, 0.89736300E-01, 0.10156900E-01, -.92561900E+00, 0.31268600E-01, 0.56505900E+00, -.61814000E-01, -.22651500E-01, 0.18474700E-02, 0.64317600E+00, 0.18924100E+00, -.59944400E+00, -.13688500E+00, -.92118500E-01, -.41634300E-01, 0.22939600E-01, -.32336400E+00, 0.98447100E-01, -.97728100E+02, -.20052800E+03, -.73025700E+02, 0.69967800E+01, 0.39476400E+02, -.15593300E+02, 0.91687700E+01, 0.58767700E+02, 0.78038900E+01, -.30495600E+02, 0.32939000E+02, -.60853900E+02, -.57453000E+02, -.28172200E+02, 0.79299200E+02, 0.22918100E+02, 0.11786400E+03, -.61410400E+02, -.17043800E+03, -.58928000E+02, -.45136500E+02, -.24642400E+02, -.32421300E+02, 0.16751600E+02, -.23924200E+02, -.22474900E+02, 0.88551800E+02, 0.60852600E+03, -.30630200E+03, -.28304700E+03, -.30444400E+03, 0.77296500E+02, 0.12544100E+03, -.16189400E+03, 0.28359900E+02, -.20417600E+03, 0.20889700E+02, -.21097900E+03, 0.28714300E+03, -.15004400E+03, 0.70567700E+01, -.14356400E+03, -.43078300E+02, -.12015900E+02, -.27031500E+02, 0.64685400E+02, -.83906600E+02, -.51536400E+01, -.24454300E+03, -.89776000E+02, 0.44443000E+02, 0.11034300E+03, 0.44901300E+02, 0.35958300E+02, -.24926500E+02, 0.70454500E+02, 0.24089600E+02, 0.42327500E+01, -.27630500E+02, -.10215800E+03, -.41893900E+03, 0.20993400E+03, 0.23294200E+03, 0.20951800E+03, -.62975400E+02, -.15558300E+03, 0.95440400E+02, -.69453700E+02, 0.12559600E+03, -.97971100E+02, 0.93745300E+02, -.11710300E+02, 0.55585900E+01, -.26944900E+02, 0.57994600E+01, -.99341300E+01, -.48249900E+02, 0.26653600E+02, 0.27230500E+02, 0.74435100E+01, -.30967400E+02, 0.79527900E+02, -.31951600E+01, -.17155200E+01, 0.34068100E+01, -.62377500E+00, -.41079300E+01, -.49899200E+01, -.20086500E+01, -.13955800E+01, -.40267800E+01, -.53800100E+01, 0.17314300E+02, 0.40872400E+01, 0.16189900E+02, -.14370600E+02, -.43412200E+01, 0.24605900E+01, 0.34126400E+02, 0.49870300E+00, 0.18241500E+02, -.11160600E+01, 0.41904700E+02, -.53099400E+01, -.33049800E+02, 0.49200100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.35646700E+01, -.27822700E+00, 0.56918200E-01, 0.75341300E+00, 0.10935100E+01, 0.21392800E+00, -.30532300E+00, 0.49732900E+00, -.71457300E-01, -.36131300E-02, 0.30016000E+00, -.25405100E+00, -.10452200E+01, -.29509800E+00, 0.61003100E-01, -.31206800E+00, -.57983900E-01, -.16457500E+00, 0.80427400E-01, 0.48341200E+00, 0.26349600E+00, -.97198800E+00, -.17801600E+01, 0.97418400E+00, -.14663400E+00, -.62091400E-01, -.40862600E-01, -.42309600E+00, -.92681100E+00, -.16047000E+01, -.36985900E+00, 0.26787400E+00, -.67027900E+00, 0.37232600E+00, -.19275100E+00, 0.68171000E+00, 0.29719100E-01, 0.74641300E+00, -.60422700E+00, 0.36879600E+00, 0.69532300E+00, 0.10504900E+01, 0.14904200E+01, 0.33859400E+00, -.11216600E+00, -.26468600E+00, 0.55640200E+00, 0.66948100E+00, 0.79535300E+00, 0.82772800E+00, -.99961300E+00, -.10410700E+01, -.16543600E+00, -.19159900E+00, 0.31799700E+00, 0.21365800E+00, 0.19174700E+00, -.92006100E+00, 0.90160200E-05, -.40646800E+00, -.42136200E+00, 0.23662100E-02, -.19693000E+00, 0.12790800E+00, -.85777300E+00, -.11432000E+00, 0.78430600E+00, -.93338700E+00, 0.68786800E+00, 0.16144700E-02, 0.32059000E-01, 0.13717000E+00, 0.25610100E+00, -.51199100E-02, 0.40663200E+00, -.76819000E-01, -.13750000E+00, -.29833700E+00, 0.20544500E-01, 0.16485200E+00, 0.46453100E-03, 0.60147700E+00, -.10866600E+00, 0.54582900E+00, -.20163300E-01, -.34315500E+00, 0.42340100E+00, 0.12360200E+00, 0.11613200E-01, 0.71514600E-01, -.59026000E-01, 0.12957300E-02, 0.36959700E-01, -.19914200E+00, 0.25898600E+00, -.30070400E+00, 0.11065500E-01, 0.15701800E+00, -.44494300E-01, 0.79582100E-01, 0.31616500E-01, 0.41697300E-01, -.10538500E-01, 0.33003100E-01, 0.17224600E+00, -.16024300E-01, 0.17901500E+00, 0.30706100E+00, 0.15364800E+00, -.23852700E+00, 0.11296700E+00, -.16775400E-01, 0.10660600E-01, -.44981100E-02, 0.52319700E-02, -.12703500E+00, 0.11528400E+00, 0.13076500E+00, -.32589800E-01, -.35061500E+00, -.63656700E-02, 0.24736300E+00, 0.57001100E-01, 0.93064800E+00, 0.48924300E-02, -.33582200E+00, -.35984600E-01, -.17167600E-01, 0.54334800E-01, 0.54510500E-01, -.70381500E-01, -.11848400E+00, 0.99271000E-01, 0.44480000E-01, -.26914500E+00, -.46999600E-03, -.14160300E+00, 0.67395400E-01, 0.15430300E-01, -.20714200E-01, 0.37040800E-01, -.12605100E+00, 0.22763900E-01, -.62713300E-01, 0.22973800E-01, -.25208000E+00, -.90949100E-02, 0.22237200E+00, -.37574700E+00, -.23443200E+00, 0.87194200E-01, -.16360600E+00, -.13595700E+00, -.63598200E-01, -.27252300E+00, 0.56719800E-01, 0.52847100E-01, -.26711800E-01, -.78329500E+00, 0.29643800E+00, -.84324300E-01, 0.17913000E+00, -.15932500E+00, -.10603700E+00, 0.72670900E+00, -.82037100E-01, 0.81803800E-02, 0.34885800E-01, 0.20472600E-01, -.23293700E+00, 0.10608000E+00, -.57493000E+00, -.13669400E+03, -.83959300E+02, 0.28442300E+02, 0.52642000E+02, -.23972100E+02, 0.13349300E+02, 0.52702700E+02, 0.12027400E+02, -.17613100E+02, 0.59017200E+02, -.52920400E+02, -.79377200E+02, -.28449000E+02, 0.75431200E+02, 0.31355700E+02, 0.67943100E+02, -.36704200E+02, -.56422300E+02, -.33921800E+02, -.16777700E+02, 0.11726500E+02, -.38779800E+02, 0.57702000E+01, 0.53387500E+00, -.44685600E+01, 0.42711700E+02, 0.37045900E+03, -.18789300E+03, -.26645100E+03, -.18571600E+03, 0.58381600E+02, 0.91272900E+02, -.12047900E+03, -.12328900E+03, -.20481200E+03, 0.36926500E+02, -.15916800E+01, 0.44200500E+03, -.22642500E+03, -.74372400E+02, -.22091700E+03, -.29704100E+02, -.82890100E+01, -.11298500E+03, 0.10645100E+03, -.11398400E+03, -.22260500E+02, -.34970500E+03, -.12450200E+03, 0.61892100E+02, 0.55570600E+02, 0.62295400E+02, 0.42497700E+02, 0.17657700E+02, 0.46148800E+02, -.43579800E+01, 0.14225200E+02, 0.20549000E+02, -.87239800E+01, 0.10492800E+03, -.53604400E+02, 0.96665200E+02, -.52198800E+02, -.58640100E+02, -.36045900E+02, -.31865400E+02, 0.60242600E+02, 0.94719000E+01, -.92580500E+01, -.17324600E+03, 0.53057300E+02, -.26686800E+02, -.19360800E+02, -.26679200E+02, -.28894300E+02, -.56010900E+02, 0.91734500E-01, -.86147100E+00, -.14787900E+02, -.36643300E+02, 0.18743900E+02, 0.50312100E+00, -.49624400E+01, 0.21538200E+01, -.34626500E+01, -.31140000E+01, -.30764300E+01, 0.28287100E+01, -.81995100E+00, -.41212900E+01, -.18893000E+01, -.72876900E+01, 0.95934000E+00, 0.83669800E+01, -.74713500E+01, -.11409600E+01, -.27648900E+00, 0.14002200E+02, -.52472300E+01, 0.79786000E+01, 0.41330800E+01, 0.35808200E+02, -.43142900E+01, -.30962200E+01, 0.65587300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.67567000E+01, -.59376800E+00, -.20232800E+01, 0.43882100E+01, 0.56137300E+01, -.45125100E-01, -.11043900E+01, 0.20176900E+01, -.18933000E-01, -.21397000E+00, 0.19729800E+01, 0.12922400E+01, -.10401700E+00, 0.36623200E+01, -.28010700E+00, -.66177200E+00, 0.10807500E+01, 0.37469100E+00, -.70953700E+00, 0.12446200E+01, -.99779500E+00, -.34150100E+01, 0.30395100E+01, -.19283500E+01, 0.14413300E+00, 0.64931200E+00, -.14632800E+00, 0.81625700E+00, 0.63437400E+00, 0.30493000E+01, -.11147600E+00, 0.19504900E+00, -.14582300E+01, 0.94927500E+00, -.16157800E+00, 0.40329900E+00, -.13331000E+00, -.81916900E+00, -.12657600E+01, 0.28309800E+00, 0.27062000E+00, 0.13152800E+01, -.55847700E+00, 0.44659800E+00, -.24318800E+01, 0.22941400E+01, 0.22896400E+01, -.15724700E+00, -.45628600E+00, 0.85458800E+00, -.38744300E+01, 0.87993400E+00, -.48798500E+00, 0.23616100E+00, -.15017700E+00, -.56795500E+00, 0.21272800E+00, 0.79401900E-01, -.46286000E-02, 0.12648000E+01, 0.31456300E+00, 0.26386100E+01, -.65650500E+00, -.57344800E+00, 0.58273700E+01, 0.13184700E+01, 0.11848900E+01, 0.16389800E+00, 0.56743600E+00, -.13651500E-02, 0.16847000E+01, -.62911600E+00, 0.20828200E+00, -.79908400E+00, 0.10575000E+01, 0.33162200E-02, 0.65996200E-01, -.82936500E+00, -.23875600E+01, 0.13715400E+01, -.25843000E-02, 0.19948600E+01, -.24730500E+01, 0.40734500E+01, 0.16133800E+00, 0.37453400E+00, 0.97245300E-01, 0.34736500E+00, 0.12417200E+00, 0.92783900E+00, -.73283400E+00, 0.79003100E-01, -.11752300E+01, -.52005100E+00, 0.79589200E+00, -.65370800E+00, -.37896400E-01, -.83865000E+00, 0.89932700E+00, 0.15636700E+00, -.18673900E+01, -.83181100E+00, -.15136200E+00, -.21522700E+00, -.54539400E+00, -.33109800E-01, 0.47667800E+00, -.26717700E+00, -.36409300E+00, 0.21608800E+00, -.71309500E+00, -.45859100E-01, -.41837800E-01, 0.46202200E-02, -.94208700E-01, 0.70156300E+00, -.24178700E+00, 0.18023800E-01, 0.89341300E-01, -.82247200E+00, 0.92849800E-01, 0.20363000E+00, -.29186100E+01, 0.74842600E+01, -.86327500E-02, -.21080700E+00, -.25936500E+00, 0.43164100E+01, -.47380900E+00, 0.18432500E-01, -.17795800E+00, -.14549900E+00, 0.26629400E+00, 0.88033300E+00, -.55956800E+00, 0.16948400E-01, -.32525600E+00, -.85674200E+00, -.39738300E+00, -.31292300E+00, 0.25861700E+00, -.11156700E+00, 0.15427900E-01, 0.72783300E+00, 0.26549800E+01, -.25875100E+00, 0.59485800E-01, 0.29463900E+01, 0.24307600E+00, 0.29944500E+00, 0.55343600E+00, -.36852800E+00, -.99510600E+00, -.10440800E+01, 0.92011900E+00, 0.43753400E+00, -.40137400E+01, 0.64288800E-01, -.23758700E+00, 0.64744600E+00, 0.76110400E+00, -.36093400E+00, -.12394200E+01, -.33761400E+00, 0.31228300E+01, 0.90396800E-01, 0.79166700E+00, -.28876700E+00, -.17124900E-01, -.52811400E+00, 0.51865200E+00, -.89712700E+00, -.14579500E+01, 0.36154000E+03, 0.41754200E+01, -.18643100E+03, -.28378500E+01, 0.46902100E+00, 0.80057400E+02, 0.13945400E+01, -.33627600E+01, 0.90132600E+02, -.93613400E+02, -.50380500E+02, -.50458000E+02, 0.93305600E+02, 0.25510300E+02, 0.31332900E+03, -.11493700E+03, -.17667200E+03, -.15670900E+03, -.11772100E+03, 0.48475300E+02, -.70742500E+02, 0.72011400E+02, -.14132200E+03, 0.42824800E+02, -.13719900E+03, -.19832600E+03, 0.13621100E+03, -.83966500E+03, 0.99158900E+02, -.20895300E+02, 0.21358600E+03, -.10115100E+03, -.15544000E+03, 0.15095900E+03, 0.18547100E+03, -.11811000E+02, -.80577500E+02, 0.52599800E+02, 0.10958900E+03, 0.40232300E+02, 0.25062700E+02, -.48993400E+02, 0.60855900E+02, 0.25508800E+01, -.22065000E+03, -.48295000E+02, 0.54706000E+02, 0.12809300E+03, -.55890100E+02, -.81199600E+02, -.64056100E+02, -.23202500E+02, -.11714200E+03, 0.39162300E+02, 0.10405600E+02, -.34515000E+02, -.11010400E+03, -.18356500E+03, 0.14307700E+03, -.69980400E+02, 0.11340800E+02, -.71686500E+02, -.17480900E+03, -.28080200E+03, 0.60597900E+02, 0.15974800E+03, -.22799900E+02, -.26376400E+03, -.84369600E+02, 0.61628400E+02, -.36879000E+02, 0.51935200E+02, -.30801700E+02, -.16774500E+02, -.25694100E+02, 0.48624900E+02, 0.55321900E+02, 0.16068500E+03, -.88614700E+02, -.20114700E+01, 0.10144700E+02, -.16817300E+02, 0.22777400E+00, -.15320200E+02, -.46364000E+01, 0.64037500E+00, 0.13999500E+02, 0.45456800E+01, 0.11850400E+01, 0.73927700E+01, -.19870200E+02, -.90225500E+01, -.39381700E+02, 0.13216600E+02, 0.84562000E+01, -.84481100E+01, -.62473500E+02, -.12824100E+02, -.28472000E+02, -.10640600E+02, -.96944200E+02, 0.23978900E+01, -.47746900E+02, 0.14848000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.29807200E+01, 0.12922400E+01, 0.24984500E+00, -.88013500E+00, -.28784100E+01, 0.37811300E+00, 0.22791500E+00, -.46472700E+00, -.12481000E+00, -.59585700E-01, -.64182000E+00, -.10280800E+00, 0.31738300E+00, -.19753200E+01, 0.23717400E+00, 0.10754000E+00, -.10005000E+01, -.77257900E-01, 0.36233800E+00, 0.71539900E-01, -.72342100E-01, 0.12126800E+01, -.11173100E+01, 0.55043700E+00, -.10725300E+00, -.18472200E+00, 0.15103200E+00, -.70383500E+00, -.52062700E+00, 0.63144200E+00, -.12557700E+00, -.43598300E-01, 0.89557600E+00, -.19801300E+00, 0.30054400E-01, -.54096000E+00, 0.79942400E-01, -.12747000E-01, -.11383600E-01, 0.99309400E-01, -.57261200E-01, 0.27097500E+00, 0.13118500E+01, 0.80173700E-01, 0.59931300E+00, -.10360400E+01, -.35018400E+00, 0.60344500E+00, 0.53068200E+00, -.34464900E+00, -.80814700E+00, -.10302300E+01, -.43935000E-01, -.38016300E+00, 0.21838200E-01, 0.21559100E+00, 0.15443500E+00, -.30431700E+00, 0.36634300E-02, 0.89170600E-01, 0.21602400E+00, -.17718300E+00, 0.91883000E-01, 0.34137700E+00, -.23689900E+00, 0.87346800E+00, 0.45748000E+00, -.21668300E+00, -.75274600E-01, 0.22537200E-02, -.34851600E+00, -.10546300E+00, -.19030600E+00, 0.48061700E+00, 0.18984400E+00, -.74685200E-02, 0.93834600E-01, 0.21080900E+00, 0.26775100E+00, -.33705200E+00, -.45642600E-03, -.71688900E+00, 0.48186800E+00, -.13770900E+01, -.63887900E-01, 0.63402600E+00, -.13620100E+00, -.35299300E-01, -.34735100E-01, -.77335900E-01, -.58636100E+00, 0.43123400E-01, 0.12586500E+01, 0.64661500E+00, -.94459100E+00, 0.47181600E+00, -.25603800E+00, 0.22074600E+00, 0.57884300E+00, 0.29014200E+00, 0.69055700E+00, 0.81982500E-01, 0.66880600E-02, 0.31216600E+00, -.43455500E-01, -.34814600E+00, -.13936500E+00, 0.10516300E+01, 0.34227900E+00, -.58615400E+00, -.30055900E+00, -.17673200E+00, 0.16451500E+00, -.53748600E-02, 0.34524500E+00, 0.34324300E-01, -.10943900E+00, 0.32657100E+00, -.14919700E+00, -.60627600E+00, 0.91903700E-02, 0.30168200E+00, 0.54001500E+00, -.30150600E+00, -.49275200E-02, -.14742200E+00, -.22381800E+00, -.10463000E+01, 0.40431500E+00, 0.83108000E-01, 0.23825500E+00, -.34899500E+00, 0.31824500E+00, 0.12722400E-01, 0.50772700E+00, 0.49177800E-02, 0.61753300E+00, -.43435800E+00, -.34409200E-01, -.50158000E-01, -.26263600E+00, 0.13014300E+00, 0.36482200E+00, 0.28285600E+00, 0.40098800E+00, 0.39934000E+00, 0.58856900E-01, 0.37686600E+00, 0.31880400E+00, 0.30996000E+00, 0.79404400E-01, -.61480200E-01, -.18769700E+00, -.24450500E+00, 0.41718300E+00, 0.61558600E-01, 0.13249500E+01, 0.48343500E-01, -.16868100E+01, -.13593000E+00, 0.21104300E+00, -.28705900E+00, 0.37376200E+00, 0.21999800E+00, 0.32771400E+00, -.71224400E-01, 0.14134900E-01, -.22504800E+00, 0.15705800E-01, -.32667600E+00, 0.16586400E+00, 0.55180900E+00, -.12983600E+00, 0.20448700E-01, 0.32981300E+02, -.11985800E+02, -.14269000E+03, 0.70779400E+02, 0.43682000E+02, 0.71371400E+02, 0.57675600E+02, 0.10487200E+02, 0.47228300E+02, 0.18332000E+02, 0.30401800E+02, 0.13405500E+02, 0.28771600E+02, -.10312700E+02, 0.72934400E+01, -.67753500E+02, 0.51840100E+01, -.15654700E+02, -.40069000E+01, -.45017000E+02, -.27532300E+02, 0.24095500E+02, -.29436400E+02, 0.17433300E+03, -.47732800E+02, 0.30011500E+02, -.16202300E+03, 0.23569800E+02, -.34332400E+02, -.62567600E+02, -.21245600E+02, 0.19833200E+01, 0.26519500E+02, 0.42604100E+02, -.10507500E+03, -.22106500E+03, 0.11372300E+03, -.41971400E+01, 0.11065100E+03, 0.42209500E+02, -.31620400E+01, 0.90163500E+02, -.23047400E+02, 0.55585400E+02, -.93736500E+01, 0.11065300E+03, 0.19721400E+03, -.96778900E+02, -.68115000E+02, -.98579400E+02, -.21754000E+02, -.39027100E+02, -.58537500E+02, -.65305300E+01, -.11124300E+03, -.29832000E+02, -.18415900E+03, -.32720000E+03, 0.16080800E+03, -.57271000E+02, 0.16377200E+03, 0.13777400E+02, -.33406600E+02, 0.13649500E+03, 0.27807200E+02, 0.14497200E+03, -.53093500E+02, 0.21536500E+03, -.90447200E+02, 0.43903000E+02, 0.31465600E+02, 0.45180200E+02, 0.24971700E+02, 0.53752700E+02, 0.29696900E+02, 0.35122000E+02, -.32065000E+02, 0.14325800E+02, 0.87686900E+02, -.38306600E+00, 0.12627000E+01, 0.62442300E-01, 0.76219900E+01, -.49753100E+01, -.55661700E+00, -.23018400E+01, -.53156900E+01, -.25728900E+01, -.77091500E+01, 0.12060100E+02, 0.43749200E+00, 0.13777100E+02, 0.48597500E+01, 0.50227500E+01, 0.15744800E+01, 0.48696600E+01, 0.24592100E+01, 0.63848400E+01, -.46507200E+01, -.50706700E+01, -.16400100E+01, -.36212300E+01, -.63159900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13605000E+02, 0.21204900E+01, 0.36050400E+01, -.78120600E+01, -.10469200E+02, 0.13464600E+01, 0.18842800E+01, -.44238000E+01, -.81176500E-02, 0.84306200E+00, -.20127700E+01, -.16322600E+01, -.20716600E+01, -.75644800E+01, 0.33607700E+00, 0.13421100E+01, -.23208200E+01, -.12077300E+01, 0.14773600E+01, -.34364500E+01, 0.17380900E+01, 0.48353900E+01, -.33358000E+01, 0.19197000E+01, -.31364300E+00, -.77923000E+00, 0.79372500E+00, -.18061600E+01, -.85636500E+00, -.33263600E+01, 0.13627200E+00, -.29330300E+00, 0.35890300E+01, -.16222900E+01, 0.67706400E-01, -.23518200E+00, 0.23252700E+00, 0.13258600E+00, 0.19513700E+01, -.44550500E+00, -.36204200E+00, -.23597400E+01, -.12806600E+00, -.71497200E+00, 0.27791700E+01, -.29391400E+01, -.35488600E+01, 0.32332000E+00, 0.58373400E+00, -.14652200E+01, 0.77878100E+01, -.11440500E+01, 0.11236900E+01, -.99691300E-01, 0.13085200E+01, 0.19738000E+00, -.30102000E+00, 0.16383400E+01, -.22370600E-02, -.68911000E+00, 0.72226700E+00, -.27809700E+01, 0.94932200E+00, 0.80071800E-01, -.60712500E+01, -.17091000E+01, -.25757600E+01, -.22501000E+01, -.15909200E+01, -.54582000E-02, -.15069100E+01, 0.36705800E+00, -.12415600E+01, 0.18390800E+01, -.25391600E+01, -.18347300E-01, -.56071000E+00, 0.15928400E+01, -.28372700E+00, -.15805800E+01, 0.72106800E-03, -.23039600E-01, -.63616300E-01, -.44374900E+01, -.80253000E+00, 0.58512700E+00, 0.48242400E+00, 0.34808800E+00, 0.86279700E+00, 0.49226200E+00, 0.78194200E+00, 0.11144600E+00, -.12940900E+01, -.17800600E+01, 0.98650100E+00, 0.17978000E+01, 0.18837500E-02, 0.76988700E+01, 0.94546100E+00, -.67718200E+00, -.99371800E+00, 0.43218700E-01, 0.47634100E+00, 0.38544300E+00, -.17432500E+00, -.69064800E+00, -.28465400E+01, -.74526900E+00, -.14585400E+01, 0.14140100E+00, -.99194800E-01, 0.20047000E+00, 0.23788300E+00, 0.97564700E-02, 0.70360800E-01, -.22239100E+01, 0.12473600E+01, -.15334900E+01, 0.87645800E-01, -.60081200E-01, 0.10625000E+00, -.35189800E+01, -.19638400E+01, -.75827700E+01, 0.30336900E+00, -.17028400E+01, 0.22803200E+01, 0.54726300E+01, -.50072900E+00, 0.71451700E-02, -.10224100E+01, 0.67251500E+00, -.29305700E+00, 0.62216300E+00, -.29141700E+01, 0.66998300E-02, -.12414500E+01, 0.22027300E+01, 0.63874200E+00, -.26292300E+00, -.82665200E+00, -.13090700E+01, -.65688500E+00, 0.50834000E+00, 0.11703600E+01, -.13113200E+01, 0.31242300E-01, -.61853000E+00, 0.52751700E+00, 0.15795300E+01, -.14396500E+00, -.25000500E+01, -.10452700E+01, -.66651700E-01, 0.36000300E+00, -.11323100E+00, 0.35800000E+01, -.27289800E+00, 0.20096600E+01, 0.63429500E+00, -.10862600E+01, 0.22749800E+01, -.20814400E+01, -.16006100E+01, 0.22712400E+01, -.56551200E+00, -.34269900E+00, 0.21999800E+01, 0.12765100E+00, -.61082400E+00, 0.49551300E+00, -.10783600E+01, 0.46366200E+01, 0.48473000E+00, -.43721700E+01, -.69747100E+03, 0.87532800E+02, -.40349200E+02, -.20014500E+03, -.43889900E+02, -.90001700E+01, -.38754700E+03, 0.14241600E+03, -.44757800E+02, -.13708200E+03, -.43476700E+03, -.16068900E+03, -.43129200E+03, 0.18915500E+03, -.33416800E+03, 0.21546200E+03, 0.21810400E+02, -.31632600E+02, 0.49477200E+02, -.41721300E+02, 0.10572200E+03, -.67345700E+02, 0.60961000E+03, -.99922000E+02, 0.21537900E+02, 0.50201000E+03, 0.50321200E+02, 0.71553300E+03, 0.18773400E+03, -.13312200E+03, 0.58883500E+03, -.12660300E+03, 0.39124400E+02, -.48813500E+03, -.12347100E+04, 0.59607100E+03, 0.22993300E+03, 0.61688700E+03, 0.29440900E+03, -.70926000E+02, 0.38413300E+03, -.31882400E+03, 0.20723800E+03, 0.96483500E+02, 0.10280000E+04, 0.85455500E+03, -.43475000E+03, -.39106000E+03, -.42734700E+03, -.93617000E+02, -.16924500E+03, -.18155700E+03, 0.16665900E+03, -.33452400E+03, -.19385500E+03, -.51064400E+02, 0.20326700E+03, -.10385200E+03, -.42509300E+03, -.10238700E+03, -.77692300E+02, -.23921100E+03, 0.32652200E+02, -.47333000E+03, -.58720700E+02, 0.11240000E+02, 0.18019800E+03, -.16657900E+03, 0.85597200E+02, -.74930700E+02, 0.83300600E+02, -.82486100E+02, 0.28358400E+02, -.11780400E+03, 0.10369700E+03, 0.27523100E+02, 0.45565900E+02, 0.47188700E+03, -.58544200E+01, 0.45605200E+02, 0.40718200E+01, 0.60469100E+02, 0.89696000E+01, -.21992900E+01, -.55409300E+02, 0.31076700E+01, 0.26113900E+01, -.30692500E+02, 0.12726200E+03, 0.47686300E+01, 0.40911800E+02, 0.12852000E+02, -.63094300E+00, 0.78093400E+01, 0.12563500E+02, 0.33886600E+02, 0.20731500E+02, -.98701100E+02, -.84615200E+02, 0.44601000E+01, -.14991100E+03, 0.30910200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.41862000E+01, -.85607200E+00, 0.24843000E+01, -.10477100E+01, 0.37423200E+01, 0.56571400E-01, -.71979300E+00, 0.20417200E+01, -.13918800E+00, -.55207100E+00, 0.69667500E+00, -.16849500E+00, -.21331400E+01, -.23768400E+01, 0.62293300E+00, -.62979800E+00, -.39324800E+00, -.71681600E+00, 0.23406100E+00, 0.11750300E+01, -.23199300E+01, -.46347500E+01, -.41367600E+01, 0.12766900E+01, -.41509800E+00, 0.17463900E+01, 0.11798400E-01, -.10939200E+01, -.11625800E+01, 0.15318000E+01, -.46395900E+00, 0.24709500E+00, -.20513500E+00, 0.46602200E+00, -.23191000E+00, 0.54845800E+00, 0.31412700E-01, 0.32995400E+00, 0.30695800E+00, 0.61829000E+00, 0.13526200E+01, 0.10339100E+01, -.15533000E+01, 0.10960700E+01, -.72463000E+00, -.73595300E+00, 0.83634200E+00, 0.21863400E+00, 0.66671300E+00, 0.59563100E+00, -.16728600E+01, -.14124100E+01, -.43302300E+00, 0.73021500E+00, 0.16183100E+00, -.63406400E+00, -.82347300E-01, -.25533300E+00, 0.44421900E-02, 0.99323600E+00, 0.52878400E+00, 0.12520600E+01, -.19803400E+00, 0.87031000E+00, -.71539900E+00, -.43848700E+00, 0.29313900E+00, 0.22562900E+00, 0.32684900E+00, 0.11632300E-01, -.28146300E+00, 0.44283100E+00, -.21270800E+00, 0.18674700E+00, 0.51157300E-01, -.21821200E+00, -.20935600E+00, -.78910700E+00, -.89276300E+00, 0.80705700E-01, -.69707100E-03, 0.13558200E+01, -.27812200E+00, 0.57335200E+00, -.57984900E-01, -.58607200E+00, 0.97399000E+00, 0.52570500E+00, 0.23635300E+00, 0.40903100E+00, -.14570700E+01, 0.82788500E-02, 0.79865800E+00, 0.16527600E+01, -.34110400E+00, -.12664000E+01, 0.22424800E+00, 0.27890800E+01, 0.70806600E+00, 0.35096100E+00, 0.56442900E-01, 0.58579800E-01, -.44072100E-01, 0.63500900E+00, 0.23014100E-01, -.54130700E+00, 0.60110300E+00, 0.82292900E+00, 0.20061100E+01, -.41364200E-01, 0.46624600E+00, -.75353600E-01, -.11525700E-01, -.17203100E-02, 0.67294600E-01, 0.39146500E+00, -.12825600E+00, 0.39311300E+00, 0.32569200E-01, -.74540300E+00, -.61677600E+00, 0.63793700E+00, 0.28133600E+00, -.70693100E+00, -.36163000E-02, 0.17180700E+00, -.13795300E+00, -.92125800E+00, 0.61954400E+00, 0.22029100E+00, 0.15623400E+00, -.44003100E+00, 0.40065800E-01, -.42311900E-01, 0.82412600E-01, 0.60341800E-02, 0.20252400E+00, 0.31544200E+00, -.78691400E-01, 0.39351600E-01, -.16809800E+00, 0.39330200E+00, 0.20200700E+00, 0.32328800E+00, 0.40381200E+00, 0.74257800E+00, 0.14803100E+00, -.41628300E+00, 0.30010800E+00, 0.40534200E+00, 0.51791900E-01, -.33235500E+00, 0.65450000E+00, 0.17756400E+00, 0.20813800E+00, 0.76816000E-01, 0.26005000E+01, 0.11266000E+00, -.11996500E+01, -.37114000E+00, 0.11872400E+00, 0.60667500E-01, -.68890800E-01, 0.33301000E+00, -.20434600E+01, 0.11224700E-01, -.15566500E+00, -.43618100E+00, -.27390700E-01, -.77622600E-01, 0.28084700E-01, 0.46743700E+00, -.49106800E+00, -.12935400E+00, -.62711200E+00, -.75280500E-01, -.26644500E+03, 0.13331800E+03, 0.10464900E+03, 0.13322600E+03, 0.10110900E+03, -.25436800E+02, 0.11755600E+03, -.35909700E+00, 0.55007100E+02, -.52998800E+01, 0.44389300E+02, -.18591600E+03, 0.96220700E+02, -.43982600E+01, 0.92949900E+02, 0.39737700E+01, 0.25663700E+02, -.18688600E+02, -.55848000E+02, 0.73317900E+02, -.38515200E+01, 0.27232800E+03, 0.80069600E+02, -.35433100E+02, -.13636800E+03, -.40088700E+02, 0.92597800E+01, -.14226000E+02, -.85495000E+02, 0.44974000E+02, -.42925100E+02, 0.10377900E+03, -.15243100E+03, -.27345500E+03, 0.13492900E+03, 0.12703700E+03, 0.13689700E+03, 0.65445700E+02, 0.17277300E+02, 0.47648400E+02, -.98315200E+02, 0.15244400E+02, 0.33146000E+02, 0.10455700E+03, 0.23552200E+03, -.11632600E+03, -.12471600E+03, -.11775700E+03, -.28416200E+02, -.43711900E+02, -.41700300E+02, 0.29173500E+02, -.14128400E+03, -.30788600E+02, -.17430700E+03, -.23769200E+03, 0.11463300E+03, -.73921400E+02, 0.11887900E+03, -.10488900E+02, -.57136300E+02, 0.14896300E+03, 0.48456000E+01, 0.13307300E+03, -.83091400E+02, 0.19478600E+03, -.51082500E+02, 0.24016400E+02, -.11609000E+02, 0.25651100E+02, 0.28172900E+01, 0.40564900E+02, 0.15920000E+02, 0.73470500E+02, -.32417400E+01, -.22460100E+02, 0.90679100E+02, 0.43427400E+01, 0.27442700E+01, -.24220600E+00, 0.10205600E+02, -.57535800E+01, -.26795300E+01, -.38280100E+01, -.39806900E+01, 0.11536100E+00, -.84424000E+01, 0.37616400E+02, -.21348600E+01, 0.17333100E+02, -.26298300E+01, 0.52962500E+01, -.87162700E+00, 0.16738500E+02, 0.18942800E+01, 0.10719000E+02, -.94179900E+01, 0.58069400E+01, -.36770900E+01, -.10399600E+02, -.23649700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11510500E+02, 0.29809900E+00, 0.54592700E+01, -.76195100E+01, -.83386200E+01, -.33725900E+01, 0.19948300E+01, -.32975600E+00, 0.22269300E-01, 0.35303800E+00, 0.14458700E+01, 0.11389600E+01, 0.52616000E+01, -.58656400E-01, -.32656700E+00, 0.14182100E+00, -.85257300E+00, -.23340400E+00, 0.47477400E+00, -.55124100E+00, -.24011700E+00, 0.42050800E+01, 0.11326300E+01, -.20496400E+00, -.49743700E-01, -.31075300E+00, 0.20491200E+00, -.51904900E-01, 0.86244700E+00, -.41359600E+01, 0.48704300E+00, -.20168600E+00, 0.38823000E-01, -.64861500E+00, 0.31373000E+00, -.38772500E+00, 0.10400800E-03, 0.19132400E+00, -.13905900E-01, -.71530600E+00, -.66785900E+00, 0.10561700E+01, 0.38503800E+01, -.71560800E+00, 0.11404700E+01, -.14173600E+01, -.54723600E+00, -.20059900E+00, 0.17186500E+00, 0.18601900E+00, -.15618100E+01, -.16011500E+01, -.15336300E+00, -.85804300E+00, 0.64766700E+00, 0.23189100E+01, -.20635500E-01, 0.19121200E+01, 0.14144000E-02, -.26495100E+01, -.15518500E+01, -.15222900E+01, 0.33884000E+00, 0.46239900E+00, -.24354900E+01, -.27577500E+00, -.47942500E+00, 0.32954800E+00, 0.29258000E+00, -.81010800E-02, -.96831800E+00, -.47140800E+00, -.85721600E+00, 0.18823500E+00, -.78579100E+00, 0.14213500E+00, 0.65709900E+00, -.48055700E+00, 0.76159100E+00, -.27488900E+00, -.99933600E-03, -.11489300E+01, -.47733300E-02, -.64242700E-01, 0.77969000E-01, 0.11747900E+01, 0.11292100E+00, -.41857000E+00, -.20488500E+00, -.58521700E+00, -.67414100E-01, 0.54151000E-01, 0.17755600E+00, -.17113000E-01, -.31714800E+01, -.19121700E+01, 0.39358900E+00, 0.39078900E+01, -.13261100E+01, -.23668800E+00, 0.25150400E+00, 0.75377200E-01, -.76266900E-01, 0.36424000E-01, -.11007900E+01, 0.16769900E+01, 0.78492300E+00, 0.58969600E+00, -.70672100E+00, -.40640500E-01, 0.48014800E+00, 0.75597000E-01, 0.35955000E+00, 0.87910500E-02, -.70959100E+00, -.77913300E-01, -.40514700E+00, -.27789700E+00, 0.32864900E-02, -.62644200E+00, 0.37127700E+00, 0.88174200E+00, 0.22902200E+01, -.31984800E+01, 0.46666200E-02, 0.15657900E+00, -.16075200E+00, -.32469100E+01, 0.13207100E+00, 0.38090700E+00, 0.45608500E+00, -.11609400E+01, 0.45010100E+00, 0.12598100E+00, -.40492800E-01, -.62142200E-02, -.14120300E+00, 0.10840800E+01, 0.99170600E-02, -.35362300E-01, -.94548700E-01, 0.16304800E+00, 0.13311100E+00, 0.35034600E-01, -.14613100E+00, 0.43145000E+00, 0.51131600E-01, 0.12281500E+01, 0.19312000E+00, -.34440200E+00, 0.20109200E+00, 0.22479100E+00, -.31385500E+00, -.30628800E+00, 0.15392800E+00, -.10424900E-01, -.18355900E+00, 0.79494700E-01, -.22166900E+01, 0.73951000E-01, -.27146500E+00, 0.13746000E+00, 0.10247800E+01, 0.37690400E+00, -.36176300E+00, -.13871600E+00, 0.14512100E-01, 0.99343400E-01, -.76897900E-02, 0.10991000E+00, 0.94207200E-01, 0.54553800E+00, -.11517400E+01, 0.26114300E+00, 0.22662100E+00, 0.97245300E-01, 0.40245200E+00, 0.14222200E+02, 0.66447900E+02, 0.23151200E-01, -.18752500E+02, 0.88628300E+02, -.16692000E+03, -.88182800E+02, -.57081200E+02, 0.91180000E+02, 0.40882600E+02, 0.41750000E+03, -.21826500E+03, -.22440300E+03, -.20871600E+03, -.57780400E+02, -.38102400E+02, -.53788500E+02, 0.91955500E+02, -.97549200E+02, -.28253100E+02, -.10618800E+03, 0.43284000E+02, -.26611300E+02, -.24582500E+03, -.21882300E+02, -.47571200E+02, 0.18386400E+02, 0.70664300E+01, -.30632600E+02, 0.34163000E+02, -.59030400E+02, 0.50757900E+02, -.22955900E+02, 0.11535800E+02, 0.32834700E+02, 0.11456500E+02, -.40687100E+02, -.16828000E+02, 0.20795500E+02, 0.23837300E+01, 0.60353900E+02, -.17491800E+02, -.56316200E+02, -.25574800E+03, 0.12649800E+03, 0.13678600E+03, 0.12789700E+03, 0.39543900E+02, 0.34216300E+02, 0.70840300E+02, -.24971300E+02, 0.86435700E+02, 0.41450400E+02, -.37064600E+02, -.23637400E+03, 0.11801800E+03, 0.60701500E+02, 0.11833000E+03, 0.12934200E+01, -.75923400E+02, 0.10062400E+02, -.64354200E+02, 0.39677500E+02, -.37307800E+02, 0.37170800E+02, -.10978300E+02, 0.53557500E+01, 0.27426600E+02, 0.53588300E+01, 0.20749800E+02, 0.93787900E+01, 0.55728000E+01, -.55570500E+02, -.14425700E+02, 0.30444200E+02, -.15239500E+02, 0.25166200E+01, -.36617300E+01, 0.15617500E+01, -.89104000E+01, -.38100000E+01, -.59702500E+00, 0.60810400E+01, 0.24895500E+00, 0.11219000E+01, 0.13752200E+01, -.15714900E+02, -.78399400E+00, 0.31861200E+01, -.10307300E+02, -.20461000E+01, -.26876500E+01, 0.42958900E+01, -.62678600E+01, 0.10712300E+02, 0.14086100E+02, 0.14013200E+02, 0.35440400E+01, 0.33444700E+01, -.52039000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.58196000E+01, 0.14699200E+01, -.67107300E+01, 0.81023500E+00, -.35262700E+01, -.16512400E+01, 0.92605300E+00, 0.62471500E+00, -.95149700E+00, -.48601700E+00, -.27925900E+00, 0.79846900E+00, 0.41188200E+01, 0.19287100E+00, -.97573800E-01, 0.10029100E+00, 0.56979100E-01, 0.11452800E+01, 0.41338800E+00, 0.28271500E+00, 0.35529300E-01, 0.93547700E+00, -.11786600E+01, 0.75690600E+00, -.52506900E-01, -.62659600E+00, -.13573300E+00, -.23659600E+00, 0.61314200E+00, -.12365900E+01, 0.73022700E+00, -.17418700E-01, 0.44642900E-01, -.73944200E+00, 0.20498700E+00, 0.69067500E+00, 0.27216500E-01, 0.85442200E+00, 0.60206300E+00, 0.24153800E+00, -.43631200E+00, -.14790300E+01, -.76967500E+00, 0.11147600E+00, 0.37872300E+00, -.10953800E+01, -.54905200E+00, 0.13027000E+00, -.39336200E+00, -.15437600E+01, -.18389100E+01, -.15835200E+00, -.78195900E-01, -.11201700E+00, -.17448600E+00, 0.10072300E+00, -.56552700E-01, -.17360300E+01, -.13555500E-02, -.11860800E+01, -.36742400E+00, -.52496400E+00, -.13269700E+00, -.60620300E+00, 0.12782900E+01, 0.31330100E+00, 0.21082100E-01, 0.10048700E+01, -.38955600E+00, -.17300500E-02, -.97512300E+00, -.57913300E+00, -.10622100E+01, 0.14939200E+00, -.12444000E+01, 0.17934500E+00, 0.41003200E+00, 0.13421900E+01, -.10924300E+00, -.15442400E+00, -.25986800E-03, -.18719700E+01, 0.85114400E-01, -.95989300E+00, 0.30140200E+00, 0.23293700E+01, -.72582900E+00, -.28052600E+00, -.82037000E-01, -.28906000E+00, 0.85078200E-01, -.82577600E-02, -.61930800E+00, -.78397100E+00, -.52837300E-01, 0.17780600E+01, -.44471200E+00, -.17804300E+01, 0.72720700E+00, -.23198200E-01, -.25616500E+00, -.84556400E-01, -.35976200E-01, -.12482400E-02, -.12466600E+01, 0.72848800E+00, -.85922300E+00, -.91502500E+00, -.66060600E+00, 0.33418700E+00, -.45637400E-01, -.12963900E-01, 0.16826200E+00, 0.19046100E-01, -.64503800E-01, 0.12862600E+00, -.35600800E+00, 0.13711000E+00, 0.37938000E-01, -.75338200E+00, 0.40688700E+00, 0.30885300E+00, 0.61763300E+00, 0.65466100E+00, -.12677600E-01, 0.30715800E+00, 0.16587200E+00, 0.27272000E+00, -.90640500E-01, 0.14100400E+00, 0.36467800E+00, -.29827400E+00, 0.20423900E+00, -.25901000E-01, -.96193500E+00, 0.17518700E-02, 0.26496400E+00, 0.59706200E+00, -.86530800E-02, 0.36630800E-01, -.26125400E-02, -.58708100E-01, 0.18078000E-01, 0.24394400E+00, -.33081900E+00, 0.56033600E+00, -.99054000E-02, 0.10352100E+01, 0.11070400E+01, -.33521600E+00, 0.12845500E-01, 0.70705400E+00, -.40770500E+00, -.84176200E-01, 0.20652100E+00, -.16186000E+00, -.16190700E+01, 0.46812700E-01, 0.64241800E+00, -.32133400E+00, -.19328700E-01, -.31788400E+00, 0.13088600E+01, 0.34292200E+00, -.86956400E+00, 0.25007100E-01, 0.35088300E-01, 0.21721800E-01, -.55593900E-01, 0.24306600E+00, 0.22551300E+00, 0.87336000E+00, -.17732000E+01, 0.14670600E+00, 0.69670000E+00, 0.13117700E+00, 0.35230200E+00, 0.86968600E-01, 0.16687800E+03, 0.49704200E-01, -.98986400E+02, 0.46000700E+02, -.14924700E+03, -.12195700E+03, 0.41783800E+02, 0.45241500E+02, 0.25518400E+02, 0.14183500E+03, -.75966400E+02, -.18182300E+03, -.70846900E+02, -.52798600E+02, 0.19102500E+02, -.48685300E+01, 0.56397300E+02, -.19035800E+02, 0.30653500E+02, -.44307900E+02, 0.19755000E+03, -.10266700E+03, -.18941600E+03, -.99011400E+02, 0.82820200E+02, 0.93356100E+02, -.48478300E+01, -.44730700E+02, -.12802600E+03, -.75426200E+02, -.19418800E+02, 0.65780700E+03, -.33521400E+03, -.12021400E+03, -.32869100E+03, -.13302800E+03, -.53609300E+02, -.15062100E+03, 0.58184300E+02, -.18029300E+03, -.57727500E+02, -.39067700E+03, -.36026800E+03, 0.17897000E+03, 0.19886500E+03, 0.18016700E+03, 0.80574700E+02, 0.45420200E+02, 0.15209700E+03, 0.51445900E+02, 0.13124900E+03, 0.42100500E+02, 0.27987600E+02, 0.16275200E+03, -.76917300E+02, -.43723700E+02, -.81060900E+02, -.49197700E+02, -.59980900E+02, -.97907100E+02, 0.11718000E+02, -.30909200E+02, -.18856500E+02, -.18044400E+03, 0.32594300E+03, -.16332700E+03, -.25246700E+03, -.16298200E+03, -.88359000E+02, -.10261100E+03, -.24294100E+02, -.86249400E+02, -.81715500E+02, -.29993600E+02, -.12099500E+03, 0.37361900E+00, -.71592400E+01, -.18137900E+01, -.10842400E+02, 0.16633300E+01, -.38297600E+01, 0.29511500E+01, 0.51431100E+01, -.84880600E+00, 0.69950400E+01, -.19697900E+02, 0.13530400E+01, -.71868200E+01, -.17017400E+02, 0.22003000E+00, -.12356800E+01, -.41707900E+01, -.17197800E+02, 0.74530900E+01, 0.12119600E+02, 0.27100000E+02, -.84125100E+01, -.13389500E+01, 0.44999400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.11522200E+02, 0.19975300E+01, 0.46586900E+01, -.89246400E+01, -.61629300E+01, -.12088100E+01, 0.13302800E+01, 0.21750800E+01, -.84368500E+00, 0.17216900E+00, 0.12443200E+01, 0.16343600E+01, 0.95490400E+01, 0.82215800E+00, -.17044100E+00, 0.18622500E+00, -.12597400E+01, 0.16621700E+01, 0.11019700E+01, -.19478700E+01, -.40342200E+00, 0.39335100E+01, -.18219100E+01, 0.18539500E+01, 0.23279600E-01, -.15410400E+01, 0.28421700E+00, -.46200800E+00, 0.23543300E-01, -.25983800E+01, 0.13053000E+01, -.19939300E+00, 0.73796500E+00, -.42632800E+00, 0.11990600E+00, 0.13692500E+00, 0.72997300E-01, -.91719100E+00, 0.31430700E+00, -.30209300E+00, -.28640300E+00, 0.11434400E+01, -.21155900E+00, 0.18259600E-01, -.57752900E+00, -.14607800E+00, -.28081600E+00, 0.41167700E+00, -.20779900E+00, -.60330400E+00, -.26098400E+01, -.18988500E+01, -.20660600E+00, -.16709300E+00, 0.12122200E+01, 0.11482200E+01, -.28284500E+00, 0.24102400E+01, -.32373500E-02, -.85150500E+00, -.10899200E+00, 0.98149600E+00, -.15913600E+00, -.50270300E-01, 0.10132800E+01, 0.21907400E+00, -.39740700E+00, 0.22817700E+00, -.21423200E+00, -.29848800E-02, -.29874300E+00, -.52499700E+00, -.11959000E+01, 0.15471300E+00, -.57650600E+00, 0.38462500E-01, 0.23632800E+00, -.39228900E+00, -.14342900E+01, 0.16695400E+00, -.19033200E-02, 0.35549500E+00, -.15831600E+01, 0.10535300E+01, 0.50764800E-01, 0.12151100E+01, -.31120500E+00, 0.18310700E+00, 0.33665700E+00, 0.67557400E-02, -.37527000E+00, -.10049100E-01, -.62402600E+00, -.11350100E+01, -.17376600E+01, -.10656000E+01, 0.26953000E+00, 0.41499000E+01, -.77315700E+00, -.29334500E+00, -.48229100E+00, -.89537000E-01, 0.13506700E+00, -.14460700E+00, -.10276900E+01, 0.63864600E+00, 0.17524500E+00, -.58260100E+00, -.74278400E+00, 0.84510700E+00, -.21010400E+00, 0.86893700E-01, -.60236600E-01, 0.37689900E-01, -.62325800E+00, 0.82956400E+00, -.55989400E+00, -.85993700E-01, 0.21203400E+00, -.16015600E+01, -.32496600E+00, 0.92396500E+00, 0.20751000E+01, -.11609800E+01, -.30858600E-01, -.59807800E-01, -.24830900E+00, -.10864900E+01, 0.32021400E+00, -.96119200E-02, 0.40663700E+00, -.91557400E+00, 0.59739300E+00, 0.23350400E+00, 0.49523500E+00, 0.13939300E-01, 0.62406800E-01, 0.90714500E-01, -.54056400E-01, -.12600400E+00, -.18870700E+00, -.10055600E+00, 0.85253900E-01, 0.52178900E+00, 0.19319900E+00, 0.10605700E+01, 0.14988200E-02, 0.10560300E+01, 0.12290700E+01, 0.12349500E+00, 0.12182400E+00, 0.62332500E-01, -.33138800E+00, -.55681200E+00, -.27187800E-01, 0.19696200E-01, -.63249000E+00, -.92683100E-01, -.11591300E+00, 0.24213300E+00, -.30831100E+00, -.53670100E-01, -.17273700E-02, 0.38267000E-01, 0.49269300E+00, 0.24711500E+00, 0.15769400E+00, 0.15775900E-01, -.90518500E-01, 0.42195200E+00, 0.19577100E+00, -.29129100E+00, -.15198000E+01, 0.20621400E+00, 0.18208000E+00, -.12037300E+00, 0.14089700E+00, 0.76812900E-01, 0.27150100E+00, 0.80180700E+01, 0.10691300E+02, 0.52692900E+02, -.14340900E+03, -.79890800E+02, -.14610700E+03, 0.74278400E+02, 0.13949700E+02, 0.35557600E+03, -.18650100E+03, -.24493500E+03, -.17770600E+03, -.66437200E+02, -.88744900E+02, -.67444200E+02, 0.61580200E+02, -.79181800E+02, -.79347200E+02, 0.90042500E+02, 0.69719300E+02, -.41254700E+02, -.15389300E+03, -.35483100E+02, 0.13507100E+03, 0.64835700E+02, -.16535900E+02, 0.17575200E+03, 0.36717300E+02, -.19382100E+02, -.55621900E+02, -.50156400E+03, 0.24851900E+03, 0.15199400E+03, 0.25122000E+03, 0.39410800E+02, -.29017900E+02, 0.16847600E+03, -.87548300E+02, 0.15048200E+03, 0.14950800E+02, 0.85218800E+02, 0.28759200E+01, -.20281500E+01, 0.66689200E+02, -.13731000E+01, 0.30895300E+02, -.30245900E+02, 0.10179000E+02, -.16399900E+02, -.39488600E+02, -.27887800E+02, -.17174900E+03, -.38161200E+03, 0.18587500E+03, -.85248100E+02, 0.19129300E+03, -.21635400E+01, -.15206900E+03, 0.46400200E+02, -.23739300E+03, 0.87529600E+02, -.65755300E+02, 0.11122600E+03, -.11606500E+03, 0.58665100E+02, 0.72491400E+02, 0.58043600E+02, 0.21174000E+02, 0.44599300E+02, -.50507400E+02, -.18597700E+02, 0.32012900E+02, 0.45917300E+02, 0.18922400E+03, -.16694300E+01, 0.88525000E+01, 0.52049200E+01, 0.10196300E+02, -.73478500E+01, -.46937800E+00, -.83596200E+01, -.54426000E+01, -.34409500E+01, -.13369300E+02, 0.30462900E+02, 0.26739400E+01, 0.25048300E+02, -.70406000E+01, -.60425100E+01, 0.18827600E+01, 0.21896400E+02, 0.11130300E+02, 0.22982100E+02, -.18522300E+02, 0.67750100E+01, 0.36761500E+01, -.40324200E+02, 0.89347400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.38877800E+01, -.10222900E+01, -.36105200E+00, 0.17604300E+01, 0.20539200E+01, -.20784400E+00, -.34028100E+00, -.51116500E+00, 0.44251500E+00, -.22344300E+00, 0.79613500E+00, 0.13166600E+01, -.35482700E+01, 0.16798900E+00, -.26856700E+00, 0.99977000E-01, 0.38020100E+00, 0.10151100E+00, -.63057400E+00, 0.32577000E+00, -.79426900E+00, 0.16214400E+00, 0.38579800E+01, -.35059900E+01, 0.43614400E-02, 0.46419900E-01, 0.20447400E+00, -.12361600E+00, 0.12534300E+00, 0.23108100E+01, -.17093700E+00, -.19315800E+00, 0.52654600E+00, -.57976300E+00, -.61358700E-01, -.76685100E+00, 0.52248600E-01, -.33248100E-01, 0.92623800E+00, 0.50498300E-01, 0.56869400E+00, -.69699700E+00, -.18296200E+01, 0.62011600E-01, 0.70343800E+00, -.12159900E+01, -.19996800E+00, -.37431300E+00, -.32924100E+00, -.13857900E+01, -.18110500E+01, -.58934400E+00, -.29641600E+00, 0.34080100E+00, -.80183500E-01, -.11661300E+00, -.29886200E+00, 0.18983600E+01, -.10366400E-02, 0.24925000E+00, 0.43766200E+00, 0.22985200E+00, 0.34799000E-01, 0.15470000E+00, 0.12295700E+01, 0.25081200E+00, -.20803300E+00, 0.73859400E-01, -.22326400E+00, -.17298300E-02, 0.29984000E+00, 0.19999100E+00, -.31478200E+00, -.12775700E+00, -.57957300E-01, 0.27608000E+00, 0.34299100E+00, 0.46074000E+00, -.20458600E+00, -.56409100E-02, -.12126600E-02, -.47184700E+00, -.45795800E+00, 0.61334700E+00, 0.40086600E+00, 0.19394600E+00, -.10007500E+00, 0.25944000E+00, -.93474100E-01, 0.57234300E-01, -.24995800E+00, 0.46344600E-01, -.20824000E+00, -.15727400E+01, 0.98287600E+00, 0.71764900E+00, -.25411700E+00, -.84380400E+00, 0.89882600E+00, 0.46186900E+00, -.48157000E+00, -.43591100E-01, -.12887100E+00, 0.50353800E+00, 0.24580300E+00, -.64515600E+00, -.13346900E+01, -.15379300E+01, -.58053700E+00, 0.46144800E+00, -.67966400E+00, 0.21641400E-02, 0.22063800E-01, -.47657400E-02, 0.12080600E+00, 0.87241500E+00, -.29022000E+00, 0.10645800E-01, 0.23790500E+00, 0.82404900E+00, -.34474100E+00, -.98014600E-01, -.70387000E+00, 0.33321500E+01, 0.15247800E-01, 0.77741800E+00, 0.36996200E+00, 0.33369700E+01, -.44901000E+00, 0.16889900E+00, -.35736300E-01, 0.25259000E+00, 0.33529000E+00, -.62631600E-01, -.55451700E+00, -.27928100E-02, 0.67640500E+00, -.53972000E+00, 0.79519300E-01, -.16640100E+00, -.53556000E-01, -.18502500E+00, 0.10684200E+00, -.17171800E+00, 0.83237700E+00, -.92736300E+00, -.15002300E-01, 0.48418000E-01, -.63787000E+00, -.34303100E+00, 0.93331100E-01, -.31907600E+00, 0.27556500E+00, 0.23344400E+00, 0.22168200E+00, 0.12723200E+00, 0.24546100E+00, 0.15908000E-01, -.29830800E+00, 0.24746800E+00, 0.14677000E+00, 0.38546300E+00, -.21967900E+01, -.31911500E+00, -.16777600E+01, -.70889800E-01, -.12391100E+00, 0.72244000E-01, -.38852100E-01, -.85419700E-01, 0.24996900E+00, -.73175500E-01, 0.88883500E+00, -.20516400E-01, 0.28473100E+00, 0.59243500E-01, -.50672600E+00, 0.52070900E-01, -.20486600E+00, 0.20289700E-03, -.46060700E+02, -.97943200E+02, 0.87474800E+02, 0.82229900E+01, 0.54764900E+02, -.85098600E+02, -.36818900E+02, -.26560900E+03, 0.13432000E+03, 0.15406300E+03, 0.13280500E+03, 0.69787500E+02, -.12691400E+01, 0.71889900E+02, -.34716700E+02, 0.92262200E+02, 0.12788500E+02, -.16826500E+02, 0.19785300E+03, -.10116200E+03, 0.31381200E+03, -.98576400E+02, 0.16300300E+03, 0.67379100E+01, 0.83175400E+00, 0.97514500E+02, -.13181400E+03, -.67163400E+01, -.13583700E+03, 0.15075100E+03, -.80752800E+02, -.17581800E+02, -.75046100E+02, -.20706400E+01, 0.10648700E+02, -.81839700E+02, -.80289900E+01, -.69504000E+02, 0.12101400E+02, -.31581400E+02, -.46900100E+02, 0.23067900E+02, -.14471100E+02, 0.23429400E+02, 0.35419400E+02, 0.42146100E+02, 0.18877100E+02, 0.26826300E+02, 0.31988000E+02, 0.36645600E+02, 0.12244900E+03, 0.15734600E+03, -.80253900E+02, -.35003000E+02, -.78649000E+02, 0.21391300E+01, 0.56143300E+02, -.88621000E+02, -.13417100E+03, -.50174500E+02, 0.45686000E+02, -.36045800E+02, 0.11185700E+03, -.56236000E+02, -.13984000E+03, -.55592100E+02, -.69856200E+02, -.67881000E+02, -.30955300E+02, 0.19531600E+02, 0.99590300E+01, -.42600400E+02, -.56038200E+02, 0.71535400E-01, -.12279100E+01, -.31995700E+01, -.35063600E+01, 0.65247100E+01, -.73376300E+01, 0.16834500E+01, 0.29349400E+01, 0.27830500E+01, 0.31064900E+01, -.30956700E+01, 0.15434000E+00, 0.13607000E+01, -.24489800E+01, -.23284100E+01, -.11179600E+01, 0.18990300E+01, -.59694300E+00, 0.14618000E+01, -.57284500E+01, 0.71983500E+01, -.56741900E+01, -.19492400E-01, 0.98898500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22515200E+01, 0.94963000E+00, 0.44059100E+00, -.76142000E+00, -.21163300E+01, 0.14752400E+00, 0.22804700E+00, -.89692600E+00, 0.18131700E+00, 0.29731100E+00, 0.22965600E+00, 0.43977900E+00, -.40176500E-01, -.74195700E+00, 0.24944300E-01, 0.11904000E+00, -.18437200E+00, -.54944700E+00, -.93783000E-01, -.45383900E+00, 0.69402300E-01, 0.11108700E+01, 0.19308600E+01, -.64910800E+00, -.22003100E-01, 0.27099200E-01, 0.16416100E+00, -.37290400E-01, 0.52955200E+00, 0.10033300E+01, 0.11353700E+00, -.12967100E+00, 0.22321800E+00, -.65265500E+00, 0.33341700E-01, -.46442200E+00, 0.13597100E-01, 0.12995100E+00, 0.22662400E+00, -.14875700E+00, 0.20728300E+00, -.48370100E+00, -.53987600E+00, -.20632800E+00, -.73009800E-02, 0.20991300E+00, -.65140100E-01, -.11583600E+00, -.73815800E-01, -.18894300E+00, 0.64998100E+00, 0.14787900E+00, 0.10941200E+00, -.18840500E+00, 0.36687600E+00, 0.47727900E+00, -.28189600E-01, 0.79516800E+00, -.20818300E-02, -.51419400E+00, -.30031200E+00, -.29450200E+00, 0.58689500E-01, -.18699400E+00, -.20883000E+00, -.93799600E-01, -.53795900E-01, 0.39914100E+00, -.11157400E+00, -.46242400E-02, 0.95550800E-01, 0.10026400E+00, 0.52698900E+00, -.15765400E+00, 0.11083600E+00, 0.70445200E-01, 0.22216800E-01, 0.49421500E+00, -.54696100E+00, 0.39395400E-01, 0.37802300E-04, -.14923800E+00, -.65678700E+00, 0.86864700E+00, 0.20652000E+00, 0.52146500E+00, -.28796100E+00, 0.29998400E-01, -.19728800E+00, 0.15965400E-02, 0.16169400E+00, -.66589200E-02, -.14221600E+00, -.20008300E+00, 0.31163900E+00, 0.10547600E+00, -.23417000E+00, 0.26418600E-01, 0.65018100E-01, 0.90567000E-01, -.31361600E+00, -.26730600E-01, 0.54156100E-01, 0.13941800E+00, -.19784900E+00, 0.43613500E+00, -.32752300E+00, 0.19157200E+00, -.12648600E+00, -.24046700E-01, 0.97874000E-01, 0.12199300E-01, 0.13613700E+00, 0.15553200E-02, 0.16258500E+00, -.87083900E+00, 0.37082300E+00, -.36610200E+00, -.11911800E-01, 0.31112300E+00, 0.67838100E-01, -.15603100E+00, -.30071100E+00, -.55084800E+00, 0.14813700E-02, 0.11161800E-01, 0.18235000E+00, 0.41592000E+00, 0.61427200E-01, 0.73202100E-01, 0.12631000E+00, 0.14127700E+00, -.33094200E-01, -.56180500E-02, -.10683000E+01, -.14785100E-02, 0.21556900E-01, 0.63202200E-01, 0.10445200E+00, -.16486900E-01, -.78800800E-01, -.13621500E+00, -.23626900E-01, 0.80492300E-01, 0.27125300E+00, 0.40133100E-02, 0.39598700E-03, 0.57051300E+00, 0.41899100E+00, 0.34810600E-01, 0.72273900E-01, -.35538000E-01, 0.52135700E-05, -.64991100E-01, 0.76441200E-01, -.91495300E-02, 0.33886200E+00, -.24162100E-01, -.53827800E-01, 0.16268100E+00, -.74185100E-01, -.29355400E-01, -.96682400E-01, 0.10444100E+00, 0.29609300E+00, 0.12077700E+00, -.35853000E-02, 0.21743100E-01, -.29138800E-02, 0.33497300E+00, -.72462100E-01, 0.66606900E+00, -.79749000E+00, -.62277600E-01, 0.17566500E+00, -.11814000E+00, -.91254600E-01, 0.16612000E-01, -.20381200E+00, -.80272800E-03, 0.21773000E+00, -.58624000E+02, 0.35513300E+02, -.62768400E+02, -.12429900E+02, -.56493700E+02, -.71280300E+01, 0.21301300E+03, -.10690600E+03, -.15138100E+03, -.10652600E+03, 0.34848400E+01, 0.26946300E+02, -.53605900E+02, 0.50352900E+02, -.65604100E+02, 0.14459400E+02, -.82289700E+02, -.31554300E+03, 0.15548600E+03, 0.52705300E+02, 0.15749200E+03, 0.11351700E+03, -.47148900E+02, 0.65372200E+02, -.32540800E+02, 0.66801200E+02, -.54292800E+02, 0.12495000E+03, -.11118100E+03, 0.53531700E+02, 0.11273200E+02, 0.55467800E+02, 0.39663900E+02, -.30573800E+02, 0.49753100E+02, -.14280100E+02, 0.37723400E+02, -.84460400E+01, -.24602100E+02, 0.15551600E+02, -.84350500E+01, -.37807400E+02, -.77621100E+01, 0.40263200E+01, -.28042400E+01, 0.15784100E+02, 0.45655900E+02, 0.11069000E+02, -.70305900E+00, 0.44850900E+01, 0.32332600E+03, -.16344700E+03, -.20300300E+03, -.16170000E+03, -.17343800E+02, 0.39549200E+02, -.78686300E+02, -.24273400E+00, -.92002400E+02, 0.59780300E+02, -.17563800E+03, 0.13076300E+03, -.65685900E+02, -.75199300E+02, -.65530000E+02, -.40242600E+02, -.85112500E+01, -.75462500E+02, -.36255800E+02, -.65376600E+02, -.25012900E+01, 0.19397300E+02, -.13649000E+01, 0.73781000E+01, 0.75165300E+00, 0.77368800E+01, 0.38139800E+00, 0.40944100E+01, -.70117800E+01, -.37752900E+00, -.23712400E+01, -.27644600E+01, 0.76365600E+01, 0.27837100E+01, 0.13330800E+01, -.10746600E+02, -.31533300E+01, 0.23458700E+01, -.82264900E+01, 0.13689800E+01, 0.38752200E+01, -.59459600E+01, -.17337200E+02, 0.93233300E+01, -.39260000E+01, 0.43054900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.45104300E+01, 0.41577700E+00, 0.12497300E+01, -.11421700E+01, -.12064200E+01, -.22591000E+01, 0.39494200E+00, 0.14246500E+00, -.10154500E+01, -.99064900E-01, -.17489100E+01, -.41452900E-02, 0.56328200E+01, 0.29177300E+01, -.67622600E-01, 0.46534800E+00, -.16552500E+00, 0.22685000E+01, 0.43543800E+00, -.19947600E+01, 0.13979100E+01, 0.40405000E+01, 0.16164000E+01, -.13671300E+00, 0.19529800E+00, -.99648700E+00, 0.16409300E+00, 0.24539300E+00, 0.24516300E+00, 0.78360400E+00, 0.32328800E+00, -.51988600E+00, 0.12280200E+01, -.61741600E+00, 0.83419300E-01, -.57739600E+00, 0.11082500E-01, -.11088000E+01, 0.91378600E-01, 0.17415600E+00, 0.81882300E+00, 0.55890400E+00, -.16745100E+01, -.98063900E-01, -.57680600E+00, -.43074900E-01, 0.89352500E+00, -.45273900E+00, -.27004500E+00, 0.10994200E+00, -.24116600E+00, 0.56754900E+00, 0.25315800E+00, -.21243000E+00, 0.63557400E+00, -.24067700E+00, 0.52360100E+00, -.16613900E+01, 0.33294100E-03, -.79056400E+00, -.32718300E+00, -.84444900E+00, 0.10139800E+00, -.18174900E+00, -.18319400E+00, 0.67917400E+00, -.10335700E+00, -.45844100E+00, 0.40514600E+00, -.28517600E-02, -.93046800E+00, -.74775900E-01, 0.35712800E+00, 0.20577300E+00, 0.55797300E+00, -.98448800E-01, -.50575000E+00, -.60505400E+00, -.17016900E+00, 0.47469100E+00, 0.23632800E-03, 0.94875600E+00, -.20174900E-01, -.89963800E+00, -.14535800E-01, -.13386300E+01, -.46279200E-01, -.25429100E+00, -.61994900E+00, 0.46552300E+00, 0.60639500E+00, 0.51600700E-01, 0.18310300E-02, 0.16938400E+01, -.98016500E+00, -.14218300E+01, 0.34522500E+00, 0.11303800E+01, 0.64735200E+00, -.16854200E-02, 0.28412500E-01, -.12308200E+00, 0.37368200E-01, 0.16940500E+00, -.13571500E+00, 0.15327700E+01, 0.10751400E+01, 0.12768100E+01, 0.12488000E+01, 0.95276200E-01, 0.14414400E+00, 0.96548500E-01, -.78201700E-02, -.26110800E-02, -.73708600E+00, -.79302100E+00, 0.52685500E+00, 0.21283400E+00, -.40141700E-01, 0.37607400E+00, 0.51260400E+00, 0.13171000E+01, -.46046300E-01, 0.52878200E+01, 0.24850200E-01, -.12410500E+00, -.11478300E+00, 0.76823300E+00, 0.29163500E+00, 0.17058000E-01, 0.34722400E+00, 0.60634000E-01, -.25539900E+00, -.90568800E-01, -.67357500E+00, -.21648100E-02, -.11662700E+01, 0.99994900E+00, 0.14470400E-01, -.17742500E+00, 0.29357700E+00, 0.18290200E+00, 0.24621000E+00, -.23692500E+00, 0.42943500E+00, -.96840200E+00, -.35931700E-01, 0.20687900E+00, -.12983200E+01, -.87419700E-01, 0.20359300E+00, -.25456400E+00, 0.35101200E+00, 0.33851100E-01, -.59062300E-01, 0.15993700E+00, 0.31200500E+01, -.67332200E-01, -.17102500E+01, -.33550600E+00, -.76080700E-01, 0.44848200E+00, -.16984800E+00, 0.24093000E+00, -.14892100E+01, -.10040300E+00, -.14609400E+00, -.22990900E+00, 0.76414800E-02, -.11106800E+00, -.26337800E+00, 0.39478300E+00, 0.84733300E-01, -.49926800E+00, 0.24356900E+00, 0.12701000E+00, -.70016600E-01, -.51409200E-01, 0.32240800E+00, 0.43336200E-02, -.90032000E+00, -.43087300E+00, 0.14536800E+03, 0.32470800E+02, 0.43156600E+02, -.17745200E+02, -.31804200E+02, -.38659100E+03, 0.22071900E+03, 0.29434300E+03, 0.19333700E+03, 0.10820400E+03, 0.87332500E+02, 0.59989200E+02, -.76760800E+02, 0.73195000E+02, 0.78447600E+02, -.20176800E+03, -.56360400E+03, 0.29663700E+03, -.19104000E+03, 0.28185700E+03, -.25368700E+03, -.30293300E+03, 0.19133600E+03, -.18105100E+03, 0.20728600E+03, -.12343500E+03, 0.18989100E+03, 0.87158400E+01, 0.34294100E+01, -.78180600E+02, -.39863200E+01, 0.63432000E+02, 0.36203600E+02, -.75577700E+02, 0.41212100E+02, 0.27700800E+02, -.75583900E+01, 0.13041100E+03, 0.91237800E+02, -.42463500E+02, -.18337200E+03, -.45610000E+02, -.13292800E+03, 0.14848500E+02, -.55684600E+02, -.22047500E+02, 0.12963100E+02, 0.31520800E+02, 0.23664600E+03, -.52540300E+02, 0.26646500E+02, 0.28933300E+02, 0.26486500E+02, -.89047500E+01, 0.87822400E+02, 0.68510600E+02, 0.19430300E+03, 0.59289200E+02, 0.40532700E+01, 0.15813800E+03, -.40952700E+00, -.17159500E+01, -.42906800E+01, 0.42926100E+00, 0.24048700E+02, 0.16649300E+02, 0.29273000E+02, 0.21568700E+02, 0.80440100E+02, -.32389000E+02, -.13019900E+03, 0.43367100E+01, -.11229500E+02, -.38243300E+01, -.15826200E+02, 0.45221500E+01, -.79431700E+00, 0.16693800E+02, 0.46143700E+01, 0.84082600E+01, 0.13176500E+02, -.64106400E+02, -.58367700E+01, -.18930600E+02, 0.95605700E+01, 0.53550500E+01, -.48958700E+01, -.22021900E+02, -.11689900E+02, -.20653600E+02, 0.33624200E+02, -.31215100E+02, 0.14206400E+02, 0.60735300E+02, 0.20011400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.70332700E+01, -.21076500E+01, -.11995200E+00, 0.15292200E+00, 0.46102600E+01, 0.67825800E+00, -.98320800E+00, 0.10365500E+01, 0.21767600E+00, -.11488700E+01, -.56749300E+01, -.26334900E+01, -.19472000E+01, -.21203800E+01, 0.12090400E+01, 0.44503600E+00, -.39732600E+00, -.47734200E+00, -.51998300E+00, 0.71695400E+00, -.55932000E+00, -.47497500E+00, -.65230000E+01, 0.25282900E+01, 0.21602800E-01, -.17513400E+00, -.32453300E+00, -.42608600E+00, -.15943900E+01, 0.12092900E+01, -.68741800E+00, -.46167000E+00, 0.96367100E-01, 0.21712600E+00, -.40937000E-01, -.10751600E+01, 0.25139700E-01, -.58972900E+00, -.29400900E+00, 0.55127000E+00, 0.35993500E+00, 0.72730500E+00, -.50453200E+01, 0.15457800E+01, 0.30145500E+00, -.20201400E+01, 0.40825700E+00, -.31857000E+00, -.64799900E+00, -.73444400E+00, -.15787900E+01, -.84110700E+00, -.24006300E+00, -.21309600E-01, 0.31203200E+00, -.82709100E+00, -.94648500E-01, -.25733000E+01, 0.13011500E-03, -.60440500E+00, 0.25727200E+00, 0.62188600E+00, -.39775500E+00, -.71731600E-01, 0.19765700E+01, 0.56161500E+00, 0.10566400E+00, -.31790300E+00, 0.14057000E+00, 0.58475200E-02, -.89648700E+00, -.12221700E-01, -.62859100E+00, 0.37442100E-01, -.10391500E+00, -.16914400E-01, 0.69419500E-01, 0.80708900E+00, -.40697600E+00, -.82730600E-01, 0.11064300E-02, -.76684800E+00, 0.31796800E+00, 0.19595700E+01, 0.40313500E+00, 0.73904300E+00, 0.23963900E+00, 0.25426200E+00, 0.82453000E-01, -.10454500E+00, -.65486200E+00, -.80922500E-01, -.19745500E+00, -.26328800E+01, -.54923100E-01, -.33690900E+00, 0.23241400E+00, -.25511300E+01, 0.36543200E+00, 0.65032400E+00, 0.53693400E+00, 0.12269300E+00, 0.43007300E-01, -.43227500E-01, 0.58209300E+00, 0.73925400E+00, 0.17908700E+00, -.50708600E+00, 0.75944100E+00, 0.55574600E+00, -.34271200E+00, 0.68485900E-01, 0.20834900E+00, 0.41443800E-02, -.27851200E-01, -.58522800E-02, 0.64101000E-01, 0.68532200E-01, -.24584300E-01, 0.22253000E+01, 0.23158900E+00, -.24418400E+00, -.72698500E+00, 0.12754500E+01, -.13673100E-02, 0.70321300E+00, 0.11998800E+00, 0.89092600E+00, -.10128200E+00, -.36317500E+00, -.70691600E-01, 0.19419400E+00, -.22329000E+00, -.66711900E-01, -.68414600E+00, -.18918100E-02, -.31034400E+00, 0.66047200E+00, 0.50132600E-01, -.91818400E-02, 0.60967000E-01, 0.91797700E-01, 0.10028300E+00, -.11192100E+00, -.95089000E+00, -.40886200E+00, -.12512100E-01, -.10141300E+01, -.73639700E+00, -.61577700E+00, -.25500800E+00, 0.23554400E+00, 0.97373600E+00, 0.68742300E+00, -.37079700E+00, -.26835800E+00, 0.11850000E+01, 0.42416600E-01, 0.16006600E+01, -.66870400E+00, -.72245000E+00, 0.12718500E-01, 0.12122900E+01, 0.52311300E+00, -.26330400E+01, -.89138300E-01, -.15980000E+00, -.42056500E+00, -.67970700E-01, -.25869800E+00, 0.18422100E+00, -.41838600E-01, -.39679400E+00, -.70133300E+00, 0.14590900E+00, -.27558000E+00, -.64539300E+00, 0.16114200E+00, -.86246600E-01, 0.10413000E-02, 0.15327100E+01, 0.47015600E+00, -.67161500E+00, -.14476000E+03, -.14468900E+03, -.57963600E+01, -.49713500E+02, -.60287000E+03, 0.33614600E+03, -.44500500E+02, 0.30145300E+03, 0.10992500E+01, 0.14718000E+03, -.97351900E+00, -.14476900E+03, 0.10152400E+03, 0.10675200E+03, 0.29161000E+03, -.58135900E+03, 0.32136500E+03, -.59772200E+03, 0.29033200E+03, 0.23375600E+03, 0.12773400E+03, 0.15182800E+02, -.18923900E+03, 0.94113900E+02, -.10789700E+02, 0.40121000E+03, 0.48403300E+03, -.24063100E+03, -.63358700E+02, -.24174600E+03, -.10716300E+02, -.70294900E+02, -.85888400E+02, -.45961400E+02, -.26404500E+03, -.31677500E+02, -.42797600E+03, 0.26511000E+03, -.12564100E+03, -.13842400E+03, -.13252300E+03, -.75943800E+02, -.10238400E+03, -.39446700E+02, 0.49730500E+02, -.14448400E+03, -.95180700E+02, -.34835000E+01, 0.11494600E+04, -.57619600E+03, -.43318000E+03, -.57453100E+03, -.20268100E+03, -.97874800E+02, -.19179500E+03, 0.27631600E+03, -.31206100E+03, 0.78748600E+01, -.66185600E+03, 0.26901500E+03, -.14082500E+03, -.48148400E+02, -.13445300E+03, -.14011800E+03, -.11230000E+03, -.15805700E+02, 0.86347600E+02, 0.62368600E+02, -.86224800E+02, 0.13661000E+03, -.11916900E+01, -.38802800E+00, 0.76609100E+01, 0.15732100E+02, -.54945200E+01, 0.60824000E+01, -.10605100E+02, -.21366300E+00, -.10507300E+02, -.11745200E+02, 0.14875900E+01, 0.32347100E+01, 0.11892000E+02, -.12556300E+02, -.42333500E+01, 0.45826100E+01, -.21048700E+01, 0.94572600E+01, 0.86652800E+01, -.35953200E+02, 0.65259800E+01, 0.79591900E+01, -.66578200E+02, 0.23020000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.31732800E+01, -.30506100E+00, -.92829000E+00, 0.22721700E+00, 0.10086000E+01, 0.13902500E+01, -.27287300E+00, 0.24114100E+00, 0.52635700E+00, -.10449400E+00, -.48116500E+00, -.47726900E+00, -.23071800E+01, -.94262800E+00, -.24787500E+00, 0.18414300E-01, 0.17658000E+00, -.29312000E+00, -.29989100E+00, 0.27621000E+00, -.59465700E+00, -.99383700E+00, 0.23819700E+00, -.12025000E+01, 0.10349100E+00, -.48413500E+00, -.36811000E+00, 0.11667300E+00, -.36842800E+00, 0.56876000E+00, 0.11111900E+00, 0.75754100E-01, -.18679100E+00, 0.11975200E+00, -.49731100E-01, 0.10624000E+00, 0.75583600E-02, 0.50649500E-01, -.28914400E+00, 0.12770400E+00, 0.81362300E-01, 0.19027300E+00, 0.44422700E+00, 0.20961700E+00, -.25339200E+00, -.23872600E+00, 0.49667200E+00, 0.19061800E+00, -.31219200E+00, -.49343800E+00, -.95599100E-01, 0.13154000E+00, -.84172500E-01, 0.10594900E+00, -.61716300E-01, -.15907900E-01, -.35830800E-01, 0.93523600E+00, -.27028900E-03, 0.48224100E+00, -.28473800E-01, 0.54748000E-02, -.21067000E-01, 0.53160600E-01, -.50579400E-01, -.22031400E+00, 0.44162900E+00, -.41430100E+00, 0.27135700E+00, -.39727100E-03, 0.71876100E+00, 0.18847000E+00, 0.47888900E+00, -.10594000E+00, 0.44528100E+00, 0.97918500E-01, -.12074100E+00, 0.39647200E-01, -.24683600E+00, 0.31896800E+00, -.96572000E-03, 0.72593600E+00, -.69505500E+00, 0.12521300E+01, 0.25700500E+00, 0.65291000E+00, 0.62324700E+00, 0.32564700E+00, 0.19531400E+00, -.11125700E+00, -.57729800E-01, 0.47903200E-01, -.77437900E+00, -.21184600E+01, 0.43731100E+00, 0.84687400E-01, -.13918300E+00, -.17704600E+00, -.11551300E+00, 0.38503600E+00, -.10545800E+01, -.11502400E+00, -.13150500E+00, -.19063700E+00, -.18839800E+00, -.48987200E+00, -.27515600E+00, -.80647500E+00, -.48847300E+00, 0.87250500E-01, -.22256400E+00, 0.47255900E-01, 0.52327700E-01, -.84579200E-02, -.56579300E-01, 0.85589500E-01, 0.87330800E-02, -.23334100E+00, -.82324400E-01, 0.34205300E+00, 0.55936800E+00, -.69286500E+00, -.28640500E-03, -.70201900E+00, 0.48913000E-02, 0.91064400E-01, 0.35005000E-01, -.18580400E+00, 0.29526100E-01, -.91062600E-01, 0.17630000E+00, -.39686100E-01, -.66993600E-01, 0.25867100E-01, -.32159200E+00, -.23540900E-02, -.10113600E+00, 0.30779700E-01, 0.71785400E-01, -.12708800E-01, -.13899000E+00, -.49570300E-01, 0.66740300E-01, -.32417600E-01, 0.16940100E-02, 0.26956300E+00, -.19663100E-01, -.99938100E-01, 0.35141500E+00, 0.41536500E+00, -.93888200E-01, -.46834100E-01, -.37707400E-01, -.43209200E-01, 0.66487500E-01, -.87029500E-01, -.34704300E+00, -.52893700E-01, 0.13891800E+01, 0.16682800E+00, -.10140400E+00, -.19930600E+00, -.72342800E+00, -.65817300E-01, -.45665000E+00, 0.13882200E+00, 0.12969800E-01, -.71362900E-01, 0.49607800E-04, 0.17435000E-01, 0.34662200E+00, 0.46853100E+00, 0.80736300E-01, 0.10763600E+00, -.26981500E+00, -.92566500E-01, 0.96214300E-01, -.56091500E-01, -.13006000E+00, 0.10352800E-02, -.14218600E+00, 0.81505400E+00, -.63763900E-01, -.37610900E+00, -.38419700E+02, -.16696600E+02, -.26084300E+02, -.49791600E+03, 0.25847000E+03, 0.16668100E+03, 0.24898200E+03, 0.29164700E+02, 0.20318900E+02, 0.84156300E+02, -.10172900E+03, 0.12244700E+03, 0.22779200E+02, 0.20523900E+03, 0.39174800E+02, -.75750600E+01, 0.12325300E+03, -.19672600E+02, 0.15081600E+03, 0.81212200E+02, -.20141100E+02, 0.70927200E+02, -.66717200E+02, 0.20998500E+02, 0.66137800E+01, 0.17185000E+03, -.81765700E+02, -.24900000E+01, -.85630900E+02, -.56427500E+02, 0.69567200E+00, -.66977300E+02, -.58720800E+02, -.11085700E+03, 0.81187400E+01, -.49891900E+02, 0.16973000E+03, -.81786300E+02, -.54777200E+02, -.84850000E+02, 0.27413900E+01, -.12289000E+01, -.56521000E+02, -.19353700E+01, -.10464500E+03, -.11626500E+02, 0.10585800E+02, 0.22515300E+03, -.11539000E+03, -.60067500E+02, -.11240300E+03, -.25029900E+02, -.83473400E+01, -.51291000E+02, -.15854800E+02, -.51698900E+02, 0.22124600E+02, -.11067400E+03, -.14644000E+02, 0.47681400E+01, -.25994900E+02, 0.74678100E+01, -.34320100E+02, -.38201500E+02, 0.18091500E+02, 0.70778000E+02, 0.71042700E+02, -.12429800E+02, 0.41769500E+02, -.90302900E+00, 0.16208600E+01, -.72595900E+00, 0.10249100E+02, 0.17243000E+01, -.24407600E+01, -.62143800E+01, 0.48888400E+00, -.13372600E+01, -.31461700E+01, 0.17253200E+02, 0.31830700E+00, 0.72177100E+01, 0.43809800E+01, -.88585600E+00, 0.96000900E+00, 0.76133000E+01, 0.46564700E+01, 0.24591500E+01, -.20888700E+02, 0.19675500E+02, -.16925300E+02, -.24950300E+02, 0.67378000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.28444500E+01, -.41888000E+00, -.45352600E+00, 0.73265900E+00, 0.69719700E+00, -.16002900E+00, -.13618000E+00, 0.21856500E+00, 0.16795800E+00, -.18576600E-02, -.28710000E+00, -.31772900E+00, -.69751700E+00, 0.11390500E+01, -.13785400E+00, -.26310800E-01, 0.13139300E+00, -.93069900E+00, -.19571200E+00, 0.38109100E+00, 0.24190300E+00, 0.31838800E-01, 0.12303700E+01, -.62086400E-01, 0.11159200E+00, -.43195100E+00, 0.40534200E-01, 0.18166300E+00, 0.14684500E+00, -.12014600E+01, 0.13011900E+00, 0.27275300E+00, -.25283400E-02, 0.53073900E+00, -.97484900E-02, 0.31551600E+00, -.19268300E-01, 0.29341600E+00, 0.52307700E-01, -.29799200E+00, -.11291100E-01, 0.10830000E+00, 0.89957100E+00, -.55859800E+00, 0.36791300E+00, 0.14083700E+01, -.18878400E+00, 0.66264800E-01, 0.23677300E+00, 0.25599000E+00, -.18629800E+00, -.45880600E+00, -.10572600E+00, 0.67590200E-01, -.22068400E+00, 0.58906800E+00, -.26939400E+00, 0.72553200E+00, -.15184700E-02, -.71528800E-01, -.22324000E+00, -.31887400E+00, 0.11263900E+00, 0.39460300E+00, -.11101800E+01, -.49088200E+00, 0.18926700E+00, 0.22967400E+00, 0.22833200E+00, -.47297900E-02, 0.10982500E+00, 0.24342400E-01, 0.30904800E+00, -.23491400E+00, -.15523600E+00, 0.79257700E-01, 0.24783300E+00, 0.15382300E+00, 0.69611900E+00, -.13005100E+00, 0.62329900E-03, -.35235300E+00, 0.33663800E+00, -.17923200E+01, -.68655900E-01, -.89287700E-01, -.27429400E+00, -.26109100E-01, -.15518700E+00, -.86194900E-01, 0.76343900E+00, 0.36656300E-01, -.12220300E+00, 0.38077300E+00, -.13631800E+00, 0.29273200E+00, -.21074700E+00, 0.98485800E+00, 0.33615200E+00, -.41932700E+00, 0.38535000E+00, -.73342800E-01, 0.77397200E-01, -.48578200E-02, -.29267000E-01, -.22620800E+00, -.26673600E+00, 0.54561800E+00, -.27888900E-02, -.16582200E+00, -.29732200E+00, -.56903400E-01, 0.10260000E-01, -.30663000E-02, 0.21319900E+00, -.54480600E+00, 0.37960500E+00, -.32380000E+00, -.91697300E-02, 0.25399500E+00, 0.23266200E+00, -.48185300E+00, -.12311300E+00, -.35751700E+00, 0.44115200E-02, -.20092300E+00, 0.16718400E+00, -.10016200E+00, -.18551200E-01, 0.64516800E-01, -.24484900E-01, 0.38289700E+00, -.19646400E+00, -.76312300E-01, 0.14056500E+00, -.28583800E-02, 0.19835100E+00, -.38589200E-01, 0.76674500E-01, 0.88561100E-01, 0.12707900E+00, 0.57411600E-02, -.18822100E+00, -.95890100E-01, -.25011100E+00, -.52731000E-01, -.30492700E-01, 0.23891900E+00, 0.49016500E+00, -.28709700E+00, 0.30967700E-01, 0.27644900E-01, -.11918800E+00, -.88316600E-02, -.15429500E+00, -.30596100E-01, 0.86745800E+00, -.45432800E-01, 0.20551900E-01, -.23520400E+00, -.25593300E+00, 0.33549900E+00, -.46353400E+00, -.23674300E+00, -.16968400E+00, 0.13193500E+00, -.26202600E-01, 0.72818800E-01, -.28930800E-01, 0.28751700E+00, 0.83351500E-01, -.81041500E+00, -.68212300E+00, 0.10426400E+00, 0.18632500E+00, 0.77393200E-01, -.33927200E+00, 0.12649500E+00, 0.16570600E+00, 0.14601700E-02, -.21400400E+00, -.30883200E+00, 0.28087200E+00, 0.33482500E+00, -.53245600E+00, 0.32929400E+02, 0.20383300E+02, 0.52725500E+02, -.42734700E+02, -.61454700E+02, -.26361200E+02, -.18480900E+02, -.41897700E+02, 0.11762800E+01, 0.20570700E+02, 0.26467800E+02, -.35336100E+02, 0.97542400E+02, 0.41280800E+03, -.22071200E+03, 0.19805700E+03, -.20648300E+03, 0.10064100E+03, 0.75109800E+02, -.90291500E+02, 0.71062900E+02, -.21769700E+03, 0.30549100E+02, -.16485900E+03, -.64394700E+01, -.76918200E+01, 0.71076800E+02, 0.32900500E+01, 0.61654100E+01, -.63951800E+01, 0.11603000E+02, -.10798800E+01, -.70547400E+01, 0.11803500E+02, -.43526400E+02, -.68905000E+02, 0.31619000E+02, 0.72957300E+02, 0.34458800E+02, 0.59800400E+02, 0.40553600E+02, 0.21606400E+02, 0.68970900E+01, -.15930200E+02, 0.35410400E+02, -.27529100E+02, -.19380400E+03, 0.95899900E+02, 0.11243500E+03, 0.96940900E+02, 0.52178800E+02, -.77161200E+01, 0.13140900E+02, -.12385500E+03, 0.95249800E+02, 0.17667300E+02, 0.63162300E+02, 0.30849900E+01, -.53390900E+00, -.45668600E+02, -.15199300E+01, -.66285600E+01, 0.71363200E+00, -.48501600E+02, -.33912400E+01, -.33102100E+02, 0.14160800E+02, 0.58553300E+02, -.14974500E+01, 0.44505200E+01, 0.66742800E-01, 0.53089000E+01, 0.18875700E+01, -.18068400E+01, -.52185300E+01, -.51876500E+00, 0.70168900E+00, -.56470800E+01, 0.16410300E+02, 0.11893800E+01, 0.11397500E+02, -.66366000E+01, -.63408400E+00, 0.11712100E+01, 0.15486800E+02, 0.18871000E+01, 0.12948700E+02, -.57240400E+01, 0.17377500E+02, -.10745600E+02, -.47278900E+00, -.29752000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.58872600E+01, -.26799000E+01, -.11454000E+01, -.37707700E+00, 0.45889200E+01, -.28439900E+01, -.60015300E+00, 0.53785600E+01, -.13441800E+01, -.22978800E+01, 0.10544800E+01, 0.30439000E+00, -.19187400E+01, 0.21106000E+01, -.46188100E+00, -.59318100E+00, 0.85646800E+00, 0.49743500E+00, -.41900900E+00, 0.54995000E+00, 0.94751600E+00, -.38022400E+01, 0.11252500E+01, -.29483800E+00, 0.97314900E-01, -.33716900E+00, 0.65284000E+00, 0.71734700E+00, 0.38059200E+00, 0.35765000E+00, 0.46916600E+00, 0.68916500E+00, 0.23886900E+00, 0.50762000E+00, -.99150500E-02, 0.65358000E+00, 0.16323000E-01, 0.48856900E+00, 0.51997700E+00, -.29776300E+00, -.40067800E+00, 0.60805700E-01, 0.25284000E+01, 0.10590300E+00, 0.19285200E+01, -.18644800E+01, -.36630600E+00, -.50621300E-01, 0.55385000E+00, -.57863500E+00, -.31493500E+01, -.28141500E+01, -.79798200E+00, 0.73299800E+00, 0.24796200E+00, 0.43724000E+00, -.87961800E+00, 0.23255700E+00, 0.23778500E-02, 0.70731100E+00, 0.94100100E+00, 0.12860700E+01, -.10541100E+00, 0.10726400E+01, -.10164500E+00, -.18811800E+00, 0.58054700E+00, 0.21078900E+01, -.11361800E+00, 0.80065700E-02, -.42605000E+00, -.19404500E+00, -.90089000E+00, -.22094100E-01, -.10920600E+01, 0.10347700E-01, 0.14799000E+00, 0.68710700E+00, -.58429000E+00, -.62520100E+00, -.13298100E-02, -.54948900E+00, -.29960100E+00, -.41114900E+01, -.28264400E+00, 0.92738100E+00, -.74749900E+00, -.19565000E-01, 0.31658700E+00, 0.31482700E+00, -.36252200E-01, -.18793100E-03, -.28796000E+00, 0.10553000E+01, -.76663100E+00, 0.10412400E+01, -.19338700E+00, 0.45333800E+01, 0.97806300E+00, -.97984400E+00, 0.26841700E+00, 0.95192500E-02, -.63056400E-01, 0.16122500E-01, -.12074100E+01, -.13189900E+00, -.11075900E+01, -.53021300E+00, -.79733500E+00, 0.10272500E+01, -.13025800E+01, -.26595400E-01, -.12662100E+00, 0.77476500E-02, -.64548000E-01, 0.12487400E+01, -.64658700E+00, -.17947700E+00, 0.34068100E+00, -.10009300E+01, -.67120500E+00, -.50868500E+00, -.62007000E+00, -.17961800E+01, -.65215100E-02, 0.53172300E-01, -.19506800E+00, -.20044500E+00, 0.29064300E+00, -.22582000E+00, -.90970800E+00, -.45704300E+00, 0.35277600E+00, 0.14120200E+00, 0.22606800E+01, 0.92145200E-02, 0.26762300E+00, -.38072100E+00, -.26631100E+00, 0.53253900E-01, 0.12642900E-01, 0.38278900E+00, -.10213800E+00, 0.43186900E+00, -.30558000E+00, 0.89604600E+00, 0.72310900E-01, 0.10389800E+01, 0.20619800E+00, -.39252500E+00, 0.44086300E-01, -.37644500E-01, 0.39826600E+00, -.18136800E+00, -.34609800E-02, 0.56599600E-01, -.32465300E+01, 0.11635200E+00, 0.12319300E+01, -.25315800E+00, -.27610400E+00, 0.24823800E+00, 0.17876300E+01, 0.69827100E-01, -.25227400E+01, -.37968600E+00, -.18927000E+00, -.27761900E-01, -.13752200E-01, -.48350800E+00, 0.98031500E-01, 0.46610700E+00, -.95418300E+00, 0.38384200E-02, 0.27720100E-01, 0.63371600E-01, -.51662000E+00, 0.26418900E+00, 0.55799200E+00, 0.51118100E-02, -.13742500E+01, 0.64914400E+00, -.69707400E-01, 0.41651600E+00, 0.31107300E+00, 0.15721000E+01, -.63355000E+02, -.59816300E+03, 0.31194500E+03, 0.42773300E+03, 0.29912200E+03, 0.55293600E+02, -.31794500E+02, 0.12025600E+03, -.10219200E+03, 0.19713500E+03, -.86966200E+01, 0.15394400E+03, 0.59670000E+03, -.29416800E+03, -.70490900E+03, -.29763900E+03, 0.42256700E+02, 0.74290000E+02, -.29885800E+02, 0.29807300E+03, -.91212600E+02, 0.11922800E+03, -.24189300E+03, 0.11476000E+03, -.62963800E+02, -.92247600E+01, -.56798300E+02, 0.64336100E+01, 0.12616500E+02, -.86964100E+02, -.34599800E+02, -.12484300E+03, 0.60285500E+01, 0.91338200E+01, -.15178600E+03, 0.77615800E+02, -.32525200E+02, 0.75858600E+02, 0.38013000E+02, -.44822900E+02, 0.63635300E+02, -.26752500E+02, 0.23986700E+02, -.24609600E+02, 0.63246000E+02, -.89976600E+03, 0.44570900E+03, 0.22747200E+03, 0.45002400E+03, -.14412700E+03, -.30090500E+03, 0.21350500E+03, -.15701200E+03, 0.30543900E+03, -.31273100E+03, 0.49787700E+03, 0.17143800E+03, -.85010900E+02, -.22883400E+02, -.85142700E+02, -.64775300E+02, -.97153900E+02, 0.43642800E+02, 0.13572700E+03, 0.17251300E+03, -.14798900E+03, -.99096000E+02, -.63363500E+00, -.17183000E+02, 0.12086200E+01, -.18930900E+02, -.32966500E+01, -.12721500E+02, 0.18671500E+02, 0.19507500E+01, 0.91599400E+01, -.28054700E+01, -.32124000E+02, -.83484300E+00, 0.22087700E+01, 0.14200200E+02, -.58812900E+01, -.23389000E+01, 0.16200000E+02, 0.42783500E+01, -.30313100E+01, -.15039400E+02, 0.15530500E+02, 0.13025200E+02, -.36724000E+02, 0.27684100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11363200E+02, 0.15429200E+00, -.30620100E+01, 0.59314600E+01, 0.90719900E+01, 0.35978300E+01, -.22336400E+01, 0.17637100E+01, -.34392500E+00, -.31170500E+00, 0.48084300E+01, 0.42186900E+01, 0.13973300E+02, 0.86651500E+01, -.34931800E+00, -.13717900E+01, 0.34588900E+01, 0.32201600E+01, 0.33382900E+00, 0.15048700E+01, 0.12394400E+01, 0.61196900E+01, -.16255200E+01, 0.39088800E+01, -.67400700E-01, -.96006400E+00, -.49352800E+00, 0.27385500E+00, 0.26823300E+00, -.14200900E+02, 0.15077900E+01, 0.71939200E+00, -.28323200E+01, -.30947000E+01, -.12054300E+01, 0.65233500E+00, -.13696900E+00, 0.22299100E+01, 0.19532500E+01, 0.75523200E+00, 0.27370100E+01, -.76582200E+00, -.12481400E+00, -.48185900E+00, -.97560300E+00, 0.21691100E+00, -.57971300E+00, -.15032100E+01, 0.43963900E+00, 0.16182400E+01, 0.53682800E+01, 0.26172400E+01, 0.78856500E+00, 0.99532600E-01, -.95855500E+00, 0.15073400E+01, -.50103400E+00, -.15288500E+01, 0.60459300E-02, -.15583800E+01, -.18974200E+01, 0.70820000E+00, -.83267100E-01, 0.14988900E+00, -.33809400E+01, -.15151300E+01, 0.10517800E+01, 0.25769400E+01, 0.83997300E+00, 0.10007900E-01, -.13357500E+00, 0.20674700E+01, 0.71494200E+00, 0.33295400E-02, 0.58075800E+00, -.12355200E+00, -.12105600E+01, -.17354800E+01, -.34759900E+01, 0.13823700E+01, -.18917600E-02, 0.55962400E+01, -.51130400E+01, 0.44609700E+01, 0.25955700E+00, 0.60567700E+00, 0.13024400E+01, 0.11903800E+01, 0.97983400E+00, -.21570100E-02, -.29315800E+00, -.44658700E-01, -.58189200E+00, -.36122500E+01, -.23961000E+01, -.24734900E+01, 0.84524100E+00, 0.39190000E+01, -.23271800E+01, 0.14422500E+00, 0.84980100E+00, 0.24667300E+00, 0.10195000E+00, -.47690800E+00, 0.56293000E+00, -.70793700E+00, 0.14124600E+01, 0.18237700E+01, 0.14045000E+01, -.13473100E+01, 0.64162600E+00, -.35208600E-01, 0.24434200E+00, -.15347800E-01, 0.76585600E+00, 0.14415300E+01, 0.35806500E+00, 0.56844800E+00, -.50845900E+00, 0.74206900E+00, 0.12276000E+01, -.26363500E+01, -.18859300E+01, -.30058900E+01, -.50709100E-01, -.12942200E+01, 0.67023800E+00, 0.13318900E+01, -.48504600E+00, 0.22574800E+00, 0.10056300E+01, -.16181500E+01, 0.90825800E+00, 0.10298300E+00, -.14001100E+01, 0.17968100E-01, -.11322700E+01, -.63972900E+00, -.55596400E+00, -.32991700E+00, 0.32226400E+00, 0.60187900E+00, 0.26007600E-01, 0.20803100E+00, -.20699200E+01, -.29270800E+01, -.12943400E+00, -.12737100E+01, -.11640200E+01, -.19637500E+01, -.24869200E-02, 0.97724800E+00, 0.49069000E+00, 0.84192900E-01, -.14213200E+00, -.41991500E-01, -.12874400E+02, 0.28481400E+00, -.99242000E+00, 0.10012500E+00, 0.54034800E+00, -.17174400E+01, 0.10374800E+01, 0.48915300E+00, -.17101300E+01, 0.14021000E+00, -.14470400E+00, -.46929600E-01, -.89319700E-02, 0.37936400E+00, 0.19704400E+01, 0.60010000E+00, 0.30608100E+00, 0.40627100E+00, 0.10175100E+01, -.36392700E+00, 0.30347700E+00, 0.26947300E+00, -.71028800E+00, -.49885500E-02, 0.19525600E+01, 0.15397200E+01, -.20512900E+01, -.25089100E+00, -.19355200E+01, -.32346400E+01, -.86827100E+00, -.19699300E+04, 0.98938700E+03, 0.84580100E+03, 0.98511400E+03, 0.79401900E+02, -.33370100E+01, 0.36312200E+03, -.35967100E+03, 0.61569700E+03, 0.49265200E+02, 0.94493700E+03, 0.19684100E+04, -.98638700E+03, 0.49312100E+03, -.98448000E+03, 0.83097300E+03, 0.60213900E+03, -.40130100E+03, 0.50844600E+03, -.99113600E+03, 0.39739800E+03, -.72647500E+03, 0.15742300E+04, -.82797800E+03, -.18525800E+03, -.78577600E+03, -.84085500E+02, -.47256600E+02, -.41523800E+03, 0.32101000E+02, -.74054300E+03, -.50421800E+00, -.70449700E+03, 0.24381000E+03, -.12141200E+03, -.47605400E+02, -.12184100E+03, 0.14273000E+03, 0.63764900E+02, 0.23847700E+02, 0.62166600E+02, -.25097800E+03, 0.20346900E+02, 0.60964800E+02, 0.99418400E+02, -.48321800E+02, 0.22159700E+03, -.48836700E+02, 0.63584500E+02, -.10387800E+03, -.13328900E+03, -.31992400E+03, 0.13914500E+03, -.91391400E+02, -.17139700E+03, 0.99369700E+02, -.56752800E+02, -.28228400E+03, -.49021800E+02, -.13203500E+03, -.21577700E+03, 0.30047800E+01, 0.24841000E+03, 0.16248100E+03, -.11029000E+03, 0.75961100E+02, -.55656500E+01, -.29749300E+01, -.48951900E+01, 0.17664800E+02, 0.12515600E+02, -.39453200E+02, -.11230100E+02, 0.61170600E+01, -.31765100E+01, -.16343900E+02, 0.90389800E+02, 0.60299600E+00, 0.27171100E+02, 0.74561000E-01, -.31157000E+01, 0.32550700E+01, 0.49603200E+02, 0.10426200E+02, 0.21578000E+02, -.82999100E+02, 0.85894700E+02, -.68502400E+02, -.75299200E+02, 0.15321500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.96489600E+01, 0.53394600E+00, 0.28652800E+01, -.33854800E+01, -.81757600E+01, -.93285000E+00, 0.15886100E+01, -.39713300E+01, 0.55809000E+00, 0.12529900E+01, -.27704800E+00, -.83873200E+00, -.24316000E+01, -.33398800E+01, -.38180700E+00, 0.80698400E+00, -.15526000E+01, -.43074300E+00, 0.94530400E-01, -.20205200E+01, 0.43427700E+01, 0.84737400E+01, 0.20049200E+01, -.83652500E+00, -.16081400E-01, -.26271800E+01, 0.38040000E+00, 0.69848700E+00, 0.47937800E+00, -.35130400E+01, -.12033800E+00, -.52005500E+00, 0.91070200E+00, -.21527800E+00, 0.72813600E+00, -.18289600E+01, 0.89246400E-01, 0.31757300E+00, -.27091800E+00, -.12722700E+01, -.25342700E+01, -.18629200E+01, 0.43130800E+01, -.14441100E+01, 0.37513700E+01, -.22843500E+01, -.17234500E+01, 0.15327200E+00, -.47045900E+00, -.23738600E+01, 0.27290900E+01, 0.12078500E+00, 0.44286700E+00, -.11499500E+01, -.29455000E+00, 0.17118000E+01, -.23826800E-01, 0.22510700E+01, -.15078700E-02, -.16620200E+01, -.59799200E+00, -.39409800E+01, 0.10125600E+01, -.64820500E+00, -.30309900E+01, -.90720300E+00, -.22385800E+01, -.13494100E+01, -.56078800E+00, -.13038300E-01, -.58176200E+00, 0.39453100E-01, 0.33617000E+00, 0.63089900E+00, 0.74800200E-01, 0.16743900E+00, 0.87130300E+00, -.35000100E-01, 0.38956700E+01, -.80784200E+00, 0.25843200E-02, -.25424400E+01, 0.31763000E+01, -.17326900E+01, 0.40381600E-01, -.51780900E-01, 0.43037300E+00, -.79955200E+00, -.33453900E+00, -.12650200E+01, 0.61486100E+00, 0.17607500E-01, 0.17454600E+01, -.70499900E+00, -.13786900E+01, -.20806300E+01, 0.61228900E+00, 0.11514800E+01, -.14050300E+01, 0.36981800E+00, 0.13187100E+01, 0.50144300E+00, -.10629100E+00, -.10039800E+00, 0.98526100E+00, 0.55013400E+00, 0.37832300E+00, 0.22292900E+00, -.12585100E+01, -.85571300E+00, 0.10432500E+01, -.81934700E-03, 0.41416300E+00, -.19886300E-01, -.43330800E+00, -.28171900E+00, -.19633100E+00, 0.39999100E+00, -.31262300E+00, 0.19307700E+00, 0.91641300E+00, 0.48442600E+00, 0.14579100E+01, -.24334200E+01, 0.22134800E-01, 0.11929900E+00, -.28191100E+00, -.34657200E+01, 0.22529800E+00, 0.18586000E+00, -.14061300E+00, -.24011800E+00, 0.16833800E+00, -.37976400E-02, -.29539300E+00, -.15605100E-01, -.86107900E-01, -.31014600E+00, 0.14936800E+00, 0.34043700E+00, -.36328800E+00, -.18469300E+00, 0.13996600E+00, -.45713000E+00, -.11178100E+01, 0.55474400E+00, -.37634600E-01, 0.38067700E+00, -.71949500E+00, -.90157200E+00, -.27900300E+00, 0.45364100E+00, 0.66500400E+00, 0.33209100E+00, -.37153100E+00, -.25278100E+00, -.18188800E+01, 0.71156900E-01, -.16109000E+01, 0.39241900E+00, -.24513400E+00, 0.16067200E+00, 0.10268600E+01, 0.64030100E-01, -.57233500E+00, -.25499500E+00, 0.57776900E+00, 0.61525600E+00, -.37471300E-01, -.11019100E+01, 0.75720900E+00, -.56320600E+00, -.30218500E+01, 0.82845600E+00, -.33553400E+00, -.28511700E+00, 0.45782100E+00, 0.47857100E+00, -.10211200E+00, 0.45961800E-02, 0.20957500E+01, 0.37051500E+00, -.62165400E+00, 0.11861200E+01, -.13515100E+01, -.10795000E+01, -.13522300E+01, 0.48440400E+00, -.66123900E+02, 0.78162500E+02, 0.64456800E-01, -.68922700E+02, -.10526800E+03, 0.13754000E+03, 0.12094400E+03, 0.11757100E+03, -.74815900E+02, 0.31191500E+03, 0.11335600E+04, -.60751100E+03, -.63957000E+03, -.56655200E+03, -.18257100E+02, 0.22576400E+03, -.19518500E+03, 0.22479300E+03, -.31045600E+03, 0.19620900E+03, -.40273800E+03, 0.12536800E+03, -.56687000E+02, -.11727800E+03, -.62570000E+02, 0.41096100E+01, -.38985100E+02, 0.23092100E+01, 0.48389800E+02, -.87924100E+02, -.12628300E+02, -.14129500E+03, -.50621700E+03, 0.24175300E+03, 0.16160800E+03, 0.25310600E+03, 0.14115900E+03, -.10286600E+02, 0.13212500E+03, -.33349000E+02, 0.18642000E+03, 0.25875900E+01, -.59121700E+02, -.74439800E+03, 0.36961400E+03, 0.36511900E+03, 0.37237300E+03, -.11069200E+03, -.38250700E+03, 0.15869700E+03, -.16569900E+03, 0.22432000E+03, -.32829500E+03, 0.30489900E+03, 0.20586800E+03, -.94851000E+02, 0.34692200E+02, -.10285600E+03, -.12248800E+03, -.84920000E+02, -.66618900E+02, -.25274600E+02, 0.56529500E+02, -.99525200E+02, -.16586600E+00, -.54662200E+01, -.21339700E+02, 0.46298800E+01, -.29650700E+02, -.79001300E+01, -.13174600E+02, 0.21665400E+02, -.11358400E+01, 0.90867400E+01, -.85238700E+01, -.35024700E+02, 0.50289000E+01, -.52422500E+01, 0.12779400E+02, -.50714400E+01, 0.15975600E+01, 0.21769700E+02, 0.15411000E+01, 0.45634100E+01, -.10189700E+02, 0.10814100E+02, 0.22550800E+02, -.45971700E+02, 0.38910000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.72596700E+01, 0.26789600E+01, -.55147200E+01, 0.85025200E+00, -.45172700E+01, 0.72033300E+00, 0.82863900E+00, -.21023700E+01, -.22399800E+00, 0.90377400E+00, -.19834000E+01, -.10551100E+01, -.27298300E+00, -.25330200E+01, 0.32006200E+00, 0.37883700E+00, -.16380700E+01, -.17095800E+01, 0.19205000E+00, 0.12343100E+01, -.92007500E+00, 0.95642400E+00, 0.39848100E+01, -.10022400E+01, -.15225700E+00, -.53737900E+00, 0.38017500E+00, -.35927800E-01, 0.69074700E+00, 0.30085600E+00, -.13342600E+00, -.36418700E-01, 0.12674500E+01, 0.78264800E+00, 0.18824600E+00, -.53995900E+00, 0.58587500E-01, 0.88876900E+00, 0.40487000E-01, -.10343400E+01, -.26398800E+01, -.16812800E+01, 0.33318500E+00, -.86530800E+00, 0.13741700E+01, 0.71047200E+00, -.65343300E+00, 0.75183000E+00, 0.18443900E+00, -.67470100E+00, 0.60209100E+00, 0.35809100E-01, 0.88518900E-01, -.20871400E+00, -.36831400E+00, 0.63582700E+00, -.20323200E+00, 0.15107900E+01, -.13457600E-02, -.13655700E+01, -.24203100E+00, -.13408300E+01, 0.47867800E+00, 0.10358800E+00, 0.18102300E+01, 0.60615400E+00, -.11705700E+01, -.25203200E-01, -.52634100E+00, -.12398800E-01, 0.59583600E-01, -.17803200E-01, 0.21704900E+00, -.13770400E+00, -.42159200E+00, 0.16160700E+00, 0.68672600E+00, 0.61617300E+00, 0.69530700E+00, 0.15605300E+00, 0.20045000E-02, -.78000500E+00, 0.10524500E+00, 0.80476200E+00, 0.25533900E+00, 0.73855000E+00, -.36840800E+00, -.33250900E+00, -.26255600E+00, -.24281200E-01, 0.56876500E-01, 0.30522000E-01, -.28274700E+00, -.21136700E+01, 0.11872600E+00, -.42595500E+00, 0.71157300E-01, -.12527300E+01, 0.95435600E+00, 0.35695900E+00, 0.79885400E+00, 0.99001500E-01, 0.32814800E+00, 0.27410700E+00, 0.59723200E+00, -.10940600E+00, -.87497900E+00, 0.30362600E+00, -.34075800E+00, -.88478200E-01, -.19914900E+00, 0.13140800E-01, 0.13142300E+00, 0.65513400E-02, -.97067400E-01, -.37622200E-01, 0.17009300E+00, 0.31112300E+00, 0.19289300E-01, -.14929000E+00, 0.65309300E+00, 0.10895300E+00, -.76090400E-01, 0.27714400E+01, 0.29638000E-02, -.68194100E+00, 0.67280500E+00, 0.29215800E+01, -.36506300E-01, 0.16279400E+00, -.64770900E-01, 0.44270900E+00, -.22907600E-01, -.69418400E-01, -.23991200E+01, 0.12425500E-02, -.54587100E+00, 0.94043300E+00, 0.12313800E+00, -.14434200E+00, 0.50704800E+00, -.33663000E+00, -.27872000E-01, -.32718400E-01, 0.30009600E+00, -.19211300E+01, -.11365800E+00, 0.88989900E-01, -.10947400E+01, -.83588600E+00, 0.19800100E+00, -.23458700E+00, -.70433300E+00, 0.21772600E-01, 0.16313000E+00, 0.72190700E-01, 0.26554000E+01, -.73428800E-01, -.70510400E+00, 0.24312800E+00, -.11210600E+00, 0.46915300E+00, -.12425500E+01, -.50658000E-01, -.76124600E+00, 0.59108300E-01, -.75418000E-01, 0.81092400E-01, 0.15082900E-01, -.26329500E+00, 0.15031000E+00, 0.37331700E-01, -.75019600E-01, -.57241500E-01, -.38180100E+00, -.15854000E+00, 0.26217400E+00, 0.54493600E-01, -.37945100E+00, 0.24533700E-02, 0.92068900E+00, -.19922800E+00, -.20747300E+00, 0.21398600E+00, -.13415700E+01, -.68231800E+00, 0.22086500E-01, 0.30978600E-01, 0.64070200E-01, -.27844200E+03, 0.48774600E-01, -.25180600E+02, -.90673900E+01, 0.60744100E+01, 0.15882700E+02, 0.20228600E+01, -.22414500E+02, 0.13323800E+03, -.14535900E+03, 0.74926600E+02, 0.57291600E+03, 0.71895900E+02, 0.15494000E+03, 0.29546100E+02, -.26571300E+02, 0.10295300E+01, -.81962200E+02, -.34175200E+02, 0.35257300E+02, 0.62542700E+02, -.29474700E+02, 0.58642900E+02, -.31165600E+02, -.83887300E+01, -.96907600E+01, -.21203600E+02, -.52831400E+02, -.66497500E+01, 0.16247800E+02, -.68518800E+02, 0.15394700E+03, -.76189900E+02, 0.57675800E+01, -.76907900E+02, -.52355800E+00, 0.30275100E+02, -.58566200E+02, 0.30475400E+02, -.11082200E+03, 0.12535200E+02, -.48179800E+02, 0.35546400E+03, -.17687800E+03, 0.90879700E+02, -.17740400E+03, 0.52961900E+02, 0.10511900E+03, -.73353200E+02, 0.90714700E+01, -.93768100E+02, 0.16239200E+03, -.20501900E+03, -.83714700E+00, -.15417100E+01, -.77614200E+02, 0.18922800E+00, -.37822900E+01, 0.36296200E+02, -.69030300E+02, -.31987000E+02, -.11091200E+03, 0.66670700E+02, 0.15206200E+03, -.30147000E+01, 0.16840700E+02, 0.16319800E+01, 0.26389000E+02, 0.50777300E+01, -.89615800E+00, -.24481000E+02, -.68364800E+00, -.60068100E+01, -.73893500E+01, 0.46483200E+02, 0.28242400E+01, 0.16748100E+02, -.65169800E+01, 0.34571500E+00, 0.42817500E+01, 0.98823900E+01, 0.32970400E+01, 0.16802500E+02, -.19768800E+02, 0.22493800E+02, -.22174900E+02, -.88239400E+01, -.73291000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.63907600E+01, 0.93093900E+00, 0.22855200E+01, -.44846300E+01, -.47487700E+01, 0.54845600E+00, 0.90103100E+00, -.18116200E+01, -.24790600E+00, 0.33434300E-01, -.16521700E+01, -.12764400E+01, -.22586800E+01, -.51011100E+01, 0.34746500E+00, 0.55883400E+00, -.10402400E+01, -.90512300E+00, 0.11139500E+01, -.50121400E+00, -.11215400E+00, 0.14812700E+01, -.45949500E+01, 0.21981800E+01, -.48529600E+00, -.56229100E+00, -.28475600E+00, -.10860600E+01, -.55373600E+00, -.25762700E+01, 0.82012800E+00, -.28164400E-02, 0.50208800E+00, -.14447600E+01, -.42916900E-01, -.10493800E-01, 0.80334000E-01, 0.47176400E+00, 0.58743000E+00, 0.29626900E+00, 0.70007300E+00, -.11492600E+01, 0.35672100E+00, 0.24676900E+00, 0.92364300E+00, -.24485700E+01, -.32774600E+00, -.46168200E-01, 0.57699500E-01, -.53920100E+00, 0.35701000E+01, 0.37370100E+00, 0.39959900E+00, 0.25165800E+00, 0.25749200E+00, -.38179100E+00, 0.36669000E-01, -.17861900E+01, -.23614300E-02, -.71885200E+00, -.28066500E-01, -.15678500E+01, 0.26881500E+00, 0.19161800E+00, -.34151200E+01, -.12282800E+01, -.17907000E+00, 0.54018600E-02, 0.21467200E-01, -.25833100E-02, -.39404300E+00, 0.28820900E+00, -.30314200E+00, 0.26142700E+00, -.10510000E+01, 0.50222900E-02, 0.80303600E-01, 0.40555200E+00, 0.56246000E+00, -.52018100E+00, 0.13764100E-02, -.44767000E+00, 0.11168800E+00, -.96115000E+00, -.40374000E+00, -.21473200E+00, 0.11513200E+01, -.30045100E+00, 0.16583200E+00, 0.16370500E+00, 0.61737900E+00, -.62049100E-03, -.18590200E+00, 0.67049600E+00, 0.45672700E+00, 0.35332500E+00, -.82849000E-01, 0.18000600E+01, -.86462400E-01, -.31281700E+00, -.20656300E+00, 0.50819600E-01, 0.13678600E+00, 0.23320900E+00, -.62091600E+00, -.29984700E+00, -.91708500E+00, -.37024100E-01, -.94622000E+00, -.32262300E+00, -.29518800E+00, 0.89635200E-03, 0.36515300E+00, 0.91251000E-02, 0.48457800E-01, -.11058800E+01, 0.79788600E+00, -.68356600E+00, 0.26879200E-01, -.13552700E+01, 0.22724600E+00, -.14627100E+01, -.30257500E+00, -.24778200E+01, -.11525100E-01, -.15992300E+01, 0.13715800E+01, 0.43811300E+01, 0.26306900E+00, 0.50458500E-01, -.72741100E-01, 0.32055600E+00, -.25814900E+00, 0.23421600E+00, -.14760800E+01, 0.16715100E-01, -.11421900E+01, 0.10196500E+01, 0.92739100E-01, -.20368000E+00, 0.41460700E-01, -.45619700E+00, -.13464800E+00, 0.55095600E+00, 0.10963900E+01, -.62815400E+00, 0.56795100E-01, -.31005600E+00, -.32969400E+00, 0.12118200E+01, -.16242400E-01, -.11804100E+01, -.49833300E+00, -.44474300E+00, 0.68839900E+00, 0.79080200E-01, 0.13508600E+01, -.67654700E-01, 0.10201700E+01, 0.22725900E+00, -.18192500E+00, 0.75569600E+00, -.18193300E+01, -.81008800E+00, 0.20449600E+01, 0.16672400E+00, -.88581800E-01, 0.27053500E+00, 0.31968900E-01, -.36724500E-01, 0.33769800E+00, -.12532800E+01, 0.13815600E+01, 0.51510900E+00, -.89937700E+00, 0.24631000E+00, -.79605200E-01, -.22444700E-01, -.98884000E-01, -.42278600E-02, -.72840800E+00, 0.45708400E+00, -.14960700E+00, -.36518600E+00, 0.63590500E+00, 0.58047200E+00, 0.27479300E+00, -.80574400E-01, -.13984800E-01, -.18869900E+00, 0.79190000E+01, 0.27589500E+02, 0.10279200E+02, -.21106100E+02, -.26450200E+02, -.42998200E+02, 0.74737900E+01, -.12487900E+03, -.50077200E+02, 0.21592000E+02, 0.10962900E+03, 0.25260400E+02, -.48799800E+02, -.52976900E+02, -.11010000E+02, -.39126800E+02, -.57916900E+01, -.44666300E+02, 0.36911900E+02, 0.31462500E+01, -.17237000E+01, 0.50759200E+02, -.15643800E+01, 0.40968000E+02, 0.38936800E+02, -.58611200E+02, -.18965900E+02, 0.15932000E+02, 0.25565400E+02, 0.35605900E+02, 0.12749000E+03, -.64709600E+02, -.93030200E+02, -.63765300E+02, -.74273300E+02, -.23281800E+02, -.52531100E+01, 0.15953000E+02, -.18383300E+02, -.24615600E+02, 0.89246000E+02, 0.90667300E+02, -.43438700E+02, 0.11753200E+03, -.45445800E+02, 0.15200300E+02, 0.76358700E+02, -.18840400E+02, 0.26477800E+02, -.42777600E+02, 0.72149600E+02, -.28679500E+02, -.90239800E+02, 0.45780200E+02, 0.76692100E+00, 0.45223700E+02, 0.36281800E+02, 0.22065400E+02, 0.12748600E+02, -.21792400E+02, 0.23779900E+02, 0.18206900E+02, 0.15354400E+02, 0.19837400E+01, 0.77734100E-01, 0.50164400E+00, -.36369500E+01, 0.35780200E+01, -.68174500E+01, 0.10342200E+01, 0.28410500E+01, -.73101300E+00, 0.56480100E+01, 0.12690300E+02, -.23539300E+01, 0.43115900E+00, 0.80964400E+00, 0.85777800E+00, -.13772600E+01, -.52720500E+01, -.15292500E+01, -.43809100E+01, 0.12067500E+02, 0.15482300E+01, 0.23489700E+00, 0.20004100E+02, -.35860400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34337700E+01, -.41394900E+00, -.58988000E+00, 0.45949200E-01, 0.11557200E+01, 0.12763800E+01, -.32399800E+00, 0.49178100E+00, 0.35421400E+00, -.17982100E+00, 0.11986900E+00, -.20540800E+00, -.15204200E+01, -.89245200E+00, 0.59010800E+00, -.73861800E-01, 0.62540100E+00, 0.37707000E+00, -.20267400E+00, 0.10063200E+00, 0.28522200E+00, 0.36890900E+00, -.21506300E+01, 0.10712300E+01, -.54927700E-01, -.97384800E-01, 0.19278000E-01, 0.11757600E-01, -.26615200E+00, -.15708700E+01, 0.12835500E+00, 0.75074200E-01, -.62425000E+00, -.53152800E+00, -.13658200E+00, 0.23979800E+00, -.34761600E-01, 0.14995500E+00, -.93288300E-01, 0.29749400E+00, 0.88511000E+00, 0.65139300E+00, -.10138700E+01, 0.33714000E+00, -.46807800E+00, -.40817500E+00, 0.26438600E+00, -.48033100E+00, -.24410400E-01, 0.57233500E+00, 0.82811400E+00, 0.31197200E+00, 0.10251400E+00, 0.87744700E-01, -.11420700E+00, -.11129500E+00, 0.68725000E-01, -.15213200E+01, 0.22343900E-02, -.71187500E+00, -.68137400E+00, -.52797800E+00, -.82214900E-01, -.21021000E+00, -.12017400E+01, -.80954400E+00, 0.36050600E+00, -.19010500E+00, 0.65752900E+00, 0.61848400E-02, -.17015900E+00, 0.61112500E+00, 0.44697900E+00, 0.13998600E+00, 0.13334800E-01, -.85451700E-01, -.31237400E+00, -.70416200E+00, 0.17140800E+00, 0.29136100E+00, -.45817800E-03, 0.10679700E+01, -.64090400E+00, 0.51605700E+00, 0.66842200E-01, -.49429100E+00, 0.63998200E+00, 0.12636900E+00, 0.71636100E-01, 0.27009100E-01, 0.40095200E+00, -.24014000E-01, -.42474600E-01, -.53874700E+00, 0.26779200E+00, 0.56695200E+00, -.54746000E-01, -.11559300E+01, -.20626800E+00, 0.97466400E-01, -.16996400E-01, 0.85238600E-01, -.10840800E+00, 0.10516700E+00, 0.52127300E+00, 0.11190700E+00, 0.78651000E+00, 0.46144100E+00, 0.27287500E-01, -.37886000E+00, -.25258800E-01, 0.54191000E-01, 0.79859000E-01, -.12524600E-01, -.16873600E+00, 0.55407200E+00, -.27929400E-01, -.27002800E+00, -.69055700E-01, 0.13257500E+01, 0.41378000E+00, -.79279500E+00, 0.85467100E-01, -.10267300E+01, 0.68319700E-02, 0.34684000E+00, -.50017100E-01, -.42581400E+00, -.14613200E+00, -.21546900E-01, -.16413600E+00, 0.36211600E+00, -.19627600E+00, -.68779100E-01, 0.17987900E+00, -.66540300E-02, 0.34871600E-01, 0.25091100E-02, 0.12280300E+00, 0.16241800E-01, 0.57225100E-01, 0.81448600E-01, -.10612500E+00, -.34685300E+00, -.12167500E+00, -.57710800E+00, -.61394900E-02, -.37285800E+00, -.32093200E+00, -.28505900E+00, 0.38479200E-01, -.76695700E-01, -.10714000E+00, 0.13889700E+00, 0.31558700E-01, -.22384700E-01, 0.17005200E+01, -.88749100E-02, -.18624900E+00, 0.13986900E+00, 0.39726500E-01, 0.20096300E+00, -.12274300E+01, -.32855600E-02, -.76403000E+00, 0.77370700E-01, -.35079200E-01, -.79766500E-01, -.25485700E-01, -.13065400E+00, 0.52191300E+00, 0.55867600E-01, 0.15600700E+00, 0.83985900E-01, 0.95631300E-01, 0.17484000E-02, 0.88341300E-02, 0.13950700E-01, 0.10722500E-01, 0.72079900E-03, 0.37245100E-01, 0.41126500E+00, -.63902000E-03, 0.33537100E-01, -.35496300E-01, -.25478600E+00, -.34866400E+00, 0.15928400E+00, 0.77750500E-01, -.12545400E+00, 0.39080200E-03, 0.32377800E+02, -.16655700E+02, 0.19504600E+02, 0.56976700E+01, 0.30685500E+01, -.10358800E+02, -.63520500E+02, 0.11866500E+03, -.59098100E+02, -.52639500E+02, -.59026300E+02, -.31300900E+02, 0.20446700E+02, -.21350100E+02, 0.18821700E+02, -.45839000E+02, 0.91946700E+01, -.31941400E+02, -.78797000E+02, 0.39580100E+02, 0.65252600E+02, 0.39568500E+02, -.18627800E+02, 0.24022400E+02, -.28428100E+02, -.46412500E+02, 0.22007300E+02, 0.15135400E+02, 0.51589100E+02, -.97116500E+02, 0.49100900E+02, 0.28859800E+02, 0.48540100E+02, 0.17796600E+02, 0.78538500E+01, 0.16225500E+02, -.12314700E+02, 0.26907500E+02, 0.11838200E+02, 0.49294300E+02, -.13328800E+03, 0.63842400E+02, 0.10511300E+03, 0.66642300E+02, -.73223700E+01, -.50790200E+02, 0.32935200E+02, -.20988700E+02, 0.42826800E+02, -.41321000E+02, 0.64021800E+02, 0.56340500E+01, -.24830200E+01, 0.30034300E+02, -.26091000E+01, -.13467400E+02, -.14893500E+02, 0.45892300E+01, 0.20211000E+02, 0.40131500E+02, -.18864100E+02, -.29052900E+02, 0.51144500E+00, -.92424400E+01, 0.16484700E+01, -.12550600E+02, 0.47426300E+00, -.10322900E+02, 0.10399800E+02, 0.14679500E+01, 0.41095200E+01, 0.78122800E+00, 0.39177400E+00, -.85962600E+00, 0.18862700E+01, 0.88231400E+00, -.25796500E+01, -.15966900E+01, 0.35857000E+01, -.83854800E+00, 0.10428800E+01, 0.15624200E+01, 0.13939400E+02, 0.77809900E+00, 0.30692500E-01, 0.47535300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.47840100E+01, 0.74204300E+00, 0.33428200E+01, -.39818500E+01, -.33662200E+01, 0.34776100E+00, 0.45356600E+00, -.31270400E+01, 0.73779400E+00, 0.85496500E+00, 0.14263300E+01, 0.22692200E+00, -.28042700E+01, -.25433600E+01, -.34884800E+00, 0.26685900E+00, -.99881100E+00, -.17729800E+01, -.24952100E+00, 0.23674800E+00, 0.52584700E+00, 0.16907500E+01, 0.70425400E+01, -.29204400E+01, 0.48788400E-01, -.49328800E+00, 0.17816000E+00, 0.39982900E+00, 0.13555700E+01, 0.18018300E+01, 0.74967100E-01, -.33752600E+00, 0.13960200E+01, 0.28529400E+00, 0.44170500E+00, -.11811700E+01, -.19285200E-02, 0.32075400E+00, -.16145800E+00, -.98384600E+00, -.24392000E+01, -.19880100E+01, 0.45756100E+01, -.12412100E+01, 0.23533600E+01, -.69743300E+00, 0.46813100E+00, 0.14774700E+00, 0.11831800E+00, -.11410500E+01, 0.76369600E+00, -.59410600E-02, 0.11464000E-01, -.60801900E-01, 0.51909500E+00, 0.46190700E+00, -.25219300E+00, 0.37219800E+00, -.20219500E-02, -.50038400E+00, 0.86235500E+00, -.84269700E+00, 0.42854000E+00, -.26721800E+00, 0.19956700E+01, 0.19867500E+00, -.14972300E+01, 0.20329300E+00, -.67569300E+00, -.35253100E-02, 0.20112100E+00, -.60773300E-01, -.47415700E+00, -.71581800E-01, -.14570600E+00, 0.98298500E-01, 0.45360600E+00, 0.16046500E+00, 0.29326800E+00, -.30690900E-01, 0.76813900E-03, 0.27426100E+00, -.33466900E+00, 0.63261800E+00, 0.25350700E-01, -.17142400E+00, 0.85236400E+00, 0.12913200E+00, 0.10613100E+00, 0.34651500E-01, 0.69262000E+00, -.33540500E-02, -.45313000E+00, 0.72105200E+00, -.71335500E-01, 0.38909100E+00, -.19900300E+00, 0.23123300E+01, 0.19091600E+00, -.82367600E+00, 0.19265700E+00, -.37029900E-01, 0.27146700E-01, 0.67524500E-01, -.50768400E+00, -.13169800E+00, -.71892900E+00, -.43946800E+00, -.58854500E+00, 0.50528900E+00, -.59112200E+00, -.17148200E-01, 0.10504600E+00, 0.64663000E-02, 0.61908200E-01, -.10891100E+00, -.75589900E-01, 0.31409000E-01, 0.94901100E-01, -.10386900E+01, -.15565200E+00, 0.11826000E+01, 0.26378100E+01, -.41936800E+01, 0.17053600E-02, -.12833500E+00, 0.37109700E+00, -.17744500E+01, -.32205700E-01, 0.17771100E+00, -.29916600E+00, -.58730900E+00, 0.29118100E+00, 0.14544500E-01, -.92424500E+00, -.86644200E-02, -.52708300E+00, 0.62795600E+00, 0.12677000E+00, -.70101800E-02, 0.31094700E+00, -.70056200E-01, -.95282100E-01, -.21705900E+00, -.11389200E+01, 0.41462000E-01, -.24688000E-01, -.63967800E+00, -.24410000E+00, -.80940000E+00, 0.14650600E+00, 0.12785300E-01, 0.77178500E+00, -.29329600E+00, -.65635200E+00, 0.11176900E+00, 0.51614500E-01, 0.12585700E-03, -.17095200E+01, -.28590300E+00, -.22323900E+00, 0.38391200E+00, 0.12888800E+00, 0.18017100E+00, 0.41245000E-01, 0.15177500E+00, -.48596800E-01, 0.10969000E+00, 0.63454400E-02, -.45930800E+00, 0.47361900E+00, -.84111600E+00, -.33637400E+00, 0.22565400E+00, -.52119200E+00, 0.12096000E+00, 0.34540600E+00, 0.75050700E-01, -.82574200E-01, 0.20351000E-02, -.72722800E+00, -.59249200E+00, 0.35203400E+00, 0.42547200E+00, -.88341800E+00, 0.49710000E+00, -.73663600E+00, 0.11169500E+00, 0.67177900E-01, -.38635400E+00, 0.55918200E-02, -.72198700E+00, -.10280200E+03, 0.63540700E+02, 0.44541600E+02, 0.76554000E+02, -.83086100E+02, 0.24065000E+02, 0.46652300E+03, -.23521900E+03, -.16008500E+02, -.23276400E+03, 0.64322200E+02, 0.11826300E+02, 0.17564200E+02, 0.28670800E+03, -.16635600E+03, 0.30182000E+02, -.24474900E+03, -.17929300E+03, 0.86088800E+02, 0.90189400E+02, 0.90215200E+02, 0.31597900E+02, 0.78562400E+01, 0.10209400E+02, -.13614000E+02, 0.32418100E+02, 0.20558200E+02, 0.85018700E+02, -.23872300E+03, 0.12020300E+03, 0.65685600E+02, 0.11934300E+03, 0.10376000E+03, 0.24192300E+01, 0.91584400E+02, 0.16049600E+02, 0.62407000E+02, 0.10981700E+02, -.19083100E+02, -.52317900E+03, 0.25673200E+03, 0.27926900E+03, 0.26178800E+03, 0.22290700E+02, -.96369100E+02, 0.86953300E+02, -.13516500E+03, 0.18644700E+03, -.97683900E+02, 0.24903700E+03, 0.21172400E+03, -.10522100E+03, -.10077100E+03, -.10536900E+03, -.99306700E+02, -.47313600E+02, -.81054900E+02, -.31248400E+02, 0.66380000E+02, -.68994300E+02, -.45954500E+02, -.12104800E+01, -.14846000E+02, 0.40603800E+00, -.23484000E+02, 0.27213100E+01, -.20861300E+02, 0.15151600E+02, 0.24487400E+01, 0.66373200E+01, -.38115000E+01, -.70565000E+01, -.66068500E+00, 0.49704900E+01, 0.11131800E+02, -.27747100E+01, -.20193900E+01, 0.17848900E+02, -.49042300E+00, 0.55093800E+01, -.99075500E+01, 0.14914100E+02, 0.18853900E+01, 0.20675800E+01, 0.33866000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.13639600E+01, -.24266000E+00, -.39593300E+00, 0.67940900E+00, 0.82441600E+00, -.30052100E+00, -.12857600E+00, 0.41789100E+00, 0.75653900E-01, -.14454600E+00, 0.19493600E+00, 0.19698200E+00, 0.38980400E+00, 0.32855800E+00, 0.27629500E-01, -.12716800E+00, -.68549500E-01, 0.34646400E-01, -.16091300E+00, 0.71142500E+00, -.53902800E+00, -.80006400E+00, 0.56004900E+00, -.25854200E+00, 0.50099700E-01, 0.22451700E+00, -.26347100E-01, 0.19262700E+00, 0.51500800E-01, 0.84129100E+00, -.11359400E+00, -.87146300E-01, -.11598600E+00, 0.24942000E+00, -.55709800E-02, 0.31285400E-01, -.14539300E-01, -.27199800E+00, -.23834300E+00, 0.25968000E-01, -.17820800E+00, 0.58245900E+00, -.63254000E+00, 0.19348000E+00, -.48531900E+00, 0.13932300E+00, 0.59616700E+00, 0.20760800E-01, -.29743200E-02, 0.16203700E+00, -.12219300E+01, -.27143900E+00, -.13033900E+00, 0.13996100E+00, 0.13389000E+00, -.18482500E-01, 0.30045700E-01, -.15979800E+00, -.51020200E-03, -.24061600E+00, -.13809100E+00, 0.10005900E+00, -.10585500E+00, -.46291400E-01, 0.13836800E+00, -.37781100E-01, -.14902100E-02, -.28787500E+00, 0.21273900E+00, 0.44293900E-03, 0.12929400E-01, -.14726900E+00, 0.18407000E+00, -.78265400E-01, 0.21992200E+00, -.86323200E-01, -.73585100E-01, -.34919600E+00, 0.34038000E+00, 0.33194000E-01, 0.31121200E-03, -.13425600E+00, 0.12391000E+00, 0.60525400E-01, -.50061400E-01, -.32107300E+00, -.73102600E-01, -.69060600E-01, -.55368400E-01, -.80671300E-01, -.52591200E-01, -.44140600E-01, -.26343500E+00, 0.21712100E-01, -.84637000E+00, -.35364000E+00, 0.18241500E+00, 0.29977800E+00, -.31844200E+00, -.61576500E-01, -.14355800E+00, 0.11441900E-01, -.12438100E-01, -.10037900E+00, 0.16553900E+00, -.13356700E+00, 0.57084500E+00, 0.16865200E+00, 0.25229200E+00, 0.37207500E-01, 0.85555300E-01, -.15307000E-02, 0.64770900E-02, -.53519800E-03, 0.49042400E-01, 0.50643500E-01, -.61210600E-01, 0.26204700E-01, 0.14932600E-01, 0.17594900E-01, 0.68121100E-01, -.25401600E+00, -.85408000E+00, 0.76228700E+00, -.22801400E-03, -.21238300E-01, -.18164200E-01, 0.22667400E+00, 0.46785300E-02, 0.29433000E-01, 0.17594200E+00, -.22782300E-01, -.31775900E-01, -.69130400E-02, 0.78145700E-01, 0.15725500E-02, 0.89463200E-01, 0.23218200E+00, -.95556500E-02, -.34018100E-01, 0.49460900E-01, 0.48831400E-01, 0.29736400E-01, 0.40439700E-01, 0.16969200E-01, -.21730400E+00, -.68991300E-02, -.64063100E-01, -.47108600E-01, 0.37529100E-01, 0.48219700E-01, -.11423500E-02, -.27199100E+00, -.19910600E-01, -.26207600E-02, 0.40488200E-02, 0.86316100E+00, -.19932800E-01, -.45660200E+00, -.74521600E-01, -.43099300E-01, -.55306600E-01, 0.44462600E+00, 0.13904300E+00, -.46069600E-01, -.31177500E-01, 0.77049200E-02, -.16204900E-01, 0.93551900E-02, 0.93924000E-01, -.57773200E-01, -.14893300E-01, 0.20968600E+00, -.92208400E-01, 0.40138900E-01, -.32551200E-01, 0.71819100E-01, -.13529000E-01, -.12956300E-01, -.80686000E-03, 0.11388300E-01, 0.53647000E-01, 0.36646400E-01, -.74848600E-01, 0.14101500E+00, -.52297200E-01, 0.25148800E-01, -.24244000E-02, -.30615900E-01, 0.10954400E+00, -.20241800E-02, -.11225500E+00, -.22561100E+00, 0.15921100E+02, 0.16467000E+02, 0.17317400E+01, 0.41208000E+01, -.22375800E+02, 0.10029000E+03, -.50604900E+02, -.12989200E+03, -.49970900E+02, -.31481300E+02, 0.18111100E+02, -.18963300E+02, 0.32166200E+02, -.30421400E+02, 0.22303500E+02, -.23785000E+02, -.39919800E+02, 0.19738400E+02, 0.10645300E+02, 0.19988800E+02, 0.16687500E+02, 0.28398500E+01, 0.12951000E+02, 0.12914600E+02, 0.93011900E+01, 0.14310900E+01, 0.14440800E+02, -.65546000E+02, 0.32688400E+02, 0.11571200E+02, 0.32760100E+02, 0.11052800E+02, -.10556500E+02, 0.26037700E+02, 0.72520300E+01, 0.34756600E+02, -.86031100E+01, 0.17619600E+02, -.11667500E+03, 0.57878700E+02, 0.72859100E+02, 0.58295200E+02, -.21047200E+02, -.49810100E+02, 0.32346500E+02, -.96131300E+01, 0.39094200E+02, -.49593700E+02, 0.57189000E+02, 0.43967000E+02, -.21482000E+02, 0.61684100E+01, -.21902800E+02, -.20143000E+02, -.12727200E+02, -.24003800E+01, -.68413800E+01, 0.30967400E+02, -.24209300E+02, -.23466400E+02, 0.52066200E+00, -.65064700E+01, 0.91512800E+00, -.11051300E+02, 0.33012800E+00, -.50716700E+01, 0.77071000E+01, 0.17081100E+01, 0.34620800E+01, 0.12152200E+01, -.62841500E+01, -.90265400E+00, -.73073500E+01, 0.34136900E+01, 0.75917200E-01, -.10437900E+01, -.50175800E+01, -.59146000E+00, -.51071700E+01, 0.13879100E+01, -.70632900E+01, 0.43000500E+01, 0.53854300E+00, 0.91571500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20295400E+01, -.29452400E+00, -.50484500E+00, 0.12159200E+01, 0.15661100E+01, -.29500400E+00, -.34293100E+00, -.12644300E-02, 0.41436400E+00, 0.58576000E-01, 0.75182500E+00, 0.22308000E+00, -.76880900E+00, 0.87930400E+00, -.15708300E+00, -.20741600E+00, -.30804100E-01, -.47917400E+00, -.60036300E+00, 0.67744300E+00, 0.80329300E+00, 0.53057800E-02, 0.23111000E+01, -.59413200E+00, 0.20510900E+00, -.11405300E+00, 0.52868900E+00, 0.51338700E+00, 0.82163100E-01, 0.88313300E+00, -.55623800E+00, 0.68057900E-01, 0.64811100E+00, 0.10360700E+01, 0.12628100E-01, 0.17919500E+00, -.18566500E-01, -.77843200E+00, -.56130500E+00, -.64062000E+00, -.44746900E+00, 0.14014700E+01, -.19240400E+01, -.13110900E+00, -.21046900E+00, 0.14131600E+01, 0.42995500E+00, -.12444100E+00, 0.43420900E-02, 0.11871300E+00, -.13859400E+00, -.28611600E+00, 0.57317400E-01, -.21331300E+00, 0.13320200E+00, 0.11293300E+01, 0.15109400E+00, 0.55030900E+00, -.23660500E-02, 0.22044400E+00, -.23775200E-01, -.92211400E-01, 0.18651400E-01, -.46075100E+00, 0.86426000E+00, -.14919100E+00, -.19951500E+00, 0.61458800E-01, -.15347900E+00, -.31958900E-02, 0.22382700E+00, -.10103900E+00, -.16011300E+00, -.65358900E-01, 0.22299500E+00, 0.25116100E-01, 0.56092100E-01, -.19418600E+00, -.48937500E+00, 0.17877400E+00, -.12350900E-03, 0.27299100E+00, -.15794200E+00, 0.76245100E+00, 0.17011800E+00, 0.12882900E-01, -.79038900E+00, 0.41284700E+00, 0.10160900E+00, -.10502500E+00, -.43255400E+00, -.14828400E-02, -.39461900E+00, -.42134900E+00, 0.32766000E+00, 0.51968400E+00, -.12713500E+00, 0.54218900E+00, 0.83761700E-01, -.12528000E+00, -.43471400E+00, -.97029800E-01, 0.24775900E-02, -.15785300E+00, 0.14446800E+00, -.71224400E+00, -.65260500E-01, 0.24003300E+00, 0.39796100E+00, -.14093500E+00, 0.51219900E+00, -.83612000E-02, -.25102500E+00, -.92725100E-02, 0.30250500E+00, 0.91419700E-01, -.15253600E+00, 0.80014100E-01, -.18492000E-01, 0.23177700E+00, -.45648500E-01, -.24209600E+00, -.79304200E+00, -.51293800E+00, 0.49205200E-02, 0.69370500E-01, -.27054800E+00, -.99566500E+00, 0.30689300E+00, -.23445200E+00, -.11875700E+00, 0.43662500E+00, -.15084700E+00, -.50678700E-01, 0.38885200E+00, -.21558900E-02, -.12376800E+00, -.72756200E+00, 0.51033600E-01, -.13795100E-01, -.11029700E+00, 0.69301300E-01, 0.62875600E-01, 0.33447200E-01, 0.41779400E+00, -.61609300E-01, 0.24827800E-01, -.75830900E-01, 0.27027300E+00, 0.33845200E+00, -.31749900E-01, -.15178400E+00, 0.22938800E-02, 0.82279800E-01, 0.76112200E-01, -.25227500E-01, 0.95239900E+00, -.53703300E-02, 0.15619300E+00, -.24683600E+00, 0.61345900E-01, 0.16717400E+00, -.12435200E+00, -.34352800E-01, -.18474700E+00, -.40174400E-01, -.91653100E-01, -.13565800E-01, 0.90565700E-02, 0.37018700E-01, -.10040900E+00, 0.24824800E+00, -.32359100E+00, -.15983000E+00, -.19784700E+00, -.36540900E-01, 0.98876200E-01, 0.46515200E-01, -.11685800E-01, -.40671800E-03, -.55909600E-01, 0.13931800E+00, 0.91084300E-01, 0.20547800E+00, -.30479200E+00, -.31021200E+00, -.11391900E+00, 0.42560500E-01, 0.94759700E-01, -.14479500E+00, -.71135200E-03, -.84094900E-01, 0.24782800E+00, -.20758400E+00, 0.25966200E+02, 0.10553300E+02, -.18999200E+01, 0.85856200E+02, 0.41639800E+02, -.22784000E+02, 0.25754900E+03, -.20967000E+02, 0.10989900E+03, 0.55107300E+02, -.55513500E+02, 0.31711200E+01, -.74360800E+02, 0.20543900E+02, -.24294400E+02, -.12420800E+01, -.28409500E+01, 0.95265100E+01, 0.51494400E+00, 0.92199100E+01, -.94425600E+01, 0.22885900E+02, 0.88487500E+01, 0.52569600E+01, 0.59110400E+01, -.35136600E+02, 0.72755600E+02, -.36774800E+02, -.10987900E+02, -.36372500E+02, 0.19661300E+02, 0.26872400E+02, -.27083300E+02, 0.95594000E+01, -.37255200E+02, 0.16587000E+02, -.31543200E+02, 0.22841700E+03, -.11334800E+03, -.40807200E+02, -.11426300E+03, 0.30413200E+02, 0.65418000E+02, -.74956400E+02, -.60116400E+02, -.68813200E+02, 0.73520500E+02, -.13030400E+03, -.62116400E+01, 0.27101500E+01, -.29980400E+02, 0.30078700E+01, -.22531200E+01, -.64764900E+00, -.20337200E+02, 0.69641600E+01, -.40163900E+02, 0.19126600E+02, 0.66112800E+02, -.26259900E+01, 0.81930100E+01, 0.14801300E+00, 0.10322400E+02, 0.17934400E+01, 0.13951200E+01, -.91600600E+01, -.14973400E+01, -.37224400E+01, -.31909700E+01, 0.19443000E+02, 0.24302600E+01, 0.32082200E+01, -.42777100E+01, 0.12519300E+00, 0.29447200E+01, 0.86197100E+00, 0.22773100E+01, 0.44099800E+01, -.11461400E+02, -.14259000E+01, -.97533600E+01, -.64360000E+01, -.39652400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17506700E+01, -.28708600E+00, -.58874900E+00, 0.14288800E+00, 0.92410000E+00, -.19018300E+00, -.14185300E+00, 0.58011200E+00, 0.64241600E-02, -.59608000E+00, -.56329100E+00, 0.96772400E-01, -.19603000E+00, -.64639900E+00, 0.15301400E+00, 0.15316000E-01, 0.40275500E-01, 0.18499300E+00, -.60827600E-01, 0.31356100E+00, -.64392900E+00, -.14806400E+01, -.38038000E+00, -.25598400E+00, -.62559600E-01, 0.62252800E+00, 0.35081400E-01, -.12971700E+00, 0.94051500E-01, 0.10925300E+01, 0.39377500E-01, 0.31107800E-01, 0.11274600E+00, -.10745500E+00, -.24798500E-01, 0.20426300E+00, 0.51746300E-02, 0.17375200E-01, 0.41065100E-01, 0.12248300E+00, 0.32087800E+00, 0.15683300E+00, -.11491000E+01, 0.30915400E+00, -.65246900E+00, 0.94859900E-01, 0.72451000E-01, 0.46220500E-02, -.11991300E+00, 0.18979000E+00, 0.34108700E+00, 0.27371600E+00, 0.86563500E-03, 0.23822200E+00, -.20152600E-01, -.29838800E+00, 0.83347200E-01, -.23305800E+00, -.30285600E-03, 0.13161200E-01, 0.10459800E+00, -.63623800E-01, 0.31392000E-01, -.54809400E-01, 0.26515300E+00, -.21414700E+00, -.14189000E+00, 0.36084100E+00, -.10362500E+00, 0.38160900E-03, 0.13857700E+00, -.43003300E-01, -.16499400E+00, -.13613300E-01, -.18091000E+00, 0.48480800E-02, -.10020700E+00, 0.20871700E-01, -.31844300E+00, 0.10322500E+00, -.31187800E-03, 0.55777000E+00, -.30820100E+00, -.93264600E+00, -.17056500E-01, 0.94305800E-01, -.50754500E-01, -.79120200E-01, -.29985100E-01, 0.14357900E+00, 0.32630800E+00, 0.24379600E-01, -.11206800E-01, -.21308900E+00, -.17753100E+00, -.24960200E+00, 0.73003700E-02, -.23646400E+00, -.99580400E-01, 0.22166300E+00, -.29991600E+00, 0.31368300E-01, -.10567300E+00, 0.98111700E-01, -.12669100E+00, 0.31809000E+00, 0.69796300E-01, -.33662500E+00, -.26415600E+00, -.38014800E-01, 0.16208800E+00, 0.24542100E-01, 0.84654700E-01, -.19777000E-02, 0.39383900E-01, -.21353300E+00, 0.11923800E-01, -.91039800E-01, -.39245900E-01, 0.16074700E+00, 0.12199400E+00, -.20629900E+00, 0.70021600E+00, -.15237200E+01, 0.35361200E-02, 0.16277200E+00, 0.17509700E+00, 0.30462900E-01, -.32914500E-01, 0.98588800E-01, -.20490400E-01, 0.14508300E+00, -.91796900E-01, -.75223800E-01, 0.32218900E+00, -.19367400E-02, 0.12518700E+00, 0.90277800E-01, 0.52560500E-03, 0.66589200E-01, 0.13667000E+00, 0.54101300E-01, -.68405500E-01, -.27193000E+00, -.32471800E+00, -.31372200E+00, -.23541800E-01, -.10765700E+00, -.19514200E+00, -.20651700E+00, -.28687300E-02, 0.13054100E+00, 0.77988100E-02, 0.15006600E+00, -.42540200E-01, -.14916300E-01, 0.36980700E+00, -.72422300E-02, 0.56506600E-01, 0.47158900E-01, -.31310500E-01, -.46740100E-02, -.14149300E+00, 0.92525900E-01, -.26129400E+00, 0.56187200E-01, 0.26448600E-01, -.78657900E-01, -.12980300E-01, 0.23409400E+00, -.21036300E+00, 0.31546400E+00, -.30214200E+00, -.77594300E-01, 0.20948700E+00, -.74801800E-01, -.22498300E+00, -.31198200E-01, -.55511200E-01, -.73394200E-03, -.71411600E-01, 0.27351300E+00, 0.16594500E+00, -.17935800E+00, 0.47875700E+00, -.32742500E+00, -.20332400E-01, -.46605500E-02, 0.84122100E-01, 0.24484100E-01, -.24576700E-02, 0.32504400E+00, -.27627900E+00, -.42782600E+00, 0.15754100E+00, 0.11726400E+02, -.14098600E+01, -.16406500E+02, -.43140700E+02, 0.18492900E+02, -.31554700E+02, 0.21890900E+02, -.53745200E+01, -.32940400E+01, 0.33950600E+02, 0.25677500E+02, 0.11507200E+02, 0.11172900E+02, 0.19890500E+02, -.50302300E+02, 0.18174500E+02, 0.18301800E+02, 0.25210000E+02, 0.25290800E+02, -.38120300E+00, 0.23328600E+02, 0.17054500E+02, -.62690600E+01, -.28158200E+00, 0.12334200E+02, -.78252300E+01, 0.33737100E+01, -.74013300E+01, 0.38893500E+01, 0.18270600E+02, -.14304900E+02, 0.24156900E+02, 0.14420500E+02, 0.73423900E+01, -.12933300E+02, -.16035600E+02, 0.42151600E+02, -.20126500E+02, -.57187300E+02, -.21144300E+02, 0.11823700E+02, -.55758200E+00, -.69637100E+01, 0.34896600E+02, 0.14447400E+02, -.13861300E+02, -.14474000E+02, 0.81763400E+02, -.40576800E+02, -.41787300E+02, -.40731900E+02, -.28232000E+02, -.10094900E+02, -.15355800E+02, -.11635000E+02, 0.12904800E+02, -.24130700E+02, -.35732300E+02, 0.61864100E+00, -.28134300E+01, -.10308300E+01, -.65371000E+01, 0.69321600E+00, -.10814700E+00, 0.38785400E+01, 0.10014700E+01, 0.11749100E+01, 0.13863700E+01, -.11406700E+02, -.11899100E+01, -.87102000E+01, 0.72249700E+01, 0.42566600E+00, -.92764500E+00, -.85947400E+01, -.15498600E+00, -.84337500E+01, -.15141400E+01, -.15244500E+02, 0.16780800E+00, 0.59875900E+01, 0.75180000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.40998700E+01, -.92534200E+00, -.36766200E+00, 0.35846900E+00, 0.22128500E+01, -.78159600E+00, -.53661100E+00, -.68838900E+00, 0.68755900E+00, -.54896700E+00, -.33229000E+00, 0.15514000E+00, -.19223500E+01, -.79972600E+00, 0.34636700E+00, 0.88114400E-01, 0.44348200E+00, -.26354200E+00, -.35512100E+00, -.32369200E+00, 0.21259900E+00, -.10680800E+01, -.15629800E+01, 0.30781400E+00, -.13608200E+00, 0.54152300E+00, -.18540300E+00, -.56564200E+00, -.60941300E+00, 0.10316600E+01, -.36615500E+00, -.19616600E+00, -.20286700E+00, -.41795100E+00, -.93618800E-01, 0.12230700E+00, -.23151900E-01, 0.17682700E+00, 0.59500800E-01, 0.36145000E+00, 0.13386900E+01, 0.90170100E+00, -.24475700E+01, 0.68248500E+00, -.10924900E+01, -.10757200E+00, 0.47717900E+00, -.37441900E+00, -.69132100E-01, 0.58857400E+00, -.16155000E+00, -.37946100E-01, -.33697200E-01, -.15197300E+00, 0.51611500E+00, -.26959300E+00, 0.24726800E+00, -.90543300E+00, -.13321800E-02, -.32796600E-01, 0.53810000E-01, 0.54148600E+00, -.33284100E+00, -.58948800E+00, 0.79439100E+00, -.19948000E+00, 0.31946000E+00, -.54881400E+00, 0.83882100E-01, 0.54485800E-02, -.73845900E-01, -.11143700E+00, -.23639600E+00, -.94990700E-01, 0.39454800E+00, -.25623200E-01, 0.67575400E-01, 0.15018000E+00, -.12791900E+00, -.11126700E+00, -.79601200E-04, -.16165700E-01, 0.16320200E+00, 0.10206500E+01, 0.21522700E+00, 0.12941500E+00, -.16016500E+00, 0.37776800E-01, 0.36553000E-01, 0.59792500E-01, -.22082300E+00, -.17904900E-01, -.58496900E+00, 0.86430900E-01, 0.69667800E+00, 0.50331800E+00, -.34232900E+00, 0.16728500E+01, 0.70192200E+00, -.22924500E+00, -.76335100E+00, -.12285800E+00, -.18734100E+00, 0.58639800E-01, -.64661700E+00, 0.25762000E-01, -.60311100E+00, -.55020900E+00, -.44091500E+00, 0.22645200E+00, -.29622900E+00, -.28555500E-01, -.19573500E+00, -.13343900E-02, 0.26362700E+00, 0.14301600E+00, -.29947700E+00, -.17070600E+00, 0.18057500E+00, -.90697900E-01, -.11961200E+01, 0.66374500E+00, 0.23361000E+00, -.14291800E+01, 0.43611500E-02, 0.58468600E+00, -.35064300E+00, -.32745400E+00, 0.13238600E+00, 0.44084900E-02, 0.25615900E+00, 0.40179700E+00, -.16795300E-01, -.75066300E-01, -.76906400E-01, -.22143600E-02, -.32222100E+00, -.10532400E+01, -.86166500E-01, -.50061700E-01, 0.29308200E+00, 0.10763900E+00, -.17852900E+00, -.13013300E+00, 0.59881000E+00, -.25305900E+00, 0.42133100E-01, 0.13699300E+00, 0.26723500E+00, -.13146100E+00, -.43448200E-01, 0.16977700E+00, 0.58322900E+00, 0.22585600E+00, -.14339200E+00, 0.31781400E-02, -.34980800E+01, 0.96907200E-01, 0.20036800E+00, 0.12891000E+00, 0.15012300E+00, -.22550000E+00, 0.61195600E+00, 0.53498000E-01, -.19122200E-01, -.18129400E+00, -.53682400E-01, 0.28492400E+00, -.13609400E-01, 0.10886700E+00, 0.89210200E-01, 0.29225000E+00, 0.86438900E+00, -.20737100E-01, -.61492000E+00, 0.11288400E+00, 0.29467000E+00, -.25427900E-01, -.18685500E+00, -.63570800E-03, 0.79314000E+00, -.40351600E+00, -.11969000E+00, 0.10234500E+00, -.97235100E+00, -.10189300E+01, -.49150800E+00, 0.25925100E+00, 0.33135700E-01, -.26994500E+00, 0.73430500E-03, -.89998800E+00, 0.46278900E+00, 0.61457600E+00, -.42453400E+00, -.39247400E+00, -.88219900E+01, 0.17208200E+02, -.19338600E+03, 0.99509500E+02, 0.24051100E+03, 0.96607800E+02, -.56819800E+02, -.32665600E+02, -.10115900E+02, -.10295900E+03, -.52182900E+01, -.60518000E+02, 0.11131500E+03, -.74796400E+02, 0.40406500E+02, 0.34806200E+02, 0.37342500E+02, -.73669300E+02, 0.21253600E+02, -.63662000E+01, -.68140200E+02, 0.32569900E+02, 0.13057900E+02, 0.35558300E+02, 0.69926000E+02, -.33877400E+02, 0.97604100E+00, -.34960000E+02, 0.11792500E+02, 0.65199700E+02, -.92644500E+02, -.40669300E+02, -.90598400E+02, 0.58961700E+02, 0.17560200E+02, 0.96882200E+01, -.63051000E+01, -.21277900E+02, -.48957600E+01, -.28936500E+01, 0.15732600E+02, 0.21106600E+02, 0.36599800E+02, 0.37824300E+02, 0.41550300E+02, -.85073900E+01, -.88471700E+01, 0.44343100E+01, 0.20573100E+02, 0.43775500E+01, 0.17533900E+02, 0.41414400E+02, -.56844200E+02, -.58089300E+01, -.58243000E+02, 0.51884800E+02, 0.49155700E+02, 0.18619900E+01, 0.10633700E+02, -.15002800E-02, 0.20151700E+02, 0.18839300E+01, 0.11492000E+02, -.13958500E+02, -.93176800E-01, 0.12756400E+01, -.15407300E+01, 0.14582400E+02, 0.69283600E-01, 0.21686300E+01, 0.48820000E+01, -.64196700E+00, -.22728000E+00, 0.17469200E+01, -.12455000E+01, 0.25193100E+00, 0.35077900E+01, 0.15952500E+02, -.19560700E+02, 0.48052000E+01, -.14200300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12794500E+02, -.18630500E+01, -.45701800E+01, 0.85031500E+01, 0.96049000E+01, -.11053000E+01, -.18111300E+01, 0.40903600E+01, 0.38414500E+00, -.19890400E+00, 0.27620400E+01, 0.23829500E+01, 0.53746900E+01, 0.10274200E+02, -.47804200E+00, -.11110100E+01, 0.20054900E+01, 0.20585600E+01, -.21582000E+01, 0.10190900E+01, 0.12478800E+00, -.28933800E+01, 0.78524600E+01, -.36765500E+01, 0.98659400E+00, 0.60131900E+00, 0.46372400E+00, 0.21405900E+01, 0.79102000E+00, 0.51130300E+01, -.14891500E+01, -.54879900E-02, -.10637100E+01, 0.29870500E+01, 0.85918000E-01, -.58975900E-02, -.15278500E+00, -.97764400E+00, -.11601300E+01, -.52721100E+00, -.14861500E+01, 0.23540900E+01, -.14296500E+01, -.23603100E+00, -.18293000E+01, 0.46088300E+01, 0.61118100E+00, 0.17218500E+00, -.21675300E+00, 0.84692900E+00, -.72234400E+01, -.86287300E+00, -.84396200E+00, -.40864300E+00, -.55340300E+00, 0.71330200E+00, -.21174200E+00, 0.31804000E+01, 0.13882000E-02, 0.13041700E+01, 0.10116500E+00, 0.33832300E+01, -.62106300E+00, -.38972600E+00, 0.72395500E+01, 0.25203000E+01, 0.38568100E+00, 0.11148700E+00, -.28276700E-01, 0.98546200E-03, 0.75720200E+00, -.57650700E+00, 0.54161100E+00, -.55135300E+00, 0.20107600E+01, -.16223300E-01, -.15950900E+00, -.69042300E+00, -.11696900E+01, 0.10647900E+01, -.15569800E-02, 0.77895500E+00, -.31262800E+00, 0.21375100E+01, 0.88468100E+00, 0.65426100E+00, -.22287000E+01, 0.58675700E+00, -.31685900E+00, -.35285800E+00, -.12259200E+01, -.18530100E-01, 0.24552300E+00, -.18708300E+01, -.91326800E+00, -.65683500E+00, 0.17213000E+00, -.41424200E+01, 0.22817400E+00, 0.78319400E+00, 0.27317300E+00, -.10888300E+00, -.26585200E+00, -.47314600E+00, 0.12786100E+01, 0.71038800E+00, 0.18024700E+01, -.97292100E-01, 0.18533100E+01, 0.73885100E+00, 0.45119200E+00, 0.13613100E-01, -.68492800E+00, -.15809100E-01, -.10637600E+00, 0.21413500E+01, -.15321800E+01, 0.13130800E+01, -.67460300E-01, 0.30031400E+01, -.37359300E+00, 0.28174900E+01, 0.49273200E+00, 0.49802900E+01, 0.20462000E-01, 0.33037500E+01, -.27038700E+01, -.86459600E+01, -.55577400E+00, -.14199900E+00, 0.10978900E+00, -.63514400E+00, 0.48581100E+00, -.47545700E+00, 0.28923500E+01, -.32980500E-01, 0.22837200E+01, -.18906900E+01, -.16549000E+00, 0.39294900E+00, -.10647500E+00, 0.91478400E+00, 0.30017300E+00, -.11152300E+01, -.22280200E+01, 0.12489000E+01, -.13473700E+00, 0.66069500E+00, 0.72952700E+00, -.24141300E+01, 0.38824900E-01, 0.23333100E+01, 0.98752000E+00, 0.89311700E+00, -.13740800E+01, -.16193200E+00, -.22447800E+01, 0.99504300E-01, -.19921800E+01, -.48437200E+00, 0.36040900E+00, -.14946600E+01, 0.36570900E+01, 0.16425600E+01, -.42296600E+01, -.33619900E+00, 0.16530600E+00, -.56668600E+00, -.58868600E-01, 0.16764700E-01, -.66075900E+00, 0.25934800E+01, -.27891100E+01, -.10340500E+01, 0.18260500E+01, -.48430800E+00, 0.15001500E+00, 0.41586800E-01, 0.20345000E+00, 0.10603500E-01, 0.14816700E+01, -.95722400E+00, 0.32724300E+00, 0.74381400E+00, -.13496300E+01, -.12315700E+01, -.55227200E+00, 0.16607600E+00, 0.10171700E-01, 0.38389000E+00, 0.32854200E+00, -.20581700E+01, 0.57448800E+00, 0.36071500E+01, -.32407400E+00, 0.55210400E+01, -.41231400E-01, 0.36168900E+03, 0.50881700E+01, 0.23790600E+02, 0.38281500E+03, -.53626800E+01, 0.19566800E+03, 0.14173500E+03, -.17783800E+03, -.30002700E+03, 0.16841600E+02, -.27160900E+02, -.41656600E+02, 0.36046800E+03, -.13927300E+03, -.16555700E+03, -.18063100E+03, -.35675300E+03, -.56618700E+02, -.99015000E+02, -.18663000E+03, -.11796500E+02, -.40611900E+02, -.16334700E+03, -.62309400E+02, 0.36919100E+02, 0.23836600E+03, 0.31370700E+02, 0.23591900E+02, 0.20129500E+03, -.24672000E+03, -.17694400E+03, -.12036100E+03, 0.18912100E+03, -.85164400E+02, 0.88172200E+02, -.55278700E+02, -.16730100E+03, -.43306600E+02, -.46104700E+02, -.27739700E+02, -.41735300E+02, -.20356100E+03, -.16056400E+03, 0.84527100E+02, -.12218400E+03, -.50209200E+03, 0.24642800E+03, 0.31838100E+03, 0.24975500E+03, 0.16665900E+03, 0.42038300E+02, 0.11016500E+03, 0.20584600E+03, -.20962100E+03, 0.18360500E+03, 0.23630100E+03, -.91230500E+01, 0.31357000E+02, 0.44956200E+01, 0.76578500E+02, -.13283700E+02, 0.26584500E+02, -.42733700E+02, -.17194800E+02, -.13631300E+02, -.22830600E+02, 0.66938000E+02, 0.14915700E+02, 0.75654500E+02, -.59840400E+02, -.84137700E+01, 0.11025300E+02, 0.76164000E+02, 0.58882100E+01, 0.76071400E+02, -.20383200E+02, 0.12854600E+03, -.21509200E+02, -.86246500E+02, -.85022400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.73580500E+01, 0.14350200E+01, 0.24910700E+01, -.70327500E+00, -.58212300E+01, 0.19145900E+01, 0.84957100E+00, -.61470900E+01, 0.13273700E+01, 0.24241100E+01, -.15513800E+01, -.29890700E+01, -.90816200E+01, -.56107600E+01, 0.12149600E+00, 0.96654200E+00, -.30326500E+01, -.86599300E+00, -.40219300E+00, -.21346400E+01, 0.39284100E+01, 0.14284400E+02, -.18783400E+01, 0.15102000E+01, 0.59452200E-01, -.35294300E+01, 0.24084200E+01, 0.14857300E+01, -.38781100E+00, -.59880200E+01, 0.14853100E-01, -.67383500E+00, 0.39634100E+01, -.72477900E+00, 0.29699200E+00, -.37952300E+01, -.72626400E-01, -.18304100E+01, 0.99642600E+00, -.19702300E+01, -.98022200E+00, -.12731200E+01, -.13651500E+01, -.16261600E+01, 0.26339900E+01, 0.10570200E+01, -.20712300E+01, -.20634700E+01, -.12447700E+01, -.18574800E+01, 0.36015300E+01, 0.46470500E-01, 0.66156000E+00, -.10889000E+01, 0.27221000E+01, 0.10963600E+01, -.72162800E+00, 0.55752100E+01, -.96403000E-02, 0.70412500E+00, 0.13382300E+01, 0.94972100E+00, 0.19171600E+00, -.10104200E+00, 0.22896500E+01, -.53684500E+00, -.21391700E+01, -.10813100E+00, -.81021100E+00, -.99781900E-02, -.56548700E-02, -.13375100E+00, -.45473200E+00, 0.20984400E-01, 0.80911800E+00, 0.19192700E+00, 0.10081600E+01, -.89393100E-01, 0.11253400E+01, -.11413500E+00, 0.16615800E-02, -.10167000E+01, 0.47191300E+00, -.13789600E+01, 0.43137300E+00, 0.77573200E+00, -.16178300E+01, 0.97731600E+00, -.13201100E+00, -.60491300E+00, -.78811800E+00, 0.82149500E-01, -.12456300E+01, -.35126200E+01, -.34582900E+00, -.35616100E+00, -.24500800E+00, 0.31898200E+01, -.74642600E+00, -.89704200E+00, 0.42189600E+00, -.97317300E-01, -.34611200E-01, -.11210200E+01, -.57150400E+00, -.12264100E-01, -.47991400E+00, -.11731500E+01, 0.28334500E+00, 0.12244800E+01, 0.16140500E+01, 0.45873400E-01, -.95920500E+00, 0.31479800E-02, 0.41329100E+00, -.19084900E+00, -.44668800E+00, -.74442500E-01, -.11719400E+00, 0.44418200E+00, 0.14699200E+01, -.87969400E+00, -.61006200E+00, 0.16351700E+01, 0.23282100E-02, 0.41963000E+00, -.12479900E+00, 0.34252100E+00, 0.38645000E-02, -.43893300E+00, 0.14803900E+00, 0.14381400E+01, -.11274500E+01, 0.96374300E-01, 0.37309900E+00, -.15200600E-02, 0.88385500E+00, -.88760800E+00, 0.17424700E+00, 0.47503400E+00, -.11885600E+00, -.30774200E+00, -.29826800E+00, -.71403700E-01, -.56030700E+00, 0.11662000E+01, 0.39696200E-01, 0.12101400E+01, 0.12555400E+00, -.74386300E+00, -.31991900E-01, 0.10297000E+00, 0.10980100E+01, -.32307500E+00, -.17676000E+00, -.47942400E-01, -.19157500E+01, 0.60189700E-01, -.58995800E+00, 0.10647000E+01, -.15910200E+00, 0.40040500E+00, 0.20185000E+00, 0.71081600E-01, 0.17192900E+01, 0.62149500E-01, 0.84196200E-01, 0.29611800E+00, 0.49369000E-01, -.10948300E+01, 0.26799200E+00, 0.16032100E+00, -.62622800E+00, 0.56396200E+00, 0.86249700E+00, 0.39261200E-02, -.94304300E-01, 0.57135900E-01, 0.17037100E+00, -.49804400E-02, -.93095600E-01, 0.12276500E+01, 0.13620300E+00, -.66762200E+00, 0.91959500E+00, 0.34286400E+00, 0.19964200E+00, -.64104600E-01, 0.98663800E-01, 0.54049400E+00, -.79842900E-02, -.78107000E+00, -.57618000E+00, -.36608600E+00, 0.26888400E+00, 0.15188300E+01, -.37573100E-01, 0.28893200E+00, 0.70267900E+03, -.35635400E+03, -.11369900E+04, -.34951300E+03, -.17951300E+03, 0.91313600E+02, -.86590700E+02, 0.15681700E+03, -.10926300E+03, 0.10889400E+03, -.34496600E+03, -.14395600E+03, 0.57691000E+02, 0.64293000E+02, 0.72209700E+02, 0.91627200E+02, 0.40787700E+02, -.30234000E+02, -.34181400E+01, -.62169100E+01, 0.30800500E+02, 0.19759700E+03, -.26158100E+03, 0.13026500E+03, -.67004300E+01, 0.13065600E+03, -.54811500E+01, -.18187100E+03, 0.21999000E+03, 0.73753200E+02, 0.19444900E+03, -.14846600E+03, -.13949300E+03, -.48947000E+03, 0.24570100E+03, 0.33378400E+03, 0.24428400E+03, -.10084500E+03, -.26698100E+03, 0.14436800E+03, 0.97696300E+02, 0.15296700E+03, -.28151600E+03, 0.29516700E+03, 0.22832100E+03, -.11161400E+03, 0.25158600E+02, -.11336800E+03, -.13103100E+03, -.10513200E+03, 0.91757000E+02, -.19476000E+02, 0.18180800E+03, -.18192800E+03, -.12693900E+03, 0.50100900E+00, -.44866200E+02, 0.34250600E+01, -.67775300E+02, -.25985500E+01, -.33828400E+02, 0.48350600E+02, 0.84475700E+01, 0.91014200E+01, 0.83394500E+01, -.39595400E+02, -.37043800E+01, -.86854100E+01, 0.59991500E+01, 0.19047700E+00, -.46400300E+01, 0.45920100E+00, -.39578300E+01, -.98524900E+01, 0.14138200E+02, -.10971900E+02, 0.45956100E+02, -.62882900E+01, 0.56501600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35976600E+01, 0.52916500E+00, 0.16503300E+01, -.26017300E+01, -.26484700E+01, 0.12222700E+00, 0.50927300E+00, -.15824300E+01, -.36128800E-01, 0.24214600E+00, -.69671700E+00, -.87955600E+00, -.24678900E+01, -.26707200E+01, 0.29184400E-01, 0.29829100E+00, -.68763000E+00, -.12040100E+01, 0.27836300E+00, 0.89898400E+00, -.32150200E+00, 0.86290800E+00, 0.35591300E+00, 0.29841100E-01, -.12596900E+00, -.37234400E+00, -.24435700E-01, -.17130300E+00, 0.36616000E+00, -.85105700E+00, 0.51427400E+00, 0.10090100E-01, 0.39022900E+00, -.35034000E+00, 0.10668800E+00, 0.29365800E+00, 0.14304500E-01, -.10588900E+00, -.43053900E-01, -.13458600E+00, -.12586000E+00, -.87425000E+00, 0.55050000E+00, -.34247800E+00, 0.53436600E+00, -.37665100E+00, 0.15429100E+00, -.15703900E+00, -.36088600E-01, -.17588700E+00, 0.16042700E+01, 0.88196200E+00, 0.26128400E+00, -.16423900E+00, 0.66120200E-01, -.24197100E+00, 0.19130500E+00, -.85964400E+00, -.30594900E-03, -.40231200E+00, 0.49711500E-01, -.95055600E+00, 0.22027200E+00, -.39477900E+00, 0.76158400E-01, -.47048200E+00, -.38965800E+00, 0.10423500E+01, -.23590700E+00, -.60087100E-04, 0.11765700E+00, 0.32530800E+00, -.54155400E-01, 0.13339600E+00, -.29976100E+00, 0.19491400E-01, -.56920800E-01, -.17866200E+00, -.29157900E+00, 0.24778900E+00, -.18100100E-03, 0.73806600E+00, -.63720500E+00, -.79869200E+00, -.19120400E-01, -.98069300E-01, 0.34429600E+00, -.68104600E-01, 0.13794500E-03, 0.26872900E+00, -.97125100E-01, 0.23879500E-01, 0.11891500E+00, 0.16215100E+01, 0.11402300E+01, 0.10682500E+01, -.13807300E+00, -.10897300E+01, 0.79334200E+00, -.16902100E+00, 0.22481500E-01, -.37432100E-01, 0.15669400E+00, 0.36494100E+00, 0.12045800E+00, -.25749600E+00, -.62898900E+00, 0.90534200E-01, -.44266200E-01, 0.68462100E-01, -.18918600E+00, 0.48237000E-01, -.87144500E-01, 0.30504900E-02, -.22922100E+00, 0.13837000E+00, -.41949600E-02, 0.10637000E+00, -.24132500E-01, -.10689700E+01, 0.92681600E-01, 0.22655500E+00, 0.39129200E+00, -.14112100E+00, -.52561000E-02, -.34496200E+00, 0.22054600E+00, 0.71585400E+00, 0.93978900E-01, 0.16433500E+00, -.62095700E-01, -.15307100E+00, 0.92651400E-01, 0.72121300E-01, -.46459000E+00, 0.46140100E-02, -.88415000E-01, 0.40822800E+00, 0.64005500E-01, -.15853900E+00, -.29441800E+00, -.86234200E-01, 0.24965000E+00, 0.27008300E+00, 0.99097400E+00, -.96002800E-01, 0.77655200E-02, 0.31055500E+00, 0.23636200E+00, 0.57289500E+00, 0.92432000E-01, -.32804900E+00, -.39370000E+00, -.13880200E+00, 0.73759900E+00, 0.52852300E-01, 0.24241900E+01, -.42749700E-01, -.44681600E+00, 0.28782700E-01, 0.26273900E+00, 0.13274700E+00, -.13981600E+01, 0.19935500E-01, 0.76920100E-01, 0.13804400E+00, 0.28291100E-02, -.16352100E+00, 0.77050100E-03, 0.47720900E-01, 0.19662900E+00, 0.19191100E+00, -.29444700E+00, 0.96628800E-01, 0.42809800E+00, -.59932600E-01, 0.20778400E+00, -.12068900E-01, -.38893700E-01, -.18474600E-02, 0.10173600E+00, 0.18649600E+00, -.15818200E+00, 0.48456100E-01, 0.13906500E-01, -.19343300E-01, -.89192400E-01, -.93415400E-02, 0.37600300E-01, -.24579600E+00, 0.71050400E-03, 0.85315800E+00, 0.82340400E-01, -.66681600E+00, -.24492800E-01, -.18977500E+01, 0.89927500E-01, 0.15753800E+00, -.97852700E-01, -.14402400E+02, -.48154000E+02, 0.94515000E+00, -.28538300E+02, -.52501900E+02, 0.92329400E+02, 0.16319300E+03, 0.72466600E+01, 0.17704000E+02, -.32700700E+02, -.23012500E+03, 0.95615500E+02, 0.46131900E+02, 0.11508300E+03, 0.17028400E+03, 0.13250600E+02, 0.77586900E+02, 0.79896800E+02, 0.43073200E+02, 0.14039200E+02, 0.10477100E+03, -.73055400E+00, -.27458000E+01, -.83916800E+02, 0.29001300E+00, 0.74283800E+01, -.84299700E+02, 0.12339100E+03, 0.82705600E+02, 0.68654900E+02, -.84475000E+02, -.35822100E+02, 0.48554800E+02, -.19397800E+02, -.21587500E+02, -.24580100E+02, 0.66315800E+02, 0.52431500E+02, -.24628300E+02, 0.45454000E+02, 0.41283500E+02, -.32016800E+01, 0.16931100E+02, 0.20626400E+03, -.10140000E+03, -.15500000E+03, -.10277100E+03, -.73673400E+02, -.14957800E+01, -.65269400E+02, -.11884100E+03, 0.34677400E+02, -.59292000E+02, -.50160100E+02, 0.10526800E+01, -.88002400E+01, -.29033400E+01, -.27508500E+02, 0.52669500E+01, -.10570200E+02, 0.13438300E+02, 0.55353100E+01, 0.26884500E+01, 0.84072200E+01, -.17705600E+02, -.38617300E+01, -.28427600E+02, 0.25101300E+02, 0.36411500E+01, -.21568600E+01, -.32132700E+02, -.10096100E+01, -.30721300E+02, 0.29146500E+01, -.62353900E+02, 0.86081700E+01, 0.34945400E+02, 0.36286600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.41588900E+01, -.12594100E+01, -.96345200E+00, 0.37251400E+01, 0.29386300E+01, -.26272400E+00, -.53252900E+00, 0.19041400E+01, 0.46773900E+00, 0.32136400E+00, 0.28351700E+01, 0.65026700E+00, 0.31999400E+00, 0.23865200E+01, -.34369300E+00, -.58031100E+00, 0.65908600E+00, -.12830500E+01, -.54894300E+00, 0.83080800E+00, 0.44863100E+00, -.16092300E+01, 0.86819300E+00, 0.48451900E+00, 0.20480300E-01, 0.65997000E+00, 0.43125700E+00, 0.53353000E+00, 0.28393600E+00, -.20263800E+01, -.82382900E-01, 0.68157000E+00, -.14878800E+01, 0.15471300E+01, -.12751500E+00, 0.57356900E+00, -.32334600E-01, 0.20665900E+00, -.65719100E+00, -.34061400E+00, -.87179800E+00, 0.13895500E+00, 0.16870100E+01, -.58239900E+00, 0.78733900E+00, 0.19789300E+01, -.95923200E+00, 0.36098400E+00, 0.80143800E+00, 0.92719700E+00, -.82284200E+00, -.16838900E+01, -.40995600E+00, 0.66074900E+00, -.49497900E+00, 0.19700800E+00, -.60365600E+00, 0.25119500E+01, 0.24764300E-02, 0.10117000E+01, 0.62557600E+00, 0.16908100E+01, 0.17186500E-02, 0.74080800E+00, 0.24636000E+00, -.38286500E+00, 0.21361800E-01, -.11449900E+00, -.11672300E+00, 0.69012400E-02, 0.29401900E+00, 0.45942700E+00, -.62432800E-01, -.42376400E+00, -.22155700E+00, 0.22877600E-02, 0.42558700E+00, -.12339700E+00, -.36128900E+00, -.56550500E+00, -.80191500E-03, -.22324900E+00, 0.19550200E+00, 0.41354600E+01, -.17658000E+00, -.45033600E+00, 0.72238800E+00, 0.20654600E+00, 0.95276100E+00, -.13825800E+00, 0.83675400E-02, -.11906900E+00, 0.24226300E+00, 0.79805700E+00, 0.53988100E+00, -.10695300E+01, 0.88610600E+00, 0.44198800E+01, -.86189800E+00, -.94858300E+00, 0.10722400E+01, 0.16997300E+00, 0.12857900E+00, -.16947800E+00, 0.27377500E+00, -.11546000E+01, -.40460900E+00, 0.59482200E+00, -.70459400E+00, -.23027400E+00, -.58199200E+00, -.81023100E-01, 0.11773100E+00, -.47007400E-02, 0.15519900E+00, 0.35927000E+00, -.41299100E-01, 0.67169400E-01, 0.21253800E+00, -.12725400E+01, -.10891600E+01, 0.70246100E+00, 0.35814100E+00, -.17535800E+01, 0.47550800E-02, -.74052500E+00, 0.31984700E-01, -.12813600E+00, 0.62187000E+00, -.26914300E+00, -.45222000E+00, -.70470000E-01, 0.10767800E+00, 0.15291100E+00, 0.47015100E+00, 0.64439400E-02, -.87000200E+00, -.47330700E+00, -.49989600E-01, -.52885700E-01, 0.18536900E+00, 0.25272100E+00, -.88111800E-01, 0.30554600E+00, 0.11917500E+00, 0.61596900E+00, 0.10275800E+00, 0.13168700E+00, 0.48888700E+00, 0.36753400E+00, -.23333800E-02, -.45623400E+00, -.12655200E+00, -.46750900E+00, -.22044100E+00, -.34421900E-01, 0.63621200E+00, -.10110700E-02, -.18903500E+00, -.71126400E-01, -.69360400E+00, 0.29406600E-01, 0.23211600E+01, 0.96979000E-01, 0.63228300E+00, -.48428800E-01, 0.39848100E-02, 0.31192300E+00, 0.26194900E-01, -.18379400E+00, 0.65576600E-01, -.52182600E+00, -.15094600E+00, 0.34939400E+00, -.26285700E+00, -.18640200E+00, -.29856700E+00, 0.18068600E+00, -.52692200E+00, 0.14040200E-02, 0.54426900E+00, -.65447000E+00, -.65293600E+00, 0.67781800E+00, -.40565600E+00, -.14839700E+00, -.22854200E+00, -.27552700E+00, 0.33047700E+00, -.34214500E+00, 0.83163900E-02, -.94260100E+00, 0.97782000E+00, -.40469000E+00, -.63099300E-01, -.22654100E+01, 0.43591900E+00, -.23020600E+00, 0.25292500E+00, 0.10001600E+01, 0.80477000E+03, -.21006700E+01, 0.30920500E+03, 0.14483900E+03, -.21369600E+03, -.21216200E+03, -.22213300E+03, 0.27696700E+00, 0.90581800E+02, 0.36165300E+03, -.18966600E+03, 0.15269800E+02, -.18079400E+03, -.18388500E+03, -.38054700E+02, -.68526400E+02, -.95217000E+02, -.10214500E+03, -.13827500E+02, -.20577400E+03, 0.29520600E+03, -.14729100E+03, 0.45834400E+02, -.14743700E+03, -.15851300E+02, 0.21395100E+03, -.25534600E+03, -.89097200E+02, -.26803900E+03, 0.18533700E+03, 0.13003600E+03, 0.23755500E+03, -.11839800E+03, -.18054200E+03, -.11808200E+03, 0.49368000E+02, 0.94446600E+02, -.37613100E+02, -.15623700E+03, -.28027300E+02, 0.19357100E+03, -.17922900E+03, -.45874500E+03, 0.22593400E+03, 0.14129200E+03, 0.22862800E+03, 0.18875500E+03, 0.70837900E+02, 0.47716200E+02, 0.18690900E+03, -.14641200E+03, 0.17968300E+03, 0.17342200E+03, -.42768000E+01, 0.42096500E+02, -.58000800E-01, 0.74068000E+02, 0.30891600E+00, 0.19608600E+02, -.48061000E+02, -.84873000E+01, -.74425800E+01, -.16151400E+02, 0.62612500E+02, 0.61165100E+01, 0.38118800E+02, -.35353600E+02, -.25449400E+01, 0.63795500E+01, 0.34500700E+02, 0.64115100E+01, 0.41750400E+02, -.22245300E+02, 0.68016200E+02, -.48477500E+02, -.35421200E+02, -.81354300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.81636000E+01, -.28857800E+01, -.99703800E+00, 0.50257300E+01, 0.53635100E+01, -.81995600E+00, -.10398300E+01, -.13606400E+00, 0.61174300E+00, -.64217600E+00, 0.19612600E+01, 0.11171000E+01, -.45932200E+01, 0.20978000E+01, 0.54634500E+00, -.76855900E+00, 0.19248200E+01, -.18676300E+00, -.85739700E+00, 0.98995400E+00, 0.10659400E+01, -.43252600E+01, -.20525300E+01, 0.29004100E+00, -.42276400E-01, 0.31861400E+01, 0.71277800E+00, -.19398500E+00, 0.34808100E+00, -.23742200E+00, -.96943800E+00, 0.67006300E+00, -.11440100E+01, -.33492300E+00, -.82076300E-01, 0.15780500E+01, 0.10117100E+00, 0.49794000E+00, 0.14489000E+00, 0.56382100E+00, 0.12326700E+01, -.12265200E+00, -.16058700E-01, 0.16345500E+00, -.60669200E+00, 0.21253400E+00, -.86896600E+00, 0.67891400E+00, 0.44233000E+00, -.28328300E+00, -.10551100E+01, -.50357600E+00, -.15794900E+00, 0.46137500E+00, -.89256100E+00, -.74895400E+00, 0.11581400E+00, -.21557800E+00, 0.10663200E-01, 0.20442000E+01, 0.20055200E+00, -.10147100E-01, -.86356900E-01, 0.71192000E+00, -.38485400E+01, -.33401600E+00, 0.12617000E+01, 0.22779400E+00, -.52233300E-01, 0.15687800E-01, 0.14535600E-01, 0.27612400E+00, 0.50775500E+00, 0.29459800E+00, 0.58040900E+00, -.28013800E+00, -.52746300E+00, -.44021200E+00, 0.42241900E+00, -.59494600E+00, -.80606700E-03, 0.45476800E+00, 0.13666600E+01, -.41420000E+00, -.21635100E+00, -.15078900E+01, 0.15499300E+00, 0.33174600E-01, -.23888300E-01, 0.35226700E-01, -.35207700E+00, -.39028000E-01, 0.11604100E+01, 0.22149900E+01, 0.10222500E+00, -.52952300E+00, 0.10334500E+00, 0.38663900E+01, 0.80713400E-01, -.17950900E+00, -.18986500E+00, -.12809300E-01, -.45513700E-02, -.15266300E+00, 0.18456400E+00, -.44710400E+00, 0.56033100E+00, 0.10350300E+01, 0.36089400E+00, -.59692700E+00, -.29485000E+00, -.10141000E+00, -.29087900E+00, -.11779100E-02, -.18368600E+00, 0.10250700E+01, -.22208500E+00, 0.51114400E+00, 0.11269600E-01, -.74794300E+00, -.14330200E+01, 0.13565400E+01, -.31902200E+00, 0.16296900E+01, -.17431200E-01, 0.18006100E+00, -.10284400E+01, -.13386900E+01, 0.35533800E+00, 0.25834200E+00, 0.33782500E+00, -.56099400E-01, 0.26832000E+00, -.11118200E+00, 0.12932500E+01, 0.96863800E-02, 0.57571700E+00, -.17720700E+01, -.20433900E+00, 0.87275100E-01, -.41091200E-01, 0.22940500E+00, -.24754600E-01, 0.21979300E+00, 0.12928400E+01, 0.94723100E+00, 0.29980700E+00, -.79476200E-01, -.34633300E+00, -.25494000E-01, -.11252700E+00, 0.17370400E+00, 0.89875200E+00, 0.24624900E+00, 0.86873100E-01, 0.53283200E-01, -.26393200E+01, 0.36052100E+00, 0.84797400E-01, -.26624500E+00, 0.17317500E+00, 0.15425000E+00, -.25525800E+00, 0.11154700E+00, -.11988400E+01, -.16012800E+00, -.10458400E+00, -.18600900E+00, -.20104200E+00, 0.16889200E+00, -.12410200E+00, 0.35916700E+00, -.72818500E+00, -.56464700E+00, -.79974000E+00, -.47207700E-01, 0.10445200E+00, 0.63971100E-01, 0.33892500E+00, 0.35463600E-03, -.18972800E+00, -.28108900E+00, 0.20498000E-01, 0.70919500E+00, 0.46864700E+00, 0.20566800E+00, 0.35207900E-01, -.22220000E+00, 0.72902800E-01, -.42836800E+00, 0.26537000E-02, 0.72511900E+00, 0.44560000E+00, -.28131900E+01, 0.83815500E+00, -.48034900E+00, -.17315400E+01, -.59939000E-01, -.34280700E+00, -.28805800E-01, -.18520500E+00, 0.93169500E+01, -.65281300E+02, 0.73335000E+02, -.11705600E+03, -.29801700E+01, -.66624600E+02, 0.42909900E+02, -.17090400E+02, -.19392000E+03, 0.89145000E+02, 0.48554200E+02, 0.97409600E+02, -.66864600E+02, 0.24026300E+02, 0.47692500E+02, -.90882100E+02, 0.42260400E+02, 0.17522700E+02, 0.87202900E+02, 0.13665000E+02, -.57591700E+01, 0.60837800E+02, -.69234300E+01, 0.44712700E+02, 0.82021000E+02, -.10990700E+03, -.55801800E+02, -.11137200E+03, 0.77410900E+02, -.33818300E+01, -.50885100E+03, 0.25460400E+03, 0.79514500E+02, 0.25420100E+03, -.49004600E+02, -.18510900E+03, 0.17209500E+03, -.72638700E+02, 0.25241100E+03, -.14823900E+03, 0.24192500E+03, 0.16687000E+02, -.83257400E+01, 0.46692600E+02, -.75783500E+01, 0.46205100E+02, 0.69712000E+02, -.92835400E+02, 0.23210100E+02, -.44859200E+02, 0.46761700E+02, 0.63604500E+02, 0.32132900E+01, 0.84645500E+01, 0.35298700E+01, 0.18682700E+02, 0.91106600E+00, 0.53306300E+01, -.10970300E+02, 0.14772100E+01, 0.79751200E+01, -.65041000E+01, 0.22399700E+02, -.97085200E+00, -.51793000E+01, 0.82477600E+01, -.26572900E+01, -.17991900E+01, -.57137900E+01, -.93204000E+00, -.46181300E+01, -.88844000E+01, 0.16009800E+01, -.20611500E+02, -.17222200E+02, -.15500300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30319200E+01, -.88705800E-01, -.53433900E+00, 0.12579800E+01, 0.12539700E+01, -.11190800E+00, -.30947000E+00, 0.35494300E+00, -.20959800E+00, -.42941200E+00, -.10002300E+00, -.19285600E+00, -.35205400E+01, -.14330900E+01, 0.61720500E+00, 0.12385400E+00, -.47698000E+00, -.13652800E-01, -.77560900E-02, -.52175300E+00, 0.31855700E+00, -.19134100E+01, 0.16694200E+00, -.77481500E+00, 0.70975600E-01, 0.21293600E+00, 0.79757800E-01, -.58274300E+00, -.67530700E+00, 0.10244500E+01, -.34395500E+00, 0.85244900E-01, 0.94614500E+00, 0.96827300E+00, -.82150200E-02, 0.48200900E+00, 0.45432100E-01, 0.23148900E-04, 0.43264100E+00, 0.67273300E-01, 0.51343100E+00, 0.16675800E+00, -.61393300E+00, 0.28756800E-01, 0.18897900E+00, -.67420400E+00, 0.41458500E+00, 0.29245200E-01, -.10292000E+00, -.90440000E+00, -.68248500E+00, -.34020500E+00, -.81150300E-01, 0.19203000E+00, 0.29934600E+00, 0.20938400E+00, -.22952800E+00, -.75925500E+00, -.31582200E-02, -.21584100E+00, 0.59299500E+00, 0.33137200E+00, 0.32570000E-01, 0.37697200E-01, 0.52266900E+00, 0.26295900E+00, 0.27282400E+00, -.52770400E+00, 0.29090900E+00, -.80721800E-03, 0.18697500E+00, -.78532200E-01, 0.76688300E-01, 0.10641300E+00, -.86068200E-01, 0.10891500E+00, 0.89588800E-01, 0.28601500E+00, 0.44134300E+00, -.17293400E+00, -.91445500E-03, -.10857200E+01, 0.22354500E+00, -.19391600E+01, 0.34797800E-01, 0.20377600E+00, -.46062500E+00, -.36621400E+00, -.23964900E+00, 0.90303600E-01, -.42137200E-01, 0.23126600E-01, -.32882700E-01, 0.30693800E+00, 0.40395300E+00, 0.52106700E+00, -.10931800E+00, -.14352300E+01, 0.91817100E+00, 0.87391400E-01, 0.24683400E+00, -.50518500E-01, 0.76953400E-01, -.69790300E-02, -.28056500E+00, 0.30451200E+00, -.68549200E+00, -.44265300E+00, 0.24317700E+00, 0.87991100E+00, -.76102700E+00, 0.98356500E-01, -.15373200E+00, 0.27583600E-02, -.47191200E-01, -.30700100E+00, 0.14926800E+00, -.56914800E-01, -.37343300E-02, -.42220000E+00, -.51646100E-01, -.16209800E+00, -.31564500E-01, -.39808500E+00, -.23866600E-02, -.23325600E+00, 0.26263000E+00, 0.10445900E+01, 0.23595600E+00, -.10524300E+00, -.23689300E+00, 0.31887000E-01, -.75942300E-01, 0.60026800E-01, 0.45635800E+00, 0.70223700E-02, 0.79691600E-02, -.25573100E-01, -.94664100E-01, 0.96642100E-01, 0.41396600E-01, 0.49867700E-01, -.41848000E-01, 0.12533400E+00, -.34654300E+00, 0.26931400E+00, 0.10183300E-01, -.53586300E+00, -.15316700E+00, 0.32550900E+00, -.17453200E+00, 0.55913600E-01, 0.63602600E-01, 0.13551400E+00, 0.10397300E+00, -.12886300E+00, -.51356500E+00, 0.54447300E-02, 0.87751300E+00, 0.95580400E-01, -.37485400E+00, 0.37976300E-01, 0.38290700E-01, -.13033800E+00, -.59905900E+00, -.39472000E-01, -.11137200E-01, -.48371700E-01, -.20419300E-01, -.24374400E+00, 0.56240300E-01, -.56370300E+00, 0.11040400E+00, 0.10318100E+00, 0.11730200E+00, 0.53056000E-01, -.23464700E+00, 0.65826300E-01, 0.18956100E+00, 0.43090300E-02, -.10395100E+00, -.32876900E+00, 0.84282700E-01, 0.15900500E+00, -.48675300E-01, 0.55728200E+00, 0.12901600E-02, 0.94540600E-02, 0.50442700E-02, 0.25360700E-01, 0.39519400E-02, 0.36059200E-01, 0.69383400E-01, -.88610700E+00, 0.30039300E-01, -.63174500E+00, -.30157600E-02, -.28844600E-01, 0.42836200E-02, 0.77611800E-01, -.32441300E+00, -.54043100E-01, 0.67991600E+02, 0.56923000E+02, -.66889600E+02, -.30925600E+02, -.43461700E+02, 0.18786100E+02, 0.72759000E+01, -.53134300E+01, -.12627700E+01, 0.32426800E+02, 0.28284600E+01, -.78854600E+02, -.12216600E+02, 0.21343700E+02, -.50692800E+02, -.15824000E+02, -.66219200E+01, -.23826900E+02, 0.72044600E+02, -.35859800E+02, 0.41240800E+02, -.35978700E+02, 0.11319900E+02, 0.42159500E+02, -.70339700E+02, -.29241900E+02, -.89744100E+02, 0.37229800E+02, -.12280500E+02, -.16613600E+03, 0.82694400E+02, -.10498100E+03, 0.83362100E+02, -.64819500E+01, -.54853100E+02, 0.73017600E+02, -.51682100E+02, 0.94157700E+02, -.33537200E+02, 0.56029300E+02, -.10701600E+03, 0.52873800E+02, 0.80432000E+02, 0.53426900E+02, 0.61856500E+02, 0.17606700E+02, 0.19223100E+02, 0.83314000E+02, -.27439100E+02, 0.36908800E+02, 0.16237700E+02, -.15565500E+01, 0.10602700E+02, 0.11503000E+00, 0.21974300E+02, -.25135300E+01, 0.94384400E+01, -.10968700E+02, -.31934700E+01, -.24219800E+00, -.62750300E+01, 0.73900200E+01, 0.20236700E+01, 0.13435800E+02, -.11155000E+02, -.13801700E+01, 0.15911600E+01, 0.11225700E+02, 0.19499900E+01, 0.14609100E+02, -.91524900E+01, 0.20093800E+02, -.14532800E+02, -.17391200E+02, -.24829300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.70267700E+01, -.20595600E+01, 0.57014800E+01, -.12891500E+01, 0.45903000E+01, 0.21669900E+00, -.95246000E+00, 0.19326500E+01, 0.47894100E+00, -.42909100E+00, -.25512900E+00, -.11367200E+01, -.18112500E+01, -.20790600E+01, 0.34245300E+00, -.40664000E+00, -.16050000E-01, 0.87453400E+00, -.61578000E-01, -.19902000E+00, 0.10157800E+01, 0.11998600E+01, -.81635400E+01, 0.39575700E+01, -.15559100E+00, -.87853000E+00, -.35714100E+00, -.59587100E+00, -.26173400E+01, -.35193900E+01, -.12988000E+00, -.29436200E-01, -.26596500E+00, -.73711900E-01, -.40436900E+00, -.13938700E+00, 0.15776800E-02, 0.40437300E+00, -.68517200E-01, 0.89415600E+00, 0.31649600E+01, 0.30717900E+01, -.59574300E-01, 0.10251800E+01, -.51915800E+00, -.10671600E+01, 0.14851800E+01, -.14114900E+00, 0.13819000E+01, 0.26213000E+01, -.20728900E+01, -.27694200E+01, -.43499600E+00, -.24925600E+00, 0.13494700E+01, 0.41354000E+00, 0.14685500E+00, -.10975500E+01, 0.34488100E-03, -.22401000E+00, -.25068200E+00, 0.18551800E+01, -.62100100E+00, 0.74368100E+00, -.26921300E+01, -.99914300E+00, 0.12620800E+01, -.18316700E+01, 0.12708600E+01, 0.12521300E-01, -.21755000E+00, 0.48731500E+00, -.42670700E+00, 0.28505600E+00, 0.93935400E+00, -.16900900E+00, -.24722700E+00, -.13953500E+01, -.60440900E+00, -.29944100E-01, -.13841900E-02, 0.15091100E+01, -.79102800E+00, 0.20216500E+01, -.66894600E-01, -.91687100E+00, 0.71946900E+00, 0.76817700E+00, 0.46694700E+00, 0.16085900E+00, -.16954100E+01, 0.13292400E-01, -.46378500E+00, -.53362200E+00, -.44688300E+00, -.30669200E+01, 0.61500600E+00, 0.59927600E+01, -.82484400E+00, -.74191000E-01, -.22147500E+00, 0.74555900E-01, -.18245500E+00, 0.23316900E+00, 0.47235800E+00, -.19831000E+00, 0.14674400E+01, 0.77795100E+00, 0.15688900E+01, -.29923000E+00, 0.58119500E+00, 0.69373000E-01, -.28723400E+00, -.14179800E-01, 0.58448600E-01, 0.12319800E+01, -.53659900E+00, -.33326300E+00, 0.90753500E-02, 0.11757100E+01, -.92370100E+00, -.41689400E+00, 0.48592100E+00, -.22910200E+01, -.10793800E-02, 0.72397200E+00, -.53579300E+00, -.39123300E+00, 0.32549700E+00, -.24329000E-01, 0.50147600E+00, 0.30956000E-01, 0.37662000E+00, 0.29464700E-01, 0.12770600E+01, 0.56805800E-02, 0.66620900E+00, -.14317200E+01, -.15423000E+00, -.12007100E-01, 0.11677000E+00, 0.20631900E+00, -.34929700E+00, 0.96371900E-01, -.14384800E+00, -.30983800E+00, 0.24629800E-01, 0.28846100E+00, 0.85755300E+00, -.54891800E+00, 0.16066200E+00, 0.11296200E+00, 0.47291500E+00, 0.25041000E+00, 0.20282300E+00, 0.10306200E+00, 0.22244800E+01, 0.31483300E-01, 0.12197600E+01, -.47624400E+00, 0.32708400E+00, -.36051600E+00, 0.13922900E+01, 0.32123200E+00, -.16558000E+00, -.29094500E-01, 0.40995300E-01, -.54076400E-02, -.20991400E-01, -.14379000E-01, -.38842600E-01, 0.10302000E+01, -.71041900E+00, -.27211200E+00, -.13070400E+01, -.10548100E+00, 0.67855800E+00, -.90920900E-01, -.21511500E+00, 0.12817700E-02, -.62546100E+00, 0.77425000E-01, -.62447900E+00, 0.44784600E+00, -.13709800E+01, -.12154500E+01, -.17531800E+00, 0.28710900E+00, -.61422500E-01, -.13999000E+00, 0.32167900E-02, 0.25431400E+00, 0.66246100E+00, 0.17866000E+01, 0.48977300E+00, 0.19824300E+01, 0.13136900E+01, -.92458700E-01, -.29739200E+00, -.72920300E+00, -.39992000E+00, -.10661100E+00, 0.19986200E+01, -.17396200E+03, 0.65432400E+02, -.23718000E+02, 0.71306200E+02, -.88098500E+02, -.18085100E+03, -.20587800E+03, 0.11991100E+03, -.47241300E+02, 0.10290700E+03, 0.21278700E+03, 0.30323500E+02, -.34301000E+02, 0.23483800E+02, 0.14537000E+03, 0.30267300E+02, 0.21231000E+03, 0.54610900E+02, -.27411000E+02, -.20727200E+03, -.27321300E+02, -.14354400E+03, -.26760500E+02, 0.41129100E+02, 0.10121300E+02, 0.11341400E+03, -.16288200E+02, 0.80206100E+02, 0.36610700E+02, -.21129800E+02, 0.15462300E+03, -.18494000E+02, -.32526600E+02, 0.12853000E+03, -.86135700E+02, -.14039200E+03, -.13327300E+03, 0.11142000E+03, 0.13939000E+03, -.10297300E+03, 0.51729200E+02, -.68099800E+02, 0.51541200E+02, -.30263100E+02, -.30937300E+02, 0.76120600E+02, -.17702800E+02, 0.71284800E+02, -.37482100E+02, 0.36561000E+02, 0.39469300E+01, -.90085000E+01, -.46501300E+01, -.26212000E+02, 0.41452900E+01, -.15788500E+02, 0.12319700E+02, 0.23968800E+01, -.60027400E+00, 0.11750800E+02, -.27621700E+02, -.55660600E+01, -.59608200E+01, 0.58505800E+01, 0.97220000E+01, -.37286000E+01, -.50874500E+01, -.77318400E+01, -.71748500E+01, 0.23585500E+02, -.35441900E+02, 0.30232300E+02, 0.19175300E+02, 0.17792000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.43690200E+01, -.18397800E+01, -.10504400E+01, 0.25508700E+01, 0.30939100E+01, -.48003300E+00, -.54503000E+00, 0.17961400E+01, -.18828400E-01, -.61055900E+00, -.57256900E-01, 0.25075500E+00, 0.28153400E+00, 0.18266500E+01, -.95950400E-01, -.32300700E+00, 0.92136000E+00, 0.19979400E+01, -.28341500E-01, -.17200800E+01, 0.20386900E+01, -.51664700E+00, -.38614000E+01, 0.17068600E+01, 0.33746300E-01, -.69928500E-01, 0.41405100E+00, 0.14542800E+00, -.90122800E+00, -.63713300E+00, 0.10012700E+00, 0.25909600E+00, -.56846500E+00, 0.20831900E-01, -.81859300E-01, 0.21951700E+00, -.85942100E-02, -.43657800E+00, -.46618000E+00, 0.39122500E+00, 0.10707500E+01, 0.39116400E+00, -.59413600E+00, 0.65753400E+00, 0.30029800E+00, -.13253000E+01, -.41016900E+00, -.53305300E+00, -.68941700E-01, -.34737700E+00, 0.11603000E+01, -.47375300E+00, 0.35406900E-01, 0.45735500E+00, 0.53923000E-01, -.26665200E+00, -.58126500E-01, -.11962400E+01, 0.14870400E-02, 0.11853200E+01, 0.10556800E+01, 0.36996600E+00, -.41880400E-01, -.43210600E+00, -.85445400E+00, -.10723700E+01, -.24963200E+00, -.42033700E+00, 0.21705500E-01, 0.14703100E-01, -.35284200E+00, 0.50675800E+00, 0.96259200E-01, 0.24957300E+00, 0.11982200E+00, -.15696900E+00, -.10620300E+00, 0.16805200E+00, 0.81181100E+00, -.74469100E+00, 0.41073900E-03, -.74338000E+00, 0.14092200E+01, -.15495400E+01, -.13653400E+00, -.40930800E+00, -.25059100E+00, 0.14053800E+00, 0.43976600E+00, -.13886900E+00, -.38658700E+00, -.90888100E-01, 0.73173600E+00, 0.15227400E+01, 0.11560600E+01, 0.48188000E+00, 0.98269600E-01, 0.11752600E+01, 0.29729700E+00, -.17898800E+00, 0.17895800E+00, 0.12033200E+00, -.94202000E-01, 0.26984100E+00, 0.62126600E+00, -.62536900E+00, -.40394700E+00, 0.40394000E+00, 0.38006400E+00, -.28110900E+00, -.10492300E+01, -.70156800E-01, -.34748900E-01, -.20914800E-01, 0.53812300E+00, 0.45192300E+00, -.16696400E+00, -.23294100E+00, -.94306600E-01, 0.13146200E+01, -.30421400E+00, -.99289400E+00, -.12669100E+01, -.23020700E+01, 0.64893800E-03, 0.54596600E+00, -.39323000E+00, -.14706800E+01, -.37051800E-01, 0.12510000E+00, -.38489500E+00, 0.68531800E+00, -.62581200E-01, -.17276700E+00, 0.13221900E+01, -.59030800E-02, 0.12992100E+01, -.10188500E+01, 0.82693800E-01, 0.99063600E-01, -.26102900E+00, 0.15707700E+00, 0.76101400E-01, -.14787500E+00, 0.88021900E+00, 0.74090200E-01, 0.45737800E-01, 0.86241200E+00, 0.15263400E+00, -.31867500E+00, 0.86062000E-01, 0.41348600E+00, -.68785600E+00, 0.10699900E-01, 0.57641300E+00, -.14086400E-01, -.20330900E+00, 0.10910300E+00, -.11225300E+01, 0.62153600E-01, 0.40519200E+00, -.31541500E+00, 0.66346600E+00, 0.29973600E+00, -.74393100E+00, -.18229100E+00, 0.15562000E-01, 0.52637400E-01, -.43833200E-01, 0.23181700E+00, -.15362700E+00, 0.15064000E+01, -.17407600E+01, -.27154700E+00, 0.42265600E+00, -.23734700E-01, -.74019800E-01, 0.84629900E-01, 0.48123500E+00, 0.50378100E-02, -.12138800E+01, 0.72199600E+00, 0.51362600E+00, 0.16126000E+00, 0.11340000E+01, 0.62237000E+00, -.13695500E-01, -.11225900E+00, 0.98434500E-01, -.34954100E+00, 0.49810300E-02, 0.46529100E+00, 0.21758900E+00, -.11821600E+01, 0.46993100E+00, 0.18278900E+01, -.10498800E+01, 0.11112800E+00, -.11691800E+00, -.10309500E+00, -.16330600E+00, -.13498700E-01, -.73473200E+00, -.51777300E+00, -.12247600E+03, -.11058600E+03, -.59729400E+01, 0.38238800E+01, -.70933800E+02, -.32600000E+02, 0.14292200E+02, 0.44547900E+01, 0.16472200E+02, -.61311400E+01, 0.11386300E+02, -.23294300E+02, -.66921100E+02, 0.29272300E+02, 0.16140600E+02, 0.40913400E+02, 0.52606200E+02, -.25905900E+02, -.36363600E+02, -.26266900E+02, -.47036500E+02, 0.90185900E+02, -.10163100E+03, -.85483400E+02, -.71730600E+02, 0.98354200E+02, 0.59623300E+02, -.18636600E+03, 0.93548600E+02, 0.19891700E+02, 0.93386500E+02, -.14759700E+02, -.33769100E+02, 0.62153500E+02, -.13386700E+03, 0.36696800E+02, -.57931000E+01, 0.12770500E+03, -.22881800E+03, 0.11389300E+03, 0.93773700E+02, 0.11436800E+03, 0.93649800E+02, 0.37890700E+02, 0.34899300E+02, 0.96865000E+02, 0.22191100E+01, 0.43859300E+02, 0.10734600E+03, 0.42249700E+01, 0.89690600E+01, 0.28544700E+00, 0.19167700E+02, -.15513400E+01, 0.53025300E+01, -.86846200E+01, -.20689100E+01, 0.13128000E+01, -.38598200E+01, -.79132900E+01, -.17163600E+01, 0.19603500E+02, -.14978200E+02, 0.17147700E+01, -.27326700E+01, 0.16561300E+02, -.37256500E+01, 0.20808300E+02, 0.41769200E+01, 0.18494200E+02, -.34731900E+01, -.10466200E+02, -.28134000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19607900E+01, -.32002800E+00, -.15552600E+00, 0.68666300E+00, 0.10433500E+01, -.42630600E-02, -.30504300E+00, -.47631200E+00, 0.63887500E+00, 0.13721700E+00, 0.96473800E+00, 0.11553700E+00, -.13195300E+01, 0.16024800E-01, -.13298700E+00, -.15539900E+00, -.88293700E-02, -.76301100E+00, -.51195900E+00, 0.89780800E+00, 0.29599900E+00, 0.10741200E+00, 0.17805500E+01, -.59514700E+00, 0.90765100E-01, 0.76392800E-02, 0.44698800E+00, 0.11186900E+00, -.46755100E-01, 0.90413000E+00, -.33691600E+00, 0.21742400E+00, 0.79361700E+00, 0.73843500E+00, -.35651100E-01, -.13306500E+00, -.24418000E-02, 0.21524900E-01, -.10928200E+00, -.36135100E+00, -.59992500E+00, 0.35234200E+00, 0.17852000E+01, -.47203500E+00, 0.53785000E+00, 0.51507900E+00, -.31933400E+00, 0.23446700E+00, 0.48791500E+00, 0.24028300E+00, 0.34306300E+00, -.73542600E+00, 0.86643300E-01, -.14407400E+00, 0.32021500E-01, 0.48759900E+00, 0.32147100E-01, -.24168600E+00, 0.16944400E-03, -.19161100E+00, -.62357500E-02, -.13326400E+00, 0.85870300E-01, 0.15006600E+00, -.33203600E+00, -.58201800E+00, -.12389600E+00, 0.32316700E+00, 0.23589600E+00, 0.15361100E-02, 0.31348900E+00, 0.41980600E+00, 0.24986000E+00, 0.47821700E-02, 0.19649200E-01, -.70071500E-02, -.17891600E-01, -.47603400E+00, 0.61464600E+00, -.68719000E-01, 0.71009200E-04, -.17739300E+00, 0.35944900E+00, -.11463200E+01, -.15456200E+00, -.68154100E+00, 0.34178800E+00, -.25361400E+00, 0.58574700E-01, 0.18408500E+00, -.13426400E+00, 0.14195100E-01, 0.20432300E+00, 0.10563200E+01, 0.23388700E+00, -.22556800E+00, 0.62271100E+00, 0.22966500E+00, 0.72219400E+00, 0.33433500E-01, 0.47243200E-01, -.21977900E-01, 0.16499300E+00, 0.10242000E+00, 0.28896500E+00, -.28232300E+00, -.32809400E+00, 0.45770400E-01, 0.11665300E+00, 0.41899900E+00, -.41126200E+00, 0.57791100E-01, -.16761800E+00, 0.15606600E-02, -.32890400E+00, 0.51183400E+00, -.47197400E+00, 0.15237600E+00, -.41247100E-01, 0.21155300E-01, 0.72886100E+00, -.27746500E+00, -.11599900E+01, 0.28923100E+01, 0.11397300E-02, -.10388300E+00, -.75462800E-01, 0.10050500E+01, -.21459100E+00, -.95457800E-01, -.52536200E+00, 0.14766400E+00, -.20030900E+00, 0.10302700E+00, -.84023300E+00, -.11847700E-02, -.25356000E+00, 0.53276700E+00, 0.79110000E-01, -.45543700E-01, -.17899100E+00, -.16664500E+00, 0.15667800E+00, 0.43262400E-01, 0.49804200E+00, 0.56391600E-01, 0.90616800E-02, 0.17794700E+00, -.25352200E+00, 0.29251300E+00, -.15060200E-01, -.29306400E+00, -.32882400E+00, 0.22898700E-01, 0.16479200E+00, -.76377000E-01, 0.15093600E+01, -.45499400E-01, -.30578700E+00, 0.28132500E+00, -.23185500E+00, 0.11632800E+00, -.33660800E+00, 0.51071400E-01, 0.62479900E+00, -.46775600E-01, 0.22954600E-01, -.45508000E-01, 0.10231300E-01, -.40497600E-01, -.89080100E-02, 0.16673300E+00, 0.34651000E+00, -.64692100E-01, 0.10532000E+00, -.44538700E-01, 0.58677100E-01, -.34138800E-01, -.30039500E-01, 0.70727800E-03, 0.41955400E+00, -.69784700E-01, -.94491500E-01, -.25629900E-01, 0.50263100E-02, -.57782300E-01, 0.26071600E-01, -.51655200E-01, -.55741800E-01, 0.84487400E-01, 0.18466200E-02, 0.28874200E+00, -.23159600E+00, -.81447700E+00, 0.33423700E+00, -.44832100E+00, -.33492200E+00, 0.14932300E-01, 0.22252000E+00, -.16504900E+00, 0.88934500E-01, 0.10555400E-01, -.55328900E+00, -.94513100E-02, -.14954600E-01, 0.80860400E+02, -.45211000E+02, 0.13558500E+02, 0.41648100E+02, -.56252000E+02, 0.25862600E+02, -.12856400E+02, 0.28281500E+02, -.31216400E+02, -.12561700E+02, 0.58616000E+02, 0.23914400E+01, 0.96098800E+00, -.10796800E+02, -.48045000E+00, 0.70888400E+00, -.20379600E+00, 0.30696600E+02, -.33292700E+00, 0.42435000E+02, 0.23992800E+02, -.16487400E+02, 0.22011000E+02, -.39575000E+02, 0.18173800E+02, -.48500500E+01, -.32041500E+03, 0.15915800E+03, -.47747600E+02, 0.16040700E+03, 0.15225700E+02, -.54174800E+02, 0.10795400E+03, -.31661800E+02, 0.16656700E+03, -.60281000E+02, 0.14936600E+03, 0.28244700E+02, -.14414200E+02, -.49846000E+01, -.14114600E+02, 0.14071400E+02, 0.22765800E+02, -.43996000E+02, -.67874900E-01, -.15894000E+02, 0.10333000E+02, -.23880300E+02, -.12431500E+01, 0.52134800E+01, -.12363400E+01, 0.87953600E+01, -.87175000E+00, 0.57649100E+01, -.46741900E+01, -.12556000E+01, 0.36338400E+01, -.28375700E+01, -.44782700E+01, 0.98549600E+00, -.17902300E+01, 0.26829800E+01, -.54803700E+00, 0.65214500E+00, -.38657800E+01, 0.15871900E+01, -.15897800E+01, -.60936000E+01, -.74934800E+01, -.11490900E+02, 0.36103600E+01, -.24801400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14274500E+01, 0.20739900E+00, 0.81600500E+00, -.10035500E+01, -.80263500E+00, 0.59024000E+00, 0.98269900E-01, -.91653000E+00, 0.10030200E+00, 0.49656200E+00, 0.36982800E+00, -.23671400E+00, -.54477500E+00, 0.34517900E-01, -.83147400E-01, 0.16914300E-01, 0.84777200E-01, -.64498800E+00, 0.17287000E+00, -.32098800E+00, 0.16078100E+00, 0.26414300E+00, 0.35227000E-01, 0.46267400E-01, -.22230700E-01, -.25920700E+00, -.56513000E-01, -.73040000E-01, 0.46226500E-01, -.13546200E+01, 0.13092300E+00, 0.17554300E+00, -.15123600E+00, 0.11216400E+00, 0.86077700E-01, 0.10141200E+00, 0.45418700E-02, 0.24711300E+00, -.11012800E+00, -.21384100E+00, -.49432800E+00, -.68008100E+00, 0.36958500E+00, -.22401500E+00, 0.10013200E+01, -.52246600E+00, -.35199200E+00, -.11940600E+00, 0.85181500E-01, -.57899000E+00, 0.11609800E+01, 0.24790300E+00, 0.12797600E+00, -.19357200E+00, -.34691500E+00, 0.15259500E+00, 0.42331800E-01, -.96953200E+00, 0.29970200E-02, -.25541900E+00, 0.30077500E-01, -.74088900E+00, 0.18490400E+00, 0.14599100E+00, -.31397000E+00, 0.86253200E-01, 0.25783400E+00, 0.90278800E+00, -.41152300E-01, 0.22846000E-02, -.77167800E-01, 0.12588000E+00, 0.26948200E-01, 0.10608600E+00, -.25389800E+00, 0.18191200E-01, 0.15952100E+00, 0.20272200E+00, 0.57475000E-01, -.14535400E+00, -.42460600E-03, -.10030700E+00, -.68366800E-01, -.70092200E+00, -.86676900E-01, 0.17977900E+00, 0.13542600E+00, -.19704000E+00, -.13120700E-01, 0.13334400E+00, 0.47375700E-01, 0.10161400E-01, 0.61582800E+00, 0.12155000E+01, 0.82426800E+00, 0.45423400E+00, -.15715600E+00, -.11918600E+01, 0.28579600E+00, -.12124800E+00, 0.62140300E+00, 0.10978000E-01, 0.75836800E-01, 0.11738500E+00, -.67083100E-02, -.30602500E-01, -.48484300E+00, 0.12147300E+00, -.27322800E-01, -.37421500E-01, -.85038000E-01, -.70169400E-02, -.28478200E-02, 0.50641700E-03, -.98289500E-01, 0.22444800E+00, -.10452800E+00, -.88287600E-02, -.57506900E-02, 0.15365400E+00, 0.17972400E+00, -.41975600E-01, -.94669300E-01, 0.64227100E+00, -.43934200E-03, -.62218700E-01, -.16150100E-01, 0.42747900E+00, -.94245500E-02, -.18048500E-01, 0.12938700E+00, 0.83549000E-01, -.14023800E+00, -.26586400E-01, 0.22594200E+00, 0.21386000E-02, -.62162700E-01, -.48798700E-02, -.41215300E-01, -.32028500E-02, 0.72729800E-01, 0.10791900E+00, -.21347000E-01, 0.56769500E-01, 0.47808800E-01, -.19039100E+00, 0.93104800E-03, -.10999500E+00, 0.12296100E-01, 0.73082600E-01, 0.26344900E-02, 0.70015500E-01, -.20195800E+00, 0.15374900E-01, -.25691900E-02, -.50806000E-02, -.22924000E+00, 0.84841100E-02, -.10448600E+00, -.11530300E+00, -.20186300E-01, -.13110700E+00, 0.37665700E+00, 0.13466000E+00, -.47925600E+00, -.12308400E-01, 0.45032600E-02, -.69489900E-02, -.12161500E-01, 0.20714600E+00, -.92051900E-01, -.38266800E-01, 0.35157900E-01, -.10182100E+00, -.60439100E-01, -.19781400E-01, 0.13086200E-01, -.55337200E-02, 0.30081500E-01, -.56806800E-03, -.11851700E+00, 0.87293000E-01, 0.12905200E+00, -.95189300E-01, 0.26852500E+00, -.50000100E-01, -.28193600E-01, 0.20775700E-01, -.68562000E-02, 0.81829400E-01, -.26332700E-02, -.11623200E+00, -.17645700E+00, 0.62076300E+00, 0.80655200E-01, 0.70667700E+00, 0.44399800E+00, -.45828000E-01, 0.18493800E+00, -.20594000E+00, 0.47622700E-01, -.16487000E-01, 0.38636600E+00, 0.21015100E+00, -.31495000E+00, 0.29457600E+00, 0.49296600E+02, 0.10362800E+02, -.17080200E+02, 0.93733500E+02, -.45891900E+02, -.35270700E+02, -.46944800E+02, 0.17135300E+02, -.97152900E+01, -.11946700E+02, 0.29654400E+02, -.16294300E+02, -.64822400E+01, -.55373200E+02, -.39218200E+02, 0.19249900E+02, 0.14622000E+02, 0.19610300E+02, -.99290500E+01, -.51789600E+00, 0.74182900E+01, -.18161200E+02, 0.22874700E+02, 0.36622100E+01, 0.20854700E+02, 0.55597300E+02, -.26451400E+02, 0.25969400E+02, -.27827800E+02, 0.58154800E+01, 0.13655300E+02, -.31751900E+02, -.32542400E+02, -.67543800E+02, 0.80825700E+01, -.40237100E+02, -.44940200E+02, 0.22538700E+02, 0.59466100E+01, 0.22407500E+02, 0.21531800E+02, 0.63464500E+01, 0.89049500E+01, -.23946000E+01, 0.76212600E+00, 0.10321000E+02, 0.23288100E+02, 0.79506000E+00, 0.30286800E+00, 0.12292000E+01, 0.15615400E+00, -.11279900E+01, -.75504300E-02, 0.29874000E+00, -.82374700E+00, -.18940200E+01, -.88394600E+00, -.65346200E-01, 0.12283900E+00, 0.56887900E+01, -.51228300E+01, -.84573000E+00, -.25449200E+00, 0.44731800E+01, -.25141100E-01, 0.57854600E+01, 0.52184000E+00, 0.26293900E+01, 0.63257700E+01, -.31173900E+01, -.31020400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.82411500E+01, -.22234700E+01, 0.45140700E+01, -.60377800E+00, 0.50004500E+01, 0.37628500E+00, -.10596000E+01, 0.19378600E+01, 0.25372100E+00, -.54902600E+00, 0.21690500E+01, 0.18293700E+01, -.34856700E+01, -.16844800E+01, 0.14713900E+01, -.51036800E+00, 0.49134100E+00, -.31906500E+00, -.27421500E+00, -.10131500E+00, 0.18836100E+00, -.26907900E+01, -.60510700E+01, 0.20447300E+01, -.41884500E+00, 0.72424900E+00, 0.74548000E+00, -.88608800E-01, -.91031200E+00, -.22254000E+01, -.42755100E+00, 0.54345200E+00, -.20289300E+01, -.33875900E+00, -.59971400E+00, 0.57221100E-01, -.30388100E-01, -.13134200E+01, 0.22397500E+00, 0.76125900E+00, 0.11904200E+01, 0.84236500E+00, 0.12951700E+01, 0.86047900E+00, -.75859600E+00, -.14239400E+01, 0.23295100E+00, -.37711400E+00, -.20380000E+00, 0.31254000E+00, 0.14145300E+01, -.37583100E-01, -.49530900E-02, 0.16548300E+00, -.42831200E-01, -.98434700E-01, -.13852700E+00, 0.27516500E+01, 0.48093000E-02, 0.20085400E+01, 0.25982200E+00, 0.59444500E+00, 0.10467100E+00, 0.64144300E+00, -.19026500E+01, -.89665300E-01, 0.50717300E+00, -.13547500E+01, -.21110800E+00, 0.40028400E-02, 0.12063200E+01, 0.95454000E-01, 0.67481400E-02, 0.95911100E-01, 0.23043300E-01, 0.15770800E+00, -.23803100E+00, 0.10463800E+01, -.88109200E+00, -.74097000E+00, -.24743600E-02, -.10985800E+01, -.20476900E+00, 0.15951900E+01, 0.41318400E+00, -.73198100E-01, -.88625300E+00, 0.14721400E+01, 0.16530700E-01, -.49021400E+00, -.91072200E+00, -.42368000E-01, 0.92775700E+00, -.24057300E+01, -.10482900E+01, 0.10188700E+00, -.75407400E+00, 0.37358300E+00, -.98053200E+00, 0.88886000E+00, -.83862700E-01, 0.22122100E+00, -.29081300E+00, 0.56887400E+00, 0.10214700E+01, -.14846200E+01, 0.15456500E+00, 0.12720200E+01, 0.14856900E+01, -.11201700E+01, -.11727500E+01, -.27466700E+00, 0.10048700E+00, -.42050700E-01, 0.17053600E+01, -.17332300E+00, 0.83935400E+00, -.24313200E+00, -.17405200E+00, 0.22497700E+01, -.14174900E+01, -.23315500E+01, -.29635300E+00, -.48874700E+01, 0.30766500E-02, -.36326900E-01, 0.91699900E-01, -.18476400E+01, -.37623200E+00, 0.11835800E+00, -.22518500E+00, 0.13215400E-01, 0.18381800E+00, -.19816300E+00, -.61185000E+00, -.14080100E-01, -.71487700E-01, -.13335300E+01, 0.23701500E+00, -.91453900E-01, -.46976600E+00, -.22591400E+00, 0.59179300E+00, -.70037200E+00, 0.38621600E+00, -.10592200E+01, -.39309100E-01, 0.31424200E+00, -.81239800E+00, -.90630400E+00, 0.62603300E-01, -.14254900E+00, 0.55937700E+00, 0.39232500E+00, 0.15644500E+00, 0.14390200E+00, -.24533500E+01, 0.85848500E-01, 0.70334600E+00, 0.56454800E+00, -.80888300E-01, 0.26488700E+00, -.27800700E+01, -.45163700E+00, -.20286200E+01, 0.10456100E+00, -.24878900E+00, -.17303100E+00, -.40659700E-01, 0.10832200E+00, 0.62505400E+00, 0.63281100E+00, 0.12693300E+01, -.48529400E+00, -.87788500E+00, -.45440400E-01, -.37562500E+00, -.72531200E-01, -.45761900E+00, 0.32448400E-03, 0.16251800E+00, 0.13159400E+01, -.10637000E+00, 0.18912700E-01, 0.10315400E+01, 0.55843700E+00, -.34740400E+00, 0.40760900E-01, -.37025200E+00, -.51095300E+00, 0.67676700E-02, 0.33783400E+00, 0.58963100E+00, -.35804200E+00, 0.87671000E+00, 0.23592400E+01, -.63259200E+00, 0.39647400E+00, -.75171100E+00, 0.10414900E+00, -.12712100E+01, -.76068100E-01, 0.18687200E+01, -.14199700E+00, 0.95928000E+00, -.56694900E+00, -.67464200E+00, 0.82892600E+02, -.13070300E+03, -.34074000E+03, 0.18395100E+03, 0.94134900E+02, 0.17017300E+03, 0.13536600E+03, 0.21635300E+02, -.23737100E+02, -.68351100E+02, 0.85887800E+02, 0.30408600E+02, 0.17155700E+03, 0.15458300E+03, -.78147900E+02, -.12082900E+03, -.77333500E+02, -.55274300E+02, -.11306200E+03, 0.66094600E+02, 0.10012500E+03, 0.24008100E+02, -.11374800E+03, -.18366900E+03, 0.22335400E+03, -.11161700E+03, 0.66131400E+02, -.11192800E+03, 0.80183200E+02, -.22922300E+02, -.32005200E+02, 0.14187200E+03, -.74133600E+02, -.49625000E+02, -.91889200E+02, 0.18366400E+03, -.90730900E+02, -.10442000E+03, -.91778300E+02, -.11330300E+03, -.87429900E+02, 0.52402400E+02, -.83846200E+01, 0.46801800E+02, -.12818900E+03, -.38290700E+02, -.44445400E+01, -.10239900E+02, 0.94940100E+00, -.23211400E+02, -.29984200E+00, -.11629900E+02, 0.92706200E+01, 0.92338700E+00, -.56342200E+01, 0.20445000E+01, 0.18883000E+02, 0.13128300E+00, -.15449400E+02, 0.10800200E+02, -.16526000E+01, 0.18897600E+01, -.71303100E+01, 0.19557400E+01, -.16081600E+02, -.11614400E+02, -.20355300E+02, 0.12954500E+02, -.45769800E+01, 0.39104800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.47444100E+01, 0.12635600E+01, 0.24441500E+01, -.36904900E+01, -.36056000E+01, 0.42423000E+00, 0.57661900E+00, -.29765300E+01, 0.32038800E+00, 0.52908400E+00, 0.30683000E+00, 0.33037300E+00, -.18347700E+01, -.24590700E+01, -.41146900E-01, 0.29078200E+00, -.54631900E+00, -.13490800E+01, 0.10025500E-01, -.77644800E-01, -.30712300E+00, 0.14080500E+01, 0.26224200E+01, -.11394300E+01, -.13810400E+00, -.22345400E+00, -.89875800E-01, -.56508300E+00, 0.12326500E+00, 0.23883800E+01, -.45039200E+00, -.44813700E+00, 0.13901700E+01, -.49838400E+00, 0.11649700E+00, -.12314700E+01, -.34222800E-01, 0.11772200E+00, 0.81709900E+00, -.46669200E+00, -.42930500E+00, -.24529800E+00, -.86542300E+00, -.11448300E+00, -.66545500E-01, -.38712100E+00, -.47360500E+00, -.54324000E+00, -.44605200E+00, -.57556500E+00, 0.17036200E+01, 0.86135400E+00, 0.32301600E+00, -.28752600E+00, 0.18079200E+00, 0.59862400E+00, 0.14379100E+00, 0.33875000E+00, -.30547200E-02, -.95014300E+00, -.88731500E-01, -.79585400E+00, 0.22683500E+00, -.16016300E+00, 0.96337600E+00, -.10011800E+00, -.45570600E+00, -.37315700E+00, -.19461900E+00, -.68199500E-02, 0.54564100E+00, -.45475600E+00, -.31758500E+00, 0.41146600E-01, 0.22965100E+00, 0.11573400E+00, 0.42721300E+00, -.18303400E-02, 0.39112600E+00, -.24747700E+00, -.40775800E-03, -.11133000E+01, 0.44218600E+00, -.79385800E+00, -.17187100E-01, -.42728200E+00, -.68644100E+00, 0.54092500E-01, -.33786300E+00, -.24869400E+00, 0.45049000E+00, -.54710500E-02, -.34987000E+00, -.52968700E+00, -.94148200E+00, -.16060200E+00, -.42030100E-01, -.67112200E+00, -.51383400E+00, 0.69180600E-01, -.30039700E+00, -.22936800E-01, -.83602900E-01, -.11984700E+00, -.66809300E+00, 0.29684300E+00, -.52295600E-01, -.61167400E+00, -.52940600E+00, 0.55093800E+00, -.10840200E+00, 0.37290600E-01, -.29784000E-01, 0.64085600E-02, -.17941200E+00, -.12536600E+00, -.17883500E+00, -.40010900E+00, 0.63844300E-03, 0.37691800E+00, 0.33337500E+00, 0.36338900E+00, 0.97378400E+00, -.20833000E+01, -.16412400E-02, 0.50151900E+00, 0.19064600E+00, -.64208000E-01, -.25228700E+00, 0.34471600E-01, 0.38584600E+00, -.31098800E-01, -.23121000E+00, 0.23046200E-01, -.77827200E+00, -.42706000E-02, -.33488300E+00, 0.17250700E+00, 0.11467000E+00, 0.59890500E-01, 0.22913900E+00, -.24390000E+00, -.11614300E+00, -.16460800E+00, -.48018500E+00, -.22362700E+00, -.61891200E-01, -.25399600E+00, 0.16772200E+00, -.78715000E+00, 0.58105900E-01, -.14358300E+00, 0.10997700E+01, 0.25556400E+00, -.28347700E+00, 0.18580000E-01, 0.27795400E+01, -.65540000E-01, -.10032400E+01, -.16472000E+00, -.41340700E+00, 0.51600900E+00, 0.81479800E-01, 0.95391700E-01, -.99372200E+00, 0.49844300E-01, -.55231500E-01, -.76444900E-01, 0.22121200E-01, -.14213100E+00, -.24918800E+00, -.55797700E+00, -.67451600E+00, -.23140600E+00, -.73579300E+00, -.96646500E-01, 0.44596100E+00, 0.63470900E-01, -.17012400E+00, 0.13048100E-02, -.19045000E+00, 0.74731900E+00, 0.52632400E-01, 0.10256300E+00, -.16936400E+00, 0.44731900E+00, -.16110800E+00, 0.84278200E-01, -.17079800E+00, 0.10417500E-01, 0.21929800E-02, -.80652500E+00, 0.41755000E+00, 0.23116100E+01, -.37210600E+00, 0.45030600E+00, 0.49886900E+00, 0.21637900E-01, -.11086100E+00, -.32370100E+00, -.21997000E+00, -.40453500E-01, 0.19401700E+01, -.38293700E-01, -.45424800E+00, -.12751200E+01, 0.14148000E+01, 0.59569900E+00, 0.15121300E+03, 0.27811800E+03, -.14757400E+03, -.13956600E+03, -.13896300E+03, 0.17953400E+02, 0.10739100E+01, 0.62797600E+01, 0.12625500E+03, -.68058700E+02, -.81780700E+01, -.12775800E+03, -.13914800E+03, 0.69912200E+02, -.27504600E+02, 0.69580500E+02, 0.28598200E+02, 0.46250600E+02, 0.88924200E+01, -.73086200E+01, 0.81804100E+02, 0.47374800E+02, 0.13616900E+03, 0.33131500E+03, -.16412600E+03, -.17805800E+02, -.16560800E+03, -.78008000E+02, 0.79209000E+02, -.10269700E+03, 0.57478200E+01, -.13324600E+03, 0.65541300E+02, -.12853200E+03, -.55044900E+02, 0.26701700E+02, -.11124100E+02, 0.27559900E+02, 0.12788600E+02, 0.41012900E+02, -.55214200E+02, -.67518300E+02, 0.89939300E+01, 0.29606800E+02, 0.28326800E+02, 0.40539500E+01, -.26431300E+01, -.19538800E+01, -.52227200E+01, 0.11185500E+01, -.26916500E+01, 0.25911100E+01, 0.60629700E+00, -.11442200E-01, 0.61542300E+01, -.34978000E+02, -.18415100E+01, -.10263800E+02, 0.10901200E+02, 0.32026800E+01, -.24476400E+01, -.17071300E+02, -.24900700E+01, -.11796700E+02, 0.72391300E+01, -.25222000E+02, 0.68506200E+01, 0.91019300E+01, 0.29281900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.62362600E+01, 0.12418200E+01, -.29543500E+00, 0.48664700E+00, -.34848000E+01, 0.23881800E+00, 0.83023000E+00, -.52930900E+00, -.41540500E+00, 0.97611500E+00, 0.10009800E+01, 0.35632400E+00, 0.22786200E+01, 0.10377600E+01, -.46807500E+00, -.60035700E-02, -.95001000E-01, -.55548800E-01, 0.28503300E+00, -.13880600E-01, -.21509800E+00, 0.77939400E+00, 0.24742600E+01, -.57914000E+00, 0.11860100E+00, -.33898300E+00, 0.64953600E-02, 0.55080900E+00, 0.13055000E+01, 0.60780100E+00, 0.45708600E+00, -.10012500E+00, -.19900900E+00, -.51260700E+00, 0.17818700E+00, -.33117900E-02, 0.51245700E-01, 0.57831100E-01, 0.63938500E+00, 0.17783400E+00, -.14526600E+01, -.33965900E+01, -.20048100E+00, -.42752100E+00, 0.10365100E+01, -.61505700E+00, -.29301500E+00, 0.32304900E+00, -.86244900E+00, -.28226300E+01, 0.60531200E+00, 0.13942300E+01, 0.27379700E+00, 0.27868800E+00, -.39284900E+00, -.81332600E+00, -.29798900E+00, 0.35713200E+00, -.23772000E-02, 0.67571500E+00, 0.59641000E+00, 0.67757500E-01, 0.62008700E-01, -.42823200E+00, 0.11535800E+01, 0.84563800E+00, -.61739100E+00, 0.15687000E+01, -.92804600E+00, -.56600700E-02, -.86801300E-02, -.25397500E-01, 0.54181000E+00, -.16413900E+00, 0.87461000E+00, 0.42642400E-01, -.40324000E+00, 0.33971700E+00, -.44782700E+00, 0.51422400E+00, 0.10947700E-02, 0.44304300E+00, -.40934200E+00, 0.83103900E+00, 0.32446100E+00, 0.85988600E+00, -.28447300E-01, 0.35076800E+00, -.18232500E-01, -.71315800E-01, -.25881600E-01, 0.56375800E-01, -.64616000E+00, -.31843300E+01, 0.16482900E+01, 0.75863100E+00, -.34517400E+00, -.40044500E+01, 0.67036300E-01, 0.98650900E+00, -.10756400E+01, -.13760200E+00, 0.34240900E-01, -.20001300E+00, 0.37262100E+00, 0.51298900E+00, -.22283300E+00, -.73331900E+00, -.54823400E-01, 0.28228000E-02, 0.99701400E+00, 0.10791000E+00, 0.14063500E+00, -.24938200E-02, -.26710800E+00, -.10262100E+01, 0.23229400E+00, 0.16939900E+00, -.23590100E+00, 0.34465900E+00, 0.93071800E+00, -.93701200E+00, -.24942600E+01, 0.37766800E+01, 0.43885800E-02, -.26838800E+00, 0.51551300E-01, 0.10443400E+01, -.46793500E+00, -.16437900E+00, -.19130600E+00, -.27541300E+00, -.17543500E+00, 0.91405900E-01, -.17950800E+01, -.52230400E-02, -.65001700E+00, 0.70681400E+00, 0.13564300E+00, -.76558600E-01, -.68218400E+00, -.36301800E+00, 0.51261500E+00, -.43655600E-01, 0.30947400E+00, 0.99510200E-01, -.27704400E-01, -.32167600E+00, -.52172400E+00, 0.12101900E+01, -.12226400E+00, 0.14910500E+00, -.65583700E+00, -.24488400E+00, -.14720800E+00, -.38171300E-01, -.28081800E+01, -.49463000E-01, 0.16023000E+01, -.58884900E+00, 0.21495300E+00, -.34861200E+00, 0.22065800E+01, 0.10110300E+00, 0.14164300E+01, -.26689900E+00, -.13454200E-01, -.10160000E+00, 0.76221600E-01, -.22687200E-01, -.52931900E+00, 0.72247500E+00, 0.46396600E+00, -.17190800E+00, 0.28816900E-01, -.60976100E-01, -.24097800E+00, -.60106500E-01, -.12086400E+00, 0.38276200E-03, -.56622900E+00, 0.27608400E+00, -.46502800E-01, 0.14543000E+00, -.73421100E+00, -.14403000E+01, 0.47702700E-01, 0.15929400E+00, 0.23014600E+00, -.15620300E+00, 0.16865500E-03, 0.60960700E+00, 0.12434700E+00, -.29202600E+01, 0.77648000E+00, -.29420900E+00, -.26957000E+00, -.24757700E+00, 0.20526000E-01, -.15730200E+00, 0.32672200E+00, 0.33616800E-01, -.11606100E+01, 0.24640900E+00, 0.55084800E+00, 0.21936100E+01, 0.60832800E+00, -.49085900E+00, -.90980800E+00, -.39391000E+03, 0.20134900E+03, 0.16169200E+03, 0.19670600E+03, 0.47462600E+02, 0.60390200E+02, 0.21180100E+02, -.57103300E+02, 0.89884200E+02, 0.46536900E+02, 0.22320200E+03, -.80554700E+02, 0.40695000E+02, -.58646300E+02, 0.40225300E+02, 0.14317200E+02, -.75533700E+02, 0.72004100E+02, 0.35616000E+02, 0.10471800E+03, -.73666100E+02, 0.36812300E+02, 0.54237800E+03, -.27111500E+03, -.10094700E+03, -.27154300E+03, -.50903400E+02, 0.75362000E+02, -.12281600E+03, 0.12119700E+03, -.16723500E+03, 0.49743200E+02, -.20257000E+03, 0.16132300E+03, -.79097400E+02, -.95351500E+02, -.80595800E+02, -.10778200E+03, -.56200300E+02, 0.10687800E+02, -.55238700E+02, 0.59965900E+02, -.84318100E+02, -.39932200E+02, -.11177500E+01, -.17787300E+02, -.30571100E+01, -.33229900E+02, 0.47215100E+01, -.14005400E+02, 0.17445100E+02, 0.48455500E+01, -.58034300E+00, 0.98624100E+01, -.26562800E+01, -.14225800E+01, -.32939800E+02, 0.27406300E+02, 0.54290000E+01, 0.84500200E-01, -.25801700E+02, -.18537300E+01, -.35107000E+02, 0.52358800E+01, -.26176300E+02, 0.13689800E+02, 0.40159800E+01, 0.37252000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16834300E+02, -.41854800E+00, 0.48594300E+01, -.10941200E+02, -.14213800E+02, -.50487800E+01, 0.34607400E+01, -.29109200E+01, 0.16217400E+00, 0.68838700E-02, -.92365500E+01, -.42326600E+01, -.14182300E+01, -.72878200E+01, 0.17380900E+01, 0.15786800E+01, -.34786300E+01, 0.49105900E+00, 0.71551500E+00, -.21467800E+01, 0.44203200E+00, 0.64497100E+01, -.74875700E+01, 0.29274600E+01, -.10954700E+00, -.20124600E+01, -.34161200E+00, -.90159200E+00, -.22778200E+01, 0.31648400E+01, -.97079000E+00, -.17698900E+01, 0.27630500E+01, -.81264400E+00, 0.51356800E+00, -.41876500E+01, 0.16717000E+00, -.17559000E+01, 0.32041500E+00, 0.14072200E+00, -.56979500E+00, 0.55268100E+00, -.38235500E+01, 0.15610000E+01, 0.18220000E+01, -.49539300E+01, 0.11342600E+00, 0.37684000E-02, -.13845400E+01, -.24646400E+01, 0.73493200E+00, -.15939500E+00, 0.74858500E-01, -.86531300E+00, 0.58416100E+00, -.70466900E+00, -.76846400E-02, -.21621100E+01, 0.53227300E-02, -.88152600E+00, 0.68199300E+00, -.12247300E+00, -.15923000E+00, 0.30654700E+00, 0.13640200E+01, 0.13528300E+01, -.95115500E+00, -.15424300E+00, 0.70365900E+00, 0.11218300E-01, -.21815700E+01, 0.75188900E+00, 0.12822700E+01, 0.79802400E-03, 0.19348600E+01, -.21723300E+00, 0.34133100E+00, -.44007000E+00, 0.36082900E+01, -.31488800E+00, 0.46775400E-02, -.26563300E+01, 0.38870900E+01, -.28717600E+01, 0.48016200E+00, -.52836900E-02, 0.11554100E+00, -.42272200E+00, -.49681900E+00, -.17138200E+01, 0.76049400E+00, -.24160100E+00, 0.39632200E+01, -.18175500E+01, -.14501800E+01, -.30316600E+01, 0.47642600E+00, -.12114000E+02, -.28317500E+01, 0.25249500E+01, 0.35809500E+01, 0.12396700E+01, -.39878900E+00, 0.18328400E+00, 0.21959400E+01, 0.22498900E+01, 0.38168100E+01, 0.53855000E+00, 0.37146800E+01, -.24935800E+00, 0.19330700E+01, -.16113100E+00, 0.57271800E+00, -.13375600E-01, 0.59852700E+00, -.77676600E+00, -.39895500E+00, 0.72449700E+00, -.74141300E+00, 0.65085300E+01, 0.25743000E+01, -.52693300E+00, -.27400200E+01, 0.69152800E+01, 0.47947800E-02, 0.23365000E+01, -.16295900E+01, -.45393900E+01, 0.15535400E-01, -.31710200E+00, 0.15188700E+01, -.10637000E-01, -.47022500E+00, -.58825600E+00, 0.14873200E+01, -.13101200E-01, 0.15775200E+01, -.90179000E+00, -.22004000E+00, 0.25172300E+00, -.60529300E+00, 0.98736600E+00, 0.13319800E+01, -.73719400E+00, 0.66892300E+00, -.43218500E+00, 0.10961100E-01, 0.13404500E+01, -.19409200E+01, -.67986800E-01, 0.14592200E+00, 0.85819900E+00, -.18847400E+01, 0.24417600E+00, 0.74879400E+00, 0.43283100E-01, 0.18169800E+00, 0.18975900E+00, -.79446600E+01, 0.23990800E+00, 0.77205100E+00, -.84177500E+00, 0.89273200E+00, 0.12777800E+01, -.23241000E+01, -.11054100E+01, 0.62100200E+00, -.51524300E+00, -.58278000E-01, -.75613400E+00, 0.15074600E+00, 0.18241500E+01, -.13857800E+01, -.70765400E+00, 0.40984600E+00, -.23757400E+00, 0.33654600E+00, 0.14507700E-01, 0.43437100E+00, 0.17131700E-01, -.25930400E-01, -.47289600E+00, 0.44485400E+00, 0.91910400E+00, 0.79252700E-01, -.95611600E+00, -.34496600E+00, 0.35275400E-01, 0.59692800E+00, -.23104000E+00, 0.11535000E-01, 0.17267800E+01, -.36639200E+00, -.23435700E+01, 0.95952400E+00, 0.18422800E+01, -.96561800E+00, -.35314400E-01, -.76739100E+00, -.42065100E+01, -.64130200E+00, 0.26727000E+00, -.13741000E+00, 0.12482300E+01, -.18669300E+01, 0.60309400E+01, 0.16974400E+01, 0.99697100E+00, -.13558700E+01, -.41136700E+00, -.12719100E+03, 0.18570200E+03, 0.40034800E+00, 0.35346400E+03, 0.94218500E+02, 0.68980800E+02, 0.28081000E+03, -.45540900E+02, 0.85043800E+02, 0.17302400E+03, -.19068400E+03, 0.89401000E+02, -.25348700E+03, 0.95177200E+02, 0.28845700E+02, -.69392600E+00, 0.19697600E+03, -.67695200E+02, 0.16996400E+03, 0.29462700E+02, 0.18868600E+03, 0.15853100E+04, -.76909900E+03, -.11143500E+03, -.79335900E+03, 0.12337100E+02, 0.42375100E+03, -.48972500E+03, 0.11764100E+03, -.46351600E+03, 0.34612600E+03, -.59494900E+03, 0.96765200E+02, -.56883200E+02, -.22086100E+03, -.47320600E+02, -.49204100E+02, 0.94121100E+02, -.12724700E+03, -.24834900E+03, 0.11154600E+03, -.10447000E+02, 0.13427100E+03, 0.25032100E+02, -.23841600E+02, -.76005500E+01, -.56130800E+02, 0.24928100E+02, -.33807700E+02, 0.33269600E+02, 0.23568100E+02, 0.61810800E+01, 0.30755700E+02, -.87765000E+02, -.21493900E+02, -.43385500E+02, 0.41306500E+02, 0.20140400E+02, -.19891000E+02, -.69033800E+02, -.18789500E+02, -.49639300E+02, 0.37784700E+02, -.11395400E+03, 0.23912400E+02, 0.92622600E+02, 0.36352800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16959900E+02, 0.40922000E+01, 0.27322200E+01, -.11091500E+02, -.92142000E+01, 0.67490600E+00, 0.17717200E+01, 0.40209500E+00, -.13541800E+01, 0.42957400E+00, -.60511200E+01, -.18811000E+01, 0.10819400E+02, -.31081100E+01, 0.94327400E+00, 0.11582900E+01, -.36125700E+01, 0.44726900E+01, 0.21430400E+01, -.39122200E+01, 0.70102400E+00, 0.88384500E+01, -.80059300E+01, 0.46779900E+01, 0.57628700E-01, -.44789400E+01, -.27353700E+00, -.59586100E+00, -.20864800E+01, 0.40631800E+00, 0.11424100E+01, -.13779400E+01, 0.29186900E+01, -.75685400E+00, 0.36928100E+00, -.27725100E+01, 0.26516200E+00, -.26572200E+01, 0.57221600E+00, 0.53743800E-01, -.77802400E+00, 0.46529800E+00, -.48099600E+01, 0.12177900E+01, 0.72935200E-01, -.28219000E+01, 0.23778900E+00, 0.99311600E+00, -.11947700E+01, -.27167400E+01, -.42433300E-01, -.14524300E+00, 0.16099100E+00, -.26623800E+00, 0.84472100E+00, -.68792100E+00, -.27103300E+00, -.44120700E+00, 0.23432100E-02, -.22311700E+00, 0.11060500E+01, 0.89210000E+00, -.20869600E+00, 0.21243200E-01, 0.26117200E+01, 0.17567900E+01, -.91728300E+00, -.75605600E+00, 0.21649400E+00, 0.84347200E-02, -.92817200E+00, 0.58375400E+00, 0.10624800E+01, 0.17533400E+00, 0.16304300E+01, -.16990500E+00, 0.29352300E+00, -.88725900E+00, 0.92235500E+00, 0.46274100E+00, 0.10115900E-02, -.42333000E+00, 0.75842800E+00, -.36701400E+00, 0.28541100E+00, -.27038800E+00, 0.16112800E+00, 0.30944300E+00, -.14355400E+00, 0.39982200E-01, -.93255500E-01, -.60240200E+00, 0.25030500E+01, -.36103800E+01, 0.29113500E+01, -.96177600E+00, -.31299000E+00, -.49680800E+01, 0.90857400E+00, 0.26832900E+01, -.48417500E+00, 0.12890900E+00, 0.42882700E+00, 0.10237700E+01, 0.18544700E+01, 0.87270000E-01, 0.25915100E+01, 0.84614400E+00, 0.36157600E+01, -.38296700E+00, 0.20016100E+01, -.28889400E+00, -.15194300E+00, 0.56126400E+00, 0.84695900E+00, 0.11000300E+01, 0.17400300E+00, 0.18671800E+01, -.44119300E+00, 0.33166800E+00, 0.58387100E+00, -.63271700E+00, -.82243200E+00, 0.69008400E+01, -.22461300E+00, -.87707300E+00, -.16837000E+00, 0.37598200E+01, 0.15520200E+01, 0.33091000E+00, 0.22682000E+01, 0.56456500E+00, 0.42112100E+00, -.29102600E-01, 0.10725800E+01, 0.13387600E+00, 0.18946800E+01, -.27096200E+01, -.40623300E+00, 0.15752600E+00, -.10859400E+00, 0.50111100E+00, 0.45024000E+00, 0.90989700E+00, 0.10576400E+01, -.35558100E+00, 0.17466200E+00, -.30636900E+00, -.42859100E+00, 0.42079400E+00, -.16247200E+00, 0.52774800E+00, -.66374500E+00, -.64620500E-01, 0.81550600E+00, -.14521900E-01, -.74652600E+01, -.85997500E+00, 0.26167800E+01, 0.49830300E+00, 0.97075300E+00, -.17922700E+01, -.32821700E+01, -.58883300E+00, -.32377000E+01, 0.46066700E+00, 0.39245400E+00, -.83126700E+00, -.12972000E+01, 0.43535800E+00, 0.11438000E+01, -.16519400E+01, -.43091000E+00, -.13823900E+01, -.12984900E+01, -.11241400E+01, -.31707700E+00, 0.26863700E-01, -.76632400E-01, -.50124200E+00, 0.22123100E+01, -.27039400E+01, -.25730900E+01, 0.20701000E+01, 0.34519200E+01, 0.68805400E+00, -.20922500E+00, -.12219200E+01, -.17144700E+00, -.21180600E+01, 0.12142100E+00, -.22331700E+01, 0.28704100E+01, -.54222500E+01, 0.26080900E+01, -.59219100E+01, -.34734000E+01, 0.13872100E+00, -.16964300E+01, 0.17073300E+01, -.19411700E+01, -.94353200E+00, 0.50658700E+01, -.11415100E+00, 0.13419500E+01, 0.21545900E+01, -.45478600E+01, 0.11694100E+01, -.30232400E+01, -.23323800E+01, 0.46429300E+00, -.38998100E+03, 0.10248600E+02, 0.34230700E+02, 0.35738600E+02, 0.65611200E+02, 0.64563600E+02, 0.28873800E+01, 0.19284100E+02, 0.39936700E+02, -.23090500E+03, 0.12131400E+03, -.17221700E+03, 0.11492800E+03, 0.12973800E+02, 0.61609800E+02, -.10464800E+03, -.54438700E+02, 0.18119300E+03, 0.60358500E+02, 0.44014200E+03, 0.54114900E+03, -.27596000E+03, -.23985400E+03, -.26856100E+03, -.52946000E+03, -.17424000E+03, -.17550000E+03, 0.25375200E+02, -.20029700E+03, -.14820700E+03, -.57498800E+01, 0.31293500E+02, -.13242700E+02, -.18882000E+03, -.13937500E+02, -.11024200E+03, 0.13969200E+03, -.34597100E+03, -.23777200E+03, 0.56346400E+02, 0.64232700E+02, 0.36390700E+03, 0.93727000E+01, -.32175200E+02, 0.77991000E-01, -.40941200E+02, 0.92766100E+01, -.56587800E+02, 0.13603400E+02, 0.55626300E+01, 0.68727000E+01, 0.10335200E+02, 0.75313900E+02, -.59558200E+01, -.74704800E+02, 0.75714800E+02, 0.14796800E+02, -.32484500E+01, -.75701500E+02, -.80614700E+01, -.80464400E+02, 0.56076500E+01, -.11380600E+03, 0.37432000E+02, -.70112900E+02, 0.59379900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.60465800E+01, -.10303300E+01, -.13489800E+01, 0.54793800E+01, 0.34657700E+01, -.18536300E+00, -.65734600E+00, -.19195400E+01, 0.83301600E+00, 0.14177000E+00, 0.38916600E+01, 0.14398900E+01, -.71970800E+01, 0.90382000E+00, 0.38599400E+00, -.66865000E+00, 0.14022900E+01, -.31101700E+01, -.78908600E+00, 0.20548800E+01, -.21991100E+01, -.76123500E+01, 0.48724600E+01, -.36834200E+01, -.85546900E-01, 0.36910700E+01, 0.51513400E+00, -.34209300E+00, 0.14536600E+01, 0.28827400E+01, -.10141100E+01, 0.67584800E+00, -.81759900E+00, 0.17598300E+00, -.55214600E-01, 0.21990300E+01, -.96798000E-01, 0.74305300E+00, 0.21721800E+00, 0.49406100E-01, 0.36413800E+00, -.51645800E+00, 0.31395200E+01, -.42114900E+00, -.84423100E+00, 0.64037300E+00, -.27424900E+00, -.29541800E+00, 0.30190200E+00, 0.73024900E+00, 0.28021100E+01, 0.15115700E+01, 0.18383900E+00, 0.56997000E+00, -.80991300E+00, -.36330400E+00, 0.14968600E+00, -.39674300E+00, -.41954400E-02, 0.65252400E+00, -.64858700E-01, -.62721900E+00, 0.27041900E+00, 0.44956600E+00, -.13866900E+01, -.54869800E+00, 0.35407200E+00, 0.18421200E+01, 0.87655600E-01, -.11731700E-01, 0.71682400E+00, -.27338900E-01, 0.93380700E+00, -.77451800E-01, -.16928700E+00, -.25561200E+00, -.89837000E+00, -.49127200E+00, -.78560400E+00, 0.33812300E+00, 0.20934200E-02, 0.28156800E+01, -.14541000E+01, -.34719600E+01, -.37695600E+00, 0.24483600E+00, 0.96563500E+00, -.44805000E+00, -.11731000E+00, 0.51630400E+00, 0.13066900E+01, 0.80717400E-01, 0.38049000E+00, 0.17378600E+01, -.15582400E+01, -.32051400E+00, -.19047500E+00, -.57812100E+00, -.97897500E+00, 0.61055500E-01, -.60671000E+00, -.12292800E-01, -.47279300E+00, 0.12411100E+00, -.75898600E+00, 0.10033900E+01, 0.26948900E+00, 0.27691500E+00, -.15097300E+01, -.55175500E+00, 0.16133600E-01, 0.95349400E-01, 0.32386900E+00, -.37294200E-01, -.43044100E+00, -.11127300E+01, 0.32633200E+00, -.94469100E+00, -.21084300E+00, 0.98872500E-01, 0.98305200E+00, -.70910700E+00, 0.18259100E+01, -.65475500E+01, 0.47138900E-01, 0.24284700E+00, 0.20331300E+00, -.34525600E+01, -.57834600E-02, 0.44625700E+00, -.15952800E+00, -.12941700E+00, -.32490400E+00, -.95717800E-01, 0.64551700E+00, -.23998000E-01, 0.25718300E+00, 0.12886700E+01, 0.25121500E+00, 0.16303700E+00, -.10594800E+00, 0.28654500E-01, -.40277300E-01, -.51553100E+00, -.39914500E+00, 0.29709000E+00, 0.12762900E+00, -.58352500E+00, -.46777900E+00, 0.17624700E+00, -.22235100E-01, -.59855900E-01, -.11315500E+00, 0.25566000E+00, -.30948900E-01, -.13876300E+00, 0.57432600E+01, 0.10162200E+00, -.17425500E+01, -.37148400E+00, -.30112800E+00, 0.52874600E+00, 0.89242700E+00, 0.39341300E+00, -.51690700E+00, -.11150800E+00, -.15360700E+00, 0.74886100E-01, 0.57364500E-01, -.40000500E+00, -.19546200E+00, 0.93322200E+00, -.39709000E+00, 0.35219900E+00, 0.25684700E+00, 0.22067300E+00, 0.24627800E+00, 0.11294000E-01, 0.51480600E-01, -.84117500E-02, -.74185400E+00, 0.97743100E+00, 0.81845300E+00, -.39207200E+00, -.85754200E+00, -.45572400E+00, -.22234800E+00, 0.42505900E+00, 0.27399000E+00, 0.48727800E+00, -.16445400E-01, 0.11632000E+01, -.81646100E+00, 0.11314100E+01, -.49313900E+00, 0.25213700E+01, 0.85381400E+00, 0.55835100E-01, 0.16998600E+00, -.29319400E+00, 0.19509400E+00, 0.11906200E+00, -.98921800E+00, 0.25125800E+00, -.11844500E+00, -.32776300E+00, 0.96678400E+00, -.20181300E+00, 0.61116100E+00, 0.49861300E+00, -.56544700E-02, -.20822000E+00, 0.99313300E+01, -.10176900E+03, -.16822900E+02, -.40022200E+01, -.51044800E+02, 0.11932000E+00, -.14653700E+02, -.26787200E+01, -.93929100E+01, 0.57551500E+01, 0.70789000E+02, 0.45641600E+01, 0.23879700E+02, 0.14455500E+02, -.33636800E+02, -.28943100E+01, -.34685200E+02, 0.13121700E+02, -.31338200E+02, -.21032500E+03, 0.10288000E+03, -.15851300E+02, 0.10553500E+03, 0.12209300E+02, -.47955200E+02, 0.71707700E+02, 0.15241000E+01, 0.64697000E+02, -.43444800E+02, 0.72403200E+02, -.19933000E+02, 0.10624900E+02, 0.43659700E+02, 0.10311500E+02, 0.11069800E+02, -.10167300E+02, 0.24920300E+02, 0.43115000E+02, -.18409700E+02, 0.61867700E+01, -.26251600E+02, -.29910500E+01, 0.22836700E+01, 0.52284500E+00, 0.11221500E+02, -.35059000E+01, 0.62762400E+01, -.41773600E+01, -.33795100E+01, 0.18355500E+00, -.59047200E+01, 0.82517300E+01, 0.31804500E+01, 0.14033900E+02, -.13157500E+02, -.25868300E+01, 0.23044600E+01, 0.17774100E+02, 0.22935400E+01, 0.15380700E+02, -.55865200E+01, 0.30976200E+02, -.58139300E+01, -.11054100E+02, -.83582600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.24123600E+01, 0.45481200E+00, 0.26294900E+00, 0.86566900E+00, -.16507800E+01, 0.23874500E+00, 0.34705600E+00, -.41743700E+00, -.31780500E+00, 0.72812000E+00, 0.10129100E+01, 0.10581100E+00, 0.44581200E+00, 0.48547200E+00, -.42862900E+00, 0.36997100E-01, 0.23885200E+00, -.27788500E+00, 0.18063000E+00, -.79604600E+00, 0.94542300E+00, 0.19099200E+01, 0.95519700E+00, 0.12679700E+00, -.66822100E-01, -.95286700E+00, -.44039100E+00, 0.17932400E+00, 0.10212700E+00, -.26030700E+01, 0.27611100E+00, -.33358100E-01, -.11359100E+01, -.26176700E+00, 0.32342500E-02, -.12551400E+00, -.50524300E-01, 0.69765100E+00, 0.11007700E+00, -.11401300E+00, -.16846300E+00, -.95463500E+00, 0.26389900E+01, -.45907600E+00, 0.11844200E+01, -.43481100E+00, -.45991200E+00, -.34760500E+00, -.56949500E-01, 0.19435600E+00, 0.66102300E+00, 0.48312900E+00, 0.68250300E-01, -.46438100E+00, -.74915300E-01, 0.80081800E-01, -.56543600E-01, 0.42220700E+00, -.28833200E-03, -.24543100E-01, -.42448000E-01, 0.14766500E+00, 0.50717200E-02, -.18762200E+00, 0.31734500E+00, -.59692400E-01, -.23343800E+00, -.38463600E-01, -.95554400E-01, 0.17881900E-03, -.28085000E-01, -.15461700E+00, 0.20813000E-01, 0.17347800E-02, -.62186800E-01, 0.25076800E-01, 0.18818900E+00, 0.24728300E+00, -.34535200E-01, -.77928200E-01, -.42393200E-03, -.62071400E+00, -.10808100E+00, 0.12232500E+01, 0.52989100E-01, 0.57623300E+00, -.52231600E-01, 0.27617600E-01, 0.48439400E-01, -.19640800E+00, -.43633800E+00, -.32318000E-01, -.64919500E+00, -.11193000E+01, 0.19195400E-01, -.46558300E+00, -.69120900E-01, -.93515000E-01, -.34716900E+00, -.51936000E-01, -.28533900E-01, -.88239800E-01, -.88411800E-02, -.26577700E+00, 0.34647300E+00, -.78776800E-02, -.58861200E-01, 0.17457900E+00, 0.38555000E-01, -.15557500E+00, -.81760800E+00, 0.65094200E-01, -.39636500E-01, -.13660000E-01, 0.12339300E-02, 0.67420400E-01, -.17972300E-01, -.14487100E+00, -.96085900E-01, 0.61227600E+00, -.19551600E+00, -.28637100E+00, -.70815200E+00, 0.11820800E+01, 0.66523000E-02, 0.12402500E+00, -.32586300E+00, -.60412100E+00, -.39832300E+00, -.38044400E-01, -.18327900E+00, 0.11316000E-01, -.10222800E-01, -.69306800E-01, -.37830100E+00, -.87410000E-02, -.33480400E+00, -.12743000E+00, 0.34690700E-01, -.98968100E-01, -.61726900E-01, -.13118100E+00, 0.92248700E-01, -.19516500E+00, 0.41387200E+00, -.14346800E+00, -.52908900E-01, 0.79691500E+00, 0.12866400E+00, -.18716200E-01, 0.91946700E-01, 0.10507100E+00, -.45501400E+00, -.13087800E+00, -.79010700E-01, 0.75358800E-01, -.81731700E-01, -.56841700E-01, 0.81992600E-01, -.15088600E+00, 0.18298800E+00, 0.39291500E-01, -.95202500E-01, -.51695900E-01, 0.85357800E+00, -.17627400E-01, 0.10717700E-02, -.57903000E-01, 0.19812300E-01, 0.26077400E+00, 0.95067300E-02, 0.17878800E-01, 0.30297000E+00, -.94977100E-01, 0.52414400E-01, -.61493000E-02, -.24066700E+00, -.23770200E-01, -.13759600E+00, -.28350600E-03, 0.10451200E+00, -.13363400E+00, -.13333900E+00, 0.22897700E+00, -.71421800E+00, -.10638800E+00, -.78759000E-01, 0.67664500E-01, -.83199400E-01, -.37538600E-01, 0.11310700E-02, 0.16220900E+00, 0.16150500E+00, 0.17534700E-01, 0.89809700E-01, 0.41224500E+00, 0.12840600E+00, 0.63519000E-02, -.19557400E+00, -.10061700E+00, -.96679400E-01, -.15248000E-01, -.35929300E+00, 0.78719500E-01, 0.25541700E+00, 0.61767700E+00, 0.52647100E+00, -.20985500E+00, -.11760800E+00, 0.37083600E+00, -.43368800E-01, -.71497100E-01, 0.75930700E-01, 0.39897000E+02, 0.65001400E+01, -.91354500E+01, 0.35327000E+02, 0.14701800E+02, 0.47720900E+01, 0.24081200E+02, 0.37217500E+02, -.18817900E+02, -.43541400E+02, -.18630100E+02, -.29090000E+02, -.23752400E+01, -.54375100E+01, 0.44657300E+01, 0.32240500E+01, -.22853100E+01, -.49337400E+00, 0.10567300E+03, -.51752200E+02, 0.97788400E+01, -.52684700E+02, -.35308900E+02, -.78669500E+01, -.34681900E+02, 0.56847700E+01, -.48008200E+02, 0.20999800E+01, -.30501100E+02, -.26095600E+02, 0.12867600E+02, 0.10517600E+01, 0.13130900E+02, -.23520000E+01, 0.13666100E+02, -.48786600E+01, -.22638700E+02, 0.14072400E+02, 0.29968700E+01, 0.31484600E+02, 0.15822400E+01, -.89927300E+00, 0.11126500E+01, -.37735700E+01, 0.11903000E+01, -.51819300E+01, 0.18132500E+00, 0.18769600E+01, 0.22138000E+00, 0.14137100E+01, 0.73200000E+01, -.17598600E+01, -.51653300E+01, 0.48566300E+01, 0.52601000E+00, -.10780600E+01, -.42915100E+01, -.97874100E+00, -.54294900E+01, 0.20181500E+01, -.90700900E+01, 0.27368900E+01, -.38923300E+01, 0.39294300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.20941700E+01, 0.28175900E+00, 0.82097900E+00, -.11686900E+01, -.43892400E+00, 0.12718500E+00, 0.11863200E+00, -.54989100E+00, -.18144500E-01, -.16748800E-02, 0.73107500E-01, 0.10740000E-01, -.69874900E+00, -.15096200E+01, 0.38320500E-01, -.21099000E-01, -.65039100E+00, 0.52055700E+00, 0.44443900E+00, -.27499100E+00, -.31610400E+00, -.20407700E+00, -.42160200E+00, -.18689100E+00, -.13140600E+00, 0.10123900E-01, -.10925900E+00, -.15132300E+00, -.38579700E+00, 0.99942000E+00, -.77571000E-01, -.23902100E+00, 0.31982800E+00, -.20631900E+00, -.29772200E-01, -.75202900E+00, -.11438600E-01, -.30173400E+00, -.28805600E+00, -.11936700E-01, 0.10305600E+00, 0.86188900E+00, -.10407000E+01, 0.62552300E+00, -.46729600E+00, -.10711800E+01, 0.46182700E+00, -.29352000E+00, -.74171900E-01, 0.50594200E+00, 0.65485000E+00, 0.25275800E+00, -.13102900E-01, 0.58997600E-01, 0.26969500E+00, -.16148700E+00, 0.11212100E+00, -.14010800E+00, 0.13682500E-02, 0.14159500E+00, 0.32687900E+00, 0.57678900E+00, -.42538600E-01, -.93051700E-01, 0.13389600E+01, 0.14334400E-01, -.39681000E+00, -.22675700E+00, 0.74696000E-01, 0.55573900E-02, 0.46454600E-01, -.17289000E-01, -.47481400E+00, 0.22555200E+00, -.33093200E+00, -.11759300E+00, -.68248100E-01, -.55091700E+00, -.52322600E+00, 0.10737200E+00, -.95212200E-03, 0.49164700E+00, -.20628000E+00, 0.23899200E+00, -.11097300E+00, -.50770200E+00, 0.34257000E+00, -.12325500E+00, 0.51295600E-01, 0.16434500E+00, -.39055500E+00, -.59731600E-01, 0.75338100E+00, 0.11549000E+01, -.13284200E+01, -.12408900E+01, 0.51790600E+00, 0.35304100E+00, -.50393900E+00, 0.12216000E+00, 0.29705800E+00, 0.10196500E+00, -.10990400E+00, -.86399900E-02, 0.11681000E+00, 0.32257500E+00, 0.75428600E+00, 0.11146400E+00, 0.22187400E+00, 0.20410600E+00, -.47984900E+00, 0.10076400E-01, 0.27445400E-01, -.25739500E-02, -.10250000E+00, 0.49505400E+00, -.34307200E+00, -.65532700E-01, -.59108200E-01, 0.86685800E+00, 0.33565900E+00, -.51602600E+00, -.56439600E+00, -.68643500E+00, -.34353700E-02, 0.30876600E+00, -.35309300E+00, -.12121100E+01, -.21045300E+00, -.90886400E-01, -.21334400E+00, -.30575300E+00, -.35178800E-01, 0.50430000E-01, 0.32888600E+00, -.33281800E-02, -.62302800E-01, 0.93898700E-01, -.49996800E-01, -.19534300E-02, -.55942000E-01, 0.58883300E-01, 0.16448200E+00, -.35421400E-01, 0.42163800E-01, 0.20698100E+00, 0.17570400E-01, -.12373300E+00, -.38009800E+00, -.30472800E-01, 0.72406900E-01, -.35274600E-01, -.92762500E-01, 0.21892500E-01, -.15454800E-01, 0.47144000E-01, -.44230900E+00, 0.32244900E-01, -.67744500E+00, 0.75298100E-01, 0.55235500E-01, -.13547400E+00, 0.33113800E+00, 0.16725200E+00, 0.31586900E+00, -.11552400E+00, 0.30801400E-02, -.68263600E-01, 0.58644500E-02, -.69930800E-01, 0.28440800E-01, 0.28276000E+00, 0.34024900E+00, -.84968000E-01, -.63063100E-01, -.52807500E-01, 0.85341200E-01, -.14694200E-01, -.52122700E-01, 0.44446000E-03, -.93859200E-01, 0.89346500E-01, -.87864700E-01, 0.19614300E-01, -.51498800E-01, -.56583600E+00, -.18306000E+00, 0.80272100E-01, 0.43234000E-01, -.93940200E-01, 0.77509800E-03, 0.36303900E+00, 0.16423400E+00, -.12644800E+01, 0.16699300E+00, -.47516200E+00, -.32476800E+00, -.93617000E-01, 0.38823500E-01, -.12651900E+00, 0.27850600E-01, 0.73014200E-02, -.56275800E+00, -.17376200E+00, 0.26138600E+00, 0.21922700E+00, -.49452300E+00, -.62788400E-01, -.88589700E-01, 0.17529400E+00, -.68801600E-04, 0.47636400E-01, -.46384200E-01, 0.21840300E-01, -.19944400E+02, 0.28508400E+02, 0.15245900E+02, 0.95559300E+01, -.12616300E+02, -.22737500E+02, 0.14231000E+02, -.74957300E+01, 0.33628800E+02, -.70868500E+01, 0.27808100E+01, 0.19327500E+02, -.17328400E+02, -.16449200E+02, -.30403400E+02, 0.16907200E+02, -.73190300E+00, -.25652700E+03, 0.12802000E+03, 0.52527500E+02, 0.12821500E+03, 0.16305100E+02, -.31262500E+02, 0.55974600E+02, -.69016800E+02, 0.81178400E+02, -.20805800E+02, 0.10889500E+03, -.25121000E+02, 0.12477200E+02, 0.21033900E+02, 0.12471000E+02, 0.29978600E+02, 0.74224800E+01, 0.66891300E+01, 0.39695200E+02, -.18397700E+02, 0.21376800E+02, -.22560700E+02, 0.39396200E+00, 0.66781000E+01, 0.42404300E+00, 0.89599800E+01, -.12061400E+01, 0.87951900E+01, -.45720600E+01, -.15722000E+01, 0.16884700E+01, -.33271000E+01, -.10722500E+02, 0.18197200E-01, 0.82823200E+01, -.66922900E+01, -.95627500E+00, -.11089300E+00, 0.57701700E+01, 0.56823000E+00, 0.87720600E+01, -.14586000E+01, 0.25140500E+01, -.53084100E+01, -.35289800E+00, -.15492300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24488200E+01, -.31429400E+00, -.12876800E+01, 0.28095600E+01, 0.16344600E+01, 0.11775200E-01, -.26788900E+00, 0.62706100E+00, 0.16595300E+00, 0.26544100E+00, 0.14743400E+01, 0.15826600E+00, -.33814200E+00, 0.17168500E+01, -.40713700E+00, -.27219200E+00, 0.67658400E+00, -.45253600E+00, -.26349300E+00, -.10669700E+00, -.94816300E-01, -.17480700E+01, 0.22017900E+01, -.10144300E+01, 0.11705000E+00, 0.55908300E-01, -.15628300E-01, 0.46092900E+00, 0.36371400E+00, -.59309300E+00, 0.32856300E+00, 0.31832400E+00, -.12206800E+01, 0.53790700E+00, 0.54408500E-01, 0.89577900E+00, -.35005800E-01, 0.34244100E+00, -.60477100E+00, -.20337500E+00, -.47992500E-01, -.14235000E+00, 0.12587000E+01, -.12404200E+00, 0.62799900E+00, -.64702300E-01, 0.22293100E+00, -.23787300E+00, -.16997400E+00, 0.87538300E-01, 0.14856200E+01, 0.71207800E+00, -.62957600E-01, 0.25818000E+00, -.43684000E+00, -.20923100E+00, -.72370800E-01, -.10123800E+00, 0.26761500E-03, 0.36589200E+00, 0.14800000E-01, -.50608800E+00, 0.12808900E+00, 0.51671400E+00, -.15156200E+01, -.10749100E+01, -.12109400E+00, 0.23688900E+01, 0.20040100E+00, -.28107100E-03, -.15108600E+00, 0.42321800E+00, 0.95544900E+00, -.52719100E+00, -.23094700E+00, -.18142800E+00, -.40892100E+00, -.22067300E-01, -.67263100E+00, 0.82694000E-01, 0.15403800E-02, 0.21219300E+01, -.85470200E+00, -.14411700E+01, -.20624200E+00, 0.28983700E+00, 0.89194600E+00, -.17084100E+00, 0.18579400E+00, 0.39638700E+00, 0.72795000E+00, 0.29331000E-01, 0.55132900E+00, -.20954300E+00, -.97223300E+00, -.10774000E+01, 0.27653500E+00, 0.15700700E+01, -.30602800E+00, -.18246300E-01, 0.41417700E+00, 0.75247300E-01, 0.32612900E-01, -.25919600E-01, 0.32115500E+00, 0.58111800E+00, -.17774600E+00, 0.59028000E-01, -.12478200E+01, -.24049600E+00, -.17003500E+00, 0.60875800E-01, 0.27817000E+00, -.43379700E-02, -.43000400E+00, -.33734000E+00, 0.16494200E+00, -.17722500E+00, -.31320200E-01, 0.88336400E-01, 0.35548700E+00, -.86621900E-01, 0.49432700E+00, -.84111200E+00, 0.12615100E-01, -.13616200E+00, 0.62131300E-01, -.87724200E+00, 0.78604200E-01, 0.20184200E+00, -.75880600E-01, -.15205500E+00, 0.42185800E-01, -.27457800E-01, -.24531600E-01, -.54374200E-02, -.11442700E+00, 0.78191700E+00, 0.99528100E-01, 0.49342900E-01, 0.72350700E-01, -.84775400E-01, 0.65346500E-02, -.25106200E+00, -.45246900E+00, -.26338600E+00, -.31691000E-01, -.32308500E+00, -.62794700E+00, -.35739900E+00, -.59183900E-01, 0.17235000E+00, 0.14459100E-01, 0.13951300E+00, -.21636800E+00, -.87594500E-01, 0.63921800E+00, -.63123600E-02, -.74279900E+00, -.70789600E-01, -.64473800E-01, 0.22698800E+00, 0.49506700E+00, 0.47620500E-01, -.11416700E+00, -.12082700E+00, -.43437100E-01, 0.26543200E+00, 0.53881800E-03, -.18051700E+00, 0.16156100E+00, -.11892600E+00, -.11254800E-01, 0.93149900E-01, -.23252800E+00, -.14868800E-01, 0.94412300E-01, 0.93196600E-01, -.20590200E-01, 0.17614600E-02, 0.44158000E+00, -.18483200E+00, -.19236500E-01, 0.30409400E+00, -.73665200E+00, -.31321500E+00, -.37571900E+00, 0.13477200E+00, 0.18065400E+00, 0.14139800E+00, 0.63421000E-03, -.39772400E-01, -.37543000E-01, 0.28230000E+00, 0.18348100E+00, -.37113200E+00, 0.13979300E+00, -.95843200E-02, 0.13783200E+00, 0.16562300E+00, -.22397400E-01, -.31192900E-01, -.64320600E-01, -.61978900E-01, 0.20552500E+00, -.78705800E-01, -.50804800E+00, -.88598200E-01, 0.14271900E+00, 0.24952100E+00, 0.11430000E-01, 0.72938000E-01, -.66317500E-01, -.80082900E+00, 0.10599000E+01, -.39351800E+02, -.72515200E+01, 0.34098400E+02, -.30435200E+01, 0.57770800E+01, 0.57225100E+02, -.28452300E+02, -.19293900E+02, -.28599400E+02, -.34143200E+02, -.31964600E+01, -.17666500E+02, 0.11336900E+02, -.18335600E+02, -.50979300E+01, -.44696300E+02, 0.99585500E+00, -.21498200E+01, 0.46395500E+01, -.25001700E+00, 0.34231600E+01, -.27616100E+02, -.12121000E+01, 0.57016300E+01, -.23640200E+02, -.13206900E+02, -.19234300E+02, -.33841400E+02, 0.16920600E+02, 0.33803200E+02, 0.16896600E+02, -.17787500E+01, -.68924500E+01, 0.22747400E+02, 0.22529600E+01, 0.42058600E+01, -.65902500E+01, 0.15137800E+02, -.18481700E+01, -.39847700E+00, 0.26603700E+01, 0.15828700E+01, -.20867800E+01, -.39355000E+01, -.14667700E+01, -.72943200E+00, -.16424500E+01, -.21956500E+01, 0.17841500E+02, 0.85920900E+00, 0.38253900E+01, -.38573200E+01, -.24519300E+01, 0.12054400E+01, 0.90325500E+01, 0.14292600E+01, 0.45577400E+01, -.20972200E+01, 0.14346000E+02, -.81449600E+00, -.85148800E+01, 0.19813300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12019200E+02, 0.36136200E+01, -.70556600E+01, -.41750800E+00, -.80047000E+01, 0.44143700E+00, 0.16242900E+01, -.37857200E+01, -.46485100E+00, 0.65927100E+00, -.39642900E+01, -.10649400E+01, 0.39606700E+01, -.28138200E+00, -.10889100E+00, 0.11868900E+01, -.68745200E+00, 0.23791200E+01, 0.13392200E+01, -.30598000E+01, 0.63638400E+00, 0.39427100E+01, 0.58480400E+00, -.76423000E+00, 0.34440000E+00, -.20178600E+01, -.10185400E+01, -.79190400E+00, 0.35362800E+00, 0.33105200E+01, 0.91615400E+00, -.10877000E+01, 0.21756800E+01, -.21633100E+01, 0.56720300E+00, -.78054600E+00, 0.17253600E+00, -.39234000E+00, 0.94835400E+00, 0.11643900E+00, -.11332600E+01, -.32833400E+01, 0.15003900E+01, -.37490600E+00, 0.13009300E+01, -.35914600E+01, 0.73852500E+00, 0.53971200E+00, -.17169400E+01, -.46289600E+01, 0.22718000E+01, 0.20314900E+01, 0.59832000E+00, -.60393900E+00, 0.19504900E+00, -.27488800E+00, 0.10345400E+00, -.22861600E+01, -.37659200E-02, -.33588200E+00, -.21159200E+00, -.31969800E+01, 0.22711800E+00, -.78459500E+00, -.31056000E+01, 0.64424400E+00, -.60691000E+00, 0.10553300E+01, -.51937500E+00, -.13637500E-01, -.97889500E+00, 0.21285100E+00, 0.12701200E+01, 0.14118800E+00, 0.16492900E+01, 0.15675900E-01, -.86699300E+00, 0.48391500E+00, 0.19393200E+01, 0.97498600E+00, 0.57921700E-02, 0.16143500E+01, 0.34607300E+00, -.39738800E+01, 0.30695000E+00, 0.10475600E+01, 0.41112100E+00, 0.50813900E+00, -.37901100E+00, -.22216500E-01, 0.27859800E+01, 0.28190700E+00, 0.90319500E-01, -.55173500E+01, 0.29684300E+01, 0.22067500E+01, -.20409800E+01, -.98402700E+01, -.23454000E+00, 0.20548100E+01, -.20099300E+01, -.23889600E+00, -.32152300E+00, 0.42795200E+00, 0.29963000E+00, 0.34547300E+01, 0.18907800E+01, -.83196700E+00, 0.43138900E-01, -.10344700E+01, 0.34044400E+01, -.87465500E-02, 0.10259700E+01, 0.12774100E-01, -.97395500E-01, -.28226200E+01, 0.16257400E+01, -.15013300E+00, -.39386700E+00, 0.26718200E+01, 0.26826900E+01, -.88281500E+00, -.56184900E+00, 0.24895300E+01, 0.24527100E-02, 0.24524600E+00, 0.42105300E+00, -.16845800E+00, 0.25909400E-02, 0.44176900E+00, 0.11219500E+01, 0.88781100E-01, 0.15481900E-01, -.11008700E+00, 0.23453300E-01, -.14204500E-02, 0.10306800E+01, -.34776400E+00, 0.18264800E-03, 0.44784500E-01, -.69182100E+00, 0.29652500E-01, 0.64749600E+00, -.15302700E+00, 0.44489200E+00, -.26320400E+00, -.11643600E+00, 0.11712400E+01, -.15544700E+00, -.14427700E+00, 0.83870800E-01, 0.64623700E+00, -.79288300E+00, 0.29567200E+00, 0.53183600E-01, -.33202700E-01, -.10052600E+01, -.74536000E-01, -.16502100E+01, 0.36383300E+00, 0.53567800E+00, -.11343000E+01, -.20276200E+00, 0.55008500E+00, 0.99698000E+00, -.80076400E-01, 0.24782400E+00, -.33717000E+00, -.31372000E-01, 0.32794800E+00, -.33746900E+00, 0.12222500E+01, 0.14351700E+01, -.10292300E+01, 0.28338500E+00, -.22724800E+00, 0.85857000E-01, -.38591000E+00, -.28671300E+00, 0.74303700E-02, -.11869400E+01, 0.19850800E+01, 0.18897900E+00, -.45018200E+00, 0.78217900E+00, -.10002400E+01, 0.33772200E+00, 0.38680700E+00, -.36185900E+00, -.26681100E+00, 0.81037200E-02, 0.18409500E+01, -.72107700E+00, 0.34641900E+01, 0.30176100E-01, 0.37364200E+01, 0.57694800E+00, 0.52861300E+00, -.11205400E+01, -.42316300E+00, -.82922300E+00, 0.60732200E-01, 0.70366900E+00, 0.12232500E+01, -.62607600E+00, 0.66871700E+00, 0.70231300E-01, 0.76748000E+00, -.73550500E+00, -.11474700E+01, 0.19838100E+00, -.67792400E-01, 0.10432100E+00, -.40652600E+01, -.29531200E+01, -.69797900E+00, 0.12704300E+03, 0.51573600E+02, -.37831900E+01, 0.12541100E+03, 0.78712000E+02, -.38385700E+02, -.14391300E+03, -.39374500E+02, -.42219600E+02, 0.32239900E+02, -.46106600E+02, -.66378300E+01, 0.15089700E+02, 0.33507200E+02, 0.33860100E+02, 0.31081100E+03, -.15202000E+03, -.18970200E+03, -.15435700E+03, -.15146100E+03, -.59692800E+02, -.77738100E+02, -.53022600E+01, -.16143100E+03, -.34162200E+02, -.44679300E+02, -.15518400E+03, 0.77357300E+02, 0.37034400E+02, 0.77975500E+02, 0.10442300E+02, 0.70819000E+02, -.26978800E+02, -.57379300E+02, 0.43020300E+02, 0.45956600E+02, 0.57500400E+02, 0.55360200E+01, -.58477400E+01, -.27797300E+00, -.10012200E+02, 0.76395000E+00, -.93716300E+01, 0.54905200E+01, 0.27128600E+01, 0.26100200E+01, 0.25586300E+01, -.20133000E+02, -.46301300E+01, -.78423400E+01, 0.80099400E+01, 0.47703500E+01, -.41638600E+01, -.67597300E+01, -.46604000E+01, -.83396600E+01, 0.97822000E+01, -.13908400E+02, 0.65227800E+01, -.23407200E+02, 0.18445600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54206400E+01, -.95959800E+00, -.14229600E+01, 0.43896800E+01, 0.19725200E+01, 0.54034700E+00, -.40958200E+00, -.74772200E+00, 0.11754300E+00, 0.84061000E-01, 0.10892800E+01, -.19557700E+00, -.53641100E+01, 0.53467500E+00, 0.19623900E+00, -.25520000E+00, 0.10220200E+01, -.27696400E+01, -.39858100E+00, 0.11578800E+01, 0.67637300E+00, -.32994800E+01, 0.37085100E+00, -.10727800E+00, -.58351700E-01, 0.14198600E+01, -.40930800E+00, -.84552500E+00, -.13570600E+00, -.22960200E+01, -.11854100E+01, 0.34061100E+00, -.14014600E+01, 0.72453700E+00, -.69160000E-01, 0.14155400E+01, -.24302300E-01, 0.81824200E+00, -.41003700E+00, 0.11823400E+00, 0.28239400E-01, 0.39915300E+00, 0.27684600E+01, -.26012500E+00, 0.11201600E+00, 0.53035600E+00, -.12444900E+01, 0.40107500E+00, 0.56835500E+00, 0.12837500E+01, 0.21126800E+00, -.14728100E+00, -.49124900E-01, -.20525200E+00, -.27448400E+00, -.31140500E+00, 0.83147900E-01, -.60693500E-01, -.45812600E-03, -.15120600E+00, -.16906500E+00, -.51976200E+00, 0.10727000E+00, 0.33332300E+00, -.61156100E+00, -.24297500E+00, 0.28325900E-01, -.58568800E+00, 0.55178600E-01, -.36501000E-02, 0.21284600E+00, 0.14153500E+00, 0.33873600E+00, -.73193800E-01, -.30357600E-01, -.21906100E-01, 0.17671900E+00, -.20918200E-01, 0.95364800E+00, -.57623200E-01, 0.17941200E-02, -.18486400E+00, 0.73672300E+00, -.76952300E+00, -.17058300E+00, -.13726600E+01, 0.19421200E+00, -.10882500E+00, -.22416900E+00, 0.15974000E+00, 0.63519700E+00, -.24698800E-01, 0.43066400E+00, 0.15679100E+01, -.24729500E+00, -.46522700E+00, 0.17273500E+00, 0.10146700E+01, 0.20031500E+00, -.21845200E+00, 0.57079800E+00, 0.13365500E+00, 0.11076800E+00, 0.16695900E+00, 0.15710200E+00, -.75983200E+00, -.18283900E+00, 0.29990900E+00, 0.42941200E+00, 0.32634600E-01, 0.32485900E+00, -.57877500E-01, -.92382700E-02, 0.12040500E-02, 0.16946100E+00, 0.57555900E+00, -.42295800E+00, 0.42814800E+00, -.36845300E-01, -.73531600E+00, 0.40143200E+00, -.20965500E+00, -.16065800E+00, -.73678400E+00, -.73573600E-02, -.39217900E+00, 0.10338400E+00, -.21716100E+00, 0.28022200E-01, -.13771100E-01, -.10360200E+00, -.40947100E+00, 0.61625600E-01, 0.94220500E-01, 0.93422100E-01, 0.36959500E-02, -.24959900E+00, -.31931300E-01, -.10369700E+00, 0.56381300E-01, 0.67901200E-01, 0.14036600E+00, 0.11745300E+00, -.77663400E-01, -.57322600E+00, 0.20113000E-01, 0.12495700E+00, -.10347500E+01, -.10180000E+01, 0.62395800E-02, -.25288900E-01, -.12335600E-01, 0.26407000E+00, 0.17869700E+00, -.12795600E+00, -.37723600E-01, 0.11781800E+01, 0.12799100E+00, -.67191600E+00, -.10771000E+00, -.29181800E+00, -.64475200E-01, 0.11069200E+01, 0.32478900E+00, 0.12967200E+00, -.11400800E+00, 0.26650600E-01, -.20804000E-01, -.47649300E-01, -.25448100E+00, -.16413600E+00, -.45889000E-01, 0.42569800E+00, -.30634300E-01, 0.18260700E+00, -.19153700E-02, -.20607900E-01, -.15896000E-01, 0.87518700E-01, -.33807500E-02, -.50775700E+00, 0.23907200E+00, 0.24125100E+00, -.40428600E+00, 0.52777700E+00, 0.23199800E+00, 0.15584500E-01, 0.47809200E-01, -.13162400E+00, 0.13517400E+00, -.46611000E-02, -.39322400E+00, -.22640700E+00, 0.66649500E+00, -.11987700E+00, -.17302400E+00, 0.52995400E+00, -.67489100E-01, 0.38396200E+00, -.23544800E+00, -.51516400E-01, 0.59552400E-01, 0.10848200E+01, 0.10105400E+00, -.49793100E+00, -.37357800E+00, 0.34998900E+00, 0.39872100E+00, 0.69902400E+00, -.10332100E+00, -.20370300E-01, -.18662600E-01, 0.36096400E-01, -.31948400E+00, 0.90709400E+00, 0.71605800E+00, -.18091900E+00, -.42015000E+02, 0.22751100E+01, -.13302500E+02, -.69503900E+02, 0.34635800E+02, -.31555600E+02, 0.34655600E+02, 0.12352800E+02, -.74475100E+01, 0.25658100E+02, -.19803300E+02, 0.36500700E+02, 0.18756900E+00, 0.10895800E+03, 0.21096300E+03, -.10264800E+03, -.20194700E+03, -.10546400E+03, -.40591500E+02, 0.41646000E+01, -.29055200E+02, 0.31215600E+02, -.42102100E+02, 0.44334500E+01, -.57432300E+02, -.43707300E+02, 0.21708300E+02, -.33627800E+02, 0.30342700E+02, -.76188200E+01, 0.15706800E+02, -.38289400E+02, -.28080500E+02, 0.24423700E+02, 0.18352400E+01, 0.48648700E+02, 0.16411900E+01, -.58082400E+01, -.26763700E+01, -.89045300E+01, 0.11601600E+01, -.72781400E+01, 0.54776000E+01, 0.57799800E+00, 0.11986900E+01, 0.27019500E+01, -.90596800E+01, -.10654300E+01, -.80062400E+01, 0.75824900E+01, 0.46814500E+01, -.12176600E+01, -.10581900E+02, -.20919900E+01, -.91305500E+01, 0.51199700E+01, -.14941400E+02, 0.82036900E+01, -.10645400E+01, 0.84686500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.15779000E+01, -.25749600E+00, -.42290400E+00, 0.68409200E-01, 0.85891800E+00, -.50528100E-01, -.14027200E+00, 0.37068900E+00, 0.61962200E-01, -.28333300E+00, -.20558600E+00, 0.50754100E-01, 0.51287600E-01, -.56284600E-01, 0.13138700E+00, -.35036300E-01, -.10812900E-01, 0.10766000E-01, -.41639100E-01, 0.28467300E+00, -.68028300E+00, -.14345300E+01, -.16000500E+00, -.23812400E+00, 0.73979100E-02, 0.54713300E+00, 0.55039300E-01, -.46750900E-01, 0.63628900E-01, 0.12465100E+01, -.56744100E-01, 0.61111800E-02, 0.13791200E+00, 0.62559300E-01, 0.42916900E-02, 0.15445500E+00, 0.16391900E-01, -.11825600E+00, 0.10237500E-02, 0.51033000E-01, -.39339800E-01, 0.35321500E-01, -.12357000E+01, 0.24138600E+00, -.36730600E+00, -.43866500E-01, 0.12236000E+00, 0.70603800E-01, -.97304500E-01, -.22561700E+00, 0.15581200E+00, 0.11940700E+00, 0.59313900E-02, 0.21124500E+00, -.83488100E-01, -.20653400E+00, 0.27411800E-01, -.36408000E+00, 0.70348900E-03, 0.44819500E-01, 0.62656700E-01, -.15192200E+00, 0.23263200E-01, -.24588400E-01, 0.92747800E-02, -.21166000E-01, -.53106400E-01, 0.31876800E+00, -.12332300E+00, 0.96180700E-03, 0.43328300E-01, 0.65762600E-01, -.20313000E-01, 0.36424000E-01, 0.16957700E-01, -.34662900E-01, -.18421900E+00, -.54338200E-01, -.21422100E+00, 0.14745900E+00, 0.18124000E-03, 0.65613100E+00, -.20380700E+00, -.11269000E+00, 0.69324000E-03, -.27536300E-01, 0.29468900E+00, -.24678000E-03, 0.45027600E-01, 0.90906900E-01, 0.13286600E+00, 0.78265900E-02, 0.12277700E+00, -.53754400E-01, -.17362800E-01, -.10934200E+00, 0.27954500E-01, -.44430000E+00, -.97798500E-01, 0.17410700E+00, -.10743400E+00, 0.46961900E-01, -.45281400E-01, 0.67575100E-01, 0.52972800E-01, 0.12510700E+00, 0.15572800E+00, -.18731900E+00, -.59012700E-01, -.46916400E-01, 0.34541200E+00, 0.74255200E-02, 0.81036700E-01, 0.48649600E-04, -.44254500E-01, -.65924700E-01, -.46166600E-02, 0.94346900E-01, -.50775500E-01, -.79042900E-01, 0.25784000E+00, -.15186800E+00, 0.21646900E+00, -.91945500E+00, -.70239800E-03, 0.31177600E-01, 0.15219300E+00, 0.15285200E+00, 0.38646400E-01, 0.57393200E-01, -.53470100E-01, 0.82607200E-03, -.24865400E-01, -.25543400E-01, 0.16314700E+00, 0.80313600E-03, 0.99296400E-01, 0.12394100E+00, -.11867500E-01, 0.24108400E-01, 0.18069600E-01, 0.40344600E-01, -.39136800E-02, -.36737600E-01, -.60422600E-01, -.43175200E-02, 0.43733800E-02, -.67612400E-01, -.52694700E-01, 0.22888200E-01, -.10405200E-01, -.45264400E-01, 0.14242300E+00, 0.37456000E-01, 0.30989200E-02, 0.17172400E-01, 0.59980100E-01, 0.63096900E-02, -.21371100E+00, 0.37844300E-01, -.28977700E-02, 0.41685700E-01, -.14213500E+00, 0.66383200E-01, -.36529200E+00, 0.48677200E-02, -.15849100E-01, -.10722700E+00, 0.31583400E-02, 0.39708800E-01, -.15035300E+00, 0.22867000E+00, -.27026600E-01, -.11384600E+00, -.20298600E+00, -.13969300E-01, 0.12138600E+00, -.51501600E-01, -.13193500E-02, 0.83269600E-04, -.21592200E+00, 0.10571800E+00, 0.15641400E+00, -.18554900E+00, 0.37541100E+00, -.27925300E+00, -.26248000E-03, -.31914900E-01, 0.14507700E-01, -.48447000E-01, -.10483400E-03, 0.64018100E-01, -.12029500E+00, -.30754900E+00, 0.21467000E+00, 0.59099300E+00, -.19296500E+00, 0.26913200E-01, 0.67932800E-01, -.12674000E+00, 0.74606100E-01, 0.15045400E-01, 0.11710000E-01, -.36540500E-01, -.13088300E+00, 0.11569900E+00, -.58334800E-01, 0.17000800E+00, 0.13615500E-01, -.37423300E-01, 0.14092800E-01, 0.24225700E-01, -.19918500E-01, 0.79378700E-01, -.76546600E-01, -.13537600E+00, -.10987200E-01, -.56012900E-01, 0.23405300E+01, -.56296900E+01, -.10031600E+02, 0.51960300E+01, -.45691100E+01, 0.50258300E+01, 0.67098500E+01, 0.97757700E+01, -.73749500E+00, -.12968700E+02, -.19544100E+01, 0.10541400E+02, 0.10492300E+02, -.66766700E+01, 0.27879200E+01, -.94143100E+01, 0.33330600E+01, 0.29104900E+01, 0.76024000E+01, -.45411100E+01, -.19262500E+02, 0.40317200E+01, 0.58569400E+01, 0.30662100E+01, -.24037600E+01, 0.11249600E+01, -.47945600E+01, 0.16683900E+01, 0.15884600E+01, 0.33554600E+01, -.11239100E+02, 0.15942100E+01, 0.14564800E+01, 0.25399100E+01, 0.52583700E+01, 0.11978300E+01, -.32496900E+00, -.42715800E+00, 0.76277600E+00, 0.20648200E+00, 0.95680500E+00, 0.76867400E+00, 0.76035400E-01, 0.67490700E+00, 0.12944400E+00, -.72836100E+01, -.73825300E+00, 0.15107400E+01, -.81916300E+00, 0.81560400E+00, -.91413300E+00, -.52498000E+00, -.90408200E+00, 0.13904800E+01, 0.59220200E+00, -.84889100E+00, -.68124700E+00, 0.27820000E+01, -.14289000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30773900E+01, -.19456000E+00, -.24623800E+00, 0.94822400E+00, 0.94072200E+00, 0.20410400E+00, -.26004500E+00, 0.76144300E-01, 0.29625900E-01, 0.91993700E-01, 0.71040400E+00, -.23942000E+00, -.17973500E+01, 0.95672700E-01, 0.18919600E+00, -.20952700E-01, -.28283700E-01, -.67325500E-01, -.17885600E+00, -.34662700E+00, 0.11101500E+01, 0.33846800E+00, -.12822100E+01, 0.45028600E+00, 0.76792200E-01, -.35334800E+00, 0.37940900E+00, -.30788400E+00, -.57114600E+00, -.10694700E+01, -.24937400E+00, 0.75704900E-01, 0.56784800E-01, 0.51313100E+00, -.27315400E-01, 0.33023500E+00, 0.19165000E-01, -.11814200E+01, 0.19417900E+00, -.29391100E-01, 0.41290500E+00, 0.25309200E+00, 0.12005300E+00, -.21006800E-01, 0.59957200E+00, -.30363600E+00, 0.23318800E+00, -.25126800E+00, -.21726600E+00, -.57087200E+00, -.49458100E+00, -.26296600E+00, -.14396600E+00, 0.41605200E+00, -.41949800E-01, -.47004400E+00, -.31599100E+00, -.87347500E+00, -.25793100E-02, 0.55256500E+00, 0.33520800E+00, -.23573700E+00, 0.11435000E-01, 0.26981700E+00, -.16077800E+01, -.39926100E+00, 0.56551500E-01, -.27078600E+00, 0.40822800E+00, -.20408200E-02, -.21624300E+00, 0.48850900E+00, 0.93119100E+00, -.10282400E+00, 0.15313900E+00, -.57303000E-01, -.20843700E+00, -.26328100E-01, -.13835700E+00, 0.83026800E-01, 0.84874300E-03, 0.63057400E+00, -.56045400E-01, 0.34676700E+00, -.52939600E-01, -.21142300E+00, 0.11875800E+00, 0.14327500E+00, 0.87143700E-01, -.19720400E-01, 0.22437600E+00, -.49757800E-02, 0.27172000E+00, 0.22703500E-01, -.25633800E+00, -.42026100E+00, 0.49317000E-01, 0.43636100E+00, -.51361200E+00, 0.60133600E-01, -.57817900E-01, 0.40205400E-01, -.31771700E-01, 0.62826400E-01, 0.33856800E+00, 0.54979200E-01, 0.45878600E+00, 0.36734600E-02, 0.14445200E+00, -.26239300E+00, 0.25806500E+00, -.32924500E-01, 0.90410400E-01, 0.14085600E-02, 0.17762700E+00, 0.88207300E-01, -.15694100E+00, 0.85940000E-01, -.23489900E-01, 0.79672000E+00, 0.32394200E-01, -.67423700E-01, -.14832100E+00, 0.16755600E+00, -.24797200E-02, 0.35477000E+00, -.14629300E+00, -.35575600E+00, -.22782100E+00, 0.27086000E-01, 0.23097300E+00, 0.11027300E+00, -.40564200E-01, -.54481800E-01, 0.15179300E-01, -.30210300E-02, 0.23170300E+00, 0.14181600E+00, 0.31217600E-01, -.52992600E-01, 0.53454800E-01, 0.17443900E-02, 0.71031800E-01, -.15147000E+00, -.18807100E-01, -.21981300E+00, -.13187800E-01, -.10481600E+00, -.58619600E-01, -.78769400E-01, 0.81383300E-01, 0.89241200E-01, -.23969200E+00, 0.50123000E-01, -.11871500E+00, 0.22829700E-01, 0.75680500E+00, -.23880000E-01, -.69085600E-01, -.16786400E+00, 0.10553900E+00, -.17682000E+00, 0.45384100E+00, 0.94114800E-01, 0.27830900E+00, 0.71106400E-01, 0.45259100E-01, 0.13956400E+00, -.15438300E-01, 0.37584700E+00, -.18748200E-03, -.15289200E+00, 0.38135700E+00, 0.79657800E-01, -.48315900E+00, -.28108500E-01, 0.31992400E+00, -.56416200E-01, -.17045700E+00, -.10836900E-02, 0.39555800E+00, -.17720000E+00, -.15789200E+00, -.50650700E-01, 0.11543200E+00, -.41481200E+00, -.18537200E+00, -.59564500E-01, 0.72578200E-01, -.11904100E+00, 0.14015900E-02, -.57423700E+00, 0.31846800E+00, 0.90673500E+00, -.39554900E+00, -.11993600E+01, 0.46815400E+00, -.58538500E-01, -.18344800E-01, 0.45723100E+00, 0.23242500E+00, 0.82879700E-03, 0.17700500E+00, -.74732600E-01, -.16896300E+00, -.45876900E+00, 0.24858800E+00, 0.14031100E-01, 0.12129000E-02, 0.65978200E-01, -.57455200E-02, 0.82041900E-01, -.78524900E-01, -.39781000E+00, -.19844100E+00, 0.49155100E+00, -.99576600E-01, -.10419800E+00, -.11819500E+00, 0.45218700E+02, 0.55382200E+02, -.28094100E+02, -.23870300E+02, -.27669900E+02, -.16601200E+02, 0.17437100E+02, -.15078900E+02, -.61251800E+01, -.27528300E+02, 0.15644200E+02, 0.23927300E+02, -.14146300E+03, 0.71984500E+02, -.30636000E+02, 0.70701200E+02, 0.17145400E+02, -.58748900E+01, 0.35768200E+02, -.54831700E+02, 0.48955900E+02, -.27967400E+01, 0.93805000E+02, -.40070100E+02, 0.19382600E+02, -.22126400E+00, 0.20929600E+02, 0.26711800E+02, 0.12723300E+02, 0.85206300E+01, 0.23129100E+02, -.91814900E+01, 0.19390800E+02, -.29447500E+02, 0.16814200E+01, 0.41099000E+01, -.26685800E+01, 0.44113200E+01, 0.10976600E+01, 0.50266900E+01, -.21830600E+01, 0.20987100E+00, 0.19454400E+01, 0.15931700E+01, -.18777700E+02, -.13442600E+01, 0.29838000E+01, -.19004600E+01, 0.20578700E+01, -.13443200E+01, 0.87583600E-01, -.15009400E+01, 0.32465000E+01, 0.19179400E+01, -.27096000E+01, -.59062000E+01, 0.31596400E+01, -.11895500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11098900E+02, -.16684000E+01, -.40744000E+01, 0.73964700E+01, 0.80474200E+01, -.11964300E+00, -.15928800E+01, 0.31421000E+01, 0.59840100E+00, -.36534900E-01, 0.31419200E+01, 0.22227600E+01, 0.53726300E+01, 0.81640600E+01, -.48705200E+00, -.98023100E+00, 0.18178900E+01, 0.17115400E+01, -.18337100E+01, 0.19844300E+00, 0.18687900E+01, -.14912000E+01, 0.30628900E+01, -.84328300E+00, 0.68715000E+00, 0.38584300E+00, 0.55213700E+00, 0.14116600E+01, -.23535000E+00, 0.26145700E+01, -.15660100E+01, 0.20367400E+00, -.87706300E+00, 0.22250800E+01, -.81174400E-01, -.44443900E+00, -.46269700E-01, 0.45275500E+00, -.15454500E+00, -.18374500E+00, -.19430900E+01, 0.42394700E+00, -.92531100E+00, 0.88762200E-01, 0.46758800E+00, 0.15377200E+01, -.13254900E+01, 0.59855300E+00, 0.11428200E+00, -.12123300E+01, -.37089000E+01, -.21340600E+01, -.28305800E+00, -.27294800E+00, -.60732900E+00, -.24601700E-01, -.19255700E+00, 0.31213800E-01, 0.53136100E-02, 0.15686400E+01, 0.16509800E+00, 0.16582000E+01, -.45892400E+00, 0.56015200E+00, 0.35573200E+00, 0.15099100E+01, 0.59830200E+00, -.46980600E+00, 0.77831500E-02, 0.58447000E-02, -.64201700E+00, -.44403600E+00, 0.11528900E+01, -.27433600E-01, 0.16766500E+01, -.36569200E+00, -.57437500E+00, 0.18350400E+00, 0.55653800E+00, -.27034100E+00, 0.23074200E-02, -.59374200E+00, 0.17357100E+01, 0.13074300E+01, 0.86913300E-01, -.34603900E-03, 0.21643900E+00, -.45727100E+00, -.33818800E+00, -.32202200E+00, -.23623000E+00, -.10792300E+00, 0.44315800E+00, -.30611600E+01, -.22559000E+01, -.32992700E+01, 0.44736300E+00, -.42237600E+00, -.11393100E+01, 0.76623600E+00, 0.10065500E+01, 0.25714700E+00, -.38206300E+00, -.84846900E+00, 0.87940100E+00, 0.16615100E+01, 0.25130500E+01, 0.36009800E+00, 0.99060300E+00, -.33702200E+00, 0.60588600E+00, -.54234400E-01, 0.14907100E+00, -.15251700E-01, -.32987000E+00, 0.60835700E+00, -.48547900E+00, 0.76078000E+00, -.19681200E+00, 0.21816700E+01, 0.12896700E+00, 0.15486200E+01, 0.19869800E+00, 0.70336600E+01, 0.23119600E-01, 0.16447800E+01, -.15767300E+01, -.36867800E+01, -.56502500E+00, 0.12260200E+00, 0.79783500E+00, -.79457500E+00, 0.42554100E+00, 0.74253100E-02, 0.10944900E+01, 0.29869200E+00, 0.12869100E+01, -.90959700E+00, -.95226500E-01, 0.50694000E+00, -.35563300E+00, 0.27379100E+00, -.18279300E+00, -.56935600E+00, -.26004900E+01, 0.15405300E+01, -.13756900E+00, 0.17516300E+01, 0.90150700E+00, -.23572200E+01, -.30542300E+00, 0.20048500E+01, 0.16358300E+01, 0.66507400E+00, -.13088600E+01, -.27648400E+00, -.12601200E+02, 0.18784100E+00, -.12342800E+00, 0.29926800E+00, -.26116200E+00, -.15600100E+01, 0.63684000E+01, 0.83421300E+00, -.19478200E+01, -.84137600E+00, 0.30788600E-01, 0.68081300E+00, 0.27321700E-01, -.61764000E+00, -.92786200E+00, 0.20587100E+01, 0.65541200E+00, -.83848700E+00, 0.25010000E+00, 0.17894400E+00, -.78500800E+00, -.42716800E-01, 0.12599500E+00, 0.12921900E-01, 0.21080700E+01, -.22900800E+01, 0.73378700E+00, 0.33032900E+00, -.20019200E+01, -.12883400E+01, -.16885700E+00, 0.26192600E+00, -.12667000E+00, 0.14374000E+01, 0.16281300E-02, -.37634000E+01, -.22079100E+00, 0.25349100E+01, -.63974600E+00, 0.64723000E+01, -.39012400E+00, 0.31560600E+00, -.18541100E+00, -.20894800E+01, -.94547800E+00, -.68221500E-01, 0.10731400E+01, -.38154900E+00, -.94971600E-01, -.12377900E+01, -.18000100E+01, 0.11717600E+00, 0.10564600E+00, 0.44125400E-01, 0.42587800E-01, 0.33374300E-01, -.34122900E-01, -.22564100E+01, 0.15708600E+01, 0.78006400E+00, 0.25650400E+00, -.78588200E-01, 0.14284200E+00, 0.18237100E+01, -.32118100E+03, 0.16203000E+03, 0.10135000E+03, 0.16049800E+03, 0.61642100E+02, 0.34185800E+02, 0.38466800E+02, -.14782500E+02, 0.11094500E+03, 0.49553500E+02, -.39044200E+01, 0.32283300E+03, -.16734700E+03, 0.48783200E+02, -.16131600E+03, -.49067400E+02, 0.41137400E+01, -.71010200E+02, 0.11593600E+03, -.95811800E+02, 0.21937300E+02, -.13044500E+03, 0.14624600E+02, -.68837100E+01, 0.22336700E+02, -.83251600E+01, -.52775700E+02, -.87591900E+00, 0.27873800E+01, -.44837700E+02, 0.31705600E+02, -.44761500E+02, 0.10337500E+03, 0.39920900E+00, -.14689800E+02, 0.40933700E+01, -.18886500E+02, -.74907800E-02, -.24702600E+02, 0.90096500E+01, 0.23665500E+01, 0.90135100E+00, -.12798000E+01, 0.46490800E+02, -.44690500E+00, -.95466600E+01, 0.75270400E+01, -.26257000E+01, -.14612500E+01, -.24528500E+01, -.35644300E+00, -.98327700E+01, 0.41398200E+00, -.58159400E+00, 0.20647400E+02, -.59717200E+01, 0.24488200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57231300E+01, 0.31892100E+00, 0.10684300E+01, -.36131000E+01, -.42882200E+01, -.11810100E+01, 0.97447500E+00, -.86918600E+00, -.39881600E+00, -.34724600E+00, -.37164400E+01, -.10856000E+01, 0.54277400E+00, -.21582400E+01, 0.63732800E+00, 0.64815500E+00, -.85329300E+00, 0.71645000E+00, 0.61312800E+00, -.13170700E+01, -.13889600E-01, 0.24246000E+01, -.21314500E+01, 0.66211900E+00, -.13316400E+00, -.56508700E+00, -.34640000E+00, -.28996800E+00, -.31476100E+00, 0.94993700E+00, 0.19407200E+00, -.64819300E+00, 0.95463300E+00, -.84226800E+00, 0.23833500E+00, -.15332000E+01, 0.22366300E-01, -.51410100E+00, 0.29212600E+00, 0.15464400E-01, 0.74117900E+00, 0.30132600E+00, -.20279600E+01, 0.37046800E+00, -.16649000E-01, -.10757300E+01, 0.61159200E+00, -.52852900E+00, -.41022400E+00, -.14294000E+00, 0.36541000E+00, 0.53945400E+00, -.14284000E+00, 0.14610700E+00, 0.67791700E-01, 0.28238200E+00, -.16089100E+00, -.27576700E+00, 0.13153200E-02, -.68187900E+00, 0.19595600E+00, -.76503300E-01, 0.69114500E-01, 0.34799900E+00, 0.94386600E-01, 0.13486200E+00, 0.77536900E-01, 0.33285200E-02, 0.29045400E+00, 0.29808200E-02, -.63055700E+00, 0.29131600E+00, -.24216700E-01, -.16245900E+00, -.36417700E-01, 0.15769300E+00, 0.51495500E+00, 0.26373500E+00, 0.15617100E+01, -.24797700E+00, 0.53836300E-03, -.20119700E+01, 0.16708900E+01, -.17154700E+01, 0.15613600E+00, 0.16897600E-01, -.83514100E+00, 0.31894300E-01, -.84730700E-01, -.92345200E+00, 0.90252100E+00, -.92202100E-01, 0.13674100E+01, 0.11087800E+01, -.83507300E+00, 0.68349600E+00, 0.12723200E+00, -.32300200E+01, -.14849600E+01, 0.21584600E+00, 0.10446300E+01, 0.44757100E+00, -.14472100E+00, 0.12547700E+00, 0.49727600E-01, 0.35350500E+00, 0.63985600E+00, -.59447800E-01, 0.70964100E+00, -.23361300E+00, 0.59611600E+00, -.55531600E-01, 0.23963800E+00, -.33874200E-02, 0.58371900E+00, -.79194100E+00, 0.15882900E+00, -.27443600E+00, -.15025100E+00, 0.16300700E+01, 0.66628200E+00, -.72544200E+00, -.45291300E-01, -.18687700E+01, 0.96528500E-03, 0.57863200E+00, -.18153500E+00, -.21662900E+01, 0.23603300E+00, -.18380800E+00, 0.28992900E+00, 0.33395100E+00, -.37359000E+00, -.12187200E+00, 0.88321300E+00, -.46655200E-02, 0.39901800E+00, -.31832800E+00, -.68599100E-01, 0.23132200E+00, 0.89796800E-01, 0.32884300E+00, 0.19604700E+00, -.48653000E+00, -.86868600E+00, -.45767600E-01, 0.48433700E-02, -.11472800E+00, -.47546400E+00, -.34570700E+00, -.70617300E-01, 0.43279500E+00, -.29379900E+00, 0.39096500E+00, -.21844300E+00, -.16083900E+00, 0.24580200E+01, 0.20275700E-01, -.14358000E+01, -.10833600E+00, 0.70580800E-02, -.15183200E+00, 0.12883900E+01, 0.43891400E+00, -.45276400E+00, -.24113800E+00, 0.66715600E-01, -.41808800E-01, -.15019200E-01, 0.99192500E-01, -.31581700E+00, 0.68007800E+00, -.92392500E+00, -.37999900E+00, 0.18370000E+00, -.16947100E+00, -.21735500E-01, 0.48292200E-01, 0.32451500E-01, 0.40563100E-02, 0.30697100E+00, -.15156300E+00, -.26618900E-01, 0.46021600E+00, -.22642600E+00, -.28002800E+00, -.16093400E+00, -.13648900E-01, 0.16950400E+00, -.53504200E-01, 0.35377800E-02, 0.30377600E+00, -.13435000E+00, -.37250000E+00, 0.21771200E+00, 0.10523400E+01, 0.28275500E-03, -.16544200E-01, -.63627600E-01, -.65363700E+00, -.37999400E-01, -.26549100E-02, -.10339700E+00, 0.23537100E+00, -.19812300E+00, 0.11534100E+01, 0.67879300E+00, 0.68199900E-02, -.10019300E+00, 0.10429300E+00, 0.13040000E+00, 0.12744200E-01, -.77151100E-02, -.13154600E+00, 0.43435600E+00, 0.49614800E+00, -.70004500E-01, 0.10328800E+00, 0.66163800E+00, 0.54627600E+00, 0.17859700E+00, 0.13825200E+02, 0.41179800E+01, 0.13967900E-01, -.11967000E+02, -.21212000E+02, -.13671800E+01, 0.87848700E+01, 0.37058300E+01, -.21539900E+02, -.19528700E+02, 0.68008300E+02, -.32006300E+02, 0.19411500E+02, -.33901200E+02, -.61606500E+01, -.65356600E+01, -.13065400E+02, 0.38769500E+02, -.27221800E+02, -.80701600E+01, -.44448200E+02, 0.67851100E+01, -.29840900E+01, 0.57442400E+01, -.48858400E+01, -.24157500E+01, -.92272300E+01, 0.10449400E+02, -.32497500E+01, 0.65268500E+01, -.80764000E+01, 0.21125600E+01, -.11648800E+01, -.89207000E-01, 0.16436000E+01, -.81562500E+00, -.20854700E+00, -.72659100E+00, -.47322400E+00, 0.15210200E+00, -.10920000E+01, -.13200100E+01, 0.57818700E+01, 0.91790400E+00, 0.71824700E+00, -.13456200E+01, -.16102000E+01, 0.99767600E+00, 0.28466500E+01, 0.94870800E+00, 0.78407300E+00, -.17941300E+01, 0.39363900E+01, 0.25663800E+01, -.37010600E+01, 0.38482700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25529800E+01, 0.44606500E+00, 0.87555300E+00, -.18116800E+00, -.13963100E+01, 0.42067900E+00, 0.20665100E+00, -.11324900E+01, -.87989100E-02, 0.10231600E+01, 0.11205200E+01, -.40630000E-01, -.14835100E+00, 0.12826300E+01, -.32620400E+00, 0.32075500E-01, 0.26021200E-02, -.28600500E+00, 0.82378400E-01, -.91734000E+00, 0.11978800E+01, 0.20192500E+01, 0.12334400E+01, -.66909500E-01, 0.10497000E+00, -.72058900E+00, 0.16826600E+00, 0.26697900E+00, 0.11896800E+00, -.93326400E+00, -.63029100E-01, -.10365200E-01, -.12499200E+00, 0.24679900E-01, 0.75724600E-01, -.10105900E+00, 0.84024200E-02, 0.15604000E+00, 0.54978400E-01, -.24518700E+00, -.47194100E+00, -.91765400E+00, 0.18553100E+01, -.66679100E+00, 0.10744400E+01, 0.12385000E+00, -.54426700E+00, 0.60586900E-01, -.42593900E-01, -.68917900E+00, 0.98029100E+00, 0.35433500E+00, 0.19299400E+00, -.38151800E+00, -.17166000E+00, 0.21566000E+00, -.63194700E-01, 0.16812400E+00, 0.11378700E-03, 0.14187300E+00, -.87179400E-01, -.50329800E+00, 0.10178500E+00, -.14562800E-01, -.56222600E+00, 0.19423300E+00, 0.69214100E-02, 0.24737700E+00, -.15688000E+00, -.32130900E-02, -.10603000E+00, 0.26439000E+00, 0.39567700E+00, -.40442900E-01, 0.38582000E+00, 0.24552000E-01, -.96735800E-01, 0.23641800E+00, 0.13987900E+00, 0.76567700E-01, 0.13255500E-02, 0.27039600E+00, 0.63866000E-01, 0.12232800E+01, 0.16031200E+00, 0.28609500E+00, 0.34048900E+00, 0.21445300E+00, 0.81471900E-01, -.89932500E-01, -.84124900E-01, 0.39129100E-01, 0.59078900E-01, -.40586800E+00, 0.86271600E+00, 0.83687400E+00, -.22694100E+00, -.33824900E+00, 0.46694500E+00, -.15581600E+00, 0.38581000E+00, -.25079100E-01, 0.16573700E+00, -.93923300E-01, 0.20361700E+00, -.30578200E+00, -.75494700E+00, 0.96562600E-01, -.28593300E+00, -.17160700E+00, 0.29896700E+00, -.33686600E-01, -.37260400E-01, 0.10979900E-02, -.29473900E-01, -.88344200E-01, 0.13879100E+00, 0.24443700E+00, -.35530900E-01, -.45968400E+00, 0.22417400E+00, 0.11752600E+00, -.99414800E+00, 0.98986200E+00, -.46763300E-02, -.22908700E+00, -.24618600E-01, 0.31165400E+00, -.36700400E-01, 0.28021300E-01, -.88123200E-01, -.16654600E+00, 0.22144400E+00, 0.53882600E-01, -.28421700E+00, 0.22764100E-02, 0.14237600E+00, -.39904200E+00, -.29864300E-01, -.27439700E-01, -.10838900E+00, -.83444500E-01, 0.31559900E-02, 0.28549100E+00, 0.32222000E+00, 0.51031700E+00, 0.20961100E-01, 0.46277300E+00, 0.29948200E+00, 0.41540800E-02, -.10126300E-01, 0.35774400E-01, 0.33696200E+00, -.26266400E+00, 0.89675200E-01, 0.59606400E-01, -.23900400E+01, 0.55065400E-01, -.21823900E+00, 0.15573800E-01, 0.20342300E+00, -.11717100E+00, 0.38754500E+00, -.28803200E-01, 0.66085500E+00, -.55659200E-01, 0.10941500E-01, 0.11989300E-01, 0.21274800E-01, -.24648400E+00, 0.15578200E+00, -.24854800E-01, -.32407000E-01, 0.58882900E-02, -.34384200E+00, 0.90490100E-01, 0.43302600E+00, -.20372300E-01, 0.13466000E+00, -.32594100E-03, -.25397800E+00, -.42905700E-01, -.13806700E+00, 0.24011800E-01, -.20041600E+00, 0.47919400E+00, -.30869900E-01, 0.66647100E-04, -.22958200E+00, -.16417900E+00, 0.36271600E-02, -.60338700E+00, 0.30172600E+00, 0.78673800E+00, -.10684100E+00, -.31963700E+00, 0.10714200E+00, 0.12274300E+00, 0.14538700E+00, -.16959800E+00, -.17833800E+00, -.22634800E-01, 0.72213500E+00, 0.86698900E-01, -.14318300E+00, -.14589000E+00, 0.39455400E+00, 0.21453200E+00, 0.21881900E+00, 0.11503200E+00, -.61304600E-02, -.57024300E-03, 0.76776400E-02, -.26009000E-01, -.53458700E+00, -.21576100E-01, -.12671900E+00, -.10289500E+00, -.41166500E+00, -.61190000E+00, -.14791000E+00, -.27454800E-02, -.21319600E+02, 0.14523400E-01, -.22677500E+01, 0.40050600E+02, -.20725600E+02, -.33754100E+02, -.22281000E+02, 0.44516000E+02, 0.43651800E+02, -.17199400E+03, 0.86141400E+02, -.41792000E+02, 0.86176000E+02, -.16238100E+02, -.49088100E+02, 0.36008700E+02, -.81817100E+02, 0.63679500E+02, -.27779900E+02, 0.10975100E+03, -.72630500E+02, 0.35598500E+02, 0.10859200E+02, 0.37789500E+02, 0.27764000E+02, 0.33529500E+02, -.28730300E+02, 0.16462100E+02, -.41605800E+01, 0.27134700E+02, 0.29893500E+02, 0.29858300E+01, 0.23624000E+01, -.77359900E+00, 0.42902900E+01, -.63212100E+00, 0.25572300E+00, -.11377100E+01, -.66021100E+00, 0.30277800E+01, -.11918900E+01, -.18995900E+02, -.16080800E+01, 0.64215100E+01, -.41138400E+01, 0.10735000E+01, -.22508200E+01, 0.18952300E+01, -.16127100E+01, 0.66244900E+01, 0.17628000E+01, -.15916200E+00, -.14566200E+01, -.32180500E+01, -.10338600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57449000E+01, 0.97724500E+00, 0.75789000E+00, -.38405500E+01, -.35200900E+01, -.33757100E+00, 0.72485200E+00, -.19478400E+00, -.66411900E+00, -.33390200E+00, -.34681900E+01, -.80286700E+00, 0.26398400E+01, -.15161500E+01, 0.52210200E+00, 0.61149300E+00, -.91441700E+00, 0.14259500E+01, 0.83665200E+00, -.16684500E+01, -.21341300E-01, 0.28124200E+01, -.24550700E+01, 0.10878500E+01, -.98473200E-01, -.11239200E+01, -.34297400E+00, -.26200600E+00, -.42734500E+00, 0.68353200E+00, 0.54656600E+00, -.61739300E+00, 0.10593800E+01, -.80735600E+00, 0.13826300E+00, -.14033000E+01, 0.19637900E-01, -.87266400E+00, 0.24400200E+00, 0.62072900E-01, 0.76820600E+00, 0.40597800E+00, -.28611300E+01, 0.50062600E+00, -.53776100E+00, -.66942200E+00, 0.78076800E+00, -.50461000E+00, -.46889700E+00, -.53989100E-01, 0.39972600E+00, 0.63650300E+00, -.10242600E+00, 0.27980000E+00, 0.28150800E+00, 0.95354800E-01, -.22166100E+00, -.15528800E+00, -.11923500E-02, -.40073900E+00, 0.47648600E+00, 0.66739200E+00, -.61977200E-01, 0.10859900E+00, 0.14070000E+01, 0.34657500E+00, 0.30237000E-01, -.31291200E+00, 0.17190700E+00, 0.20906400E-02, -.30250700E+00, 0.14726300E+00, -.26040000E+00, -.10011500E+00, -.18048800E+00, 0.13736600E+00, 0.41185800E+00, 0.24473600E+00, 0.14199600E+00, 0.71863200E-01, -.48984900E-03, -.91114800E+00, 0.24226500E+00, -.45390200E+00, 0.57902600E-01, 0.44642800E+00, -.61052500E+00, 0.35448000E+00, 0.24229200E+00, -.21839900E+00, 0.54800600E+00, -.17584100E-01, 0.33802900E+00, 0.13968500E+00, 0.12636600E+00, 0.87501900E+00, 0.10707400E+00, -.12259900E+01, -.35651800E+00, 0.17722900E+00, -.26787700E+00, -.27813500E-01, -.47414700E-02, 0.20430100E+00, -.25301700E+00, 0.12634100E+00, 0.53699700E-01, -.13017200E+00, 0.26532200E+00, -.22567600E+00, 0.34186200E+00, -.40457100E-01, 0.30122000E+00, 0.72215600E-02, 0.53174600E+00, -.10570800E+01, 0.52093200E+00, -.52982400E+00, -.58086200E-01, 0.74156200E+00, 0.56227700E+00, -.12980000E+01, -.47179700E+00, -.20878400E+01, -.10392200E-01, -.23082500E+00, 0.43643400E+00, 0.58033400E+00, 0.41171100E+00, -.23131900E+00, 0.21498400E+00, 0.53128800E+00, -.43537200E+00, -.41544900E-01, 0.26125800E+00, 0.75317500E-02, -.14534600E+00, -.26501300E-01, -.43640200E-01, 0.91165600E-01, 0.14118700E+00, 0.93467500E-01, 0.72390000E-01, -.67268200E-01, -.27300400E+00, -.32600400E+00, 0.55800500E-02, -.22321600E+00, -.18993600E+00, 0.18354100E+00, -.41024500E-01, -.13897000E+00, -.42282600E+00, 0.19140000E+00, 0.30441500E-01, -.71329900E-01, 0.29020300E+01, -.52949500E-01, -.35639300E+00, -.59500500E-01, -.52683500E-01, 0.10999800E+00, 0.37411900E+00, 0.37981800E-01, 0.34139300E+00, -.74335200E-01, -.22727100E-01, 0.39774400E-01, -.74870000E-02, 0.22003100E+00, -.16528900E+00, 0.11036300E+00, -.29039900E+00, -.21490400E+00, -.19068000E+00, -.11052700E+00, -.77437600E-01, 0.45882800E-01, -.42278400E-01, 0.36596200E-02, -.54033100E-02, 0.13880700E+00, -.17698500E+00, 0.28882200E+00, 0.15786300E+00, -.32556900E-01, 0.57158700E-02, -.64043200E-01, 0.49698600E-01, -.17642000E+00, 0.51346400E-02, 0.46611800E+00, -.64228200E-01, -.66515500E+00, 0.24684600E+00, -.25544000E-01, 0.77221500E-01, -.10448800E+00, -.19846000E-01, 0.82612000E-01, 0.22933800E-01, -.71226700E-01, -.12527600E+00, 0.49656600E-01, 0.19661100E+00, 0.45941200E+00, 0.32403800E+00, -.73829300E-01, -.23799700E-01, 0.45448300E-01, 0.22566000E-02, 0.38157500E-01, -.25524400E-01, -.30750900E+00, 0.35465300E+00, 0.39308100E+00, 0.36347300E-03, 0.79332200E-01, 0.54534800E+00, 0.40714700E+00, 0.14643700E+00, -.40280200E-01, -.27944800E+00, 0.79899900E+01, -.15818900E+02, -.10821100E+02, -.83477300E+01, -.32133900E+01, -.45409900E+01, -.99092600E+01, 0.26900200E+01, 0.11456700E+02, -.32377000E+01, 0.83377100E+01, -.55275400E+01, -.10640500E+02, -.19059200E+02, -.14197200E+01, 0.81759200E+01, -.90413400E+01, -.14033500E+02, -.10155300E+02, -.16421600E+02, 0.83372600E+01, 0.83751500E+01, 0.73362000E+01, 0.80036900E+01, -.36825600E+01, 0.75062700E+01, 0.71252000E+01, 0.76920300E+01, -.17862800E+01, 0.62855200E+01, -.21983700E+00, 0.83925000E+00, 0.13127000E+01, 0.66692600E+00, -.30347600E+00, -.48543600E-01, -.85307000E+00, -.39880100E-04, 0.65622400E-01, -.16480300E+01, -.55955300E+00, 0.33542700E+00, 0.30778900E+01, -.29594300E+01, -.98032000E+00, 0.30248800E+00, 0.39329500E+01, 0.32430600E+00, 0.31883300E+01, -.13456200E+01, 0.44746100E+01, 0.17307400E+01, -.44652500E+01, -.34317600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.82973100E+01, -.22471100E+01, -.20005600E+01, 0.10204400E+01, 0.51002100E+01, -.18676300E+01, -.77952200E+00, 0.51998300E+01, -.13643500E+01, -.22606800E+01, 0.35820500E+01, 0.48769400E+01, 0.60889700E+01, 0.54418200E+01, 0.45556300E+00, -.71921300E+00, 0.30746100E+01, 0.20439900E+01, -.43605900E-01, -.68452500E+00, 0.15374000E+01, 0.32457300E+00, -.52696300E+01, 0.21726900E+01, -.21405900E+00, 0.36177100E-01, 0.75017500E-01, -.93555600E+00, -.91055000E-01, -.43699300E+01, 0.11198200E+01, 0.61000400E+00, -.18617300E+01, -.20346800E+01, -.36240700E+00, 0.12498300E+01, -.55806100E-01, 0.77322400E+00, 0.15391100E+01, 0.15860700E+01, 0.27230200E+01, -.10493100E+01, -.36143100E+01, 0.70671600E+00, -.21143900E+01, -.97021800E+00, 0.52625400E+00, -.91535100E+00, -.13232800E+01, -.28709500E+01, 0.21252000E+01, 0.21586000E+01, 0.29439600E+00, 0.97229000E+00, -.11644300E+01, 0.11924400E+01, -.54901300E+00, 0.12484800E+01, -.13125500E-02, 0.10825100E+00, -.13963600E+01, 0.16642500E+01, -.60763500E+00, -.15908400E+01, 0.74124300E+00, -.90383800E+00, 0.15383800E+01, -.22678100E+00, 0.12684700E+01, 0.88303500E-02, -.10651700E+00, 0.33288900E+00, 0.75357600E+00, -.61682600E+00, 0.13901600E+01, -.26197200E-01, -.13563300E+01, -.39355100E+00, -.24835100E+01, 0.93535700E+00, -.25373400E-02, 0.39679800E+01, -.30044200E+01, 0.42144700E+01, 0.77222800E+00, 0.54031000E+00, -.77978800E-01, 0.64448900E+00, 0.75529200E+00, 0.67500400E-01, 0.18082000E+00, -.65224400E-01, -.10563500E+00, -.15144000E+01, -.11079800E+01, -.12448500E+01, 0.52829000E+00, 0.25558700E+01, -.10170800E+01, 0.22757400E+00, -.87640800E+00, -.18654700E-01, -.31526200E+00, -.39275700E+00, -.19700400E-01, -.62014300E-01, 0.38344200E+00, -.11285000E+01, -.35226800E+00, 0.58802900E+00, -.86231100E-01, 0.17887600E+00, -.31045200E+00, -.13024000E-01, -.54616600E+00, 0.31873000E+01, -.15746000E+01, 0.28137200E+00, 0.13523700E+00, 0.23122200E+01, -.37334700E+00, -.15018700E+01, -.21099900E+01, -.45706400E+01, -.74552800E-02, 0.13076600E+01, -.33248700E+00, -.13004300E+01, -.13903600E+01, 0.18177200E+00, -.16631900E+01, 0.35876200E+00, 0.30283300E+00, -.10739400E+00, -.30459300E+00, -.22813200E-01, 0.14041000E+01, -.70105900E+00, 0.22892500E+00, -.16077000E+00, -.16294400E+00, -.28998100E+00, -.24637800E+00, -.41245500E+00, 0.14265500E+01, -.18208300E+00, -.23454000E-02, 0.13101000E+01, 0.12843200E+01, -.83480200E+00, 0.37140200E+00, 0.25270200E+00, -.21465100E+01, -.59256700E+00, -.57970800E+00, 0.15133200E+00, -.44379000E+01, 0.26235200E-01, -.19706400E+01, 0.12412500E+01, 0.22431800E+00, -.96778700E+00, 0.98771100E+00, 0.60218000E+00, 0.34560500E+01, -.82245600E-01, 0.23111800E+00, 0.44479700E+00, 0.61778600E-01, 0.91064500E+00, -.16777600E+00, 0.44040200E+00, 0.19800200E+01, 0.31150800E+00, -.46199200E+00, -.77854900E-01, -.47729600E+00, -.18483100E+00, -.73667600E+00, -.32339100E-02, 0.82537900E+00, 0.10128900E+01, -.51145500E+00, -.10896500E+01, 0.17437800E+01, 0.85317800E+00, 0.30912800E+00, -.13327600E+00, -.51496300E+00, 0.46363800E+00, 0.10860700E-03, -.30509800E+00, -.10877400E+01, -.73858400E-01, 0.59038400E+00, 0.14421000E+01, 0.41515300E+00, 0.20347700E+00, 0.29412700E+00, -.46161100E+00, -.10520600E+01, -.14590000E+00, -.90414600E+00, -.42046300E+00, 0.12691500E+01, 0.23169100E+00, -.20221300E+01, 0.76364800E+00, 0.25720400E+00, -.82092800E+00, -.41673600E-01, -.58210700E-01, 0.50720000E-01, -.11358200E+01, 0.15218700E+01, -.35803700E+00, 0.38715100E+00, 0.56885000E+00, -.40632000E+01, -.12893900E+01, -.71662300E-01, -.95524400E-01, 0.32761000E-01, 0.14579000E-01, -.63203400E+02, -.12812700E+02, 0.15047500E+02, -.42539000E+02, -.80359700E+00, -.14930100E+02, 0.95578800E+02, 0.40236900E+02, -.12513100E+02, -.16283800E+03, -.19737400E+02, 0.54194300E+02, 0.95982300E+02, -.31236300E+02, -.58586900E+02, 0.38728800E+01, 0.67601900E+02, -.12351800E+02, -.90938000E+02, 0.44280400E+02, -.37486100E+02, 0.43143000E+02, 0.73372400E+02, 0.26887700E+02, 0.10388000E+02, -.35628500E+02, 0.27434300E+01, 0.30073700E+02, 0.15796700E+02, 0.27357000E+01, -.90607200E+01, -.19544500E+01, -.17729800E+02, 0.37309400E+01, -.11187800E+02, 0.13112400E+02, 0.30443800E+01, 0.22476000E+01, 0.31863200E+01, -.25440900E+02, -.41561400E+01, -.34728200E+01, 0.40499900E+01, 0.76036300E+01, -.25823700E+01, -.70715900E+01, -.30990500E+01, -.42423600E+01, 0.58397500E+01, -.99719000E+01, -.17352400E+01, 0.20259300E+02, -.76920900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.24576400E+01, -.77944900E+00, -.94405200E+00, 0.16641300E+01, 0.19917300E+01, -.19480500E+00, -.30815500E+00, 0.14552900E+01, -.20108700E+00, -.18948800E+00, -.20560200E+00, 0.14634000E-02, -.81893000E+00, 0.18610200E+01, -.33304700E-01, -.38736900E-01, 0.37257900E+00, 0.54591400E+00, -.83564800E-01, -.66317700E+00, 0.80322000E+00, -.55283200E+00, -.77415900E+00, 0.21242800E+00, 0.87790000E-01, 0.84838500E-01, 0.26210200E+00, 0.63405900E+00, 0.21416500E+00, -.14032400E+01, 0.50584500E+00, 0.31519900E+00, -.71179200E+00, 0.32059100E+00, 0.48993000E-01, 0.71207200E+00, -.27698000E-01, -.13386200E+00, -.78997100E+00, 0.11029100E+00, 0.13991000E+00, 0.14122100E+00, 0.15827600E+01, -.13112800E-01, 0.11159100E+00, 0.11664500E+00, 0.44433400E+00, -.41758800E-01, 0.11530300E+00, 0.18582600E+00, -.14481600E+01, -.32223700E+00, -.18032200E+00, 0.85563100E-01, 0.12558700E-01, -.63818100E+00, 0.99495600E-01, -.78587300E+00, 0.22934500E-02, 0.72892600E+00, 0.85693000E-01, 0.88622200E-01, -.17863100E+00, -.63722700E+00, -.90117500E-02, -.59741800E+00, 0.14349300E-01, 0.57609400E+00, 0.41744300E-01, 0.96434100E-02, -.52806500E+00, 0.34687500E-01, -.42106300E-01, -.30551800E-02, -.38413600E+00, -.10057700E+00, -.18364300E+00, 0.37873100E+00, -.17816800E+00, 0.32340800E-01, -.15071600E-03, 0.59034900E+00, -.28477700E+00, -.10772400E+01, -.11518700E+00, 0.89889000E-01, 0.27667600E+00, -.25497600E+00, 0.28779400E-01, 0.18654500E+00, -.68012900E-02, -.62504000E-01, 0.21718300E+00, 0.19615200E+01, -.30930500E+00, 0.16615900E+00, -.90724900E-01, 0.66155800E+00, -.20339700E+00, -.86218000E+00, 0.10154100E+01, 0.84209300E-01, -.46361000E-02, -.26288200E-01, 0.57705600E+00, -.13034800E-01, -.13359700E+00, 0.19097100E+00, -.42768000E-02, -.23099500E-02, -.71776100E+00, -.14975900E-01, -.33185000E-01, -.10952200E-01, 0.17355400E-01, -.59867600E-01, 0.77308500E-01, 0.45864700E-01, -.12396000E+00, -.61246000E-01, 0.76202500E-01, -.31973400E+00, 0.25857000E+00, -.10616900E+01, 0.45316200E-02, -.18846300E-01, 0.70751600E-01, 0.35353400E+00, 0.77175600E-01, -.66624100E-01, -.20269300E+00, -.19217200E-01, 0.22518600E-01, 0.18888600E-01, 0.11420300E+01, 0.26286600E-02, 0.29839300E-01, 0.70092500E-01, -.71501700E-01, -.11084300E+00, 0.11616800E+00, 0.13025700E+00, -.56681600E-01, 0.18880200E+00, 0.34689900E+00, -.14175200E+00, 0.88146100E-02, -.27607000E+00, -.14949500E+00, 0.39217100E+00, -.10884500E-02, 0.63816000E-01, 0.24472900E-02, -.98755100E-01, 0.16853400E+00, 0.44190600E-01, -.14627400E+01, 0.28337000E-01, 0.84487000E+00, -.14932100E+00, 0.11419000E+00, -.13241800E+00, -.12543300E+01, -.18751300E+00, -.57810400E+00, 0.23258000E+00, 0.16165300E-01, -.57861400E-01, -.56663100E-01, 0.24955400E+00, 0.40820700E+00, -.26790300E+00, 0.40002000E-01, 0.36522600E+00, 0.37041100E+00, 0.95209700E-01, -.34238400E+00, -.77447100E-02, 0.32968100E-01, -.20196400E-02, 0.18113000E+00, -.12697600E+00, 0.50380200E-01, -.23136400E+00, -.13972900E-01, -.14036200E-01, 0.74329600E-01, 0.41467200E-01, 0.78001200E-01, 0.69863600E-01, -.40628300E-02, 0.30547000E+00, -.25269100E+00, -.95597300E+00, -.29551700E+00, -.70560800E+00, -.48361400E-01, 0.21122400E-01, 0.88013300E-02, 0.28849300E+00, 0.74016800E-01, 0.61276600E-01, -.49344800E+00, 0.15028600E+00, -.16673700E+00, 0.19016300E+00, -.12237900E+01, -.14036900E+00, -.39038400E+00, -.13971700E+00, 0.23975800E-01, -.34371100E-01, 0.37969000E-01, 0.24704500E+00, -.87117800E-03, -.33362300E+00, 0.25149100E-01, 0.46343700E-01, -.15755400E-01, -.53346800E+00, 0.41059600E-02, 0.25130700E-01, -.81766200E+00, 0.74512000E-03, 0.13609100E-01, 0.48112700E+02, -.31801700E+02, -.41654200E+02, -.27830500E+02, 0.48864300E+02, 0.87363800E+02, -.20867700E+03, 0.10338200E+03, -.51013600E+02, 0.10444400E+03, -.11712700E+02, -.39837900E+02, 0.27704600E+02, -.95987400E+02, 0.97398100E+02, -.26293200E+02, 0.12107000E+03, -.51225000E+02, 0.25139700E+02, 0.98299400E+00, 0.27099200E+02, 0.29270100E+02, 0.33960700E+02, -.38659900E+02, 0.22023800E+02, -.10381400E+02, 0.33036800E+02, 0.10785000E+02, 0.36148100E+01, 0.29912900E+01, -.68101100E+00, 0.80770000E+01, -.23072800E+00, 0.25002700E+01, -.20567500E+01, -.48213000E+00, 0.38050200E+01, -.17733100E+01, -.16300500E+02, -.22633700E+01, 0.78283400E+01, -.50517900E+01, 0.15037500E+01, -.23770000E+01, 0.27054500E+01, -.15840600E+01, 0.80830600E+01, 0.23671400E+00, 0.52972900E+00, -.30310500E+01, 0.74184600E-01, -.13698300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.68796500E+01, 0.15776400E+01, 0.49605100E+01, -.27975800E+01, -.43704000E+01, 0.19275000E+01, 0.64164900E+00, -.45598100E+01, 0.17051600E+01, 0.22545100E+01, -.11949400E+01, -.17530900E+01, -.41195000E+01, -.38701400E+01, 0.53454500E+00, 0.48421900E+00, -.22271600E+01, -.12327400E+01, 0.29808400E-01, -.44829300E+00, -.18704800E+01, 0.32240200E+01, 0.80007300E+00, -.10886000E+01, -.14131500E-01, -.42969200E+00, 0.75175200E+00, 0.30674900E+00, -.44903600E+00, 0.10988700E+01, -.34504600E+00, -.48781000E+00, 0.17854600E+01, -.48681600E-01, 0.29962900E-01, -.15609800E+01, 0.27992000E-01, -.10398500E+01, -.25741300E+00, -.90811800E+00, -.41367700E+00, 0.16114200E+01, 0.25477000E+01, -.42274200E+00, -.25849800E+00, 0.24481700E+00, 0.13608600E+00, 0.13004700E+00, 0.14272100E+00, 0.13993900E+01, 0.66663100E+00, -.17546400E+00, 0.87188000E-01, -.64669600E+00, 0.91810300E+00, 0.46097700E+00, 0.13305300E+00, 0.22112600E+01, -.29855500E-02, -.33591100E+00, -.18987100E+00, 0.21793100E+00, 0.55025900E-01, 0.45347900E+00, 0.40801300E+00, -.79278800E-01, -.33479000E+00, -.29880900E+00, 0.17206500E+00, -.78209700E-02, 0.77427900E+00, 0.59873600E-01, 0.26905000E+00, -.18751300E+00, 0.45507100E+00, 0.66282400E-01, 0.14085400E+00, -.77411300E+00, -.10719000E+00, 0.60946500E+00, -.38854500E-04, 0.97796900E+00, -.10027900E+01, 0.20114100E+00, -.19483400E-01, -.55795000E+00, 0.62497700E+00, 0.22419600E+00, -.19023000E+00, 0.89375800E-01, 0.23189000E+00, 0.45292900E-01, -.67929100E+00, -.48448300E+00, -.20796300E+01, -.24267700E+01, 0.68928700E+00, 0.26332900E+01, -.13716600E+01, 0.31120000E+00, -.12416500E+01, -.59825300E-01, -.57654300E-01, -.13161000E+00, -.53462600E+00, -.22618200E-01, 0.35595600E+00, -.22636700E+00, -.24181700E+00, 0.11888500E+00, 0.86624600E-01, 0.12593200E+00, -.16912500E-01, -.41881900E-02, -.22944400E+00, -.95979900E-01, -.24708500E+00, -.73465700E+00, -.21592400E+00, 0.61963400E+00, 0.14501400E+01, -.13987500E+01, 0.10015200E+00, -.18392600E+01, -.10351700E-02, -.94857100E-01, 0.54164300E-02, -.77480100E+00, -.22016900E+00, -.71479500E-01, 0.19362400E+00, -.50960000E+00, -.30017100E-01, 0.21485000E+00, -.48581900E+00, -.26276500E-02, -.12038400E+00, 0.55154300E+00, 0.71980800E-01, 0.55273200E-02, -.30946300E+00, -.20541000E+00, 0.71165700E-01, -.12103400E+00, -.39991200E+00, 0.32426900E+00, 0.12320400E-01, -.85082500E-01, -.10202800E+00, 0.21076900E+00, -.54841200E-01, -.23650000E+00, 0.43238400E+00, -.85179200E-01, -.50881900E-01, -.11333100E-01, 0.12805600E-01, -.16935300E-01, -.95305700E+00, 0.23689600E+00, -.33596600E-01, -.28359600E+00, 0.74999000E+00, 0.26644800E+00, 0.14633000E+01, -.39459800E-01, 0.97549500E-01, -.42765200E-01, 0.53819800E-01, -.16574100E+00, -.14804800E+00, 0.52233900E+00, 0.40141300E+00, 0.60652600E-01, 0.10958800E+00, -.12743900E+00, 0.33726100E-01, -.11712300E+00, -.34270300E+00, -.20213800E-02, -.11557100E+00, 0.53510100E+00, -.95635100E-01, -.46381800E+00, 0.45565800E+00, -.57972000E+00, -.72200600E+00, 0.28504600E+00, -.12683600E+00, -.48444700E+00, 0.11031300E-02, 0.88775300E-01, -.41264400E-01, -.46265400E+00, 0.39515600E+00, -.50650200E+00, 0.76101200E+00, -.12144500E+00, -.43493800E-01, -.20523000E+00, -.10075500E+01, -.17682300E+00, 0.18450900E+01, 0.90261900E-01, 0.71234300E-01, -.27069500E+00, 0.46298500E+00, 0.32298000E-01, 0.73948900E+00, 0.61511000E-01, -.17876400E-01, -.89693100E-01, 0.94318300E-01, -.24147900E+00, 0.12361900E+01, 0.17007200E+01, -.49981100E+00, 0.10564000E+01, 0.27487200E+01, 0.24996900E+01, 0.33048400E+00, 0.58683800E-01, -.43315700E+00, -.56277800E-03, 0.11086900E+00, -.68083000E+00, -.57093600E+02, 0.48176200E+01, 0.10024800E+02, 0.18515800E+01, -.34680800E+01, -.65882800E+02, 0.31752400E+02, 0.19691600E+03, 0.33637200E+02, -.17749900E+03, -.15500700E+03, 0.84561500E+01, 0.41557700E+02, 0.18283500E+02, -.92017900E+02, 0.70293700E+02, 0.58664600E+02, -.27574600E+02, 0.31733800E+01, -.39202500E+02, -.49717900E+02, 0.18475900E+02, -.31057500E+02, -.36462300E+01, -.12340600E+02, -.89782000E+01, 0.10430100E+03, -.32537500E+01, -.18128200E+01, 0.79147000E+01, -.22970900E+01, -.23413100E+01, -.13273800E+02, -.38702100E+01, -.16615600E+01, 0.11852600E+01, -.81222800E+01, 0.34752700E+02, 0.34027600E+01, -.50164600E+01, 0.39633200E+01, -.64903700E+01, 0.34507900E+01, 0.22409800E+01, 0.43055400E+01, -.50401100E+01, -.89807000E+01, 0.30260500E+01, 0.16585400E+02, -.39000200E+02, 0.14447400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.22778700E+01, 0.39481900E+00, 0.60980100E+00, -.57623100E-01, -.13060400E+01, 0.16019100E+00, 0.20893600E+00, -.78510300E+00, -.91048100E-01, 0.50157900E+00, 0.49627000E+00, 0.17790300E-02, -.56166700E+00, 0.20867600E+00, -.27835200E+00, 0.10840600E+00, 0.54724700E-01, -.33584900E-02, 0.63446900E-01, -.84934500E+00, 0.13386400E+01, 0.21269100E+01, 0.65628900E+00, 0.79115100E-01, -.16932100E-01, -.64593700E+00, 0.78790100E-01, 0.67225300E-01, 0.45982400E-01, -.12168400E+01, 0.53272800E-01, -.75169900E-02, -.96466100E-01, -.25390600E+00, 0.55795300E-02, -.20307500E+00, -.12922700E-01, 0.27669300E+00, 0.16513600E+00, -.12564000E+00, 0.15197400E+00, -.59898100E+00, 0.17034800E+01, -.46302200E+00, 0.61485200E+00, 0.19982600E+00, -.47182700E+00, -.12900600E+00, -.96285400E-01, -.76179100E-01, 0.10605900E+01, 0.43897900E+00, 0.14737100E+00, -.29174900E+00, -.11686400E-01, 0.10272600E+00, -.23813000E-01, 0.47868600E+00, -.14952600E-02, 0.25206700E+00, 0.62847200E-01, -.17133800E+00, 0.80025100E-01, -.63425500E-01, -.22487700E+00, -.18718100E+00, -.15770800E+00, 0.15810100E+00, -.47227900E-01, -.28396000E-02, 0.17221000E-01, 0.10789900E+00, 0.21358800E+00, -.74379800E-01, 0.17546000E+00, 0.50022000E-01, 0.56832800E-01, 0.14920500E+00, 0.80993000E-01, 0.14082700E-01, 0.46317300E-03, 0.31070700E-01, 0.22633800E-01, -.18138400E+00, 0.73232100E-01, 0.26810800E+00, -.12271800E+00, 0.11783700E+00, -.30521100E-01, -.54606000E-01, 0.11810200E+00, 0.42418600E-01, -.24976200E-01, -.56890700E+00, 0.18560400E+00, 0.26115000E+00, -.21077600E+00, 0.26623000E+00, 0.10957000E+00, -.37434600E-01, 0.33443100E-01, -.25987600E-01, -.57443600E-02, -.83767400E-01, -.12674900E+00, 0.18708600E-01, -.34255300E+00, 0.38933500E-01, -.21526100E+00, -.17636100E+00, 0.18387200E+00, -.27818300E-01, -.45698800E-01, -.31798400E-02, 0.11479200E+00, -.21171800E+00, 0.20872800E+00, 0.18760400E-01, -.40726800E-01, -.18608700E+00, -.13228800E-01, 0.13713500E+00, 0.18890600E+00, -.50678200E+00, 0.60979800E-04, -.13142900E+00, 0.12541900E-01, -.29574300E+00, 0.99893400E-02, 0.37574900E-02, -.24766100E-01, -.23933500E-01, 0.16478100E+00, 0.29684900E-01, -.11306400E+00, -.99145700E-03, 0.99313200E-01, -.52801500E+00, 0.12726200E-02, 0.30428700E-01, -.59124600E-01, -.75658200E-01, -.64737000E-01, 0.10188100E+00, 0.76958100E-02, 0.33374900E+00, 0.43430600E-02, 0.30933600E+00, 0.25509700E+00, -.59043100E-01, -.31818900E-01, 0.97279100E-01, 0.22715000E+00, -.18249700E+00, 0.28459900E-01, 0.16347000E-01, -.20906500E+01, 0.39130500E-01, 0.36598500E+00, 0.42000500E-01, 0.98618300E-01, -.10864200E+00, 0.12465100E+00, -.14038900E+00, 0.61329100E+00, 0.35588200E-01, 0.29432300E-01, 0.96146900E-01, 0.11034200E-01, -.14450900E+00, 0.13398000E+00, -.18975200E+00, -.24617500E+00, 0.19458200E+00, 0.40053000E+00, 0.51188600E-01, -.16525800E+00, 0.47489200E-01, 0.26221000E-01, -.25287500E-02, -.16830500E-02, 0.15402200E+00, -.13406600E+00, 0.22497000E-01, -.24992100E+00, 0.50607800E+00, 0.76142000E-01, 0.29412700E-01, -.89898700E-01, -.46724000E-02, -.16054000E-02, -.31318600E+00, 0.11998400E+00, 0.62597300E+00, -.25653900E+00, 0.22726100E-01, 0.38112900E+00, 0.52929800E-01, 0.54310800E-01, 0.30869400E-01, -.58477800E-01, -.11906900E-02, 0.41196700E+00, 0.13329900E+00, -.13389200E+00, -.31548700E+00, 0.50503100E+00, -.86591100E-02, 0.85703500E-01, -.35310400E-02, -.15423700E-01, -.66760600E-01, 0.62957400E-01, 0.63882900E-01, -.59023800E+00, -.70562300E-01, -.32478900E-01, 0.46808800E-01, 0.26885700E+00, -.25305800E+00, -.69822800E-01, -.10651500E-01, 0.18686700E+00, -.25868600E-02, 0.10086500E+00, -.26262900E-01, 0.52314100E-01, 0.14219700E+02, 0.39453700E+01, -.21073500E+00, -.55112300E+01, -.26143500E+02, 0.12811400E+02, 0.22455000E+02, 0.13033400E+02, -.11094300E+02, -.19837500E+02, 0.14439700E+02, 0.81017900E+01, 0.42505400E+01, -.15226900E+02, 0.19133100E+02, 0.50677900E+01, -.23064600E+01, 0.50340900E+01, -.23532800E+01, -.55875500E+01, -.51681500E+01, 0.51786400E+01, 0.11523900E+02, 0.33216900E+01, -.47119500E+01, -.11528300E+02, -.59327400E+00, 0.12773900E+01, -.86888200E-01, 0.11762200E+01, -.91208800E+00, 0.92325600E+00, -.17774000E+01, -.61069700E+00, -.59885800E+00, -.15807100E+00, 0.35451700E+01, 0.57791100E+00, 0.10083800E+00, -.46659500E+00, -.86193800E+00, 0.52443600E+00, 0.15321200E+01, 0.61671300E+00, 0.27170000E+00, -.78729800E+00, 0.10762100E+01, 0.69601200E+00, -.48385000E+01, 0.23527800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.29799000E+01, 0.47102800E+00, 0.71335200E+00, -.21362100E+01, -.20527800E+01, -.22553700E+00, 0.38118800E+00, -.10659700E+01, -.17831700E+00, -.10907000E+00, -.18694600E+01, -.50516400E+00, -.23890800E+00, -.12706000E+01, 0.24856500E+00, 0.35759100E+00, -.58099600E+00, -.15213100E-01, 0.17154000E+00, 0.35033600E+00, 0.94095000E-01, 0.17223300E+01, 0.73370500E+00, -.26940200E+00, -.45294100E-01, -.48336200E+00, -.75288300E-01, 0.15279900E+00, 0.34759000E+00, 0.25463900E+00, 0.28195800E+00, -.23732900E+00, 0.60488100E+00, -.33783100E+00, 0.12576000E+00, -.72262800E+00, 0.24406600E-02, -.24118900E+00, 0.12517900E-02, -.13738000E+00, -.92672200E-01, -.48174700E+00, -.65312200E+00, -.12038100E+00, 0.21408800E+00, -.21035500E+00, 0.29010900E+00, -.28026100E+00, 0.23464000E-02, 0.15439600E+00, 0.44051700E+00, 0.57044100E+00, -.11511300E-01, -.36020700E-01, 0.27164900E-01, -.12855000E+00, -.58102300E-01, -.71960200E+00, 0.13420300E-02, -.33249700E+00, 0.35352800E+00, 0.26450700E+00, 0.27665200E-01, 0.73554700E-01, 0.14924900E+01, 0.36063000E+00, 0.83493100E-01, 0.68362000E+00, 0.35035800E-01, 0.36139000E-02, -.55614100E-01, 0.26442000E+00, 0.70379100E-01, 0.84813500E-02, -.99462400E-01, 0.34501200E-01, 0.22010200E+00, -.17853600E+00, 0.30602700E+00, 0.25865100E+00, -.38054800E-03, -.37154500E+00, 0.10695000E+00, -.11470900E+01, -.10703100E-01, 0.56963700E-01, 0.21856000E+00, -.18141500E+00, -.44237900E-01, 0.93379600E-01, 0.32955100E+00, -.90792400E-02, 0.67990600E+00, 0.20560200E+01, -.84724300E-01, 0.50007800E+00, 0.10227800E+00, -.14605600E+01, 0.37482600E+00, 0.15637600E+00, -.14536700E+00, -.60493900E-01, -.75793000E-01, 0.33673300E+00, -.39832500E+00, 0.29669800E+00, 0.40193000E+00, 0.59195400E+00, 0.70334500E+00, -.30353800E+00, -.22973500E+00, -.58879400E-01, 0.13482300E+00, -.85597200E-03, 0.35227200E+00, -.38362800E+00, 0.25077800E-01, -.28070500E+00, -.15415100E+00, 0.46464600E+00, 0.90537600E+00, -.11581700E+01, -.55769600E+00, 0.91086200E+00, -.36395000E-02, -.16793100E+00, -.12260300E-01, 0.15166100E+00, 0.18415000E+00, 0.12328400E-01, 0.64809100E-01, 0.42994800E+00, -.31454800E+00, -.81630500E-03, 0.33872000E+00, 0.35977600E-02, 0.43164000E+00, 0.23460200E+00, -.53982500E-02, 0.67917100E-01, -.20080200E-01, 0.14388800E-02, 0.21923300E+00, -.14917900E+00, 0.15006200E+00, -.45059400E+00, 0.18459900E-01, 0.50609900E+00, -.39044200E+00, -.29550100E-01, 0.10036000E+00, -.63094400E-01, -.85022000E+00, 0.10987900E+00, 0.27770500E+00, -.24037700E-01, 0.32495500E+01, -.15271700E-01, -.15930600E+01, 0.29704300E+00, 0.33289800E+00, -.57140600E-01, 0.70229100E+00, 0.26379700E+00, 0.14126900E+01, -.23116400E+00, 0.51250800E-01, 0.50294500E-01, 0.40103700E-01, 0.45427300E-01, -.47093600E+00, 0.87044700E+00, -.11756800E+00, -.28713400E+00, 0.35445900E+00, -.77140800E-01, -.74853400E-01, -.43909400E-01, -.66040800E-01, 0.87423400E-03, 0.39133600E+00, -.48847600E-01, 0.53356600E-01, 0.78315600E-01, -.16128800E+00, -.49272700E+00, -.15835300E+00, -.21075800E-01, -.12217300E-01, -.68651900E-01, 0.20917000E-02, 0.50411700E+00, -.36461900E+00, -.40710600E+00, 0.35168000E+00, 0.35212900E+00, -.41644300E+00, 0.12406100E+00, 0.79031500E-01, -.38611200E-01, 0.30609100E-01, -.84050800E-02, -.56237400E+00, -.16074300E+00, 0.34326900E-02, 0.51255900E+00, -.13291700E+00, 0.56304900E-01, 0.21409300E+00, 0.10547300E+00, 0.15123600E-01, 0.41568600E-02, 0.10601600E-01, -.18832400E+00, 0.45877200E+00, 0.52743000E+00, -.94042300E-01, 0.71527300E-01, 0.96090800E+00, 0.53022000E+00, 0.14094700E+00, 0.23314500E-01, 0.63104700E+00, -.40905300E-03, 0.77483700E-01, -.40498500E+00, 0.29376000E+00, -.35484500E+00, 0.11864900E+02, -.40482100E+01, -.12303400E+02, 0.58055300E+02, -.29792200E+02, -.21155400E+02, -.29156000E+02, 0.77744000E+01, 0.28944400E+02, -.11987900E+02, 0.12315900E+02, -.20040900E+02, 0.11433600E+02, -.34105000E+02, 0.77931600E+01, -.36057000E+01, 0.61046800E+01, -.23677000E+01, -.27694100E+00, -.19162800E+02, 0.14005700E+02, 0.20177000E+02, 0.18640600E+02, -.10925500E+02, -.34771400E+02, 0.59354100E+00, 0.14719000E+01, -.10482400E+01, 0.10811200E+01, 0.15525800E+00, 0.48761300E+01, -.76685100E+00, 0.15622000E+00, -.22044700E+00, 0.13773800E+01, -.40796100E+01, -.67423100E+00, -.27920400E+00, 0.58698300E-01, 0.44147800E+00, -.36237200E+00, 0.76884800E+00, -.58699400E+00, -.92795800E-01, 0.52043700E+00, 0.84783000E+00, -.20988800E+01, 0.38966500E+01, -.15090600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.76396500E+01, -.21181100E+01, 0.35073100E+01, -.10975000E+01, 0.48269200E+01, 0.15735000E-01, -.95608900E+00, 0.30028700E+01, 0.58233000E-01, -.90606700E+00, 0.22566700E+00, -.54959700E-02, 0.60478800E+00, 0.29945600E+01, -.57296700E-01, -.25482500E+00, 0.51808500E+00, 0.14464800E+00, -.35613900E+00, -.31108700E+00, -.38711400E+00, -.33956900E+01, -.11516800E+01, -.20341000E+00, 0.16083100E+00, 0.11904200E+01, 0.40229200E+00, 0.25370500E+00, -.42882000E+00, -.39295200E+00, -.17807400E+00, 0.44053200E+00, -.93488100E+00, 0.55457600E+00, -.20929500E+00, 0.52662800E+00, -.20578600E-03, 0.96721600E-01, -.11154700E+01, -.11632000E-01, 0.12569700E+00, 0.16359100E+01, 0.51235400E+01, 0.58796900E-01, 0.44318100E+00, -.13380000E+01, 0.62379400E-01, 0.32041900E+00, 0.49662800E+00, 0.95582300E+00, -.10081900E+01, -.17205200E+01, -.27900000E+00, -.27850300E+00, 0.39143800E+00, -.22796900E+00, 0.24075800E+00, -.94558500E-01, 0.31095400E-02, 0.60026500E+00, 0.15166300E-01, -.74373600E+00, 0.13383700E+00, 0.10943400E+01, -.26064500E+01, 0.44126200E+00, 0.78442400E+00, -.66995500E+00, 0.35792700E+00, -.25457300E-02, 0.21589700E+00, 0.58285400E-01, 0.22043200E+00, 0.63301800E-01, 0.33627700E+00, -.20282100E+00, -.52141700E+00, -.46911900E+00, 0.45348000E+00, -.85601600E-01, 0.23607000E-02, 0.13940000E+01, 0.63386400E+00, 0.64457600E+00, -.16501800E+00, -.15257300E+01, 0.10916500E+01, 0.11275400E+00, -.13686800E+00, 0.65278600E-01, 0.95039500E+00, 0.20367800E-01, 0.88078700E+00, 0.64024000E+00, -.12724800E+01, -.12091900E+01, -.76392600E-01, 0.26237000E+01, -.98976400E+00, -.30269700E+00, 0.74723500E+00, 0.22525900E+00, -.17605000E+00, -.52738400E-01, -.17825400E+00, 0.57216000E+00, 0.55492400E+00, 0.38330400E+00, -.57017200E+00, -.41499900E-01, -.45418800E+00, -.73926700E-01, 0.21614700E+00, -.70931600E-02, -.86059200E-01, 0.54934700E+00, -.27068800E+00, -.19685100E+00, 0.10312800E+00, 0.51263900E+00, -.92718500E-01, 0.64174200E+00, 0.94163300E+00, -.36294700E+00, 0.13306500E-01, 0.27382500E+00, -.30315300E+00, -.17085300E+01, -.15040500E+00, 0.16236500E+00, 0.28608600E-01, -.24485100E+00, 0.21394900E+00, 0.54136600E-01, 0.33502900E+00, -.89830000E-02, -.38917300E-01, -.52184400E+00, 0.81490800E-01, -.10113100E+00, -.33181900E-02, 0.88519800E-01, -.16688300E+00, -.77331300E-01, 0.51753800E+00, 0.56701400E+00, 0.55932700E-01, 0.66617700E+00, 0.36711400E+00, 0.10773200E+00, 0.15175700E+00, -.13428900E-01, -.29250700E+00, -.67052600E+00, -.27096500E+00, 0.93406700E-01, -.25280500E+01, 0.17873500E-01, -.95509300E+00, 0.75419400E+00, 0.47618900E-01, -.38402400E+00, -.77171100E+00, 0.25107100E+00, 0.69099300E+00, 0.18454300E+00, 0.13406000E+00, 0.18221000E+00, -.79334300E-02, 0.22594900E+00, 0.58388300E+00, 0.26308900E+00, 0.83250300E+00, 0.66957300E+00, 0.54246700E+00, 0.31201100E-01, -.21379100E+00, -.91238700E-01, -.11103300E+00, -.46457600E-02, 0.77595900E-01, 0.79873500E+00, 0.10844800E-01, -.78110400E+00, 0.14230800E+01, -.13660800E+00, 0.24669500E+00, -.22602300E+00, 0.23442300E+00, 0.14887800E+00, -.54263900E-02, 0.32884600E+00, -.21834900E+00, 0.11241700E+00, -.58210800E+00, -.10376500E+01, -.24925000E+00, 0.25693200E-01, 0.49217700E+00, 0.50116300E+00, 0.93768400E+00, 0.12533900E+00, -.50987700E+00, 0.15238800E+00, -.59307100E+00, -.30387700E+00, -.37660000E+00, 0.36579900E+00, 0.34796500E+00, -.55729700E+00, 0.31957800E-01, -.12311700E+00, 0.10746100E+00, -.77377700E+00, -.13725800E+01, -.13273300E+01, 0.35471300E+00, -.73120300E+00, -.18996600E+01, -.20162300E+01, -.17545500E+00, 0.38899200E-01, 0.11091000E+01, -.11969400E-01, -.36345300E-01, 0.53777200E+00, -.31133900E-01, -.94326900E+00, -.18642600E+00, -.11471100E+02, 0.90051400E+02, 0.11402100E+02, -.82439400E+01, -.56260400E+02, -.61216000E+01, 0.41734300E+02, 0.78062800E+02, 0.15789300E+02, 0.75517200E+01, 0.14521100E+01, 0.43698700E+02, -.50252400E+01, 0.32494000E+02, -.15894800E+02, -.11186500E+02, -.98069000E+01, 0.36778400E+01, 0.99323000E+01, -.33474500E+02, -.14749900E+02, -.30130700E+02, 0.24545100E+02, -.25440500E+02, 0.54326800E-01, 0.30571200E+01, -.35242800E+01, 0.44099300E+01, 0.29837800E+01, 0.51663700E+01, -.33644900E+01, 0.85159300E+00, -.13208400E+01, 0.62888700E+01, 0.26587800E+02, -.12801600E+01, -.13610200E+02, 0.12857900E+02, 0.43618800E+01, 0.72816700E+00, -.11911600E+02, -.82509600E+00, -.14125400E+02, 0.31594200E+01, -.11564400E+02, -.11324100E+02, 0.12415400E+02, -.62207700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.71337500E+01, -.20902700E+01, -.11667000E+01, -.31000300E+00, 0.48802900E+01, -.16737800E+01, -.79470700E+00, 0.57035000E+01, -.13140000E+01, -.22062800E+01, 0.23095800E+01, 0.18670000E+01, 0.50267000E+01, 0.28318200E+01, -.37390600E+00, -.75008300E+00, 0.16711400E+01, 0.22593000E+01, 0.94434500E-01, 0.14780200E+00, 0.11791200E+01, -.39082100E+01, -.49755300E+01, 0.21204800E+01, -.44422000E-01, 0.89528100E+00, -.45339400E+00, -.36909200E+00, -.44566500E+00, -.25446700E+01, 0.30607100E+00, 0.51924800E+00, -.23268800E+01, -.18994200E+00, -.18071100E+00, 0.19469400E+01, 0.11920500E-01, 0.70173400E+00, -.83017000E-01, 0.12335700E+01, 0.14015700E+01, 0.58108000E+00, 0.15400700E+01, 0.65269500E+00, 0.43037400E+00, -.17945800E+01, 0.12984000E+01, 0.33054700E+00, 0.63109500E+00, -.48229800E+00, -.28997600E+01, -.18689600E+01, -.48454600E+00, 0.30136200E+00, 0.59203100E-01, 0.42791000E+00, -.11239500E+00, -.22876100E+01, 0.61291500E-02, -.13913600E+00, -.37689200E+00, 0.12829300E+00, -.26615000E+00, 0.27178000E+00, -.24936600E+01, 0.54850300E+00, 0.15671100E+01, -.11673100E+00, 0.47213800E+00, 0.10509000E-01, -.81594800E+00, -.21525200E+00, -.75278500E+00, 0.19240400E+00, -.39957400E+00, -.12483500E+00, -.48253000E+00, 0.23786700E+00, -.10492200E+01, -.28900300E+00, -.12612900E-02, 0.75873700E+00, -.55880600E+00, 0.29895300E+01, 0.96993800E-01, 0.61702200E+00, 0.89543000E+00, 0.41991100E-01, 0.34243800E+00, -.10854000E-01, -.59608000E+00, -.37818100E-01, 0.66819600E+00, 0.11879300E+01, 0.11464700E+00, -.75754100E-02, -.46943400E+00, 0.21909100E+01, -.55193400E+00, -.36383900E+00, 0.17598700E+00, 0.52998800E-01, -.22166500E+00, 0.13481100E-04, -.58132900E+00, 0.31618900E+00, 0.32859000E+00, -.61670300E+00, 0.20618600E-01, 0.12870700E+00, -.13772900E+00, -.49189700E-01, 0.30278700E+00, 0.83908900E-02, -.16990600E+00, 0.13978700E+01, -.75228200E+00, 0.14295100E+00, 0.35620200E+00, 0.16782800E+00, -.21037800E+01, 0.19249700E+01, 0.65034400E+00, -.10059100E+01, -.72974200E-02, 0.10414500E+01, -.50114900E+00, -.11127700E+01, 0.34916400E-02, 0.14324200E+00, -.16343300E+00, -.51567500E+00, 0.69207100E+00, -.63545500E-01, 0.15255800E+01, 0.16142400E-02, 0.54659400E+00, -.14009200E+01, -.22162300E+00, -.40799000E-01, -.61046300E-01, 0.34236700E+00, -.64885700E-01, 0.42280000E+00, 0.83006000E+00, 0.86199600E+00, 0.58957600E-01, 0.16466900E+01, 0.12889000E+01, 0.11387300E+00, 0.18736200E+00, 0.39463500E+00, -.94397400E+00, -.43872700E+00, 0.91840600E-02, 0.11283100E+00, -.38307700E+01, 0.78877400E-01, 0.86426300E+00, -.35892100E+00, 0.19671200E+00, -.43899600E+00, 0.13693600E+01, -.99868500E-01, 0.44898800E+00, 0.90002100E-02, 0.73434100E-01, 0.24927300E+00, -.54442700E-01, 0.88019900E+00, 0.64085400E-02, 0.29324900E+00, -.72551600E+00, 0.46830200E+00, 0.27173900E+00, -.74158000E-01, -.28762200E+00, 0.12395400E+00, -.15713300E+00, -.19165300E-02, 0.54174600E-01, 0.39433300E+00, -.63936100E+00, -.73540100E-01, -.39546400E+00, -.79517900E+00, 0.25479500E+00, 0.63675100E-01, 0.21594600E+00, 0.22176900E+00, -.17083100E-02, -.65337700E+00, 0.44307600E+00, 0.30876900E+00, -.46600000E+00, -.23122200E+01, 0.84819800E+00, -.41699100E+00, 0.37383700E+00, 0.42681400E+00, 0.66114000E+00, 0.59490100E-03, -.94629500E+00, -.27300400E+00, 0.66481900E+00, -.12538800E+01, -.21183600E+01, 0.94269700E-01, -.54271200E-01, -.30078800E-01, -.72994600E-01, 0.12233400E-01, -.15526600E-01, 0.28260400E+00, 0.13722000E+01, -.71659400E+00, 0.67982400E-01, -.13695900E+00, -.28047700E+01, -.12537900E+01, -.96643200E-01, -.27277700E-01, 0.24630300E+01, 0.86449200E-03, 0.40826900E+00, -.11453600E+01, -.67532200E-01, 0.10658800E+01, 0.14066200E+01, 0.50921300E+00, 0.15010200E+03, -.21834400E+01, -.12300500E+01, -.47784900E+02, 0.13296000E+01, 0.55474100E+02, 0.28354100E+02, -.28668000E+02, -.33864800E+02, 0.28272700E+02, 0.26602300E+02, -.14163600E+02, -.29187000E+02, 0.13635200E+02, -.24873900E+02, 0.10661700E+02, 0.16833900E+02, 0.15543100E+02, -.10174800E+02, -.31554000E+02, -.16375800E+01, 0.21224400E+02, 0.76021000E+01, 0.13522100E+00, -.37277300E+01, -.65013400E+00, 0.45768100E+01, 0.15366100E+01, -.16883900E+01, 0.38146800E+01, 0.11585700E+01, 0.15558300E+01, 0.65587000E+00, 0.12128500E+01, -.24310400E+00, -.75468000E+00, 0.64661200E+00, 0.30767300E+01, -.37273300E-01, -.32030900E+01, -.34494100E+00, -.11008500E+01, 0.83594200E-01, -.18966800E+01, 0.22271100E+01, 0.12065500E+02, 0.42719900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.16533800E+02, 0.57902500E+01, 0.19803500E+01, -.22709700E+01, -.12510500E+02, 0.17803700E+01, 0.22290700E+01, -.75279200E+01, 0.63921100E+00, 0.34840700E+01, 0.51401400E+01, 0.64132900E+00, -.50159200E+01, -.53684700E+01, -.98365300E+00, 0.78790500E+00, -.28686700E+01, -.58569600E+01, 0.91376100E+00, 0.12311600E+00, -.24784900E+01, 0.41496000E+01, 0.16839700E+02, -.72759400E+01, -.23296200E+00, 0.10629300E+01, 0.99193700E-01, -.77960200E-01, 0.32950900E+01, -.20611400E+00, -.51280000E+00, -.64533400E+00, 0.25021900E+01, 0.33175300E-01, 0.25555800E+00, -.11001900E+01, -.75412600E-01, -.65905100E+00, 0.33783200E+00, -.19700600E+01, -.25511300E+01, -.86754700E+00, 0.68302800E+01, -.31435400E+01, 0.15709100E+00, 0.39317400E+01, 0.12931600E+01, 0.97332200E-01, 0.26458200E+00, 0.13256500E+01, 0.21712700E+01, 0.17508600E+01, 0.57599900E+00, -.91719800E+00, 0.15094600E+01, 0.25307600E+01, 0.21163800E+00, 0.63130200E+01, -.98825500E-02, -.25003400E+01, -.65475900E+00, -.17308200E+01, 0.10038900E+01, -.11022100E+01, 0.32990900E+01, -.91510600E-01, -.26955400E+01, -.55798000E+00, -.42024600E+00, -.25947900E-01, 0.13433500E+01, -.21104700E+00, -.61772600E-01, -.52461400E+00, -.50474700E+00, 0.77031600E+00, 0.12115900E+01, -.54376900E+00, -.37314000E+00, 0.12179200E+01, -.47811500E-02, 0.37094300E+00, -.30298600E+01, -.15761600E+01, -.11689200E+00, 0.45745500E+00, -.12746200E+01, 0.10714900E+00, -.26889500E+00, 0.33288900E+00, 0.92209100E+00, 0.28763000E+00, -.13155800E+01, 0.41158700E+00, 0.14526700E+01, 0.21277700E+01, -.89296700E+00, -.13376200E+01, 0.30527500E+00, -.92315500E+00, 0.36445300E+00, -.23468000E-01, 0.40680700E+00, 0.73106500E+00, -.78149100E+00, -.17503300E+01, -.16538900E+01, -.75761700E+00, -.48265500E+00, 0.26176900E+00, 0.20218300E+01, -.95258800E-01, -.17925400E+00, 0.30058100E-01, 0.81061300E+00, -.10934000E+01, 0.22278400E-01, 0.15086000E+00, 0.23164900E+00, -.47652800E+01, 0.99966300E+00, -.23760500E+00, 0.32244100E+01, -.16724800E+01, -.35783400E-02, -.23979200E+01, 0.16855600E+01, 0.28004600E+01, 0.28568800E+00, 0.19484100E+00, 0.14912700E+00, -.39520200E+00, 0.35559500E+00, 0.38058400E+00, -.10612600E+01, 0.13051400E-01, -.78449000E+00, 0.10089400E+01, -.23799700E-01, -.61151200E-01, 0.40234700E+00, -.41153900E+00, -.21855400E+00, 0.11677600E+00, -.13692900E+01, -.11383500E+01, -.18737100E-01, -.10430800E+01, -.10800400E+01, 0.63720400E+00, 0.12954600E+00, -.39923600E+00, -.13100400E+01, -.74526500E+00, -.10301300E+00, 0.71215600E-01, 0.15290500E+01, -.10984800E+00, -.97814600E+00, 0.86090600E+00, -.29350300E+00, -.12908900E+00, -.13179000E+01, -.60605500E+00, 0.42595000E+01, 0.53668600E+00, 0.36058300E+00, 0.42041100E+00, 0.63353700E-01, 0.17192500E+00, 0.18601700E-01, -.20295900E+01, 0.18681400E+01, 0.10929800E+01, 0.11566800E+01, 0.60053000E-01, -.26567100E+00, -.19199600E+00, -.53578600E+00, -.13518400E-01, -.10118300E+01, 0.10337300E+01, 0.13997000E+00, -.18819100E+01, 0.14237700E+01, 0.14774900E+01, 0.13036800E+00, 0.80376100E-01, -.53552000E+00, 0.22227800E+00, -.10005500E-01, -.13582100E+01, -.44317100E+00, 0.44466800E+01, -.15270900E+01, -.83638400E+00, 0.21866500E+01, 0.14835600E+00, 0.42131300E+00, 0.29268900E+00, -.27428200E+00, 0.31838300E+00, 0.22307100E+01, 0.13779600E+01, -.18572600E+01, -.18484400E+01, 0.74921400E+00, 0.79591600E+00, 0.21478600E+01, -.59978200E+00, 0.36083800E-01, -.35053600E+00, 0.34376700E+00, -.44091400E+01, 0.10357000E+01, 0.16463500E+01, 0.59307700E-01, 0.27872200E+01, 0.18995900E+00, 0.65661700E+00, -.77314800E+00, 0.76542800E-02, -.43264600E+01, -.18498200E-02, 0.47960200E+00, 0.34095300E+01, 0.73841300E+00, 0.31319000E+01, -.36686500E+01, -.14877600E+00, -.21659700E+01, 0.63724100E+03, -.32703200E+03, -.30958800E+03, -.31764900E+03, 0.19231000E+03, 0.14631500E+03, -.15072900E+03, 0.17551200E+03, -.18453200E+03, 0.97833500E+02, -.41021200E+03, -.18344400E+03, 0.89721700E+02, 0.89127100E+02, 0.74505000E+02, 0.52398200E+02, 0.43192300E+02, 0.24535600E+02, -.10555300E+03, 0.76087000E+02, 0.24762600E+02, 0.15752200E+03, 0.15229800E+01, -.63517000E+01, 0.12055400E+01, 0.10159500E+02, 0.56892900E+01, -.87302000E+01, 0.29366400E+01, 0.87378800E+01, 0.46373300E+00, 0.39872400E+01, 0.99032100E+02, -.29117600E+01, -.11629600E+02, 0.87975800E+01, 0.98542600E+00, -.17540600E+01, -.59373900E+01, -.10641800E+01, -.10786200E+02, 0.83787200E+01, 0.98629300E+00, -.50573400E+01, 0.32673800E+02, 0.14509400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.52277800E+01, 0.55770400E+00, -.18821400E+01, 0.38703600E+01, 0.58271100E+01, 0.19750400E+01, -.14027900E+01, 0.12115000E+01, -.67924900E+00, -.96948500E-01, 0.35535300E+01, 0.26027400E+01, 0.38439100E+01, 0.58339500E+01, -.87426700E+00, -.58333300E+00, 0.16707100E+01, 0.21567000E+01, 0.38176200E-01, -.86087100E+00, 0.11217300E+01, -.43022800E+00, 0.47724300E+00, -.87284500E+00, 0.13620100E+00, -.24434100E+00, 0.10247100E+00, 0.83846200E+00, 0.78098700E+00, 0.38090200E+00, 0.68282100E+00, 0.42869000E+00, -.12704900E+01, -.51100400E+00, -.70926900E-01, 0.94808900E+00, -.54412300E-01, 0.46894000E-01, -.22707200E+00, 0.37787100E+00, 0.46211300E+00, -.87036200E+00, 0.19896600E+01, -.10576700E-01, -.12254300E+01, -.78993000E+00, -.15402200E+00, -.40255000E+00, -.40309800E+00, -.11022400E+01, 0.56454200E+00, 0.17561100E+01, 0.29348600E+00, 0.37985900E+00, -.64086700E+00, -.35488100E+00, 0.59575900E+00, -.20983400E+00, -.16240500E-02, 0.21675800E+00, -.16495300E+00, -.19107500E+01, 0.53836200E+00, -.58568300E+00, 0.66028800E-01, 0.11702700E+00, 0.13296000E+00, -.12286100E+01, -.14637800E+00, -.97256800E-02, 0.11498100E+01, -.79661800E+00, -.40199200E+00, 0.54132400E+00, -.13442600E+00, 0.17412700E+00, 0.11988900E+00, 0.41070100E+00, 0.11338900E+01, 0.11568700E+00, -.39162400E-03, -.21103500E+01, 0.11150900E+01, 0.16838000E+00, 0.33662700E+00, -.11136700E+01, -.21629600E+00, -.56494900E+00, -.10439900E+01, -.12497700E+00, -.28762100E+00, -.41507200E-01, -.24587300E+00, -.11075400E+01, -.27765800E+00, -.69297600E+00, 0.23832100E+00, -.14670500E+01, 0.54856800E-01, 0.28263300E-01, 0.99922500E+00, 0.15943400E+00, -.14169800E+00, -.24218200E+00, 0.96948500E+00, -.18318200E+00, -.66663100E-01, -.10059200E+01, 0.42722400E+00, 0.75882900E+00, -.13279500E+01, 0.11914400E+00, -.31668200E+00, -.18610700E-01, 0.93160600E-01, 0.37100900E+00, -.76284400E+00, -.41518800E-01, -.11971300E+00, 0.14362100E+01, 0.30889800E+00, -.61313100E+00, 0.64957600E+00, -.52350600E+00, 0.24111300E-01, 0.80630800E+00, -.40212000E+00, -.15393300E+01, -.31512800E+00, -.37862500E+00, -.12643100E+01, 0.99503300E+00, -.22293300E+00, -.26790500E+00, 0.14437900E+01, -.19545300E-01, 0.10315500E+01, -.32075000E-01, 0.24376000E+00, -.39139300E-01, -.15719800E+00, -.21726200E+00, 0.89352600E-01, -.47409100E+00, 0.71292400E+00, 0.28880200E+00, 0.31088800E-02, -.27240800E-01, -.77487700E+00, 0.60812800E+00, -.13996900E-01, 0.26530200E+00, -.15669700E+01, -.34159100E+00, 0.10176700E+00, 0.60764400E-01, 0.84019200E+00, -.18458000E-01, -.18995500E+01, 0.51354500E+00, 0.37902900E+00, 0.60475000E-01, -.12424600E+01, 0.12902600E+00, 0.14533000E+01, -.31813200E+00, 0.44231500E+00, 0.60121200E-01, -.18741000E-01, -.33172600E+00, 0.87222400E-01, -.18548900E+00, 0.46362800E+00, -.69513600E-01, -.16286200E+00, 0.30028700E+00, -.30383600E+00, -.66465200E-01, 0.34633300E+00, 0.43440000E-02, -.82916400E+00, -.10707000E+01, 0.69181300E+00, 0.23753900E+00, -.46174100E-01, 0.10961000E+01, -.23249100E-01, -.18100000E+00, -.59366700E-01, -.37652200E+00, 0.56627900E-02, 0.28124900E+00, 0.35162700E+00, -.12325000E+01, -.13253800E+00, -.92287700E-01, -.32242100E+00, 0.13311100E+00, -.12688200E+00, -.17033700E+00, -.88097500E-01, 0.45651300E-01, 0.27504600E+00, 0.21189600E+00, -.52833500E+00, 0.72844300E+00, -.96122900E-01, 0.16370300E+00, -.14858300E+00, 0.26616800E-01, 0.84336200E-01, -.89204800E-02, 0.24877500E-01, -.44990800E+00, -.31403900E+00, -.16346900E+00, 0.12847000E+00, -.29857200E+00, 0.16852500E+01, -.24057600E+00, -.14258000E+00, -.63927500E-01, -.67952000E+00, -.58877700E-02, -.17009900E+00, 0.10977900E+01, -.61263600E-01, -.31452900E+00, -.10021000E+01, -.13325300E+00, -.55650700E+00, 0.19935300E+00, 0.37689700E+02, 0.14737900E+02, -.14862700E+00, -.19926000E+02, 0.15377300E+02, -.18214400E+02, 0.31271800E+01, -.14777700E+02, 0.11671600E+02, 0.48700200E+01, 0.28644200E+02, -.14045300E+02, -.16784200E+02, -.10432600E+02, -.14975100E+02, -.25598800E+02, 0.12806300E+02, 0.17469200E+02, 0.15047200E+02, -.22346900E+02, -.20689600E+02, 0.90727800E+00, -.21423900E+01, -.83685300E+00, -.38829900E+01, 0.10435300E+01, -.15985400E+01, 0.87991700E+00, 0.55504100E+00, 0.40291800E+00, 0.11560600E+01, -.30595900E+01, -.11651400E+01, -.12193200E+00, 0.41514800E+00, 0.28520900E+01, -.72799800E+00, 0.45354000E+00, -.13242200E+01, -.14064000E+00, -.42664300E+00, -.28724400E+00, -.51960900E+00, -.14218900E+01, 0.11725900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13527500E+02, 0.34053000E+01, 0.97647000E+00, -.30710100E+01, -.87617800E+01, 0.13803900E+01, 0.15531300E+01, -.41933400E+01, 0.72358300E+00, 0.19556600E+01, 0.22170000E+01, -.21166200E+01, -.51093900E+01, -.44294100E+01, -.36075500E+01, 0.10809700E+01, -.15017000E+01, -.17643800E+01, -.58612900E+00, -.40908800E+00, 0.26629500E+00, 0.84841800E+00, 0.45331700E+01, -.24360600E+00, 0.90652500E-01, 0.10317900E+01, -.87476400E+00, -.24722500E+01, -.11959300E+01, 0.82222700E+01, -.16804500E+01, -.15371100E+01, 0.29232400E+01, -.82649300E+00, -.10093300E+00, -.22139400E+01, -.13266200E+00, 0.10767600E+01, 0.35128700E+01, 0.16688200E+00, 0.12642900E+01, -.96468600E+00, -.39781700E+01, -.88912800E-01, -.15706200E+01, 0.86300400E+00, -.27139300E+00, -.20498500E+01, -.19382800E-01, 0.50631200E+00, 0.14422900E+01, 0.14780700E+01, 0.51499000E+00, 0.16090700E+00, -.35485500E+00, 0.42891700E+00, 0.39281800E+00, 0.16753400E+01, 0.31623900E+00, 0.24224300E+00, -.20894200E+00, 0.93195100E+00, 0.35646200E-02, -.16000800E+00, -.93780300E-01, -.10175300E+01, -.39283300E+00, -.16700900E+00, 0.23424200E+00, 0.65284100E-03, -.97289500E+00, -.33436800E+00, 0.12732200E+00, 0.22537600E+00, -.10923200E+00, -.32543700E+00, 0.13664700E+00, -.74147800E+00, 0.62304000E+00, -.30900400E+00, 0.15559100E-02, 0.56405800E+00, 0.47975200E+00, -.54502200E+01, -.52304700E+00, -.30217600E+00, -.68567000E+00, -.40757900E+00, 0.10541700E-01, 0.36468000E+00, -.47388100E-01, -.26908600E-01, 0.85819700E+00, 0.49542800E+01, -.13552600E+00, 0.81587700E+00, 0.11056800E+00, 0.10497900E+01, 0.59463400E+00, -.16033100E+01, 0.13626000E+01, -.28050500E+00, -.24909400E+00, 0.15740800E+00, -.38264500E+00, 0.13687400E+01, 0.15625000E+01, 0.21630100E+01, -.58939600E-01, -.10392500E+01, 0.12740600E+01, -.73478000E-01, -.45671600E+00, -.65865800E-02, -.76915300E+00, 0.13086100E+01, -.10236300E+01, -.33372500E+00, -.29980900E+00, 0.46104100E+00, 0.10847300E+01, -.30922500E+01, -.10093400E+01, -.42936600E+01, -.14130700E-01, 0.27779300E+00, -.38291000E+00, -.19320900E+01, -.10291100E+01, 0.25294700E+00, 0.66931500E+00, -.84184300E-01, 0.10479300E+00, 0.54903100E-01, 0.36002900E+00, -.10245300E-01, 0.71282000E+00, -.12226000E+01, -.34934800E-01, 0.23384000E+00, -.31962000E+00, -.21269200E+00, 0.62676200E-01, -.23811200E+00, -.10560000E+01, -.85576900E+00, -.73394700E-01, -.48137400E+00, 0.61661200E+00, -.97301500E+00, -.18230600E+00, 0.11080600E+01, 0.30079700E+00, 0.11424100E+01, 0.10869500E+00, -.25846400E+00, -.65031500E+01, 0.20164000E+00, 0.30460400E+00, -.54508400E-01, -.10181900E+00, -.98899400E+00, 0.24647700E+01, 0.95002200E-01, -.61125000E+00, -.51481300E+00, -.97210200E-01, 0.46548800E+00, -.17362400E-02, -.49041800E+00, 0.54652600E-01, -.67417900E+00, 0.21814600E+01, -.77366300E+00, -.71825400E+00, 0.36933200E+00, 0.68387900E+00, -.76383600E-02, 0.45408000E+00, 0.98347700E-04, 0.61104500E+00, -.13861100E+01, 0.34261200E+00, 0.38330900E+00, -.38303600E+01, -.11429600E+01, -.29307000E+00, 0.85594300E+00, -.52538600E+00, 0.64089100E+00, -.86917900E-02, -.24197800E+01, 0.80539200E+00, 0.54483000E+00, -.76063200E+00, 0.17266700E+01, 0.75126700E-01, 0.39277900E+00, -.52957600E+00, -.17529600E+01, -.11805100E+01, 0.13457500E+00, 0.19979200E+01, 0.20574700E+00, -.14637600E+01, 0.49929700E+00, -.42420300E+00, 0.66578300E-01, -.10207300E+01, -.36030100E+00, 0.12662600E+00, 0.14103100E+00, -.18043700E+00, 0.84426200E+00, 0.15623400E+00, -.15186900E+01, 0.66374200E+00, -.72121500E+00, 0.35379300E+01, -.38391400E+00, 0.49396200E+00, -.66153000E-01, -.42261900E+00, -.97559700E-02, -.46927500E+00, -.11683600E+00, -.67923500E+00, 0.89494800E+00, 0.15473000E+00, -.32719400E+00, 0.39950200E+00, 0.18665000E+00, 0.19389600E+00, 0.12923600E+03, -.12126500E+01, 0.40023800E+02, 0.51588600E+02, -.13182700E+02, -.40392000E+02, -.50475000E+02, 0.56795100E+02, 0.42386800E+02, 0.21336500E+03, -.10479400E+03, -.12197300E+03, -.10288200E+03, -.81356900E+02, -.10447200E+03, 0.89800300E+02, 0.10484700E+03, -.11279000E+02, -.83721500E+02, -.12008700E+03, -.67109800E+01, -.10368900E+02, -.10149500E+01, -.36543300E+02, -.30615800E+01, -.21548300E+01, 0.16119600E+02, -.58178900E+01, -.20703400E+01, -.31134100E+01, -.66588800E+02, 0.39811800E+01, 0.15356900E+02, -.14836700E+02, -.92759800E+00, 0.40977200E+01, 0.13397500E+02, 0.28645000E+01, 0.15364200E+02, -.70964000E+01, 0.96858500E+01, 0.41739400E+01, 0.23656800E+01, 0.37316100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.46207000E+01, 0.15099300E+01, 0.45232700E+00, -.28327500E+01, -.32279700E+01, 0.61313500E+00, 0.57405600E+00, 0.72174000E-01, -.71640000E-01, 0.40785100E+00, -.13110900E+01, -.15122200E+01, 0.91971300E+00, -.38887300E+01, 0.47680900E+00, 0.34011400E+00, -.21294200E+01, -.37297300E+00, 0.59775000E+00, -.59805700E-01, -.14053700E+01, 0.38508400E+01, 0.32966700E+00, 0.23929300E-01, -.33348500E-01, -.22492400E+01, 0.78856400E-01, 0.32134100E+00, -.13288300E+00, -.26255500E+01, 0.91954500E+00, -.16903300E+00, 0.10993200E+01, 0.51824000E+00, 0.42103500E-01, -.82088100E+00, -.33034500E-01, -.73758800E+00, -.66071700E+00, -.61034500E+00, -.10529500E+01, 0.35726500E+00, -.13416000E+00, -.22669200E+00, 0.29671400E+00, 0.58621600E+00, 0.43571900E+00, -.11594700E+00, -.12545500E+00, 0.72546800E+00, 0.15274500E+01, -.21323700E-01, 0.14528500E+00, -.35362300E+00, 0.10829600E+01, 0.78364800E+00, -.14372000E+00, 0.17819600E+01, -.98440900E-02, -.63095500E+00, 0.57522400E+00, 0.17408900E+01, -.95042000E-01, -.26390500E+00, 0.37543200E+01, 0.12157900E+00, -.92657600E+00, 0.12925700E+01, -.18594100E+00, -.92121800E-02, 0.15160800E+00, -.23584600E+00, -.38979600E+00, -.36572000E+00, -.63930400E+00, 0.91679700E-01, 0.34923000E+00, 0.12633900E+00, -.90780800E+00, 0.30023200E+00, 0.38085100E-03, -.57027400E-01, -.11697900E+01, -.18647200E+01, 0.96526700E-02, 0.12225300E+01, -.78476900E+00, -.26151700E+00, 0.18568200E+00, 0.18040500E+00, 0.23457300E+00, -.28159000E-01, -.32988200E+00, -.11676100E+01, -.11830200E+01, -.74719000E+00, 0.35595700E+00, 0.40824300E+00, -.24132800E-01, 0.21735700E+00, -.26950900E+00, -.41413900E-01, 0.38342900E-01, -.10366300E+00, -.38599400E+00, 0.26505100E+00, -.63390600E+00, -.10557300E+01, -.10426400E+01, 0.97810400E+00, -.10544800E+01, 0.10220400E+00, -.49313100E-01, 0.13225400E-01, -.29395100E+00, 0.15860600E+00, -.14368400E+00, -.59164000E+00, 0.19710700E+00, 0.51587800E+00, 0.26986500E+00, -.38436700E+00, 0.24100000E+00, -.81724500E-02, 0.23934300E-02, 0.23868100E+00, 0.12531200E+00, 0.77036700E+00, 0.56825000E-01, -.30719000E+00, -.58377400E+00, 0.20793100E+00, -.64493800E-02, 0.76262300E-01, 0.66357200E+00, 0.16670100E-02, 0.27668200E-01, 0.53554300E+00, 0.51050800E-01, -.12197000E+00, 0.21564400E-01, -.69322600E-01, -.62726600E-02, 0.92046500E-02, -.49581500E-01, -.35110500E+00, -.95066000E-01, -.98616700E-01, -.29666000E+00, -.55020100E-02, 0.23748400E-01, 0.26709000E-01, -.26059800E+00, -.12072700E+00, 0.73284800E-01, -.11560600E-01, 0.29964900E+00, -.11569600E+00, 0.41464600E+00, 0.56121100E-01, 0.71882800E-01, -.38728300E-01, -.39893900E+00, -.78659100E-01, -.40414100E+00, 0.73768000E-01, 0.31710300E-01, 0.26959400E-01, -.81831200E-02, -.91742900E-01, 0.28858500E+00, 0.51635100E-01, -.20379600E+00, 0.25127200E+00, 0.62270000E+00, 0.63647700E-01, -.46473100E+00, 0.19981700E-01, 0.70085200E-01, 0.68680000E-02, -.10359900E-01, -.75256200E-01, 0.30584800E-01, 0.21269900E-01, -.13264800E+00, 0.13161900E+00, -.20775000E-01, 0.49019200E-01, 0.82478400E-01, -.10120100E+00, 0.84419400E-02, 0.25383600E+00, -.66388500E-01, 0.74584400E-01, -.36621700E+00, 0.23084300E-01, 0.18808500E+00, 0.74546100E-01, 0.40908900E-01, 0.15118000E+00, 0.18193600E+00, -.27680300E-01, -.74512400E-01, 0.20375300E+00, -.31364700E+00, 0.88098700E-01, -.28926300E+00, 0.26089100E-01, -.27593300E-01, -.10404800E+00, 0.39416700E-01, -.62948600E-01, 0.90563400E-01, -.30034600E+00, -.34988300E+00, 0.21319500E-03, 0.27741200E-01, 0.11280300E+00, 0.47943900E+00, -.32653500E+00, -.12134100E+00, 0.45679400E-01, -.25467800E+00, 0.40122500E-02, -.50112400E-01, 0.53316100E+00, 0.18538600E-01, 0.41915300E-01, -.37733700E+00, 0.73662600E-01, -.23890500E+00, 0.76823900E-01, -.39531000E-01, -.50579800E-02, 0.83276700E+01, -.14396800E+02, 0.34941400E+01, -.13392800E+02, 0.11737500E+01, -.65723800E+01, 0.22233900E+01, -.23796200E+00, 0.98067600E+01, -.45207300E+01, -.53571600E+01, -.55150500E+01, -.30734100E+01, -.55261400E+01, -.36033500E+01, 0.12385800E+01, 0.12598600E+02, -.65852600E+01, -.29864600E+01, 0.11260500E+01, -.13780000E+01, -.32828500E+00, -.14633400E+01, 0.10373100E+01, -.11769300E+01, 0.53606900E+00, 0.10029000E+01, 0.78801400E+00, 0.77981400E+00, 0.51883500E+00, -.12156600E+01, -.21808500E+01, 0.22887500E+01, 0.18009400E+01, -.93236900E+00, -.19595100E+01, -.10431500E+01, -.21987600E+01, 0.38015400E+00, -.20298400E+01, -.46505700E+00, -.10986000E+01, 0.89541600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14605400E+01, 0.14506500E+00, 0.37938500E+00, -.81525100E+00, -.46448300E+00, 0.63076900E-01, 0.10754400E+00, -.40859400E+00, -.10678700E+00, 0.13911700E+00, -.37231100E+00, 0.75528900E-01, 0.75400600E+00, 0.94280000E+00, -.56537600E-01, 0.15279800E+00, 0.10769700E+00, 0.37621200E+00, 0.12607400E+00, -.90285400E+00, 0.57691600E-01, 0.11055400E+00, 0.12774600E+01, -.82091100E+00, 0.12024300E+00, -.12827800E+00, -.23633700E+00, 0.28774500E+00, 0.30804900E+00, 0.94117000E+00, 0.12357500E+00, -.25980200E+00, 0.13435600E-01, -.19674800E+00, 0.14772100E+00, -.50908900E+00, -.21941900E-01, -.18914900E+00, -.13553400E+00, -.15841700E+00, -.13337500E+00, -.16764900E+00, -.70479200E+00, 0.15549100E-01, 0.19625900E-01, -.35261800E+00, 0.21695200E+00, -.42572900E+00, -.29240200E+00, 0.60674100E-02, 0.10224900E+01, 0.10119900E+01, 0.50779700E-01, -.61702400E-01, -.12211800E+00, -.36596300E-01, 0.10311500E-02, -.65663600E+00, 0.16804400E-02, -.13170200E+00, 0.98162200E-01, -.71141700E-01, 0.35196600E-01, 0.17546600E+00, 0.35334200E+00, 0.32873700E+00, 0.10235500E+00, 0.53435500E+00, -.44958200E-01, 0.12629500E-02, 0.15355400E-01, -.23445300E-01, 0.14247600E+00, 0.10879100E-01, -.39333400E-01, -.27154300E-01, -.26314200E-01, 0.57626700E-01, 0.22249900E+00, 0.26250500E-01, 0.10951100E-03, -.27340400E+00, 0.16240200E+00, -.10614500E+01, -.33264400E-01, -.18858800E+00, -.88359400E-01, -.15277600E+00, -.22013300E+00, 0.69017600E-01, 0.16724400E+00, -.16424000E-01, 0.27993700E+00, 0.65457000E+00, -.54896100E+00, 0.16626500E+00, -.56733600E-01, -.66465200E+00, 0.27647000E+00, 0.73063600E-01, 0.10902900E+00, -.71200300E-02, -.28035500E-02, 0.66857000E-01, 0.46657500E-01, 0.30526500E-01, 0.54347900E-01, 0.13756400E+00, 0.30461300E+00, -.71865800E-02, -.12689700E+00, -.31257000E-01, 0.57971300E-01, -.90303800E-03, 0.14037600E+00, -.15887400E+00, 0.46525400E-02, -.37160700E-01, -.40258700E-01, 0.38015100E+00, 0.28380700E+00, -.30510500E+00, -.54391400E+00, 0.79830300E+00, 0.59259900E-03, 0.74379200E-01, -.47190500E-01, -.64883900E-01, -.63236900E-01, 0.14479100E-01, 0.47666900E-02, 0.11144000E+00, -.11996600E+00, -.25623500E-01, 0.12332900E+00, -.10824200E-02, 0.18883100E+00, 0.12881300E+00, 0.18955700E-01, 0.12854400E-01, -.32744700E-01, 0.79590700E-02, 0.72927200E-01, -.63967300E-01, 0.94604300E-01, -.60112200E-01, 0.31387400E-02, 0.15833600E+00, -.19614300E+00, -.24691000E-01, 0.22351600E-01, -.14707000E-01, -.12184500E+00, -.95158000E-02, -.13271300E-01, 0.81715000E-02, 0.47689700E+00, 0.50223800E-04, -.46958200E+00, 0.87212700E-02, 0.69444300E-01, 0.12818000E-01, -.38925200E-01, 0.51593900E-01, 0.10298200E+00, -.46603100E-01, 0.81651500E-03, -.31719400E-01, 0.16843300E-03, 0.71807100E-01, -.67085000E-01, 0.20170400E+00, 0.53590500E-01, -.11434300E+00, 0.38174200E-01, -.27869000E-02, 0.24553200E-01, -.22957600E-01, 0.21484800E-01, -.22657200E-03, 0.13169500E+00, -.40288100E-01, 0.58912700E-01, -.28951100E-01, 0.11966700E+00, -.68240900E-01, 0.19267700E-02, -.18331800E-01, -.24528600E-01, 0.23007600E-01, -.86905500E-03, 0.77413300E-02, -.16332100E+00, 0.19829400E+00, 0.20512500E-02, 0.39957800E-01, -.89634200E-01, 0.31978000E-01, 0.17576600E-01, -.32596500E-01, 0.12875500E-01, 0.84345900E-02, -.39115400E-01, -.27886500E-01, -.95245600E-01, 0.59915600E-01, 0.20708700E-01, 0.65775100E-01, 0.13943600E+00, 0.43035300E-01, 0.75271400E-02, -.31021500E-02, 0.67202800E-02, 0.21722700E-01, 0.14879500E+00, 0.11067200E+00, -.38032100E-01, -.32685500E-01, 0.28039900E+00, 0.10591900E+00, 0.21718700E-01, 0.17895600E-01, 0.15341400E+00, -.15273100E-02, -.66905500E-03, -.24407800E-01, 0.36058500E-01, -.34015800E-01, 0.21105300E+00, 0.14802000E+00, -.79309700E-01, 0.28989700E-01, -.38803700E-02, 0.93593900E-01, 0.22169100E-01, -.17638500E+02, -.20263300E+02, -.37357300E+01, 0.35809600E+01, 0.77169800E+01, -.13514700E+02, -.26940600E+01, -.24622500E+02, 0.12044100E+02, 0.13600700E+02, 0.11208700E+02, 0.63630600E+01, 0.13630700E+02, -.11208900E+02, -.15903700E+02, 0.11807200E+01, 0.80066800E+01, 0.20666700E+02, 0.56718700E+00, 0.56679200E-01, 0.88351700E+00, 0.27630700E+01, -.11224200E+00, -.17766200E+01, -.91289200E+00, 0.49184000E+00, 0.54530100E+00, -.73983100E+00, 0.48515500E+01, -.19809400E+00, -.53728500E+00, 0.59568500E+00, -.41641400E+00, -.40830100E+00, -.54700100E+00, -.14632500E+00, -.57966600E+00, 0.60286300E-01, -.66221200E-01, 0.15480400E+01, -.27042200E+01, 0.12749500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11540500E+02, -.19590700E+01, -.15124100E+01, 0.58343500E+01, 0.74644800E+01, 0.64241600E+00, -.14854300E+01, 0.22398600E+01, 0.88630000E+00, 0.14520700E+00, 0.47882700E+01, 0.92736500E+00, -.19006200E+01, 0.33132100E+01, -.72559200E+00, -.11045600E+01, 0.15712300E+01, -.15690900E+01, -.14504300E+01, 0.30624200E+01, -.62456800E-01, -.48721400E+01, 0.10216600E+01, -.10358000E+00, 0.26787200E+00, 0.94560800E+00, 0.42206600E+00, 0.46447000E+00, -.53237300E-01, -.15601100E+01, -.62678200E+00, 0.11085300E+01, -.21239000E+01, 0.17694400E+01, -.27951600E+00, 0.26041000E+01, -.34869800E-02, 0.14596800E+01, -.49086100E+00, 0.11716000E+00, -.14943000E+01, -.54929800E+00, 0.32716700E+01, -.31101900E+00, 0.10602900E+01, 0.63872900E+00, -.15054400E+01, 0.11177600E+01, 0.67776600E+00, -.42348200E+00, -.16371800E+01, -.17395400E+01, 0.79398100E-01, -.41908000E+00, -.51679500E+00, -.51054100E+00, 0.25051000E+00, -.83581600E+00, 0.17202800E-02, 0.52385800E+00, -.83573800E+00, -.91513400E+00, -.85560500E-01, -.21765300E+00, -.20813000E+01, -.45650500E+00, 0.48061500E-01, 0.66293000E+00, -.33339200E+00, -.23289600E-02, 0.30604300E+00, -.24144100E+00, 0.30467200E+00, 0.19873700E+00, 0.28657300E+00, -.28835000E+00, -.79387000E+00, -.19164600E+00, -.46757600E+00, -.13118000E+00, 0.16713000E-02, 0.15243000E+01, -.48396800E+00, 0.18181900E+01, 0.86083700E-01, -.67447600E+00, 0.12842900E+01, -.57895200E+00, -.47107800E+00, 0.41784900E+00, -.13843900E+01, -.14537500E-01, -.76278100E+00, -.14894100E+01, 0.20651700E-01, -.16615700E+01, -.20516600E+00, 0.15656900E+01, 0.10490700E+01, -.29616400E-01, 0.61584400E+00, 0.10596200E+00, 0.96463100E-01, -.37044400E+00, 0.77898800E+00, -.21185000E+00, -.13257700E+00, 0.29127200E-02, -.13152800E+00, 0.69191500E+00, -.78606300E+00, 0.86711700E-01, -.56980400E+00, -.47598300E-02, -.10179600E+01, 0.22070600E+01, -.98715000E+00, 0.12402800E+01, 0.13246400E+00, -.10678000E+01, -.12525500E+01, 0.27985300E+01, 0.91622800E+00, 0.51413700E+01, 0.10313800E-01, 0.59894700E+00, -.82567300E+00, -.52127000E+00, -.72170600E+00, 0.34444800E+00, -.36806200E+00, -.10621000E+01, 0.88843900E+00, 0.68693100E-01, -.67969100E+00, -.97216200E-02, 0.20363600E+00, 0.13415400E+00, 0.63906700E-01, -.19164700E+00, -.22918200E+00, -.13167400E+00, -.93853300E-01, 0.15752300E+00, 0.30211000E+00, 0.55168200E+00, -.78205800E-01, 0.43941600E+00, 0.39193400E+00, -.52353300E+00, 0.54553200E-01, 0.30959200E+00, 0.10894500E+01, -.34464900E+00, -.64280100E-01, 0.13228700E+00, -.63228300E+01, 0.41443600E-01, 0.11761500E+01, 0.10824700E+00, 0.91473100E-01, -.26017100E+00, -.83256600E+00, -.12539000E+00, -.12967800E+01, 0.19020900E+00, 0.51124900E-01, -.15446800E+00, -.47349800E-02, -.43043900E+00, 0.44850100E+00, -.39062700E+00, 0.29167500E+00, 0.40346500E+00, 0.46696600E+00, 0.11151200E+00, 0.35231600E-01, -.38109600E-01, 0.29164000E-01, -.24157700E-02, 0.51325400E+00, -.54838500E+00, 0.80840800E-01, -.32122800E+00, -.29307800E+00, 0.44449100E-01, -.31709000E-01, 0.44740500E-01, -.33406700E-01, 0.29186000E+00, -.39396600E-02, -.11932200E+01, 0.26707800E+00, 0.10850400E+01, -.35802100E+00, -.56709500E+00, -.21005600E+00, 0.17904600E+00, 0.20437400E-01, 0.72909500E-01, -.29094600E-01, 0.74682600E-01, 0.49320700E+00, -.15898100E+00, -.30423400E+00, -.95509600E+00, -.10798900E+01, 0.11893600E+00, -.16087700E+00, -.22443800E+00, 0.73547100E-02, -.25340800E-01, 0.10976800E-01, 0.94783000E+00, -.67311100E+00, -.75795400E+00, -.51837300E-01, -.16126300E+00, -.10962300E+01, -.89765200E+00, -.29121300E+00, 0.26858500E+00, 0.81562100E+00, 0.31145400E+00, -.63905500E+00, 0.14306300E+00, -.79568300E+00, 0.19624900E+00, 0.28633400E+01, -.72870000E+00, 0.89986100E+00, -.22610000E+00, -.47843100E-01, 0.35582900E+00, 0.99714600E-01, 0.47697200E+01, 0.69543200E+02, 0.38756300E+02, 0.37413500E+02, -.19807100E+02, 0.61978900E+02, 0.46018600E+02, 0.92796700E+02, -.45396700E+02, -.58716400E+02, -.49982400E+02, -.27605900E+02, 0.49233100E+02, -.49132000E+02, -.70928800E+02, -.78107000E+02, 0.26478000E+02, 0.10805000E+03, -.32900200E+01, -.76582500E+01, -.10880500E+01, -.20507000E+02, 0.47278300E+01, -.19040900E+02, 0.47351200E+01, 0.15026600E+01, -.26247000E+01, 0.64757200E+01, 0.65411000E+02, -.93924100E-02, -.31021100E+02, 0.28292500E+02, 0.39688000E+01, 0.28079300E+01, -.25570300E+02, 0.17856800E+01, -.32166800E+02, 0.45703300E+01, -.27738300E+02, -.55286300E+01, 0.14825400E+01, 0.67865000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.93558000E+01, -.30302000E+01, -.89705600E+00, 0.15291900E+01, 0.74074900E+01, -.13002400E+01, -.12283500E+01, 0.40005100E+01, -.84715600E+00, -.19868000E+01, -.21898900E+01, 0.15110400E+01, 0.57499100E+01, 0.84119000E+01, 0.39900500E+00, -.52372300E+00, 0.36351900E+01, 0.32661400E+01, -.63325000E+00, -.93206800E-01, 0.22337500E+01, -.65808300E+01, -.11037400E+02, 0.55156100E+01, 0.21663200E+00, 0.59766600E+00, -.94733200E+00, -.84340700E+00, -.21962800E+01, 0.48910100E+01, -.62297100E+00, 0.15347100E+00, -.24974700E+01, -.40517300E+00, -.88274000E-01, 0.12842800E+01, 0.11422900E+00, 0.10677500E+01, 0.13790700E+01, 0.17820400E+01, 0.17410400E+01, -.17719700E+00, -.54759100E+01, 0.23887900E+01, -.48712600E+00, -.33205400E+01, -.10236900E+01, 0.49656700E+00, -.47240500E+00, -.29498100E+01, -.40435100E+01, -.91842400E+00, -.59436800E+00, 0.12822400E+01, -.23047700E+01, -.21248500E+01, -.56672700E+00, -.70040900E+01, 0.66869600E-02, 0.26293500E+00, -.87611200E+00, -.18295200E+01, -.45344000E+00, 0.46698300E+00, -.49092400E+01, 0.27458900E+00, 0.21372900E+01, -.19270800E+01, 0.48500700E+00, 0.69223500E-02, -.81054800E+00, 0.49944900E+00, 0.29432300E+00, 0.60662300E+00, 0.75627600E+00, -.27642400E+00, -.72116800E+00, 0.57320700E+00, 0.14407700E+01, -.45849200E+00, 0.47631100E-02, -.68678400E+00, 0.19658000E+01, 0.56270100E+01, 0.50912800E+00, -.11443300E+01, 0.20151300E+01, 0.54524300E+00, -.26896300E+00, -.51293600E+00, -.68745900E+00, -.10999700E+00, -.19152500E-01, -.13002100E+01, 0.25363600E+01, 0.17548000E+01, -.64141900E+00, -.42764500E+01, 0.55119900E+00, 0.61686300E+00, -.30704600E-01, 0.10224200E+00, -.70819800E-02, 0.18266000E+00, 0.11862000E+01, 0.96720500E-01, 0.11551000E+01, 0.10634500E+01, 0.22628100E+01, -.12964600E+01, 0.13401800E+01, -.11319700E+00, 0.36288400E+00, -.93173000E-02, 0.55595000E+00, -.56686000E+00, 0.65209800E+00, 0.10542700E+01, -.45123200E+00, 0.90805300E+00, -.23136500E+00, 0.38177600E+00, -.10809100E+01, 0.86419900E+00, -.23148200E-01, 0.20073400E+00, -.19280400E-01, -.47577200E+00, -.18547700E+00, 0.29427300E+00, 0.10215900E+01, -.38734400E+00, -.12950800E+00, -.20205800E+00, -.17929900E+01, 0.16991200E-02, -.13646000E+00, -.23241700E+00, -.11669200E-01, 0.15912100E+00, -.12244600E+00, 0.18966900E+00, 0.21362500E+00, -.80688700E-01, -.30954900E+00, 0.53909700E+00, 0.15874500E-01, 0.40680600E+00, 0.98134800E+00, -.11679000E+00, -.31078200E-01, -.16089400E+00, 0.65250200E+00, 0.29751500E+00, -.14152700E+00, -.64018000E-02, 0.13225800E+01, -.93207200E-02, -.21387400E+00, -.25803600E+00, -.17260100E+00, 0.13078100E+00, 0.79256700E+00, 0.23258000E+00, -.41246700E+00, -.12387000E+00, -.11769500E+00, -.24351100E+00, 0.25273700E-01, -.80381200E-01, -.37383000E+00, 0.17287200E+00, 0.22899400E-01, -.54120700E+00, -.10522100E+01, -.18785200E+00, 0.77895000E+00, -.39359300E-02, -.16783100E+00, 0.81437500E-03, 0.60305900E+00, -.26254900E+00, -.18935800E+00, 0.27277900E+00, -.12636900E+00, -.62487100E+00, -.85734700E-02, -.12516800E+00, -.58215700E-02, 0.27534200E+00, 0.15489000E-03, -.59873800E+00, 0.83892500E-01, -.26600200E+00, 0.95749400E+00, 0.60665000E-01, -.16856500E+00, -.16736000E+00, -.16301200E-01, -.22736700E+00, -.23666200E+00, -.98428500E-01, 0.39258200E+00, -.41324000E+00, 0.63167400E+00, -.49550400E-01, 0.11469300E+00, -.11030000E+00, -.18497200E+00, 0.18458600E+00, -.68723200E-01, 0.12231800E+00, -.12921400E+00, 0.15276700E+01, 0.61942500E+00, -.14671300E+00, -.14128000E+00, -.38684300E+00, -.50889000E+00, 0.42303800E+00, 0.37728100E+00, -.63541900E-01, 0.15321100E+01, 0.58522700E-02, -.33004800E-01, -.19842100E+01, -.11622500E+00, -.46120200E+00, 0.13867900E+01, -.52357500E-01, 0.90025400E+00, -.32292700E+00, 0.12106500E+00, 0.63338900E-01, 0.31743500E+00, -.14295300E+01, -.58936300E+00, 0.43965200E+02, 0.21330900E+02, 0.19894100E+02, 0.69385200E+01, 0.23850600E+02, 0.11129700E+02, -.60166700E+01, -.12486300E+02, -.10853100E+02, 0.35683200E+00, 0.61725400E+02, -.50661900E+02, -.72829200E+02, -.61484200E+02, 0.41865000E+02, 0.10327100E+03, -.27790100E+01, -.25097100E+01, 0.16444400E+01, -.46946000E+01, 0.86512400E+00, -.13384800E+02, 0.45118500E+00, 0.80421800E-02, -.21564100E+01, 0.10738400E+01, 0.48265800E+02, 0.17740300E+01, -.15561600E+02, 0.13866300E+02, -.20670400E+01, 0.25447300E+01, -.12219000E+02, 0.29240700E+01, -.16161300E+02, 0.17939900E+01, -.12279000E+02, -.38612800E+00, -.93697600E+00, 0.54162400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23217600E+02, -.40107300E+01, -.93058700E+01, 0.11607600E+02, 0.13761000E+02, 0.23078300E+01, -.27816000E+01, 0.19021500E+01, 0.19397800E+00, -.21111600E+01, -.97451800E+01, -.55569900E+01, -.76696000E+01, -.69232700E+00, 0.17770600E+01, -.34317600E-01, 0.16230800E+01, 0.80580300E+00, -.14167400E+01, 0.32038900E+01, 0.25540200E+00, -.56542700E+01, -.10395400E+02, 0.37963800E+01, 0.18859600E+00, -.65215700E+00, -.13199500E+01, 0.52045300E+00, -.30243400E+01, 0.41012000E+01, -.11936400E+01, 0.97336600E-02, -.14083800E+01, 0.13515200E+01, -.22719600E+00, -.61712400E+00, 0.55887700E-01, 0.59768100E+00, -.46515200E+00, 0.14688800E+01, 0.79001200E+00, -.13956700E+01, -.88383400E+01, 0.22816800E+01, 0.76475200E+00, -.16071200E+01, 0.71880900E+00, 0.79215000E-01, -.42848700E+00, -.97485800E+00, 0.13086500E+01, 0.18606900E+01, -.83244300E-01, 0.95560900E+00, -.22678700E+01, -.34839000E+01, -.15043900E+00, -.83368500E+01, 0.76277000E-02, 0.91951600E+00, 0.67679800E+00, -.61063500E+00, -.38943900E+00, 0.19684000E+00, -.49059800E-01, 0.42923600E+00, 0.12461100E+01, -.37075200E+00, 0.31710200E+00, 0.17211300E-01, -.40027000E+00, 0.14015800E+01, 0.16790800E+01, -.28357400E+00, 0.10370700E+01, -.76539900E-01, -.28553400E+00, 0.17188400E+01, 0.21584200E+01, -.27832100E+00, 0.48468900E-02, -.16909700E+01, 0.31239600E+01, 0.13982900E+01, 0.65613200E+00, -.22556600E+01, 0.60300600E+00, 0.30753000E+00, -.70972400E+00, 0.27328700E-01, -.55497400E+00, -.14309400E+00, 0.11928500E+01, -.17833600E+01, 0.52536100E+01, 0.28372600E+01, -.70053300E+00, -.10356500E+02, 0.32464300E+01, 0.16721300E+01, 0.14085300E+01, 0.40677200E+00, 0.25481500E+00, 0.59772000E+00, 0.32078600E+01, -.19120900E+01, -.61191200E+00, 0.41386800E+00, 0.34635500E+01, -.86918700E+00, 0.42259500E+00, -.24112500E+00, 0.31060100E-01, -.22605300E-01, 0.15967800E+01, -.90837400E+00, 0.12255100E+01, 0.13966400E+01, -.26527100E+00, 0.31906500E+01, -.54300700E+00, -.10665000E+00, -.34647500E+01, 0.73523100E+01, 0.23149100E-02, 0.12041400E+00, 0.59258000E+00, 0.51804400E+01, 0.14898200E+00, -.31231900E+00, -.26064700E+00, 0.16811200E+01, -.83497400E+00, -.48523000E+00, -.12586100E+01, 0.67066800E-02, -.43045200E+00, -.61025800E+00, -.13894200E+00, 0.24812300E+00, 0.73437300E+00, 0.47544500E+00, -.22681400E-01, -.76472700E+00, -.11684300E+01, -.23703400E+01, -.14008300E+00, -.25157000E+01, -.29551200E+01, -.82042400E+00, -.40476200E+00, 0.22728200E-01, 0.19643600E+01, 0.12175700E+01, 0.57607400E-01, -.34567400E-01, -.25025200E+01, 0.76445200E-01, 0.21640200E+01, -.42499700E+00, 0.56744800E+00, -.37147700E-01, -.93900600E+00, -.43372000E+00, -.32781200E+01, -.23251600E+00, -.23826900E+00, -.35974900E+00, -.12883300E-01, -.62088900E+00, 0.91152200E-01, -.64793300E+00, 0.17994700E+01, -.54473900E+00, -.98632400E-01, -.29232600E+00, -.88033900E+00, 0.26155300E+00, -.82557100E+00, 0.31487800E+00, 0.25025300E+01, 0.26431200E+00, 0.50490500E+00, -.42948400E+00, -.29423500E+00, -.12108500E+01, 0.28899200E+00, 0.27735700E+00, 0.18382600E+00, 0.16076600E+01, -.24873100E-01, -.41869100E+01, -.91866200E+00, -.23256000E+00, 0.71371700E-01, -.27239500E-01, 0.95208500E+00, -.85466700E-01, 0.14278800E+01, -.10954400E+01, 0.19592900E+00, 0.10664300E+00, 0.88173300E+00, -.10706800E+01, -.93525200E+00, -.10391100E+01, -.19008200E+01, 0.70124900E+00, 0.34335000E+00, -.31982100E+00, -.42787700E-01, 0.10856500E+00, -.12851600E+00, 0.43014500E+01, 0.15778400E+01, -.30515800E+00, -.45140200E+00, 0.66869100E+00, -.35337600E+01, -.44220700E+01, 0.36841900E+00, 0.10250400E-01, 0.54230400E+01, 0.19572600E-01, -.23252800E+00, -.25086000E+01, -.10953900E+01, -.16252800E+01, 0.30147900E+01, 0.88128900E+00, 0.20576600E+01, -.51488000E+00, -.17434200E-01, 0.25469200E+00, 0.17513800E-01, 0.47315800E+01, 0.16376800E+01, -.14754300E+01, -.14225600E+03, -.42363900E+02, -.10570200E+02, -.16072400E+02, 0.18825900E+03, -.92464000E+02, -.30341700E+02, -.11773500E+03, -.57682800E+02, -.15334900E+03, 0.11945500E+03, 0.17848800E+03, 0.85083900E+02, -.93859900E+02, -.20010800E+03, -.91291600E+00, 0.11885200E+00, 0.69593700E+00, 0.96858600E-01, -.64025500E+01, 0.19922800E+02, 0.65719000E+01, -.64661400E+01, 0.29489000E+00, -.88679200E+01, -.89779800E+02, 0.33431900E+01, 0.32760300E+02, -.30937600E+02, -.55189300E+01, 0.21157600E+00, 0.34628900E+02, 0.11467500E+01, 0.34713900E+02, -.95065700E+01, 0.36636800E+02, -.67119800E+00, -.41000300E+01, -.32452000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.47385100E+01, -.78638000E+00, -.30270600E+01, 0.46077200E+01, 0.35417700E+01, -.13805200E+00, -.59583900E+00, 0.22574300E+01, -.14988300E+00, -.29242900E+00, -.58166800E+00, -.30500000E+00, 0.18370900E+01, 0.22374500E+01, 0.36778400E+00, -.26603700E+00, 0.89147300E+00, 0.19513300E+01, -.14161100E+00, -.70871200E+00, 0.43072200E-01, -.52777400E+00, -.53087200E+01, 0.19986400E+01, 0.30237300E-01, 0.62208400E+00, 0.41999100E+00, 0.15022700E+00, -.10617200E+01, -.51593500E+00, -.16466400E+00, 0.33194800E+00, -.86160800E+00, 0.14909000E-03, -.31491000E+00, 0.85525800E+00, 0.28559100E-01, -.29824200E+00, -.29462900E+00, 0.56886900E+00, 0.16204700E+01, 0.85928100E+00, -.28041000E+01, 0.78327900E+00, -.14540800E+01, 0.43869500E+00, -.82695900E+00, -.18681300E-01, 0.76677900E-01, 0.88861300E+00, 0.68743800E+00, 0.92120400E-01, 0.22091700E+00, 0.33570700E-01, -.28512500E+00, -.70682700E+00, 0.38603000E+00, -.13166900E+01, 0.11365500E-02, 0.68004600E+00, -.11569200E+00, 0.47370600E+00, -.21265000E+00, 0.26900500E+00, -.22231200E+01, -.78945600E-01, 0.94747300E+00, -.84409100E+00, 0.32027100E+00, 0.34119000E-02, 0.34394900E+00, 0.30074400E+00, 0.82982800E+00, 0.11330200E+00, 0.81087200E+00, -.11014600E+00, -.29738900E+00, -.32712900E+00, 0.66904400E-02, -.16795900E+00, -.36880000E-03, -.40537500E+00, 0.37288600E+00, 0.12893000E+01, 0.28504300E-01, -.54608400E+00, -.36444400E+00, 0.28997500E-01, -.23787000E+00, -.21725000E-01, -.61866100E+00, -.73503600E-02, 0.13473800E+00, -.65238500E+00, 0.15774800E+01, -.72126100E+00, -.82560100E-01, -.17632700E+01, -.37032000E+00, 0.83380600E+00, -.77042000E+00, 0.22498900E-01, -.14745500E+00, 0.91241700E-01, 0.13269700E+00, 0.22630600E+00, 0.44644500E+00, 0.99717000E+00, 0.42084600E+00, -.11002000E+01, 0.28346700E+00, -.17297100E-01, -.39798400E-01, -.21426400E-01, 0.17839600E+00, -.49535400E+00, 0.37096100E+00, -.27220600E+00, -.15706700E+00, 0.55448200E+00, -.39671700E+00, -.13189900E+00, -.81585500E+00, 0.27455100E+01, 0.13323600E-01, -.24013100E+00, -.34881200E+00, 0.89140500E+00, 0.31736900E+00, -.11651900E+00, 0.55195700E+00, 0.69600700E+00, -.26441600E+00, 0.13103300E-01, 0.11122500E+00, 0.32348100E-02, 0.13419700E-01, -.10771800E+01, 0.75453400E-01, 0.51837000E-01, -.21995900E+00, -.24675600E+00, 0.11138400E+00, -.12144700E+00, 0.93616200E+00, -.49568900E+00, 0.47446000E-02, 0.36520200E+00, -.41302700E+00, 0.47747100E+00, -.98221700E-01, -.10210800E+00, -.61107200E+00, 0.20160700E+00, 0.66181100E+00, -.11341600E+00, 0.22432200E+01, -.42452800E-01, 0.13855400E+01, 0.51562900E+00, 0.41230900E+00, -.31105100E-01, -.14583800E+01, -.62912900E+00, 0.21056100E+01, 0.16604300E+00, 0.20771200E+00, -.15969300E-01, -.15119300E-01, 0.22041600E+00, -.13354600E-02, 0.35413700E+00, -.66641800E+00, 0.72029500E-01, 0.39814200E-01, -.32393900E+00, -.23973500E-01, -.42322700E-01, -.27156000E+00, -.19384000E-02, 0.37998400E+00, 0.74487300E+00, -.84469000E+00, 0.29427200E+00, -.10103000E+00, -.10239400E+01, -.91931000E-02, -.60424600E-01, 0.22265500E+00, -.14089300E+00, 0.21842200E-02, 0.16616100E+01, -.97463200E-01, -.61817800E+00, 0.19660400E+00, 0.11580100E+00, -.12182700E+00, -.10720400E+00, -.22854600E+00, 0.82704300E-01, 0.43594900E+00, 0.47701800E-01, -.52309900E+00, 0.56631900E+00, -.16095700E-01, 0.13379500E+01, 0.78871700E+00, -.11482800E+00, 0.22411800E-01, 0.22020000E+00, 0.80682300E-01, -.10773900E+00, 0.11647700E+00, -.11491400E+01, -.56690600E+00, 0.42030500E+00, 0.83275100E-01, 0.15881700E+00, 0.18826000E+01, 0.10839300E+01, -.11988400E+00, 0.82999300E-01, -.18094000E+01, -.92301000E-02, 0.19785000E+00, 0.99264800E+00, 0.53164700E+00, 0.15515100E+00, -.14430700E+01, -.17461100E+00, -.64726400E+00, 0.27395700E+00, -.63175000E-01, 0.29357800E+00, -.67540900E-02, 0.50844600E+00, -.17265400E+00, 0.39017100E+00, -.58699700E-01, -.15325900E+02, -.11618500E+02, -.21686000E+02, -.60713000E+02, 0.30476900E+02, 0.47412700E+02, 0.39517200E+02, 0.16674100E+02, 0.90877900E+00, -.30951600E+02, -.29501800E+01, 0.40781400E+02, 0.14015200E+02, -.30333100E+02, 0.48552600E+01, 0.69548600E+01, -.20367800E+01, 0.14080500E+02, 0.14373700E+01, 0.11205900E+02, -.84026800E+01, 0.21212400E+01, 0.69705500E+00, 0.31072600E+01, 0.52286000E+01, -.33204400E+01, -.14928900E+01, 0.20688200E+01, 0.26126000E+01, -.32152600E+01, -.72273000E+00, -.34247300E+01, -.11322100E+01, 0.29355300E+01, 0.36406500E+00, -.58908800E+01, 0.20780800E+01, -.42982300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.75335100E+01, 0.19618300E+01, 0.27405200E+01, -.54908400E+01, -.48962400E+01, 0.41151700E+00, 0.77343000E+00, -.33987600E+01, -.16942700E+00, 0.16642800E+00, -.24254600E+01, -.60519000E+00, -.12006200E+01, -.38918900E+01, 0.42081500E+00, 0.66781700E+00, -.18436400E+01, -.86211300E-02, 0.39056900E+00, 0.92586800E+00, 0.23746400E-01, 0.28636700E+01, 0.31713400E+01, -.16760000E+01, -.88732200E-01, -.71184700E+00, 0.97148200E-01, 0.22422300E+00, 0.89401900E+00, 0.17184900E+01, 0.71263600E-01, -.50293500E+00, 0.19588200E+01, -.46076100E+00, 0.37642100E+00, -.14515200E+01, 0.70001900E-01, -.15202100E+00, 0.49777800E-01, -.49526600E+00, -.17711300E+01, -.13138200E+01, 0.53037800E+00, -.30463800E+00, 0.83054500E+00, -.13426300E+01, -.38752800E-01, 0.32648400E+00, 0.58790900E-01, -.49952500E+00, 0.71667800E+00, 0.97127100E+00, 0.12011200E+00, -.47235700E+00, -.34530100E+00, -.21114700E+00, 0.13796900E+00, -.13698300E+01, 0.46101700E-02, -.75397800E+00, 0.44228800E+00, -.30425900E+00, 0.20820800E+00, 0.31219600E-01, 0.30450400E+01, 0.16431000E+01, -.14920800E+00, 0.98709400E+00, -.21277900E+00, 0.27383300E-02, -.28413600E+00, -.12429600E+00, 0.24349400E+00, 0.28843500E+00, -.28778500E+00, -.80780100E-02, 0.44685300E+00, 0.39746600E-01, 0.81864100E+00, 0.24913000E+00, -.51732000E-03, -.10023300E+01, 0.34605900E+00, -.37314200E+01, -.15132700E+00, 0.61780600E+00, 0.15122500E+00, -.80672800E+00, -.45332500E+00, 0.16517600E+00, 0.71798900E+00, -.11852900E-01, 0.14771200E+01, 0.30890400E+01, -.27177000E+00, 0.18220000E-01, -.30818000E+00, -.45541100E+01, 0.10531100E+01, 0.64727100E+00, 0.34584300E+00, -.10710100E+00, -.15656700E+00, 0.70402500E+00, -.36958800E+00, 0.63413600E+00, 0.97934200E+00, 0.12423200E+01, 0.14907700E+01, -.64402300E+00, -.14785500E+00, -.19971200E+00, 0.55208700E+00, -.22827700E-02, 0.62132300E+00, -.79769400E+00, -.83549200E-02, -.14096400E+00, -.33582400E+00, 0.13599000E+01, 0.20434500E+01, -.19993500E+01, -.21483500E+01, 0.33657800E+01, -.38588600E-02, -.87381000E-01, -.35471100E-01, 0.54573900E+00, 0.32857600E+00, -.13654800E-01, 0.54610600E+00, 0.56934400E+00, -.87801700E+00, -.67874500E-01, 0.70082500E+00, 0.78022900E-02, 0.30683900E+00, 0.68815900E+00, -.10555500E+00, 0.12835100E+00, 0.48466600E-01, 0.37013700E+00, 0.54239100E+00, -.18831500E+00, -.65909600E-01, -.78403300E+00, 0.61805300E-01, 0.73143500E-01, -.98735100E+00, 0.22729400E+00, 0.14244900E+00, -.27478300E+00, -.12792800E+01, 0.40051500E+00, 0.92370300E-01, -.65078300E-01, 0.75124000E+01, -.34496500E-01, -.32389200E+01, -.14557100E+00, -.34646500E-01, -.86690700E-01, 0.32745000E+00, 0.46663100E+00, 0.39148200E+00, -.18505200E+00, 0.51444600E-01, -.37243200E+00, -.25213500E-01, 0.27643300E+00, -.11278000E+00, 0.78319900E+00, 0.61277900E+00, -.64452300E+00, 0.61312000E+00, -.11767900E+00, 0.70267200E-01, -.12917200E+00, -.52625700E-03, 0.26317800E-02, 0.38271600E+00, -.17424100E+00, 0.13669900E+00, 0.33971600E-01, 0.21998000E+00, -.92766600E+00, 0.23242500E-01, 0.52647200E-01, -.94297800E-02, -.44679100E-03, -.48478800E-04, 0.87763200E+00, -.98759000E+00, 0.10046500E+01, 0.10803500E+00, 0.13120800E+01, 0.51805500E+00, 0.41299700E-01, -.20514900E+00, -.17577700E+00, -.36283800E-01, -.68867900E-02, 0.61783400E+00, 0.61205900E+00, -.90038400E+00, 0.69653200E+00, 0.45733800E+00, 0.26899500E+00, 0.12131700E+00, -.16023600E+00, 0.87506700E-01, -.46569200E-01, 0.76004800E-01, -.11873100E+01, -.32560300E-02, 0.59949100E+00, 0.12974400E+00, 0.39470700E+00, 0.13656700E+01, 0.10436200E+01, 0.21205300E+00, 0.83699900E-01, -.60465600E+00, 0.20876300E-02, -.76305200E-01, -.24186600E-01, 0.40600300E-01, -.71038100E+00, -.16598900E+01, 0.10174600E+00, -.27534300E+00, 0.92189700E-01, -.89193300E-01, 0.56576800E+00, 0.98997900E-01, 0.32748000E+01, 0.18868200E+00, 0.27873200E-01, -.14768200E+00, -.39588100E+00, -.31262200E+02, -.45593300E+02, -.51074000E+02, 0.25810700E+02, 0.73373200E+02, 0.27618500E+02, 0.29180300E+02, -.35680300E+02, -.15865100E+02, 0.50566700E+02, 0.95303400E+02, -.30957100E+01, -.87137500E+02, 0.73035400E+01, 0.12134000E+02, -.29213600E+01, 0.26008700E+02, 0.86000800E+00, 0.22005100E+02, -.12895600E+02, 0.23225200E+01, 0.13780400E+01, 0.32611000E+01, -.95990400E+01, -.42728700E+01, 0.80315400E+01, -.65989100E+01, 0.11156100E+01, -.45832300E+01, 0.11224400E+02, -.42845400E+01, 0.93207000E+01, 0.16696000E+01, 0.13960900E+02, -.11232800E+02, 0.45809200E+01, -.87335700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.40839600E+01, -.15507400E+01, -.91578900E+00, 0.69741900E+00, 0.30617100E+01, -.18645300E+01, -.39557800E+00, 0.26522200E+01, -.88010400E+00, -.12913300E+01, 0.11853400E+01, 0.17506100E+01, 0.19835500E+01, 0.43439600E+01, -.44239700E+00, -.32287000E+00, 0.15512000E+01, -.22313600E+00, -.35539600E+00, 0.97312500E-01, 0.14103500E+01, -.25790300E+01, 0.76530900E+00, 0.53507600E+00, 0.64407100E-01, 0.37486900E+00, -.23983500E+00, -.24471000E+00, 0.44269200E+00, 0.82479900E+00, -.13507000E-01, 0.26369100E+00, -.99275300E+00, 0.68177100E-01, 0.46101100E-01, 0.69542300E+00, -.14717200E-01, 0.46163300E+00, 0.39231600E+00, 0.66283400E+00, -.76777700E+00, -.18459200E+01, 0.43251100E+00, 0.37384600E+00, 0.52114000E+00, -.11904000E+01, -.90270600E+00, 0.17593000E+00, -.57640200E+00, -.24846600E+01, 0.10992300E+00, 0.28346000E+00, -.90228700E-01, 0.10360200E+01, -.10673500E+01, -.67291100E+00, -.68683100E+00, -.38545100E+00, 0.11987600E-02, 0.16573800E+01, 0.89746500E+00, 0.10618100E+01, -.17645500E+00, -.82010100E+00, 0.92663800E+00, -.80266600E+00, -.76973700E+00, 0.89457800E+00, -.48555800E+00, 0.12789500E-01, -.41346800E+00, 0.85493400E-01, -.34280900E+00, 0.20159800E+00, 0.49018500E+00, -.71525600E-01, -.24039700E+00, 0.44320400E+00, 0.28496500E+00, -.40741700E+00, 0.49446300E-04, -.56360600E+00, 0.87275600E+00, -.22333000E+01, -.25729800E-02, 0.53851100E+00, -.57151700E+00, -.29117200E+00, 0.17614100E+00, 0.27043700E-01, -.61431900E+00, -.13610900E-01, 0.10959600E+01, -.16163300E+01, 0.28163900E+00, -.54002900E+00, 0.87636900E-01, -.27316400E+01, 0.48786500E+00, 0.40255400E+00, 0.23300800E+01, 0.37948900E+00, 0.49128700E-01, 0.91527600E-01, 0.15069300E+01, 0.46017300E+00, 0.13193100E+00, 0.26604800E+00, 0.17154900E+00, 0.11066000E+00, -.58432100E+00, -.70959000E-01, -.12073500E-03, -.73354300E-02, -.72769600E-01, -.27192600E+00, -.11833000E-01, 0.92658200E+00, -.12677800E+00, -.55194800E+00, -.69663900E+00, 0.11450600E+01, 0.10817800E+01, 0.25087500E+00, 0.98463200E-02, 0.70374900E-01, -.15626700E+00, 0.31415400E-01, 0.41410700E+00, -.19176100E+00, -.43169000E+00, 0.20553800E+00, 0.16343500E+00, 0.96062300E-01, 0.25199700E+00, 0.10494300E-02, -.22601500E+00, 0.29748700E-02, 0.41311900E-01, -.10283700E+00, 0.13811900E+00, -.71769600E-01, 0.11313900E+00, 0.57676400E-01, 0.31299400E+00, -.25496600E+00, -.23280500E-01, 0.14288100E+00, -.50232800E+00, 0.21807900E+00, 0.99656700E-01, 0.13392300E+00, -.99884000E+00, -.31118100E+00, 0.87202900E-01, -.70217700E-01, 0.15050900E+01, -.82454500E-01, 0.41065300E-02, 0.64516200E+00, -.13861800E+00, -.40159900E+00, 0.45291800E+00, 0.30059500E+00, 0.11653700E+01, 0.96062500E-01, 0.20701000E+00, 0.26257500E+00, 0.17517000E-01, -.88902000E-01, 0.20030200E+00, 0.35312000E+00, 0.35613000E+00, 0.34128300E+00, 0.60750500E-01, 0.45672800E-02, 0.24922900E+00, -.11672100E+00, -.76341100E-01, 0.22514600E-02, 0.24114600E+00, 0.14707600E-01, -.40687800E+00, -.19154600E+00, 0.76650000E-01, -.10321800E+00, 0.73232300E-01, -.12274300E+00, -.62988400E-01, 0.21567700E+00, 0.77083200E-02, 0.44912400E+00, -.24186000E-02, 0.19274700E+01, -.58850200E+00, -.57148500E+00, 0.77580800E+00, 0.72296100E-01, -.20837500E-01, 0.38910700E+00, 0.18218500E+00, -.22685300E-01, 0.83055700E+00, 0.61655200E+00, -.57976000E+00, -.18188300E+00, 0.17175700E+00, 0.22650300E+00, 0.32762100E-01, -.63025200E+00, 0.34043600E-01, -.32581100E-01, 0.32437500E-01, -.13658600E+01, -.11734800E+01, -.43880400E+00, 0.33166000E+00, -.25687100E-01, -.10531600E+01, 0.19430500E+00, -.13832600E+00, 0.69118000E-02, -.11083300E+01, 0.19237400E-02, -.12964400E-01, 0.88310700E+00, -.27089600E+00, -.19828600E+00, -.25373000E+00, -.78927600E-01, -.38618100E+00, 0.39809400E-01, 0.23277200E-02, -.20220900E+00, 0.15877800E-01, -.90334600E+00, -.20034600E+00, -.92031200E-01, -.18759800E+00, -.32814800E+00, -.30317400E+00, 0.40649300E+02, -.39031000E+02, 0.19807100E+02, 0.25492800E+02, 0.15290300E+02, 0.46205100E+01, 0.12669900E+01, -.38180400E+01, 0.52798200E+01, 0.37130000E+02, 0.19940700E+01, 0.68391200E+01, 0.14593500E+01, 0.31615100E+00, -.72063600E-01, 0.26606900E+01, -.86771600E+00, 0.12048200E+01, -.11448900E+01, -.43701600E+00, -.73255400E+00, 0.19663800E+00, 0.27462800E+01, -.11569000E+01, -.22270900E-01, 0.44479700E+00, 0.75538600E+00, -.77623100E+00, 0.20021800E+01, 0.14838800E+00, 0.24196000E+00, -.27609600E+00, 0.20054000E+01, -.20440200E+01, -.10792800E+01, 0.14180400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.17165100E+02, -.35179000E+01, -.78234900E+01, 0.94520700E+01, 0.98267600E+01, -.16055500E+01, -.14417400E+01, 0.82256700E+01, -.19998300E+01, -.32160400E+01, -.68143000E+01, -.20155200E+01, 0.63966900E+01, 0.63292100E+01, 0.78536900E+00, -.43148400E+00, 0.33739700E+01, 0.47626400E+01, -.77926900E+00, 0.12735000E+01, 0.19271800E+01, -.14685000E+01, -.16098600E+02, 0.75695700E+01, 0.22366400E+00, -.96506800E+00, -.60478700E+00, 0.92706100E+00, -.24437400E+01, -.28990400E+01, 0.56498800E+00, 0.82610700E+00, -.36156900E+01, 0.13268600E+00, -.34237000E+00, 0.12613000E+01, -.25658400E-01, 0.15327300E+01, 0.25195300E+00, 0.18554400E+01, 0.29332900E+01, -.27114500E+00, -.12028100E+02, 0.26304500E+01, -.66909500E+00, -.75356700E+00, -.28718800E+01, -.10068900E+01, -.12242600E+01, -.13123800E+01, -.55977400E+00, 0.46738700E+00, -.15815800E+00, 0.94621500E+00, -.32637900E+01, -.12251900E+01, -.63543200E+00, -.51269300E+01, 0.52078400E-02, 0.33643700E+00, -.17455800E+01, -.18033100E+00, -.76650100E+00, 0.10200800E+00, -.75481000E+01, -.22231500E+01, 0.21883500E+01, 0.89950000E+00, 0.36379500E+00, 0.14019200E-01, -.21885200E+01, 0.12248800E+01, 0.12487700E+01, -.26216300E-01, 0.34463100E+00, 0.66212100E-01, -.32991800E+00, 0.22985700E+01, 0.13929400E+01, -.97332600E+00, 0.27656100E-02, -.27959800E+01, 0.26806200E+01, 0.16585200E+01, 0.51398900E+00, 0.17033000E+01, -.17877900E+01, 0.97585700E+00, 0.54731400E+00, -.76682300E+00, -.26166000E+01, 0.25593200E-01, -.48853500E+00, -.66328200E+01, 0.61274100E+01, 0.23720600E+01, -.68219000E+00, -.50487900E+01, 0.22373200E+01, 0.14911800E+01, 0.10927100E+01, 0.36218400E+00, 0.55322300E+00, 0.40594400E+00, 0.28536400E+01, -.22820100E+01, -.54954100E+00, 0.12020200E+01, 0.28670400E+01, -.22565300E+01, 0.34525700E+01, -.17522600E+00, 0.29366800E+00, 0.31237900E+00, 0.10432200E+01, -.14558900E-01, 0.13371600E+01, 0.22430200E+01, -.31394700E+00, -.15190100E+01, -.27809500E+00, 0.35513800E+00, -.19737300E+01, 0.83039300E+01, -.27583000E-01, -.12351800E+01, 0.12295800E+01, 0.73323800E+01, 0.80739900E+00, 0.54369500E+00, 0.10287700E+01, 0.53293700E+00, 0.96745100E+00, -.16035600E+00, -.13972200E+01, 0.35004200E-01, 0.27861400E+01, -.10154700E+01, -.58451700E-01, 0.45487100E-01, -.56973300E+00, 0.23411300E+00, -.42774500E+00, 0.88956900E+00, 0.30337900E+00, -.32977000E+00, 0.36174500E-01, 0.15669000E+01, 0.21672700E+01, -.12271800E+00, -.12844400E+00, 0.48799100E+00, 0.11804100E-02, -.23901700E+00, 0.12964800E+01, -.19356200E+00, -.18743400E+01, 0.91395700E-01, 0.23661800E+01, 0.48217100E+00, 0.88612400E+00, -.15985800E+01, 0.12182400E+01, 0.45428600E+00, -.13750800E+01, 0.17011400E+00, 0.14184900E+00, -.67599900E-01, 0.30397600E-02, -.35149300E+00, -.10630900E+00, 0.23232100E+01, -.13069100E+00, 0.33688800E+00, 0.18731600E+01, 0.60447000E-01, 0.85287400E-01, -.28216500E+00, 0.24618200E+00, -.48343600E-02, 0.24292600E+01, -.94193900E+00, 0.81287300E-01, -.15673200E+01, 0.11454900E+01, -.12596100E+01, 0.12477100E+01, -.56548500E+00, 0.48016900E-01, 0.17565000E+01, -.14395800E-01, -.25343900E+01, -.23888000E+01, 0.39470800E+01, 0.43158500E+00, 0.39349700E+01, 0.10209600E+01, 0.36555200E+00, 0.98837700E+00, -.36303000E+00, 0.42989800E+00, -.24567400E-03, 0.40095800E+01, 0.98196200E+00, -.23928200E+01, -.10319400E+01, -.23914400E+01, 0.82333600E+00, 0.44689200E+00, -.16724700E+01, 0.12070800E-01, -.86075300E-01, 0.78701200E-01, 0.12117100E+01, -.12311600E+01, 0.29934000E+00, 0.44997200E-01, 0.13305200E+01, -.51297300E+00, -.17079200E+01, 0.90219800E+00, -.39837100E-02, 0.13098500E+01, 0.21231500E-01, -.70461900E+00, -.13462800E+01, -.14057400E+01, -.27969100E+01, 0.19521300E+00, 0.56333600E+00, 0.11702000E+01, -.58256400E+00, 0.22902100E-01, 0.60761100E+00, 0.17083300E+00, 0.27896000E+01, 0.14745700E+00, -.28387300E+00, -.24950200E+00, 0.66522400E+00, 0.10671300E+01, 0.81259600E+00, 0.31679800E+03, -.15681000E+03, -.21160800E+03, -.20201100E+03, -.65151400E+02, 0.44227300E+01, 0.10945800E+02, -.21075400E+02, -.78025500E+02, -.16718500E+02, 0.11580600E+03, -.76284300E+01, -.21294200E+02, 0.62838000E+01, -.36685400E+02, 0.31956700E+01, -.30611300E+02, 0.21937100E+02, -.10617000E+00, -.13523000E+01, -.79670500E+01, 0.16448200E+02, 0.58282300E+01, -.40880500E+01, 0.20041600E+01, -.49468000E+01, 0.59950400E+01, -.34674300E+00, 0.78528500E+01, -.44434600E+01, -.72930600E+01, -.15570600E+01, 0.11960700E+02, -.79400400E+01, 0.18102900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54349600E+01, -.12847300E+00, -.18140100E+01, 0.29142400E+01, 0.32360700E+01, 0.16052200E+01, -.75476100E+00, 0.13322800E+01, -.50727000E+00, -.22765300E+00, 0.46794300E-01, -.24010500E+00, -.26731500E+00, 0.16613400E+01, -.46879300E+00, -.11038700E+00, 0.85840800E+00, -.57543600E+00, -.15119300E-01, -.33450700E-02, 0.95845900E+00, -.14341300E+01, -.82120100E+00, 0.16511300E+01, 0.39717000E-01, 0.14236700E+00, -.54074500E+00, -.93073100E+00, -.96044300E+00, -.24468900E+01, -.50690500E+00, 0.13486000E+00, -.73570800E+00, 0.43419900E+00, -.51378900E+00, 0.83498200E+00, -.66772500E-01, 0.95215800E-01, -.17379800E+00, 0.45338000E+00, 0.80454700E+00, 0.64749400E+00, -.94170600E+00, 0.37340100E+00, -.10305000E+01, 0.15231200E+01, -.89331200E+00, -.59653500E-01, 0.30615200E+00, 0.18659500E+01, 0.71072200E+00, 0.14688900E+00, 0.95128800E-01, -.31294500E-01, 0.51801900E+00, -.13218000E+01, 0.20808400E+00, -.31737500E-01, -.17662500E-02, 0.12907900E+01, 0.11244300E+01, 0.18226800E+01, -.27957300E+00, -.17490200E+00, 0.30227600E+01, 0.10266900E+00, -.24786400E+00, -.17322400E-01, -.38763400E+00, 0.58463200E-02, 0.89688100E-01, 0.28704300E+00, -.27831500E+00, -.13091400E+00, 0.26282600E+00, -.17313900E+00, -.33001200E+00, 0.10973200E+00, -.14702100E+01, 0.25175800E+00, 0.14257400E-02, 0.13038300E+01, -.34317000E+00, 0.48080200E+00, -.21277600E+00, -.92838600E+00, -.23680800E+00, 0.29812800E+00, 0.44201500E+00, 0.33067900E+00, 0.18637900E+00, -.14079800E+00, 0.26090200E+00, 0.81097800E+00, -.83848800E+00, -.11112600E+01, 0.70234800E+00, 0.40264600E-01, -.69165100E+00, -.48925700E+00, 0.17285300E+01, 0.31986100E+00, 0.18655300E+00, -.37569900E+00, 0.47523300E+00, -.79636900E+00, -.14138800E+00, -.20963000E+00, 0.54183200E+00, 0.69645100E+00, -.24351600E+00, -.26756700E-02, -.25991800E+00, 0.51393200E-02, 0.12750400E+00, 0.14369400E+01, -.75738100E+00, 0.47249000E+00, 0.28582600E-01, 0.47094000E+00, 0.54056500E+00, -.85046600E+00, -.19022800E+01, 0.13787300E+01, -.15881500E-01, 0.18322100E+00, -.27598000E+00, 0.33032200E+00, -.37044300E+00, -.56843500E+00, -.24711600E+00, -.28248100E+00, 0.29744600E-01, 0.79687900E-01, 0.28619200E+00, 0.32444000E-02, -.24764900E+00, -.58933100E+00, -.15183800E+00, -.30506100E-01, -.64519400E-01, 0.95313400E-01, 0.98340500E-01, 0.96275000E-01, -.67050400E+00, -.21070500E-01, -.42488100E-01, -.67052800E+00, 0.10857500E+00, -.27930700E+00, -.21994000E-01, 0.25279800E+00, 0.26263200E+00, 0.23309100E+00, -.32909300E+00, 0.73197800E-03, -.11146900E+01, -.54313600E-02, 0.19588800E+00, -.19700300E+00, -.11718500E+00, -.53509100E+00, 0.17479700E+01, 0.41780000E+00, -.35580100E+00, -.11976200E+00, 0.35382400E-01, -.55321900E-01, 0.15637900E-01, -.85108600E-01, -.45775300E-01, 0.25902400E+00, 0.19755100E-01, -.19506200E+00, 0.35246100E+00, -.12783400E+00, 0.24040200E-01, 0.20087700E-01, 0.50632000E-01, 0.98809900E-03, 0.46108000E-01, 0.22244600E+00, -.16123800E+00, -.78693100E-01, -.11719900E+00, -.48923500E+00, -.13971100E+00, 0.19175800E+00, -.51134000E-01, 0.79331000E-01, -.22950700E-03, -.36841500E+00, -.25785600E-01, 0.34199700E+00, -.10265000E+00, -.17425800E+00, 0.28524700E+00, -.71285300E-01, 0.22689900E+00, -.24488600E+00, -.25658000E-01, -.33179600E-01, 0.90214200E+00, -.65665100E-02, -.33140700E+00, -.89821400E-01, 0.34393500E+00, 0.21825000E+00, 0.29878900E+00, -.37437400E-01, 0.48834900E-02, 0.52873400E-01, -.60650200E-01, -.10447500E-01, 0.67643700E+00, 0.51335200E+00, -.14742700E+00, 0.55438800E+00, 0.16335000E+00, 0.71969100E-01, 0.79325700E-01, -.62388200E-02, 0.23891900E+00, 0.57652300E-02, -.35604500E-01, -.23886500E+00, -.42658900E-01, -.25378300E-01, 0.23313000E+00, 0.23699900E-01, 0.15593500E+00, -.62302300E-01, 0.37061900E-01, -.41093600E-01, -.45358100E-02, -.33357200E+00, -.55362900E-01, -.60283600E-02, 0.10250400E-01, 0.32083700E-02, -.73081200E-01, 0.29991100E-02, -.38402500E-01, 0.15025000E+02, -.73228500E+00, -.81092800E+01, -.25901200E+00, 0.50926700E+01, -.54084000E+01, -.51967400E+01, -.39079200E+01, 0.35199500E+01, 0.99740100E+01, -.22513400E+00, -.42677400E+00, 0.25776200E+00, -.14630300E+01, 0.10533000E+00, -.40327400E+00, 0.70611900E+00, -.47342200E-01, -.11880300E+00, -.25199000E+00, 0.14670300E+01, 0.14100000E+00, -.50477100E+00, 0.45124000E+00, -.21001600E+00, 0.16150300E+00, -.33483900E+00, 0.18676300E+00, -.53156400E+00, -.71747600E-01, -.20630500E+00, 0.34457200E+00, -.14986100E+00, 0.51866700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.42526200E+01, 0.77061200E+00, 0.57271000E-01, 0.80326100E+00, -.24574700E+01, 0.74930000E-01, 0.61023000E+00, -.61891600E+00, -.35248400E+00, 0.66083000E+00, 0.10695100E+01, 0.48667000E+00, 0.16454300E+01, 0.13844600E+01, -.46655100E+00, -.72916900E-01, 0.71768400E-01, 0.12510000E+01, 0.34524800E+00, -.27021800E+00, -.49923100E-01, 0.16776400E+01, -.10717400E+00, 0.34531100E-01, 0.66544900E-01, -.61438200E+00, 0.12920200E-01, 0.84938600E+00, 0.54373000E+00, -.16107800E+00, 0.48671300E+00, -.38887500E-01, -.94651100E+00, -.75302600E+00, 0.55603400E-01, 0.22571200E+00, -.18144800E-01, 0.53726200E+00, 0.15037100E+00, 0.51193700E-02, 0.25215500E+00, -.81097900E+00, -.73633000E+00, -.22946600E+00, -.53051100E+00, 0.12764600E+01, -.82967600E+00, -.23442600E-01, -.31754000E+00, -.58147200E-01, 0.68553900E+00, 0.10633500E+01, 0.18516100E+00, -.14991700E+00, -.35782300E+00, -.18214000E+00, 0.16621300E+00, -.75428700E-01, -.25576100E-02, 0.12068800E+00, -.20409500E+00, -.53020400E+00, 0.26557100E-01, -.46357700E+00, 0.18434900E+00, -.44567200E+00, -.90817600E-01, 0.92217700E+00, -.52438200E+00, -.49350900E-02, 0.10984400E+00, -.41950700E+00, -.53634500E+00, -.46328000E-01, -.32653000E+00, 0.11070300E+00, 0.19332600E+00, 0.41972100E+00, 0.15810600E+00, 0.74383000E-01, 0.34554400E-03, -.55243200E+00, -.10421500E-02, -.60002400E+00, 0.10223200E+00, 0.51321800E+00, -.44324300E+00, 0.28653000E-01, -.17513400E+00, -.17185500E+00, -.29055700E-03, 0.17437500E-01, -.41299500E+00, -.32688300E+00, 0.69534600E+00, 0.16298000E+01, -.68680900E+00, -.26764800E+01, 0.23182300E+00, 0.91594600E-01, -.39300100E+00, -.49326000E-01, 0.83773200E-02, -.10031100E-01, -.21428000E+00, -.29282200E+00, -.46789300E-01, -.47622800E+00, 0.16777000E+00, 0.44384200E-01, 0.36778600E+00, -.36325900E-01, 0.13307400E+00, 0.83223500E-02, 0.23926400E+00, -.44007300E+00, -.95768700E-01, 0.86837000E-01, -.36758400E-01, -.31128200E+00, 0.25655900E+00, -.20556100E+00, -.87961400E+00, 0.77086200E+00, -.83905500E-02, 0.19703100E+00, -.50994300E-01, -.28482000E+00, -.18496300E+00, -.63277100E-01, 0.14332600E+00, -.30699300E+00, -.25591500E+00, 0.10491700E-01, 0.32947400E+00, 0.16725100E-02, -.25159000E+00, 0.21826500E+00, -.11088300E+00, 0.13200900E+00, 0.58784100E-02, 0.25279300E+00, 0.10348000E+00, -.22723400E+00, -.85876700E+00, 0.38222000E+00, -.10424200E-01, -.18767400E+00, 0.60509200E-01, 0.31259700E+00, 0.22520500E-01, -.48470400E-01, 0.29896300E-01, 0.13223500E+00, -.55501800E-01, 0.84163900E-02, 0.94274600E+00, -.60261200E-01, 0.90071000E-01, -.13013500E+00, -.35478000E-01, -.67175500E-01, 0.15978800E+00, 0.33417600E-01, 0.24996600E+00, -.19037400E-01, 0.31112400E-02, -.24414500E-01, 0.45907900E-02, -.47033700E-01, 0.82185900E-01, -.32304400E+00, 0.87818900E+00, 0.10696300E+00, -.18271900E+00, 0.94263800E-01, -.12655700E+00, -.62328500E-01, 0.59961800E-03, 0.43546200E-02, 0.62566900E-02, -.88318200E+00, 0.13173500E+00, 0.76682900E-01, -.42969900E+00, -.31439300E+00, -.10285600E+00, 0.11943600E-01, 0.10839900E+00, -.40297300E-01, 0.47554100E-02, 0.35245200E+00, -.14467500E+00, -.82495700E+00, 0.28009600E+00, 0.12962200E+00, 0.28421900E+00, -.98323700E-01, -.19498900E+00, -.43384700E-01, -.17505700E+00, -.52049200E-01, 0.31940900E+00, 0.34180600E+00, -.15527300E+00, 0.64112100E+00, 0.13782400E+00, -.45338200E-01, -.37453500E+00, -.89815300E-01, 0.54043200E-01, -.34125400E-01, 0.49697700E-01, -.14129400E+01, -.61776900E+00, 0.54269000E-01, 0.26550300E+00, -.38585800E+00, -.16162800E+00, 0.64958300E+00, 0.20518800E+00, 0.16297800E-01, -.34891500E+00, -.15745200E-02, 0.84777200E-01, 0.45626200E+00, 0.18029900E+00, 0.33994800E-02, -.81045100E+00, 0.14800900E+00, -.13255700E+00, -.57561200E-01, 0.38658000E-02, 0.11501000E+00, 0.26934700E-01, 0.34871900E+00, 0.22042200E+00, 0.15162300E+00, -.45094500E-01, 0.35032700E+00, 0.38669200E+00, -.12093400E+00, -.80837400E-01, -.92074100E-02, -.29180100E+02, -.41105400E+01, -.56689700E+01, -.24166700E+02, 0.63178500E+02, 0.19288600E+02, 0.15733500E+02, -.23890100E+02, 0.12956200E+02, -.22819900E+01, -.48235000E+01, 0.12568800E+01, -.71916000E+01, -.67626700E+00, -.48583700E+01, 0.55899400E+01, -.87577600E+00, 0.29957000E+00, -.32138700E+01, -.11551100E+02, 0.22164200E+01, 0.59903100E+01, -.58547200E+01, -.10917700E+01, 0.15324200E+01, 0.59010900E+01, 0.17879100E+01, 0.60454500E+01, -.22771000E+01, 0.63080900E+01, 0.44324900E+01, -.13294000E+01, 0.53144200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.12327800E+02, 0.20818700E+01, 0.26823700E+01, -.23407800E+01, -.89091900E+01, 0.52201200E+00, 0.14809800E+01, -.47942300E+01, 0.39507800E+00, 0.21540000E+01, 0.22393100E+01, 0.29826200E+00, -.13309800E+01, -.31075900E+01, -.93166200E+00, 0.55889100E+00, -.16994000E+01, -.49888000E+00, 0.66910300E+00, -.19943900E+01, 0.41798600E+01, 0.10539300E+02, 0.49336400E+01, -.38643500E+00, -.17844500E+00, -.34353700E+01, -.22913700E+00, 0.83398000E+00, 0.41642900E+00, -.46797300E+01, 0.22622600E+00, -.55736300E+00, 0.10454400E+01, -.46970100E+00, 0.12828600E+00, -.32741100E+01, -.94271900E-01, 0.42770000E+00, -.29807500E+00, -.11786500E+01, -.18717900E+01, -.29816900E+00, 0.50332700E+01, -.15867200E+01, 0.21109500E+01, 0.70281000E+00, -.29168500E+00, -.32650300E+00, 0.38429500E+00, 0.68956700E+00, 0.68177000E+00, -.53814400E+00, 0.25041900E+00, -.12919400E+01, 0.89101300E+00, 0.25741900E+01, -.27101600E+00, 0.35287000E+01, -.60765400E-02, -.94277100E+00, -.52198400E+00, 0.85124700E+00, 0.14322100E-01, -.10766100E+01, 0.10732800E+01, -.95980800E-01, -.10362500E+01, -.25854500E+01, 0.24422200E-01, -.59881700E-02, 0.19602300E+00, -.43033500E+00, -.75974400E+00, -.62258300E-01, -.69626200E-01, 0.34221100E+00, 0.13508800E+01, -.20572900E+00, 0.25592100E+01, -.47054300E+00, -.65239000E-03, -.43830600E+01, 0.22278400E+01, 0.22751200E+01, -.12970800E+00, 0.15408900E+00, -.15482200E+01, -.35367900E+00, 0.35450900E+00, -.11905100E+01, -.31127100E+00, -.85078800E-01, -.13254400E+01, 0.55944300E+00, 0.72019000E+00, 0.23001900E+00, 0.49869500E+00, 0.23751700E+01, -.33409400E+00, -.10432500E+01, -.67843200E+00, -.39746300E+00, 0.16974000E+00, -.71472600E+00, -.25125500E+00, -.10032300E+01, -.41356100E+00, -.25115400E+00, -.40955800E+00, 0.15695000E+00, -.65762400E+00, -.34533000E-01, -.38085600E+00, 0.11372700E-01, 0.30804600E+00, 0.83342400E+00, -.39544600E+00, -.15769000E+00, 0.13932100E+00, 0.12573200E+00, -.54612800E-01, -.13862300E+01, -.46688700E+01, 0.53760900E+01, -.25471100E-01, -.31083700E+00, -.37843500E+00, 0.28773500E+01, -.11365800E+01, -.45644100E+00, -.62793200E+00, 0.30289200E+00, 0.17147800E+00, 0.22231100E+00, -.81683000E+00, 0.39350100E-02, 0.15272900E+00, -.15251400E+01, -.63799700E-01, -.42800900E+00, -.48768600E+00, -.49973400E+00, 0.25320800E-01, 0.65087500E+00, 0.22508800E+01, -.41437500E-01, 0.41190300E-02, 0.17010000E+01, 0.16879600E+01, 0.81653900E+00, 0.36320900E+00, -.41816200E+00, -.19157000E+01, -.75566000E+00, 0.95473500E-01, 0.31346000E+00, -.21336400E+01, -.10408800E+00, 0.25679700E+00, 0.56032400E+00, 0.67501000E+00, -.53684400E+00, -.10544800E+01, -.13711100E+00, 0.43882000E+01, -.12152100E+00, 0.13703700E+00, 0.17212500E+00, 0.93940900E-01, 0.16446900E+00, -.26018300E+00, 0.34015200E+00, 0.27512600E+01, -.52418900E+00, -.96011800E+00, 0.47410400E+00, 0.33638700E+00, -.45305100E+00, 0.35987500E+00, -.45097600E-03, -.21062900E+01, -.13600500E+00, 0.67367700E+00, -.97384400E+00, 0.63870200E+00, 0.37731200E+00, 0.49816800E+00, -.90728100E-01, -.84938400E+00, -.23265900E+00, 0.52679600E-02, 0.15372200E+00, 0.19514000E+00, -.15193400E+00, 0.19880100E+00, 0.11732700E+01, -.70061500E+00, 0.12654800E+00, -.96335400E-02, -.15719600E+01, -.30846300E+00, 0.73393300E-01, 0.17984700E+00, 0.50530600E-01, -.55123100E+00, 0.12970500E+01, 0.13457500E+01, 0.57399000E+00, 0.28847200E+00, 0.26082600E+00, -.10613800E+00, -.90321600E-01, 0.35999600E+00, 0.36526000E+01, -.60446000E+00, -.20594500E+01, -.34481900E+00, -.63435500E+00, 0.16639400E+00, -.21954600E+00, 0.19175200E+00, -.74498500E-02, 0.30886100E+01, -.17287200E-02, -.47775700E+00, -.16512900E+01, -.24473800E+00, -.41616900E+01, 0.14874500E+01, 0.25298100E+00, 0.88769900E+00, -.15752900E-01, 0.11647500E+00, -.58126900E+00, -.76069100E-01, 0.23506900E+01, 0.43444300E+00, -.18176600E+00, 0.16505500E+00, 0.27587900E+00, -.12728400E+00, 0.12897600E+01, 0.64276300E+00, 0.65749300E-02, -.33598000E+00, 0.38863700E+02, -.19358900E+02, -.69190500E+02, 0.64326500E+02, 0.99124600E+02, -.26045700E+02, -.46645500E+02, -.18163900E+03, -.36782200E+01, 0.63507100E+01, -.41074800E+01, -.91945700E+01, -.60075500E+01, 0.14915000E+02, -.58918000E+00, -.62863200E+01, -.13948800E+01, -.83522400E+00, -.81434100E+02, 0.26291300E+01, 0.23779100E+02, -.21626400E+02, -.11607300E+01, 0.18317900E+01, 0.15646800E+02, -.67922900E+00, 0.23457500E+02, -.16908000E+01, 0.80601500E+01, 0.23175300E+01, 0.84154900E+00, -.13712400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12628900E+02, -.28223000E+01, -.16716800E+01, 0.49962500E+01, 0.81391200E+01, -.43384900E+00, -.14729900E+01, 0.13455400E+01, 0.28018300E+00, -.11853800E+01, 0.81540100E+00, 0.31220600E+01, -.41907600E+01, 0.45824300E+00, 0.12104900E+01, -.75263200E+00, 0.21709000E+00, -.54027600E+00, -.57781500E+00, 0.32381600E+01, -.27296400E+01, -.38636700E+01, 0.15106300E+00, -.28256500E+01, -.74792800E+00, 0.38191800E-01, 0.10925100E+01, 0.11191600E+01, 0.26961500E+00, 0.59576700E+00, 0.13143900E+00, 0.10286000E+01, -.29143100E+01, -.94225700E+00, -.58208100E+00, 0.97898400E+00, 0.28471900E+00, -.10932400E+01, -.14603400E+01, 0.98143500E+00, -.30760900E+00, 0.56867600E-01, -.94027500E+00, 0.17760000E+01, 0.49087400E+00, -.69796400E+01, 0.18712700E+01, 0.19906400E+01, -.18915200E+01, -.78679400E+01, -.90465200E+01, -.32960000E+01, -.11248000E+01, 0.49834600E+00, 0.23502000E+00, -.64702000E+00, 0.56447100E-01, 0.24707200E+01, -.48542800E-01, -.10730200E+01, -.25994800E+00, -.41726400E+01, 0.38660700E+00, -.21894300E+00, 0.18656200E+01, 0.17144300E+01, 0.13507200E+01, -.36496600E+01, 0.49988000E+00, -.90739900E-01, 0.18778000E+01, -.10100300E+01, -.98148700E-01, -.59490800E-01, -.17497900E+00, 0.74022500E+00, 0.99005200E+00, 0.16286500E+01, 0.15077700E+01, -.13706700E+00, 0.12369200E+00, -.24799500E+01, -.79886800E-02, 0.11946900E+01, 0.11328500E+01, -.26743400E+00, 0.75726500E+00, 0.44578000E+00, -.12166400E+01, 0.31661600E+00, 0.63577600E+00, 0.17171500E+00, 0.45770400E-01, -.41294400E+01, 0.27275300E+01, 0.27838200E+01, -.17289800E+01, -.43941900E+01, 0.22086800E+01, 0.16266000E+01, -.16679600E+01, -.11805100E-01, -.14133200E+00, 0.11434200E+01, -.97675700E-01, 0.31855900E+00, -.17902600E+01, -.31118200E+01, -.10090500E+01, 0.23593600E+01, -.20176500E+01, -.12824600E+00, -.13587000E+00, 0.18597600E-02, 0.30823100E+00, 0.10055100E+01, 0.34282900E+00, -.35914800E+00, 0.23535400E+00, -.16978300E+00, -.11583300E+00, -.11152000E+01, 0.13468000E+00, 0.18261000E+01, -.66580800E-02, -.13925300E+00, 0.92726300E+00, 0.54651100E+01, 0.18266100E+00, 0.12019200E+00, 0.48362700E+00, 0.74457000E-01, 0.26101000E+00, 0.55314400E-01, 0.40273300E+00, 0.21245000E-01, 0.41165900E+00, 0.18602700E-01, -.18111900E+00, -.43744700E-01, 0.31073000E+00, 0.21873100E+00, -.11011400E+00, 0.87807700E+00, 0.71036000E+00, 0.11306900E+01, 0.15347500E+00, -.25655200E-01, 0.66193800E+00, 0.98231700E+00, -.16195000E+00, -.44525900E+00, 0.11862700E+01, -.46711900E+00, 0.16051900E+00, 0.11479900E+00, -.33501500E+01, 0.13712600E+00, 0.18367300E+01, -.21012700E+00, -.35835500E+00, -.18332200E+00, -.29828800E+00, -.12650200E+00, -.12759300E+01, 0.43016100E+00, -.71402400E-01, -.20385300E+00, -.63009300E-01, -.66492100E-01, 0.14632500E-01, 0.77470000E+00, -.51623800E+00, -.28320300E-01, -.26575000E+00, 0.51947400E-01, -.99886200E-01, -.21550100E+00, -.23138100E+00, -.57177200E-02, 0.52245200E-01, -.11678800E+01, 0.54407500E+00, -.42845300E+00, 0.19625800E+00, -.93546800E+00, 0.49328400E+00, -.35149800E+00, 0.23805800E+00, 0.19581900E+00, -.10029500E-01, -.26579600E+01, 0.21948000E+00, -.13226900E+01, 0.91257600E-01, -.44481600E+00, -.63360700E+00, 0.15991900E+00, -.27366100E+00, 0.50254300E+00, 0.28259500E+00, 0.22503100E+00, 0.19416400E+00, 0.13292100E+00, -.54955100E+00, -.56333200E+00, -.37480400E+01, 0.59472900E-01, -.46960800E+00, -.66840900E+00, 0.95455600E-01, -.21079900E+00, 0.22411200E+00, 0.29974100E+01, 0.52937300E+00, -.93562900E+00, -.22452500E-01, 0.15700900E+00, 0.49234800E+01, -.17210100E+01, 0.62155300E+00, 0.12272600E+00, 0.14528100E+01, -.14089200E-01, -.82918100E+00, -.21858900E+01, 0.35495900E-01, -.10341300E+01, 0.20670900E+01, 0.43281600E+00, 0.16074400E+01, -.47919300E+00, 0.61754400E-01, -.24259400E+00, -.18760700E-01, -.38322100E+01, -.64564600E+00, -.39291600E+00, -.69029300E-01, 0.28224500E+00, -.57529000E+00, 0.45255400E+00, 0.49506100E+00, 0.32312400E-01, 0.40237400E+00, 0.14764500E+00, 0.27818400E+02, 0.76418600E+02, -.16783400E+03, -.10032400E+03, -.49661900E+01, 0.63316600E+02, 0.61267000E+02, 0.51509300E+01, -.11554100E+02, -.48228600E+00, -.11278600E+02, 0.55533200E+01, -.27610400E+02, 0.68227000E+01, 0.50904900E+01, 0.17985300E+01, 0.71969500E+01, 0.50737800E+02, -.51305100E+01, -.16585500E+02, 0.17264100E+02, 0.31906400E+01, -.36953800E+01, -.13812400E+02, -.29874400E+01, -.16354200E+02, 0.66829300E+01, -.13210900E+02, -.91956600E+01, 0.51633700E+01, 0.24312200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.85114900E+01, 0.28175800E+01, 0.25459900E+01, -.19530000E+01, -.55969900E+01, 0.32668700E+01, 0.75142400E+00, -.56193400E+01, 0.16516900E+01, 0.27307500E+01, -.15971400E+01, -.24056600E+01, -.53177700E+01, -.52015300E+01, 0.52201800E+00, 0.55649400E+00, -.25057400E+01, -.21782000E+01, 0.27908500E-01, 0.17899100E+00, -.21168200E+01, 0.39699400E+01, 0.35696600E+01, -.18157300E+01, 0.13230000E-02, -.76586800E+00, 0.74811400E+00, 0.41692300E+00, -.17828700E+00, 0.15664100E+01, -.38911200E+00, -.46149700E+00, 0.29339400E+01, 0.10556800E+00, 0.17687900E-01, -.21264500E+01, 0.52599900E-01, -.11423200E+01, -.44928000E-01, -.13037100E+01, -.12843200E+01, 0.71704600E+00, 0.13178000E+01, -.56273800E+00, 0.14779600E+00, -.41491100E+00, 0.54468600E-01, -.58951600E-01, 0.14404600E+00, 0.11077300E+01, 0.23019800E+01, 0.62325900E+00, 0.46010900E+00, -.82069600E+00, 0.72331300E+00, 0.81850700E+00, 0.33071900E+00, 0.24280900E+01, -.22470900E-02, -.10188600E+01, -.79896600E-01, -.78377900E+00, 0.48683700E+00, 0.60939500E+00, 0.10356000E+00, 0.48784800E+00, -.61225100E+00, -.58724100E+00, -.19345700E-01, -.12526200E-01, 0.10787700E+01, 0.74274300E-01, 0.97328900E+00, -.14223700E+00, 0.77286000E+00, 0.65945100E-01, 0.25713800E+00, -.74183000E+00, 0.50492600E-01, 0.27466300E+00, -.26828100E-03, 0.38625300E+00, -.60719700E+00, -.21392800E+00, -.16640000E+00, -.99787000E+00, -.29161100E-01, 0.19688700E+00, -.36723000E+00, -.11517700E+00, 0.42061000E+00, 0.16710400E-01, -.45175800E+00, -.79788600E+00, -.10522600E+01, -.24606100E+01, 0.77991900E+00, 0.29356100E+00, -.19292900E+01, 0.23801300E+00, -.32967200E+00, -.73296200E-02, 0.15494600E+00, -.43507100E+00, 0.19615300E+00, -.93324600E-01, 0.33124800E+00, 0.68159500E+00, -.11598200E+00, -.59687300E+00, 0.41334900E+00, 0.18221400E+00, -.69317400E-01, -.14759100E-01, -.29602900E+00, -.42260100E+00, 0.45850800E+00, -.99883400E+00, -.37892500E+00, 0.14963100E+01, 0.27212000E+01, -.25346800E+01, -.72004700E+00, 0.13633300E+01, 0.66873500E-02, -.92160600E+00, 0.69154800E+00, 0.26346500E+01, -.49954500E+00, 0.39043700E-01, 0.49683100E+00, 0.45457000E+00, -.51531400E+00, 0.65950500E-01, -.89144200E+00, -.15704700E-03, 0.33304700E+00, 0.73151500E+00, 0.35498400E+00, 0.54746800E-01, -.25390100E+00, -.69482500E+00, -.34382400E+00, -.63829400E-01, -.30115700E+00, -.11568500E+01, -.12202900E+00, -.14828200E+00, -.17626200E+00, -.62785600E+00, -.15611800E+00, -.20789000E-01, 0.12286500E+01, -.17562700E-01, 0.83714000E-01, 0.10851900E-01, -.15750500E+01, -.24468400E-01, 0.49689000E+00, -.37931800E+00, 0.24156500E+00, 0.43966200E+00, -.26748700E+00, -.10770800E+00, -.15922900E-01, 0.88666000E-01, -.71406900E-01, -.26527300E+00, 0.52408000E-01, -.10358700E+00, -.39315600E+00, 0.56430000E+00, -.16975100E+01, -.41925800E+00, -.20677200E+00, -.14714400E+00, 0.86084000E-01, 0.86238400E-02, -.13478100E+00, -.40474600E-02, -.21159600E+00, 0.70703400E+00, 0.43694400E+00, 0.89828200E-01, -.20644300E+00, -.49008700E+00, -.22523400E+00, 0.98391200E-02, 0.96887600E-01, 0.14719500E-01, -.74005300E-02, -.41334500E+00, 0.65663400E-01, -.17962300E+01, 0.48971800E+00, 0.22062000E+01, -.17148100E+01, 0.17694900E+00, -.76321200E-01, -.71574800E+00, -.76420400E-01, 0.84038900E-01, 0.32008900E+00, -.54798200E+00, -.18552500E+00, -.48119200E+00, -.90174200E-01, 0.10393000E+00, 0.41616500E+00, 0.70908900E+00, 0.32729700E-01, 0.35813600E-01, -.37992600E-01, 0.23048100E+01, 0.87399700E+00, 0.19944600E+00, -.42719200E+00, -.11640900E+00, 0.30771900E+01, -.12331700E+01, 0.17322200E+00, 0.42441000E-01, 0.11160100E+01, -.28752800E-02, -.76187800E-01, -.42033900E+00, 0.44090500E-01, 0.93661800E+00, 0.37963000E+00, 0.30872200E+00, 0.25968300E+00, 0.11130100E+00, 0.84179300E-02, 0.22418900E+00, -.20511300E-01, 0.17235300E+01, 0.92599500E-01, -.69270800E+00, 0.33523400E+00, -.12053800E-01, 0.32013300E+00, 0.61794400E+00, 0.24563100E+00, -.48389300E-01, 0.83231600E+00, 0.56315000E+00, 0.32133000E+00, 0.94760600E+02, -.11400100E+03, -.11757400E+03, -.85705200E+02, 0.64856700E+02, 0.14617300E+03, 0.30717400E+00, 0.22389600E+01, 0.24596800E+01, 0.61651200E+01, 0.36592900E+01, -.53068500E+01, -.57041100E+01, 0.31471000E+01, -.40135400E+00, 0.22773500E+01, 0.58275400E+02, -.64385700E+00, -.25645300E+02, 0.23564800E+02, 0.11791800E+00, 0.27719200E+00, -.26013700E+02, 0.15590000E+00, -.26655300E+02, 0.26108400E+01, -.23543600E+02, 0.75051500E-01, -.26251600E+00, 0.41738100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.10966500E+02, 0.19305200E+01, 0.28376000E+01, -.40487700E+01, -.50285400E+01, -.99622700E+00, 0.90988000E+00, -.32460200E+01, 0.89675600E+00, 0.11688700E+01, 0.33297100E+01, 0.21444000E+01, 0.21126100E+01, -.17777400E+01, 0.23589700E+00, -.40477400E-01, -.14887800E+01, 0.14426900E+01, 0.36602300E+00, -.68641200E+00, -.18625800E+01, 0.33695100E+01, 0.55209400E+01, -.30399600E+01, -.84339100E-01, 0.42210500E+00, 0.14897500E+01, 0.14016800E+01, 0.22143600E+01, 0.43979600E+01, 0.11133200E+01, -.16678000E+00, 0.26013100E+01, -.15264300E+01, 0.18931300E+00, -.15893900E+01, 0.19720200E-01, -.10300800E+01, 0.12135400E+01, -.73696400E+00, -.59043100E+00, -.15274400E+01, -.10213700E+01, -.80678400E+00, -.57882300E+00, 0.80030500E+00, 0.19415400E+01, -.44403400E+00, -.52627300E+00, -.20380800E+01, 0.12864200E+01, 0.10448200E+01, 0.32364900E+00, 0.60970300E+00, 0.12301900E+00, 0.14660000E+01, -.30779900E+00, 0.19861700E+01, -.10974300E-02, 0.70926200E+00, 0.62435300E-01, 0.78500700E+00, 0.59282400E-01, -.60499600E+00, -.59680000E+00, -.63621100E-01, -.54744600E-01, 0.17774300E+01, -.24252100E+00, 0.36601600E-03, 0.48346600E+00, -.25738400E+00, -.11396900E-01, 0.78656200E-01, 0.43710300E-01, 0.37576800E-02, -.48022400E+00, -.75920900E+00, -.15108500E+01, 0.27007900E+00, -.37605300E-02, 0.11250900E+01, -.19402800E+01, -.28892400E+00, -.24820900E-01, 0.21475600E+01, -.56060700E+00, -.90035600E-01, 0.38003500E+00, -.23095600E+00, -.54769600E+00, 0.85554100E-01, -.77736400E+00, -.86499800E+00, 0.63477700E+00, 0.14164100E+01, -.61037500E+00, 0.24223900E+00, -.71114700E+00, -.80400800E-01, -.19282000E+01, -.40170800E+00, -.26754200E+00, -.28989700E+00, -.91046200E+00, 0.74005400E+00, 0.13863600E+00, -.24363300E+00, -.16900200E+01, -.57733500E+00, -.40878900E+00, 0.56453400E-01, -.17247100E+00, -.33192900E-02, -.31424500E+00, -.11725900E+01, 0.87050500E+00, -.94168000E+00, 0.95464200E-01, -.78769600E+00, -.10574900E+01, 0.69337400E+00, 0.11194900E+01, 0.19903800E+00, 0.11928300E-01, 0.85155000E-01, -.29727500E+00, -.34654100E+00, 0.82456100E-01, 0.38462000E+00, 0.26691700E+00, 0.56678000E+00, 0.13668700E+00, -.11777300E+00, 0.53497900E+00, -.34174200E-02, 0.86077600E+00, -.55292000E+00, 0.16524100E+00, -.12799500E+00, -.22752200E+00, -.38018700E+00, -.30024800E+00, 0.29225600E+00, 0.20411500E+01, 0.42255900E+00, 0.51904800E-01, 0.17044000E+01, 0.15215100E+01, 0.56460100E+00, 0.11667400E+00, -.22039200E+00, -.91341100E+00, -.54216000E+00, 0.30007300E+00, 0.16720900E+00, -.43538800E+00, -.13562500E-01, 0.14535900E+00, 0.28140900E+00, 0.62001000E+00, 0.42341800E+00, -.29988600E+01, -.61185700E+00, 0.12466800E+01, 0.25105800E+00, -.49015900E-01, 0.84402700E-01, -.13403900E-01, 0.47931500E+00, 0.12255500E+00, 0.18834500E+00, -.21760100E+00, 0.88663100E-01, -.66273600E+00, 0.23368600E+00, 0.19549000E+00, -.11247900E+00, 0.23345900E-01, 0.19068800E-03, -.57157800E+00, 0.21125500E+00, 0.24178300E+00, 0.18281800E+00, -.31742400E+00, 0.23894300E+00, 0.51212100E-01, -.58728300E-01, 0.33224300E-01, -.34577600E+00, 0.40495600E-02, 0.16631400E+01, 0.22190600E+00, -.13507300E+01, 0.19491200E+00, 0.13721700E+01, -.13120800E+01, 0.20743300E+00, -.77741500E+00, 0.50216100E-01, -.16974200E+00, 0.73163300E-01, -.24114700E+01, -.10626000E+00, 0.10020900E+01, 0.82713800E+00, 0.28783600E+00, -.58539900E+00, -.80451500E+00, 0.46957900E+00, 0.12340200E-01, -.57557400E-01, 0.66596100E-01, -.23809800E+00, -.16999800E+01, -.11945600E+01, 0.35276000E+00, -.16695600E+01, -.47796600E+00, 0.33570400E+00, -.13208200E+00, -.39029800E-02, -.82693400E+00, -.14159700E-01, 0.58276500E-01, 0.94546500E+00, 0.15454900E+00, -.38828000E+00, -.56150200E+00, -.11157200E+00, -.42332700E+00, 0.15541600E+00, 0.18564000E-01, -.11060800E+00, -.31733000E-01, 0.51488900E-02, -.10024900E-01, 0.20899300E+00, -.24656800E-01, 0.39899000E+00, -.14984900E+00, 0.49045800E-01, 0.14991000E-01, 0.15112900E+00, -.24351000E+00, 0.48816900E+00, 0.34405800E+00, -.11036600E+00, 0.57639800E+02, 0.11589900E+01, 0.46712100E+01, -.57511900E+01, 0.64942800E+02, -.14507800E+01, 0.11259400E+01, 0.24807900E+01, 0.70486800E+01, 0.16711500E+00, 0.27563500E+01, -.12705800E+01, 0.34855400E+00, 0.13277000E+00, -.34721200E+01, 0.90809700E+01, 0.19158500E+01, -.12397600E+01, 0.15366700E+00, -.15158500E+01, 0.14039400E+01, 0.62187000E+00, 0.21446500E+01, -.12075600E+01, -.24123700E+01, 0.34348100E+01, 0.38904300E+01, -.26565200E+01, 0.48029600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.30875900E+01, -.39295000E+00, -.71572200E+00, 0.92988900E+00, 0.81149100E+00, -.34272100E+00, -.14179100E+00, 0.56409000E+00, 0.65876700E-01, -.47455200E+00, -.76430300E+00, -.80580700E-01, -.61997400E+00, 0.90347500E+00, -.19529500E+00, 0.41892300E-01, 0.32181700E+00, -.51317400E+00, -.26760500E+00, 0.41614100E+00, 0.34090500E+00, -.22393800E-01, 0.16697200E+01, -.45482100E+00, 0.71485500E-01, -.38965900E+00, 0.60932300E-01, 0.28674800E+00, 0.30820400E+00, -.14737300E+01, 0.23004700E+00, 0.32141000E+00, 0.87897600E-01, 0.39180100E+00, -.27313400E-01, 0.31501500E+00, -.46950600E-01, 0.38783000E+00, -.15695200E+00, -.25872600E+00, -.72164000E-01, 0.47807000E+00, 0.87234300E+00, -.28619200E+00, -.17921700E-01, 0.91985600E+00, -.37855100E+00, -.10405000E+00, 0.11326600E+00, 0.74737300E+00, -.27973700E+00, -.29629000E+00, -.11924100E+00, -.15912300E-01, -.21964800E+00, 0.53553900E+00, -.12440500E+00, 0.11208900E+01, -.23152500E-02, -.51259500E-01, -.26972500E+00, 0.77663400E-01, 0.18630300E-01, 0.28130300E+00, -.60904800E+00, -.51661800E+00, 0.28465200E+00, 0.15347500E+00, 0.22182700E+00, -.45514100E-02, 0.12884500E+00, -.23297900E+00, 0.15292500E+00, -.29430800E+00, -.10369100E+00, 0.73588700E-01, 0.39636700E+00, 0.17851300E+00, 0.42665500E+00, -.25125300E+00, 0.68619200E-04, -.59968100E+00, 0.43005900E+00, -.19107600E+01, -.14603900E+00, 0.30275100E+00, -.10286500E+01, -.83564700E-01, -.42753800E-01, -.10120000E+00, 0.52159800E+00, 0.43011500E-01, -.54665000E+00, -.24359100E+00, 0.67599000E-01, -.23782700E+00, -.49903500E-01, 0.18920100E+01, 0.39296600E+00, -.41643600E+00, 0.17951600E+00, -.12806000E+00, 0.84635500E-01, -.13757600E+00, -.21208900E+00, -.32478200E+00, -.62982800E+00, 0.26577200E+00, -.47313200E+00, -.22175500E+00, -.59644500E+00, -.18932400E-01, -.30338900E-01, -.25389600E-02, 0.13146900E+00, -.38454300E+00, 0.30964600E+00, -.25581800E+00, 0.33065800E-02, -.20216400E-01, 0.16818800E+00, -.62230100E+00, -.74637000E+00, 0.13711900E+00, 0.17908900E-02, -.31007800E+00, 0.33841200E-01, 0.45107100E+00, -.56911300E-01, 0.22122500E-01, 0.24790200E+00, 0.13614800E+00, -.12989000E+00, -.57621000E-01, 0.33994500E+00, 0.16963100E-02, -.10062200E+00, -.30387100E+00, -.47405600E-01, 0.11853400E-01, 0.22961100E+00, 0.17278300E+00, -.16172200E+00, -.10852200E+00, -.21074400E+00, -.37517900E+00, -.10924800E-01, -.88977900E-01, 0.32632200E+00, -.15799900E+00, 0.22739700E-01, 0.16619700E+00, 0.12507000E-01, 0.14990900E+00, -.91490600E-01, -.23254600E-01, -.77175500E-01, -.69523400E-02, 0.63074100E+00, -.41349500E+00, -.16395400E+00, 0.39688800E-01, 0.20065700E+00, 0.76391700E-01, -.82919400E+00, -.83004700E-03, -.48595000E-01, -.45799100E-01, -.48440800E-01, 0.20068300E+00, 0.20583700E+00, -.13485700E+00, -.33463100E+00, -.11765100E+00, -.23651100E+00, 0.65024400E-01, -.17242500E+00, 0.59852000E-01, 0.24685000E+00, 0.41597700E-02, -.73701000E+00, -.19428700E+00, 0.29055000E+00, 0.36344900E+00, -.58334300E+00, 0.15848100E+00, -.20456000E+00, 0.18541400E+00, 0.38522600E-01, -.14210400E+00, 0.21471900E-02, 0.15198900E+00, 0.47063700E+00, -.89782700E+00, 0.25214100E+00, -.23995500E+00, 0.13580500E+00, -.13273900E+00, -.84668300E-01, -.26446000E+00, -.24794100E+00, -.28539400E-01, 0.33448500E+00, 0.12888700E+00, 0.27657700E+00, 0.29391400E+00, 0.11735100E+00, -.16906000E+00, -.29279100E+00, 0.29505500E+00, 0.43720300E-02, 0.28889400E-01, -.29227000E-01, -.13712700E+00, 0.62844300E+00, -.14209700E+00, 0.68940600E-01, -.48525400E-01, -.27465000E+00, -.19927200E+00, -.68076800E-01, -.40434200E-03, 0.63537600E-01, -.11812400E-02, -.95021900E-01, 0.43651100E-02, -.37888600E-01, 0.85844400E+00, 0.17943100E+00, -.46224700E-01, 0.47065600E-01, 0.21475100E-01, 0.70702900E-02, -.12573800E+00, -.14181000E-01, -.39483200E+00, -.35621000E-01, -.83545100E-01, 0.94308400E-02, -.16912500E+00, -.21808900E+00, -.26642500E-01, 0.29374200E-01, -.20619100E-01, 0.58386400E-01, 0.84207200E-01, -.59968800E-01, 0.17061000E+00, -.26556600E+00, -.18881000E+02, 0.11547500E+02, 0.97393200E+00, 0.11723500E+02, 0.13558800E+01, 0.28046900E+00, -.11792300E+00, 0.38067500E+01, 0.10164400E+01, -.36124100E+00, -.14804600E+01, 0.10205700E+01, 0.19209900E+00, 0.87952700E+00, 0.48971400E+01, -.48123300E+00, -.28003900E+00, 0.79138300E+00, 0.61421800E+00, -.70730000E+00, 0.91206000E+00, -.40899200E+00, -.72021300E-01, 0.55219200E+00, 0.24638900E+01, -.24962000E+01, 0.76431500E+00, 0.36332000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.21482000E+01, -.33282600E+00, -.48719200E+00, 0.84268400E+00, 0.38478700E+00, 0.16863100E+00, -.16103800E+00, 0.46539700E+00, -.13402400E+00, -.19161200E+00, -.38331500E+00, -.43978100E+00, -.11417800E+01, 0.70859500E-01, -.19204400E+00, 0.78802200E-01, 0.44580400E+00, -.62227300E+00, -.14316100E+00, -.73631500E-01, 0.46646100E+00, -.99382100E+00, 0.26596000E+00, -.56216500E-01, -.26795700E-01, 0.23342300E-01, -.36589300E+00, -.32325900E+00, -.18385300E+00, -.17716000E+01, -.15970500E+00, 0.12460400E+00, -.63562100E+00, 0.35953800E+00, -.57950600E-01, 0.59041500E+00, -.24203300E-01, 0.39373500E+00, -.42378000E+00, 0.19191300E-01, -.12909200E+00, 0.21544800E+00, 0.13081800E+01, -.28244200E-01, 0.12634100E+00, -.55959200E-01, -.34102900E+00, 0.78129100E-01, 0.32207000E-01, 0.63025700E+00, -.80714800E-01, -.30670000E-01, -.42153600E-01, -.21854300E+00, -.29997000E-01, -.33065100E+00, 0.22309000E+00, 0.73133000E+00, -.13181000E-02, 0.19410300E+00, 0.70927700E-01, -.51258400E+00, 0.12981200E+00, -.11671600E-01, 0.24554900E+00, -.21459300E+00, -.20967200E+00, -.58246800E+00, 0.47218700E-01, -.34377400E-02, 0.84318200E-01, -.94861200E-01, 0.24207000E+00, -.58380000E-01, 0.65279900E-01, 0.23301200E-02, 0.33851700E+00, 0.17408400E+00, 0.59398000E+00, -.19783400E+00, 0.93131000E-03, -.69904300E+00, 0.71503500E+00, -.50763900E+00, -.14975800E-02, -.38997700E+00, -.20311300E+00, -.10717600E+00, -.24354500E+00, -.24096900E-01, 0.49706600E+00, -.20146800E-01, 0.46275300E-01, 0.25677100E+00, -.32542400E+00, -.40893000E+00, 0.14231000E-01, 0.76844800E+00, 0.18830900E+00, -.79330000E-01, 0.30515400E+00, 0.27401100E-01, 0.40832000E-02, -.11341800E-01, -.15329900E+00, -.11291100E+00, -.40346400E+00, 0.41282500E+00, -.59400700E-02, -.60363900E-01, -.47789700E+00, -.18183200E-01, -.46528700E-01, -.85570600E-02, 0.78336700E-01, 0.68462900E-02, 0.17419300E-01, -.26089900E-01, -.63320100E-01, -.27552300E-01, 0.17901000E+00, -.39304300E+00, -.30122800E+00, -.75816000E+00, 0.37572700E-02, -.25767300E+00, 0.91499300E-02, 0.16189000E-01, 0.11630400E+00, -.22106600E-01, 0.13413600E-01, 0.18815300E-01, -.48343100E-01, 0.57739700E-02, 0.60765000E-01, 0.71377300E-03, -.18192400E+00, -.17612300E+00, 0.77780800E-03, -.20720300E-01, 0.70365700E-01, 0.84679900E-01, -.73568300E-02, -.26503500E-01, 0.14051500E-01, -.45545000E+00, -.58057300E-02, -.25385000E-01, -.12385900E+00, -.10999700E+00, 0.13774200E-01, 0.81333500E-01, 0.25996300E+00, 0.73721400E-01, 0.71082900E-01, -.86831900E-03, -.72417500E+00, 0.27817100E-01, -.17616900E+00, 0.11164600E+00, 0.82352400E-01, -.61360700E-01, 0.12369300E+00, 0.12062000E+00, 0.39728500E-01, -.33205600E-01, -.12403200E-01, -.28697400E-01, 0.15591800E-01, -.74221700E-01, 0.24261400E-01, 0.53302600E+00, -.30104500E+00, 0.11412600E-01, 0.11631400E+00, -.16782200E-01, 0.14034300E+00, -.17699300E-02, 0.15410800E-02, -.10633100E-02, 0.25537400E-01, 0.17126200E+00, 0.11972100E-01, -.11408200E+00, 0.68535500E-01, -.61790300E-01, -.53198400E-01, 0.15981700E-01, -.22329000E-01, 0.27211100E-01, -.12765100E-02, 0.12644000E+00, -.17459900E+00, -.21057500E+00, 0.11853000E+00, 0.29091800E+00, -.28420700E+00, 0.44900800E-01, 0.78855000E-01, -.14381400E+00, -.55341400E-03, 0.11919300E-01, -.16040200E+00, -.12594600E+00, -.54366200E-01, 0.56715800E-02, -.30598900E+00, 0.80504800E-01, 0.48994900E-01, -.72760300E-01, 0.28913400E-02, 0.11359400E-01, -.11428100E-01, 0.46026900E+00, 0.17335000E+00, -.12529200E+00, -.39244100E-01, -.31023300E-01, 0.20189100E+00, -.39015500E+00, 0.55691400E-01, 0.27307700E-02, 0.38628600E+00, 0.13934400E-02, -.40736700E-02, -.15106100E+00, -.95680800E-01, -.13356000E+00, 0.26504600E+00, 0.68548500E-01, 0.69395100E-01, -.36528400E-01, -.24562200E-02, 0.17412600E-02, 0.44850700E-02, 0.28270200E+00, 0.18186600E-01, -.13084500E+00, 0.47216200E-01, -.25409500E+00, 0.20442700E-01, 0.14603000E+00, -.84701200E-02, 0.14416700E-01, 0.85317400E-01, 0.48750200E-01, 0.10453800E+00, 0.13131200E+00, 0.15106400E+00, -.48091100E+00, 0.90431000E+01, -.21990100E+01, -.13076700E+02, 0.14903700E+01, 0.11405100E+01, -.63007900E+00, 0.24125000E+01, 0.15248100E+00, 0.25006600E+01, -.12893500E+01, 0.41849800E+00, 0.12398500E+00, 0.48776900E+00, -.29495300E+01, -.98948100E+00, 0.12822800E+01, -.10027000E+01, 0.95243400E+00, -.10579300E+01, 0.13006800E+01, -.85478000E+00, 0.14220000E+01, 0.72356000E+00, 0.13208400E+01, -.11492600E+01, 0.87134400E+00, -.16590600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.22641100E+02, -.61432700E+01, -.47260300E+01, 0.74771700E+01, 0.14365600E+02, -.27631000E+01, -.24108000E+01, 0.73661600E+01, -.13247900E+01, -.42375100E+01, -.46860500E+01, -.64012100E+00, 0.21447900E+01, 0.54736600E+01, 0.83512100E+00, -.51792000E+00, 0.33861300E+01, 0.53422100E+01, -.83072900E+00, 0.48111700E+00, 0.13794700E+01, -.61341600E+01, -.15189100E+02, 0.49579800E+01, 0.11473800E+00, 0.48767600E+00, -.11427800E+01, 0.92265500E-01, -.26793000E+01, 0.14149000E+01, -.11003800E+00, 0.26543700E+00, -.37877400E+01, -.28138100E+00, -.25336200E+00, 0.13099400E+01, -.60747500E-01, 0.14159200E+01, -.11934100E+00, 0.27177600E+01, 0.37096400E+01, 0.29196600E+00, -.39467300E+01, 0.27906000E+01, -.10563800E+01, -.20703200E+01, -.24687100E+00, -.30692000E+00, -.52166300E+00, 0.17011900E+00, -.26987800E+01, 0.52756400E+00, -.68116900E+00, 0.93241900E+00, -.18301300E+01, -.40244900E+01, -.39707000E-01, -.88634900E+01, 0.73858200E-02, 0.26743200E+01, 0.48738500E+00, 0.18824700E+01, -.13823800E+01, -.24230900E+00, -.93645800E+00, -.94784800E+00, 0.21398100E+01, 0.64618000E+00, 0.72522900E+00, 0.35627400E+00, -.17135100E+01, 0.79057400E+00, 0.49214700E-01, 0.76495800E-02, 0.80068900E+00, -.49520700E+00, -.12248100E+01, 0.83483000E+00, 0.13127900E+01, 0.95029600E-01, 0.45284400E-02, 0.72768900E+00, 0.28074000E+01, -.10971400E+00, 0.48859200E+00, -.64843500E+00, 0.16209800E+01, 0.37881400E+00, 0.23722700E+00, 0.26927900E+00, -.23788100E+01, -.10459200E+00, 0.22341500E+00, -.45553400E-01, 0.25790400E+01, 0.18462800E+01, -.82835300E-01, -.23571200E+01, 0.35223400E+01, 0.69100100E+00, 0.19641000E+00, 0.77017000E-01, -.15936300E+00, -.10027600E+00, 0.14920400E+01, -.16131500E+01, 0.60558700E+00, -.27688300E+00, 0.43374500E+01, -.16780600E+00, 0.50599300E+00, -.20305500E+00, -.50776200E+00, -.16096000E-01, 0.91729400E+00, 0.14595600E+01, -.61809600E+00, 0.23846300E+01, -.84757900E-02, 0.17251400E+01, -.24047200E+01, 0.17024900E+01, -.19440100E+01, 0.51687100E+01, -.60823000E-03, 0.10793100E+01, -.11969000E+01, -.23597400E+01, 0.56295700E+00, -.77219800E+00, -.84342400E+00, 0.44439600E+00, -.12579900E+00, -.28941200E+00, 0.47682000E+00, -.38204800E-02, -.10215900E+01, -.65921700E+00, -.47456300E+00, 0.72294300E-01, 0.42613300E+00, 0.10718400E+01, 0.22096100E+00, -.55357500E+00, -.87603500E+00, 0.74550300E+00, 0.18256800E+00, -.23144400E+01, -.21336800E+01, 0.68780700E+00, -.52776000E+00, 0.17633900E+00, 0.18482200E+01, 0.12863000E+01, -.23191300E+00, -.11323500E+00, -.49517900E+01, 0.30347900E+00, 0.40754800E+01, -.45333400E+00, 0.35103800E+00, -.67394200E+00, 0.20006000E+01, 0.20854100E+00, -.22216400E+01, -.97450900E+00, -.35295300E+00, -.22524100E+00, -.73818800E-03, -.14482300E+01, 0.25713300E+00, 0.10391900E+01, 0.42503000E+01, -.19480500E+00, 0.91099600E+00, 0.47983600E+00, -.75453000E+00, -.68093400E-01, 0.59875300E+00, -.23983500E-02, 0.22710000E+01, -.31692300E+01, -.11100700E+00, -.14596300E+00, 0.34763900E-01, -.15370900E+01, 0.53376200E+00, -.97595300E-01, 0.20384800E+00, 0.27971700E-01, -.96947500E-02, -.63842100E+00, -.13406200E+01, -.27124500E+01, 0.25727000E+00, -.61855300E+00, 0.19488300E+00, -.37863700E-01, 0.12091800E+01, 0.53902200E-01, 0.14883600E+01, 0.18410500E+00, -.45181900E+01, -.48464900E+00, -.16003400E+00, 0.25933600E+01, -.23599000E+01, -.81113600E+00, -.18869100E+01, -.28948900E+00, -.10965100E+00, 0.30399300E-01, -.14599900E-01, 0.32067300E+01, -.19871200E+01, -.70992700E+00, -.38865500E+00, -.59462300E+00, -.23480700E+01, -.30227800E+01, 0.24099600E+00, -.83271600E-01, 0.52525200E+01, 0.10942200E-01, -.35956100E+00, -.18798400E+01, -.86884700E+00, -.40245400E+01, 0.54158500E+00, 0.12617300E+01, 0.75020200E+00, -.64926800E+00, 0.75338600E-01, 0.38169400E+00, 0.12795100E+00, 0.39924300E+01, 0.80662700E+00, -.15818500E+00, 0.18328200E+00, 0.91959000E-01, 0.11250300E+01, 0.19930700E+00, 0.39084100E+00, 0.46354100E-01, -.37322400E+00, 0.18892800E-01, 0.13138900E+01, -.21753400E+01, 0.22239900E+01, -.89737000E+00, -.12062000E+02, -.37058900E+02, -.26715000E+03, 0.15158600E+02, 0.36241900E+02, -.10041700E+02, 0.48780200E+02, -.23530700E+01, 0.69491500E+02, -.33211300E+02, 0.22768400E+01, -.78954900E+00, 0.62185700E+01, -.49289100E+02, -.11152900E+02, -.41661000E+01, 0.37564500E+01, 0.12545700E+02, -.11894300E+02, -.15271300E+02, -.13129200E+02, -.46682900E+01, 0.10305300E+02, -.15599400E+02, -.72591000E+01, 0.10632000E+02, -.18935400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.26714300E+02, 0.70591300E+01, 0.27034600E+00, -.38135900E+01, -.15982800E+02, 0.17479800E+01, 0.30049100E+01, -.83535500E+01, 0.39121600E+00, 0.38446900E+01, 0.13496300E+01, -.49035600E+00, -.47900300E-01, -.46173100E+01, -.77053700E+00, 0.10121900E+01, -.32511800E+01, -.63225000E+00, 0.12946000E+01, -.14707100E+01, -.10004700E+01, 0.92407000E+01, 0.11494900E+02, -.46885800E+01, 0.29610100E+00, -.20956100E+01, 0.92203800E+00, 0.50393900E+00, 0.29254300E+01, 0.87936700E+00, 0.11004300E+01, -.96203200E+00, 0.48193700E+01, -.29442100E+01, 0.50391900E+00, -.65344300E+00, -.70099600E-01, -.77678300E+00, 0.15432800E+01, -.10183000E+01, -.21960000E+01, -.40144800E+01, 0.50110300E+01, -.21793400E+01, 0.15307800E+01, -.23546200E+01, 0.23722200E+01, 0.10582300E+01, -.86684600E+00, -.48962800E+01, 0.16699700E+01, 0.17095900E+01, 0.10555800E+01, -.10838400E+01, 0.21143600E+01, 0.20691400E+01, 0.28665700E+00, 0.38048000E+01, 0.51473000E-02, -.15722500E+01, -.12617300E+01, -.40851800E+01, 0.78415000E+00, -.16420200E+01, -.31106000E+01, 0.10609500E+01, -.18318900E+01, 0.20752900E+01, -.11163400E+01, 0.81969700E-01, -.11409600E+00, -.67799600E+00, 0.11731000E+01, 0.31274100E+00, 0.19320000E+01, 0.21490100E+00, -.13703100E+01, -.79676900E+00, -.97348800E+00, 0.21856500E+01, -.16698100E-01, 0.49714400E+01, -.40059600E+01, -.42429400E+01, 0.50815200E+00, 0.23483100E+01, -.10718700E+01, 0.56816700E+00, -.10580600E+01, 0.32336900E+00, 0.13679600E+00, 0.38050900E+00, -.18359900E+01, -.73921800E+01, 0.11830500E+01, 0.28163700E+00, -.25823400E+01, -.54735300E+01, -.56066100E+00, 0.19717000E+01, -.30271200E+01, -.47695800E+00, -.61459300E-01, 0.34663900E+00, 0.64421800E+00, 0.23936800E+01, 0.64954600E+00, -.66958100E+00, -.10188600E+01, -.46462900E+00, 0.26968000E+01, 0.31483200E+00, -.73424900E-01, 0.14913600E+00, -.87949300E+00, -.11236200E+01, 0.10739800E+00, -.10268200E+01, -.54295600E+00, 0.26949900E+01, 0.35485300E+01, -.51502100E+01, -.46129300E+01, 0.44102100E+01, -.40135700E-01, 0.20906500E+00, 0.16635000E+00, 0.24908200E+01, -.19139000E+01, 0.67512900E+00, -.18078800E+00, 0.61475800E+00, -.66122800E-01, -.25692200E-01, -.20124900E+01, -.23282300E-02, 0.16713300E+01, -.11499000E+00, 0.40584900E+00, -.15962500E+00, -.12752300E+01, -.10364900E+01, 0.73193200E-01, -.39651800E+00, 0.20514700E+01, -.13425000E+01, 0.32569100E-01, 0.24632800E+00, -.56168000E+00, 0.13988300E+01, 0.24604100E+00, 0.77800400E+00, -.23603300E+01, -.49652700E+00, 0.30693600E+00, 0.39109900E+00, -.86439200E+01, -.18077600E+00, 0.33516000E+01, 0.16996500E-01, 0.21792800E+01, -.11057800E+01, -.33729300E+01, -.19275600E+00, 0.25618300E+01, 0.12937600E+00, 0.21271300E+00, -.21052600E+00, 0.61738400E-01, 0.88114800E+00, -.20740700E+00, 0.29729900E+01, 0.18183400E+01, -.31524600E+00, -.18702400E+01, 0.44922100E+00, 0.93824200E+00, -.84140500E+00, 0.42371900E+00, 0.44504500E-02, -.40723900E+01, 0.23489000E+01, 0.14777300E+01, -.19990300E+01, 0.21677800E+00, -.26019400E+01, 0.54314500E+00, 0.63550200E+00, -.25522800E+00, -.67373200E-01, 0.12994200E-02, 0.36378100E+01, -.64350800E+00, -.48395900E+01, 0.65156800E+00, 0.59657200E+01, -.20291500E+01, 0.52518200E+00, -.85517500E+00, -.23937200E+01, -.78711200E+00, 0.25911800E+00, -.22005900E+01, 0.12700400E+01, -.37164900E+00, 0.57566300E+01, 0.23448000E+01, -.11396200E-02, -.25279300E+01, 0.11188100E+01, 0.24887100E+00, 0.93522500E-01, -.65850800E-01, -.13313700E+01, -.34832000E+01, -.16849400E+01, 0.57553100E+00, -.17090200E+01, -.16757000E+01, -.23850500E+01, -.50896800E-01, 0.18221500E-01, 0.76174400E+00, -.19406000E-02, 0.11037900E+00, 0.29860000E+01, -.13435600E+00, -.13522300E+01, -.22508700E+01, 0.11246900E+01, -.71295300E+00, 0.61967600E+00, 0.20671800E+00, 0.65744100E+00, -.40561600E-01, 0.57012100E+01, 0.15269200E+01, -.12739300E+00, 0.62807300E+00, -.23805600E+00, 0.12366700E+01, 0.34337300E+00, -.55525200E+00, -.80371500E-01, 0.33816700E+01, 0.70993000E+00, 0.17921600E+01, 0.14791700E+00, 0.20599200E+01, -.45391300E+01, -.93401400E+01, -.36437600E-01, -.26253800E+03, 0.19641900E+02, 0.44606300E+02, -.11148800E+02, 0.68350700E+02, 0.15025600E+00, 0.80699500E+02, -.41690700E+02, 0.12131200E+01, -.22661600E+01, 0.44684700E+01, -.12116000E+03, -.99483000E+01, 0.33485700E+02, -.28032900E+02, 0.12026900E+02, -.12633900E+02, 0.23154500E+02, -.12407100E+02, 0.34177300E+02, 0.70411600E+01, 0.21735000E+02, -.12349300E+02, 0.11423200E+02, -.21127700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.34195200E+02, -.82093100E+01, -.54461500E+01, 0.12265500E+02, 0.20708700E+02, -.15239400E+01, -.37357800E+01, 0.91297600E+01, 0.33567800E+00, -.36664500E+01, 0.57314100E+00, 0.12594300E+00, -.34829100E+01, 0.77282100E+01, 0.32843700E+00, -.17681200E+01, 0.58058400E+01, -.23473300E+01, -.30422100E+01, 0.66849500E+01, -.22432400E+01, -.14104500E+02, -.61121700E+01, 0.24675100E+01, 0.25940800E+00, 0.33660000E+01, -.57699000E+00, 0.52544900E+00, -.44781900E+00, -.26553900E+01, -.10136400E+00, 0.21239900E+01, -.56517700E+01, 0.22405400E+01, -.71464800E+00, 0.50455800E+01, -.19188700E+00, 0.32539400E+01, -.86467000E+00, 0.12721300E+01, 0.20175500E+01, 0.49736500E+00, -.51954300E+01, 0.11578900E+01, -.85916100E+00, 0.28393000E+01, -.17172100E+00, -.47465900E+00, 0.10927400E+01, 0.19776900E+01, -.65059600E+01, -.28710100E+01, -.11161000E+01, 0.14906800E+01, -.13893600E+01, -.56357900E+00, -.51673700E+00, -.44889400E+01, -.80434000E-03, -.69202700E+00, -.14809600E+01, 0.19731700E+00, -.67119900E+00, 0.14186400E+00, -.24124100E+01, -.21230600E+01, 0.25663800E+01, 0.15187600E+01, -.65436300E+00, 0.34953200E-02, 0.23577600E+00, -.55786600E+00, -.32478800E+01, -.27549000E+00, -.33428300E+01, 0.35826800E+00, -.25917300E+00, 0.32024500E+01, -.29966100E+01, -.85809600E+00, -.10946600E-02, -.66935700E+00, -.15096600E+01, 0.64155900E+01, 0.62568300E+00, 0.52927300E+00, -.46267500E+00, 0.55142200E+00, 0.19827700E+00, -.52725200E-02, -.20229100E+01, -.33747700E+00, -.39215500E+01, -.77654900E+00, -.70462200E+00, 0.47037100E+01, -.53654900E+00, 0.78875100E+01, 0.13306400E+01, -.27697900E+01, -.19504300E-01, 0.89909700E-01, 0.50230400E+00, -.81607900E+00, -.92246900E+00, -.23601900E+01, -.42683400E+01, -.22295700E+01, -.27098000E+01, 0.18854300E+01, -.34157600E+01, 0.26181900E+00, -.98517000E+00, 0.17531800E+00, -.39406400E+00, 0.34301700E+01, -.57915400E+00, 0.62851200E+00, 0.85555200E+00, -.37241200E+01, -.42442000E+01, 0.27327700E+01, 0.35364300E+01, -.53143800E+01, -.58125500E-01, 0.35850100E+00, 0.73321200E+00, 0.20136500E+01, -.13690300E+01, 0.22441800E-01, -.23807600E+01, -.92712500E+00, 0.13010700E+01, -.17551900E+00, -.18219500E+01, 0.11204600E-01, -.86503400E+00, 0.25597200E+00, 0.79147300E-02, -.93000800E-01, 0.12013700E+01, -.33437400E+00, -.15481900E+01, -.48522500E+00, -.19935100E+01, 0.74103100E+00, -.39888500E-01, -.47462000E+00, 0.98323500E+00, -.24850900E+01, -.16198100E+00, 0.46835800E+00, 0.41013000E+01, 0.25857200E-01, -.11424400E+01, 0.15635600E+00, -.68570500E+01, -.21573000E+00, 0.70796200E+01, -.56488300E+00, 0.36648400E-01, 0.15856500E+01, -.16277500E+01, -.93122300E+00, -.28253000E+01, 0.65377000E+00, -.51189300E-01, -.11657500E+00, -.36978300E+00, -.10851200E+00, 0.80253700E+00, -.20189400E+01, -.39514500E+01, 0.71972100E+00, -.18989800E+01, -.17693100E+00, 0.36110600E+00, 0.37918400E+00, -.28715000E+00, -.17989300E+00, 0.36032400E+01, -.31547000E+01, -.19539200E+01, 0.23065600E+01, -.34064500E+01, -.64914100E+00, -.96810900E+00, -.40008400E+00, 0.62934200E+00, -.61018700E+00, 0.20949200E-01, -.24185500E+01, 0.21958100E+01, -.27368900E+01, 0.10672400E+01, -.40202800E+01, -.12523800E+01, -.19653400E-01, 0.29267800E+00, 0.70770000E+00, 0.81205800E+00, -.14659400E+00, 0.13551000E+01, -.47308800E+00, -.29157700E+00, 0.89424000E+00, -.49918400E+00, -.10854900E+01, -.19935300E+01, 0.11204500E+01, 0.55376400E-01, 0.46085300E+00, -.19751500E+00, 0.88696900E+01, -.24842700E+00, -.16694800E+00, -.16303500E+01, -.12151100E+01, 0.16097100E+01, -.14597300E+01, -.23527800E+00, 0.30103800E-01, 0.60526500E+01, -.12214200E-01, -.96410400E+00, -.43941100E+01, -.79890300E+00, 0.81363500E+00, 0.53998600E+01, 0.94263000E-01, 0.15817200E+01, -.59846300E+00, 0.15377200E+00, -.13382900E+00, 0.45020200E-01, -.12649500E+01, 0.53242000E-01, -.13339100E+01, -.17028100E+00, -.60469500E+01, 0.16398900E+01, -.28710100E+00, -.50167900E+00, 0.11068400E+00, 0.15041000E+01, 0.21898500E+00, 0.28260100E+00, 0.24727400E+01, -.14028300E+01, 0.21928800E+01, 0.98011000E+01, -.10227800E+01, 0.77954900E+00, -.10275200E+02, -.14019700E+02, 0.49334600E+01, -.29652300E+02, -.49353200E+01, -.12237100E+02, 0.15992400E+02, -.32687200E+01, -.28173800E+01, -.75114900E+01, 0.44319400E+02, 0.28939900E+01, -.38309200E+02, 0.30330600E+02, -.19221500E+01, 0.48395700E+01, -.38008300E+02, 0.38189400E+01, -.40453400E+02, -.31925700E+01, -.41597800E+02, 0.21302200E+02, -.71424500E+01, 0.21538300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.23108800E+02, 0.49738700E+01, 0.62308700E+01, -.76773800E+01, -.14260600E+02, 0.12592200E+01, 0.24723200E+01, -.69018000E+01, 0.50676600E+00, 0.35891700E+01, 0.10301900E+02, 0.43809600E+01, -.18532300E+01, -.22315200E+01, -.16190000E+01, 0.11940000E-01, -.21081300E+01, -.51064800E+01, 0.10624100E+01, -.94262300E+00, -.18734700E+01, 0.23329600E+01, 0.19468100E+02, -.84670900E+01, -.91742000E-01, 0.19188900E+01, 0.78445200E+00, -.34217400E+00, 0.47916000E+01, 0.19233800E+01, -.29983000E-01, -.28032600E+00, 0.19407900E+01, -.11586400E+01, 0.49728400E+00, 0.21545600E+00, 0.43718000E-01, -.84595300E+00, 0.63996400E+00, -.16017900E+01, -.35928000E+01, -.28714100E+01, 0.97427800E+01, -.35328200E+01, 0.46322500E+00, 0.27677200E+01, 0.62982700E+00, 0.12163400E+01, 0.10152200E+00, -.21664500E+01, 0.15963700E+01, 0.93933800E+00, 0.62393900E+00, -.51609400E+00, 0.18006000E+01, 0.25761400E+01, 0.69851200E-02, 0.88074000E+01, -.65427100E-02, -.21870600E+00, -.31053800E-01, -.89001300E+00, 0.86125700E+00, -.12538600E+01, 0.34042900E+01, 0.12591600E+01, -.23062100E+01, 0.84404700E+00, -.13357400E+01, -.24167400E-01, 0.13664800E+01, -.11200200E+01, -.36175500E+00, 0.49311200E-01, 0.96045500E-01, 0.12187500E+00, -.53314300E+00, -.11968900E+01, -.21835000E+01, 0.12863500E+01, -.26650700E-02, 0.35929200E+01, -.37109300E+01, -.13592800E+00, -.24098600E+00, 0.13809600E+01, 0.75166600E+00, -.46033900E+00, 0.23954900E+00, 0.47187000E+00, 0.64941400E+00, 0.19148400E+00, -.63454700E+00, 0.16081100E+01, -.33599300E+01, -.11941400E+01, 0.14236200E+00, 0.43472600E+01, -.13712100E+01, -.75669600E+00, -.13604500E+01, -.35489700E+00, 0.45356100E-01, -.31620300E+00, -.16904200E+01, 0.12197900E+00, -.11044800E+01, -.19371200E+01, -.32550900E+01, 0.18673800E+01, -.57370700E+00, 0.21510600E+00, -.13397900E+00, 0.22838400E-01, -.13578600E+01, 0.90346600E+00, -.17506000E+01, -.73035800E+00, 0.34659700E+00, -.26055500E+01, 0.67597000E+00, 0.20878800E+00, 0.26742500E+00, -.95403100E+00, 0.10049500E-01, 0.21707300E-01, -.28233900E+00, -.17556600E+01, -.85955700E+00, 0.20775600E+00, -.92151100E+00, -.94404400E+00, 0.36106800E+00, 0.34125300E+00, -.10143700E+01, -.16427000E-01, -.37501600E+00, 0.11617500E+01, 0.25102000E+00, -.41398200E+00, -.74834100E+00, -.90167100E+00, 0.55262400E+00, 0.41434800E+00, 0.24119400E+01, 0.90121900E+00, 0.11305200E+00, 0.97018400E+00, 0.33395900E+00, 0.15173900E+01, 0.41676700E+00, -.38453400E+00, -.31543600E+01, -.11980800E+01, -.69462100E+00, 0.92268300E-01, 0.12030100E+01, 0.49048800E-01, -.38150800E+01, 0.84545500E+00, -.67257800E+00, -.75853200E-01, -.33262500E+00, 0.15984000E+00, 0.49024100E+01, 0.22953100E+00, 0.15776100E+00, 0.51192800E+00, 0.12986000E+00, 0.11718900E+01, -.80497700E+00, -.10452600E+01, 0.16140800E+01, 0.45743400E+00, 0.10110700E+01, 0.25438000E+00, -.37331100E+00, -.89433100E-01, -.16326400E-01, -.26109200E-02, -.23334200E+01, 0.26241800E+01, 0.12218600E+01, -.22674100E+01, 0.39771900E+01, 0.35353700E+01, 0.97885600E+00, -.32837600E+00, -.80152300E+00, 0.46700700E+00, -.36315800E-03, -.88252500E-01, -.11977700E+01, 0.22063400E+01, -.11341100E+01, -.27245600E-01, -.32138100E+00, 0.23661700E-01, 0.35080100E+00, 0.50175100E-01, -.40473000E+00, -.51275500E-01, -.24851400E+01, -.11148000E+01, 0.13574600E+01, -.18441900E+01, 0.46586600E+00, 0.37022900E+00, 0.15736400E+01, -.19918400E+00, -.21797400E+00, -.88108600E-01, 0.76168500E-01, -.14345100E+01, 0.14766300E+01, 0.85695400E+00, -.76740400E-01, 0.13150100E+01, -.46196100E+01, 0.83720100E+00, -.17529700E+00, -.17154400E+00, -.25675700E+01, 0.16960100E-01, 0.40987200E+00, 0.16502400E+01, -.11962900E-01, -.66887100E+00, 0.41858100E+00, -.39347000E+00, -.38817900E+00, -.46596600E-01, 0.99581400E-01, -.82780000E+00, 0.74028500E-02, -.44563200E+01, -.14608400E+01, 0.16610000E+01, -.59027300E+00, 0.31792400E+01, -.17399600E+01, 0.61621200E+00, 0.95669700E+00, -.47340200E-01, -.38418000E+01, -.47070800E+00, -.15977200E+01, -.14042600E+01, 0.30697600E+00, 0.73631900E+00, -.52399300E+01, 0.66133800E+00, -.44085200E+00, -.19615600E-01, -.21863400E+02, -.12457900E+01, -.32360200E+02, 0.22539800E+01, -.39401000E+02, 0.22702500E+02, 0.98885900E+00, 0.45660100E+01, 0.33917800E+01, -.50123900E+02, 0.62361200E+00, 0.21755900E+02, -.16727100E+02, 0.62657200E-01, -.64028600E+00, 0.21132000E+02, -.64135700E+00, 0.22911100E+02, 0.32914400E+01, 0.20080300E+02, -.86555400E+01, 0.63454300E+01, 0.41219800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.98372500E+01, -.32112200E+01, -.36740600E+00, -.32988500E+00, 0.63219600E+01, -.30593200E+01, -.95551600E+00, 0.72170400E+01, -.16882000E+01, -.30285800E+01, 0.31780600E+01, 0.35045000E+01, 0.65580100E+01, 0.53495000E+01, -.50954600E+00, -.78615900E+00, 0.27737100E+01, 0.33260900E+01, -.16593100E+00, -.72995500E+00, 0.12410600E+01, -.30023600E+01, -.45545600E+01, 0.16738300E+01, -.15695100E+00, 0.12866100E+01, -.76126500E-01, -.90643400E-01, -.51694800E+00, -.18300900E+01, 0.43406000E+00, 0.70303500E+00, -.33465600E+01, -.14712400E+00, -.27865200E+00, 0.17906400E+01, -.16316900E+00, 0.66314500E+00, -.86230700E+00, 0.98341100E+00, 0.21458400E+01, 0.23978200E+01, 0.19631400E+01, 0.12284200E+01, -.14719600E+01, -.11482600E+01, -.13430500E+01, -.95063200E+00, 0.27519500E+00, 0.23706100E+01, -.18045600E+01, -.10435300E+01, -.50379600E+00, 0.50458200E+00, -.63338300E+00, 0.89614800E-01, 0.37568200E-01, -.20369700E+01, 0.44450600E-02, 0.16689900E+00, -.23216400E+00, 0.21031500E+01, -.63967500E+00, -.24643600E+00, -.25133500E+00, -.11447700E+01, 0.15442300E+01, -.46610100E+00, 0.57085800E+00, 0.22100900E-01, -.26823000E+00, -.36735100E+00, -.13313500E+01, 0.38482800E-01, -.11336100E+01, -.13329100E+00, 0.14835800E+00, 0.29157600E+00, -.11122000E+01, -.91050500E+00, -.36438300E-02, -.10688700E+01, -.16585100E-01, 0.24060500E+01, -.36421400E+00, 0.10077500E+01, 0.40627600E+00, -.18873800E+00, 0.11055400E+01, -.37279100E-01, -.73892600E+00, -.17004800E+00, -.11125500E+01, 0.23791700E+01, 0.74332000E-01, 0.41987000E+00, 0.73774300E+00, 0.72337300E+01, -.17639700E+00, -.13701300E+01, -.10527500E+01, -.14918800E+00, -.22356600E+00, -.34438200E+00, -.18885700E+01, -.89837700E+00, -.10963100E+01, -.65936400E+00, -.13575600E+01, 0.85164000E-02, -.16532400E+01, -.16508300E-02, -.56971100E-01, 0.12272000E-02, -.32322400E-01, 0.86193900E+00, 0.46735300E-01, 0.24099900E+00, 0.41319300E+00, -.46497800E+01, -.28701400E+01, 0.34466900E+01, 0.43058300E+01, -.54059200E+01, -.35175600E-02, -.62708200E+00, -.32161100E+00, -.32137200E+01, 0.10399800E+01, 0.17451600E+00, 0.33839000E+00, -.19122600E+01, 0.13470300E+01, 0.15357800E+00, 0.19789200E+01, 0.12657500E-01, -.66222100E+00, -.44428100E+00, -.40967900E+00, -.22768500E+00, 0.33069800E+00, 0.64524500E+00, -.41149100E-01, 0.60864300E+00, -.13421500E+00, 0.17537600E+01, 0.17948900E+00, 0.89101200E+00, 0.13519200E+01, -.16907400E+00, 0.41240000E-01, 0.39188300E-01, 0.77478800E+00, -.37427500E-01, 0.22050700E+00, -.46318900E-01, 0.58944700E+00, 0.13746500E+00, -.13192900E+01, 0.28731700E+00, -.59586600E+00, -.81323000E-01, 0.17070900E+01, 0.26766800E+00, -.86614400E+00, -.52383000E-01, 0.17278800E-01, 0.54489900E-02, -.69337500E-01, -.41804700E+00, 0.29828800E+00, -.74128000E+00, -.82641600E+00, 0.49305300E+00, 0.14775200E+01, 0.19032200E+00, -.10831300E+01, 0.23900800E+00, 0.46315000E+00, 0.51947200E-02, 0.24217000E+00, -.95207400E+00, 0.64316500E-01, 0.43503500E+00, 0.48310600E+00, 0.17946500E+01, -.50173900E+00, -.11586600E+00, -.27534800E-01, -.58805200E+00, 0.84539800E-02, -.79537500E+00, 0.40638200E+00, 0.11331100E+01, -.94307500E-01, -.58475100E+00, 0.11409500E+01, -.17750500E-01, 0.34947600E+00, 0.59740300E+00, -.15458800E+00, -.15592400E+00, 0.16644000E+01, 0.29314200E-01, 0.14366100E+00, -.10797800E+01, 0.62802500E+00, 0.16292300E+00, 0.10289700E+01, -.46338200E+00, -.78276200E-01, -.35735500E+00, 0.38673200E+00, -.27937600E+00, -.10868500E+01, 0.13011100E-01, -.99549000E-01, 0.22808100E+00, 0.10664200E+00, 0.56240500E+00, -.18516100E+00, 0.79607900E-01, 0.90789600E+00, -.13725600E-01, -.39098100E-01, -.77331100E+00, 0.58360600E+00, -.41777100E+00, 0.59039700E+00, 0.14383900E+00, -.22030800E+00, -.19880500E+00, -.17042800E+00, -.41697200E+00, 0.34216300E-01, 0.30350600E+01, 0.69371000E+00, -.72397700E+00, 0.15850100E+00, 0.12218900E+00, -.83491400E-01, 0.77216500E+00, 0.31313000E+00, -.31577000E-01, 0.16721300E+01, 0.71841400E+00, 0.48129800E+00, 0.14158500E-01, 0.40408600E-01, 0.35489200E+00, 0.25472800E+01, -.24068300E+00, 0.30401700E+00, 0.74715200E-01, -.70263800E-01, -.13892300E+01, -.57799400E+00, 0.40381100E+01, -.26466600E+01, -.14057700E+01, 0.52275100E+01, 0.46023800E+01, 0.81942400E+01, 0.81048400E+02, -.29021300E+01, -.33721900E+02, 0.29870000E+02, 0.13386800E+01, -.55119100E+00, -.32001700E+02, -.13982700E+01, -.34575300E+02, 0.48329100E+01, -.28428800E+02, -.59683700E+01, 0.19140500E+01, -.34862400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.23034400E+02, 0.50768100E+01, 0.35805800E+01, -.61335500E+01, -.13504100E+02, -.30494000E+00, 0.25618600E+01, -.54175800E+01, 0.25987200E+00, 0.27947600E+01, 0.96244700E+00, -.36529100E+01, -.13096800E+01, -.51116300E+01, -.28536100E+01, 0.76597700E+00, -.46534600E+01, -.18796600E+01, 0.96624600E+00, -.15083000E+00, -.81742300E+00, 0.30333900E+01, 0.14740900E+02, -.50225000E+01, 0.40795100E+00, 0.19101500E+00, 0.43651400E+00, 0.15575300E+01, 0.26593100E+01, 0.36108300E+01, -.48410200E+00, -.54422300E+00, 0.40281300E+01, 0.31783300E+01, 0.97264000E+00, -.16453600E+01, -.93314600E-02, -.18094200E+01, -.19941500E+01, -.32312500E+01, -.56597300E+01, 0.83661900E+00, 0.65450600E+01, -.26638300E+01, 0.23723800E+01, 0.40926800E+01, -.67179200E+00, 0.99442700E+00, 0.17966200E+01, 0.33957500E+01, -.23476500E+01, -.20016300E+01, -.10598700E+00, -.12008400E+01, 0.15306100E+01, 0.16250600E+01, 0.42318800E+00, 0.39632300E+01, -.21928400E-01, -.13997300E+01, 0.62498100E+00, -.14108400E+01, 0.85375900E+00, -.28770100E+00, 0.27175200E+01, 0.16635400E+01, -.36993000E+01, -.99224300E-01, -.23523600E+01, -.67380400E-01, -.10901700E+01, -.19195300E+01, -.24616900E+01, 0.27742500E+00, -.21015800E+01, 0.10617400E+00, 0.22130800E+01, 0.60570800E+00, 0.67168500E+00, -.11852400E+01, -.42129600E-01, -.42189100E+01, 0.28708300E+01, -.20421200E+01, -.12012300E+01, 0.31152700E+00, -.15746500E+01, -.12969200E+01, -.30228800E+00, -.45681100E-01, -.14020500E+01, 0.20483600E+00, 0.35641700E+00, 0.62602500E+01, -.11911100E+01, -.18425700E+01, 0.20502200E+00, 0.41084500E+01, -.37281800E+00, -.25582400E+01, 0.37343600E+01, 0.40605700E-01, 0.75607100E+00, -.14947500E+00, -.35779200E+00, -.65036600E+00, -.18532100E+01, 0.17394700E+01, -.83047900E+00, -.81659300E+00, 0.12286700E+01, -.31360100E+00, 0.32071300E+00, 0.32847500E-01, 0.78003000E+00, -.41000900E+01, -.61427200E-02, 0.25020000E+00, 0.11049000E+00, -.48262200E+01, 0.96110100E-01, 0.29321900E+01, 0.33961500E+00, 0.48377800E+01, 0.22503300E-01, -.17657400E+01, -.32473800E+00, -.21335600E+01, 0.66066800E+00, -.38389200E-01, 0.78166900E+00, -.12876700E+00, -.69829600E+00, 0.14161400E+00, 0.49902200E+00, 0.11957300E-02, -.20226500E+01, 0.67503700E+00, -.37005900E+00, 0.38534300E+00, 0.15133100E+00, 0.35550300E+00, 0.72929300E-01, 0.29579900E-01, -.14376300E+01, 0.55763200E+00, -.63874900E-01, 0.35718000E+00, -.14895400E+01, 0.71837800E+00, -.35337900E+00, 0.34751600E+00, 0.84431800E+00, 0.85411800E-01, -.66471900E-02, -.20947300E+00, -.70071100E+00, -.99467700E-02, -.26134000E+00, -.84213500E+00, -.24529800E+00, -.57016300E-02, 0.49679900E+01, -.20519200E+00, 0.61112400E+00, -.55059200E+00, 0.36577300E-01, 0.25893400E+00, 0.13222900E+00, -.44456600E+00, -.18530900E+01, -.30929600E+00, -.10698100E+01, 0.27415700E+00, 0.21581900E+01, 0.14852600E+00, 0.42479700E-01, 0.17786800E+00, 0.50416800E+00, -.75280400E-02, -.47037500E+00, -.73581900E+00, 0.41456700E+00, -.58846700E+00, 0.71682700E-01, -.35451800E+00, 0.56739400E+00, 0.29840600E-01, 0.23104600E+00, -.50407100E-03, -.15597300E-01, -.17487900E+01, -.61193200E+00, 0.39471600E+01, -.21057600E+01, -.20772900E+01, 0.10872300E+01, -.71081000E-01, 0.42679700E+00, 0.12540000E+01, 0.13449900E+01, 0.77967300E-01, -.18835100E+00, 0.23028200E+00, -.15065000E+01, -.24960600E+01, -.84018500E-01, -.67295100E+00, 0.11678300E+01, -.78559000E+00, -.50431000E-01, -.24063800E+00, 0.21272200E+00, 0.41006700E+00, -.15261000E+01, 0.30577700E+00, -.20099800E+00, 0.70368300E+00, 0.14589100E+01, -.48149700E+00, 0.17275000E+00, -.14986200E-01, -.79285900E+00, -.99190300E-03, -.69816800E+00, 0.64153300E-01, 0.13842100E+00, -.19025300E+01, -.75628800E-01, 0.47558400E+00, 0.40687300E+00, -.34393400E+00, 0.13878200E+00, -.13139200E+01, -.10821700E+00, -.49744700E+01, -.93637800E+00, 0.79632100E-01, 0.22546400E+00, 0.34147000E+01, -.23456100E+01, 0.72237200E+00, 0.51170400E+00, 0.40223700E-01, -.14618300E+01, -.44751200E+00, 0.53893600E+00, -.12750500E+01, 0.13544700E+01, -.14886000E+01, -.65141100E+01, 0.60694900E+00, -.33753500E+00, -.62087300E-01, 0.19683400E+00, 0.15086400E+01, -.19246200E+02, -.58777300E+01, 0.96502800E+01, 0.78044400E+01, -.92630700E+01, -.74882400E+01, -.11907500E+02, -.15901000E+03, 0.49360900E+01, 0.68670800E+02, -.59817500E+02, -.36913300E+01, 0.98628000E+00, 0.67664200E+02, 0.19870100E+01, 0.70729900E+02, -.64138800E+01, 0.59897400E+02, 0.29585700E+01, -.53185000E+00, 0.70910800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.11158200E+02, -.33019000E+01, 0.39476500E+01, -.47544700E+00, 0.65091900E+01, -.45310800E+00, -.12946500E+01, 0.31985000E+01, 0.33043100E+00, -.12015700E+01, 0.18107500E+01, 0.10028500E+01, -.33858800E+00, 0.23132200E+01, -.54638700E-01, -.58376800E+00, 0.15672500E+01, -.38679600E+00, -.45887700E+00, -.34757800E-01, 0.39646200E+00, -.36573200E+01, -.37018200E+01, 0.14744300E+01, -.58061300E-01, 0.12052400E+01, -.39037500E+00, -.42580000E+00, -.94639400E+00, -.14427900E+01, -.26441200E+00, 0.42066600E+00, -.21672100E+01, 0.48284500E+00, -.30083300E+00, 0.11797100E+01, -.82215600E-01, 0.34813100E+00, -.41831000E+00, 0.57211800E+00, 0.21579600E+01, 0.20001800E+01, -.60981600E+00, 0.55121800E+00, -.91145900E+00, 0.10666100E+01, 0.46125400E+00, -.42871000E+00, 0.57678500E+00, 0.15141400E+01, -.10023300E+01, -.13150300E+01, -.36605000E+00, 0.35233400E+00, 0.18593600E+00, 0.43414400E+00, -.72128300E-01, -.77402100E+00, 0.22385300E-02, 0.39362100E+00, 0.10731100E+00, 0.97342700E+00, -.24806300E+00, 0.18809900E+00, -.12047200E+01, -.92596300E+00, 0.94765700E+00, -.62041900E+00, 0.31304500E+00, 0.11736600E-01, 0.40926700E+00, 0.17394100E+00, -.95003300E+00, 0.13080100E+00, -.51925100E+00, -.91034400E-03, -.12890700E+00, -.36807100E-01, -.27393600E+00, -.32411000E+00, -.14832400E-02, 0.27917700E+00, -.21956900E+00, 0.13834900E+01, -.92438300E-01, -.97005500E-01, 0.10450800E+01, 0.14815400E+00, 0.58949700E+00, 0.48129100E-01, -.12864000E+00, -.31898800E-01, -.27729800E+00, 0.17793100E+01, 0.12170900E+00, 0.83740100E+00, 0.30555900E-01, 0.43005800E+01, -.57149500E-01, -.10846300E+01, -.92579900E-01, 0.49286800E-02, -.19308700E+00, 0.81903100E-01, -.81558800E+00, -.40863500E+00, -.36875600E+00, -.38880400E+00, -.69531900E+00, 0.80404900E-01, -.70373100E+00, -.69576700E-01, -.99336100E-01, 0.19093100E-02, 0.22815400E+00, 0.78903400E+00, -.18704600E+00, 0.97192100E-01, 0.34673100E+00, -.19159400E+01, -.20760100E+01, 0.21796900E+01, 0.31782000E+01, -.39170000E+01, 0.81691900E-03, 0.18576100E+00, -.25041600E+00, -.20485600E+01, 0.45352100E+00, 0.23538200E+00, 0.14440000E+00, -.41765400E+00, 0.71220200E+00, -.24932300E-01, 0.14072100E+01, 0.18087500E-02, 0.81312900E-01, -.11284300E+01, -.21890200E+00, -.29459700E-02, 0.55361900E+00, 0.27672200E+00, -.32998900E+00, 0.68014400E-01, -.13504500E+00, 0.62742100E+00, 0.57742000E-01, 0.11919200E+01, 0.87366600E+00, -.96654100E+00, 0.17649000E+00, 0.18030700E+00, 0.17663200E+00, -.74462800E-01, -.17458100E+00, 0.42110300E-01, -.89494800E-02, 0.61798100E-01, -.99918400E+00, 0.40832900E+00, -.37177300E+00, 0.12172400E+00, 0.48654700E+00, -.31676900E-01, -.17747300E+00, -.79942300E-02, 0.60307300E-01, 0.23769800E+00, -.46191400E-01, -.67355300E-01, 0.29998500E+00, -.92219100E+00, -.11713000E+00, 0.27797100E+00, 0.40068500E+00, 0.92544900E-01, -.11735800E+00, 0.15329500E+00, 0.37991300E+00, 0.42117900E-03, -.29569900E+00, 0.25553600E+00, -.36045400E-01, 0.32237500E-02, 0.66530700E+00, 0.15244800E+01, -.18903100E+00, -.37208700E-02, -.22322700E+00, -.17450800E+00, 0.29658300E-02, -.93789000E+00, 0.46317300E+00, 0.26788800E+01, -.43333100E+00, 0.10911300E-01, 0.11130200E+01, 0.59491200E-01, 0.16662800E+00, 0.28386300E+00, -.39948900E+00, -.10916300E+00, 0.13303900E+01, -.15177800E+00, 0.33468400E+00, -.18421900E+01, 0.23417100E+00, 0.26082400E+00, 0.84674600E+00, -.47660500E+00, -.90329900E-01, -.91634100E-01, 0.87612100E-01, -.15726200E+00, -.55446100E-01, 0.95846400E-01, -.10219700E+00, 0.29566900E+00, -.10514800E+01, -.47743700E-01, -.33672200E+00, -.22150200E-01, 0.11037400E+01, -.47987800E-02, 0.10076500E+00, -.89127600E+00, 0.13164900E+00, 0.12423400E+01, 0.16797600E+01, -.22234300E+00, 0.28587500E+00, -.34660800E-01, 0.24021900E-02, -.42948900E+00, -.29372600E-01, 0.16704200E+00, 0.19019700E+00, -.29367500E+00, 0.87014300E-01, -.56893600E+00, -.36779500E+00, 0.16414900E+00, -.20839600E-01, 0.10210700E-01, 0.67578800E+00, 0.24982200E+00, 0.12483500E+00, 0.27414200E+00, -.19548400E+00, 0.19974700E+00, 0.16624900E+01, -.24404100E+00, 0.20854900E+00, 0.22667700E+00, -.17540600E+00, 0.74872000E+00, -.10504700E-01, -.37755800E+01, -.13870100E+01, 0.61657700E+00, -.35191100E+01, -.28209300E+01, -.24530900E+01, -.46469500E+02, 0.21149900E+01, 0.24029600E+02, -.20577900E+02, -.15932700E+01, 0.72018100E+00, 0.23530700E+02, 0.10916700E+01, 0.24900700E+02, -.19402500E+01, 0.22406400E+02, -.18382400E+01, -.23321100E+00, 0.27232800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57003900E+00, 0.34969500E+00, 0.41179500E-01, -.72708200E+00, -.63179600E+00, 0.92165300E+00, 0.77280800E-01, 0.56055000E-01, 0.27134600E-01, 0.12038400E+00, 0.13695100E+00, -.99451500E-01, -.37952800E+00, -.61695900E+00, -.14294400E+00, -.16461200E-02, -.31689200E-01, 0.17986200E-01, 0.62874100E-01, -.10659400E-02, -.10981300E+00, -.97452700E-02, 0.31278500E+00, -.83463100E-01, 0.25223900E-02, 0.49818200E-01, -.95784400E-01, 0.80704900E-01, 0.12942100E+00, 0.92107800E-01, 0.44514000E-01, -.18730200E-01, -.39792400E-01, -.77148400E-01, 0.10261900E-01, -.84017700E-01, -.82148500E-02, 0.12265300E+00, -.82313600E-01, -.37058400E-01, -.11427800E+00, -.25503100E-01, 0.38029000E+00, -.36781100E-01, -.56912800E-02, 0.49482600E-01, -.10781800E+00, 0.14150600E-01, 0.11778600E-01, 0.13876800E+00, 0.22889400E-01, 0.58403800E-01, 0.22686300E-01, -.69340700E-01, 0.63314600E-01, -.30575700E-01, 0.68203100E-01, 0.23538500E+00, 0.23267000E-03, -.11570100E-01, 0.20319500E-01, -.13073100E+00, 0.54867700E-01, -.29242600E-01, 0.30740100E+00, 0.17144700E-01, -.19970600E+00, 0.44007100E-01, -.13184000E+00, -.53898200E-03, 0.41712700E-01, -.73187000E-01, -.19880000E+00, 0.45002000E-01, -.16503300E+00, 0.20553900E-01, 0.90579800E-01, 0.34845800E-01, -.75812700E-03, -.12428200E-02, -.11050800E-03, -.13138900E+00, -.26134900E-01, -.58307300E-01, -.33178400E-02, 0.36349000E-01, 0.30530300E-01, 0.53210900E-03, -.48285200E-01, 0.75939900E-02, -.20406900E-01, 0.47822300E-02, -.91395300E-01, -.40667900E-01, -.54432900E-01, 0.13003300E+00, -.54405800E-01, -.22821300E+00, 0.18558800E-01, -.22782500E-01, 0.27541100E-01, -.92745800E-02, 0.13299000E-01, 0.26919400E-01, -.24217600E-02, 0.44411400E-01, 0.51063000E-01, 0.87262800E-01, 0.17932000E-02, -.39938000E-02, -.94078200E-01, 0.63579100E-02, 0.26686900E-01, 0.42113200E-03, -.64931200E-01, 0.29336800E-01, 0.30871600E-02, -.54542200E-01, 0.11192500E-03, 0.65403800E-01, 0.70979000E-01, -.39955900E-01, -.77061800E-01, 0.39601400E+00, 0.38573600E-04, -.27868400E-02, -.25044700E-01, -.68790900E-01, -.56989600E-01, -.23634900E-01, 0.62132000E-02, -.45311100E-01, -.47065300E-01, 0.22762300E-02, 0.18187200E-02, -.55644200E-03, -.14057900E+00, 0.45988100E-02, 0.12673100E-01, 0.24628800E-01, -.37972800E-01, -.14460700E-03, 0.32914300E-01, -.50839900E-01, -.10839900E+00, 0.25290100E-01, -.60824200E-02, -.81908700E-02, -.64221800E-01, -.28735700E-01, -.67739400E-02, -.18452500E-01, 0.84103400E-01, 0.38156500E-01, 0.20862400E-01, -.90612900E-02, 0.62362300E+00, -.12130200E-01, -.24892100E-01, -.20672400E-01, -.30938600E-01, 0.79102500E-01, -.65965000E-01, -.17644000E-01, -.10817700E+00, -.27204800E-02, -.78224200E-02, -.46487000E-01, 0.33610600E-02, -.71028900E-01, -.26260300E-01, -.26075100E-01, -.15661800E+00, -.21682300E-01, 0.12721600E+00, -.15063700E-01, -.38109100E-01, 0.20306700E-01, 0.38748700E-01, 0.51473400E-03, -.75836000E-01, 0.95101400E-01, 0.31278700E-02, 0.39454200E-01, 0.12687600E-01, 0.83525300E-01, 0.93585500E-02, 0.86683900E-02, -.42797700E-02, 0.69816500E-03, 0.51794100E-03, 0.22616100E+00, -.50316800E-01, 0.21787800E-01, 0.32669100E-01, 0.20070900E-01, -.39513900E-01, -.71654200E-02, -.34931200E-02, 0.96473000E-02, -.18992400E-01, -.10527400E-01, 0.20044800E-01, 0.14246700E-02, 0.22164300E-01, -.40389200E-01, 0.52124100E-01, -.24100800E-01, 0.27123800E-01, -.37986700E-02, -.55210800E-02, -.59705300E-02, 0.59111600E-02, 0.13045300E-01, 0.67750500E-02, 0.19886300E-01, -.15134500E-01, 0.46264400E-01, -.73749000E-01, 0.56231900E-01, -.50235100E-02, 0.31272500E-03, -.15885200E-01, 0.65901700E-03, -.57668400E-02, -.32474100E-01, 0.22114400E-01, -.25474100E-01, 0.58970200E-01, -.25118500E-01, 0.59221200E-03, -.55579400E-02, -.12790100E-02, -.23189100E-01, 0.16162700E-02, -.44922500E-01, -.25559800E-01, 0.27645800E-01, -.11073800E-01, 0.92212300E-02, -.26942300E-01, 0.10917800E-02, 0.25125900E-02, 0.13161300E-02, -.67627600E-01, -.13020200E-01, -.28175300E-01, -.20214800E-01, -.14096500E-01, 0.31514600E-01, 0.35708100E-01, 0.14020500E-02, -.65241600E-02, 0.82963000E-02, -.12721600E-01, 0.59924400E-01, 0.25542600E-01, 0.12437300E-01, -.62476200E+00, -.27110800E-02, -.26823900E-01, 0.45490500E-01, -.32588200E-01, -.21371900E+01, 0.54750300E-01, 0.48110900E+00, -.37676600E+00, 0.55130800E-01, -.34437600E-02, 0.42564600E+00, -.12359900E-01, 0.50202900E+00, -.57367000E-02, 0.39718000E+00, -.62525100E-01, 0.78149400E-01, 0.72378300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.21205900E+02, 0.51881900E+01, 0.24368100E+01, -.57065100E+01, -.12560100E+02, 0.17466900E+01, 0.22506000E+01, -.51686100E+01, 0.42498700E+00, 0.28865600E+01, 0.27058800E+01, -.42788000E+01, -.59518800E+01, -.85371700E+01, -.42395200E+01, 0.68045400E+00, -.50532800E+01, -.35246500E+01, 0.26576200E+00, 0.17221500E+01, -.17552400E+01, -.58062700E+00, 0.10187000E+02, -.16621400E+01, -.30684900E+00, 0.10686600E+01, 0.35332300E+00, 0.47179500E+00, 0.79683500E+00, 0.58966600E+01, -.14190400E+01, -.48021200E+00, 0.15578600E+01, 0.17195500E+01, 0.14086700E+00, -.75560800E+00, -.28995600E+00, -.11730000E+01, -.18339400E+01, -.13069700E+01, -.37672900E+01, 0.16599200E+01, 0.61881100E+01, -.97422100E+00, -.50784400E+00, 0.48529600E+00, 0.29467000E+00, -.11077800E+01, 0.82342000E+00, 0.16006000E+01, 0.34502700E-01, -.44273200E+00, 0.54145500E+00, -.11353400E+01, 0.61162500E+00, -.65864000E+00, 0.12405100E+01, 0.74493900E+00, -.22696100E+00, 0.55321200E+00, -.13478100E+01, -.50519400E+01, 0.67027800E+00, -.12236400E+01, -.31561700E+01, 0.85884600E-01, -.17899400E+01, -.27950100E+01, -.86208500E+00, 0.10350200E+00, -.12581100E+01, -.15132700E+01, 0.66500700E+00, 0.50096400E+00, -.16497400E+00, -.94209500E+00, 0.21505700E+00, -.81919300E+00, 0.14040200E+01, -.10991900E+01, 0.12593100E-01, 0.17007200E+01, 0.35797800E+01, -.50828400E+01, -.15734800E+01, -.21680600E+01, -.19702800E+00, 0.27543700E-01, 0.62166400E-01, -.67684300E-01, 0.49000300E+00, -.27615500E+00, 0.21916500E+01, 0.78080800E+01, -.23317200E+01, -.27601500E+01, 0.29878400E+00, 0.64147200E+01, -.33116300E+01, -.19747900E+01, 0.90560200E+00, -.96838200E-01, -.55174500E+00, -.24546700E+00, -.15324400E+00, 0.43497900E-01, 0.16539100E+01, 0.24094400E+01, -.29992600E+00, -.14801100E+01, 0.11856500E+01, -.72123100E-01, -.97093100E+00, -.39030300E-01, 0.60833800E-01, 0.26182800E+01, -.21225800E+01, -.41288800E+00, -.32372200E+00, 0.17306200E+01, 0.14435400E+01, -.44466300E+01, -.27826800E+01, -.92265500E+01, 0.20201500E-02, 0.30411200E+00, -.66195200E+00, -.47393200E+01, -.19863000E+01, 0.94219500E+00, -.14036300E+01, 0.21219600E+01, -.85163200E+00, -.25045300E+00, -.35312500E+00, -.44260100E-01, 0.53860500E+00, -.16407100E+01, 0.14366700E+00, 0.33700000E+00, 0.66391700E+00, -.33012500E-01, -.14779100E+01, -.68513200E+00, 0.16199900E+01, 0.27467200E+00, 0.10000300E+00, 0.54335400E+00, 0.18866500E+01, 0.28192900E+00, -.11027600E+00, 0.96439000E+00, -.13257300E+01, -.20711900E+00, -.15769000E+00, -.23903200E-01, -.15589100E+02, 0.35693800E+00, 0.66517300E+00, 0.81051500E+00, 0.72714500E+00, -.19000000E+01, 0.17205300E+01, 0.15452300E+00, 0.32849600E+01, -.24915200E+00, 0.11928000E+00, 0.94533900E+00, -.21205400E-01, 0.10666700E+01, 0.32744000E-01, 0.15390300E+01, 0.28321400E+01, 0.81942200E-01, -.23164700E+01, 0.21164300E+00, 0.14119700E+01, -.38505200E+00, -.71496500E+00, -.12475600E-01, 0.18353000E+01, -.10200900E+01, -.49070400E+00, -.10146100E+01, -.83836800E+00, -.30842100E+01, -.14749500E+00, 0.75905300E-01, -.81660100E-01, 0.24183200E+00, -.10731600E-01, -.33612600E+01, 0.55505100E+00, -.14201200E+01, -.21562000E-01, 0.13628000E+01, -.97953800E+00, 0.24295400E+00, 0.14645200E+00, -.11240800E+01, 0.87089100E+00, 0.37936100E+00, -.35008800E+01, -.25920500E+00, -.41057300E+00, 0.22209800E+01, -.14218000E+01, 0.16176500E+00, -.12459400E+01, 0.23767500E+00, 0.10958100E+00, 0.21237400E+00, -.19446200E+00, 0.43803000E+00, -.58295500E-01, -.16580300E+01, 0.52903900E+00, -.18464300E+01, 0.12011700E+01, -.19094500E+01, 0.14885800E+00, -.59491000E-01, 0.11837000E+01, -.15523300E-01, -.22919000E-01, 0.71482700E+00, -.67510200E+00, -.58507900E+00, -.11212400E+01, 0.45886700E+00, -.18239000E+00, 0.24788500E+00, 0.13953000E+00, 0.92008100E+00, 0.48375400E-02, 0.22953700E+01, 0.68059400E+00, -.12719500E+00, 0.69398900E-01, -.11404300E+01, 0.13309200E+01, -.21860800E+00, -.71619500E-01, 0.15032400E-01, 0.10456800E+01, 0.50929400E+00, 0.47322000E+00, 0.14255000E+00, 0.34399800E+00, -.38324400E+00, -.15904400E+01, 0.41185100E-01, 0.14847500E+00, -.22961900E+00, 0.99442100E-01, -.18591600E+01, -.72592700E+00, -.53848300E+00, -.12587200E+02, 0.36134600E+01, 0.63977600E+00, 0.83074300E+00, 0.16524900E+01, 0.25735900E+02, -.39097000E+00, -.60020200E+01, 0.49899100E+01, -.35638700E+00, 0.14530700E+00, -.50184600E+01, 0.25356200E+00, -.60422300E+01, 0.78526800E+00, -.34834500E+01, -.15760400E+01, 0.28224100E+00, -.75137700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19390400E+01, 0.39152500E+00, 0.14245300E+00, -.87659200E-02, -.98484000E+00, -.20205800E+00, 0.23531900E+00, -.35005800E+00, -.20623600E+00, 0.13662000E+00, -.24399800E+00, -.13393200E+00, 0.41381100E+00, -.17796600E-01, -.15513800E-01, 0.75508600E-01, -.17297800E+00, 0.61051100E-01, 0.80166700E-01, 0.72600200E-01, -.27364600E-01, 0.53909200E+00, 0.73346400E+00, -.19025600E+00, 0.73001700E-02, -.19456000E+00, 0.60098700E-01, 0.88280900E-01, 0.19784300E+00, 0.30781400E+00, 0.22969400E-01, -.54064000E-01, 0.28463200E+00, -.11745400E-02, 0.60606000E-01, -.19004500E+00, 0.64808100E-02, 0.23476000E-01, 0.91171100E-01, -.11873800E+00, -.41207000E+00, -.39422300E+00, -.15190300E+00, -.10621000E+00, 0.21761000E+00, -.57845500E-01, -.23989400E+00, 0.18147500E-01, -.97602000E-01, -.28385800E+00, 0.16485300E+00, 0.22970500E+00, 0.56164900E-01, -.99247900E-02, -.14374200E+00, -.45232700E-01, -.18481000E-01, -.71248000E-01, -.85635100E-05, -.22968500E+00, -.53559900E-01, -.19388600E+00, 0.45456000E-01, -.79665700E-01, 0.35474600E+00, 0.10136100E+00, -.20106700E+00, 0.78474900E-01, -.76677500E-01, -.10158100E-02, -.91978300E-01, -.14132500E-01, 0.69238000E-01, 0.73694900E-03, 0.26755200E-01, 0.11487800E-02, 0.58403400E-01, 0.32744300E-02, 0.13886900E+00, 0.32317200E-01, 0.24904500E-03, -.15158000E+00, 0.14122500E+00, -.10947600E+00, 0.12020300E-02, -.37236500E-01, -.86531300E-01, -.63683800E-01, -.66403900E-01, -.75166400E-02, 0.31000100E-01, -.20511600E-02, 0.79982500E-01, -.14926900E+00, -.85089900E-02, -.76220500E-01, 0.78262200E-01, -.68768000E+00, 0.12365300E+00, 0.12865400E+00, 0.15534500E+00, 0.21002000E-01, 0.50614300E-01, 0.26166800E-01, 0.16405500E+00, 0.24271100E-01, -.36995500E-01, 0.37240000E-01, 0.63928800E-01, 0.13521700E-01, 0.21434900E-01, 0.58015100E-02, 0.24031300E-01, 0.80095200E-03, -.48577600E-01, -.63837200E-01, 0.28862600E-01, 0.91386600E-01, -.29385800E-01, -.30674300E-01, 0.22032200E+00, -.34335400E-01, -.13790200E+00, 0.57115000E+00, 0.99791700E-04, -.11350900E+00, 0.86097000E-01, 0.27232700E+00, -.36124400E-01, 0.18722000E-02, -.49110200E-01, -.30406900E-01, -.34889100E-01, 0.46712900E-02, -.31446800E+00, -.13608900E-03, -.77052700E-01, 0.32563500E+00, 0.23744600E-01, -.11698500E-01, 0.30443900E-02, -.54350000E-01, 0.57216000E-01, -.19533700E-01, -.66099100E-01, -.16859700E+00, -.16461200E-01, -.14320200E+00, -.24867200E+00, -.32479000E-01, 0.11306300E-01, -.69201900E-01, -.72756000E-01, 0.28782800E-01, -.41673200E-01, 0.16338700E-02, 0.73254600E+00, -.23091000E-01, -.22489500E+00, 0.17106200E-01, -.51638300E-01, 0.10487800E+00, -.23583700E+00, -.13748200E-01, -.94599500E-01, 0.75489500E-02, -.96650300E-02, -.43583000E-01, 0.51205000E-02, -.42983100E-01, -.79706100E-02, -.16860300E+00, 0.10340000E+00, -.38660000E-01, 0.10503100E-02, -.19310500E-01, 0.80972400E-02, 0.26306700E-02, -.15655900E-01, 0.30736800E-03, 0.64216200E-01, -.35528500E-01, 0.58682600E-02, 0.11841700E-01, 0.14013900E-01, 0.54260700E-01, 0.63405800E-01, -.25788600E-01, -.50422100E-02, 0.91777200E-01, -.24404600E-03, 0.80080400E-01, -.10027400E+00, 0.44484900E-01, 0.69405400E-02, -.39905100E-01, -.85239300E-01, -.13177000E-02, -.24592200E-01, 0.83023200E-02, -.19654700E-02, -.44196600E-03, 0.38210600E-02, -.88830500E-02, -.40178800E-01, -.10494400E-01, 0.27826200E-01, 0.12635700E-02, -.53782200E-02, -.94488100E-02, 0.24567600E-02, 0.56784700E-02, -.56660000E-02, 0.21381600E-01, -.13568300E-01, 0.13215800E-01, 0.66664000E-02, 0.13498800E-01, 0.18014600E-02, 0.56870900E-01, 0.21401900E-01, -.77361600E-03, -.17388200E+00, 0.11438800E-02, -.10020100E-01, 0.53344700E-01, -.35679600E-01, -.62641900E-01, -.10312700E+00, -.16859700E-01, -.28025000E-01, -.17577000E-01, -.71358200E-02, 0.11324700E-01, 0.60426000E-02, -.88478500E-01, -.51137000E-01, 0.42944000E-01, -.24495500E-01, 0.77730100E-01, -.16989000E-01, -.11289100E-01, 0.17976400E-01, -.17284800E-02, -.13662300E+00, -.42630200E-01, -.55127200E-01, -.44194200E-01, -.14076600E-01, 0.50447900E-01, 0.61793700E-01, 0.22047500E-01, -.33964600E-01, -.32573500E-01, 0.31859700E-01, -.90933000E-01, 0.11271600E-01, -.10701500E+00, 0.51566500E-01, -.23416200E-01, 0.32594600E+00, 0.21430600E+00, 0.31202500E+00, 0.49433900E+01, -.21070000E+00, -.24191200E+01, 0.20637400E+01, 0.14269800E+00, -.55088200E-01, -.23131000E+01, -.10541900E+00, -.24943800E+01, 0.24770200E+00, -.21393300E+01, -.44119800E-01, -.11822000E-01, -.29175100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.25185900E+01, 0.35018900E+00, 0.34461100E+00, -.38840600E+00, -.11487900E+01, -.23887500E+00, 0.26692000E+00, -.34907100E+00, -.29237400E+00, 0.25709400E+00, 0.10956900E+00, -.20553000E+00, 0.53264600E+00, 0.88832100E-01, -.79772100E-01, 0.51026200E-01, -.29311800E+00, -.54516700E+00, 0.16349500E+00, 0.24450900E+00, -.30130600E+00, 0.18458500E+00, 0.12133100E+01, -.21277400E+00, -.42229300E-02, -.15491000E+00, -.28559800E-01, -.51451100E-01, 0.16678800E+00, 0.49747200E+00, -.75328600E-01, -.72322900E-01, 0.36776000E+00, 0.14685300E+00, 0.55096400E-01, -.14148000E+00, 0.14370500E-01, -.57788300E-01, 0.83854000E-01, -.13752800E+00, -.63245800E+00, -.33599300E+00, -.82656000E-03, -.11523300E+00, 0.38340400E+00, -.24585300E+00, -.16632900E+00, 0.10864600E+00, -.66773800E-01, -.47672900E+00, 0.77357100E-01, 0.71420900E-01, 0.46949900E-01, 0.82524300E-02, -.10371000E+00, 0.38139600E-01, -.46199400E-01, -.21495600E+00, 0.48017600E-04, -.28812400E+00, 0.30142100E-01, -.23586700E+00, 0.75277100E-01, -.54167200E-02, 0.40706100E+00, 0.32610500E+00, -.19408100E+00, -.11860100E+00, -.12475400E+00, -.16935400E-02, 0.31537500E-01, -.82857600E-01, -.10563500E+00, 0.55785100E-01, 0.13809600E+00, 0.88907700E-02, 0.93455800E-01, -.11011500E+00, 0.26565900E+00, 0.30050900E-01, 0.33902200E-03, -.22876500E+00, 0.25596300E+00, 0.36684000E-01, 0.46502700E-02, -.17513900E+00, 0.54553600E-01, -.86674300E-01, -.86162900E-01, -.17180600E-01, -.48779800E-02, 0.33778300E-02, 0.42456900E-01, -.36855800E+00, -.14091100E+00, -.16274900E+00, 0.69726800E-01, -.60083800E+00, 0.18766800E+00, 0.15783500E+00, 0.19437300E+00, 0.21426500E-01, 0.35766800E-01, 0.10276400E-01, 0.82878200E-01, -.20305000E-01, -.12239600E+00, -.70213800E-01, -.87870000E-01, 0.10018300E+00, -.10116200E+00, 0.29186000E-02, -.57992600E-04, 0.15121500E-02, -.73669500E-01, 0.31401100E-01, -.88125300E-01, 0.11004500E+00, -.16161800E-01, -.25066200E+00, 0.15059100E+00, 0.27208900E-01, -.72484200E-01, 0.27805500E+00, -.53965700E-03, -.82713400E-01, 0.28759600E-01, 0.12686500E+00, -.38466100E-01, -.10422300E-01, -.43444700E-01, -.72450200E-01, -.32985400E-01, 0.22409000E-01, -.25134700E+00, -.55596600E-05, -.15889600E+00, 0.22842900E+00, 0.11677700E-01, -.13412900E-01, 0.86430500E-02, -.50633700E-01, 0.76500800E-01, -.25557500E-01, -.24358900E-01, -.10013100E+00, -.11756500E-01, -.89015800E-01, -.16050000E+00, -.18090900E-01, 0.18434900E-01, -.59563300E-01, -.78312100E-01, 0.22954800E-01, -.43028200E-01, -.22005100E-02, 0.76633100E+00, -.24427300E-01, -.39392100E+00, 0.70053300E-01, -.81798400E-01, 0.72738700E-01, 0.32799900E-01, 0.51092600E-01, -.58345200E-01, -.35929700E-01, -.26446400E-02, -.64126400E-02, 0.12319200E-01, -.95076900E-01, -.35577300E-01, -.11289000E+00, 0.20456300E+00, -.37172300E-01, -.10623800E+00, -.91397800E-03, 0.11387100E+00, -.83408600E-02, -.23442700E-02, 0.11731800E-02, -.13079500E-01, -.72558700E-01, 0.13670800E-01, -.14161600E-01, 0.57088300E-02, 0.46148300E-01, 0.27515500E-02, -.10467000E-01, -.34530100E-01, 0.57381000E-01, 0.14382100E-02, -.15909700E-01, -.11575000E-01, 0.31143400E+00, -.29999000E-01, -.35375500E-01, 0.63514400E-01, 0.48910100E-02, 0.49208500E-02, -.15773900E-01, -.18849600E-01, -.14616600E-01, 0.15796300E+00, 0.13902900E-01, -.60706500E-01, -.31674900E-02, 0.25341600E+00, 0.64344600E-01, 0.77148700E-01, -.30994700E-01, -.81239500E-03, 0.70271100E-02, -.58012500E-02, -.19902400E+00, -.57787500E-01, 0.27838900E-01, 0.30708500E-01, 0.30751500E-01, -.16713000E+00, 0.13184600E+00, -.10267600E-01, -.46544200E-02, -.15850300E+00, 0.13148200E-02, -.13011400E-01, 0.67515600E-01, -.30099300E-01, -.16116400E+00, -.14013200E+00, -.37645700E-01, -.84318100E-01, 0.28065300E-02, 0.40846800E-02, 0.35582700E-02, 0.66134400E-02, -.66938900E-02, 0.23401500E-02, 0.22360500E-01, -.15094400E-01, 0.17846200E-01, -.13151900E-01, 0.19119700E-01, -.11215800E-01, -.19641100E-02, 0.10126700E-01, -.28865300E-01, 0.24578200E-02, -.49682200E-01, 0.25183900E-01, -.61844600E-01, -.99113600E-01, 0.78333400E-02, 0.42105000E-02, -.30383200E-01, 0.16007300E-01, -.34257700E-01, 0.11407700E-01, -.59864100E-01, 0.12313300E+00, -.25264100E-01, 0.74297200E+00, 0.29842200E+00, 0.40011600E-01, 0.15599900E+01, -.62194100E-01, -.61723500E+00, 0.52309300E+00, 0.21554400E-01, -.80475400E-02, -.51165700E+00, 0.10771600E-01, -.63750300E+00, 0.92024300E-01, -.56076000E+00, 0.10296400E+00, 0.99508500E-01, -.10316500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.12392500E+01, -.14055800E+00, -.63237000E+00, 0.72698700E+00, 0.72524500E+00, -.37388500E+00, -.95931900E-01, 0.48562700E+00, -.26421900E+00, -.31260200E+00, 0.93037600E-01, 0.22139400E+00, 0.37814300E+00, 0.48425800E+00, -.20786400E-01, -.67954500E-01, 0.41457100E+00, 0.60771600E+00, -.88683700E-02, -.46832800E-01, 0.45319000E+00, -.18573600E+00, -.78065100E+00, 0.36156900E+00, -.24362500E-01, -.51381500E-01, -.35139600E-01, -.71791700E-02, -.59385800E-01, -.33643600E+00, 0.87081200E-01, 0.80221900E-01, -.30877600E+00, -.11613700E+00, -.28366100E-01, 0.28813500E+00, -.15382200E-01, 0.16870800E+00, 0.10874100E+00, 0.18549600E+00, 0.36878200E+00, -.59602100E-01, -.70570700E+00, 0.17186400E+00, -.15993700E+00, -.76106400E-02, -.86712300E-01, -.16302000E+00, -.10508400E+00, -.68309600E-01, -.95160500E-01, 0.13819700E+00, -.27183000E-01, 0.13593600E+00, -.17983400E+00, -.11777000E+00, -.38774600E-01, -.40261500E+00, 0.67865400E-04, 0.86802700E-01, -.60199700E-01, 0.15576800E+00, -.10471500E+00, -.12361000E+00, -.24741200E+00, -.28273900E+00, 0.16861700E+00, 0.37047100E-01, 0.12380400E+00, 0.26356900E-02, -.18679300E+00, 0.41345100E-01, 0.67457900E-01, -.22740400E-01, 0.95927900E-02, -.37839900E-01, -.18419600E-01, -.16604300E-01, -.23704400E-01, -.59895500E-01, -.11112100E-03, 0.17833100E-01, 0.79849500E-01, 0.36631400E-01, -.27037300E-01, 0.12855400E+00, -.67126100E-01, 0.51282700E-02, 0.10903100E+00, -.18281000E-01, -.25756900E-01, -.11542300E-01, -.38943700E-03, -.90493300E-01, 0.31450000E+00, 0.20576000E+00, -.39256200E-01, -.31547000E+00, -.59840500E-01, 0.41470200E-01, -.17585200E+00, -.24171100E-01, -.46999300E-01, -.41331900E-01, -.15895500E-01, 0.87812300E-01, 0.18636200E+00, -.12297000E+00, 0.35255600E-01, -.43346700E-01, 0.14169900E+00, 0.45812500E-02, 0.23014900E-02, 0.10879800E-02, -.71918800E-01, 0.14764300E+00, 0.29894700E-01, 0.25153400E-01, 0.23666800E-01, 0.95646600E-01, -.26091200E+00, 0.23152400E+00, 0.56716400E-01, -.25868800E-01, -.27323000E-02, 0.14800600E+00, -.37090000E-01, 0.77141800E-01, 0.11226000E-01, 0.16645500E-01, 0.21368300E-01, 0.70453000E-02, 0.78524700E-01, -.23799900E-01, 0.15035900E+00, 0.11701000E-02, 0.25218200E+00, -.15770000E+00, -.17763900E-01, 0.62599800E-02, -.33242400E-01, 0.16164500E-01, -.24382300E-01, 0.94592200E-01, 0.81622600E-01, 0.10306000E+00, 0.36318800E-02, 0.10620600E+00, 0.33085700E+00, -.20200100E-01, 0.77243800E-02, 0.36370700E-01, -.95287500E-01, 0.18242100E-01, 0.54508100E-02, 0.33717900E-02, -.10918600E+00, 0.58485600E-02, 0.28452800E+00, -.10972200E+00, 0.31038500E-01, -.54296000E-03, 0.10122600E+00, -.28503400E-01, -.32034000E-01, -.50732900E-03, -.11776900E-01, 0.95607500E-03, -.44529500E-02, 0.17879600E-01, -.12091900E-01, -.15045900E-01, -.88724700E-01, -.28382400E-02, -.11441300E-01, 0.52581500E-02, -.32885800E-01, 0.15124000E-01, 0.92359700E-03, -.61599900E-05, 0.18745300E-01, -.53554500E-01, -.35110500E-01, 0.85208700E-01, -.26704900E+00, -.85155500E-01, 0.93055900E-02, 0.32700500E-01, 0.17652500E-01, 0.38381500E-01, -.35104300E-03, 0.14479100E-01, 0.31347700E-01, -.14893700E-01, 0.22145800E-01, -.11801300E-01, 0.66765200E-01, -.32179600E-01, -.17039100E-01, -.28462500E-01, 0.98102500E-02, 0.17654100E-02, -.82994900E-01, 0.87417000E-02, 0.81345500E-01, -.13969900E-02, -.13803700E+00, -.38636300E-01, -.61722100E-01, 0.41886400E-01, -.53420100E-02, -.27869900E-02, 0.26936300E-02, 0.56953000E-01, 0.81904400E-01, -.59351100E-01, 0.17316300E-01, -.23745000E-01, -.17521700E+00, -.68868800E-01, 0.11202700E-01, -.28939100E-02, 0.11040500E+00, -.12141300E-03, 0.22326600E-01, -.10255700E+00, -.16553900E-01, 0.75154800E-01, 0.10283900E+00, 0.77310600E-02, 0.74120600E-01, -.15400000E-01, 0.42038100E-03, -.12648600E-01, -.12173300E-02, -.90732400E-01, -.21143900E-01, 0.51226700E-03, 0.47893300E-03, 0.24371800E-01, -.17133700E-01, -.41325000E-02, 0.11404200E-01, 0.15272000E-02, 0.13710400E-01, 0.71665700E-02, -.17747100E-01, 0.26554000E-01, -.45165200E-01, 0.85501100E-01, 0.23553300E+00, -.10015500E-01, -.10113700E-01, 0.49979900E-02, -.10305100E-01, -.77732400E-01, 0.35475200E-03, -.99264200E-01, 0.53088300E+00, -.69536100E-02, 0.31521800E+00, 0.61744600E-01, 0.34366300E+00, 0.48181400E+00, 0.21748500E-01, 0.38271700E+00, -.24380800E+00, -.17968100E+00, 0.50262800E-01, 0.44978500E+00, 0.56297800E-01, 0.42783400E+00, 0.58226000E-01, 0.59349100E+00, -.74295600E+00, 0.81089500E-01, 0.76142900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.19993200E+02, 0.46984000E+01, 0.19577800E+01, -.30188700E+01, -.12631200E+02, -.15830700E+00, 0.24339800E+01, -.71503600E+01, 0.56490300E+00, 0.29149600E+01, 0.26720700E+01, 0.27241100E+01, 0.35852300E+01, 0.67248200E+00, -.99591100E+00, 0.92876000E+00, -.74748500E+00, -.15937300E+01, 0.67371600E+00, -.22089700E+01, 0.97738200E-01, 0.67907300E+01, 0.13920100E+02, -.48770500E+01, -.44523200E-02, -.66395500E+00, 0.26756800E+00, -.45444600E-01, 0.32071300E+01, 0.20543000E+01, 0.55709700E+00, -.57951200E+00, 0.19753000E+01, -.55988900E+00, 0.48774600E+00, -.77334000E+00, 0.22013600E+00, -.15441700E+01, 0.55741600E+00, -.17431200E+01, -.28029600E+01, -.20152200E+01, -.35952100E+01, -.20159900E+01, -.17391300E+01, 0.53317400E+01, -.15261100E+01, -.70934700E+00, -.16942800E+01, -.73868100E+00, 0.45506400E+01, 0.39313600E+01, 0.95676600E+00, -.12872100E+00, -.12182000E+00, 0.70082200E+00, 0.85538900E-01, 0.56195300E+01, -.12405700E-01, -.31002300E+00, 0.62592500E-01, -.28745900E+00, 0.44298600E+00, -.22300700E+01, 0.52913800E+01, -.10234800E+01, -.30726600E+01, 0.86998900E+00, -.11327200E+01, -.17175200E-01, 0.82543900E+00, -.46889500E+00, 0.44528300E+00, -.49363000E+00, 0.10765700E+00, 0.19231900E+00, 0.69242700E+00, -.59751700E+00, 0.19199000E+00, 0.54294500E+00, -.59833200E-03, -.47436600E+00, -.23506800E+00, -.28085400E+01, -.29706900E+00, 0.36812500E+00, -.20805700E+01, -.58262800E+00, 0.11543900E+00, -.13014800E+00, 0.10553800E+01, 0.52273400E-02, -.11212700E+01, -.17907200E+00, 0.17697300E+00, 0.51067800E+00, 0.76233900E+00, -.20328600E+01, 0.36852400E-01, -.33903200E+00, -.46044800E+00, -.22705600E+00, 0.42519900E+00, -.50098400E+00, 0.94891500E-01, -.68587700E+00, -.13740400E+01, -.90379200E+00, -.20493500E+01, 0.72527200E+00, 0.21219000E+00, 0.15644100E+00, -.50550000E+00, 0.17599700E-01, -.57650600E+00, -.10484800E+01, 0.21253400E+00, -.19147400E+00, -.12744200E-01, -.17027500E+01, 0.13075600E+01, -.35704000E+00, -.20269400E+00, 0.10920900E+01, 0.15820000E-02, -.71954200E+00, 0.22627000E+00, 0.63442200E+00, -.62020500E-02, -.38309600E+00, -.15054100E+00, 0.16709000E+00, -.22958800E+00, 0.79271200E-01, -.11203000E+01, -.97042000E-03, -.54049600E+00, 0.10353200E+01, 0.20685300E+00, -.21839100E+00, -.19065200E+00, -.41744700E+00, 0.40467600E+00, -.11344300E+00, 0.11147800E+00, -.45200200E+00, -.14079900E+00, -.17509700E+01, 0.26207800E+00, 0.11168900E+01, -.67983000E-01, -.38757000E+00, -.38349200E+00, 0.10538700E+00, 0.17638500E+00, -.62937800E-02, 0.55499500E+01, -.27729900E+00, -.88315200E+00, 0.11377800E+00, 0.21508000E+00, 0.17021100E+00, -.21841600E+01, -.49970400E-02, 0.88495800E+00, -.68237000E-01, 0.12205400E+00, -.26366600E+00, 0.12957800E+00, -.12479600E+01, -.60061700E-01, -.65197800E+00, 0.14791500E+01, -.49358600E+00, -.13716100E+01, 0.29181200E+00, 0.10901200E+01, -.27623100E+00, 0.49149300E+00, 0.10926800E-01, -.15261700E+01, -.12460000E+01, 0.12503000E+01, -.25277600E+00, 0.99185100E+00, 0.14310600E+01, -.68922400E+00, -.96991000E-01, -.49930200E+00, -.54476900E+00, 0.15652100E-01, 0.39934100E+00, 0.23132200E+00, -.24680900E+01, 0.11572500E+01, 0.24371800E+01, -.13593100E+01, 0.24553500E+00, -.43191700E+00, -.13542700E+01, -.17333200E+01, -.22408200E+00, 0.85454300E+00, -.60534300E-03, 0.50607100E+00, 0.23107900E+01, 0.21187400E+01, -.34064100E-01, 0.28323900E+00, 0.87844100E+00, 0.53731900E-01, 0.20146600E+00, -.20429300E+00, -.20930000E+01, 0.17281000E+01, 0.17031900E+01, -.10575500E+00, 0.60039600E-02, 0.78214600E+00, 0.27563700E+01, -.23646600E-01, -.33878500E-01, -.29571400E+01, 0.48672900E-02, -.82189700E-01, 0.19708200E+01, 0.29747900E+00, -.10724200E+01, -.25076800E+01, -.11410300E+01, -.12739000E+01, 0.51004600E+00, 0.13186800E+00, -.10616900E+00, -.80639300E-01, 0.25103800E+00, 0.37627200E+00, 0.45958900E+00, -.17353700E+00, 0.50760900E+00, 0.35458400E+00, 0.48741900E-01, -.13582100E+00, 0.41756700E-03, 0.35070300E-01, 0.12596500E+00, -.21368800E+00, -.82783400E-01, 0.72460800E+00, -.42589600E+00, -.50235900E+01, 0.98731900E-01, 0.27162300E+00, 0.21333900E+00, 0.48840100E+00, -.10804300E+01, 0.33366800E-01, -.79166800E+00, 0.13237800E+02, -.88393600E+00, 0.69890600E+01, -.32743100E+01, 0.13639100E+02, 0.95238200E+02, -.79782000E+00, -.80998800E+01, 0.54640700E+01, -.14315800E+01, 0.52749800E+00, -.42456100E+01, 0.14448300E+01, -.82436000E+01, -.40524300E+00, -.26564500E+01, 0.47151400E+01, -.22450500E+01, -.15809500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.31194200E+01, -.83245700E+00, 0.21373200E-01, 0.14317700E+00, 0.19200300E+01, -.33725000E-01, -.39230000E+00, 0.81186800E+00, 0.32432700E-01, -.45019500E+00, 0.43709500E-01, 0.57436600E-01, -.23655600E+00, 0.25567400E-01, 0.31050700E-01, -.12802400E+00, 0.30129500E+00, 0.34327000E+00, -.70052800E-01, 0.34971200E-01, 0.38514000E+00, -.79361200E+00, -.18244200E+01, 0.72373800E+00, -.27506500E-01, 0.18797700E+00, -.14006900E+00, -.11154000E+00, -.41103600E+00, -.99789500E-01, -.73908500E-01, 0.28726300E-01, -.39694600E+00, 0.11713800E-02, -.64637900E-01, 0.51654600E-01, -.55645200E-02, 0.84165800E-01, -.37646100E-01, 0.29873100E+00, 0.57114300E+00, 0.25505600E+00, -.31574000E+00, 0.30641700E+00, 0.34107000E-01, -.40275900E+00, 0.38892800E+00, -.88352700E-01, 0.79481700E-01, 0.20807500E-01, -.26556900E+00, -.23785500E+00, -.10108700E+00, 0.12925100E+00, 0.37950200E-02, -.14904500E+00, -.28421000E-01, -.71374800E+00, 0.11362800E-02, 0.32126400E+00, 0.16682300E+00, 0.19999600E+00, -.81194400E-01, 0.11040600E+00, -.47664400E+00, -.14137700E+00, 0.23447200E+00, -.75055900E-01, 0.10191100E+00, 0.40281300E-02, -.70524500E-01, 0.13453300E+00, -.19035600E+00, 0.53732500E-01, -.83239200E-01, -.12649800E-01, -.11468000E+00, 0.67270600E-01, -.10998300E+00, -.78482200E-01, -.17081400E-03, 0.17249100E+00, -.46688900E-02, 0.31875400E+00, 0.76770600E-02, -.11927300E+00, 0.23394600E+00, 0.19176100E+00, 0.15354500E+00, 0.86191400E-02, -.21365700E+00, -.96511700E-02, 0.66218800E-01, 0.62678700E-01, 0.30051700E+00, 0.33124000E+00, -.83790600E-01, 0.15835400E+00, -.39645700E-01, -.11340100E+00, 0.11011600E+00, 0.35639700E-01, -.32662900E-01, 0.16921000E-01, 0.16084000E+00, -.15910900E+00, 0.20823800E+00, -.12321200E+00, 0.30579800E+00, 0.27818300E-01, 0.11933800E+00, -.16843000E-01, -.49497800E-02, 0.71828500E-03, 0.10094000E+00, 0.25297000E+00, -.41675300E-01, 0.77274000E-01, 0.40253100E-01, 0.17721700E+00, -.32983500E+00, 0.20434200E+00, 0.34892400E+00, -.75548100E+00, -.32452300E-02, 0.23428200E+00, -.40157100E-01, -.36037800E+00, 0.35568400E-01, -.13575500E-01, -.41324000E-01, 0.47578900E-02, 0.86986700E-01, -.23242900E-01, 0.41524800E+00, 0.34312800E-03, 0.23765000E+00, -.29283200E+00, -.34410300E-01, 0.48576900E-01, 0.21474500E-01, 0.94286100E-01, -.92949600E-01, 0.10633600E-01, -.21329600E+00, 0.27134700E+00, 0.15760300E-01, -.38371600E-01, 0.17237600E+00, -.13305600E+00, -.27828700E-01, 0.73321600E-01, 0.29091000E+00, 0.12589500E-01, -.70314600E-02, -.42446500E-04, -.60130500E+00, 0.33939300E-01, 0.34067200E+00, -.85297400E-01, 0.39173100E-01, -.87038800E-01, 0.27005600E+00, 0.18033500E-01, -.18356400E+00, 0.51219900E-03, -.54775800E-02, 0.43995300E-02, -.85541600E-02, -.72425900E-01, 0.44028500E-01, 0.22361100E-01, -.62286500E-01, 0.45776700E-01, 0.42157600E-01, 0.16610800E-01, -.39593800E-01, 0.11346000E-01, 0.16577100E-01, -.68275700E-03, 0.83795600E-01, -.66371500E-01, -.35017000E-01, 0.76621900E-02, -.35030000E-01, -.41679100E-01, 0.37972000E-03, 0.42425000E-03, 0.20231800E-01, -.11776300E-01, -.84839700E-03, -.27287400E+00, 0.41752400E-01, 0.15895600E+00, -.27579900E-01, 0.83438700E-01, 0.93201400E-01, 0.47252400E-02, 0.94312500E-01, -.15051700E-01, 0.97843200E-01, 0.14779500E-01, 0.30540100E-01, -.60476000E-02, -.78995200E-01, -.10684300E+00, -.25141400E+00, 0.31183500E-01, -.97493400E-02, -.74291500E-01, -.50072900E-02, -.24429000E-02, 0.20877000E-02, 0.27115700E+00, -.73338800E-01, -.12456200E+00, -.14380700E-01, -.36001200E-01, -.18917600E+00, -.32865500E+00, 0.54166600E-04, -.10051800E-02, 0.50442000E+00, -.37295500E-03, -.15488500E-01, -.22976600E+00, -.63653300E-01, -.10645200E+00, 0.26626300E+00, 0.78714300E-01, 0.16188300E+00, -.32774000E-01, 0.62063000E-02, 0.16100900E-01, 0.45237600E-03, 0.27703100E+00, 0.10263400E+00, -.90322700E-01, 0.35312600E-01, -.10252200E+00, 0.91182200E-01, 0.23860200E-01, 0.74155300E-02, 0.54147300E-02, 0.12759000E+00, 0.38635800E-01, 0.77684200E-01, 0.27352200E-02, 0.37022900E-01, -.67080700E-01, -.11005000E+00, -.13053800E-01, 0.28827400E-01, 0.55287800E-01, -.49619500E-01, 0.16092300E+00, -.19754300E-01, 0.15603100E+00, -.28146500E+00, 0.57982400E-01, -.15289600E+01, -.24184500E+00, -.74702600E+00, -.46267500E-01, 0.16450100E+00, 0.13352900E+01, -.11660800E+01, -.17060800E+00, 0.75542400E-01, 0.14709600E+01, 0.11794500E+00, 0.14022500E+01, -.77283900E-01, 0.14921300E+01, -.20546700E+00, 0.15185300E-01, 0.19540000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.44133500E+01, 0.10718700E+01, 0.72506100E+00, -.95267200E+00, -.26953100E+01, 0.17797700E+00, 0.49146000E+00, -.15328500E+01, 0.19607700E+00, 0.72763400E+00, 0.70600000E+00, 0.13609900E+00, -.39407800E+00, -.74054200E+00, -.11596300E+00, 0.12207400E+00, -.58608200E+00, -.69671400E+00, 0.16573100E+00, -.10204200E+00, -.41149800E+00, 0.10230200E+01, 0.28351500E+01, -.11657700E+01, -.35192500E-02, -.16875500E+00, 0.15905900E+00, 0.36433700E-01, 0.57578700E+00, 0.34416300E+00, 0.41534400E-01, -.10507100E+00, 0.65577900E+00, -.67011400E-01, 0.91606300E-01, -.20886200E+00, 0.11920200E-01, -.17379800E+00, 0.91670700E-01, -.38219800E+00, -.74315700E+00, -.36673400E+00, 0.78323400E+00, -.47235700E+00, 0.46107500E-01, 0.46410500E+00, -.77511000E-01, 0.16817000E+00, -.35206200E-01, -.18253400E+00, 0.44174800E+00, 0.26800000E+00, 0.12278800E+00, -.10348600E+00, 0.18274200E+00, 0.32783400E+00, -.67337600E-02, 0.12641100E+01, -.16851000E-02, -.26591000E+00, -.51898700E-01, -.12806100E+00, 0.12281200E+00, -.21256700E+00, 0.86800400E+00, 0.12072300E+00, -.48578200E+00, 0.74750900E-01, -.16423300E+00, -.43962100E-02, 0.17346100E+00, -.10979200E+00, 0.59767600E-01, -.28813300E-01, 0.14693500E-01, 0.30038300E-01, 0.63035200E-01, -.20337400E+00, -.64960200E-01, 0.20194200E+00, -.12173900E-03, 0.21788400E+00, -.33209500E+00, -.26381500E+00, -.20598600E-01, 0.16675300E+00, -.20447300E-01, -.13680700E+00, -.36167300E-01, 0.38989200E-01, 0.18741000E+00, 0.22256600E-01, -.97769500E-01, -.53452000E-01, -.46594500E+00, -.26824000E+00, 0.13184300E+00, 0.43575700E-01, -.47906300E-01, 0.51180900E-01, -.17047800E+00, -.47194600E-01, 0.40101300E-01, -.16096100E-01, -.10312400E+00, 0.81812000E-01, -.18569000E+00, -.11331000E+00, -.45262100E+00, 0.15669400E+00, -.12286200E+00, 0.35342500E-01, 0.10082100E-02, 0.16431300E-02, -.16712600E+00, -.13043200E+00, -.85828100E-01, -.11852300E+00, -.19336000E-01, -.22263400E+00, 0.43058500E+00, -.34675900E+00, -.30007700E+00, 0.78917200E-01, 0.17489200E-02, -.17497200E+00, 0.46180200E-01, 0.30983900E-01, -.15639700E+00, 0.24092200E-01, -.13264200E+00, -.74773200E-01, -.41231900E-01, 0.53035000E-01, -.45976100E+00, -.24924800E-02, -.13545000E+00, 0.44313600E+00, 0.62828600E-01, -.61779100E-01, -.99813900E-01, -.16904400E+00, 0.11234400E+00, 0.73303200E-02, 0.27019800E+00, -.11189100E+00, -.11532200E-01, 0.80400100E-01, -.15329700E+00, 0.17921600E+00, 0.53932600E-01, -.12552500E+00, -.45272600E+00, -.10345600E+00, -.40364100E-01, 0.14772900E-01, 0.73180500E+00, -.41856300E-01, -.58070800E+00, 0.17236100E+00, -.80596100E-01, 0.64382100E-01, -.24366400E+00, 0.12898800E-01, 0.55068800E+00, 0.93268400E-02, 0.19722500E-01, 0.26876500E-01, 0.19697900E-01, 0.91096700E-01, -.11479700E+00, -.19543200E-02, 0.21587000E+00, -.22663200E-01, -.63442100E-01, -.80768600E-02, 0.91993400E-01, -.39461700E-01, -.52282000E-01, 0.11983000E-03, -.21502100E+00, 0.24267200E+00, 0.71356700E-01, -.18526100E+00, 0.33900300E+00, 0.20265900E+00, 0.60081000E-01, -.32817300E-01, -.86384500E-01, 0.31444200E-01, 0.91074100E-03, 0.25248700E+00, -.11540200E+00, 0.66479300E-01, -.36004300E-01, 0.23832100E-01, -.10888000E+00, 0.12556900E-01, -.96292600E-01, 0.25853000E-01, -.14518900E+00, -.17174400E-01, -.99774100E-01, -.39752900E-01, 0.13061900E+00, -.26687900E-01, 0.30768600E+00, 0.77406400E-02, 0.12870100E+00, 0.38644900E-01, -.87046700E-02, -.30417100E-02, 0.38016400E-02, -.39762900E+00, 0.10338700E+00, 0.21895000E+00, -.22463500E-03, 0.12701100E+00, 0.53529800E-01, 0.50091900E+00, 0.13312400E-01, -.96937000E-02, -.71975500E+00, 0.11756800E-02, 0.52605400E-01, 0.33663100E+00, 0.85037800E-01, 0.16858600E-02, -.30278800E+00, -.12011900E+00, -.20288000E+00, 0.32466000E-01, -.67081100E-03, -.61498400E-01, -.24888800E-02, -.52877600E+00, -.17416200E+00, 0.19922400E+00, -.75235000E-01, 0.27326100E+00, -.14136000E+00, 0.28398000E-01, 0.39868000E-01, -.53887300E-02, -.29736300E+00, -.60332200E-01, -.13908500E+00, -.96465200E-01, 0.29414300E-01, -.50462100E-01, -.27370200E+00, 0.50666000E-01, -.45734100E-01, -.80186900E-01, 0.11372700E+00, -.22820100E+00, 0.28189200E-01, -.20101400E+00, 0.42000600E+00, -.89816500E-01, 0.22621200E+01, 0.22965000E+00, 0.12599200E+01, 0.83505900E-01, -.70447800E+00, -.14095400E+01, 0.12002300E+01, 0.12958100E+00, -.29398000E-01, -.15854800E+01, -.51048600E-01, -.14871400E+01, 0.86332000E-01, -.15923100E+01, 0.35361200E+00, -.16652600E-01, -.66651100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.13330200E+01, 0.65854900E-01, 0.16828800E-01, 0.49852800E+00, -.23322600E+00, -.12618900E+00, 0.80877400E-01, 0.25217200E+00, -.19028500E+00, 0.36540700E+00, 0.25000900E+00, -.28735900E-01, 0.68270900E+00, 0.87486200E+00, 0.51592800E-01, 0.14410200E-02, -.77288100E-01, 0.12753700E+00, 0.26515800E+00, -.92820900E+00, -.26861000E+00, -.12941600E+00, -.20246800E+00, 0.72106600E-01, 0.20572500E-01, 0.64257400E-01, 0.30632700E-01, -.14464800E-01, -.48531500E-01, 0.58160500E+00, -.34074300E-01, -.60972300E-01, 0.71776600E-01, -.13357900E-01, 0.73551200E-02, -.83706400E-01, 0.11345300E-01, -.17147200E+00, 0.67273300E-01, 0.32996600E-01, 0.48328700E-01, 0.10616600E-01, -.54792500E+00, 0.43895800E-01, -.13319200E+00, 0.87253100E-01, 0.47561700E-01, 0.35466100E-01, -.17628500E-01, -.12220900E+00, -.44741200E-01, -.61270600E-02, 0.22283000E-01, 0.50806000E-01, 0.39324400E-01, -.33867300E-01, -.21262200E-02, -.21897200E+00, 0.16138500E-03, -.13955100E+00, -.89941900E-02, 0.20600100E-02, -.17751900E-01, -.15765700E-01, 0.17619800E+00, 0.57503300E-01, -.56558000E-01, 0.47466500E-01, 0.25069400E-01, 0.46803600E-03, -.20019700E-01, -.63397700E-01, 0.90962100E-01, -.18314100E-01, -.69429400E-02, -.28766000E-01, -.39097400E-01, 0.23020600E-01, 0.73940100E-01, 0.18233000E-01, 0.10359400E-03, -.10506400E+00, -.34904000E-01, -.49066400E+00, -.25941300E-01, -.65396500E-01, -.18907800E+00, -.57879800E-01, -.10905500E+00, 0.19005600E-01, 0.37727200E-01, -.17865800E-01, -.37818500E-01, 0.40203600E-01, -.67726800E+00, -.33596700E-01, 0.25860300E-02, 0.21569800E+00, -.29982200E-01, 0.19146000E-02, -.43279300E-01, 0.13291100E-01, 0.85944600E-02, -.60279600E-02, 0.39735500E-01, -.10555400E+00, 0.88923900E-04, 0.24946700E-01, 0.16931900E-01, -.15366500E-01, 0.19564400E-01, -.97924400E-02, 0.10909500E-01, -.21420700E-03, 0.65337900E-01, -.42984700E-01, 0.15057200E-01, -.34850200E-01, 0.79298300E-02, 0.38393400E-01, -.29692000E-02, -.15834700E+00, -.28705200E+00, -.75337100E-01, -.54965400E-03, -.81800200E-02, 0.45968000E-02, 0.25185500E-01, -.58184800E-02, -.15661200E-01, -.25785800E-01, 0.18312200E-01, -.98687700E-02, -.97311700E-03, 0.23371900E-01, 0.12324100E-03, 0.35083400E-02, -.25685600E-01, -.60851900E-02, 0.61477800E-03, 0.25037900E-01, 0.10649700E-02, -.14939700E-01, -.26020800E-02, -.35510100E-02, -.50480600E-02, 0.43946800E-02, -.46496400E-01, -.30830200E-01, -.47519100E-02, 0.37363200E-02, -.15972700E-02, -.48599900E-02, -.17803500E-01, -.34929400E-01, 0.91365900E-02, -.10777700E+00, 0.48479200E-02, -.10550000E-02, -.58095500E-03, 0.16246300E-01, 0.72247600E-03, -.23623100E-01, -.13503100E-01, 0.87883000E-01, 0.28013400E-02, 0.24336900E-02, -.20281200E-02, -.13303100E-02, 0.59095300E-02, -.13562600E-02, -.49472100E-01, 0.14197400E-01, 0.14251900E-01, -.30513100E-01, 0.10387800E-01, -.56213500E-02, -.18296700E-02, 0.11714000E-01, -.47229400E-04, -.80190400E-01, -.19001400E-02, 0.21194600E-01, -.17173900E-01, 0.46089900E-01, 0.40224600E-01, -.24994100E-02, -.19862500E-02, -.44833800E-03, -.10224400E-01, -.14860300E-03, 0.55747900E-01, -.16310900E-01, -.73537400E-01, 0.12809400E-01, 0.73077800E-01, 0.44749400E-01, -.25300900E-01, 0.33068800E-01, -.70638900E-01, 0.86770500E-02, -.26449500E-02, 0.55714400E-01, 0.38452900E-01, -.44622100E-01, 0.10832400E+00, 0.18552900E+00, 0.53409500E-02, -.27967400E-02, 0.63612800E-02, 0.22578500E-02, -.11320500E-02, 0.10910200E-02, 0.20477800E-01, -.18401100E-01, -.66765800E-02, -.38091700E-02, -.65427500E-02, 0.32904000E-01, -.54613200E-02, -.70213100E-02, 0.24720800E-02, 0.67364700E-02, -.15929400E-03, 0.10213000E-05, -.21551600E-02, 0.52125700E-02, -.33238100E-01, -.27825500E-01, 0.76789100E-02, -.80964000E-02, 0.34683200E-02, 0.12477000E-02, 0.11082600E-01, 0.89812000E-03, 0.99389300E-01, 0.18368400E-01, -.90566800E-02, 0.26400600E-02, -.13452200E-01, 0.19710700E-01, 0.30661300E-02, -.50830400E-02, 0.20307900E-03, 0.39898700E-01, 0.76098000E-02, 0.15652100E-01, 0.75151800E-02, 0.56244200E-02, -.23932400E-01, -.22525000E-01, -.49999500E-02, 0.95758800E-02, -.15998900E-02, -.57756100E-02, 0.62424700E-02, 0.54769400E-03, -.30470400E-02, 0.47481000E-01, -.28064200E-02, -.44553900E-01, 0.41841900E-01, 0.45069000E-01, 0.15237000E-02, -.67887000E-01, -.71894700E-01, 0.15158600E+00, -.67233600E-02, -.15383400E-03, -.52009900E-01, 0.80709000E-02, -.45763100E-02, 0.64367700E-02, -.66583700E-01, 0.32896100E-01, 0.52391000E-02, -.32152200E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.35703500E+01, 0.83269500E+00, 0.71235100E+00, -.88031100E+00, -.21182900E+01, 0.33394400E+00, 0.35716600E+00, -.14817700E+01, 0.25521000E+00, 0.61278100E+00, -.63734000E-01, -.11381500E+00, -.21331600E+00, -.90782900E+00, 0.47309100E-01, 0.19230600E+00, -.54433100E+00, -.63220100E+00, 0.12518900E+00, -.84751700E-01, -.50402500E+00, 0.62265100E+00, 0.16314300E+01, -.71190800E+00, -.11225000E-01, -.85145600E-01, -.29714100E-01, -.10417900E+00, 0.29860000E+00, 0.87867600E+00, -.80803200E-01, -.18649900E+00, 0.67645500E+00, -.61183400E-01, 0.64886500E-01, -.43277500E+00, 0.13440400E-01, -.10227500E+00, 0.23412500E+00, -.23400100E+00, -.52990600E+00, -.24248500E+00, -.57849000E-01, -.22807100E+00, 0.43666900E-01, 0.29366200E+00, 0.71356900E-01, 0.14369800E+00, -.73215300E-01, -.17122500E+00, 0.26878100E+00, 0.19785300E+00, 0.84619900E-01, -.11401100E+00, 0.13373900E+00, 0.67904700E-01, 0.23621200E-01, 0.55671300E+00, -.99288400E-03, -.23416500E+00, -.37447900E-01, -.20103000E+00, 0.78513700E-01, -.10323600E+00, 0.64402600E+00, 0.17268500E+00, -.36904700E+00, -.12448900E-01, -.10809800E+00, -.33085700E-02, 0.72034300E-01, -.46352400E-01, 0.60703300E-01, -.72558500E-02, 0.10774500E-01, 0.11382700E-01, 0.18972400E-01, -.90616900E-01, -.17127600E-02, 0.17941000E+00, 0.28950100E-03, 0.17866100E+00, -.18362200E+00, -.16595400E-01, 0.26464600E-01, 0.43200000E-01, 0.13087300E+00, -.82074200E-01, -.85638300E-01, 0.33499300E-01, 0.11588900E+00, 0.10568200E-01, 0.22562800E-01, -.19497500E+00, -.40906900E+00, -.27728600E+00, 0.15222400E+00, -.35757800E+00, -.38554800E-01, 0.15405200E+00, -.46383700E-01, -.45522500E-02, 0.46678100E-01, -.23620900E-01, 0.88009300E-02, 0.14730100E+00, -.26363400E-01, -.65124800E-01, -.15401800E+00, 0.11112000E+00, 0.35712100E-01, 0.36154500E-01, 0.41721600E-02, 0.22422200E-02, -.14072600E+00, -.12543000E+00, -.38993300E-02, 0.14952700E-01, -.38599000E-01, -.37426400E-01, 0.40345100E+00, -.21325400E+00, -.13020300E+00, 0.25856000E+00, 0.21638900E-03, -.15472700E+00, 0.98853500E-01, 0.25583300E+00, -.77701400E-01, -.13080000E-01, -.44917200E-01, -.45647900E-01, -.61643200E-01, 0.39318100E-01, -.55453600E+00, -.89508200E-03, -.20889500E+00, 0.45103200E+00, 0.48018300E-01, -.38380400E-01, -.30434000E-01, -.12946000E+00, 0.66497100E-01, -.27738800E-01, 0.25250600E-01, -.20057100E+00, -.17294900E-01, -.14384000E+00, -.30420100E+00, 0.48358000E-01, -.35759000E-02, -.12247100E+00, -.84055100E-01, -.12676700E-01, -.42631900E-01, -.32668500E-02, 0.59567500E+00, -.29586100E-01, -.30445300E+00, 0.12115200E+00, -.67648300E-01, 0.79649100E-01, -.15480500E+00, 0.31159600E-01, 0.12592100E+00, -.13892200E-01, -.24459900E-02, -.25221700E-01, 0.20570700E-01, -.67333700E-01, -.54999400E-01, 0.60000500E-02, 0.23657900E+00, -.51836800E-01, -.10354500E+00, -.23028500E-01, 0.96736000E-01, -.31596100E-01, -.69091500E-01, -.37674700E-04, 0.67278000E-01, 0.28046800E-01, -.11266900E-01, -.62789100E-01, 0.16767200E+00, -.36746800E-01, -.27124300E-01, -.21386900E-01, -.31987900E-01, -.12565800E-01, 0.49729700E-03, 0.10841300E+00, -.63372700E-01, -.33826100E-01, 0.42537500E-01, -.14796000E+00, -.96255500E-01, 0.23187700E-01, -.63723500E-01, 0.59152800E-01, -.10357200E+00, -.16743700E-01, 0.81682400E-01, -.34826900E-01, 0.10025400E-01, -.18341100E-01, 0.10087700E+00, 0.16158200E-01, 0.58476500E-01, -.25864000E-02, 0.30621600E-02, 0.32849800E-02, -.37156000E-02, -.10254800E+00, -.60667300E-02, 0.13745700E+00, -.22837200E-01, 0.37264900E-01, 0.29224800E+00, 0.22311200E+00, 0.12187300E-01, 0.31506400E-03, -.24135000E+00, 0.66067500E-03, 0.23055600E-02, 0.63024100E-01, 0.51968000E-01, -.58990800E-01, -.17020500E+00, -.35218700E-01, -.89924300E-01, -.13670500E-02, -.52164000E-02, -.12599900E-01, 0.68619100E-03, -.16721200E+00, -.47026100E-01, 0.10311100E-02, -.15524300E-01, 0.25209700E-01, -.34996900E-01, -.13573700E-02, -.21985400E-01, -.50721900E-03, -.32255500E-01, -.42849900E-01, -.37567200E-02, -.32883700E-02, 0.21740600E-01, -.79583800E-01, 0.10151400E-01, 0.13408700E-01, -.18350000E-01, -.35876700E-01, 0.26867000E-01, -.56790000E-01, 0.33485400E-01, -.71065800E-01, 0.21694900E+00, -.53111100E-01, 0.10729200E+01, 0.85983500E-01, 0.40870700E-01, 0.38407900E-01, -.48290100E+00, 0.10383700E+00, -.40183600E-01, 0.26055200E+00, -.10902600E-01, 0.18075800E-01, -.89992500E-01, 0.28338100E-02, 0.26602900E-01, -.16209200E-01, -.47377500E-01, 0.15711400E-01, -.62773400E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.38921900E+01, -.50755600E+00, -.16197300E+01, 0.29919800E+01, 0.29935800E+01, -.33389800E+00, -.52574800E+00, 0.20984300E+01, -.21792300E+00, -.15527600E+00, 0.60505700E+00, 0.58432500E+00, 0.18208200E+01, 0.28058000E+01, 0.18820600E-01, -.38298200E+00, 0.71384800E+00, 0.10699000E+01, 0.34793700E-01, -.12220800E+01, -.10202400E+01, -.18211500E+01, 0.50955400E+00, -.86329100E+00, 0.30042800E-01, 0.58191400E+00, -.21615900E+00, 0.40313800E+00, -.81432400E-02, 0.15950200E+01, -.11901200E+00, 0.12446200E+00, -.56282900E+00, 0.39112500E+00, -.12619600E+00, -.67800700E+00, -.85866900E-01, 0.14171700E+00, -.17902800E+00, 0.55556000E-01, 0.62142500E+00, 0.12108900E+01, -.98524400E+00, 0.47079900E+00, -.89109400E+00, 0.10771600E+01, 0.83162900E+00, -.35834800E+00, -.15874700E+00, 0.68865500E+00, -.20895400E+01, -.27496800E+00, -.45031900E+00, 0.28391800E+00, -.23946900E+00, 0.67393500E+00, -.27942300E+00, 0.74614900E+00, 0.48830700E-03, 0.29291300E+00, -.12510900E+00, 0.17526700E+01, -.41657000E+00, -.66649100E-01, 0.18025900E+01, 0.15275100E+00, 0.61383200E+00, -.17483700E+00, 0.57340400E+00, 0.61072400E-02, 0.33589100E+00, -.12536200E+00, 0.10707900E+00, -.61060100E+00, 0.62401800E+00, 0.11364400E+00, 0.52653500E+00, -.37025000E+00, 0.62379900E+00, 0.32494300E+00, -.13072400E-02, -.81439600E+00, 0.36288800E+00, 0.14435000E+01, 0.37463700E+00, 0.37510900E+00, -.72872100E+00, 0.25900200E+00, -.62023600E-01, -.34685100E+00, -.40405900E+00, 0.62941700E-02, 0.69373100E-01, -.46098400E+00, 0.88200500E+00, 0.10613100E+00, -.30167500E+00, -.16288100E+01, -.17731100E-01, 0.42838200E+00, -.55362600E+00, -.11298900E+00, -.27498800E+00, 0.41053800E-01, -.48791400E+00, 0.11516300E+00, 0.58038400E+00, -.66834300E-01, 0.72632600E+00, -.10697800E+00, 0.11189900E+00, -.97557500E-01, -.12553800E+00, -.33335700E-02, 0.45347800E+00, 0.59174400E+00, -.31645000E+00, 0.38006400E+00, -.17845500E-01, 0.26028400E+00, -.47004700E+00, 0.99198800E+00, 0.19186800E+01, -.10996200E+01, -.14633700E-02, 0.43575400E+00, -.42656000E+00, -.22148200E+01, 0.11652700E+00, -.20271100E+00, -.77454900E-01, 0.12926500E+00, 0.14131800E+00, -.72443900E-01, 0.28203400E+00, -.61389300E-02, 0.26979000E+00, -.12858100E+01, -.58859700E-01, 0.58173500E-01, -.42396400E-01, 0.17001000E+00, 0.88339600E-01, -.68044900E-01, 0.39376600E-02, 0.72815600E+00, 0.31666100E-01, 0.16705900E+00, 0.29280800E+00, 0.78665400E-01, -.39469200E-01, 0.27463800E+00, 0.23252800E+00, -.15500200E+00, -.59987200E-01, 0.17618700E-01, -.20578200E+01, 0.67409200E-01, 0.47814600E+00, 0.58537400E-01, 0.29175400E+00, -.47695200E+00, -.64764800E+00, -.33597600E-01, 0.29404600E+00, 0.27716500E+00, 0.94010400E-01, -.35346000E+00, -.31083800E-01, 0.97401100E-01, 0.20799600E+00, -.55719800E-01, -.73858900E+00, 0.33318900E+00, 0.98546700E+00, -.11904400E+00, -.15084200E+00, -.78431300E-03, -.14442800E+00, -.19188500E-02, 0.22746700E+00, 0.36127200E-01, -.19439100E+00, -.67419000E-01, -.19947500E+00, 0.68384200E-01, 0.78780600E-01, 0.97482100E-03, 0.77752200E-01, -.87010300E-01, -.77898700E-03, 0.12546800E+00, 0.28656700E+00, -.12066400E+01, -.86410200E-01, -.67203300E+00, 0.56603600E+00, -.34778200E-01, -.11108700E+00, 0.29075200E+00, -.71232700E-01, -.59910400E-02, 0.82827200E+00, 0.22440800E+00, -.38107500E+00, -.27655200E+00, 0.48025400E+00, -.50019200E-01, 0.14748700E-01, -.22643500E-01, 0.11012400E-01, -.49030300E-01, 0.42132600E-01, 0.14839800E+00, -.27222600E+00, 0.68216900E-01, -.24797600E-01, 0.12034300E-01, 0.79714800E+00, 0.45043000E+00, 0.13412200E+00, 0.10822000E-02, -.11846100E+00, -.33194800E-02, 0.48264700E-01, -.41772800E+00, -.35363400E-01, 0.69170600E+00, 0.68865700E-01, -.62339600E-01, 0.22765800E+00, -.20076100E-01, 0.22368800E-01, -.46788600E-01, -.51227900E-02, 0.41881800E+00, -.46879000E-01, 0.93981400E-01, -.85845700E-01, 0.13775400E+00, -.18929900E-01, 0.23270900E+00, 0.16606800E+00, 0.13076700E-01, -.43664200E+00, 0.12226300E+00, -.19921600E+00, 0.27309100E-01, -.19096200E+00, 0.11882800E+00, 0.51983300E+00, -.12552600E-01, -.60383100E-01, -.52901800E-01, 0.35543300E-01, -.26359800E+00, -.41938500E-01, -.16260000E+00, 0.28265500E+00, -.13937600E-01, 0.15547500E+00, -.21256100E+00, 0.10072800E+01, 0.88218300E-01, 0.37597700E+00, -.14400900E+00, -.60511700E+00, 0.67054600E+00, -.10894200E+00, -.25634500E+01, -.10426600E+00, 0.13383200E+00, 0.89175800E-01, -.12785700E+01, 0.66674200E+00, 0.32247600E+00, -.95743200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.29012900E+01, -.75575600E+00, -.26115700E+00, 0.39593700E+00, 0.17588300E+01, -.88425500E-01, -.33186600E+00, 0.10984100E+01, -.16620300E+00, -.49364300E+00, 0.11529000E+00, 0.20740700E+00, 0.25645300E+00, 0.56236700E+00, -.13347300E-01, -.13766300E+00, 0.47702400E+00, 0.34618300E+00, -.86822400E-01, 0.45045100E-01, 0.32857000E+00, -.90563700E+00, -.15152400E+01, 0.58992700E+00, -.52238100E-02, 0.30275000E+00, -.14306400E+00, -.93391600E-01, -.25326600E+00, -.22944300E+00, -.45001200E-01, 0.84404800E-01, -.57154200E+00, -.10910000E-01, -.54833300E-01, 0.25214600E+00, -.67554600E-02, 0.13003000E+00, -.40679700E-01, 0.29689900E+00, 0.53191700E+00, 0.16941700E+00, -.15740900E+00, 0.21969700E+00, -.15917400E-01, -.21386900E+00, 0.18766300E+00, -.55171600E-01, 0.66587300E-01, 0.11751200E-01, -.37393900E+00, -.22058300E+00, -.92871100E-01, 0.88276800E-01, -.58538800E-01, -.13276000E+00, -.61200900E-02, -.62684000E+00, 0.14882000E-02, 0.24655400E+00, 0.32589400E-01, 0.10874300E+00, -.76672400E-01, 0.90436400E-01, -.58724600E+00, -.28198800E-01, 0.35998500E+00, -.74457100E-01, 0.97268800E-01, 0.34315400E-02, -.86846500E-01, 0.77565800E-01, -.90785900E-01, 0.28100200E-01, 0.94086200E-02, -.13087400E-01, -.10702300E+00, 0.11395100E+00, -.12033300E+00, -.10104400E+00, -.19859900E-03, 0.76140600E-01, 0.28408500E-01, 0.60073600E+00, 0.32113800E-01, -.99416300E-01, 0.15563500E+00, 0.12122200E+00, 0.89514600E-01, -.99085000E-02, -.20195900E+00, -.14046500E-01, 0.86074500E-01, 0.17363800E+00, 0.31476900E+00, 0.21556600E+00, -.11793300E+00, 0.29929800E+00, -.30053200E-01, -.11354000E+00, 0.11843700E+00, 0.35050200E-01, -.29853800E-01, 0.63549900E-02, 0.64488200E-01, -.17607200E+00, 0.90206600E-01, -.45930500E-01, 0.25495300E+00, -.14935400E-02, 0.90392500E-01, -.24462900E-01, -.58728200E-02, -.21395100E-03, 0.99017900E-01, 0.23196000E+00, -.44044100E-01, 0.10229500E+00, 0.52785200E-01, -.33433700E-01, -.45581900E+00, 0.41082400E+00, 0.41782200E+00, -.41136200E+00, -.12975300E-02, 0.17482400E+00, -.57222500E-01, -.24507300E+00, 0.14694200E+00, -.18682900E-01, 0.36084500E-01, -.14535200E-02, 0.85947700E-01, -.28753100E-01, 0.45163700E+00, 0.16570700E-02, 0.10409100E+00, -.36050000E+00, -.54436500E-01, 0.32997500E-01, 0.53994900E-01, 0.13641100E+00, -.66238600E-01, 0.31676400E-01, -.13290800E+00, 0.21575400E+00, 0.23196800E-01, -.40863800E-01, 0.14588800E+00, -.50613100E-01, -.31300600E-01, 0.74481700E-01, 0.28512000E+00, 0.17048000E-01, 0.62191000E-02, -.17181500E-02, -.59058800E+00, 0.37385300E-01, 0.35417300E+00, -.91764800E-01, 0.43241600E-01, -.68221300E-01, 0.21009700E+00, -.38833700E-02, -.22629200E+00, 0.38144100E-02, -.66028200E-02, 0.34921000E-02, -.12682000E-01, -.52371600E-01, 0.48400400E-01, -.37964200E-02, -.97438400E-01, 0.50530500E-01, 0.57598600E-01, 0.13141400E-01, -.54438400E-01, 0.18544300E-01, 0.22003500E-01, -.76083700E-03, 0.95766200E-01, -.68128800E-01, -.38030500E-01, 0.20832000E-01, -.62274200E-01, -.28347100E-01, 0.11004500E-01, 0.21331000E-02, 0.27020900E-01, 0.68036800E-03, -.11210900E-02, -.24997300E+00, 0.29077800E-01, 0.14567900E+00, -.28342100E-01, 0.20883200E-01, 0.86609200E-01, 0.19987800E-02, 0.91252700E-01, -.42191300E-02, 0.10263700E+00, 0.19021700E-01, 0.25010700E-01, -.35173900E-02, -.83548100E-01, -.10343300E+00, -.25879800E+00, 0.28411200E-01, -.24341400E-01, -.68439600E-01, -.29266900E-02, 0.37974000E-03, -.43074600E-03, 0.26473600E+00, -.69772400E-01, -.13860000E+00, -.75468900E-02, -.48849100E-01, -.23051100E+00, -.36655500E+00, -.13649400E-01, -.60523200E-04, 0.50059000E+00, -.58323200E-03, -.12476700E-01, -.20309100E+00, -.71398200E-01, -.65972800E-01, 0.25785100E+00, 0.81699200E-01, 0.15061500E+00, -.27321700E-01, 0.44112600E-02, 0.29987200E-01, 0.99448400E-03, 0.31186900E+00, 0.10925700E+00, -.10149200E+00, 0.39090100E-01, -.13032100E+00, 0.88128500E-01, 0.16988600E-02, -.13275700E-01, 0.50475500E-02, 0.14278300E+00, 0.24690000E-01, 0.75918800E-01, 0.15148400E-01, 0.21717900E-01, -.71106500E-01, 0.12829600E-01, -.22525900E-01, 0.28955700E-01, 0.56509400E-01, -.58952000E-01, 0.16001200E+00, -.19743200E-01, 0.14977400E+00, -.25683000E+00, 0.60911300E-01, -.15611000E+01, -.17353500E+00, -.75481600E+00, -.53509200E-01, 0.62382200E+00, -.45340100E+00, -.89853100E-03, -.48840900E-01, -.50950000E+00, -.12961500E+01, -.14657400E-01, 0.68972600E-01, 0.34979500E-01, -.65458000E+00, 0.34515400E+00, 0.14586400E+00, -.32846000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.23496300E+01, -.76657500E+00, 0.39842000E+00, -.31268900E+00, 0.14328900E+01, -.48116000E+00, -.23452700E+00, 0.14806600E+01, -.22485500E+00, -.56793200E+00, 0.74896600E+00, 0.66255400E+00, 0.13511400E+01, 0.11314900E+01, -.18754700E+00, -.17281000E+00, 0.57192100E+00, 0.41013600E+00, -.30374600E-01, -.17307500E+00, 0.55542300E+00, -.58342300E+00, -.87362400E+00, 0.51547200E+00, -.17265700E-02, 0.27085400E+00, -.83888900E-01, -.88709200E-01, -.72715100E-01, -.10974600E+01, 0.80202500E-01, 0.15414800E+00, -.64225800E+00, 0.28061700E-01, -.62492000E-01, 0.46319700E+00, -.19391300E-01, -.16539600E-01, -.12890800E+00, 0.22457700E+00, 0.45785100E+00, 0.39531400E+00, 0.80579900E-02, 0.10768000E+00, -.13913700E+00, -.32640000E-01, 0.19099200E+00, -.12774900E+00, 0.92560900E-01, 0.12851000E+00, -.34557100E+00, -.35161900E+00, -.75144400E-01, 0.88640200E-01, 0.55757200E-01, 0.20422400E+00, -.11931600E-01, 0.87197900E-01, 0.79331600E-03, 0.17992300E+00, -.15673300E-01, 0.19379000E+00, -.31007900E-01, 0.49553500E-01, -.65248200E+00, -.10383900E+00, 0.25115200E+00, -.53940900E-01, 0.92948600E-01, 0.22243100E-02, -.56694500E-01, -.27214800E-01, -.17815200E+00, 0.43994700E-01, -.57723100E-01, -.12201500E-01, -.62497000E-01, -.75469300E-01, -.19690400E+00, -.14657100E+00, -.65151900E-03, 0.69174900E-01, -.57438700E-01, 0.23451500E+00, -.45395100E-01, 0.21080600E-01, -.10155300E+00, 0.44288900E-01, 0.13422500E+00, -.12360300E-01, -.16318100E+00, 0.72501200E-03, 0.64319500E-01, 0.34431800E+00, 0.17014000E+00, 0.90566200E-01, -.10841900E+00, 0.96811300E+00, -.88938500E-01, -.24416300E+00, 0.10995100E+00, 0.22981200E-04, -.42041500E-01, 0.10434500E-01, -.63709600E-01, -.31126900E-01, 0.46813100E-01, 0.53065500E-01, -.82539200E-01, -.21340900E-01, -.68022300E-01, -.19946100E-01, -.53056100E-02, -.59204000E-03, 0.14026400E-01, 0.18707200E+00, -.61329300E-01, -.25992900E-01, 0.87868300E-01, -.19920400E+00, -.55414500E+00, 0.38254200E+00, 0.33571700E+00, -.61975300E+00, 0.12173500E-02, 0.12819800E+00, -.14062800E+00, -.48596700E+00, 0.10579200E+00, 0.20497500E-01, 0.91932900E-02, -.19379900E-01, 0.11823200E+00, -.15742400E-01, 0.64721900E+00, 0.53795800E-03, 0.11764800E+00, -.45603900E+00, -.45608200E-01, 0.15615100E-02, 0.20909700E-01, 0.11672500E+00, -.51500000E-01, 0.44671600E-01, 0.14135700E+00, 0.15591900E+00, 0.21720800E-01, 0.22893400E+00, 0.25269300E+00, 0.20249300E-01, 0.35674500E-01, 0.61194600E-01, -.84980500E-01, -.67160000E-01, 0.48043100E-01, 0.23349100E-01, -.34892100E+00, 0.20507500E-01, 0.13007800E+00, -.34324800E-01, 0.48589000E-01, -.45033700E-01, 0.11742200E+00, -.46520700E-01, 0.15813600E+00, 0.28900300E-02, 0.13855700E-01, 0.53711900E-01, -.10490100E-01, 0.69881500E-01, 0.12288200E-01, -.10632700E-01, -.14129400E+00, 0.82503200E-01, 0.42525300E-01, 0.30001700E-01, -.60652900E-01, 0.19772600E-01, 0.42427500E-01, 0.47877700E-04, -.23898300E+00, 0.54231600E-01, -.27707700E-01, 0.15571900E-01, 0.78514500E-02, 0.16448400E+00, 0.67432100E-01, -.12971500E-01, -.29296700E-02, -.45226000E-01, 0.72031700E-03, 0.70577800E-01, 0.79693900E-01, 0.17267500E+00, -.75165900E-01, 0.10035500E+00, 0.25015000E-01, -.14716100E-01, 0.21955900E-01, 0.69908600E-03, 0.11544400E+00, 0.14196800E-01, -.23500400E+00, 0.44332600E-01, 0.86592900E-01, -.91194000E-02, -.91246300E-01, -.74057100E-02, -.23100100E-01, -.90043000E-02, -.72349300E-02, -.95543000E-02, 0.10459200E-01, -.12920000E+00, -.76134200E-01, -.18318800E+00, 0.58381900E-01, -.81613000E-01, -.48982300E+00, -.22846200E+00, -.75495200E-01, -.96707800E-02, 0.57440400E-01, -.11491600E-02, 0.32205900E-01, 0.12662400E+00, -.41924400E-01, 0.81160300E-01, 0.77275200E-01, 0.58221100E-02, -.46656300E-02, 0.19636300E-01, 0.74997000E-02, -.33547700E-01, -.27697400E-02, -.90814000E-01, -.29088300E-01, 0.70838400E-01, -.30680200E-01, 0.92859400E-01, -.27587800E-01, 0.46206100E-01, 0.39154000E-01, -.10590500E-02, -.12553300E-01, 0.30066300E-01, -.89402900E-02, -.43882000E-01, 0.26304300E-01, 0.16945000E-01, -.23882800E+00, 0.75486800E-02, 0.13350000E-01, 0.40735700E-01, -.56455600E-03, 0.11098600E+00, -.19952600E-01, 0.10238100E+00, -.13109200E+00, 0.45903100E-01, -.10964600E+01, -.89989400E-01, -.20911900E+00, -.34475000E-01, 0.53933200E+00, -.15605300E+00, 0.18125100E-01, -.31490200E+00, -.33016700E+00, 0.67506600E+00, 0.13220700E+00, -.57402200E-02, -.93674400E-02, -.97919700E-02, 0.49264500E-01, -.20193800E-01, 0.27746400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.14442100E+01, -.63540100E-01, -.21211900E+00, -.31217700E+00, 0.19529300E+00, 0.70623500E-01, -.52103600E-01, -.37762000E-01, 0.14173400E+00, -.25494500E+00, -.31140000E+00, -.26039800E-01, -.11568700E+00, -.47835500E+00, 0.53119200E-01, -.86961500E-02, -.73740000E-01, -.36576800E-01, -.16843500E+00, 0.71998200E+00, -.24555800E+00, -.23400000E+00, -.12586300E+00, -.36184800E-01, 0.15202900E-01, 0.97445100E-01, 0.48350800E-02, 0.18975200E-01, -.18629700E-01, 0.28842700E+00, -.18646000E-01, -.17141000E-01, 0.55767100E-01, 0.39851900E-01, -.44753100E-03, -.57955600E-01, -.71147200E-03, -.78346800E-01, 0.77073100E-04, 0.29229300E-01, -.37254600E-01, 0.82852200E-01, -.28021000E+00, 0.62975500E-01, -.12406900E+00, 0.34020700E-01, 0.41003900E-01, 0.11962400E-01, 0.55938300E-02, -.15336700E-01, -.28607100E+00, -.12332600E+00, -.32333300E-01, 0.57391900E-01, 0.35884500E-01, -.60897500E-02, -.36724500E-01, 0.16032800E-01, 0.21129400E-03, -.89968500E-01, -.18302700E-01, 0.10923200E+00, -.32836400E-01, 0.31966700E-01, 0.10664600E+00, 0.97172900E-01, 0.35938200E-01, -.16604800E+00, 0.46773300E-01, 0.49257800E-03, -.23596400E-02, -.57979500E-01, 0.13627100E-01, 0.35247000E-02, 0.10111100E-01, -.65217200E-02, 0.73086700E-02, -.11648200E-01, 0.82143900E-01, -.55847600E-02, -.11849200E-03, -.11597800E+00, -.15941300E-01, -.49800300E-01, -.14212700E-02, -.78819300E-03, -.59312400E-01, 0.54812200E-02, -.32795600E-01, 0.39371400E-02, -.11779500E-01, -.29505900E-02, -.72428600E-01, -.35762400E-01, -.12003600E+00, 0.42376800E-01, -.24443000E-01, 0.33775600E-01, 0.39865400E-01, 0.13132100E-02, -.59763600E-01, -.17180200E-01, 0.10056400E-02, 0.14935900E-01, -.13010800E-01, -.29671600E-01, 0.40392400E-01, 0.20135700E-01, 0.10423800E+00, 0.23671200E-01, -.42133400E-02, -.70741700E-02, 0.11444100E-01, 0.58867600E-03, 0.63092400E-01, -.27093300E-01, 0.21914900E-01, -.27918000E-01, 0.12237100E-01, 0.45506200E-01, -.11656500E-01, -.15149000E+00, -.15913700E+00, -.97984600E-01, -.10651200E-02, -.33326500E-01, 0.37329100E-01, 0.34218500E-01, -.22617900E-01, -.58886400E-03, 0.16713800E-01, -.48265400E-02, -.19142800E-01, 0.18762200E-02, -.18433800E-01, 0.17462200E-03, 0.58122900E-02, 0.67703000E-01, -.33819300E-02, 0.21031700E-02, 0.20218300E-01, 0.12070000E-01, -.17253800E-01, 0.87457800E-02, -.54134500E-01, 0.12686100E-02, 0.22669600E-02, -.70110900E-01, 0.19613500E-02, 0.31178000E-01, 0.20729400E-02, -.11185100E-01, -.75566600E-01, -.23595400E-01, -.51763500E-01, -.13286100E-02, 0.76388000E-02, -.31183700E-02, 0.84317400E-02, 0.30042400E-03, -.28972900E-01, -.26270400E-01, 0.60669800E-01, -.28424200E-02, 0.60688900E-01, 0.14237600E-01, 0.67535800E-02, 0.56476000E-02, 0.53780400E-03, 0.39201700E-01, 0.17784200E-01, -.79874200E-01, 0.12463300E+00, 0.23555100E-01, 0.86904400E-02, 0.38160600E-02, -.26766100E-02, -.78565400E-02, -.12201500E-01, -.56912600E-03, -.98353700E-02, 0.36485900E-01, -.98962300E-02, -.56765200E-01, 0.10094700E+00, 0.35900000E-01, 0.26117100E-01, -.58269200E-02, -.13868500E-01, 0.27187200E-01, -.85069600E-03, 0.57906000E-02, -.67734400E-01, 0.18980400E+00, -.65274400E-01, -.70138500E-01, 0.91896000E-01, -.14284900E-01, 0.97885600E-02, 0.27928000E-01, -.53734300E-02, -.37322600E-02, 0.11967600E+00, 0.36415700E-01, -.54661200E-01, -.18698900E-01, 0.12302300E+00, 0.26500800E-02, 0.11390100E-01, -.86680600E-02, -.11311000E-02, -.40535200E-02, 0.33579800E-02, -.36077500E-02, -.15402600E-01, 0.20207800E-02, 0.45136800E-03, 0.31608800E-02, 0.56138700E-01, 0.25308500E-01, 0.98142700E-02, -.23011100E-02, -.86126000E-02, -.24509900E-03, 0.45663100E-02, -.30107500E-01, 0.12273900E-02, 0.41075300E-01, -.16203100E-01, 0.32125300E-02, 0.12887400E-01, -.15534400E-02, 0.17688400E-02, -.84843300E-02, -.11767000E-02, 0.17905000E-02, -.87896900E-02, 0.75797700E-02, -.66987700E-02, 0.12415100E-01, -.33394600E-02, 0.17015600E-01, 0.12439500E-01, 0.83390400E-03, -.30381700E-01, 0.77405500E-02, -.12237900E-01, -.29757400E-02, -.11498900E-01, 0.88867300E-02, 0.62105900E-02, 0.51460700E-03, -.36758800E-02, -.26769100E-02, 0.34238200E-02, -.10931800E-01, -.86092300E-03, -.82477700E-02, 0.56124900E-03, -.30638500E-02, 0.65217500E-02, -.57389600E-01, 0.76515100E-01, 0.67846600E-02, 0.39453800E-02, -.45510100E-01, 0.45445900E+00, 0.82117300E-01, 0.71213100E-01, -.84907400E-02, 0.53614700E-02, -.89055600E-01, -.11680800E-01, -.43865300E-02, 0.99416800E-02, -.15603300E-01, 0.73103500E-03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.31959800E+01, 0.49914800E+00, 0.54954900E+00, -.81060100E+00, -.17511100E+01, 0.81241700E-02, 0.30991600E+00, -.93533000E+00, 0.12217300E+00, 0.40057100E+00, 0.25813900E+00, -.65076700E-01, -.15542800E+00, -.78284700E+00, -.31726400E-01, 0.16723000E+00, -.49591600E+00, -.53190200E+00, 0.75927400E-01, -.15304100E+00, -.12166300E+00, 0.10463500E+01, 0.17833500E+01, -.66701300E+00, 0.13289600E-02, -.20994600E+00, 0.64041300E-01, -.13297700E-02, 0.33063700E+00, 0.21879600E+00, 0.43657800E-02, -.14461700E+00, 0.59647600E+00, 0.68228800E-02, 0.75263500E-01, -.36880600E+00, 0.88412300E-02, -.21609000E+00, 0.54600100E-01, -.29562800E+00, -.61353700E+00, -.24552300E+00, 0.42855100E+00, -.31221600E+00, 0.22048000E+00, 0.15951600E+00, 0.71583000E-01, 0.73078800E-01, -.38098700E-01, -.18677400E+00, 0.32707900E+00, 0.11208000E+00, 0.81976000E-01, -.97184100E-01, 0.18533000E+00, 0.21009700E+00, -.52283700E-02, 0.74859200E+00, -.94666800E-03, -.23154800E+00, 0.95270100E-01, -.16292200E+00, 0.12923200E+00, -.16903900E+00, 0.89468200E+00, 0.14984900E+00, -.50024100E+00, 0.63351200E-02, -.14319400E+00, -.24805500E-02, 0.52610800E-01, -.21588600E-01, -.23893400E-01, -.10702500E-01, -.95960000E-01, 0.41707100E-01, 0.12383100E+00, -.61224500E-01, 0.43515200E-01, 0.12169500E+00, -.49606000E-04, 0.24423700E-01, -.16328600E+00, -.25559000E+00, -.10034100E-01, 0.10792900E+00, 0.18513400E-01, -.75511500E-01, -.78069100E-03, 0.15878800E-01, 0.17134000E+00, 0.92066100E-02, 0.69847100E-01, 0.17287500E+00, -.19078200E+00, -.39342000E-01, 0.82457800E-01, -.16480500E+00, 0.51173800E-01, -.29783600E-01, 0.16024300E+00, 0.10432500E-01, 0.48530600E-01, 0.56573800E-01, 0.69976900E-03, -.46497600E-01, -.19228800E+00, -.51231500E-01, -.20820700E+00, 0.90145300E-01, -.82060100E-01, 0.46072500E-02, 0.22539100E-01, 0.20593800E-02, -.23511000E-01, -.72428800E-02, -.87678700E-01, 0.83042600E-02, -.52510800E-02, -.22516100E+00, 0.34768200E+00, -.25876800E+00, -.93917700E-01, -.78676300E-01, -.47019000E-04, -.17108400E+00, 0.89566100E-01, 0.37468000E-01, -.71177600E-01, 0.23619600E-01, -.78263700E-01, -.52248100E-01, -.11270300E-01, 0.27871500E-01, -.21037700E+00, -.83745000E-03, -.47022200E-01, 0.32374600E+00, 0.25810400E-01, -.26388400E-01, -.19973000E-01, -.60279000E-01, 0.64976400E-01, -.10065000E-01, 0.14392000E-01, -.16166100E+00, -.13886000E-01, 0.23437100E-01, -.18445500E+00, 0.74153200E-04, 0.39299000E-01, -.50208300E-01, -.28329800E+00, -.55004400E-01, -.12252300E-01, 0.62762900E-02, 0.56345500E+00, -.22359500E-01, -.61095200E+00, 0.12778500E+00, -.40884800E-01, -.81729000E-02, -.62774200E-01, 0.28162100E-01, 0.25660500E+00, 0.10768100E-01, 0.28553800E-01, 0.21435200E-01, 0.11906700E-01, 0.51333200E-01, -.44493600E-01, -.40263200E-01, 0.10780600E+00, 0.13956300E-01, 0.39589700E-01, -.16266500E-01, 0.70727600E-01, -.20133000E-01, -.20991700E-01, -.10518400E-03, -.11553600E+00, 0.14728900E+00, 0.37785100E-01, -.16247900E+00, 0.33422200E+00, 0.16211700E+00, -.11388000E-01, -.13265100E-01, -.59860900E-01, -.18810800E-01, 0.41025500E-03, -.15364300E-01, -.64454900E-01, 0.28930800E+00, -.73241100E-01, -.71301600E-01, 0.50871300E-01, 0.17108300E-01, -.14813700E-01, 0.52363900E-01, -.11670400E+00, -.23517000E-01, 0.13916400E+00, -.13176500E-01, 0.28544800E-02, -.16701100E+00, 0.10349300E+00, 0.60191200E-01, 0.17207800E+00, -.58887600E-01, -.21752000E-02, -.43060500E-02, 0.32973100E-02, -.31996900E+00, 0.16880900E+00, 0.21729800E+00, -.11589700E-01, 0.19544300E+00, 0.32622900E-01, 0.30060200E+00, -.16842300E-01, -.18368500E-02, -.41382600E+00, 0.14112300E-02, 0.28592200E-01, 0.18168900E+00, 0.70234700E-01, 0.12123500E-01, -.21607200E+00, -.80530000E-01, -.12619500E+00, 0.45612900E-01, -.36649400E-02, -.25854700E-01, -.26820900E-02, -.18658500E+00, -.48243000E-01, 0.65388200E-01, -.20857900E-01, 0.13794200E+00, -.81431200E-01, 0.69187200E-02, 0.64400200E-02, -.49436800E-03, -.15154800E+00, -.40042700E-01, -.53867900E-01, -.64753100E-01, 0.31268700E-01, -.99082000E-01, -.98050800E-01, 0.23967200E-01, -.26847600E-01, -.36195000E-01, 0.38920200E-01, -.79954300E-02, 0.20296100E-01, -.11359500E-01, -.60868800E-01, -.28487900E-01, 0.54424900E+00, 0.21426500E+00, -.22304800E+00, 0.20349100E-01, -.86843100E-01, 0.24060000E+00, 0.22820300E-03, 0.67728200E-01, 0.85035200E-01, -.18420600E+00, -.49585000E-01, -.99701700E-01, 0.19184000E+00, 0.48418200E-02, -.14245700E-01, 0.16417300E+00, -.45061300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.19456300E+02, -.32987700E+01, -.46762200E+01, 0.44203900E+01, 0.14464100E+02, -.10943300E+01, -.23865800E+01, 0.87676600E+01, -.97203100E+00, -.34664700E+01, -.40117400E+01, -.54185400E+00, 0.41059700E+01, 0.51001400E+01, 0.16329300E+01, -.13359000E+01, 0.28882800E+01, 0.70662600E+00, -.54481900E+00, 0.51001700E+01, -.87796300E+01, -.16905600E+02, -.93781900E+01, 0.16560800E+01, 0.52593600E-01, 0.41759600E+01, -.14137500E+01, -.75023100E+00, -.13199200E+01, 0.65578300E+01, 0.22819000E+00, 0.90734500E+00, -.34256000E+01, 0.10867800E+01, -.42470900E+00, 0.33661600E+01, -.37613000E-01, 0.60796700E+00, -.53129000E+00, 0.22943700E+01, 0.37777700E+01, 0.39415200E+01, -.49811600E+01, 0.29722100E+01, -.38792000E+01, -.69119100E+00, 0.32196100E+01, 0.26593600E+00, 0.86389400E+00, 0.26893100E+01, -.85716800E+01, -.18757600E+01, -.15028800E+01, 0.15038300E+01, -.90881400E+00, -.17012800E+01, 0.22659100E+00, -.68833400E+01, 0.11954700E-01, -.12882900E+01, -.18543600E+01, 0.11566200E+01, -.10256600E+01, 0.30145900E+01, -.19653300E+01, 0.16324300E+01, 0.51478900E+01, 0.16882900E+01, 0.23658800E+01, 0.91225000E-02, -.13431000E+00, -.25335200E+00, 0.17792100E+00, -.11612500E+01, -.83457300E+00, 0.15640600E+00, -.13944000E+00, 0.96952300E+00, -.12637500E+01, 0.40254400E+00, -.26395500E-02, -.10140100E+01, -.14714800E+01, 0.21525200E+01, 0.77304500E+00, -.95818200E+00, 0.59070100E-01, 0.34347700E+00, -.15818200E+01, 0.66998000E+00, -.67037200E+00, -.26040500E-01, -.67495900E+00, 0.13979300E+01, 0.96459000E+00, 0.35950700E+01, -.19149300E+01, -.71443200E+01, 0.18705100E+01, 0.67995400E+00, -.41382100E+00, 0.16114600E-01, -.89866200E-01, 0.10534700E+01, -.11124100E+01, 0.69198400E-01, 0.60298900E+00, 0.38758100E+00, 0.39453400E+01, 0.95661000E+00, -.52810600E+00, -.61446300E-01, -.24087900E+00, 0.15740100E-01, 0.88260700E+00, -.53415500E+00, 0.67044700E+00, -.59928800E-01, 0.20817000E+00, 0.15670900E+00, -.15698000E+01, 0.14401300E+01, 0.39456100E+01, -.26015300E+01, -.10754600E-01, 0.64295200E+00, 0.54087800E+00, -.12958600E+00, 0.91403100E+00, 0.34045500E+00, 0.15412000E+01, -.36671900E+00, -.45562200E+00, -.38983100E+00, 0.19203000E+01, 0.16559300E-01, 0.30953200E+00, 0.22572400E+01, -.30243300E+00, 0.48924500E-01, 0.12893400E+01, 0.13483300E+01, -.47249900E-01, -.46530900E+00, -.22015600E+01, -.99121100E+00, 0.40291300E-02, -.33448800E+01, -.13527300E+01, -.35128300E-04, -.65906500E-01, 0.46322900E+00, 0.14031000E+01, 0.58138100E+00, 0.19854800E+00, -.49243100E-01, 0.45485100E+01, 0.52642100E-01, 0.13837700E+01, -.15317300E+01, -.32667800E+00, -.13042400E+00, 0.54987100E+00, 0.52445100E+00, -.55179100E+01, 0.49336600E+00, -.29818100E-01, -.16538400E+01, 0.16848500E+00, 0.82796300E+00, 0.22497600E+00, -.36997000E+00, -.32569000E+01, 0.69998400E+00, 0.30534700E+01, -.91258000E+00, -.92576100E+00, 0.42094000E+00, -.94185500E+00, -.83822200E-02, 0.28602400E+01, 0.69818600E+00, -.13601700E+01, 0.87104900E+00, -.35108800E+00, -.71318500E+00, 0.94516100E-01, 0.16907900E-01, 0.96753000E+00, 0.48711600E+00, -.16578800E-01, 0.16287200E+01, -.10616400E+01, -.12456000E+01, -.24522500E+00, -.20213600E+01, 0.11056100E+01, -.55095000E+00, -.50527900E+00, 0.20316900E+01, 0.34165600E+00, -.70672200E-01, -.20756200E+01, 0.44571900E+00, 0.11472200E+01, 0.12451200E+00, -.19583000E+00, -.21327800E+01, -.12817400E+01, 0.58181400E-01, -.74854900E-01, -.12756100E+00, 0.10058800E+00, -.28902300E+00, -.19032700E+00, 0.61158900E+00, 0.78297900E-01, -.35671900E+00, -.13013000E+01, 0.17222600E+01, 0.22025400E+00, -.53850300E-01, -.11621100E+01, -.10060300E-01, 0.70090600E+00, -.17176600E+01, 0.68005300E+00, 0.31243100E+01, -.93494900E+00, 0.25498500E+00, 0.20702200E+00, 0.11404600E+00, -.36301700E-01, -.78521500E+00, -.16093600E+00, -.16659400E+01, -.57374500E+00, 0.27044800E+00, -.11660000E+00, 0.12119200E+01, -.41004300E+00, 0.11516700E+01, 0.82367100E+00, 0.34079100E-01, -.97254500E+00, 0.10656800E+01, -.41225800E+00, -.19213000E+00, -.60826000E+00, 0.12256700E+01, 0.27637000E+01, 0.63519100E-01, -.48617600E+00, -.22227500E+00, -.21750400E+00, -.81769700E+00, -.19349900E+00, -.56390500E+00, -.43554400E+01, 0.32095900E+00, -.60140400E-01, 0.19929900E+01, -.36131100E+00, -.25870900E+00, 0.29170300E+01, 0.19442200E+01, 0.10209500E+01, 0.27616400E+01, -.14285000E+00, -.52050600E+00, -.19080100E+01, -.33948500E+01, -.35883700E+01, 0.95132000E+01, -.92985700E+00, 0.25358900E+00, -.26237000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.40874300E+01, -.16647700E+00, 0.11582300E+01, -.22899200E+01, -.14593700E+01, -.29096700E+00, 0.39178600E+00, -.72575100E+00, -.58851200E-01, 0.59020900E+00, -.39093400E+00, -.23714100E-01, 0.16056700E+01, 0.14825500E+01, 0.17741500E-01, 0.31352700E+00, -.18684300E+00, 0.38330400E+00, 0.22878500E+00, -.19411500E+01, 0.23247800E+00, 0.24124100E+01, 0.45616400E+00, -.17594900E+00, 0.16801000E+00, -.54145800E+00, -.14284500E+00, 0.56398900E+00, 0.32785900E+00, 0.16950300E+01, 0.29653900E+00, -.58875400E+00, 0.22370400E+00, -.76394400E+00, 0.13790000E+00, -.14998600E+01, -.42695200E-01, -.94130000E+00, 0.38135000E+00, -.13307200E+00, 0.55344300E+00, -.25865800E+00, -.21102800E+01, -.32234300E-01, -.11694500E+00, 0.98352200E-01, 0.25962800E+00, -.10060100E+01, -.83981100E+00, -.48952300E+00, 0.11829500E+01, 0.11008800E+01, 0.15778700E+00, -.29884600E-01, 0.28641500E+00, -.40573200E+00, -.57823100E-01, -.64474500E+00, -.40728800E-03, 0.21413300E+00, 0.40079200E+00, 0.15490300E+00, -.50391200E-01, 0.83599000E-01, -.38152600E-01, -.72067900E-01, -.36954300E+00, 0.68913700E+00, -.13262100E+00, 0.17226700E-02, 0.16674900E+00, 0.18386700E+00, 0.52471100E+00, -.50313600E-01, 0.96910000E+00, -.16239700E+00, -.39971000E+00, -.84664900E+00, 0.28100900E+00, 0.54647500E+00, 0.12425500E-02, 0.12626800E+01, -.14675300E+00, -.50508200E-02, 0.28153600E-01, -.95490800E+00, 0.83774800E+00, 0.11738200E+00, -.21720700E+00, 0.14751000E+00, 0.15748900E+00, 0.17320900E-02, -.33463700E-01, -.10482900E+01, -.61089700E+00, -.12324400E+01, 0.16501300E+00, -.87256200E+00, -.91588700E+00, 0.51229100E+00, -.58032500E+00, 0.28014700E-01, -.21662100E+00, -.10445900E+00, 0.36335700E+00, 0.11847500E+01, 0.18783100E+01, 0.14665500E+00, 0.67594500E+00, -.15328000E+00, 0.95676300E+00, 0.78429400E-01, 0.64956900E-01, -.39459800E-02, -.33553700E+00, -.18034100E+00, -.82449400E-01, -.73218100E-01, -.16810800E+00, 0.12045500E+01, 0.74116400E+00, -.11170500E+00, -.12133500E-01, 0.30677400E+01, 0.99111600E-02, 0.40522100E+00, -.34862300E+00, -.22893200E+00, -.41142100E-01, 0.14743200E+00, 0.68017600E+00, 0.14770800E+00, -.22988800E+00, 0.10293600E-01, -.41200200E+00, -.33771700E-02, 0.46467500E-01, 0.49803200E+00, 0.54223300E-01, 0.32312400E-01, -.68246100E-01, -.12514500E+00, 0.67536700E-01, -.18809700E+00, 0.13780100E+00, -.27843800E+00, -.30373700E-01, 0.10404700E+01, -.30732200E+00, -.37413100E+00, 0.11941500E+00, 0.73866600E-01, -.29494700E+00, -.92980700E-01, -.10028900E+00, 0.41766600E-01, -.10233200E+01, -.10659000E-01, -.11491700E+01, 0.22552400E+00, 0.13057500E+00, 0.54793200E-02, 0.78595900E+00, 0.19199200E+00, 0.12991500E+01, -.13408600E+00, 0.63582100E-01, 0.57560600E-01, 0.19350200E-01, 0.27169700E+00, -.34673600E+00, 0.34449800E+00, -.15079900E+00, -.14122500E+00, 0.26472000E+00, -.66112100E-01, -.18261200E+00, -.72138200E-02, -.53947400E-01, -.33306000E-03, 0.24404200E+00, 0.45598200E-01, 0.38274000E-01, 0.29191800E-01, 0.19035600E+00, -.18823700E+00, -.14018300E+00, -.65227500E-01, 0.10119600E-01, -.17329900E+00, 0.11718800E-02, 0.18144300E+00, -.29168400E+00, -.48455000E+00, 0.15904000E+00, 0.33380100E+00, -.19611200E+00, 0.66942800E-01, 0.20791200E+00, 0.10440200E+00, 0.21302600E+00, -.40641900E-02, -.58292100E+00, -.18060200E+00, -.77053000E-01, 0.34012500E+00, 0.24750200E+00, -.67580000E-01, 0.11154000E-01, 0.69092200E-01, -.14404600E-01, 0.18582400E-01, -.36251000E-02, 0.29798800E+00, -.20986300E-02, 0.47820100E+00, -.20063600E+00, 0.13771000E+00, 0.87335400E+00, 0.37119200E+00, 0.55949700E-01, 0.76891800E-02, 0.53637800E+00, 0.25563100E-02, -.15406600E-02, -.31497800E+00, 0.15939400E+00, -.42561700E+00, 0.53413600E+00, -.16148200E+00, 0.93921600E-01, -.59072000E-01, -.37661800E-02, -.38896300E-01, -.50056300E-02, 0.48064800E-01, 0.18102400E+00, -.77259700E-02, 0.33181600E-02, -.99661100E-02, 0.25423100E+00, 0.17610500E+00, 0.10796400E+00, -.97734800E-02, 0.50472000E-01, 0.13255400E+00, -.23293800E-01, -.17606000E-01, 0.12513700E-01, 0.26114300E-01, -.58501300E+00, 0.50933500E-01, 0.29494100E-01, -.62246500E-02, 0.13111500E+00, -.36403900E-01, -.32739800E-01, -.50166500E-01, -.16767300E+01, 0.45383900E-01, 0.48057900E+00, -.35532000E+00, 0.43647900E+00, -.43276700E-01, 0.16511800E+00, 0.53834100E+00, -.10483500E+01, 0.10011900E+01, 0.31443300E+00, -.12502900E+00, 0.11575800E+01, 0.20504300E+01, -.87508100E+00, -.10284100E-04, 0.20038900E+01, -.14849200E+00, 0.60313300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.30366800E+01, 0.34865400E+00, 0.46131500E+00, -.80719800E+00, -.16301300E+01, -.17827800E+00, 0.31241100E+00, -.78578100E+00, -.43151500E-02, 0.32351600E+00, 0.16062800E+00, -.15716000E+00, -.67037500E-01, -.57226600E+00, -.11283100E-01, 0.11763900E+00, -.46907800E+00, -.63295200E+00, 0.10427600E+00, 0.13507200E+00, -.39055600E+00, 0.54135600E+00, 0.14604600E+01, -.49524600E+00, -.19370500E-01, -.14920400E+00, 0.30074200E-02, -.56268700E-01, 0.23891300E+00, 0.67653300E+00, -.41620100E-01, -.12583600E+00, 0.51549900E+00, 0.80284500E-02, 0.62005800E-01, -.30307200E+00, 0.14589900E-01, -.10707000E+00, 0.15224900E+00, -.21600000E+00, -.60533000E+00, -.23936900E+00, -.64969600E-01, -.16583600E+00, 0.11743700E+00, 0.50436300E-01, -.12091600E+00, 0.12390300E+00, -.76374000E-01, -.28177100E+00, 0.10447500E+00, 0.58104500E-01, 0.48021200E-01, -.40667700E-01, 0.34150100E-01, 0.13117700E+00, -.48730600E-01, 0.53454100E+00, -.52751000E-03, -.30645500E+00, -.17688700E-01, -.11269000E+00, 0.86606700E-01, -.51614100E-01, 0.80934100E+00, 0.30039600E+00, -.33433700E+00, -.48465300E-01, -.12561400E+00, -.28624700E-02, 0.38007500E-01, -.68434500E-01, -.61958600E-01, 0.17381700E-01, -.28870500E-01, 0.22556000E-01, 0.96792000E-01, -.10598600E+00, 0.17948500E-01, 0.13948900E+00, 0.12474800E-03, 0.22547700E-01, -.89654500E-01, 0.17909000E+00, 0.25986300E-01, 0.72815600E-01, 0.85439100E-01, -.64637100E-01, -.50864400E-01, 0.41926900E-02, 0.77159900E-01, 0.10290200E-01, 0.56004800E-01, -.22504000E+00, -.32235300E+00, -.21692700E+00, 0.86868700E-01, -.32420100E+00, 0.91703300E-01, 0.12465600E+00, 0.12252500E+00, 0.40239900E-02, 0.43299300E-01, 0.14217000E-01, -.26957200E-02, 0.25543900E-01, -.11848400E+00, -.35230800E-01, -.16163800E+00, 0.85771100E-01, -.53271600E-01, 0.96085500E-02, 0.22841200E-01, 0.22873900E-02, -.81374000E-01, 0.17933100E-01, -.79384500E-01, 0.61083100E-01, -.12898100E-01, -.17185400E+00, 0.27511100E+00, -.13811300E+00, -.20266500E+00, 0.16291500E+00, -.10352800E-02, -.11986700E+00, 0.51001600E-01, 0.96483300E-01, -.76120600E-01, 0.11794300E-01, -.38274900E-01, -.10671600E+00, -.18189100E-01, 0.24508900E-01, -.29706100E+00, -.33006900E-03, -.14261300E+00, 0.30306600E+00, 0.86653700E-02, -.27336300E-01, -.86556800E-02, -.40131500E-01, 0.73797300E-01, 0.80548000E-02, 0.23194500E-01, -.91533300E-01, -.10014300E-01, -.12579800E-02, -.13067300E+00, 0.16423700E-01, 0.26811200E-01, -.61783800E-01, -.14686400E+00, -.24078700E-01, -.47413000E-01, 0.59817000E-02, 0.40338200E+00, -.19142200E-01, -.43675500E+00, 0.73002700E-01, -.78080900E-01, 0.20375100E-01, 0.21996200E-01, 0.38979200E-01, 0.40804400E-01, -.90504400E-02, 0.72796200E-02, -.23276100E-02, 0.10534800E-01, 0.16651900E-01, -.48762500E-01, -.72465900E-01, 0.15476900E+00, -.14183300E-01, -.83011100E-01, -.16680500E-01, 0.12616600E+00, -.13938200E-01, -.21977700E-01, 0.17885500E-03, -.27132700E-01, 0.54421300E-01, 0.10476700E-02, -.11521300E+00, 0.23557200E+00, 0.87672600E-01, 0.13882900E-01, -.21265700E-01, -.51241600E-01, 0.13520200E-01, 0.55198600E-03, -.94976600E-01, -.41396000E-01, 0.31008700E+00, -.54076100E-01, -.21269500E+00, 0.53711300E-01, -.36405800E-02, -.53313600E-02, 0.41744400E-01, -.72802400E-01, -.21348400E-01, 0.12875300E+00, -.42584200E-01, -.26123500E-02, -.13453800E+00, 0.75119300E-01, 0.55146200E-01, 0.11153700E+00, -.46066300E-01, -.52036100E-02, 0.12824800E-01, -.13387400E-01, -.13018300E+00, 0.14860300E+00, 0.14648400E+00, -.20080300E-01, 0.11175000E+00, -.10623200E+00, 0.26323300E+00, 0.11844700E-01, -.57687600E-02, -.18209900E+00, 0.19229000E-02, 0.50502900E-02, 0.12876300E-01, 0.26954100E-01, -.16827200E+00, -.51011400E-01, -.63337600E-01, -.25577500E-01, 0.46590800E-02, -.10569700E-02, -.12324100E-01, 0.19467500E-03, -.10880900E+00, -.43538400E-01, 0.86906500E-01, -.12086100E-01, 0.14026100E+00, -.72060600E-01, 0.70538900E-02, 0.46440300E-02, -.55769800E-03, -.10710500E+00, -.39464200E-01, -.26090700E-01, -.81093100E-01, 0.56434900E-01, -.14575700E+00, -.23835200E+00, 0.24011900E-01, -.12144900E-01, -.35146500E-01, 0.31912800E-01, 0.59824200E-02, 0.19183900E-01, -.94448000E-02, 0.57786800E-01, -.26609100E-01, 0.43917500E+00, 0.48785200E+00, -.18826900E+00, 0.18867600E-01, -.69572900E-01, 0.18015000E+00, 0.42975600E-01, 0.16044900E-03, 0.14645800E+00, -.29505200E+00, -.12189000E+00, -.35709400E-01, 0.88393200E+00, -.39191100E-02, -.22944700E-01, 0.14886300E+00, -.70201100E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.32344300E+01, -.88186700E+00, -.43935500E+00, 0.44966600E+00, 0.21414600E+01, -.33206700E+00, -.39678400E+00, 0.10223000E+01, 0.25865200E-01, -.57117600E+00, -.91409600E-01, 0.33348300E+00, 0.11001000E+01, 0.68469400E+00, 0.86202600E-01, -.15237300E+00, 0.39246700E+00, 0.53947900E+00, -.30388500E-02, 0.10155900E+00, 0.20014600E+00, -.98664600E+00, -.21846600E+01, 0.97262400E+00, -.36677200E-01, 0.35030500E+00, -.11505700E+00, -.22286700E+00, -.45072200E+00, -.59300200E+00, -.81528500E-01, 0.66442700E-01, -.51993400E+00, -.16522500E-02, -.11330700E+00, 0.27824900E+00, -.11359800E-01, -.59211100E-01, -.30548700E-01, 0.39136100E+00, 0.68850600E+00, 0.60967300E+00, -.81334800E+00, 0.38052300E+00, -.35407400E+00, -.29294100E+00, 0.43681800E+00, -.11876000E+00, 0.12984500E+00, 0.27561700E+00, -.43107600E+00, -.28623700E+00, -.10506100E+00, 0.11308300E+00, -.12973400E-01, -.67104300E-01, -.17035900E-01, -.63357400E+00, 0.17170600E-02, 0.14106500E+00, -.81215800E-01, 0.34827600E+00, -.12930600E+00, 0.17006100E+00, -.59058100E+00, -.60933500E-02, 0.46667300E+00, -.68306000E-01, 0.21485300E+00, 0.39578100E-02, -.38600500E-01, 0.11461400E+00, -.13501000E+00, 0.97356000E-01, -.57583800E-01, -.39750400E-01, -.22572900E+00, -.12870700E+00, -.39743900E+00, 0.61599400E-02, -.63183400E-03, 0.41458800E+00, -.25049700E+00, 0.39687600E+00, 0.15156200E-02, -.15855800E+00, 0.15628000E+00, 0.99495500E-01, 0.87017800E-01, 0.46839900E-01, -.29555300E+00, -.13215400E-01, 0.21091400E+00, 0.28911900E+00, -.15227400E+00, -.12807900E+00, 0.61427800E-01, 0.35262500E+00, -.19842600E+00, -.57412400E-01, 0.16221200E+00, 0.47943000E-01, -.51052100E-01, 0.14355500E-02, 0.12361600E+00, 0.24825600E-01, 0.34179800E+00, 0.11724200E+00, 0.26933800E+00, -.28633500E-01, 0.29535500E-01, -.67384700E-02, -.39721200E-01, -.23035600E-02, 0.42300100E-01, 0.24689000E+00, -.44979200E-01, -.80587100E-02, 0.95800500E-02, 0.38229000E+00, -.23370500E+00, -.10763400E-01, 0.13501400E+00, -.39439500E+00, -.82535400E-03, 0.23262600E+00, -.13741800E+00, -.29123000E+00, 0.73407100E-01, -.41796500E-01, 0.38030600E-02, 0.43867700E-01, 0.44125100E-01, -.20115400E-01, 0.49386600E+00, 0.73628800E-03, 0.11399400E+00, -.41160700E+00, -.57300300E-01, 0.28347600E-01, 0.43157300E-01, 0.11492100E+00, -.74407500E-01, 0.79360000E-02, -.34370100E-01, 0.14641300E+00, 0.18249700E-01, 0.53487100E-02, 0.12133500E+00, -.59618400E-01, -.28588700E-01, 0.63140900E-01, 0.26350800E+00, 0.57919500E-01, 0.49796700E-01, 0.11232000E-02, -.72345800E+00, 0.38222700E-01, 0.42481800E+00, -.46907300E-01, 0.76065400E-01, -.10620400E+00, 0.23880400E+00, 0.13425500E-01, -.14555200E+00, -.39696400E-01, -.10752600E-01, -.13139400E-01, -.49395200E-02, -.65545100E-01, 0.67878000E-02, 0.18345300E+00, 0.46377500E-02, 0.58500600E-02, 0.43250200E-01, 0.68378500E-02, -.45066700E-01, 0.30672600E-02, 0.14413800E-01, -.77428500E-03, 0.10865700E+00, 0.12753500E-01, -.77230800E-01, -.15701000E-01, -.16307300E-01, -.17551600E+00, 0.30549800E-01, 0.13296100E-01, 0.14058100E-01, -.28786100E-02, -.11145200E-02, -.67361900E-01, -.20624700E-01, -.68247700E-01, 0.18069500E-01, 0.88104100E-01, -.15794600E-01, 0.36727200E-03, 0.78050600E-01, -.67671500E-01, 0.95292100E-01, 0.19455000E-01, -.16508800E+00, -.36869700E-01, -.31369700E-02, -.17360500E-01, -.31977800E+00, 0.10441200E-01, -.52221300E-01, -.45327000E-01, -.33691500E-02, 0.16942900E-02, -.16907000E-02, 0.30600600E+00, -.26914600E-01, -.20864800E+00, -.45845500E-02, -.11603800E+00, -.21128100E+00, -.41744500E+00, -.28240300E-03, -.38784400E-02, 0.52845400E+00, -.67917100E-03, -.65816800E-03, -.18527500E+00, -.53169300E-01, -.12905500E+00, 0.30739900E+00, 0.97961100E-01, 0.15438700E+00, -.40528000E-01, 0.97089600E-02, -.71617600E-02, -.24636800E-02, 0.19976100E+00, 0.80062100E-01, -.64630100E-01, 0.39880400E-01, -.42554000E-01, 0.45990500E-01, 0.45705500E-01, 0.15132200E-01, 0.52617900E-02, 0.93730800E-01, 0.49619000E-01, 0.86256700E-01, -.25843100E-01, 0.84524800E-01, -.97831200E-01, -.31459700E+00, 0.81817000E-02, 0.23930700E-01, 0.48878100E-01, -.32984100E-01, 0.15067300E+00, -.16606500E-01, 0.13122000E+00, -.37217800E+00, 0.57923300E-01, -.14650200E+01, -.30497600E+00, -.61328600E+00, -.47713500E-01, 0.85466000E+00, -.94649000E-01, -.62101200E-01, 0.20331100E-01, -.12601600E+00, 0.26712700E+00, 0.22578400E+00, 0.57196400E-01, -.26171500E+00, 0.96259100E-03, 0.29969600E-01, -.47158300E-01, 0.15276700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
    }
};





    static double torsion_lu_parameters[6][226][226] = {
        { { 0.94284900E+05, -.22786400E+05, -.21308600E+05, -.24816500E+05, 0.88768100E+03, 0.33655300E+05, -.13480700E+04, -.23321600E+05, -.55191400E+05, 0.12923900E+05, 0.12091100E+05, 0.14177800E+05, 0.26520000E+03, -.19720500E+05, 0.98955800E+03, 0.13380900E+05, 0.43534100E+05, -.98086600E+04, -.91923100E+04, -.10794800E+05, -.87359800E+03, 0.15557300E+05, -.62118700E+03, -.10155200E+05, 0.84517400E+05, -.18228800E+05, -.19001600E+05, -.21895700E+05, 0.10412200E+04, 0.29040700E+05, -.43792200E+04, -.20552900E+05, -.69903900E+05, 0.22654700E+05, 0.15673800E+05, 0.18524600E+05, -.60238200E+03, -.24828100E+05, 0.11276900E+04, 0.17403400E+05, 0.10002400E+06, -.32822700E+05, -.20655200E+05, -.24122300E+05, -.24926000E+04, 0.35601000E+05, 0.38789400E+03, -.22203900E+05, 0.74568300E+05, -.14823100E+05, -.13557900E+05, -.16135900E+05, -.58567800E+04, 0.26390200E+05, -.92470600E+03, -.15175000E+05, -.46455700E+05, 0.10450100E+05, 0.97773500E+04, 0.11486900E+05, 0.99597400E+03, -.16602900E+05, 0.66140400E+03, 0.10806900E+05, -.87506900E+05, 0.17401600E+05, 0.17512200E+05, 0.20934600E+05, 0.30703600E+04, -.31710700E+05, 0.33413200E+03, 0.19643000E+05, -.39176300E+05, 0.89361900E+04, 0.79703600E+04, 0.91473900E+04, 0.15645500E+04, -.13535400E+05, 0.25485900E+04, 0.86086100E+04, -.13309100E+06, 0.27293400E+05, 0.24748000E+05, 0.29402800E+05, 0.96481100E+04, -.47768700E+05, 0.11125400E+04, 0.27579500E+05, -.23604900E+05, 0.81628200E+04, 0.44681200E+04, 0.53657700E+04, 0.10055300E+04, -.87674100E+04, -.11312400E+04, 0.48064900E+04, -.77248600E+05, 0.15193500E+05, 0.17658600E+05, 0.20469200E+05, -.19808200E+04, -.26679700E+05, 0.31990600E+04, 0.19184300E+05, -.11152800E+06, 0.18843600E+05, 0.22157700E+05, 0.26112700E+05, 0.40635500E+04, -.39720800E+05, 0.17650700E+04, 0.24286500E+05, 0.10875000E+06, -.31295200E+05, -.24416200E+05, -.28520800E+05, 0.85035800E+03, 0.39367100E+05, -.13998500E+04, -.26674000E+05, -.47557000E+05, 0.10866700E+05, 0.10151000E+05, 0.11913900E+05, 0.74758100E+03, -.16991100E+05, 0.73347600E+03, 0.11219300E+05, -.13467200E+06, 0.29403800E+05, 0.27500900E+05, 0.32388100E+05, 0.48324500E+04, -.49016600E+05, 0.22319300E+04, 0.30564000E+05, -.53648700E+05, 0.92643600E+04, 0.11382500E+05, 0.13550400E+05, 0.92431100E+03, -.19593500E+05, 0.80988400E+03, 0.12912500E+05, -.25130000E+05, 0.50926100E+04, 0.45422400E+04, 0.52721700E+04, 0.20352600E+04, -.89244200E+04, 0.31900000E+03, 0.48252900E+04, -.31800600E+05, -.91581400E+03, 0.72521100E+03, 0.56976800E+04, -.11163300E+05, -.11266500E+05, 0.12533400E+05, 0.35566700E+04, -.55063200E+04, -.10695400E+05, -.15438800E+05, 0.45101100E+04, 0.23158800E+05, -.77606400E+04, 0.15333800E+05, -.50633300E+04, -.40028600E+04, 0.52434900E+04, 0.47159200E+04, -.23522600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26462900E+01, 0.17014800E+06, -.28707700E+05, -.28887300E+05, 0.37288100E+05, 0.10382400E+05, 0.14174900E+05, -.32630200E+05, -.30285700E+04, -.98628200E+05, 0.16597600E+05, 0.16899200E+05, -.20210200E+05, -.73587100E+04, -.74252500E+04, 0.19234200E+05, -.13503100E+04, 0.83536400E+05, -.12517300E+05, -.12564300E+05, 0.15956700E+05, 0.47773000E+04, 0.64831400E+04, -.14518800E+05, -.66698300E+04, 0.16819100E+06, -.27336100E+05, -.27492900E+05, 0.36997300E+05, 0.71325800E+04, 0.13090000E+05, -.31649000E+05, 0.31533400E+05, -.89302100E+05, 0.15531300E+05, 0.14445500E+05, -.29207100E+05, 0.25488400E+04, -.95582600E+04, 0.17489300E+05, -.11257100E+06, 0.17910500E+06, -.15674800E+05, -.10935200E+05, 0.52043800E+05, -.27259300E+05, 0.24290800E+05, -.16327400E+05, -.81766100E+04, 0.17004500E+06, -.16347700E+05, -.16690600E+05, 0.20783200E+05, 0.87040400E+04, 0.18417000E+05, -.20240300E+05, 0.17035400E+04, -.89284200E+05, 0.13286300E+05, 0.13327600E+05, -.16984600E+05, -.50167700E+04, -.69332100E+04, 0.15424200E+05, 0.71899100E+04, -.18560700E+06, 0.25227600E+05, 0.25022400E+05, -.32129600E+05, -.84741100E+04, -.14784000E+05, 0.29570100E+05, 0.20160000E+05, -.91367200E+05, 0.94823600E+04, 0.82629200E+04, -.16509800E+05, 0.34059100E+04, -.46681100E+04, 0.10729600E+05, 0.12912500E+05, -.29252400E+06, 0.29976400E+05, 0.29893400E+05, -.38459200E+05, -.13916700E+05, -.28278600E+05, 0.35321500E+05, 0.30790600E+05, -.42059200E+05, 0.27979900E+04, 0.13165200E+04, -.11701600E+05, 0.81789400E+04, -.54106600E+04, 0.27717500E+04, -.52403000E+04, -.14536800E+06, 0.28501000E+05, 0.29908300E+05, -.35284600E+05, -.11544400E+05, -.14999400E+05, 0.33904900E+05, 0.56335000E+04, -.25837200E+06, 0.35721800E+05, 0.35675500E+05, -.43326000E+05, -.12315200E+05, -.19978200E+05, 0.41864600E+05, -.47386000E+05, 0.17693700E+06, -.27519300E+05, -.25971500E+05, 0.49056800E+05, -.57881700E+04, 0.17784600E+05, -.31209400E+05, 0.51980400E+03, -.89301700E+05, 0.13817200E+05, 0.13922800E+05, -.17457700E+05, -.54580900E+04, -.68804500E+04, 0.16023700E+05, 0.29016700E+04, -.27050100E+06, 0.37067800E+05, 0.37052600E+05, -.44363600E+05, -.11673500E+05, -.17198900E+05, 0.44089800E+05, -.56762400E+05, -.85855800E+05, 0.19042100E+05, 0.21700800E+05, -.80409100E+04, -.24441900E+05, -.31449800E+04, 0.22948900E+05, 0.19635100E+05, -.71218000E+05, 0.56879400E+04, 0.45530400E+04, -.11251300E+05, 0.31502200E+04, -.61761300E+04, 0.61651900E+04, -.29181200E+04, -.40354400E+04, -.69187700E+04, 0.54873000E+04, -.52320500E+04, 0.14315900E+04, 0.32534500E+05, 0.54528100E+05, -.61753900E+04, -.36954400E+04, -.25752200E+05, 0.43685600E+05, 0.14450300E+05, 0.22861900E+05, -.34116800E+04, -.12405200E+05, -.55363300E+04, 0.26465700E+05, -.42714400E+05, -.11482200E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.66745500E-01, 0.47727000E-01, 0.92155100E+04, 0.11209400E+05, -.12509800E+05, -.36271500E+04, -.42053800E+04, 0.12086400E+05, 0.17714500E+04, 0.13434900E+02, -.52998200E+04, -.64519700E+04, 0.64874900E+04, 0.26855700E+04, 0.20596000E+04, -.69811700E+04, 0.61979000E+03, -.71333800E+03, 0.38670800E+04, 0.47483500E+04, -.51985000E+04, -.15352000E+04, -.18649800E+04, 0.52168400E+04, -.37331700E+04, -.17542000E+04, 0.68079600E+04, 0.76703000E+04, -.88348700E+04, -.23704900E+04, -.52234900E+02, 0.82576500E+04, 0.12191600E+05, -.30552900E+04, -.71487900E+04, -.83646100E+04, 0.61567400E+04, 0.66888200E+04, 0.13934700E+04, -.87835900E+04, 0.74345900E+04, -.24016500E+04, 0.86183600E+04, 0.10818400E+05, -.13349200E+05, -.16612000E+04, -.63107100E+04, 0.11826000E+05, 0.83906900E+04, -.21487900E+04, 0.55071900E+04, 0.74071500E+04, -.86054800E+04, -.10500200E+04, -.55609200E+04, 0.83978600E+04, -.60875000E+03, 0.76891300E+03, -.40989400E+04, -.50287100E+04, 0.54875100E+04, 0.16449700E+04, 0.19719700E+04, -.55294900E+04, -.57398400E+04, 0.35113400E+04, -.73195100E+04, -.93659400E+04, 0.11001800E+05, 0.19862400E+04, 0.48987400E+04, -.10458300E+05, -.19201600E+04, 0.15618400E+04, -.25128700E+04, -.27938700E+04, 0.39189400E+04, 0.51532600E+02, -.59361800E+02, -.32483000E+04, -.11183000E+05, 0.23961000E+04, -.10270400E+05, -.13620800E+05, 0.15175900E+05, 0.32206000E+04, 0.96736000E+04, -.15322600E+05, -.27844300E+04, 0.92106200E+03, -.18625300E+04, -.23603000E+04, 0.31417500E+04, 0.23755400E+03, 0.16954900E+04, -.26622900E+04, 0.48888000E+04, 0.19992600E+04, -.65417600E+04, -.74194000E+04, 0.81430700E+04, 0.27585800E+04, 0.22420600E+03, -.79138600E+04, -.10319400E+05, 0.70809800E+04, -.76854800E+04, -.92439300E+04, 0.13025900E+05, 0.45939200E+02, 0.39626300E+04, -.10624000E+05, -.31021100E+04, -.15135800E+03, 0.10871600E+05, 0.13307300E+05, -.13634700E+05, -.48725000E+04, -.40769600E+04, 0.14256800E+05, -.13257600E+01, 0.55216700E+03, -.43178400E+04, -.52842500E+04, 0.56372300E+04, 0.18648700E+04, 0.19452600E+04, -.57788300E+04, -.41741400E+04, 0.23619400E+04, -.11650100E+05, -.14708300E+05, 0.15748800E+05, 0.34601000E+04, 0.57936500E+04, -.16383000E+05, 0.10502900E+05, -.26541700E+04, -.49886300E+04, -.60447300E+04, 0.35749300E+04, 0.49183500E+04, 0.85449600E+03, -.64400600E+04, -.91402700E+04, 0.24521600E+04, -.15638300E+04, -.20538600E+04, 0.43216500E+04, -.17142300E+04, 0.20849700E+04, -.25388300E+04, 0.61440900E+03, 0.12449700E+04, 0.42877800E+04, -.48391200E+04, 0.64737800E+04, -.63034000E+04, -.26752600E+04, -.67355100E+04, 0.50347800E+04, 0.47903000E+04, 0.88514100E+04, -.76871000E+04, -.17083500E+04, 0.44235600E+04, -.80198000E+04, -.31234300E+04, 0.46848600E+04, -.44723500E+04, 0.93945100E+04, 0.62607800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.26806200E-01, -.37390000E-01, -.21946500E+01, -.35771400E+04, -.21984900E+04, 0.14421300E+05, 0.33812800E+05, -.24647800E+04, -.45644500E+04, 0.40936900E+04, 0.14525600E+04, 0.38267000E+04, -.22399300E+03, -.11095200E+05, -.22773300E+05, 0.29770300E+04, 0.68747500E+04, -.42944500E+04, -.22052900E+04, -.43276100E+04, 0.77885600E+03, 0.10239500E+05, 0.18479600E+05, -.35479500E+04, -.60112100E+05, 0.26191800E+05, 0.16022200E+05, 0.18258900E+05, -.47181800E+04, -.14819900E+05, 0.15723000E+05, 0.18513200E+05, -.22255300E+05, 0.15496700E+05, 0.37365000E+04, 0.72510300E+04, 0.13678500E+04, -.20663000E+05, -.31428200E+05, 0.62537500E+04, 0.36631700E+05, -.11646000E+05, -.11006700E+05, -.18119700E+05, 0.26485300E+04, 0.35216700E+05, 0.43921200E+05, -.16305500E+05, -.22171000E+05, 0.15833500E+05, -.35720000E+04, -.61271800E+04, 0.12097600E+05, 0.65704200E+04, 0.27835300E+05, -.50514900E+04, -.75265000E+04, 0.47289500E+04, 0.24009800E+04, 0.46606200E+04, -.87844200E+03, -.10989400E+05, -.19714400E+05, 0.38246600E+04, -.25855800E+05, 0.14579300E+05, 0.84916600E+04, 0.13683700E+05, -.32758500E+04, -.25515100E+05, -.39039300E+05, 0.11864100E+05, 0.24900400E+05, -.10444800E+05, -.63430400E+04, -.72140900E+04, 0.95137600E+03, 0.78117300E+04, -.79451000E+04, -.74859200E+04, 0.78129200E+04, -.85893100E+04, 0.10848700E+05, 0.16820500E+05, -.17718100E+05, -.20461300E+05, -.52429100E+05, 0.15146600E+05, -.41134600E+05, 0.17738300E+05, 0.82668000E+04, 0.11766900E+05, 0.11439800E+04, -.20839300E+05, -.14366600E+05, 0.10769100E+05, 0.50631200E+05, -.22838200E+05, -.13376700E+05, -.14836600E+05, 0.38146900E+04, 0.10252000E+05, -.16552700E+05, -.15220000E+05, -.36789800E+04, 0.38154600E+04, 0.13810500E+04, 0.50598800E+04, -.14513200E+04, -.18138400E+05, -.40496700E+05, 0.28441800E+04, 0.21507900E+05, -.11222200E+05, -.40675400E+04, -.97652900E+04, -.29250900E+04, 0.25176300E+05, 0.45128600E+05, -.81451200E+04, -.65372100E+04, 0.43998400E+04, 0.20657100E+04, 0.42998300E+04, -.63340700E+03, -.10732000E+05, -.20013000E+05, 0.34820800E+04, -.29400400E+05, 0.17083600E+05, 0.80204900E+04, 0.15099300E+05, -.18022900E+04, -.31105400E+05, -.55480700E+05, 0.12619700E+05, -.13372400E+05, 0.10625400E+05, 0.17303500E+04, 0.35389100E+04, 0.94659400E+03, -.11628000E+05, -.19486900E+05, 0.27673100E+04, -.18820000E+04, -.18240200E+04, 0.25105900E+04, 0.40537100E+04, -.28971400E+04, -.62602200E+04, -.12065100E+05, 0.34059100E+04, -.15133300E+04, 0.20149800E+05, 0.63436600E+04, -.50969000E+04, -.36267800E+05, -.44808800E+04, -.25463100E+05, -.34124000E+05, 0.52164100E+04, 0.11293100E+05, -.32960500E+05, -.31967500E+05, -.24429800E+05, -.32046900E+05, 0.56730100E+04, 0.10465900E+05, 0.50564500E+04, 0.84372500E+04, 0.96478600E+04, -.39999100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25756100E-01, 0.53881100E-01, -.73564800E+00, 0.10269200E-01, 0.39663700E+04, 0.64616600E+04, 0.83348100E+04, 0.16076000E+04, 0.13500900E+03, 0.10847000E+04, 0.11793600E+03, 0.19206200E+03, -.27589300E+04, -.42035700E+04, -.65364400E+04, -.81694900E+03, 0.25545300E+03, -.82537500E+03, -.13860300E+03, -.20669800E+03, 0.21826100E+04, 0.37049700E+04, 0.52629500E+04, 0.62452000E+03, -.10974300E+05, 0.24376600E+04, 0.26119500E+04, 0.32020700E+04, 0.29617200E+04, -.97197700E+02, 0.44934700E+04, 0.45873200E+04, -.41794400E+04, 0.38457200E+04, 0.13059200E+04, 0.19054900E+04, -.39041200E+04, -.85650700E+04, -.95120100E+04, 0.65834200E+03, 0.97442100E+04, -.23305600E+04, -.17345800E+04, -.23010800E+04, 0.45280400E+04, 0.12115100E+05, 0.10991200E+05, -.26275400E+03, -.61867500E+04, 0.41038700E+04, 0.92649400E+03, 0.14260500E+04, 0.40447300E+04, 0.43768100E+04, 0.77216400E+04, 0.29914400E+04, -.21384700E+03, 0.87899000E+03, 0.13900800E+03, 0.21372300E+03, -.23403900E+04, -.39360300E+04, -.56349600E+04, -.67441700E+03, -.48940900E+04, 0.38022600E+04, 0.98446400E+03, 0.10841700E+04, -.39319700E+04, -.89627800E+04, -.10573300E+05, -.70788000E+03, 0.77067000E+04, -.22693900E+04, -.20155900E+04, -.25040900E+04, -.13082800E+04, 0.11818600E+04, -.18673200E+04, -.31230500E+04, 0.84525600E+04, -.57988500E+04, -.88532500E+03, -.15832400E+04, -.75210700E+04, -.78377000E+04, -.14015300E+05, -.40189100E+04, -.11917400E+05, 0.48156300E+04, 0.18090500E+04, 0.23958800E+04, -.29843200E+03, -.69102700E+04, -.34571100E+04, 0.17360700E+04, 0.60419100E+04, -.38308200E+03, -.14220500E+04, -.16409600E+04, -.26508000E+04, -.19095200E+04, -.53218400E+04, -.29921600E+04, -.21821900E+04, 0.35089000E+04, -.12560200E+03, 0.92478000E+02, -.43826700E+04, -.92198400E+04, -.11991200E+05, -.22985100E+04, 0.92357500E+04, -.44771800E+04, -.11814800E+04, -.16404900E+04, 0.37318900E+04, 0.99039100E+04, 0.11199000E+05, 0.33399500E+03, -.10962900E+03, 0.89573800E+03, 0.12882500E+03, 0.19985300E+03, -.23895600E+04, -.39025500E+04, -.57167900E+04, -.69570800E+03, -.50510200E+04, 0.50472500E+04, -.37051300E+03, -.37955000E+03, -.41720400E+04, -.88554900E+04, -.14031000E+05, -.28943900E+04, -.88018500E+03, 0.28573100E+04, 0.13376300E+03, 0.29751600E+03, -.22562200E+04, -.29863300E+04, -.62465000E+04, -.60790900E+03, -.61788500E+03, -.79325700E+03, -.95231900E+01, -.29393700E+02, -.11437100E+04, -.27502000E+04, -.32509600E+04, -.65148900E+03, -.16146800E+03, 0.88718900E+04, 0.61870600E+03, -.12109500E+04, -.72182700E+04, 0.16169200E+04, -.62021500E+04, -.57693100E+04, 0.11594900E+04, 0.39404200E+04, -.94735000E+04, -.74243800E+04, -.72167600E+04, -.31134300E+04, 0.75471400E+02, 0.70110100E+04, 0.93663900E+03, 0.84282200E+04, 0.14395300E+03, 0.38137000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.66642900E+00, 0.11184600E+00, 0.68910100E+00, 0.77811100E+00, 0.16526700E+01, -.19235300E+05, -.37967500E+05, -.28435000E+04, 0.38821200E+04, -.52375200E+04, -.16675400E+04, -.20957100E+04, 0.22099500E+04, 0.14210700E+05, 0.27060400E+05, -.18065700E+03, -.67359500E+04, 0.50867000E+04, 0.23857600E+04, 0.28652300E+04, -.22478000E+04, -.13030400E+05, -.21784500E+05, 0.12089400E+04, 0.76343000E+05, -.29552000E+05, -.18658600E+05, -.23325600E+05, 0.14645700E+04, 0.17304800E+05, -.18731300E+05, -.25169700E+05, 0.22464700E+05, -.18750400E+05, -.57354500E+04, -.80979400E+04, 0.33073900E+04, 0.27646400E+05, 0.39655400E+05, -.59336600E+04, -.46249200E+05, 0.14871600E+05, 0.12692100E+05, 0.15800500E+05, -.51380400E+04, -.44767600E+05, -.49818400E+05, 0.12026700E+05, 0.21467600E+05, -.15362000E+05, 0.27082600E+04, 0.12747400E+04, -.12836100E+05, -.11276200E+05, -.31370400E+05, -.16646000E+04, 0.72453900E+04, -.55528900E+04, -.25941500E+04, -.31150600E+04, 0.24878400E+04, 0.13936600E+05, 0.23285000E+05, -.13429700E+04, 0.29622900E+05, -.17824300E+05, -.89819100E+04, -.10271200E+05, 0.52243400E+04, 0.32147700E+05, 0.44879100E+05, -.65401400E+04, -.34743500E+05, 0.14335000E+05, 0.82150200E+04, 0.10624000E+05, 0.50613700E+03, -.96833900E+04, 0.89749500E+04, 0.11630300E+05, -.57168500E+04, 0.94598600E+04, -.10498600E+05, -.96939200E+04, 0.20253900E+05, 0.29083900E+05, 0.59500400E+05, -.51299100E+04, 0.50828100E+05, -.22013400E+05, -.10057300E+05, -.12850100E+05, -.82761100E+03, 0.26507700E+05, 0.16559400E+05, -.11322200E+05, -.62137600E+05, 0.22431300E+05, 0.15151800E+05, 0.18536000E+05, -.12011400E+04, -.11041900E+05, 0.20142100E+05, 0.20418800E+05, 0.84239700E+03, -.55555500E+04, -.90223600E+03, -.51561000E+03, 0.43682800E+04, 0.23606600E+05, 0.47228100E+05, 0.42620000E+04, -.29154200E+05, 0.16127100E+05, 0.51954800E+04, 0.71090300E+04, 0.74442900E+03, -.32646100E+05, -.51669600E+05, 0.35096000E+04, 0.61692200E+04, -.52763900E+04, -.22553800E+04, -.27359200E+04, 0.22914600E+04, 0.13647900E+05, 0.23662200E+05, -.97397600E+03, 0.34780800E+05, -.22153600E+05, -.76468500E+04, -.88414600E+04, 0.31090200E+04, 0.37321300E+05, 0.62817200E+05, -.36435500E+04, 0.13015200E+05, -.13809600E+05, -.24935700E+04, -.31782700E+04, 0.14571700E+04, 0.13928700E+05, 0.24801800E+05, -.14113900E+04, 0.39706900E+04, 0.28742300E+04, -.23485100E+04, -.23585100E+04, 0.27545600E+04, 0.85918200E+04, 0.13184700E+05, -.10221300E+04, 0.18151800E+04, -.29370400E+05, -.76039700E+04, 0.71931900E+04, 0.37211000E+05, 0.36478000E+04, 0.30636100E+05, 0.37066300E+05, -.72889300E+04, -.12937900E+05, 0.36513800E+05, 0.37256400E+05, 0.29976800E+05, 0.29692400E+05, -.34730400E+04, -.16820000E+05, -.68591200E+04, -.16820100E+05, -.10231500E+05, 0.12755200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17923100E+00, -.81434000E-01, -.33635900E+00, -.17148700E+00, 0.33844000E+00, -.29256900E+00, 0.63056900E+04, -.25180300E+03, -.35588300E+03, 0.51383300E+03, 0.15862800E+03, 0.22948800E+03, -.27130400E+03, -.40354300E+03, -.44756300E+04, 0.34075700E+03, 0.97640300E+03, -.72605300E+03, -.30182900E+03, -.38994000E+03, 0.25359700E+03, 0.49174400E+03, 0.36039600E+04, -.47278600E+03, -.14946500E+05, 0.97822600E+04, 0.20206600E+04, 0.25718500E+04, 0.12598500E+04, -.48211500E+04, 0.44119600E+04, 0.21762700E+04, -.31969900E+04, 0.12444100E+04, 0.69086600E+03, 0.12040900E+04, -.69895600E+02, -.11260500E+04, -.64201400E+04, 0.12559900E+04, 0.79584800E+04, -.14249000E+04, -.12123000E+04, -.11824800E+04, -.41612300E+03, 0.33557400E+04, 0.65665200E+04, -.13300500E+04, -.47953600E+04, 0.36803800E+04, 0.40552700E+03, 0.10151100E+04, 0.12336100E+04, -.19613400E+04, 0.41005700E+04, 0.64255700E+03, -.10182500E+04, 0.75964400E+03, 0.33457100E+03, 0.43580700E+03, -.29454000E+03, -.53048100E+03, -.38628600E+04, 0.52397300E+03, -.47338900E+04, 0.27545500E+04, 0.11604900E+04, 0.12959200E+04, -.41802500E+03, -.19109900E+04, -.73065700E+04, 0.14739600E+04, 0.84953700E+04, -.40670300E+04, -.10866700E+04, -.13503900E+04, -.82227500E+03, 0.33815600E+04, -.26617300E+04, -.11684200E+04, 0.40404500E+04, -.19672600E+04, 0.34515100E+03, -.18427200E+03, -.22375800E+04, 0.20070400E+04, -.88029000E+04, 0.39430600E+03, -.85085800E+04, 0.32283200E+04, 0.13013400E+04, 0.16330600E+04, 0.67931800E+03, -.29997300E+04, -.22965600E+04, 0.15402800E+04, 0.10766200E+05, -.88063800E+04, -.13399300E+04, -.16889700E+04, -.11312000E+04, 0.31954900E+04, -.42268400E+04, -.13760900E+04, 0.26350100E+04, -.15880200E+04, 0.75085000E+03, 0.96479000E+03, -.18507300E+04, 0.23118300E+03, -.91412300E+04, 0.12383900E+04, 0.37697200E+04, -.62426100E+03, -.12255800E+03, -.69246600E+02, -.81320400E+03, 0.19206100E+04, 0.81760800E+04, -.21861500E+03, -.85076600E+03, 0.68706100E+03, 0.27654300E+03, 0.36552800E+03, -.26592700E+03, -.48993800E+03, -.39183000E+04, 0.45658900E+03, -.78653600E+03, 0.17615500E+04, 0.33146000E+03, 0.24483300E+03, -.59858900E+03, -.17564100E+04, -.11129300E+05, 0.56997200E+03, -.55263400E+03, 0.14541100E+03, 0.47857200E+03, 0.81348800E+03, -.67630400E+03, -.12499500E+04, -.46541400E+04, 0.88452100E+03, 0.75051900E+03, 0.30115400E+03, 0.12645900E+03, 0.35756300E+02, -.48943700E+03, 0.29752100E+03, -.22083700E+04, 0.14445700E+03, -.35630000E+03, 0.48614900E+04, 0.15001800E+04, -.13872400E+04, -.81385300E+04, -.40441700E+03, -.58731400E+04, -.64839500E+04, 0.14168900E+04, 0.20326100E+04, -.71099900E+04, -.55674300E+04, -.54791400E+04, -.66444900E+04, -.34739000E+03, 0.20649700E+04, 0.13769900E+04, 0.13064300E+04, 0.14965800E+04, -.86106300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27065700E+00, 0.54360900E-01, 0.83467000E+00, -.42259800E+00, -.23210500E+00, 0.92134800E-01, -.58767600E+00, 0.90476200E+03, 0.13350300E+04, -.31981000E+03, -.48047400E+03, -.64828200E+03, 0.36866700E+03, 0.80032600E+03, 0.11284200E+04, -.12195700E+04, -.83774800E+03, 0.24655200E+03, 0.33407400E+03, 0.44177500E+03, -.31068800E+03, -.49862000E+03, -.70310300E+03, 0.91125000E+03, 0.11561600E+05, -.50491200E+04, -.14599700E+04, -.16414100E+04, -.89068000E+03, 0.38703000E+04, 0.53832900E+03, -.92962700E+03, 0.34280300E+04, -.13336600E+04, -.20831600E+04, -.27934000E+04, 0.18195800E+04, 0.30919600E+04, 0.43845000E+04, -.35891900E+04, 0.16021800E+04, 0.18627900E+04, 0.39733600E+03, 0.25855900E+03, -.10306200E+04, 0.19179800E+03, -.48579400E+03, 0.15089900E+04, -.19026700E+04, 0.17689400E+04, -.27990400E+03, -.58222800E+03, 0.82167700E+03, -.21989000E+03, 0.14416100E+04, 0.12942300E+03, 0.88805500E+03, -.25408000E+03, -.37352100E+03, -.49594700E+03, 0.35360800E+03, 0.54307500E+03, 0.77586800E+03, -.99784900E+03, 0.33018000E+04, -.12697300E+04, -.91306600E+03, -.11027400E+04, 0.53069900E+03, 0.13226600E+04, 0.10122500E+04, -.21262400E+04, -.51928000E+04, 0.28497400E+04, 0.62635200E+03, 0.67996900E+03, 0.43606100E+03, -.19731500E+04, -.34047000E+03, 0.32609400E+03, 0.92261300E+04, -.46324900E+04, -.10981100E+04, -.11478200E+04, -.96985600E+03, 0.28701500E+04, -.57469300E+03, -.24450600E+04, -.81339800E+03, -.75958800E+03, -.65242100E+03, -.73408700E+03, 0.11275500E+04, 0.11978800E+03, 0.92358400E+03, -.11882900E+04, -.12007000E+05, 0.44622400E+04, 0.16515300E+04, 0.19522100E+04, 0.88668500E+03, -.40203600E+04, -.36642100E+03, 0.12607900E+04, -.81711000E+04, 0.37313200E+04, 0.84779700E+03, 0.10114700E+04, 0.11897700E+04, -.31233500E+04, -.61640400E+03, -.23596300E+03, 0.11146200E+04, 0.40086300E+03, 0.47307100E+03, 0.54564100E+03, -.10565600E+04, 0.13662900E+03, -.18293100E+04, 0.17901200E+04, 0.95996400E+03, -.26110500E+03, -.38178300E+03, -.50960800E+03, 0.34213600E+03, 0.58376600E+03, 0.83627100E+03, -.10164900E+04, 0.97263800E+03, 0.46625100E+03, -.88125800E+03, -.10621100E+04, 0.11797600E+04, 0.26621400E+03, 0.16901500E+04, -.25813400E+04, 0.31245200E+04, -.12322000E+04, -.16188400E+04, -.22182000E+04, 0.12621500E+04, 0.20662600E+04, 0.27423200E+04, -.27759000E+04, -.13322200E+04, 0.52752300E+03, 0.60379300E+03, 0.82088500E+03, -.27137400E+03, -.98725200E+03, -.92384600E+03, 0.52395000E+03, 0.59886500E+03, -.27014100E+03, -.49685100E+02, -.15166500E+03, -.41606700E+03, -.24467700E+03, 0.74985700E+03, 0.95730100E+03, 0.15965900E+03, 0.15826200E+01, -.87179700E+03, 0.18716700E+03, 0.98623600E+03, 0.36139700E+03, -.50797800E+03, -.60991200E+03, 0.11522000E+03, 0.20688300E+03, 0.72232600E+03, 0.20022500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.41677200E+00, -.49392100E-01, 0.66353500E+00, -.66703300E-01, -.22693500E+00, 0.88575700E-01, -.42004500E+00, -.19269500E+00, -.24362300E+04, 0.10789100E+04, 0.53212500E+03, 0.67707800E+03, 0.24399000E+02, -.90790700E+03, -.49847700E+02, 0.69827300E+03, 0.19132200E+04, -.80588700E+03, -.42657800E+03, -.53796500E+03, 0.53178400E+01, 0.69973600E+03, 0.89660300E+02, -.54883900E+03, -.24587900E+03, 0.16574400E+04, 0.15542200E+04, 0.20174800E+04, -.17406400E+04, -.17329500E+04, -.31255800E+04, 0.20680900E+04, -.46576600E+04, 0.31062900E+04, 0.10483000E+04, 0.13404000E+04, -.18440500E+03, -.15215700E+04, -.77642500E+03, 0.14893400E+04, -.17502900E+04, -.12630600E+03, -.18109600E+03, -.36550400E+03, 0.96274600E+03, -.65709500E+03, 0.13286400E+04, -.48516200E+03, 0.19018500E+03, -.37274900E+03, 0.11269500E+03, 0.37500300E+02, -.13060600E+03, -.59041800E+03, -.75278200E+03, 0.11404900E+03, -.20638500E+04, 0.87429700E+03, 0.45254600E+03, 0.56892100E+03, -.45378100E+00, -.74749400E+03, -.86596000E+02, 0.58051700E+03, -.37044200E+04, 0.16177000E+04, 0.10352700E+04, 0.13298900E+04, -.27170000E+03, -.17002700E+04, -.79903200E+03, 0.13486300E+04, -.25064000E+03, -.21016900E+04, -.58141100E+03, -.79936900E+03, 0.46751700E+03, 0.24834900E+03, 0.15296800E+04, -.88424700E+03, -.12007800E+04, 0.52411600E+03, 0.47969200E+03, 0.69115800E+03, -.59820900E+03, -.57421900E+03, -.14213800E+03, 0.58349900E+03, -.96007800E+03, 0.95200300E+03, 0.65432800E+03, 0.83292500E+03, -.57527600E+03, -.73071300E+03, -.12377200E+04, 0.93123300E+03, -.14024700E+04, 0.19368500E+04, -.12138000E+04, -.16414000E+04, 0.22976200E+04, 0.13573800E+04, 0.34722100E+04, -.16380100E+04, -.53997400E+04, 0.19645800E+04, 0.16649600E+02, -.14851100E+03, 0.16797400E+04, -.94488700E+03, 0.22152700E+04, -.21565300E+03, 0.17685100E+04, -.17538700E+04, -.75672900E+03, -.10233800E+04, 0.55102600E+03, 0.13614700E+04, 0.74013200E+03, -.10711600E+04, -.20863500E+04, 0.89310100E+03, 0.45970900E+03, 0.58077400E+03, 0.25928800E+01, -.76431700E+03, -.79304500E+02, 0.59445600E+03, -.57477600E+04, 0.15992900E+04, 0.14291200E+04, 0.17792600E+04, -.32664000E+03, -.29922500E+04, -.12844800E+03, 0.16973200E+04, -.31497000E+04, 0.15767300E+04, 0.57237800E+03, 0.65699200E+03, 0.11396400E+03, -.13544100E+04, -.14192000E+03, 0.71177900E+03, -.16091000E+04, 0.13835800E+03, 0.28730700E+03, 0.34606000E+03, 0.15644900E+03, -.50668900E+03, 0.31649000E+03, 0.29754700E+03, -.12761700E+04, -.57739400E+02, -.21658400E+01, 0.31208600E+03, 0.36303200E+04, -.29418200E+03, -.22516600E+03, 0.28125900E+03, -.30430300E+03, -.44391000E+03, 0.32994200E+04, 0.16790600E+03, -.63167100E+03, 0.21175900E+04, 0.61234700E+03, 0.69170600E+02, -.23390300E+03, 0.26081300E+03, 0.46664000E+03, -.11918800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14468500E+00, 0.63913100E-01, 0.65829700E+00, -.24215700E+00, -.22410900E+00, 0.10543300E-01, -.78294400E+00, 0.64122300E+00, 0.35126200E+00, -.33530200E+03, -.62801800E+02, -.61943800E+02, 0.12310700E+03, -.10671800E+03, 0.17565700E+03, -.64511400E+02, -.11538700E+02, 0.23186500E+03, 0.43893100E+02, 0.38362900E+02, -.88748100E+02, 0.76423900E+02, -.11357000E+03, 0.39385500E+02, -.16431000E+04, -.56658600E+01, -.59017100E+03, -.69480900E+03, 0.10045900E+04, 0.52991300E+03, 0.11340800E+04, -.83426200E+03, 0.92200900E+03, -.58626800E+03, -.35404000E+03, -.29210800E+03, 0.20540800E+03, 0.68004200E+02, -.98400700E+02, -.40815500E+03, -.16051500E+04, -.47124600E+03, 0.28344800E+03, 0.41055400E+03, 0.23434000E+03, 0.40360400E+03, 0.45341100E+02, 0.46228500E+03, -.25668100E+04, 0.88303900E+03, 0.25380400E+03, 0.47750500E+03, 0.25410200E+03, -.11288800E+03, -.11198000E+01, 0.38246900E+03, 0.20076100E+02, -.25410500E+03, -.44776500E+02, -.36586700E+02, 0.92678000E+02, -.85464100E+02, 0.12004600E+03, -.37297600E+02, -.20182500E+03, -.37682100E+03, -.17090300E+03, -.18259500E+03, 0.30749300E+03, 0.98247700E+02, 0.36959900E+03, -.17752300E+03, -.66091500E+03, 0.34472300E+03, 0.31485800E+03, 0.44399900E+03, 0.90742300E+02, 0.20265500E+03, -.45457000E+03, 0.53413400E+03, 0.18563300E+04, -.10041600E+04, -.48977100E+03, -.72581400E+03, 0.42599200E+03, 0.97694800E+03, 0.71276800E+03, -.62205800E+03, 0.29475600E+03, 0.40954800E+03, -.31036500E+03, -.32568700E+03, 0.20055000E+03, 0.31539300E+03, 0.21944600E+03, -.39208100E+03, 0.29692200E+04, -.60290400E+03, 0.45023300E+03, 0.50295300E+03, -.14237100E+04, -.39993100E+03, -.11748500E+04, 0.61480100E+03, 0.72074900E+03, -.63977400E+03, 0.47987600E+03, 0.66764800E+03, -.68825100E+03, -.37565300E+03, -.64029000E+03, 0.77241400E+03, -.34483800E+03, -.34435500E+03, 0.41827100E+03, 0.47730400E+03, -.45583700E+03, -.58340300E+03, -.20611500E+03, 0.47788600E+03, 0.69106400E+01, -.26167900E+03, -.47884300E+02, -.42209100E+02, 0.98591100E+02, -.90124300E+02, 0.13020300E+03, -.43635100E+02, -.73238700E+03, -.56438200E+03, -.46201100E+03, -.52729800E+03, 0.10498900E+04, 0.53174000E+03, 0.93985500E+03, -.42571700E+03, -.39229000E+02, -.33626200E+03, -.12946300E+03, -.91124500E+02, 0.28738100E+03, 0.13772600E+03, 0.72405700E+03, -.74177300E+02, 0.29477500E+03, -.26433800E+03, 0.11628100E+02, -.83442400E+01, -.53507400E+02, -.32771800E+02, -.81318800E+02, 0.21197500E+02, -.44306700E+02, -.85844100E+02, 0.39451600E+02, -.44179900E+02, -.11829100E+04, -.19199800E+03, 0.10287600E+03, 0.17838600E+03, 0.45104700E+02, 0.48579900E+02, -.80656100E+03, 0.12579300E+03, -.10256700E+03, -.67915400E+03, 0.13065400E+03, -.15831900E+03, 0.42172900E+02, -.30460900E+03, 0.26344600E+02, 0.97394600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.59585900E+00, 0.81075100E-01, 0.39728100E+01, -.83669200E+00, 0.33483200E+00, 0.26096100E+00, -.10053600E+01, -.93812200E+00, 0.13710300E+01, 0.78399300E-01, -.39329900E+03, -.43639500E+03, 0.67774700E+03, 0.51003900E+02, 0.10047100E+04, -.54026300E+03, -.44133400E+02, 0.81953000E+02, 0.33760700E+03, 0.37131200E+03, -.54878000E+03, 0.81625000E+01, -.68266900E+03, 0.44755400E+03, -.16934000E+05, 0.46083400E+04, -.13960700E+04, -.14434400E+04, 0.63626100E+04, -.34769600E+04, 0.47418800E+04, -.21926600E+04, 0.23440500E+04, -.68027400E+03, -.96973400E+03, -.10363800E+04, 0.11387600E+04, -.75033800E+02, 0.15644800E+04, -.13975800E+04, -.21867600E+03, 0.79603900E+02, -.28990600E+03, -.32619500E+03, 0.28968100E+03, 0.82141600E+03, 0.68844500E+03, -.22113000E+03, -.43247600E+04, 0.27694000E+04, 0.13570700E+04, 0.17908700E+04, -.55589000E+03, -.18698300E+04, -.18259500E+04, 0.15152300E+04, 0.74003900E+02, -.90770900E+02, -.35486800E+03, -.38695100E+03, 0.58001300E+03, -.13232900E+02, 0.71923600E+03, -.46787400E+03, 0.68110100E+03, -.64683100E+03, -.11693300E+04, -.13321700E+04, 0.14515900E+04, 0.71539800E+03, 0.16406900E+04, -.14923200E+04, 0.85319900E+04, -.20419000E+04, 0.50846600E+03, 0.53146600E+03, -.25747200E+04, 0.23311600E+04, -.22525100E+04, 0.10020700E+04, 0.54126600E+04, -.42449500E+04, -.29572200E+04, -.37057300E+04, 0.26887900E+04, 0.39708500E+04, 0.48232800E+04, -.34558300E+04, -.11993100E+04, 0.54739400E+03, -.19493100E+03, -.11620600E+03, 0.66149900E+03, -.75024400E+03, -.19784200E+03, -.37526300E+03, 0.13689100E+05, -.49364900E+04, 0.14299600E+04, 0.16054800E+04, -.60594500E+04, 0.22489900E+04, -.42729400E+04, 0.21151100E+04, 0.67360300E+04, -.23641800E+04, 0.44510600E+03, 0.70422300E+03, -.25782200E+04, 0.81252900E+03, -.25455900E+04, 0.90402900E+03, 0.84067800E+03, -.92834100E+03, 0.51453100E+02, -.36597500E+02, -.80319100E+03, 0.10430000E+02, -.46598400E+02, 0.93787700E+02, 0.19642500E+02, -.48982300E+02, -.34656800E+03, -.37937400E+03, 0.58629000E+03, -.10698900E+02, 0.76326300E+03, -.46449000E+03, -.18110500E+03, -.10513300E+03, -.62689300E+03, -.53658700E+03, 0.17853000E+04, 0.88328700E+03, 0.79469600E+03, -.59782400E+03, 0.31027800E+03, 0.53842400E+03, -.52653500E+03, -.49039500E+03, 0.10629800E+04, 0.48517400E+03, 0.17743200E+04, -.70175700E+03, 0.29335000E+03, -.79499800E+03, -.30258700E+03, -.37038200E+03, 0.22545400E+03, 0.22305900E+03, 0.17328900E+03, -.29023800E+03, -.24141400E+03, -.51485800E+03, 0.12829700E+03, -.14154700E+03, -.38673300E+04, -.70612600E+03, 0.61091900E+03, 0.95363200E+03, 0.15479100E+03, 0.10111000E+03, -.37490600E+04, 0.62583900E+03, 0.51494300E+03, -.19828000E+04, -.15799500E+02, -.63676400E+03, 0.13700500E+03, -.86683400E+03, 0.61317700E+03, 0.50482900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19439200E+00, 0.12879700E+00, 0.30248000E+01, -.10019200E+01, 0.77702700E-01, -.18508000E-01, -.16620000E+01, -.49216200E+00, 0.70982600E+00, 0.18011600E+01, 0.13129800E+00, -.81989500E+02, 0.15295400E+03, 0.16842600E+03, 0.12191100E+04, -.10608100E+03, -.25651100E+03, 0.19881000E+03, 0.65485100E+02, 0.13495900E+03, -.11415400E+03, -.24019100E+03, -.82550200E+03, 0.16188400E+03, -.86994500E+03, 0.15892800E+04, 0.15465100E+03, 0.11357900E+03, 0.27680900E+03, -.12428100E+03, 0.47049700E+03, 0.96953600E+02, 0.16430400E+03, -.12029100E+03, 0.19976600E+02, -.19798300E+03, 0.35521600E+03, 0.81566400E+03, 0.28096700E+04, -.24306600E+03, 0.18751600E+04, 0.16435900E+04, 0.83647800E+02, 0.27733900E+03, -.55245500E+03, 0.85604400E+03, 0.18043800E+03, 0.37247000E+03, 0.75118300E+03, 0.61533700E+03, -.17570000E+03, -.28685300E+03, 0.47370700E+03, 0.84369800E+03, 0.13363600E+04, -.22602700E+03, 0.28141400E+03, -.21478600E+03, -.70648800E+02, -.14395800E+03, 0.12230100E+03, 0.25831300E+03, 0.88607500E+03, -.17338100E+03, 0.17239000E+04, -.86814200E+03, -.46548500E+03, -.73087400E+03, 0.28936400E+03, 0.10056500E+04, 0.13391900E+04, -.78842700E+03, -.20676000E+02, 0.26592300E+03, 0.27274600E+03, 0.37787900E+03, -.59546500E+03, 0.15082100E+03, -.14795900E+03, 0.38717800E+03, 0.30466000E+03, 0.10197300E+02, 0.16910300E+03, 0.27641600E+03, -.82403500E+03, -.41031400E+03, -.15402700E+04, 0.20786800E+03, -.16444700E+04, -.37828300E+03, 0.12899800E+02, -.10681900E+03, 0.51760200E+03, -.28635600E+03, 0.37368500E+03, -.16095600E+03, -.26105600E+04, -.10909300E+04, 0.35328700E+03, 0.50449600E+03, 0.28446400E+03, -.11333800E+04, 0.13443600E+03, 0.45159900E+03, 0.19575400E+03, -.11531800E+04, -.90157800E+02, -.23599500E+02, 0.19614500E+03, 0.15876100E+03, 0.54310500E+03, -.10818100E+03, 0.25210000E+04, -.10822300E+03, -.27247100E+03, -.35531000E+02, -.52723100E+03, 0.36431200E+03, -.23715600E+04, 0.21352600E+02, 0.19804100E+03, -.15763600E+03, -.50956900E+02, -.12557600E+03, 0.12816700E+03, 0.22877900E+03, 0.94979400E+03, -.15280200E+03, -.22706200E+04, 0.14058600E+04, 0.30141900E+03, 0.89250700E+02, 0.35081400E+03, -.32988400E+03, 0.28784200E+04, 0.31399500E+02, -.20411900E+03, -.67917500E+02, -.73244700E+01, -.98713500E+02, 0.34960100E+03, 0.69225800E+02, 0.15868800E+04, -.13363100E+03, 0.61566700E+02, -.80308800E+02, 0.68531700E+02, 0.12738200E+03, -.14493100E+03, -.80324700E+02, -.58828100E+02, 0.11542800E+03, -.16410500E+03, -.79267400E+03, -.29401600E+03, 0.28027500E+03, 0.51198800E+03, -.14315700E+03, 0.10296200E+04, 0.71106400E+03, -.28364900E+03, -.53230600E+03, 0.33933600E+03, 0.75413600E+03, 0.13607500E+04, 0.86708700E+03, -.50932500E+00, -.77965800E+03, -.27408500E+03, -.39435000E+03, -.32243400E+03, -.91842300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13191100E+01, -.50824500E+00, 0.18446400E+00, 0.13563100E+00, -.29406100E-01, -.24395000E-01, 0.36572200E+00, -.12845000E+01, 0.50332100E+00, 0.34310100E+01, 0.19422100E+00, 0.18187600E+01, -.24873800E+03, 0.37317100E+03, -.12298400E+04, -.39280200E+02, 0.57586100E+03, -.74897800E+03, -.14061100E+03, -.14744100E+03, 0.21984300E+03, -.32466300E+02, 0.81591500E+03, -.12419800E+03, 0.12589700E+05, 0.62921500E+04, -.34952900E+03, -.46197600E+03, -.27292100E+04, 0.16406400E+04, -.20550700E+04, -.10156600E+02, -.14423400E+04, -.44801100E+04, -.75490400E+03, -.12737200E+04, 0.93223400E+03, 0.43205200E+03, 0.92999000E+01, -.13255100E+04, 0.50881900E+04, -.10412800E+04, 0.10787700E+04, 0.10433600E+04, -.30707700E+04, -.35405700E+04, -.25690900E+04, 0.14219500E+04, 0.45888100E+04, -.52886200E+04, -.45102000E+03, -.99005000E+03, -.40006200E+03, -.24252200E+04, -.15032200E+04, -.96825200E+03, -.66653800E+03, 0.76649100E+03, 0.14995800E+03, 0.14940600E+03, -.23099700E+03, 0.37879100E+02, -.86897700E+03, 0.12172200E+03, -.20375100E+04, 0.22391500E+04, 0.99887200E+03, 0.12776000E+04, -.10494100E+04, -.15507700E+04, -.17199900E+04, 0.12100700E+04, 0.32547800E+04, -.45410800E+04, -.60867300E+03, -.10359800E+04, -.80281000E+03, -.17214800E+04, 0.14580100E+03, -.12637500E+04, 0.53777800E+04, 0.40093900E+04, 0.23720400E+03, 0.46313000E+03, -.27525100E+04, 0.19744500E+04, 0.87176200E+02, 0.47150100E+03, 0.12745500E+03, -.73548100E+03, 0.14197500E+03, 0.10382000E+03, 0.58246100E+02, -.63094500E+03, -.14497100E+03, 0.36597800E+02, -.18078900E+05, -.30082400E+04, 0.39059800E+03, 0.66097400E+03, 0.46656400E+04, -.18400400E+04, 0.23728100E+04, 0.27543800E+03, -.13667600E+05, 0.46359100E+04, 0.10418700E+04, 0.10070500E+04, 0.18835000E+04, -.37010700E+04, 0.30926300E+03, 0.61918700E+03, 0.12651500E+04, 0.40872800E+04, 0.30392200E+02, -.91387700E+02, -.14126400E+03, 0.22777600E+04, 0.19097300E+04, 0.37414100E+03, -.46158100E+03, 0.55571700E+03, 0.10358900E+03, 0.10502300E+03, -.22405100E+03, 0.12287700E+03, -.94078300E+03, 0.75561500E+02, 0.72181500E+04, 0.27757500E+03, 0.15014500E+04, 0.19801900E+04, -.46487200E+04, -.15585600E+04, -.67931500E+04, 0.16634400E+04, 0.15856400E+04, -.43183200E+04, 0.47579000E+03, 0.48268700E+03, -.15195200E+04, -.22391300E+03, -.33167700E+04, 0.37801100E+03, -.55004300E+03, 0.53023400E+04, 0.11696000E+03, 0.16324800E+03, -.17637500E+03, 0.34462900E+03, -.13634200E+03, 0.16258800E+03, 0.54189700E+03, 0.87127400E+03, 0.25653600E+03, -.25234400E+03, 0.74153800E+03, -.78147700E+03, -.11949900E+04, -.67483200E+03, 0.25795300E+03, 0.35347800E+03, -.15946700E+04, -.42920700E+03, -.55467600E+03, 0.71991600E+03, -.14203500E+03, 0.62978500E+03, 0.25897600E+03, 0.13178100E+04, -.52224300E+03, -.35238900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11606000E+00, 0.79574200E-01, 0.21922800E+01, -.68729100E+00, 0.35136000E-01, 0.64579700E-01, -.81789000E+00, -.28892100E+00, 0.52491000E-01, 0.11315100E+01, 0.15118100E+00, 0.45448400E+00, -.28114200E-01, 0.16724600E+03, 0.77029600E+02, 0.64546200E+01, 0.32122100E+02, 0.16769500E+02, 0.80646000E+01, 0.17243000E+02, -.17782600E+02, -.14081800E+03, -.15097700E+03, 0.13667400E+02, -.21461700E+04, 0.19528800E+04, 0.14155200E+04, 0.16561500E+04, -.72157900E+03, -.18703700E+04, -.10361000E+04, 0.17480100E+04, -.45600300E+03, 0.62245600E+03, 0.21731100E+03, 0.15810200E+03, -.14116600E+03, 0.75898700E+01, -.96690000E+01, 0.27837700E+03, 0.12019500E+04, -.65658200E+03, -.64298300E+03, -.96108600E+03, 0.43606700E+03, -.29374800E+03, 0.49698900E+03, -.10316700E+04, 0.17195000E+04, -.10641200E+04, -.11446900E+03, -.36695200E+03, -.13009700E+03, -.26846300E+03, -.12648500E+03, -.30643400E+03, -.43538400E+02, -.10651300E+02, -.10834900E+02, -.23861300E+02, 0.20438700E+02, 0.15308000E+03, 0.16343900E+03, -.19994100E+02, -.44119500E+03, 0.15655700E+03, 0.12837100E+03, 0.15972200E+03, 0.22129200E+02, -.91343300E+02, 0.44530200E+03, 0.15070500E+03, 0.24306600E+04, -.22505900E+04, -.80047200E+03, -.10070900E+04, -.71018900E+02, 0.37495300E+03, 0.35962500E+03, -.10758700E+04, -.18844200E+04, 0.11146800E+04, 0.50270900E+03, 0.79762300E+03, -.47480800E+03, -.91977300E+03, -.39398100E+03, 0.73116400E+03, -.80911300E+03, 0.43000900E+03, 0.64674200E+03, 0.75940500E+03, -.41706900E+03, -.65953800E+03, -.46032600E+03, 0.82816600E+03, 0.39570200E+03, 0.15542300E+03, -.11943800E+04, -.13765300E+04, 0.12594100E+04, 0.17017500E+04, 0.12498800E+04, -.14215000E+04, -.59255200E+03, -.16520300E+03, -.87818500E+03, -.11788400E+04, 0.11665900E+04, 0.82785900E+03, 0.18497400E+04, -.12428300E+04, -.11866600E+04, 0.36736100E+03, -.24942200E+03, -.38916500E+03, 0.58950700E+03, 0.27500000E+03, 0.64519300E+03, -.39696000E+03, -.15038200E+02, -.17317100E+02, -.91538000E+01, -.17734600E+02, 0.12733900E+02, 0.15689100E+03, 0.13551300E+03, -.13334300E+02, 0.89847200E+03, -.87648200E+03, 0.45928900E+03, 0.61686600E+03, -.83751800E+03, -.65732200E+03, -.83812300E+03, 0.52838200E+03, -.19851700E+03, 0.13927200E+03, 0.16942700E+03, 0.10765100E+03, -.19695300E+03, -.24541200E+03, -.41457700E+03, 0.11220000E+03, -.61015300E+03, -.74767100E+01, -.87538000E+02, -.84194600E+02, 0.26292800E+03, 0.79932100E+02, 0.43816900E+03, -.11383200E+03, 0.11435600E+03, -.11168900E+03, -.32682200E+02, 0.34751400E+02, 0.18336600E+04, 0.10627800E+03, -.27138800E+02, 0.11850300E+03, -.34204600E+02, -.11224800E+03, 0.13699800E+04, 0.17493400E+03, 0.27145500E+03, 0.12974200E+04, -.38841200E+03, 0.34681000E+02, -.29453700E+02, 0.11966600E+03, -.27491700E+02, 0.21106000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.54524000E+00, -.41408900E-01, 0.10261800E+01, 0.25439100E+00, 0.15137700E+00, 0.18236300E+00, -.20690800E+00, -.47698200E+00, -.23166000E+00, 0.69329100E+00, 0.93482000E-01, 0.64050200E+00, -.24128200E-01, 0.94186400E+00, -.28553000E+03, 0.12246900E+02, 0.11060700E+03, -.16985400E+03, -.35605300E+02, -.46738600E+02, 0.36782400E+01, 0.86653500E+02, 0.33819200E+03, -.59317100E+02, 0.69428300E+04, -.43420900E+03, -.12352800E+04, -.15850100E+04, -.30749900E+03, 0.21864300E+04, -.51302400E+03, -.15104600E+04, 0.49955800E+03, -.13359100E+04, -.53900700E+03, -.58247900E+03, 0.54989700E+03, 0.73799300E+03, 0.42942400E+03, -.60021900E+03, -.10071700E+04, 0.50912400E+03, 0.13816300E+04, 0.17630700E+04, -.16181600E+04, -.13797100E+04, -.10749400E+04, 0.18381100E+04, -.38708600E+04, 0.12880500E+04, 0.62994800E+03, 0.94550200E+03, 0.79364400E+02, -.18218000E+04, -.30306300E+03, 0.80627200E+03, -.11356600E+03, 0.16549000E+03, 0.35393700E+02, 0.49229400E+02, 0.10282100E+00, -.88028000E+02, -.36042800E+03, 0.62370000E+02, 0.12414900E+03, 0.31502300E+03, 0.29183500E+02, 0.27627600E+01, -.47422300E+02, -.26038000E+03, -.96134300E+03, 0.34841900E+02, -.30931800E+04, 0.48838500E+03, 0.58176200E+03, 0.73864500E+03, 0.95609600E+02, -.13248300E+04, 0.12024400E+03, 0.69096200E+03, 0.84323700E+04, -.26684800E+04, -.13491500E+04, -.18890500E+04, -.36978200E+03, 0.32085500E+04, 0.19693700E+03, -.17090700E+04, 0.63470600E+03, -.31653800E+03, -.77433500E+03, -.93771200E+03, 0.81841700E+03, 0.54112400E+03, 0.47618400E+03, -.98712400E+03, -.47672500E+04, 0.13292800E+02, 0.81721000E+03, 0.10527900E+04, 0.32088800E+03, -.13121800E+04, 0.43268800E+03, 0.10357300E+04, -.31373100E+04, 0.12263200E+04, 0.85150800E+03, 0.11535000E+04, -.12875100E+03, -.16056800E+04, -.13250900E+04, 0.11555100E+04, 0.19184600E+04, -.43190100E+02, 0.29938100E+03, 0.43987400E+03, -.81424300E+03, 0.54773600E+03, -.34240700E+03, 0.52971300E+03, -.10917500E+03, 0.13618700E+03, 0.29743400E+02, 0.39894800E+02, 0.14649800E+01, -.74244300E+02, -.33311400E+03, 0.52053300E+02, -.11158500E+04, 0.12522300E+04, -.95829700E+02, -.19224100E+03, 0.31465900E+03, -.74189300E+03, -.65174500E+03, -.21228900E+03, 0.10482000E+04, -.12632200E+04, -.30284100E+03, -.30071500E+03, 0.11216500E+03, 0.50078400E+03, 0.15238100E+02, -.28733700E+03, 0.22989700E+03, 0.97194400E+03, 0.21473400E+03, 0.24193600E+03, -.31112400E+03, -.19613900E+03, -.67592300E+03, 0.26883300E+03, -.12110200E+03, 0.24767600E+03, 0.85574900E+02, -.70737800E+02, -.47837100E+03, -.25438800E+03, -.37561500E+03, -.25170600E+03, 0.74274100E+02, 0.13881000E+03, -.94234800E+03, -.28464600E+03, -.50474900E+03, -.37175900E+03, 0.36198600E+03, 0.61719100E+02, 0.72046900E+02, 0.16235100E+03, 0.25717400E+02, -.23180800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.24493400E+00, 0.35588200E-01, 0.45427800E+00, -.37945400E+00, -.66447500E-01, -.69356800E-01, -.13375700E+00, 0.24745000E+00, -.55124200E+00, 0.11252200E+00, -.97766100E-01, -.90085700E-01, 0.28002200E-02, 0.21838300E+00, -.27103100E+00, 0.15210300E+02, 0.10553600E+02, -.29435600E+02, -.13276300E+02, -.20221900E+02, 0.64479000E+01, 0.22987000E+02, 0.73721700E+02, -.32376600E+02, 0.39208800E+04, -.51566600E+03, -.39069700E+03, -.47186100E+03, -.56810900E+03, 0.11398700E+04, -.59508500E+03, -.41631100E+03, 0.34690000E+03, -.36354400E+03, -.28724900E+03, -.30175600E+03, 0.27220000E+03, 0.54965900E+03, 0.43986500E+03, -.28250800E+03, -.85814800E+03, 0.41533100E+03, 0.64046300E+03, 0.88322100E+03, -.57840600E+03, -.54233000E+03, -.46036400E+03, 0.89754400E+03, -.18992900E+04, 0.10317200E+04, 0.29361200E+03, 0.44715800E+03, 0.97226900E+02, -.58835400E+03, 0.17774400E+02, 0.40563700E+03, -.91457300E+01, 0.26605300E+02, 0.11688500E+02, 0.20282300E+02, -.32185000E+01, -.22124600E+02, -.75506100E+02, 0.33156200E+02, 0.20179200E+03, -.28644800E+02, -.99688400E+01, -.27956200E+02, -.78917900E+01, -.34630200E+02, -.34711800E+03, 0.10273100E+02, -.23039000E+04, 0.44043600E+03, 0.22091700E+03, 0.29369700E+03, 0.31614200E+03, -.64594700E+03, 0.24499700E+03, 0.24437800E+03, 0.36619700E+04, -.15972700E+04, -.58678100E+03, -.79456600E+03, -.21092800E+03, 0.12108600E+04, -.16423900E+03, -.74536500E+03, 0.40357700E+03, -.15824000E+03, -.41457900E+03, -.53073600E+03, 0.41793900E+03, 0.43062400E+03, 0.36861700E+03, -.52544700E+03, -.30570200E+04, 0.70845300E+03, 0.37718000E+03, 0.40929100E+03, 0.46942000E+03, -.85645600E+03, 0.66081200E+03, 0.39691700E+03, -.16993700E+04, 0.68871300E+03, 0.40194500E+03, 0.53762500E+03, 0.11235400E+03, -.74847800E+03, -.30085600E+03, 0.55107300E+03, 0.90833300E+03, -.29969700E+03, 0.22658800E+03, 0.36512700E+03, -.48935000E+03, 0.80437300E+02, -.56796800E+03, 0.37293700E+03, -.18410500E+02, 0.25337800E+02, 0.10416300E+02, 0.16362500E+02, -.24517600E+01, -.20241500E+02, -.55003400E+02, 0.29239000E+02, -.15547600E+04, 0.82914200E+03, -.17464200E+03, -.27660800E+03, 0.59061700E+03, -.46138500E+03, 0.43540500E+03, -.26897300E+03, 0.45013600E+03, -.42887000E+03, -.23365000E+03, -.24850200E+03, 0.18525200E+03, 0.30110900E+03, 0.32970200E+03, -.21479900E+03, 0.78417500E+02, 0.22299200E+03, 0.16050500E+03, 0.19383400E+03, -.18819500E+03, -.18956700E+03, -.35145100E+03, 0.19941800E+03, -.77570000E+02, 0.34316900E+02, -.51459500E+01, 0.95914400E+01, 0.27548600E+03, -.64686300E+02, -.57372400E+02, 0.50247600E+01, -.92368200E+01, 0.14093900E+02, 0.16257900E+03, -.51828800E+02, -.12207600E+03, 0.13312500E+03, 0.19990500E+03, -.34782300E+02, -.87670100E+01, -.79496600E+01, 0.40208900E+02, -.15263000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.32409100E+01, 0.12362200E+01, 0.35135300E+00, 0.55772700E+00, 0.13754500E+01, 0.94088300E+00, -.90277600E+00, 0.30673700E+01, -.13759100E+01, -.49414400E+01, -.39450500E+00, -.38302000E+01, -.24106700E+01, 0.76639400E+00, 0.32640500E+01, 0.70957100E+00, 0.60882700E+03, -.40550300E+03, 0.16008000E+03, 0.17575800E+03, -.48891800E+03, 0.15723500E+03, -.18155000E+03, 0.19211800E+03, -.61211200E+04, 0.26640600E+04, 0.23241800E+04, 0.33889300E+04, -.40680100E+03, -.32752400E+04, -.15733400E+04, 0.34842600E+04, 0.62096000E+04, -.49647700E+04, -.44073800E+03, -.13016200E+04, -.15858500E+04, 0.13189200E+04, -.81339500E+03, -.10411800E+04, -.71598000E+03, 0.25238900E+04, -.14428900E+03, -.84543200E+03, -.35328900E+03, -.34216500E+03, 0.21933100E+04, -.64371500E+03, -.10676200E+05, 0.69063800E+04, 0.34369800E+04, 0.30949900E+04, -.14838900E+04, -.48569100E+04, 0.22390600E+03, 0.29362100E+04, -.57394200E+03, 0.38079000E+03, -.21409200E+03, -.25463300E+03, 0.54810500E+03, -.13201600E+03, 0.19528200E+03, -.27009900E+03, -.29349900E+04, 0.84090100E+03, -.58054200E+02, 0.37088600E+03, 0.16052600E+04, -.13018100E+04, 0.38743400E+02, 0.37273800E+03, 0.95008700E+04, -.13896000E+04, -.21467600E+04, -.29668200E+04, -.47986600E+03, 0.25770200E+04, 0.57137600E+03, -.30214300E+04, 0.14964400E+05, -.79074300E+04, -.45048300E+04, -.41573100E+04, 0.16206500E+04, 0.47863700E+04, -.16651000E+04, -.39061700E+04, -.24610300E+04, 0.47836700E+03, 0.20116500E+04, 0.24937300E+04, -.10595400E+04, -.24202700E+04, -.25197900E+04, 0.25807900E+04, -.87726900E+04, -.51707800E+03, -.24904300E+03, -.74715900E+03, 0.24454500E+04, -.11649900E+04, 0.28120100E+04, -.85171900E+03, -.10573800E+05, 0.53842000E+04, -.19925500E+04, -.29114800E+04, 0.60066600E+04, -.17440800E+04, 0.41694600E+04, -.30360900E+04, -.29739900E+04, 0.33071400E+04, -.14756600E+04, -.21110000E+04, 0.22686100E+04, 0.65136500E+03, 0.19228000E+04, -.20368900E+04, -.47808800E+03, 0.30821300E+03, -.12991300E+03, -.14953600E+03, 0.38223100E+03, -.12215200E+03, 0.14116500E+03, -.16427300E+03, 0.95918100E+04, -.32002500E+04, 0.28689800E+03, 0.10530900E+04, -.20138400E+04, 0.11470300E+04, -.31661100E+04, 0.10708500E+04, 0.62003400E+04, -.42438300E+04, -.26369700E+03, -.67879000E+03, -.18209500E+04, 0.12358000E+04, -.23900300E+04, -.41998600E+03, -.38360300E+04, 0.37736600E+04, -.75558700E+03, -.72722100E+03, 0.24958100E+04, -.40428300E+03, 0.17851000E+04, -.86816300E+03, -.42989000E+03, -.32885200E+03, -.23166000E+03, 0.26972100E+03, 0.35334600E+04, 0.40704400E+03, -.51879700E+01, -.10955700E+04, -.24978400E+03, -.23016000E+03, 0.30426400E+04, -.96436800E+03, -.53660100E+02, 0.31793400E+04, 0.19746700E+02, 0.93117300E+02, -.25362800E+03, 0.10965000E+03, -.12977500E+04, -.18119700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19324600E+01, -.17628400E+00, -.31292500E+00, 0.10105700E+01, 0.25097700E+00, 0.47952200E+00, 0.27696000E+00, -.17363900E+01, 0.71583200E+00, -.16965300E+01, 0.75242800E-01, 0.90973200E+00, -.38953000E+00, 0.74016200E+00, 0.99231700E-01, -.34422100E+01, -.31350200E+00, -.30294700E+03, -.58054500E+02, -.64953600E+02, 0.99811700E+02, 0.21696500E+02, 0.14314100E+03, -.70612500E+02, 0.48356200E+04, 0.24851600E+04, -.73438300E+03, -.12661500E+04, 0.79607700E+02, 0.18941300E+04, 0.35651800E+03, -.11180000E+04, -.95080800E+03, -.19380300E+04, -.61116100E+03, -.51965100E+03, 0.11133200E+04, 0.58471900E+03, 0.10736900E+04, -.65724000E+03, -.22144700E+04, -.81810400E+03, 0.19591700E+04, 0.26708000E+04, -.18462200E+04, -.22239400E+04, -.20435400E+04, 0.28193400E+04, -.44314300E+04, 0.46348900E+03, 0.18938600E+03, 0.65377900E+03, 0.11138600E+04, -.19463400E+04, -.39599500E+03, 0.49283100E+03, -.11454600E+02, 0.30109300E+03, 0.68334000E+02, 0.82397800E+02, -.11130600E+03, -.28088300E+02, -.15186000E+03, 0.87340000E+02, 0.38606800E+02, 0.48401600E+03, 0.10939300E+03, 0.24332700E+02, -.32995000E+03, -.14299200E+03, -.55062400E+03, 0.43745900E+02, -.21770200E+04, -.70832400E+03, 0.29863200E+03, 0.54549400E+03, -.78917000E+02, -.11164600E+04, -.46379000E+03, 0.40502200E+03, 0.91032400E+04, -.20829000E+04, -.59758600E+03, -.13278900E+04, -.19373800E+04, 0.34718100E+04, 0.49371300E+03, -.11639500E+04, 0.15898700E+04, 0.15482600E+03, -.12650700E+04, -.16043100E+04, 0.11691500E+04, 0.13668000E+04, 0.13399000E+04, -.16776200E+04, -.33936300E+04, -.13848600E+04, 0.60437400E+03, 0.10105800E+04, -.83368200E+01, -.11766900E+04, 0.21235300E+03, 0.10071200E+04, -.29019300E+04, 0.17968600E+04, 0.10969400E+04, 0.16095000E+04, -.93717200E+03, -.17225400E+04, -.13709800E+04, 0.15796200E+04, 0.26528900E+04, -.15814400E+03, 0.73068100E+03, 0.10271200E+04, -.15749600E+04, 0.62815400E+03, -.11227200E+04, 0.12065000E+04, -.16895300E+02, 0.23330400E+03, 0.46419000E+02, 0.54511000E+02, -.73667800E+02, -.23128600E+02, -.11248400E+03, 0.58175300E+02, -.22993200E+04, 0.26788800E+04, 0.80834800E+02, -.12699200E+03, 0.30125300E+03, -.13387800E+04, 0.16255100E+03, -.16758400E+03, 0.35020300E+03, -.15482400E+04, 0.28787900E+02, 0.15539500E+03, -.10245100E+02, 0.10970300E+03, 0.63118400E+03, 0.17647200E+03, 0.89839700E+03, 0.19206000E+04, 0.24575500E+03, 0.22138600E+03, -.65563000E+03, 0.11039000E+02, -.66103300E+03, 0.24534200E+03, 0.55488100E+02, 0.12694900E+03, 0.37618700E+02, -.32081700E+02, -.73482500E+03, -.58182700E+03, -.32148200E+03, 0.61034400E+03, 0.29959100E+02, 0.18175000E+02, -.14688900E+04, 0.41756000E+03, -.30915000E+03, -.13575000E+03, 0.38766100E+03, -.11100400E+03, 0.33364300E+02, 0.79391100E+02, -.25211500E+03, -.13730300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.97502600E+00, 0.21130000E+00, 0.19361700E+01, 0.63051900E+00, 0.72849100E+00, 0.71521600E+00, -.21122500E+01, -.13024100E+01, -.35311200E+00, -.10370100E+01, 0.44988300E+00, 0.79378000E+00, -.53903800E+00, 0.13698100E+01, 0.14498700E+01, 0.57687900E+00, 0.15691000E+00, 0.25470300E+00, -.89667100E+02, -.88144200E+02, 0.15148700E+03, -.35454600E+02, -.15925000E+03, -.92488700E+02, 0.40468500E+04, -.23177800E+03, 0.64063600E+03, 0.68722100E+03, -.22470000E+04, 0.14192900E+04, 0.14224000E+03, 0.85079700E+03, -.15023800E+04, 0.60878200E+03, -.17359500E+03, -.20808500E+03, 0.51858800E+03, -.59109300E+03, -.19165800E+03, -.27788500E+03, 0.25114700E+04, -.63972900E+03, -.13643600E+04, -.17871200E+04, 0.14242200E+04, 0.11790000E+04, -.59835300E+03, -.17598400E+04, 0.10741700E+05, -.56733700E+04, -.25629100E+04, -.32438600E+04, 0.14716100E+03, 0.43150000E+04, 0.15781200E+03, -.30896000E+04, -.59212200E+02, 0.25077100E+02, 0.10592000E+03, 0.10172000E+03, -.16243300E+03, 0.20090600E+02, 0.18372300E+03, 0.10599600E+03, -.11258500E+03, 0.13950800E+03, 0.55449000E+03, 0.69561300E+03, -.91218100E+03, 0.45659300E+02, 0.60686000E+03, 0.69066000E+03, -.12755900E+04, -.34721600E+03, -.53127200E+03, -.63658900E+03, 0.12866000E+04, -.24427700E+03, -.11265000E+03, -.67787600E+03, -.14623900E+05, 0.80656200E+04, 0.39052100E+04, 0.48096100E+04, -.82559700E+03, -.56749400E+04, 0.15414500E+02, 0.46659900E+04, 0.11032300E+04, -.79028700E+03, 0.33266800E+03, 0.45227600E+03, -.10226500E+04, 0.30828400E+03, 0.14672200E+03, 0.46344000E+03, -.32964800E+04, 0.47720800E+03, -.64250200E+03, -.66313100E+03, 0.18059000E+04, -.12323100E+04, -.23668600E+03, -.85829300E+03, -.24909200E+04, 0.22335100E+03, 0.22052200E+03, 0.77188500E+02, 0.73769800E+02, -.47096700E+03, 0.12206700E+04, -.21718500E+02, -.25494100E+04, 0.17115800E+04, 0.67705700E+03, 0.55262000E+03, -.14931500E+03, -.88467800E+03, 0.39565600E+03, 0.56604100E+03, 0.22606000E+02, -.14861500E+02, 0.63138700E+02, 0.58828900E+02, -.11627600E+03, 0.38212400E+02, 0.12939900E+03, 0.63020900E+02, 0.33599400E+04, -.15060900E+04, -.72813800E+02, 0.36383800E+02, -.77807700E+03, 0.11028300E+04, -.34344700E+03, 0.11921600E+03, -.25420000E+04, 0.81003000E+03, 0.44728300E+03, 0.44863400E+03, 0.90955900E+02, -.93853900E+03, -.28172000E+02, 0.42049700E+03, 0.39040900E+02, 0.18616600E+03, 0.19456100E+03, 0.19687400E+03, -.30696400E+03, 0.94524200E+02, 0.28776700E+03, 0.21348100E+03, 0.57853700E+03, 0.32704500E+02, 0.34898500E+02, -.35044900E+02, -.18201300E+03, -.25704500E+03, 0.37643600E+03, 0.20129400E+03, 0.28167200E+02, -.55310300E+02, 0.30469500E+03, 0.49179500E+03, 0.50421300E+03, -.16547500E+03, -.22590800E+03, -.24985100E+02, 0.38820700E+02, -.10865700E+03, 0.25068400E+03, -.23726200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.30979300E+00, 0.12589900E-02, 0.51337300E+00, 0.73026900E-01, 0.15119600E-01, 0.65841500E-01, -.76318500E+00, -.44297900E+00, 0.33284600E+00, 0.24521600E+00, 0.75992400E-01, 0.11683100E+00, 0.71638900E-01, 0.31273600E-01, -.17356800E+00, 0.31191700E+00, 0.30100900E-01, -.48833000E-01, 0.17147100E+00, -.57900400E+01, -.62996600E+01, 0.25598100E+02, 0.87978800E+02, -.37238100E+01, 0.41943800E+04, -.12828500E+04, -.67236500E+03, -.83550800E+03, -.42306900E+03, 0.13169400E+04, -.62211400E+03, -.84722500E+03, 0.29093900E+03, -.20518700E+03, -.21888800E+03, -.22656400E+03, 0.21868200E+03, 0.46230900E+03, 0.54847300E+03, -.24077400E+03, -.39771300E+03, 0.61045300E+03, 0.59008500E+03, 0.77782000E+03, -.68118000E+03, -.24535900E+03, -.24461500E+03, 0.80651200E+03, -.18618100E+04, 0.10040000E+04, 0.30480300E+03, 0.44683800E+03, 0.80463800E+02, -.54593000E+03, 0.17640600E+03, 0.39224100E+03, 0.61468700E+01, -.46420600E+01, -.30454400E+01, 0.43800800E+01, 0.10237700E+02, -.24100900E+02, -.92715600E+02, 0.20155100E+01, 0.33722800E+03, -.10414900E+03, -.13560800E+03, -.18229100E+03, 0.10112600E+03, 0.49592800E+02, -.30115800E+03, -.18681100E+03, -.31689300E+04, 0.10346600E+04, 0.54459500E+03, 0.68146600E+03, 0.22498700E+03, -.89907800E+03, 0.41404600E+03, 0.67269800E+03, 0.36075700E+04, -.15579400E+04, -.67241800E+03, -.89345900E+03, -.44307400E+02, 0.13136400E+04, -.20268800E+03, -.82771500E+03, -.45130900E+02, -.17745200E+03, -.35600400E+03, -.44047500E+03, 0.44874800E+03, 0.17986900E+03, 0.19387500E+03, -.47596300E+03, -.21991400E+04, 0.57858500E+03, 0.43468100E+03, 0.54980200E+03, 0.86276400E+02, -.77078100E+03, 0.27061800E+03, 0.56561600E+03, -.11352000E+04, 0.22586800E+03, 0.32257500E+03, 0.51008200E+03, -.59128400E+02, -.70371100E+03, -.70748900E+03, 0.49894800E+03, 0.15155600E+04, -.43394000E+03, 0.62968100E+01, 0.80943900E+02, -.35510100E+03, 0.27838400E+03, -.54981600E+03, 0.10990100E+03, -.11706900E+02, 0.45850800E+01, 0.13415600E+01, 0.66569300E+01, 0.70444600E+01, -.23416900E+02, -.66720700E+02, 0.48419700E+01, -.16014000E+04, 0.80658000E+03, -.17738800E+02, -.94921800E+02, 0.32383900E+03, -.39882900E+03, 0.35880400E+03, -.12131300E+03, 0.49287100E+03, -.38396200E+03, -.27351600E+03, -.30438800E+03, 0.23069600E+03, 0.36066300E+03, 0.34847700E+03, -.30700900E+03, 0.59308800E+02, 0.24175800E+02, 0.14159800E+03, 0.18176300E+03, -.19953200E+03, -.20671600E+03, -.45033300E+03, 0.18602500E+03, -.13270100E+03, 0.24122000E+02, -.86909300E+01, 0.98684400E+01, -.35129300E+02, -.37074600E+02, -.34776600E+02, -.11475700E+03, -.89087100E+01, 0.29125200E+02, -.94861600E+02, -.12585600E+03, -.12487700E+03, -.16670700E+03, 0.17637200E+03, -.51570200E+02, -.10635900E+02, 0.51278700E+02, 0.63412200E+02, -.16206800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.41409300E+00, -.14001000E-01, -.78194600E-01, 0.59596900E-01, -.53935100E+00, -.22681800E+00, -.30080400E+00, 0.37277700E-01, 0.46673500E-01, 0.12132800E+00, 0.20300500E-01, -.11105300E+00, 0.10565700E+00, 0.42884400E-01, -.57624100E+00, 0.66418000E+00, -.17930200E-01, 0.92710100E-01, 0.22399900E+00, -.12037900E-01, -.11153400E+02, 0.20204000E+02, 0.68248100E+02, 0.10738600E+00, 0.25776600E+04, -.11805400E+04, -.63583400E+03, -.88781700E+03, 0.10721900E+03, 0.94594500E+03, -.57102700E+02, -.89690300E+03, 0.28479300E+03, -.34607100E+03, -.17755900E+03, -.13816900E+03, 0.10718900E+03, 0.29477000E+03, 0.39821800E+03, -.15362700E+03, 0.86103600E+02, 0.55582200E+03, 0.53418400E+03, 0.70538900E+03, -.75601700E+03, -.14733000E+03, -.22317200E+03, 0.73795500E+03, -.16091000E+04, 0.91570600E+03, 0.29028900E+03, 0.46318700E+03, 0.13646300E+02, -.53154100E+03, 0.21108500E+03, 0.42237100E+03, 0.88213600E+01, -.58015100E+01, -.22810500E+01, -.12204100E+00, 0.13411100E+02, -.18473700E+02, -.74512100E+02, -.37667700E+00, -.12185300E+02, -.56660000E+01, -.80782800E+02, -.14317700E+03, 0.12833200E+03, -.41248700E+02, -.21649500E+03, -.14467300E+03, -.16085600E+04, 0.10874700E+04, 0.43440000E+03, 0.57999800E+03, -.90588000E+02, -.54492800E+03, 0.79195700E+02, 0.59159600E+03, 0.28895600E+04, -.12998400E+04, -.62096600E+03, -.88771000E+03, 0.10724700E+03, 0.10727500E+04, -.22870200E+03, -.83854400E+03, -.17684800E+03, -.19894600E+03, -.28312100E+03, -.35277900E+03, 0.38798100E+03, 0.79928100E+02, 0.16162400E+03, -.38290900E+03, -.18164000E+04, 0.17836400E+03, 0.45097000E+03, 0.66832500E+03, -.11719500E+03, -.75401400E+03, -.95933800E+02, 0.66532200E+03, -.82739600E+03, 0.14953000E+03, 0.35161500E+03, 0.54937800E+03, -.16132400E+03, -.59621800E+03, -.73626200E+03, 0.55147700E+03, 0.12674200E+04, -.23659000E+03, -.46304200E+01, 0.64903300E+02, -.26440700E+03, 0.23498500E+03, -.46843300E+03, 0.86642000E+02, -.81161300E+01, 0.29747100E+01, 0.96094300E+00, 0.21714800E+01, 0.10074200E+02, -.18275600E+02, -.52042100E+02, 0.19018700E+01, -.94644300E+03, 0.67452000E+03, -.74429400E+02, -.18543500E+03, 0.27767800E+03, -.11889400E+03, 0.31698300E+03, -.18937700E+03, 0.45592500E+03, -.37673500E+03, -.22823100E+03, -.19943500E+03, 0.12888500E+03, 0.28556600E+03, 0.17612200E+03, -.20921900E+03, 0.15211000E+03, 0.71085800E+02, 0.11822300E+03, 0.11243600E+03, -.14513000E+03, -.97016000E+02, -.32864400E+03, 0.12413000E+03, -.13787000E+03, 0.15201800E+02, -.57900100E+01, 0.69443400E+01, -.39066200E+03, -.25243700E+02, -.13065100E+02, -.14990800E+03, -.59566100E+01, 0.17565700E+00, -.43671300E+03, -.14921000E+03, -.48204300E+02, -.31108000E+03, 0.17040700E+03, -.47696500E+02, -.74875800E+01, 0.25419800E+02, 0.21989000E+02, -.10544300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.42793800E+00, 0.54287300E-01, 0.22831700E+01, -.46068300E+00, -.16242300E+00, 0.14923300E+00, -.12571900E+01, -.48777500E+00, 0.62974500E+00, 0.14157300E+01, -.17783500E+00, 0.53219000E+00, -.17256800E+00, 0.11395400E+01, 0.10293100E+01, -.76267200E+00, 0.52663400E-01, -.21522300E+00, 0.18149600E+00, -.13293600E+01, -.59491600E-01, 0.18541500E+02, 0.29862900E+02, -.51014100E+00, -.28140800E+04, 0.12467000E+04, 0.15969700E+03, 0.42910700E+03, 0.59666300E+03, -.10990600E+04, -.72495100E+01, 0.39045600E+03, 0.15741900E+03, -.31861200E+02, -.50623200E+02, -.65819300E+02, 0.14450800E+03, 0.47697200E+02, 0.10736900E+03, -.33788400E+02, -.94183800E+03, 0.30046600E+03, 0.37574300E+02, 0.86942100E+02, 0.12409500E+03, -.36761800E+03, 0.82662100E+02, 0.51508100E+02, -.17494000E+04, 0.86251000E+03, 0.51265100E+03, 0.64336500E+03, -.33431400E+02, -.83121900E+03, -.55867900E+03, 0.69273000E+03, -.21831800E+00, 0.50034500E+00, -.10993000E+01, -.13261600E+01, 0.17856100E+01, -.19666900E+02, -.31560000E+02, -.10153200E+01, 0.34907500E+03, -.21481600E+03, -.98521600E+01, 0.18413100E+02, -.55978200E+02, -.31700400E+02, -.26757800E+03, 0.26308300E+02, 0.61768600E+03, -.58114000E+03, 0.14447600E+02, -.69102000E+02, -.28351000E+03, 0.21984700E+03, 0.10278300E+03, -.84162700E+02, 0.20791000E+04, -.13563900E+04, -.70777500E+03, -.82017200E+03, 0.14843100E+03, 0.92701300E+03, 0.69603100E+03, -.89069100E+03, 0.17399900E+03, -.14630200E+02, -.64433600E+02, -.69760600E+02, 0.13211400E+03, 0.38275000E+02, -.94025100E+01, -.46196200E+02, 0.25200600E+04, -.72799600E+03, -.38767200E+01, -.25019200E+03, -.74273800E+03, 0.10173200E+04, 0.59836900E+02, -.20776800E+03, 0.73961800E+03, -.32260300E+03, -.85059600E+02, -.22471100E+03, -.15731500E+03, 0.34272500E+03, 0.14354500E+03, -.22294700E+03, 0.50086400E+03, -.23151600E+03, -.12561800E+03, -.15310100E+03, -.58102400E+02, 0.18584300E+03, 0.24160200E+02, -.16315300E+03, -.48301900E+01, 0.41023600E+01, 0.23294200E+01, 0.25705600E+01, -.10187100E+01, -.17041900E+02, -.26187200E+02, 0.30105800E+01, -.13235700E+04, 0.63125500E+03, 0.21536800E+03, 0.31731600E+03, 0.66012700E+02, -.51373900E+03, -.74704200E+02, 0.27632400E+03, 0.11686600E+03, -.84389800E+01, -.50917400E+02, -.75556700E+02, 0.11158600E+03, 0.92442400E+02, 0.46123400E+02, -.72415900E+02, -.40177500E+02, -.84674300E+02, -.34217700E+02, -.30691900E+02, -.13655200E+02, -.27108600E+02, 0.22562000E+02, -.43939000E+02, -.18576300E+02, 0.20489000E+01, -.83849200E+01, 0.85628100E+01, 0.36229600E+03, -.26795900E+02, -.51279200E+02, 0.29493000E+03, -.83798300E+01, 0.23326500E+02, 0.19950100E+03, 0.75904300E+02, -.10245800E+03, 0.41635600E+03, -.22835700E+02, -.72813200E+01, -.92219700E+01, 0.27951300E+02, 0.28972400E+02, -.17647200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.62421000E+00, -.13528200E-01, 0.15130900E+00, 0.32971400E+00, -.12974000E+00, 0.20203000E+00, -.37105000E+00, -.52511600E+00, -.28504700E-01, 0.56353700E+00, -.31704700E-01, 0.39899100E+00, 0.29721000E+00, -.43955800E+00, -.56813200E+00, 0.61113800E+00, -.95596800E-01, -.22081400E+00, -.50478600E-01, -.20071900E+00, -.25952700E-01, 0.77196500E+00, 0.94005000E+02, 0.36756000E+01, 0.67635200E+04, -.13423600E+04, -.87156700E+03, -.16994800E+04, -.26789300E+03, 0.26246600E+04, -.38168400E+03, -.17143500E+04, -.50547300E+03, 0.45467900E+03, -.11876300E+03, -.64004600E+02, 0.20134400E+03, 0.29066100E+03, 0.62475200E+03, -.13360100E+03, -.28705700E+03, 0.12476400E+03, 0.74725300E+03, 0.91249900E+03, -.89923100E+03, -.13127400E+03, -.71011200E+02, 0.97159500E+03, -.90079900E+03, 0.24164600E+03, -.14207900E+03, -.77717900E+02, 0.37460900E+03, -.11802000E+03, 0.77705500E+03, -.22642300E+03, 0.77133400E+01, -.43997300E+01, -.23502100E+01, -.20099500E-01, 0.34033300E+00, 0.25159500E+01, -.10214500E+03, -.38715400E+01, -.21695000E+03, 0.15434300E+03, -.18442200E+03, -.31334600E+03, 0.24255400E+03, 0.12059200E+03, 0.41159800E+02, -.34737000E+03, -.49649800E+04, 0.95409300E+03, 0.87709600E+03, 0.13331800E+04, 0.71752200E+02, -.16516300E+04, 0.19359300E+03, 0.13473500E+04, 0.25182200E+04, -.50615600E+03, -.48387700E+02, -.33406200E+03, -.42521700E+03, 0.10196900E+04, -.87204900E+03, -.16106200E+03, -.52150500E+03, 0.25029800E+03, -.29869000E+03, -.39737900E+03, 0.50258600E+03, 0.49138000E+02, 0.14594000E+03, -.49030800E+03, -.19036900E+04, 0.48593600E+03, -.11584500E+03, 0.48368400E+03, 0.24767700E+03, -.10089600E+04, -.44679100E+02, 0.53556200E+03, -.12089900E+04, 0.72455200E+02, 0.79864300E+02, 0.51096200E+03, -.83447400E+02, -.85591400E+03, -.10551400E+04, 0.50864400E+03, 0.17439700E+04, -.90459600E+03, -.11078000E+03, -.81786700E+02, -.18370400E+03, 0.45007700E+03, -.49078000E+03, -.19776700E+02, -.50797200E+01, 0.11072700E+01, 0.27698300E+00, 0.17782000E+01, 0.11188500E+01, -.22809500E+01, -.72235800E+02, -.11767600E+01, -.18628500E+04, 0.41134500E+03, 0.34885100E+03, 0.23257100E+03, -.10849000E+03, -.66894100E+03, 0.15525100E+03, 0.21054300E+03, 0.10717300E+03, -.22688100E+03, -.23273800E+03, -.26009000E+03, 0.26442500E+03, 0.17293200E+03, 0.49446900E+03, -.27079300E+03, 0.67392100E+02, -.71541800E+02, 0.19404700E+03, 0.21763900E+03, -.28279900E+03, -.18325800E+03, -.60725600E+03, 0.23461600E+03, -.15977600E+03, 0.94718300E+01, -.51698000E+01, 0.47851600E+01, -.57154500E+03, -.22212700E+02, -.11789700E+03, -.35024700E+03, -.37796200E+01, -.14835300E+02, -.98091600E+03, -.14855800E+03, -.17217400E+03, -.45789300E+03, 0.12077800E+03, -.29898100E+02, -.57226100E+01, 0.13324300E+03, 0.92294400E+02, -.21698900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13970500E+01, 0.51847800E-01, 0.52260600E+00, -.13914900E+01, 0.60650800E+00, -.51257800E+00, 0.10174900E+01, 0.12618100E+01, 0.43401600E+00, 0.19899300E+01, -.24463200E+00, -.85287600E+00, -.33971800E+00, 0.11983000E+00, 0.13619300E+01, -.23924000E+01, 0.27633500E+00, -.25869900E+00, -.12144700E+01, 0.67399900E+00, 0.59560200E+00, -.49945200E+00, -.83152300E+00, -.88070500E+01, -.20071000E+04, 0.66193400E+04, -.17521000E+03, 0.78439200E+01, 0.89611700E+03, -.48011700E+03, 0.10461300E+03, 0.12411600E+03, 0.26439800E+03, -.41106800E+03, 0.29967700E+00, 0.66824100E+02, -.19386300E+02, -.20047400E+03, -.21860000E+03, 0.73677300E+02, 0.96777600E+02, 0.74810200E+03, 0.36385600E+03, 0.34830000E+03, -.46243400E+03, -.47730200E+03, -.20181000E+03, 0.26923000E+03, -.15225400E+04, -.49328200E+03, 0.13386500E+04, 0.15990900E+04, -.10023100E+04, -.12414300E+04, -.77436400E+03, 0.17578000E+04, 0.23307200E+01, -.65800000E+01, 0.22846400E+01, 0.31740500E+01, -.20238000E+01, -.29795800E+01, -.67056700E+01, 0.11609300E+02, 0.50189300E+02, 0.47242000E+03, -.23819500E+01, -.65608900E+01, 0.15305100E+02, 0.40780900E+02, -.32017900E+02, 0.26991800E+02, 0.16328100E+04, -.37774700E+04, 0.16880300E+03, 0.87853900E+02, -.73797500E+03, 0.13354200E+03, -.22893900E+03, 0.84525900E+02, 0.14591900E+04, 0.16404100E+04, -.13867800E+04, -.15927800E+04, 0.10636800E+04, 0.97444100E+03, 0.52672300E+03, -.17588000E+04, 0.80468000E+02, -.45097700E+03, 0.10067900E+03, 0.16208800E+03, -.55224800E+02, -.57351200E+02, -.13886000E+03, 0.24270200E+03, 0.20987400E+04, -.38502500E+04, -.13674400E+03, -.42693100E+03, -.36696600E+03, 0.93273600E+03, 0.39562600E+03, -.55060800E+03, 0.13268900E+04, -.22787300E+04, 0.61784600E+02, -.12441600E+03, -.34766200E+03, 0.53667300E+03, 0.34562500E+03, -.12612000E+03, -.53187500E+02, 0.70951700E+03, -.16814600E+02, -.27729600E+02, 0.18947800E+02, -.77449700E+01, -.17769300E+02, -.65764100E+02, -.50288000E+00, -.78459500E+01, 0.29968400E+01, 0.38750600E+01, -.28845000E+01, -.24905000E+01, -.46072200E+01, 0.10637100E+02, 0.10960500E+04, -.26103300E+03, 0.39719000E+03, 0.47816000E+03, -.68083200E+03, -.10263100E+02, -.82013300E+03, 0.53897900E+03, -.18318500E+03, -.35756600E+03, 0.20264800E+03, 0.27923700E+03, -.80017200E+02, -.37530200E+03, -.54003200E+03, 0.18015400E+03, 0.34653900E+03, 0.14406800E+03, -.12851800E+03, -.16671600E+03, -.40510100E+01, 0.30691100E+03, 0.21268700E+03, -.10149800E+03, -.10081700E+02, -.16788600E+02, -.10361300E+02, 0.11329600E+02, 0.56260800E+03, -.44504100E+02, -.85659300E+01, -.17021300E+03, -.11431300E+02, -.20920600E+02, -.41133800E+03, -.24309900E+03, 0.24648400E+01, 0.12744900E+04, -.88843800E+02, -.53237200E+02, -.11021100E+02, 0.58527300E+02, -.18512200E+03, 0.83629800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13343700E+01, 0.26645500E-01, -.28962800E+01, -.11575200E+01, 0.24888500E+00, -.53822300E+00, 0.21174600E+01, 0.13890000E+01, 0.94735600E-02, 0.12763700E-01, -.16919500E+00, -.10417500E+01, -.27645700E+00, -.70194700E+00, 0.57248200E+00, -.29628400E+01, -.55551800E-01, -.24190800E+00, -.11602500E+01, -.16864100E+01, 0.49899300E+00, -.11120900E+01, 0.78727600E+00, 0.13270100E+00, -.17160900E+05, 0.51824600E+04, 0.20321500E+04, 0.35183200E+04, 0.23525000E+04, -.67634800E+04, -.72006500E+03, 0.33349500E+04, -.59580500E+02, 0.32668800E+03, 0.30879700E+03, 0.29101100E+03, -.84456800E+01, -.17593800E+03, -.57447000E+03, 0.43917500E+03, -.38133300E+04, 0.65969100E+03, -.33133300E+03, -.43505500E+03, 0.12410800E+04, -.91051200E+03, 0.95793800E+03, -.66071300E+03, -.39624500E+04, 0.17321300E+04, 0.14101500E+04, 0.15698300E+04, -.14881900E+03, -.19392000E+04, -.16094400E+04, 0.17638200E+04, -.43518600E+01, 0.82226100E+01, -.65648100E+00, -.49556200E+01, 0.29959500E+01, -.32686900E+00, 0.91660600E+00, -.49570700E+01, 0.75749900E+03, -.48272500E+03, 0.18360600E+03, 0.34079500E+03, -.30906000E+03, -.63645700E+02, -.57423700E+03, 0.37211900E+03, 0.79227500E+04, -.31323500E+04, -.10827700E+04, -.17649800E+04, -.11768300E+04, 0.31209000E+04, 0.48622600E+03, -.17617100E+04, 0.25105000E+04, -.25495600E+04, -.13989400E+04, -.13171800E+04, 0.31387900E+03, 0.12076100E+04, 0.15441000E+04, -.16087600E+04, 0.46430000E+03, 0.31188400E+03, 0.32911900E+03, 0.44456600E+03, -.19296700E+03, -.65232000E+02, -.48967600E+03, 0.60955500E+03, 0.10742500E+05, -.21416100E+04, -.99850400E+03, -.22183400E+04, -.15244300E+04, 0.46312500E+04, 0.13297700E+04, -.20419800E+04, 0.38226400E+04, -.73108000E+03, -.72691300E+03, -.15127300E+04, -.26948000E+02, 0.22353000E+04, 0.17709600E+04, -.14855000E+04, -.25857500E+03, -.38253400E+03, -.43032900E+03, -.59477100E+03, 0.34309500E+03, 0.26934600E+03, 0.64940200E+03, -.70330000E+03, -.15248700E+01, 0.91670000E+01, 0.37451200E+01, 0.22077700E+01, -.34976800E+01, -.25204300E+01, -.72597500E+01, 0.24603900E+01, -.21688700E+04, 0.11489500E+04, 0.42749300E+03, 0.69519600E+03, 0.14557600E+03, -.10402900E+04, -.14469800E+03, 0.64555900E+03, 0.18392700E+03, 0.48745400E+03, 0.12558100E+03, 0.25820100E+02, 0.34749100E+01, -.56355700E+02, -.31363200E+03, 0.71207000E+02, -.27280500E+03, -.39197500E+03, -.26741300E+03, -.27885300E+03, 0.25248200E+03, 0.11228300E+03, 0.62995300E+03, -.34055600E+03, 0.51946900E+02, -.39542800E+02, -.28087300E+02, 0.28886400E+02, 0.26576200E+04, 0.76580800E+02, -.19236100E+03, 0.80888100E+03, -.28804000E+02, 0.30848400E+02, 0.25116000E+04, 0.21360200E+03, -.39608300E+03, 0.21768400E+04, -.27264900E+03, 0.60913100E+02, -.28760800E+02, 0.47466700E+00, -.13712300E+02, 0.16082500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.83549900E+00, -.11339900E-01, 0.15501800E+01, 0.61447300E+00, 0.29257000E-01, 0.34138500E+00, -.10235300E+01, -.57821300E+00, -.19949800E+00, -.15907500E+00, 0.43592700E-01, 0.31471100E+00, -.26503100E+00, 0.54507100E+00, 0.89140800E+00, 0.91734100E+00, 0.14205900E+00, 0.94056500E-01, 0.75925100E+00, 0.46055300E-01, 0.34592900E-01, -.25481700E+00, -.47852800E+00, -.12257800E+00, -.23083100E+00, 0.26614100E+04, 0.38100900E+03, 0.40425600E+03, -.34146200E+03, -.18600000E+03, -.60323900E+03, 0.43727300E+03, 0.20146400E+03, 0.59103100E+02, -.14085400E+02, -.44065500E+02, 0.83516600E+02, 0.98305700E+02, 0.96425000E+01, -.41291500E+01, -.46419500E+03, -.13098800E+03, -.23381600E+02, 0.65069500E+02, 0.74278300E+02, -.20859600E+03, 0.33040300E+02, -.64702000E+01, -.52700200E+03, -.12989800E+03, 0.39135300E+03, 0.44077100E+03, -.17552900E+03, -.34390500E+03, -.31141400E+03, 0.46625100E+03, -.48467200E+00, -.17981500E+01, -.76169100E+00, -.51257100E+00, 0.13810500E+01, -.54068500E+00, 0.62237800E+00, -.72051100E+00, -.36569000E+02, 0.12616200E+03, -.21863900E+02, -.40155800E+02, 0.52059900E+02, 0.30925700E+02, 0.10560200E+03, -.37758800E+02, -.13505500E+04, -.16062700E+04, -.16139200E+02, 0.38923500E+02, 0.29285700E+03, -.38313600E+03, 0.34189200E+03, -.95793300E+01, -.20924700E+01, 0.43314100E+03, -.24653200E+03, -.24988300E+03, 0.16184400E+03, 0.12772100E+03, 0.22655000E+03, -.27434800E+03, -.52055500E+02, 0.16616300E+03, 0.11603200E+03, 0.70117000E+02, -.92245900E+01, -.29052300E+02, -.64355500E+02, 0.10947100E+03, 0.22168300E+04, -.12523600E+04, -.58990100E+03, -.70658300E+03, -.14628600E+02, 0.10155300E+04, 0.50297200E+03, -.69726600E+03, 0.42932600E+03, -.86529600E+03, -.34130400E+03, -.36826600E+03, 0.15490800E+03, 0.32538500E+03, 0.53538600E+03, -.40456400E+03, 0.24444000E+02, -.70168800E+02, 0.27689700E+02, 0.86550200E+02, -.12750300E+03, -.49025100E+02, -.63731900E+02, 0.64622300E+02, -.87757400E+00, -.46554500E+00, 0.13558300E+01, 0.16128100E+01, -.80184400E+00, -.12691600E+01, -.23188700E+01, 0.15764000E+01, -.57813300E+03, -.36042000E+02, 0.14537900E+03, 0.16037600E+03, -.15637200E+02, -.31602900E+03, -.10606000E+03, 0.13845200E+03, -.48569600E+02, -.10278100E+03, 0.50425600E+02, 0.28878300E+02, 0.40619100E+02, -.83139100E+02, -.49977900E+02, 0.20887000E+02, -.61006400E+02, -.61274200E+02, -.51442200E+02, -.23732600E+02, -.67475200E+01, -.68892600E+01, 0.30822700E+02, -.26417500E+02, 0.31029100E+00, 0.13539100E+02, -.19257400E+01, 0.23157500E+01, 0.76636400E+03, -.15766900E+02, -.65680500E+02, 0.27401300E+02, -.22974600E+01, -.17066700E+02, 0.43651300E+03, -.11727100E+02, -.21609200E+02, 0.77302000E+03, -.12044400E+03, -.14749700E+02, -.22979100E+01, 0.35733600E+02, -.19262100E+02, 0.13760800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43472100E+00, -.21221900E-01, -.19000800E+00, 0.50862900E+00, -.16223400E+00, 0.20671800E+00, -.28461700E+00, -.99127100E-01, 0.14377400E+00, 0.20619900E+00, -.32741000E-02, 0.17524500E+00, 0.20548200E+00, -.98315600E-01, -.18423800E+00, 0.65656400E+00, -.10303600E+00, -.14009800E+00, 0.17546100E+00, -.48433900E+00, 0.47791300E+00, -.53305800E-01, 0.50145500E-01, 0.60653400E-01, 0.35013700E-01, -.43706000E+00, 0.48368200E+03, 0.35425200E+03, -.35323600E+03, -.16890600E+03, -.36849700E+03, 0.37046600E+03, 0.67027800E+02, 0.17551300E+03, -.15417400E+02, -.34795300E+02, 0.62351000E+02, 0.78203300E+02, 0.10222400E+02, -.73593700E+01, -.27372100E+03, -.49971700E+03, -.10847100E+03, -.38691400E+02, 0.11403900E+03, -.71380700E+02, 0.72238800E+02, -.95513800E+02, -.63806100E+03, 0.17640300E+03, 0.10698500E+03, 0.13253900E+03, 0.13528100E+03, -.19190900E+03, 0.39968400E+02, 0.11868400E+03, -.72910800E+00, 0.96648200E+00, -.13255400E+01, -.62461200E+00, 0.15895900E+01, -.10685700E+00, 0.78919700E+00, -.60138200E+00, -.12521900E+03, 0.10072900E+02, -.53097200E+02, -.88995800E+02, 0.85229800E+02, 0.18897600E+02, 0.15894800E+03, -.94124700E+02, -.12880700E+04, -.10017200E+03, -.11753600E+03, -.99463800E+01, 0.37845700E+03, -.33093100E+03, 0.28303700E+03, -.53312100E+02, -.20038400E+03, -.20618700E+03, 0.38734200E+02, 0.11615500E+02, -.22111100E+02, -.94507700E+02, -.31369600E+02, 0.18649500E+02, -.19049800E+02, 0.27762500E+03, 0.62515700E+02, 0.90432200E+00, 0.97610000E+01, 0.26182000E+02, 0.40555700E+02, 0.22097600E+02, 0.19311500E+04, 0.10611500E+03, -.57867900E+03, -.50423500E+03, -.11047100E+03, 0.78463100E+03, 0.15357000E+03, -.47212300E+03, 0.32927500E+03, -.17134400E+03, -.37237800E+03, -.27647100E+03, 0.97884100E+02, 0.21355900E+03, 0.30320500E+03, -.28991800E+03, -.26650700E+02, -.28301600E+03, 0.15540200E+01, 0.48207800E+02, -.44907600E+02, -.30303900E+02, -.12182400E+02, 0.30438100E+02, -.19866600E+00, 0.27442300E+01, 0.80546800E+00, 0.12202900E+01, -.39160000E+00, -.52396300E+00, -.14155700E+01, 0.13412700E+01, -.57500800E+03, 0.11076700E+02, -.16244300E+02, -.61780200E+02, 0.15715200E+03, -.18107400E+03, 0.16629700E+03, -.86731900E+02, 0.45527600E+02, 0.54536900E+02, -.31745500E+02, -.69534100E+02, 0.62785600E+02, 0.43752000E+02, 0.10284300E+03, -.62098400E+02, -.10975000E+03, -.15983900E+03, -.17538200E+02, 0.12750400E+02, -.57228100E+01, -.63524600E+02, -.80007000E+01, 0.14801600E+01, -.63119800E+01, 0.10371700E+02, -.10926400E+01, 0.14622700E+01, 0.40760700E+03, 0.10523000E+02, -.66850900E+02, 0.32245000E+02, -.14408300E+01, -.17263700E+02, 0.39462000E+03, 0.15133200E+02, 0.16795800E+02, 0.28308300E+03, -.84102600E+02, 0.14709100E+02, -.14289300E+01, 0.14025400E+02, 0.44780700E+02, -.47249000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20591500E+00, -.57174800E-01, -.19823400E+01, 0.58485600E+00, -.16307700E+00, -.11427800E+00, 0.55496600E+00, 0.25260300E+00, -.50711900E+00, -.26336400E+00, -.21427500E-01, -.11972600E+00, -.77128800E-02, 0.33088100E+00, -.12688900E-01, 0.81190800E+00, -.34954300E-01, 0.18700600E+00, 0.66410100E-01, -.38276400E+00, 0.60026000E+00, -.55475100E+00, -.37924400E+00, -.21947400E+00, -.16840600E+00, 0.37164400E+00, 0.78450200E-01, 0.15326400E+03, -.72526000E+02, -.85580900E+02, -.45710200E+03, 0.17615300E+03, -.18613300E+02, -.22248400E+03, 0.45071300E+02, 0.71152600E+02, -.11461200E+02, -.51767900E+02, -.33633000E+02, 0.74663700E+02, -.32132200E+03, 0.84867400E+03, 0.64868400E+02, 0.12975100E+03, -.19935500E+02, 0.43866700E+01, -.12021000E+03, 0.11707700E+03, 0.58500700E+03, -.28341500E+03, 0.24416100E+03, 0.29787400E+03, -.38791400E+03, 0.13580600E+03, -.44178000E+03, 0.38069900E+03, -.10778000E+01, -.63039600E+00, -.22895400E-01, 0.34039400E+00, -.33946800E+00, -.12527700E+01, -.98551600E+00, 0.76677000E-01, 0.23350500E+02, 0.78327800E+02, 0.15919000E+02, 0.25683800E+02, -.45355300E+01, 0.15930200E+02, -.45980600E+02, 0.35556600E+02, 0.71445200E+02, 0.29070600E+03, 0.42793900E+02, -.21535100E+02, -.99017200E+02, 0.24493600E+03, 0.30827900E+03, -.25095300E+02, -.93485200E+03, 0.72270400E+03, -.25189000E+03, -.26510800E+03, 0.44129000E+03, -.99535100E+02, 0.44659500E+03, -.36508800E+03, 0.10191700E+03, -.38388300E+03, 0.85481200E+02, 0.10568200E+03, -.90962600E+02, -.13040500E+02, -.16389500E+03, 0.13647100E+03, -.92070000E+03, -.20936900E+03, 0.11447400E+03, 0.39505400E+01, 0.16020700E+03, -.29433100E+03, 0.40101500E+03, -.46817900E+02, -.10614900E+03, -.14475400E+03, -.59171900E+02, -.15731400E+03, 0.11597400E+03, 0.13816600E+03, 0.40454000E+03, -.16765400E+03, 0.55332300E+03, 0.22034400E+03, -.14268200E+03, -.14063300E+03, -.73153900E+01, 0.81934300E+02, -.11400000E+03, -.15509800E+03, 0.47364700E+00, -.14909400E+01, 0.52730700E+00, 0.58795300E+00, -.80769100E+00, -.44595800E+00, -.84037300E+00, 0.68673900E+00, -.15970500E+03, 0.46988000E+03, 0.15834300E+03, 0.16607400E+03, -.20916300E+03, 0.60428900E+02, -.39374600E+02, 0.18443500E+03, 0.14415000E+02, -.10641100E+03, 0.24698700E+02, 0.55653000E+02, -.47198500E+02, -.28201900E+02, -.20584200E+03, 0.50365000E+02, 0.11024700E+02, 0.12065300E+03, -.41098100E+02, -.52451100E+02, 0.23876900E+02, 0.39515400E+02, 0.10706700E+03, -.53841400E+02, 0.31814900E+01, -.82812200E+01, -.28078500E+01, 0.28319900E+01, 0.57796000E+03, -.20855100E+02, 0.87829400E+02, 0.49813200E+02, -.28362400E+01, -.84871500E+01, 0.58605200E+03, -.34142200E+02, -.94388100E+01, 0.52770200E+03, -.46387100E+02, -.52575100E+02, -.27714900E+01, 0.28265900E+01, -.27660900E+02, 0.30303000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11115300E+01, -.38928600E-01, 0.25451900E+01, 0.98105500E+00, -.14201200E+00, 0.49014200E+00, -.17684600E+01, -.12281200E+01, 0.32095500E+00, 0.63977500E+00, 0.17898700E+00, 0.11552900E+01, 0.47861100E+00, 0.55951900E+00, -.58988300E+00, 0.30970000E+01, -.17047600E-01, 0.12216900E-01, 0.84502300E+00, -.11664200E+00, -.74013900E+00, 0.17148600E+01, 0.31715100E+00, -.76915600E-01, -.81969100E+00, -.84730000E+00, 0.18756400E+00, 0.20811600E+01, -.21990500E+03, -.67958600E+02, 0.56936300E+03, 0.10856900E+02, 0.31732500E+03, -.25808500E+03, -.11386700E+03, -.17800000E+03, 0.61376500E+01, 0.19307000E+03, 0.14087000E+03, -.15386200E+03, 0.12962000E+04, -.55634600E+03, 0.13827000E+02, -.42670700E+02, -.36105500E+03, 0.87858300E+02, -.62654500E+02, -.89054900E+01, -.19742000E+03, 0.31026300E+03, -.55384700E+03, -.64158100E+03, 0.49941500E+03, 0.39780400E+02, 0.85331900E+03, -.76540700E+03, 0.25535500E+01, -.32566400E+01, 0.65013000E-01, -.85449700E+00, 0.12749600E+01, 0.33353500E+01, 0.29923000E+01, -.35218900E+00, 0.62600100E+02, -.19011100E+03, 0.18876400E+02, 0.18847900E+02, -.66988800E+02, -.50360700E+02, -.62051000E+02, 0.16333200E+02, 0.88919100E+03, -.25590200E+03, -.25942900E+03, -.30920700E+03, 0.29058500E+03, 0.54651100E+01, -.41236400E+03, -.31145100E+03, 0.12179100E+04, -.81268300E+03, 0.58205700E+03, 0.66013600E+03, -.78095700E+03, -.86624400E+02, -.10219100E+04, 0.85229900E+03, -.41353600E+02, 0.16664000E+02, -.22025200E+03, -.26708400E+03, 0.18350700E+03, 0.97795300E+02, 0.33571300E+03, -.30226000E+03, -.92066900E+03, -.66288800E+02, 0.37474300E+02, 0.88756700E+02, 0.48858000E+03, -.20359200E+03, -.44034800E+03, 0.77522500E+02, -.93719000E+03, 0.31515300E+03, 0.28458700E+03, 0.39385300E+03, 0.10944900E+03, -.58135900E+03, -.64285500E+03, 0.35281900E+03, -.74820300E+03, 0.34364500E+03, 0.37701000E+03, 0.43227700E+03, -.21763600E+03, -.18672100E+03, -.69353300E+02, 0.45978400E+03, -.19048200E+01, -.45577400E+00, -.19326600E+01, -.24297700E+01, 0.27725000E+01, 0.14739900E+01, 0.41435600E+01, -.28687500E+01, 0.10143100E+04, -.61856400E+03, -.49440000E+03, -.54917300E+03, 0.47211500E+03, 0.26806700E+03, 0.16882300E+03, -.55083100E+03, 0.77949800E+02, -.18642100E+03, 0.30096400E+02, 0.21940100E+02, -.53838000E+02, 0.19909700E+02, 0.11857400E+03, 0.40785600E+02, -.12150000E+02, 0.17910900E+03, 0.74909000E+02, 0.87507400E+02, -.88857000E+01, -.53727500E+02, -.15825000E+03, 0.87051000E+02, -.70461300E+01, 0.26005300E+02, 0.30058200E+01, -.32631700E+01, -.79871400E+03, -.25141200E+02, -.45749400E+02, -.21174200E+03, 0.32780100E+01, 0.22852700E+02, -.61080400E+03, -.97808100E+01, 0.11065500E+03, -.78933200E+03, 0.10835400E+03, 0.25234600E+02, 0.30667400E+01, -.42501900E+02, -.57782500E+02, -.46873800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12643200E+01, 0.16240500E-02, -.16069300E+00, -.61809300E+00, -.39224400E+00, -.60719900E+00, 0.23829400E+00, 0.87822800E+00, 0.21747700E+00, -.77480200E-01, -.20718000E+00, -.50478000E+00, -.92240900E-01, -.44916900E+00, -.77759600E+00, -.11310400E+01, 0.98112400E-01, 0.35119500E+00, -.22003000E+00, 0.17921500E+01, -.95075900E+00, 0.39790400E-01, -.97215700E+00, 0.35962600E+00, -.87198200E-01, -.34435600E+00, -.13757700E+00, -.97118100E-01, -.76169600E-01, 0.14133600E+03, 0.26235700E+03, 0.71209700E+02, 0.78387600E+02, -.23517500E+03, -.16895700E+02, -.88189200E+01, -.44024000E+02, 0.28159900E+02, 0.17002100E+02, -.84095200E+01, 0.18570300E+03, 0.34575400E+03, 0.14247800E+03, 0.18942200E+03, -.16959200E+03, 0.63856300E+01, -.20572000E+03, 0.20889800E+03, 0.77534800E+03, -.83559500E+02, -.29145500E+03, -.29609200E+03, 0.51259400E+02, 0.33259100E+03, 0.67391400E+02, -.31607600E+03, 0.15425600E+01, -.42712800E+01, 0.71840000E+00, 0.10085700E+01, -.11318700E+01, 0.35836000E+00, 0.27901900E-01, 0.97926700E+00, -.15331300E+03, 0.74888500E+02, 0.10273400E+02, -.11567200E+01, 0.28389700E+02, -.63598800E+01, 0.21889600E+02, 0.58764300E+01, 0.69625700E+03, 0.80124500E+02, -.83464100E+02, -.10855200E+03, -.58624000E+02, 0.16841900E+03, -.20430000E+03, -.13301100E+03, -.22061600E+03, 0.43313600E+02, 0.27044300E+03, 0.26323500E+03, -.20384300E+03, -.12192600E+03, -.78112700E+02, 0.30284600E+03, 0.12043300E+03, -.23310500E+03, -.97029800E+02, -.10796900E+03, 0.40404000E+02, 0.79810000E+02, 0.65081300E+02, -.11030400E+03, -.15832200E+04, 0.32730700E+02, 0.15532400E+03, 0.19212500E+03, 0.35563500E+03, -.62011300E+03, -.48728700E+00, 0.13286600E+03, -.83234200E+03, 0.13189300E+03, 0.18973000E+03, 0.23528000E+03, 0.15127400E+03, -.37375300E+03, -.11331700E+03, 0.21641300E+03, 0.26468200E+02, 0.15885600E+03, 0.97668700E+02, 0.12891600E+03, -.10338300E+03, -.48018700E+02, -.11007700E+03, 0.13276300E+03, 0.70082100E+00, -.28451600E+01, -.11518900E+01, -.11668400E+01, 0.51830400E+00, 0.41148400E+00, 0.12098700E+01, -.14528500E+01, 0.86454300E+02, 0.95064300E+02, -.67092600E+02, -.79067900E+02, 0.96330300E+02, 0.97778600E+02, 0.58940400E+02, -.73034600E+02, -.94994900E+02, -.17288600E+03, 0.33443100E+02, 0.89788700E+02, -.60049300E+02, -.45917000E+02, -.36206500E+02, 0.93239900E+02, 0.60955700E+02, 0.20454900E+03, 0.38920000E+02, 0.20812900E+02, -.14967500E+01, 0.16576500E+02, -.19748200E+02, 0.26088700E+02, -.39778300E+01, 0.79689800E+01, 0.44191300E+01, -.48382800E+01, -.22006300E+03, -.17391800E+02, 0.48338600E+02, 0.92415300E+01, 0.48124000E+01, 0.31391300E+00, -.19931300E+03, 0.38359600E+02, 0.54568500E+01, -.11844200E+03, 0.54583400E+02, -.10766300E+02, 0.46643600E+01, -.27372800E+02, -.44444800E+02, -.22543900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.28808800E-01, -.54259000E-01, -.19463100E+01, 0.90152100E+00, -.34506500E-01, 0.54809200E-01, 0.90747900E+00, 0.25981000E+00, 0.24179200E-01, -.33858200E+00, -.15488500E+00, -.54845500E+00, 0.77302900E-01, 0.20452300E-01, 0.27420000E+00, -.81758500E+00, -.11826800E+00, -.17194900E+00, -.14488500E+00, -.55007500E+00, 0.26278700E+00, -.44586700E-01, -.31357800E+00, -.16652500E+00, 0.24684000E-01, -.41786700E-01, 0.78097000E+00, -.17494000E+00, -.34188200E+00, -.31419700E+00, 0.27985000E+03, 0.19513600E+02, 0.97007900E+02, -.20741000E+03, -.59533100E+02, -.59539300E+02, -.35339900E+00, 0.63036500E+02, 0.43231900E+02, -.56664100E+02, 0.61671600E+03, -.24072400E+02, 0.61879800E+02, 0.18974300E+02, -.18570300E+03, 0.12498800E+02, -.11792400E+03, 0.43427700E+02, 0.95016400E+02, 0.89858100E+02, -.18938100E+03, -.21117500E+03, 0.86433900E+02, 0.30976900E+02, 0.28006300E+03, -.24956400E+03, 0.17685800E+01, -.10291000E+01, 0.31239600E+00, 0.80914700E-01, -.14702800E+00, 0.12591200E+01, 0.63698800E+00, 0.30516600E+00, -.35201700E+02, -.37496600E+02, 0.16974700E+02, 0.17662100E+02, -.20447600E+02, -.34240500E+02, -.37430000E+02, 0.17244100E+02, 0.10618400E+04, -.26831800E+02, -.15848200E+03, -.20466200E+03, -.44821400E+02, 0.18858600E+03, -.25427500E+03, -.18822700E+03, 0.60471500E+03, -.28763900E+03, 0.15994100E+03, 0.16027800E+03, -.23522800E+03, 0.18661300E+02, -.36922600E+03, 0.21970500E+03, 0.10912300E+03, -.15772300E+03, -.11328800E+03, -.12030700E+03, 0.49675600E+02, 0.94237600E+02, 0.15301600E+03, -.12835300E+03, -.14570300E+04, 0.65866600E+02, 0.12413100E+03, 0.15532900E+03, 0.34815200E+03, -.41257600E+03, -.46834300E+02, 0.11542900E+03, -.56058100E+03, 0.26965000E+03, 0.20162000E+03, 0.23050300E+03, 0.22771800E+02, -.31755800E+03, -.28650800E+03, 0.21346200E+03, -.27604200E+03, 0.23995900E+03, 0.14443500E+03, 0.15437800E+03, -.63212600E+02, -.29071000E+02, -.12218600E+02, 0.16717500E+03, -.34021100E+00, -.89493100E+00, -.10490800E+01, -.11567300E+01, 0.88979700E+00, 0.74606000E+00, 0.18105300E+01, -.13273900E+01, 0.64569200E+03, -.10772500E+03, -.23625600E+03, -.27891900E+03, 0.20518800E+03, 0.16686300E+03, 0.80288200E+02, -.25776000E+03, 0.61024200E+02, -.82039800E+02, 0.14374600E+02, 0.31599400E+02, -.53052300E+02, -.71292900E+01, 0.20289100E+01, 0.40611100E+02, 0.19565900E+02, 0.13849200E+03, 0.36099400E+02, 0.23813800E+02, 0.14502700E+02, -.12034600E+01, -.38380400E+02, 0.25896500E+02, -.60584900E+01, 0.92946000E+01, 0.33288200E+01, -.35677000E+01, -.29015100E+03, -.15612700E+02, 0.15123800E+02, -.90213400E+02, 0.35622700E+01, 0.10996100E+02, -.24827000E+03, -.14000300E+02, 0.57536700E+02, -.23202900E+03, 0.60803900E+02, 0.97322500E+01, 0.34725100E+01, -.31020400E+02, -.35681200E+02, -.10543700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.74669700E+00, -.19564600E-01, 0.34460400E+00, 0.40513900E+00, 0.10152000E-01, 0.28328800E+00, -.40053300E+00, -.31562500E+00, 0.36756900E-01, 0.50213800E+00, -.18494900E+00, 0.33448100E+00, 0.21499600E+00, -.59077100E+00, -.43101000E+00, -.26477000E+00, -.12052200E+00, -.12789600E+00, -.15356500E+00, -.48362400E+00, 0.22751700E-01, 0.72751500E+00, 0.89632100E+00, 0.63589400E-01, 0.18459000E-01, 0.43291900E+00, -.53765900E-02, -.72970000E-01, -.13841000E-01, 0.41179700E-01, -.10403000E+00, 0.45512300E+02, 0.31737900E+02, -.12685200E+03, -.21975800E+01, -.16242400E+01, -.15936100E+02, -.12286800E+02, -.47082300E+01, 0.28008600E+01, 0.14420200E+02, 0.16437500E+03, 0.81107400E+02, 0.11196000E+03, -.69152100E+02, -.31655800E+02, -.76702100E+02, 0.11118300E+03, 0.23661100E+03, 0.18167200E+02, -.52606300E+02, -.49303200E+02, -.30065300E+02, 0.62039500E+02, -.26081000E+02, -.54534300E+02, 0.85355400E+00, -.23867100E+01, 0.42745500E+00, 0.56051100E+00, -.57787000E+00, 0.11485600E-01, -.62805600E+00, 0.52148100E+00, -.50730400E+02, 0.14497000E+02, 0.46088700E+01, 0.15694800E+01, 0.75458300E+01, -.71952100E+01, -.16960000E+01, 0.70077300E+01, 0.47579000E+03, 0.61720800E+02, -.40401600E+02, -.58353200E+02, -.87034500E+02, 0.14734200E+03, -.33671700E+02, -.78622200E+02, -.11935500E+03, -.41227500E+02, 0.70562800E+02, 0.63466900E+02, -.33443000E+02, -.43715000E+02, -.14406000E+01, 0.73296600E+02, 0.35084500E+02, -.77585600E+02, -.22419200E+02, -.26940900E+02, 0.70167500E+01, 0.13693200E+02, 0.10162200E+02, -.17159100E+02, -.84918800E+03, -.28104300E+02, 0.77162400E+02, 0.10045600E+03, 0.19335200E+03, -.27484900E+03, 0.91572300E+02, 0.64884000E+02, -.28018200E+03, 0.36025700E+02, 0.69809700E+02, 0.88430900E+02, 0.53197700E+02, -.10371100E+03, -.10267100E+02, 0.74360800E+02, 0.33335600E+02, 0.22512200E+02, 0.24632100E+02, 0.40018800E+02, -.22993900E+02, -.52372500E+00, -.49056600E+02, 0.36759000E+02, 0.43577800E+00, -.15414300E+01, -.26471600E+00, -.25825700E+00, -.11837200E+00, 0.89226500E-01, 0.17997100E+00, -.37405000E+00, -.85666100E+02, 0.15412900E+03, 0.14543600E+02, 0.15614100E+02, 0.23333800E+02, -.79232000E+01, 0.10286800E+02, 0.15700800E+02, -.42102700E+02, -.10045100E+03, 0.35029000E+02, 0.63777900E+02, -.33209400E+02, -.34980600E+02, -.57167600E+02, 0.66638300E+02, 0.48348700E+02, 0.12151700E+03, 0.16339800E+01, -.60976300E+01, 0.41258800E+01, 0.29339900E+02, 0.17567300E+02, -.60438200E+01, -.37610300E+01, -.10984900E+01, -.11205300E+01, 0.94667800E+00, 0.17863000E+02, -.97679000E+01, 0.18200700E+02, 0.97984700E+01, -.95747600E+00, -.19892100E+01, 0.13566400E+02, 0.13471800E+02, 0.34740900E-01, 0.37671100E+02, 0.17726200E+02, 0.90893700E+00, -.10087500E+01, -.89728900E+01, -.34699900E+02, 0.79745200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.90342500E+00, -.75790900E-01, 0.18562400E+01, 0.76774500E+00, -.14611600E+00, 0.50264400E+00, -.66694900E+00, -.45669500E+00, 0.32601500E+00, 0.88041900E+00, 0.18754100E+00, 0.83997600E+00, 0.25939000E+00, 0.44037800E+00, 0.61916000E+00, -.26450800E+00, -.12448000E+00, 0.12591900E+00, 0.51870000E+00, -.42686900E+00, 0.97542500E+00, -.29778600E+00, -.32490000E+00, -.14558800E+00, 0.13008800E+00, 0.19615900E-01, 0.52655400E+00, -.62796400E+00, -.61398800E+00, -.10803900E+00, 0.14438400E+00, 0.47572700E+00, 0.23153300E+03, -.79515800E+02, -.58883700E+02, -.82081000E+02, 0.66382300E+02, 0.67612900E+02, -.12453200E+02, -.67648500E+02, 0.45088200E+03, -.15829000E+03, -.83489400E+01, -.42619200E+02, -.15999300E+03, 0.66224000E+02, 0.13867400E+03, -.31906500E+02, -.46724500E+03, 0.16266800E+03, 0.18523000E+03, 0.21356600E+03, -.15166300E+03, -.19055600E+03, 0.23110000E+03, 0.20927200E+03, 0.11818800E+01, 0.59908300E+00, -.73453800E+00, -.10924900E+01, 0.20379500E+01, 0.40001900E+00, -.89548800E+00, -.94983000E+00, -.18898800E+03, 0.71169800E+02, 0.54451800E+01, -.42634900E+01, 0.47654700E+02, -.34844300E+02, 0.60183100E+02, -.48607300E+01, 0.19855200E+02, -.15487000E+02, -.35770000E+01, -.83587500E+01, 0.24554700E+02, -.80333600E+02, -.13349600E+01, -.38641100E+01, 0.23749200E+03, 0.30213800E+02, -.17755800E+03, -.20503500E+03, 0.26216400E+03, -.80528900E+00, -.36911400E+03, -.18812400E+03, -.22560700E+03, 0.67587100E+02, 0.63600800E+02, 0.55477600E+02, 0.72467400E+01, -.68072900E+02, 0.24635400E+01, 0.54171600E+02, 0.24343000E+02, -.73152300E+02, -.76555800E+02, -.69739800E+02, 0.11322600E+03, 0.37290500E+02, -.35694900E+02, -.75915200E+02, 0.23005500E+03, 0.24229300E+02, 0.15444700E+02, 0.28258700E+02, -.84862900E+02, 0.17883700E+02, -.88359900E+02, 0.22905800E+02, -.74215400E+02, 0.10767600E+03, 0.63317500E+01, 0.15062500E+02, -.11091800E+02, -.36373600E+02, -.37228900E+02, 0.12428400E+02, -.71895800E+00, 0.41836300E+00, 0.58487000E+00, 0.82357100E+00, -.55005000E+00, -.22028500E+00, 0.85026900E-01, 0.77580600E+00, 0.19424500E+03, -.20359500E+03, -.36746700E+02, -.67309400E+02, 0.69689300E+02, 0.60757700E+02, 0.34490000E+02, -.57458100E+02, 0.20026900E+03, -.65989900E+02, -.23063300E+02, -.49470900E+02, 0.23581900E+02, 0.28145000E+02, -.83637700E+02, -.43945400E+02, -.40895500E+01, -.14528700E+02, -.15542400E+02, -.11431800E+02, 0.76683200E+01, 0.15439700E+02, 0.89362800E+01, -.13171400E+02, -.21298200E+02, -.62401400E+01, -.14895000E+02, 0.15078200E+02, -.12772000E+02, 0.45675100E+01, -.27221900E+02, -.21983900E+03, -.15038500E+02, -.19307100E+02, -.46176400E+02, -.14396500E+03, 0.57793900E+02, -.19878300E+02, 0.19625300E+02, -.44511300E+01, -.15141400E+02, 0.65503900E+01, -.20301800E+02, -.72402000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.63426100E-01, -.34190400E-01, -.96062300E+00, 0.27598300E+00, -.63086400E-03, -.63921000E-01, 0.38007400E+00, 0.42530900E-01, -.22601600E+00, -.38302900E+00, -.49347700E-01, -.26987600E+00, 0.42353400E-01, -.26575200E+00, -.28156700E+00, 0.41829600E+00, 0.41085500E-02, 0.17313200E-01, 0.60819500E-02, 0.17723800E+00, 0.12844300E+00, -.45394500E-01, 0.40761400E-01, -.12350400E-01, 0.63492000E-02, 0.10457200E+00, 0.49866300E-01, -.17593500E+00, -.11217200E+00, -.45054700E-02, -.23168600E-01, 0.13623700E+00, 0.45093500E-01, -.11328900E+03, 0.90212700E+01, 0.90864700E+01, -.11050000E+02, 0.70095600E+01, 0.28993800E+02, 0.78949100E+01, 0.10409200E+03, 0.27574200E+03, 0.26432200E+02, 0.43415600E+02, -.58887500E+02, 0.29885300E+02, -.71168100E+02, 0.52366600E+02, 0.36207500E+03, -.11608400E+03, -.52369600E+02, -.67145800E+02, -.38255300E+02, 0.13397900E+03, -.24884400E+02, -.62336000E+02, 0.30731900E+00, -.70120100E+00, 0.13266100E+00, 0.30881400E+00, -.47047200E+00, 0.18617200E+00, 0.32680700E+00, 0.30358600E+00, -.43437000E+02, 0.31588200E+02, 0.68659100E+01, 0.26837000E+01, 0.12885800E+02, -.74370000E+01, 0.11716600E+02, 0.63528700E+01, 0.36183600E+03, 0.75102400E+02, -.50372400E+02, -.59422200E+02, -.41976300E+02, 0.14051600E+03, -.18766400E+02, -.50939800E+02, -.17901600E+03, 0.20703700E+03, 0.40393100E+02, 0.55179500E+02, -.17520400E+02, -.60153600E+02, 0.16168200E+02, 0.55276900E+02, 0.22390200E+02, -.16198900E+03, 0.87032100E+00, -.41848900E+01, -.16530500E+01, 0.64616000E+01, -.13143500E+02, -.33635200E+01, -.76554200E+03, -.57545000E+02, 0.70019600E+02, 0.89471200E+02, 0.15332700E+03, -.25966500E+03, 0.55869700E+02, 0.72320300E+02, -.29954500E+03, 0.69991500E+02, 0.24533600E+02, 0.30980100E+02, 0.83563900E+02, -.86152100E+02, 0.36728400E+02, 0.27541800E+02, 0.11406600E+03, 0.13410500E+03, 0.81274000E+01, 0.18681400E+02, -.49641500E+02, 0.12660700E+02, -.46649300E+02, 0.21426600E+02, 0.12459200E+00, -.96291700E+00, -.33990600E+00, -.34373700E+00, 0.14624300E+00, 0.12764800E+00, 0.35260800E+00, -.40948900E+00, 0.11340100E+03, 0.78939200E+02, -.33642000E+02, -.41736600E+02, 0.18675900E+02, 0.76680900E+02, 0.15046500E+02, -.33198500E+02, 0.12386000E+01, -.52265500E+02, 0.15877400E+02, 0.32287900E+02, -.38395000E+02, -.84688700E+01, -.47453700E+02, 0.33380200E+02, 0.86948800E+01, 0.83472000E+02, 0.57062100E-01, -.30005700E+01, 0.89455000E+01, 0.59371000E+01, 0.68907700E+01, -.16545200E+01, 0.84145600E+00, 0.47069500E+01, 0.37469900E+01, -.38670500E+01, 0.63511400E+01, -.14661500E+02, 0.32627600E+02, -.46280700E+01, 0.38553000E+01, -.27357800E+00, 0.37543600E+02, 0.83021200E+00, 0.17153700E+02, 0.19497300E+02, 0.30721500E+01, -.17487000E+02, 0.38502900E+01, -.11989000E+02, -.15843900E+02, 0.56221100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18430100E+01, -.71787700E+00, -.13904300E+01, 0.12555900E-02, -.84944400E+00, -.67248900E+00, 0.39477400E+00, -.17466400E+01, 0.58821000E+00, -.32357300E+01, 0.10540400E+01, 0.87474800E+00, -.40571400E+00, -.61617700E-01, -.28536600E+00, -.16375000E+01, -.13244500E+00, 0.97312900E+00, 0.61131700E+00, 0.28109300E+01, -.67967600E+00, -.13311400E+01, -.76242300E+00, 0.12779200E+01, -.24031100E-01, -.50554000E+00, -.71583400E+00, -.16673700E+01, 0.28038800E+00, -.40969100E+00, -.64612000E+00, -.13356900E+01, -.11782600E+01, -.15085700E+01, 0.14040300E+03, 0.32750500E+02, -.52483700E+02, 0.89982000E+02, 0.11415500E+03, -.46999000E+01, -.64160600E+03, 0.49777000E+03, 0.20917700E+02, 0.36370600E+03, 0.10197000E+03, -.11761300E+03, -.19898500E+03, 0.45542700E+03, 0.18911300E+04, 0.11856100E+04, -.48293300E+03, -.55174100E+03, -.28757600E+02, 0.80372700E+03, -.20299300E+03, -.57946300E+03, 0.35828300E+01, -.71300800E+01, 0.12710200E+01, 0.18394300E+01, -.30449100E+01, 0.10181300E+01, -.62488900E-01, 0.19013100E+01, -.51386100E+03, -.75346700E+02, 0.52299900E+02, 0.35281700E+02, 0.13607900E+03, -.13868800E+03, 0.66846400E+02, 0.82820200E+02, 0.89913200E+03, 0.10257300E+03, -.16512800E+03, -.16118900E+03, -.13209700E+03, 0.40238900E+03, -.10598300E+03, -.19219400E+03, -.10880100E+04, -.12803500E+04, 0.43041200E+03, 0.51736400E+03, -.23392200E+03, -.49055600E+03, 0.12762300E+03, 0.55477800E+03, -.30562900E+02, 0.87824300E+02, 0.60754200E+02, -.60116600E+02, 0.33644100E+02, 0.72171100E+01, -.19589300E+02, -.62214000E+02, -.31862700E+04, 0.47704100E+03, 0.42953900E+03, 0.49991000E+03, 0.57996900E+03, -.10834100E+04, 0.37017400E+03, 0.50685000E+03, -.11570800E+04, 0.90599300E+03, 0.35771500E+02, 0.94554000E+02, 0.45628400E+03, -.26605700E+03, 0.27760900E+03, 0.13142200E+03, 0.24536000E+03, -.41024600E+03, -.23564800E+02, 0.18191600E+03, -.16617700E+03, -.17452400E+02, -.22961700E+03, 0.22025600E+03, 0.13987300E+01, -.43273000E+01, -.13263900E+01, -.16329200E+01, -.93271500E+00, 0.48033900E+00, 0.24731300E+00, -.22400300E+01, -.19084800E+04, 0.53595700E+03, 0.11477700E+03, 0.15124100E+03, 0.40178500E+03, -.52532900E+03, 0.25245300E+03, 0.13563800E+03, -.36606500E+03, -.18519800E+02, 0.11193100E+03, 0.22360300E+03, -.84286500E+02, -.12328500E+03, -.57520600E+02, 0.28594800E+03, 0.50539300E+02, 0.31266600E+03, -.85748000E+01, -.51683200E+01, 0.46038700E+02, 0.16533600E+01, 0.41622400E+02, -.28886600E+02, -.75511300E+01, 0.18262900E+02, 0.10750300E+02, -.11658900E+02, 0.10250300E+03, -.30177500E+01, 0.56776400E+02, 0.22684400E+03, 0.11592100E+02, -.55948800E+01, 0.17475200E+03, 0.12755300E+03, 0.96653500E+01, 0.15070300E+02, 0.39166600E+02, 0.30411700E+01, 0.11405600E+02, -.41718900E+02, -.37823700E+02, 0.40665000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49629800E+00, -.11680200E-01, -.22781100E+01, 0.43225200E+00, -.22738200E+00, -.21023200E+00, 0.12034400E+00, 0.82331600E+00, -.11036100E+01, 0.31187600E+00, -.57896300E+00, -.13431500E+00, 0.55225600E-01, -.22990200E+00, -.40372800E+00, -.21222500E-01, 0.77427100E-01, 0.98366000E-02, 0.10061700E+00, 0.10652700E+01, 0.11195900E-01, -.58942100E+00, 0.39565600E-01, 0.27930800E+00, 0.14049200E+00, -.76516900E-01, 0.57241200E+00, 0.33252300E+00, 0.15253800E+00, 0.38135900E-01, 0.91300100E+00, -.78348900E+00, -.44835900E+00, -.13557500E+01, 0.25538000E+00, 0.21390200E+02, -.87775900E+01, -.76907600E+01, -.14197400E+02, 0.22564600E+02, -.18036200E+03, 0.27164000E+03, 0.55273300E+02, 0.45338100E+02, 0.45885500E+02, -.29798600E+01, -.67163300E+01, 0.58552500E+02, 0.30095000E+03, -.31056900E+03, -.56615700E+02, -.57937300E+02, -.45655600E+01, 0.13088500E+03, -.90730600E+02, -.32449300E+02, -.49114400E+00, -.10545500E-01, -.42553100E+00, -.14188900E+00, -.73682500E-01, 0.15228400E-01, 0.56602000E+00, -.29825000E+00, 0.58260400E+02, 0.32736500E+02, 0.33852300E+02, 0.42748300E+02, -.20910000E+02, 0.95226500E+00, -.48820800E+02, 0.47741900E+02, 0.35568500E+03, 0.23903500E+02, -.21090400E+02, -.23301000E+02, -.12177000E+03, 0.18328100E+03, -.35674100E+02, -.29289100E+02, -.11158200E+03, 0.38346900E+03, -.23074100E+02, -.50787600E+02, 0.24678200E+02, 0.45275100E+02, 0.21676500E+03, -.82778800E+02, 0.72530100E+01, -.10248200E+03, -.47970500E+01, 0.16469000E+02, -.33268800E+00, -.86724700E+01, -.47690100E+02, 0.16229300E+02, -.74619700E+03, 0.13900900E+03, 0.77200500E+02, 0.81562400E+02, 0.16460900E+03, -.25055400E+03, 0.95610700E+02, 0.79936700E+02, -.37086200E+03, 0.19085100E+03, 0.15288100E+02, -.14822800E+02, 0.18258700E+03, -.20878000E+02, 0.19413000E+03, -.15038800E+01, 0.13930300E+03, 0.15263200E+02, 0.95005100E+01, -.88470300E+01, -.45329000E+02, -.10757200E+02, -.27351100E+02, -.15146000E+02, 0.89593200E+00, -.13888300E+01, -.56128000E+00, -.36447800E+00, -.30513700E+00, 0.23859700E+00, -.11154300E+00, -.45583700E+00, -.38568000E+03, 0.73391300E+02, 0.96205700E+02, 0.11737100E+03, -.26873700E+02, -.67685700E+02, -.30331700E+02, 0.10158200E+03, 0.49890500E+02, -.71800600E+02, -.46154300E+01, -.31650500E+01, -.11917200E+02, 0.25883600E+02, -.46857600E+02, -.61206600E+01, -.71697600E+01, 0.54307500E+02, 0.51192400E+01, -.44206900E+01, 0.57991500E+01, 0.50223100E+01, 0.28467700E+02, -.37641000E+01, 0.63167200E+01, 0.29785900E+01, 0.24879900E+01, -.27500400E+01, 0.72017500E+02, -.22094300E+01, 0.13803400E+02, 0.53568400E+02, 0.27452600E+01, -.61823400E+01, 0.86257500E+02, 0.26979500E+02, -.44253000E+02, 0.47206300E+02, 0.31440800E+01, -.15988600E+02, 0.26738900E+01, 0.51572800E+01, -.17241000E+01, 0.58645900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.80327500E+00, -.85645800E-01, -.13254900E+00, 0.66691600E+00, 0.13783300E+00, 0.28977200E+00, 0.85979500E-01, -.48315900E+00, 0.18841700E+00, -.59933800E+00, -.32729500E-01, 0.31431900E+00, -.19551200E+00, 0.41503400E+00, 0.46001400E+00, -.18788600E+01, -.32745800E-01, 0.24757000E+00, 0.27895100E+00, -.19057100E+00, 0.74428200E+00, -.19345800E+00, -.28617100E+00, 0.66953800E-01, 0.18245700E+00, 0.38947500E+00, 0.44433100E-01, -.89985500E+00, -.30341500E+00, -.24034600E+00, -.19511000E+00, -.17177300E+00, 0.10625500E+00, 0.19065500E+00, -.84428600E-01, 0.70854000E+00, -.29750000E+02, -.68133800E+01, -.32849400E+02, -.18346000E+02, 0.70704600E+01, -.21878600E+03, 0.52889900E+02, 0.12497100E+03, -.52792700E+02, -.10862500E+03, -.76078800E+02, 0.14539900E+03, 0.24393000E+03, 0.42119700E+03, -.14191400E+03, -.10025900E+03, -.10132900E+02, 0.51074200E+02, 0.31093700E+02, -.15097400E+03, 0.20983400E+01, -.26766500E+01, 0.69102200E+00, 0.93755200E+00, -.89245800E+00, 0.25029000E+00, -.12303300E+01, 0.10716500E+01, -.13732500E+03, -.84528200E+01, -.11530100E+02, -.22799400E+02, 0.22837100E+02, -.20048100E+02, 0.16382200E+02, -.18404600E+02, 0.44220500E+03, -.12280800E+03, -.53596100E+02, -.79468500E+02, -.26677800E+02, 0.58677800E+02, -.54372100E+02, -.67691600E+02, 0.22528600E+03, -.71896300E+03, 0.11662800E+03, 0.46807500E+02, -.96017500E+02, 0.11000600E+02, -.11730800E+03, 0.10311600E+03, 0.19835900E+02, 0.14619100E+03, -.35603500E+02, -.47825200E+02, 0.90646600E+01, 0.34089300E+02, 0.51526100E+02, -.56799200E+02, -.82056200E+03, 0.22876200E+03, 0.80825000E+02, 0.10126700E+03, 0.21298300E+03, -.23989000E+03, 0.11770900E+03, 0.10139100E+03, -.19312400E+03, 0.18492100E+03, 0.12421700E+03, 0.17680900E+03, -.46448200E+02, -.19386100E+03, -.21393800E+03, 0.17989400E+03, -.20072300E+03, -.18797900E+03, 0.32979400E+02, 0.88832200E+02, 0.26239300E+02, -.26486800E+02, -.14591200E+02, 0.10198300E+03, 0.58410100E+00, -.10795000E+01, -.31349400E+00, -.26155500E+00, -.13674000E+00, 0.24414400E+00, 0.44064400E+00, -.39870300E+00, -.12128400E+03, 0.57845000E+02, -.67054600E+02, -.95354300E+02, 0.17109400E+03, -.61563600E+02, 0.10476900E+03, -.81170900E+02, -.12414800E+03, 0.31263900E+02, 0.10843200E+02, 0.62798100E+02, -.26704900E+01, -.52411700E+02, 0.40766000E+02, 0.73696800E+02, 0.53166800E+02, 0.61829100E+02, 0.22641100E+02, 0.90861600E+01, 0.24628800E+01, 0.14074200E+02, -.16181800E+02, 0.11619200E+02, -.13816100E+02, 0.10290600E-01, -.81689400E+00, 0.62307000E+00, -.35701900E+02, 0.13579400E+02, -.13141400E+02, 0.10392500E+02, -.63947700E+00, 0.16564700E+01, -.49885500E+02, 0.28963900E+02, -.36886200E+01, -.81330200E+02, 0.49793900E+02, 0.34019700E+02, -.68170700E+00, -.20679500E+02, -.80225400E+01, -.12562800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12231300E+01, 0.37653000E+00, 0.17994900E+01, -.86995200E+00, 0.14487500E+01, 0.33199200E+00, -.59190900E+00, 0.10284400E+01, 0.10566700E+01, 0.76648200E+00, -.42089900E+00, -.46360800E+00, -.49856300E+00, -.21613000E+00, 0.10771700E+01, -.22260000E+01, 0.13262800E+00, -.14667000E+00, -.32723800E+00, -.14776700E+01, -.44115500E+00, 0.11996000E+01, 0.34133300E+00, 0.12917000E+00, -.52724500E-01, 0.25785600E+00, -.21468600E+00, 0.13617300E+01, -.19071900E+00, 0.63596200E+00, 0.12069100E+01, 0.66090600E+00, 0.35016200E+00, -.39808600E+00, 0.49156700E+00, -.63336600E+00, 0.84613300E-01, -.14218700E+03, -.74627200E+02, 0.34431800E+02, 0.32097200E+03, -.39161800E+03, -.10589700E+03, -.29694700E+03, -.28454300E+02, 0.93186400E+02, 0.23334400E+03, -.36147900E+03, -.11118800E+04, -.96154500E+03, 0.34000000E+03, 0.28221900E+03, 0.12991600E+03, -.48071600E+03, 0.12279900E+03, 0.31534500E+03, -.32778500E+01, 0.45760000E+01, -.40842300E+00, -.16340700E+01, 0.21839000E+01, -.68608200E+00, 0.32324700E+00, -.17484700E+01, 0.50299100E+03, -.46035300E+02, -.33049600E+02, -.15493700E+02, -.12637400E+03, 0.14758000E+03, -.19942300E+02, -.47847200E+02, -.89308700E+03, -.22497100E+02, 0.10834200E+03, 0.11499100E+03, 0.14445400E+03, -.33325900E+03, 0.11252000E+03, 0.11409200E+03, 0.15301800E+03, 0.10251900E+04, -.23364000E+03, -.15815100E+03, 0.89276500E+02, 0.16765000E+03, -.24579500E+02, -.19178000E+03, -.83580300E+02, 0.11729200E+02, 0.27284500E+02, 0.68253000E+02, 0.14468600E+02, -.67117300E+02, 0.11562000E+02, 0.60580300E+02, 0.31535900E+04, -.64564300E+03, -.39416600E+03, -.43698300E+03, -.60693200E+03, 0.99577200E+03, -.43320500E+03, -.42220500E+03, 0.14123200E+04, -.95600100E+03, -.19766300E+03, -.24639800E+03, -.35432200E+03, 0.46945300E+03, -.10512600E+03, -.28428100E+03, -.66796800E+02, 0.22516100E+03, -.52568900E+02, -.18372400E+03, 0.10891600E+03, 0.89752000E+01, 0.15850800E+03, -.21307200E+03, -.17296100E+01, 0.40163300E+01, 0.18882600E+01, 0.16199400E+01, 0.71404900E+00, -.10624400E+01, -.12909400E+01, 0.20847900E+01, 0.12613200E+04, -.41836400E+03, 0.40909000E+01, 0.26067300E+02, -.37249900E+03, 0.41576700E+03, -.28009100E+03, 0.18699400E+02, 0.23518400E+03, 0.26666100E+02, -.32173300E+01, -.10983300E+03, 0.27901700E+02, 0.74151800E+02, -.33563300E+02, -.15654600E+03, -.39029500E+02, -.23132700E+03, -.57490000E+02, -.25857900E+02, -.24358400E+02, 0.33638800E+02, 0.11870900E+02, -.13971800E+02, 0.16598500E+02, -.20350300E+02, -.11433600E+02, 0.12346800E+02, -.70188500E+02, -.10313200E+02, -.58609100E+02, -.11102000E+03, -.12294800E+02, 0.10349800E+01, -.12552600E+03, -.62944800E+02, 0.29800800E+02, 0.26878800E+02, -.77269200E+02, -.11913500E+02, -.12110600E+02, 0.29395500E+02, -.53439100E+01, -.83771200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.12642000E+01, -.51088200E-01, -.11332200E+00, 0.72424400E+00, -.54604600E-01, 0.23948100E+00, -.43771900E+00, -.21960000E+01, 0.11079600E+00, 0.10551700E+00, 0.32896300E+00, 0.16374900E+01, 0.27096900E-01, 0.13592400E+01, 0.12022000E+01, 0.37065000E+00, -.17666900E+00, 0.17970200E+00, 0.59351500E+00, -.75663700E+00, -.45224900E+00, 0.89088200E+00, 0.32276700E-01, -.48011300E+00, -.34882500E+00, -.82116500E+00, 0.31140200E+00, 0.82866700E+00, -.19165900E+00, -.31487200E+00, 0.50437400E+00, 0.10585100E+01, 0.73305000E-01, -.22444500E+01, 0.29872800E+00, -.92224600E+00, -.42497000E+00, 0.91801200E-01, 0.56360700E+02, 0.19329800E+02, 0.31741600E+03, 0.15877800E+03, -.39907800E+02, -.15383500E+03, -.58624600E+02, 0.21656100E+02, 0.12362000E+03, -.16862100E+03, -.56660700E+03, -.36716300E+03, 0.11436500E+03, 0.78555500E+02, 0.13299200E+03, -.28275900E+03, 0.11004600E+03, 0.71566200E+02, -.55005600E+00, 0.21290800E+01, -.11207100E+00, -.70070200E+00, 0.20983000E+00, 0.58294900E+00, 0.19264800E+01, -.62322500E+00, -.44354600E+01, 0.12783200E+03, 0.58481500E+01, 0.65202400E+01, -.51573800E+00, 0.10953900E+02, 0.50235700E+02, 0.40550700E+01, -.23594100E+02, -.11699600E+03, -.27281400E+02, -.35664400E+02, 0.64906000E+02, -.10125000E+03, -.15663800E+02, -.33037000E+02, 0.77783400E+03, 0.58030400E+03, -.13449700E+03, -.10643300E+03, -.19181100E+03, 0.29877100E+03, -.93167600E+02, -.84886500E+02, -.11697800E+03, -.16359700E+03, 0.51893400E+02, 0.72775500E+02, 0.15881000E+01, -.75719800E+02, -.79855600E+02, 0.72840800E+02, 0.32677300E+03, -.16003400E+03, -.10232100E+03, -.10344400E+03, 0.37645800E+02, 0.16385300E+03, -.58311500E+02, -.10804100E+03, 0.26957500E+03, -.22902900E+03, -.26868800E+02, -.52113000E+02, -.14780100E+02, 0.57398200E+02, -.35911000E+02, -.50009100E+02, -.71245700E+02, 0.33786700E+03, 0.34299100E+02, -.89563700E+01, -.59334300E+02, 0.79640700E+01, 0.83933200E+02, -.10424600E+02, -.78403400E-01, -.14940400E+00, -.13695100E+00, -.14348800E+00, 0.64352000E+00, -.10911800E+00, -.16769900E+00, -.23962000E+00, 0.58705600E+03, -.38671100E+03, -.58333900E+01, -.64469300E+01, -.10993900E+03, 0.98280800E+02, -.17306700E+03, -.17795800E+02, 0.34724200E+02, 0.19190600E+02, 0.30494800E+02, 0.10734200E+01, -.51721000E+02, -.31523700E+02, -.25558600E+02, -.16402500E+02, -.59542500E+02, -.33343100E+02, -.98017600E+01, -.63786500E+01, 0.12602700E+02, 0.31810000E+01, -.80672200E+01, -.17780400E+00, 0.12498100E+02, 0.11233600E+02, 0.74796300E+01, -.74043900E+01, -.46117100E+02, -.23721200E+02, -.28204800E+02, -.51465300E+02, 0.74045700E+01, 0.53266200E+01, -.80851800E+02, -.10149400E+02, -.78893400E+01, -.47655300E+02, -.14909800E+02, -.27477500E+02, 0.74943700E+01, 0.19354700E+02, -.12233200E+02, -.28988800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13304000E+01, -.33313400E-03, 0.38228300E+00, 0.74848900E+00, 0.96315600E+00, 0.81224000E+00, -.52537200E-01, -.36307800E+00, 0.21589200E+00, 0.11785300E-01, 0.84349900E-02, 0.48797800E+00, 0.10217800E-01, 0.23241300E+00, 0.54592700E+00, -.53606600E+00, -.13396000E+00, 0.44251300E-01, 0.38043300E-01, -.18816600E+01, 0.14670800E+01, -.12417100E+00, -.12633400E+00, -.41567200E+00, -.31163600E-01, 0.82408900E+00, 0.65360200E+00, -.11297300E+01, -.37072400E+00, -.31108300E+00, -.92057100E+00, 0.98438500E+00, 0.31211800E+00, 0.39155000E+01, -.46191100E+00, -.19426800E+00, 0.73968500E+00, 0.18937100E+00, -.20215300E+00, -.39581500E+02, -.14250300E+02, 0.37639500E+03, 0.57930800E+02, 0.33088600E+02, 0.45638300E+02, 0.32614800E+02, -.10671800E+03, 0.11037900E+03, 0.52796900E+03, 0.15867700E+03, -.31305700E+02, -.73192700E+02, -.14026100E+03, 0.23328000E+03, -.46386800E+02, -.34482500E+02, 0.51316000E+00, -.81379100E+00, 0.44830600E+00, 0.21210400E+00, -.84318100E+00, -.42711800E+00, -.73799900E+00, 0.12536300E+00, 0.14075700E+02, -.45232300E+02, 0.37816500E+02, 0.55357500E+02, -.17271500E+02, -.13309300E+02, -.64432200E+02, 0.67575900E+02, 0.69384600E+03, -.40805900E+02, -.30615200E+02, -.64912900E+02, -.17989000E+03, 0.27250500E+03, -.33369100E+02, -.55442100E+02, 0.44275100E+02, 0.24972500E+02, -.59571700E+02, -.54491300E+02, 0.10659300E+03, 0.18936100E+01, 0.65059500E+02, -.86201100E+02, 0.13750300E+03, -.17540800E+03, -.22588900E+02, -.12646700E+02, -.30292200E+02, 0.57407500E+02, 0.21703200E+02, -.26149400E+02, -.20119000E+04, 0.26364300E+03, 0.26183200E+03, 0.33676200E+03, 0.26116200E+03, -.67406000E+03, 0.15818800E+03, 0.30076500E+03, -.46325200E+03, 0.30412000E+03, 0.94290300E+02, 0.68705100E+02, 0.10352400E+03, -.90622000E+02, 0.91627500E+02, 0.86373700E+02, 0.57476600E+02, 0.20077900E+02, -.11835000E+02, -.28668600E+02, 0.25580800E+02, 0.15850000E+02, -.23075700E+02, -.11685000E+01, 0.33528100E+00, -.25559700E+01, -.28429700E+00, -.31672800E+00, -.71478300E+00, 0.49412900E-01, -.68239500E-01, -.41075700E+00, -.31958600E+03, 0.39358700E+01, 0.17959300E+03, 0.20178500E+03, -.11227000E+03, -.16749300E+03, -.81057200E+02, 0.21453000E+03, -.11569300E+03, -.58380000E+02, 0.62088600E+02, 0.74511100E+02, -.25658400E+02, -.70160900E+02, -.79372000E+02, 0.88765200E+02, 0.31169700E+02, 0.13737000E+03, -.80077200E+01, -.25431500E+02, 0.23657900E+02, 0.22549400E+02, 0.40364700E+02, -.29686800E+02, 0.19675100E+01, -.36113800E+01, 0.84933300E+00, -.11748700E+01, 0.37727700E+02, 0.44374500E+01, 0.64862300E+02, 0.12674300E+02, 0.11630600E+01, 0.13742500E+01, 0.54680700E+02, -.14695900E+02, 0.13032500E+02, 0.41709400E+02, 0.21557000E+02, -.61968500E+01, 0.11701500E+01, 0.11675500E+02, -.32687700E+02, 0.16211000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.59669400E+00, -.64069300E-01, -.20228500E+00, 0.18309100E+00, -.31298700E+00, -.13909400E+00, 0.60677400E-01, -.37018600E+00, 0.56895800E-01, -.37572700E+00, 0.29993300E-01, 0.30559000E+00, -.70819100E-01, 0.18683900E+00, 0.46141400E+00, -.68371300E+00, -.28791100E-01, -.55374300E-02, 0.17012700E+00, -.65714300E+00, 0.50812500E+00, -.12470500E+00, -.17436000E+00, -.81190300E-01, 0.63154800E-01, 0.33550000E+00, 0.26900500E+00, -.22990300E+00, -.18235500E+00, -.15597300E+00, 0.21730800E-01, -.30268300E+00, -.15524200E+00, -.55002200E+00, 0.30828000E+00, 0.46563900E+00, 0.45420300E+00, 0.24005700E+00, -.27614200E+00, -.15903100E+00, 0.33522100E+03, 0.10060300E+02, -.47805700E+02, -.11291600E+03, -.53277500E+02, 0.33759400E+02, 0.28283500E+02, -.11202700E+03, -.17491500E+03, -.16626400E+03, 0.11521300E+03, 0.81291100E+02, -.61551500E+02, -.10417900E+03, 0.11749600E+03, 0.83727200E+02, -.12742700E-02, 0.15592900E+01, -.37945500E-01, -.42250500E+00, 0.27408100E+00, 0.10260800E+00, 0.23893000E+00, -.36440500E+00, -.92986300E+02, 0.10924000E+03, 0.77375100E+01, 0.10427600E+02, 0.18782700E+02, -.27222600E+02, 0.24183200E+02, 0.70664600E+01, 0.26291000E+03, -.14687300E+03, -.32565200E+02, -.47947600E+02, -.14914400E+02, 0.55984100E+01, -.26887700E+02, -.31593700E+02, 0.28567200E+03, 0.32637900E+03, -.15178300E+03, -.10439700E+03, 0.50071000E+02, 0.54515000E+02, -.17984400E+03, -.10356900E+03, 0.18566300E+02, -.11486500E+03, 0.38305800E+02, 0.37416100E+02, -.29409600E+02, 0.52551900E+01, 0.45974900E-02, 0.37934900E+02, -.21539200E+03, 0.59468300E+02, 0.11771300E+02, 0.58048400E+01, 0.83654500E+02, -.24640600E+02, 0.19929200E+02, -.49967700E+01, 0.18493400E+03, -.83356000E+02, 0.76159700E+02, 0.53260200E+02, -.90315000E+02, -.93340200E+01, -.12624100E+03, 0.64867100E+02, -.89210400E+02, 0.17985200E+03, -.22864700E+02, -.39739700E+02, 0.30707300E+02, 0.24588600E+02, 0.60504400E+02, -.37544900E+02, -.22913400E-01, -.14590800E+00, -.51762800E-01, -.82948100E-01, 0.10571400E+00, 0.50350100E-01, 0.18926200E+00, -.12907700E+00, 0.53049700E+03, -.23936500E+03, -.19147400E+02, -.27057200E+02, -.78112200E+02, 0.75295100E+02, -.10036600E+03, -.16273400E+02, 0.25194500E+02, 0.50450800E+02, -.12529100E+02, -.16867200E+02, -.67246000E+01, -.24843500E+02, -.15977500E+02, -.30001200E+02, -.11381900E+02, -.40820600E+02, 0.30781600E+01, -.29531200E+01, 0.85840100E+01, 0.59688600E+01, -.72212400E+01, 0.56358100E+01, 0.11330200E+01, 0.41235700E+00, 0.24701500E+00, -.25017500E+00, -.50392600E+02, -.12116700E+01, -.25459200E+00, -.11516700E+03, 0.25671200E+00, 0.14513800E+01, -.77435900E+02, -.67059900E+02, 0.40925900E+02, -.64167600E+02, 0.19087600E+02, -.59422200E+01, 0.26564900E+00, 0.10403700E+02, 0.30759400E+01, -.79079900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18526800E+01, 0.49219600E-02, -.39001000E+01, -.52574100E+00, -.61730300E+00, -.65907600E+00, 0.74535500E+00, 0.19030600E+01, -.20017600E+00, 0.18826000E+01, -.78080100E+00, -.83140200E+00, 0.67226200E+00, -.14006000E+01, -.19504500E+01, -.10038300E+00, -.14331800E+00, 0.98075500E-02, -.63448700E+00, 0.10906200E+01, 0.32869500E+00, -.68941000E+00, -.44124200E+00, -.68219200E-01, 0.17238900E+00, -.88405700E+00, 0.25186900E+00, -.12282700E+01, -.71236900E+00, -.12651700E+00, -.11604900E+01, 0.75075200E+00, -.57711700E+00, 0.26956500E+01, -.10906600E-01, -.50468900E+00, -.20876600E+01, 0.28410200E+00, 0.63707100E+00, 0.33607200E+00, -.96094800E+00, -.56652300E+03, 0.11949000E+03, 0.15358300E+03, -.82663300E+02, -.31562700E+03, 0.13729900E+03, 0.15141800E+03, -.11633200E+04, 0.14778000E+04, -.36075000E+03, -.20609100E+03, 0.47075600E+03, -.62549100E+03, 0.18206900E+03, -.43585300E+03, 0.71419400E+01, -.37551900E+01, 0.11270100E+01, 0.94532800E+00, -.16660000E+01, 0.21722900E+01, -.11634300E+01, 0.16041400E+01, -.85776600E+03, 0.39527800E+02, 0.63996100E+02, 0.55216000E+02, 0.14834600E+03, -.20873700E+03, 0.78169000E+02, 0.76565800E+02, 0.13246400E+04, -.34275900E+03, -.21227400E+03, -.26746700E+03, -.12569700E+02, 0.77989700E+02, -.21922900E+03, -.23383600E+03, 0.22058200E+04, -.25412800E+04, 0.35220800E+03, 0.13952000E+03, -.85945000E+03, 0.62207500E+03, -.38127700E+03, 0.36647500E+03, -.24383000E+03, 0.50929400E+03, -.16358900E+02, -.40300400E+02, 0.87411900E+02, -.55710800E+02, 0.27167200E+02, -.31369400E+02, -.22966700E+04, 0.79951600E+03, 0.16736000E+03, 0.17229500E+03, 0.82753800E+03, -.54360000E+03, 0.43322200E+03, 0.18646700E+03, -.44205500E+03, 0.67409100E+03, 0.47172200E+03, 0.55746900E+03, -.86385600E+02, -.53879400E+03, -.62164400E+03, 0.58635100E+03, -.57174100E+03, -.28581000E+03, 0.13255800E+03, 0.21576000E+03, -.62440200E+02, 0.24785700E+00, 0.12676500E+03, 0.23206300E+03, 0.29651900E+01, -.77954100E+00, -.23003800E+01, -.16013400E+01, -.46710600E+00, 0.67629300E+00, 0.17286000E+00, -.24314400E+01, -.24002800E+03, 0.17525900E+03, -.25402500E+03, -.33212200E+03, 0.66717200E+03, -.20319000E+03, 0.25285600E+03, -.30193000E+03, -.19660700E+03, 0.94416000E+02, 0.89253100E+02, 0.15399900E+03, -.10105600E+03, -.14593200E+03, 0.12027700E+03, 0.18070300E+03, 0.35362900E+02, 0.12484200E+03, 0.70747700E+02, 0.25253100E+02, 0.62891300E+02, 0.33927200E+02, -.44076300E+02, 0.34732900E+02, -.35106600E+02, 0.19551100E+02, 0.45800400E+01, -.54452200E+01, -.12372000E+03, 0.46888300E+00, -.11158400E+03, 0.13951700E+03, 0.54106600E+01, 0.22449400E+01, -.18758100E+03, 0.19100100E+03, -.58992000E+02, -.32980100E+03, 0.17303200E+03, 0.70255700E+02, 0.49381900E+01, -.73257000E+02, -.55947300E+02, -.97934100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14376400E+01, -.54332700E+00, 0.20901700E-01, 0.16653800E+00, -.34195900E+00, -.35106800E-01, -.19525200E+00, -.18504400E+00, -.44534300E+00, 0.61097400E-03, -.19193900E+00, 0.38820500E+00, 0.14474700E+00, -.14820800E+01, -.75354400E+00, 0.24501900E+00, 0.13592000E+00, 0.37414400E+00, 0.19428900E+00, -.50827100E-01, -.61868000E+00, 0.40282000E+00, 0.94011000E+00, -.31534300E+00, 0.15307500E+00, 0.68413900E+00, -.78502400E+00, 0.44804400E+00, -.32398500E+00, 0.11821000E+01, -.83086200E+00, 0.32355300E+00, 0.20748900E+00, 0.45300200E+01, -.43946500E+00, -.16634400E+01, -.15526400E+01, 0.69363100E+00, -.74812900E+00, -.20549000E-01, -.10714700E+01, -.15493200E+00, 0.13870000E+03, 0.20540200E+03, -.66959300E+02, -.33132000E+03, 0.57577700E+02, 0.24089900E+03, -.46858300E+03, 0.11881400E+04, -.94562200E+02, 0.24506000E+02, -.17057200E+02, -.38244800E+03, 0.53431500E+02, -.91600900E+02, 0.60832300E+01, -.16566100E+01, 0.58012100E+00, 0.63571700E+00, -.19053700E+01, 0.15105500E+01, -.13213200E+01, 0.93311900E+00, -.91145500E+03, 0.22812200E+03, 0.71596300E+02, 0.71060100E+02, 0.18605200E+03, -.23565500E+03, 0.75875500E+02, 0.10764300E+03, 0.21507700E+04, 0.95836000E+01, -.28252700E+03, -.35507200E+03, -.26715100E+03, 0.39703600E+03, -.28664800E+03, -.34561700E+03, 0.17481300E+04, -.15267900E+04, -.11845600E+03, -.30274100E+03, -.22783300E+03, 0.52849600E+03, -.18431600E+03, -.19978900E+03, -.12688400E+03, 0.15268000E+03, 0.43147200E+02, 0.17794400E+02, 0.12684400E+02, -.19439400E+02, -.33480200E+02, 0.43753000E+02, -.39301100E+04, 0.79269900E+03, 0.42274900E+03, 0.45512700E+03, 0.10411900E+04, -.10567800E+04, 0.62910700E+03, 0.46818200E+03, -.73484600E+03, 0.11075000E+04, 0.46957200E+03, 0.50755500E+03, 0.10695300E+03, -.48385000E+03, -.33814800E+03, 0.58254400E+03, -.32717300E+03, -.21261300E+03, 0.32038200E+02, 0.12900500E+03, -.80099500E+01, 0.44041100E+02, 0.74097400E+02, 0.14083300E+03, 0.45512800E+01, -.45990600E+01, -.24351900E+01, -.17710300E+01, -.17449600E+01, 0.12691700E+01, -.40420500E-01, -.27123000E+01, -.97693100E+03, 0.34338900E+03, -.63895200E+01, -.32889600E+02, 0.47538800E+03, -.48469900E+03, 0.14344700E+03, -.48235100E+02, -.24444200E+02, 0.11972900E+03, 0.12227700E+02, 0.11439400E+03, -.89170400E+02, -.11681600E+03, -.32158700E+02, 0.13874900E+03, 0.36041200E+02, 0.19966500E+03, 0.68037700E+02, 0.73962600E+01, 0.75385900E+02, 0.60519100E+02, 0.32321100E+02, 0.13053700E+02, -.25921200E+02, 0.13956300E+02, 0.57863300E+01, -.70994000E+01, 0.31165600E+01, -.22054800E+01, -.62399800E+02, 0.28100700E+02, 0.70608900E+01, -.20124000E+01, -.55601900E+02, 0.52237100E+02, -.53775900E+02, -.22028500E+03, 0.18259800E+03, 0.50407800E+02, 0.65736500E+01, -.26944400E+02, -.25720400E+02, 0.31807000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.63469700E+01, -.21113600E+01, -.61023100E+00, 0.63199700E+00, -.11115800E+01, -.10835700E+01, 0.25017900E-01, -.67095100E+01, 0.71766300E-01, 0.36247400E+01, 0.21233900E+01, 0.60918300E+01, 0.90929600E+00, 0.35299200E+01, 0.18250800E+01, -.20041900E+01, -.10190200E+00, 0.15257500E+01, 0.14234900E+01, 0.65872400E+01, -.99849600E-01, -.10701400E+01, -.12220900E+01, 0.23127400E+01, -.15282400E-01, -.51638600E+00, -.11605300E+01, -.23762500E+01, 0.43643600E+00, -.53394500E+00, -.16762700E+01, -.47763400E+00, -.28045800E+01, 0.36337800E+01, 0.17279700E+01, 0.25097300E+01, 0.21999400E+00, 0.34735200E+00, -.36536600E+01, -.29567000E+01, 0.20335200E+01, -.79203900E+00, 0.18333600E+01, -.46084800E+03, 0.73932900E+02, 0.11308900E+03, 0.41938800E+03, -.51177000E+03, -.30862900E+04, 0.63191600E+03, 0.36443000E+03, 0.26029300E+03, 0.62790400E+03, -.10857000E+04, 0.37885900E+03, 0.16155600E+03, -.41772000E+01, 0.14850300E+01, 0.12581400E+01, -.19650300E+01, 0.12666500E+01, -.44712000E+00, 0.96681700E+00, -.17911600E+01, 0.64384500E+03, -.47176900E+03, 0.19527700E+02, 0.71658800E+02, -.21892800E+03, 0.16802200E+03, -.13584000E+03, 0.51218600E+02, -.17993100E+04, -.37703000E+03, 0.25021500E+03, 0.22120600E+03, 0.36988900E+03, -.67925300E+03, 0.19400800E+03, 0.24634800E+03, 0.19201800E+04, -.90180600E+03, 0.15670000E+03, 0.27161000E+03, -.75889600E+03, 0.47699600E+03, -.64920500E+03, 0.36881300E+03, -.12361600E+03, 0.88696000E+02, 0.11682500E+02, 0.13091500E+03, -.36085300E+02, -.13351000E+03, -.97846100E+02, 0.13106500E+03, 0.25024900E+04, -.46614100E+03, -.33409000E+03, -.22561100E+03, -.64941600E+03, 0.82728200E+03, -.36899800E+03, -.25353500E+03, 0.11137000E+04, -.12780100E+04, -.16755400E+03, -.21480300E+03, -.34748600E+03, 0.32788200E+03, -.18982900E+03, -.26589900E+03, -.18582000E+03, 0.58535100E+03, 0.37926900E+02, -.23109400E+03, 0.99939800E+02, 0.73674600E+02, 0.27655200E+03, -.19806700E+03, -.38657400E+01, 0.55063000E+01, 0.13750100E+01, 0.39302600E+00, 0.21419000E+01, -.13232200E+01, -.59151100E+00, 0.73505800E+00, 0.19625200E+04, -.42592700E+03, 0.13910500E+03, 0.12672300E+03, -.61577600E+03, 0.36267700E+03, -.39486600E+03, 0.18934300E+03, -.28981400E+03, -.32312600E+03, 0.33410100E+03, 0.11965400E+03, -.12101200E+03, -.19053000E+03, -.26285300E+02, 0.11031800E+03, -.50933700E+02, -.74885400E+02, -.97850100E+02, -.58714000E+02, 0.12159300E+02, 0.33717900E+01, 0.13528100E+00, -.57566300E+02, 0.35927100E+02, -.17504600E+02, -.99386300E+01, 0.10892700E+02, -.11523200E+03, 0.46623200E+00, -.34031200E+02, -.11639600E+02, -.10844800E+02, 0.26951200E+02, -.17592000E+03, 0.37659500E+02, -.44158800E+02, 0.28136500E+02, -.96722400E+02, -.29997600E+02, -.99400500E+01, 0.44952100E+02, -.16943000E+03, 0.52794300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19042400E+01, -.39129000E+00, 0.52583600E+00, 0.78759300E+00, 0.43870500E+00, 0.29590500E+00, 0.46129400E+00, -.17852700E+01, 0.67782600E+00, 0.28958600E+01, 0.13167200E+00, 0.20058000E+01, 0.47665100E+00, 0.17954500E+01, 0.10990400E+01, -.25683000E+01, -.25241400E+00, 0.20097400E+00, -.70923800E-01, 0.26091100E-01, 0.22305200E+01, -.18627900E+01, -.10856700E+01, -.34930200E+00, 0.50848900E+00, 0.90807300E+00, -.55033200E+00, -.28650500E+01, -.12790600E+01, -.99810700E+00, 0.43344600E-01, 0.37258300E+00, -.48157700E+00, -.57488400E+01, -.29793600E+00, 0.60642400E+00, 0.42434500E+00, -.35799800E+00, 0.34792100E+00, 0.54376000E+00, -.47490600E+00, 0.77863900E+00, 0.45668700E+00, -.18034400E+00, -.85305100E+02, 0.29946400E+03, -.81074500E+02, -.44601600E+01, 0.56935100E+03, -.13259600E+04, 0.33367400E+03, 0.20903700E+03, -.27833500E+03, 0.40720800E+03, -.51653600E+02, 0.37539900E+03, -.56152700E+01, 0.97862700E+00, -.12178800E+01, -.33729600E+00, 0.18129100E+01, -.13896500E+01, 0.13178500E+01, -.78172600E+00, 0.43110500E+03, -.67522600E+02, -.50765000E+02, -.61799100E+02, -.46559600E+02, 0.88535500E+02, -.26489600E+01, -.10263800E+03, -.20887200E+04, 0.59226300E+02, 0.23366400E+03, 0.31999800E+03, 0.25460700E+03, -.33072500E+03, 0.29180000E+03, 0.29952400E+03, -.20195700E+04, 0.19911400E+04, -.17808000E+03, 0.52120300E+02, 0.60618500E+03, -.60203200E+03, 0.76593500E+02, -.85880900E+02, -.14708900E+03, 0.51589300E+02, 0.25035900E+02, 0.17316200E+02, 0.14154800E+02, -.74992100E+02, -.16489600E+02, -.15472600E+02, 0.32749800E+04, -.88199000E+03, -.39774000E+03, -.39563100E+03, -.86839100E+03, 0.80637700E+03, -.60965400E+03, -.43006900E+03, 0.36486700E+03, -.92668600E+03, -.57528900E+03, -.59783600E+03, 0.14104600E+03, 0.46038700E+03, 0.63955800E+03, -.68741000E+03, 0.52626600E+03, -.24261000E+02, -.31541800E+02, -.71332700E+02, -.37012200E+02, -.84432200E+02, -.20981100E+03, -.80203100E+02, -.35212600E+01, 0.13137000E+01, 0.27792000E+01, 0.23874100E+01, 0.66511600E+00, -.11410400E+01, -.14970800E+00, 0.33148800E+01, 0.26986500E+03, -.23363300E+03, 0.68770200E+02, 0.10101400E+03, -.39757200E+03, 0.35596200E+03, -.10512600E+03, 0.98748500E+02, 0.25592500E+03, -.25477200E+03, -.21203200E+02, -.12011800E+03, 0.89218700E+02, 0.18723500E+03, -.94305200E+02, -.13220900E+03, -.25879300E+02, -.80421300E+02, -.10233000E+03, -.29616200E+02, -.72076100E+02, -.40619500E+02, 0.10266200E+02, -.41011600E+02, 0.23612300E+02, -.11751800E+02, -.62174500E+01, 0.73926900E+01, 0.10630200E+03, -.23130900E+01, 0.39041000E+02, -.19264200E+03, -.73665600E+01, -.16327100E+02, 0.17179300E+03, -.19438500E+03, 0.50292600E+02, 0.33573300E+03, -.20334200E+03, -.55365400E+02, -.67829200E+01, 0.33294400E+02, 0.72095900E+01, 0.20425800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19063700E+01, -.93540400E-01, -.53105400E+00, 0.18083200E+01, 0.96007800E-02, 0.86923400E+00, -.61124200E+00, -.19601900E+01, 0.20702100E+00, -.38177900E+00, 0.14616600E+00, 0.11756100E+01, 0.52768100E-01, 0.11434000E+01, 0.72526200E+00, 0.52970300E+00, -.14429900E+00, 0.25553500E+00, 0.11911400E+01, -.29784600E+01, 0.36171800E+01, 0.31566100E+00, 0.19419600E+00, -.83657600E+00, 0.23893700E+00, 0.48892800E+00, 0.13339800E+00, 0.89249800E+00, -.28307100E+00, 0.32781700E+00, 0.25756300E+00, -.10843600E+01, -.39588400E+00, -.68229300E+01, 0.28956400E+00, -.89822700E+00, -.68976500E+00, 0.15428000E+00, 0.32500100E-01, -.15588500E+00, 0.17696000E+01, -.14965300E+00, 0.11563400E+01, 0.24119300E+00, -.17863200E+00, 0.26337400E+03, -.12631700E+03, 0.56045700E+01, 0.96039500E+03, -.16470800E+04, -.93969200E+02, -.18851900E+03, -.19055800E+02, 0.53796500E+03, -.82258500E+02, -.79525400E+02, -.24984000E+01, 0.87206100E+00, -.46288600E+00, -.68959600E-01, 0.81842700E+00, -.12364300E+00, 0.25333200E+01, -.27381600E+00, 0.59750700E+03, 0.28298100E+02, 0.30356900E+02, -.22254700E+02, -.11924500E+03, 0.18941400E+03, 0.61281200E+02, -.48625300E+02, -.65947400E+03, -.17639900E+03, 0.66331800E+02, 0.10740400E+03, 0.69459300E+02, 0.10046700E+03, 0.12993100E+03, 0.10460500E+03, -.12258400E+04, 0.19966700E+04, 0.17015400E+03, 0.24304000E+03, 0.17024800E+03, -.26411000E+03, 0.31034300E+03, 0.17773000E+03, 0.15791600E+02, -.85751100E+02, -.70622200E+02, -.64673300E+02, 0.54553000E+02, 0.11344000E+02, 0.37818400E+02, -.10831400E+03, 0.19487800E+04, -.37653200E+03, -.28755300E+03, -.29045900E+03, -.48590300E+03, 0.41457500E+03, -.45756100E+03, -.32032500E+03, 0.97520700E+02, -.47377000E+03, -.36802300E+03, -.39712800E+03, 0.13065800E+03, 0.27005400E+03, 0.44184900E+03, -.46741600E+03, 0.26974600E+03, -.13136800E+02, 0.75723500E+02, 0.21382100E+02, -.10913600E+03, -.11222400E+03, -.11600400E+03, -.11013700E+01, -.38225500E+01, 0.11251800E+01, 0.12666200E+01, 0.12758600E+01, 0.10564200E+01, -.12397000E+01, 0.34007900E+00, 0.19026900E+01, 0.36241700E+03, -.33177300E+03, -.59870800E+02, -.44940500E+02, -.12872500E+03, 0.39487300E+03, -.42923100E+02, -.48143300E+02, 0.21770500E+03, -.64401200E+02, -.58223200E+01, -.91218200E+02, 0.41969900E+02, 0.19360100E+03, 0.19893300E+02, -.10976500E+03, -.26158700E+02, -.74900000E+02, -.74857500E+02, -.10000600E+02, -.36287400E+02, -.42394600E+02, -.27209400E+02, -.11363400E+02, 0.11851500E+02, 0.15863300E+01, 0.30717400E+01, -.22682600E+01, 0.92673500E+01, -.56015500E+01, 0.37656400E+02, -.37709600E+02, 0.22687000E+01, -.43184600E+02, 0.99318600E+02, -.18998800E+02, 0.71174300E+01, 0.15466700E+03, -.13604700E+03, -.36031300E+02, 0.25986300E+01, -.12096900E+02, 0.11719300E+02, 0.13294800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.61824000E+01, -.22258600E+01, -.93878200E+00, -.28925800E+00, -.26715300E+01, -.15574200E+01, 0.14385100E+01, -.68557800E+01, 0.90736800E+00, 0.67759100E+01, 0.11199700E+01, 0.73670000E+01, 0.31833900E+01, -.39079900E+00, -.28599600E+01, 0.59257100E+00, -.11397900E+01, -.17553200E+00, 0.11819300E+01, -.52309100E+00, -.17211700E+00, -.10937700E+00, 0.10047500E+01, 0.15102100E+01, 0.10514300E+00, -.17562600E+01, 0.29690900E+01, 0.52482300E+01, 0.19287700E+01, 0.70087300E+00, 0.99370100E+00, -.37424300E+01, -.29976100E+01, -.15759900E+02, 0.14802900E+01, -.18746700E+01, 0.74736500E-01, -.98985100E+00, 0.24637700E+01, 0.39695000E+00, -.64309100E-01, -.19110000E+01, 0.16713200E+01, 0.59106700E+00, -.63673700E+00, 0.15653300E+01, 0.38053700E+03, 0.57364500E+01, 0.57527200E+03, 0.86252100E+03, -.37626000E+03, -.42743300E+03, 0.12013000E+03, 0.15245500E+03, 0.19420600E+03, -.53151600E+03, 0.29813700E+01, 0.27856400E+01, -.22655300E+01, -.19227200E+01, 0.20863200E+01, 0.27820600E+01, 0.15231300E+01, -.15386900E+01, -.65927200E+03, 0.21677100E+03, 0.59746600E+02, 0.85176900E+02, 0.15583000E+03, -.20935400E+03, -.61303400E+02, 0.12325800E+03, 0.23362600E+04, -.59251500E+02, -.37832000E+03, -.42203600E+03, -.21858900E+03, 0.64219500E+03, -.34014800E+03, -.38983900E+03, -.31231700E+03, -.83664300E+03, 0.23769900E+03, 0.37451300E+03, -.29656600E+03, -.21385000E+03, -.36397800E+03, 0.46735600E+03, -.48288400E+03, 0.24535300E+03, 0.10033700E+03, 0.10016000E+03, 0.50716900E+02, -.20014100E+03, -.11923900E+03, 0.11831300E+03, -.31454600E+04, 0.10006600E+04, 0.37098500E+03, 0.28765300E+03, 0.10851900E+04, -.89897400E+03, 0.64298400E+03, 0.31859500E+03, -.11833700E+04, 0.14937300E+04, 0.63036200E+03, 0.64991700E+03, 0.17985200E+03, -.65063600E+03, -.45635400E+03, 0.71971800E+03, -.17198000E+03, -.35236600E+02, -.17351200E+02, 0.26792800E+02, -.41198200E+02, -.28995700E+02, 0.60708800E+02, 0.34561900E+02, 0.37666200E+01, 0.11094300E+00, -.32852400E+01, -.29545000E+01, -.23490100E+00, 0.17678100E+01, 0.28000600E+01, -.39272200E+01, -.33957600E+03, 0.35938700E+03, -.39560600E+03, -.35364600E+03, 0.77019500E+03, 0.15198800E+03, 0.33716400E+03, -.33776200E+03, 0.46959100E+03, 0.13320100E+03, -.32112500E+03, -.22523300E+03, 0.68789400E+02, 0.20774900E+03, 0.65063700E+02, -.20777100E+03, -.70870200E+02, -.22890900E+02, 0.17815100E+03, 0.10846700E+03, 0.12947300E+02, -.29183700E+02, -.82227500E+02, 0.12056600E+03, -.26423500E+02, 0.83532500E+01, -.70066100E+01, 0.57947400E+01, -.13681500E+03, 0.14687600E+02, -.55844500E+02, -.53779700E+02, -.57659700E+01, 0.53971000E+01, -.88251600E+02, 0.62545200E+01, -.45244900E+02, -.42255100E+03, 0.24521000E+03, 0.21389800E+02, -.69410100E+01, -.10756900E+03, 0.11750100E+03, -.76362700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.53157700E+00, 0.33086200E-01, -.78152600E+00, -.61855900E-01, 0.10191100E+00, -.17375300E+00, 0.60492200E+00, 0.28855500E+00, -.83396100E+00, -.40893000E-01, 0.34032700E-01, 0.15855100E+00, -.11007900E+00, 0.77801600E-01, 0.41210300E+00, -.30098000E-01, 0.43188300E-01, 0.10607400E+00, -.22780500E-02, -.66596000E+00, -.36089600E+00, 0.43520600E+00, -.90940700E-01, 0.14496500E+00, -.12114200E+00, -.43186400E+00, 0.65800600E-01, -.31655500E+00, -.39222800E-01, 0.30544800E+00, -.51023800E+00, -.51572800E-02, 0.34783700E-01, 0.14970400E+01, 0.32228700E-01, -.73478300E-01, -.85798600E-01, 0.18400700E+00, -.13268300E+00, 0.13839500E+00, 0.28031800E+00, 0.91517200E-01, -.89501800E-01, -.41685800E-01, 0.84125300E-01, -.16009700E+00, 0.12786900E-01, -.47207000E+01, 0.86630800E+02, -.82685300E+01, -.39987200E+02, -.34744000E+02, 0.10471500E+02, 0.32691900E+02, 0.95702100E+01, -.37530600E+02, 0.51909400E-01, -.39318300E-01, 0.95453200E-01, -.65673300E-01, 0.15784900E-01, 0.33234000E-01, -.42668100E-01, -.64181400E-01, -.12793500E+02, -.72992800E+01, 0.10860800E+02, 0.83243100E+01, -.54592600E+01, 0.22028700E+02, 0.14654000E+02, 0.10403500E+02, -.61667900E+02, 0.47490300E+02, 0.15825300E+02, 0.15055400E+02, 0.59394700E+01, -.95748100E+01, 0.10446900E+02, 0.14924300E+02, -.20124500E+03, 0.32714400E+02, 0.78531000E+02, 0.65608600E+02, -.11463000E+02, -.58008700E+02, -.12778000E+02, 0.62128300E+02, 0.17561600E+02, -.44843300E+01, -.41779600E+00, -.36309900E+00, -.87405300E+01, 0.98871400E+01, 0.59939500E+00, 0.51132700E+01, 0.38121400E+02, -.35204300E+02, -.19675000E+02, -.23395300E+02, 0.16023400E+02, 0.22739700E+02, 0.20276400E+02, -.18966500E+02, -.13202100E+01, 0.22438400E+02, 0.54594600E+00, -.15528300E+01, 0.30613400E+00, -.29420100E+01, 0.24377800E+01, 0.11238300E+01, 0.49527800E+01, 0.32645400E+01, -.56295800E+01, -.42537300E+01, 0.65929100E+01, -.73657600E+01, -.42347500E+01, -.58515600E+01, -.27599900E-01, 0.93561400E-01, -.88796200E-01, -.77294200E-01, 0.72874400E-01, -.17887300E-01, 0.37924600E-01, -.91289000E-01, -.30467200E+02, 0.41835500E+02, 0.15514800E+02, 0.46188500E+01, -.23796100E+01, 0.37725700E+01, 0.20822300E+02, 0.79999000E+01, -.46656600E+01, -.65963900E+01, 0.14284900E+02, 0.70436500E+01, -.10347500E+02, -.59288800E+01, -.25854000E+01, 0.91995300E+01, -.33281000E+01, 0.66487800E+01, -.17255800E+01, -.39477500E+00, 0.33165500E+01, 0.19220700E+01, 0.21675600E+01, -.78975200E+00, -.12870000E+01, -.16011000E+01, -.12099400E+01, 0.12013100E+01, 0.15817900E+02, 0.11383600E+01, 0.15686300E+01, 0.55939100E+01, -.11999000E+01, -.50489500E+01, 0.23201300E+02, 0.83349100E+01, 0.17746600E+00, 0.15156400E+02, 0.23184700E+01, -.31765000E+00, -.11548300E+01, -.82614000E+00, -.82989500E+01, -.10492700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.27892200E+01, -.14729600E+00, -.10078800E+01, 0.25044400E+01, -.11795600E+01, 0.78483200E+00, -.16976900E+01, -.29503800E+01, -.89061200E+00, -.31119500E+01, 0.33932400E+00, 0.19720600E+01, 0.24548300E+00, 0.57000400E+00, -.89050500E+00, 0.24845600E+01, -.44178000E+00, 0.65435200E+00, 0.21969100E+01, -.14968100E+01, 0.19929400E-03, -.16886800E-01, 0.88319800E+00, -.13819700E+01, 0.16522800E+00, 0.37835300E+00, 0.18826700E+00, 0.89057500E+00, -.23633600E+00, -.27762500E+00, 0.68275200E+00, 0.27917800E+01, -.38789700E+00, -.52056400E+01, 0.24772100E+00, -.98143300E+00, -.15803800E+01, -.54083300E+00, 0.13265100E+00, -.12925300E+01, -.11505000E-01, -.23723000E+00, 0.74501100E+00, 0.40663300E+00, 0.10302700E-01, 0.46178700E+00, 0.51206200E-01, 0.84135200E+00, -.59581100E+03, 0.29284400E+02, 0.16349700E+03, 0.16016600E+03, -.40556500E+02, -.20250700E+03, -.21202400E+02, 0.17643000E+03, 0.41772800E-01, 0.14278800E+01, -.47508200E+00, -.23900600E+00, 0.78390300E-01, 0.11235400E+00, 0.93707500E+00, -.22994400E+00, -.95828300E+02, 0.10129200E+03, 0.89305500E+01, 0.23189200E+02, 0.29136500E+02, -.62483900E+02, -.38045900E+02, 0.26135000E+02, 0.52028200E+03, -.18710800E+03, -.89588700E+02, -.94620200E+02, -.60784300E+02, 0.17557300E+03, -.50252200E+02, -.74408400E+02, 0.45521800E+03, 0.79712400E+02, -.21164800E+03, -.14925900E+03, 0.80614600E+02, 0.13945700E+03, 0.42987700E+02, -.14032600E+03, -.30138900E+02, -.26029000E+02, -.54764500E+01, -.12739600E+02, 0.44138900E+02, 0.75543100E+01, 0.22777000E+02, -.23164300E+02, -.10258100E+04, 0.45560100E+03, 0.15687700E+03, 0.14866000E+03, 0.15683500E+03, -.33622000E+03, 0.81778400E+02, 0.10552100E+03, -.31720900E+03, 0.23237100E+03, 0.98786400E+02, 0.74823300E+02, 0.67088900E+02, -.10175700E+03, 0.14877600E+02, 0.55456800E+02, 0.56382600E+01, -.23444500E+02, -.61472300E+01, 0.75844500E+01, -.30162000E+02, -.69968800E+00, 0.13508900E+02, 0.50053700E+01, 0.46390300E+00, -.55333900E-01, -.54430200E+00, -.55889700E+00, -.61765000E-01, 0.25042500E+00, 0.32462100E+00, -.58525300E+00, 0.40336200E+02, -.91082700E+02, -.64215800E+02, -.43712100E+02, 0.69742000E+02, 0.13643900E+02, -.31520900E+02, -.41624700E+02, 0.57622900E+02, 0.11011000E+03, -.80503300E+02, -.50820400E+02, 0.29114400E+02, 0.38000400E+02, 0.37459000E+02, -.67004200E+02, -.39643600E+02, -.38111400E+02, 0.36468100E+02, 0.22179600E+02, 0.36362600E+00, -.20078600E+02, -.19583300E+02, 0.28653500E+02, 0.34477100E+01, 0.67514900E+01, 0.62701300E+01, -.64568600E+01, -.58382500E+01, -.56379300E+01, -.96300500E+01, -.35195200E+02, 0.64531100E+01, 0.10630300E+02, 0.42302900E+01, -.35257400E+02, 0.47460000E+00, -.27166300E+02, 0.16330200E+02, -.46401200E+01, 0.61896400E+01, -.10617600E+02, 0.50008700E+02, -.11783000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23020600E+00, 0.17987800E-01, 0.10014200E+01, -.16361700E+00, 0.13286200E+00, 0.93988000E-01, -.21453500E+00, -.48246900E+00, 0.27563200E+00, -.11415600E+00, 0.86987100E-01, 0.30157000E+00, -.18330700E+00, 0.32085400E+00, 0.48702400E+00, -.84127000E+00, 0.48905500E-01, 0.12650300E+00, 0.10281700E+00, -.17111300E+00, -.30544700E+00, 0.26778500E+00, -.92052600E-01, 0.42223800E-01, 0.23877400E-02, -.17824500E+00, -.26585500E+00, -.32286100E+00, -.14045100E-01, -.11423400E-01, -.38106300E+00, 0.77603500E-01, 0.85319200E-01, 0.64444900E-01, -.21514400E-01, -.85269600E-01, 0.35447200E-01, 0.16648400E+00, -.38451200E-02, 0.58330200E-02, 0.96561300E-01, 0.10222300E+00, 0.37857800E-01, -.47911600E-01, -.62336700E-02, 0.50380000E-01, -.28051200E-01, 0.16156600E+00, -.44399600E-01, 0.74999800E+02, 0.24156700E+02, 0.20369200E+02, -.21179600E+02, -.58820800E+00, 0.78041800E+01, 0.25068300E+02, -.24923200E+00, -.64631900E-01, -.40224100E-01, -.14960600E-02, 0.35044600E-01, -.18033600E+00, -.20501100E+00, -.24376700E-01, -.16867300E+01, -.14786700E+02, -.74106400E+01, -.24865300E+01, 0.22348500E+01, -.35112500E+01, -.14177400E+02, -.16111400E+01, -.97450000E+02, 0.10718300E+02, 0.22189700E+02, 0.23671900E+02, 0.13551900E+01, -.34755800E+02, 0.99749100E+01, 0.23575600E+02, -.10521800E+03, -.47496100E+02, -.18697000E+02, -.80982900E+01, 0.39596900E+02, -.41449100E+02, -.17347900E+02, -.15575400E+02, -.73684100E+01, 0.63080100E+01, 0.47490600E+01, 0.52340200E+01, -.62797500E+01, -.48784600E+01, -.24618400E+01, 0.74598000E+01, 0.23997900E+02, -.44392800E+01, 0.19567300E+01, 0.51042600E+01, -.17969600E+02, 0.95717000E+01, 0.20045700E+01, 0.36160900E+01, 0.13168600E+02, -.24409700E+02, -.29120100E+01, -.73821500E+00, -.28567300E+01, 0.71769200E+01, 0.52376500E+01, 0.57502200E+00, 0.19487200E+02, -.34207800E+01, -.14296000E+02, -.12511300E+02, 0.13115400E+02, 0.77286000E+01, -.31368900E+01, -.11073500E+02, 0.22024600E+00, 0.37712600E-01, 0.61603800E-01, 0.21763500E-01, -.93863300E-01, 0.64982600E-01, 0.24303800E-02, 0.31169300E-01, -.47498400E+02, 0.29112100E+02, 0.24998900E+02, 0.24298800E+02, -.27487600E+02, -.25407200E+02, -.12219800E+01, 0.24598300E+02, -.18392700E+02, -.13355100E+02, -.15931700E+01, 0.18176800E+01, 0.39111700E+01, -.12228500E+02, -.97754400E+01, 0.29781400E+01, 0.19686700E+01, 0.61053100E+00, 0.25423400E+01, 0.24714600E+00, -.19845300E+01, 0.14291600E+01, 0.48615200E+01, -.11118700E+01, 0.83515800E+00, -.18811800E+01, -.11150100E+01, 0.11053400E+01, 0.86237700E+01, 0.85647400E+00, 0.22696900E+01, -.72262300E+01, -.11037700E+01, 0.30441900E+01, 0.26173700E+01, -.11661700E+02, 0.35828800E+01, 0.12076700E+02, -.31583500E+00, -.40886900E+00, -.11115900E+01, 0.53793600E+01, 0.91368800E-01, -.54358900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.29072500E+01, -.15632200E+00, -.85151000E+00, 0.24216300E+01, -.55255600E+00, 0.87540500E+00, -.17511700E+01, -.34355600E+01, -.36888900E+00, -.73726000E+00, 0.43233100E+00, 0.21816000E+01, 0.19603900E+00, 0.14861600E+01, 0.34274900E+00, 0.11299900E+01, -.85512200E-01, 0.38062200E+00, 0.15414500E+01, 0.28739100E+00, -.85389200E+00, 0.26458400E+01, 0.16033800E+01, -.13775500E+00, 0.52814300E-01, -.19494500E+01, 0.11814800E+01, 0.95175000E+00, -.40105900E+00, 0.54234000E+00, 0.14679500E+01, 0.12142900E+00, -.71684100E+00, -.76989900E+01, 0.52073400E+00, 0.91059100E+00, 0.21772200E+00, 0.99648700E-01, 0.54912100E+00, -.10213300E+01, 0.17045400E+01, -.77336500E+00, 0.20535600E+01, 0.27676600E+00, 0.13541100E+01, -.33823600E+00, -.10155100E-01, -.40214200E+01, -.83364200E+00, 0.73533900E+00, -.51999500E+03, -.43793900E+03, 0.40673500E+03, -.69132200E-01, -.18505600E+02, -.49770600E+03, 0.37045900E+01, 0.83726200E+00, 0.86890800E+00, 0.95095300E-01, -.72948900E+00, 0.18900400E+01, 0.14064300E+01, 0.54608200E+00, 0.26459100E+03, 0.49631000E+02, 0.53496700E+02, 0.55043800E+01, -.95328700E+02, 0.20753200E+03, 0.83545400E+02, 0.28287900E+02, 0.94137700E+03, -.40782800E+03, -.16869100E+03, -.21600300E+03, 0.45117200E+02, 0.32887000E+03, -.81142500E+02, -.17630400E+03, 0.89129900E+03, -.28464900E+03, 0.57414400E+03, 0.38746300E+03, -.62588100E+03, 0.39423600E+03, 0.11629000E+03, 0.48759000E+03, 0.10909500E+03, -.15689000E+03, -.13369600E+03, -.10665600E+03, 0.93753900E+02, 0.77398000E+02, 0.59203600E+02, -.11994100E+03, -.89333600E+03, 0.60581900E+03, 0.27077500E+02, 0.27315300E+02, 0.33767400E+03, -.27382300E+03, 0.11850500E+03, 0.61046900E+01, -.42151400E+03, 0.47430100E+03, 0.20486400E+03, 0.24054500E+03, -.35591300E+02, -.28975700E+03, -.27490900E+03, 0.21469800E+03, -.33463600E+03, 0.18557200E+03, 0.11962700E+03, 0.10829800E+03, -.10658100E+03, -.10347300E+03, 0.10991500E+03, 0.92044500E+02, -.16008600E+01, 0.28305000E+01, -.18885200E+01, -.16696100E+01, 0.14557900E+01, -.30692400E+00, 0.11925900E+01, -.19521800E+01, 0.43266600E+03, -.19314400E+03, -.26723900E+03, -.31641600E+03, 0.41713700E+03, 0.27451500E+03, 0.17554700E+03, -.25567700E+03, -.10225700E+03, 0.33431600E+03, -.28592800E+02, -.22589100E+02, -.30024200E+02, 0.26569100E+02, 0.21061500E+03, -.23211200E+02, -.64319300E+02, -.11373300E+03, 0.70956200E+02, 0.66030700E+02, 0.31096200E+02, -.41977300E+02, -.10279100E+03, 0.74739400E+02, -.23336000E+02, 0.16572900E+02, 0.11065800E+02, -.11266600E+02, -.93998800E+02, -.36753500E+01, -.77244000E+01, 0.19284900E+03, 0.11250700E+02, -.18205900E+02, -.78687600E+01, 0.19856400E+03, -.50470300E+02, -.15325100E+03, 0.58660000E+02, 0.29627500E+01, 0.10916200E+02, -.89823600E+02, 0.44082900E+02, -.36057600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12634200E+01, 0.47133200E-01, 0.28137100E+00, -.25719000E+00, 0.14405600E+01, 0.53967600E+00, 0.93700800E+00, 0.65200100E+00, 0.44711500E+00, 0.14190100E+01, -.15725600E+00, -.27795600E+00, -.25305400E+00, 0.22061200E+00, 0.19248100E+01, -.19390200E+01, 0.18217600E+00, -.47147800E+00, -.86716500E+00, -.62211900E+00, 0.57171000E+00, -.52074900E+00, -.47282300E+00, 0.33310300E+00, 0.17616100E+00, 0.39634300E+00, 0.18305800E+00, -.43451700E+00, -.29361700E+00, 0.36400700E+00, 0.11870800E+00, -.20816400E+00, -.21125400E-01, -.11919600E+01, -.10085400E-01, -.23734600E+00, -.29460600E+00, 0.17814500E+00, -.38660500E+00, -.12121200E+00, 0.77173100E+00, -.15211600E+00, 0.41282900E+00, 0.10704700E+00, -.19354600E+00, 0.43767700E+00, -.73702000E-01, -.18220400E+00, 0.28864300E+00, 0.28464900E+01, -.24395900E+00, -.85828500E+02, 0.71623500E+02, -.47256500E+01, -.41033400E+01, -.11205800E+03, 0.11139000E+01, -.64025200E+00, 0.23086200E+00, 0.23249600E+00, -.36942500E+00, 0.54544700E+00, 0.30556100E+00, 0.43447000E+00, -.63760100E+02, 0.17581500E+03, 0.23103000E+02, -.58925200E+01, 0.28697200E+02, 0.24771000E+02, 0.50041000E+02, 0.22915400E+01, 0.27748900E+03, -.67676200E+02, -.77835800E+02, -.83567000E+02, 0.40007100E+02, 0.99503400E+02, -.16374100E+02, -.78516300E+02, 0.23868300E+03, -.13600500E+01, -.66565400E+01, 0.91195100E+02, -.13190800E+03, 0.91144300E+02, -.18497500E+02, 0.12561900E+03, 0.18573200E+02, -.34908800E+02, -.36222100E+01, -.15023600E+02, 0.17464200E+02, 0.19638200E+02, 0.15467700E+02, -.17064500E+02, -.14214200E+03, 0.12472600E+02, -.51195200E+00, -.17004400E+02, 0.87612300E+02, -.48482600E+02, 0.87730800E+01, -.13076400E+02, 0.18736600E+02, 0.95997200E+02, 0.30992100E+02, 0.11434000E+02, -.22615900E+02, -.26929900E+02, -.64226700E+02, 0.73406300E+01, -.12446300E+03, 0.34958700E+02, 0.40223500E+02, 0.56949200E+02, -.46155700E+02, -.44662300E+02, 0.22762500E+02, 0.53218300E+02, -.66408000E+00, 0.15463500E+00, -.12064500E+00, -.20008600E+00, 0.24932800E+00, -.22805800E+00, 0.82436400E-01, -.28519300E+00, 0.14524200E+03, -.49753200E+02, -.10674500E+03, -.10881500E+03, 0.16063300E+03, 0.89276200E+02, 0.49083400E+02, -.87616400E+02, -.33765400E+02, 0.89871400E+02, -.59781200E+01, 0.15735300E+02, -.67405200E+01, -.23299300E+01, 0.34326200E+02, 0.21048400E+02, -.83833300E+01, 0.15308800E+01, -.25594000E+00, 0.38513500E+01, 0.12751700E+02, -.38438200E+01, -.15213000E+02, 0.46298300E+01, -.34227600E+01, 0.80515300E+01, 0.42865300E+01, -.42804400E+01, -.22478300E+02, -.38573500E+01, -.50337500E+01, -.66910500E+01, 0.42712300E+01, -.12993200E+02, 0.11458300E+02, 0.11740000E+02, 0.12429700E+01, -.30412400E+02, 0.61655000E+01, 0.31927300E+01, 0.43034300E+01, -.36780100E+02, 0.10044900E+02, 0.83645400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.39030800E+01, -.82784000E+00, 0.35675200E+00, 0.14202000E+01, 0.38011000E+00, 0.68545500E+00, 0.13874800E+01, -.22919700E+01, 0.22960600E+01, -.32365400E+01, 0.60407500E+00, 0.14499800E+01, -.36903900E+00, 0.10205000E-01, -.87565700E+00, -.55088500E+01, -.63593600E+00, 0.93973900E+00, 0.65627500E-01, 0.34930500E+00, -.63965900E+00, 0.64082600E+00, 0.80781700E+00, 0.13699500E+01, 0.20069300E+00, -.69229200E+00, 0.96606400E+00, -.70143000E+00, 0.13306700E+01, 0.57710900E+00, 0.98715800E-02, -.19053000E+01, -.85935000E+00, -.53616000E+01, -.44052800E+00, 0.40859700E+00, 0.28766600E+01, -.11988100E+01, 0.96291300E+00, 0.13577700E+01, -.28830200E+01, -.63439000E+00, 0.23694100E+00, 0.20453500E+00, 0.41737500E-01, 0.27065400E+00, -.13783800E+00, 0.28140400E+00, -.30352400E+00, 0.61706300E+00, -.38884400E+00, 0.83135200E+00, 0.10391200E+03, 0.52322300E+02, -.52328000E+01, 0.12069100E+02, 0.23375400E+00, 0.20146500E+01, -.14598800E+01, -.79074400E+00, 0.94909300E+00, 0.54214300E+00, 0.13560700E+01, -.81212300E+00, -.81700200E+03, 0.16814300E+03, 0.68946900E+02, 0.81240100E+02, 0.21439800E+03, -.29686500E+03, 0.69303100E+02, 0.77901600E+02, 0.12322500E+04, 0.65420800E+02, -.27015600E+03, -.26683700E+03, -.11399600E+03, 0.41896400E+03, -.13629200E+03, -.26711900E+03, -.30376200E+03, -.23626100E+03, -.83169100E+02, -.13833300E-01, -.77514500E+02, -.19785400E+03, -.18863900E+02, -.23730300E+02, 0.30657800E+02, 0.44177700E+02, 0.86807200E+02, 0.97484100E+01, 0.47190400E+02, 0.43777800E+02, 0.73306300E+02, 0.20374900E+02, -.91262300E+03, 0.21460700E+03, 0.26963300E+03, 0.19845900E+03, 0.15619400E+03, -.31656800E+03, 0.16729500E+03, 0.22020300E+03, -.26379300E+03, 0.45278300E+03, 0.20752300E+03, 0.15381800E+03, 0.69659900E+02, -.10819700E+03, -.17867100E+02, 0.16554000E+03, 0.13708900E+03, -.49279700E+02, -.30653000E+02, -.30392100E+02, -.49325900E+02, 0.25758900E+02, -.19486000E+02, -.35788100E+02, 0.23973800E+01, -.61489800E+00, -.14069500E+01, -.57845100E+00, -.47218200E+00, 0.55555800E+00, -.13829400E+00, -.73524100E+00, 0.35091300E+03, -.26751100E+02, -.16897400E+03, -.17187100E+03, 0.18048500E+03, 0.22139000E+03, 0.61407100E+02, -.16545800E+03, 0.30159500E+03, -.90313600E+02, -.79636800E+02, -.10167900E+03, -.58042600E+01, 0.11267800E+03, -.10617900E+02, -.11154600E+03, -.34766700E+02, 0.22355000E+02, 0.19470300E+02, -.27861000E+01, 0.19813600E+02, 0.33790500E+01, 0.23451100E+02, 0.32979100E+01, 0.26637200E+00, 0.63255100E+01, 0.16856500E+01, -.21080700E+01, -.22613800E+02, 0.32169600E+01, 0.92407200E+01, 0.55358300E+02, 0.21136300E+01, -.11662600E+02, 0.24113600E+02, 0.79086500E+01, 0.99894400E+02, -.96560900E+02, 0.63162700E+02, -.82149300E+01, 0.14999300E+01, -.35993900E+02, 0.14001400E+02, -.13945000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17593400E+01, 0.20252700E-01, -.20313300E+01, -.10709200E+01, -.52866400E+00, -.55927500E+00, 0.26393700E+01, 0.20066900E+01, 0.81899500E+00, -.54625300E+00, -.45264400E+00, -.13982300E+01, -.50147200E-01, -.20672900E+01, -.10861500E+01, -.32057800E+01, -.15460400E+00, 0.82098500E-01, -.12622300E+01, -.19475100E+01, 0.26994200E+00, -.15166900E+01, 0.29644000E+00, -.59066700E+00, 0.73895200E+00, 0.97232200E+00, 0.23614500E-01, 0.15056100E+01, 0.86342500E+00, 0.38351100E+00, -.72642000E+00, 0.40335800E-01, -.15115700E+00, 0.16534500E+01, -.78974800E+00, 0.21003300E+00, -.44235200E+00, -.15136700E+00, -.13003200E+01, 0.45430600E+00, 0.54806400E+00, -.79129700E-01, 0.48126900E+00, 0.88240400E-01, -.11411500E+00, 0.38561200E+00, -.53321400E-01, -.43746000E+00, 0.44481800E+00, 0.26917600E+01, -.39762200E-01, -.35344100E+00, 0.14765300E+00, -.66770300E+02, -.79632100E+02, -.84529900E+01, 0.80690200E+00, -.52258200E+00, 0.74817200E+00, 0.37454600E+00, -.56850500E+00, -.66659500E-02, -.31630700E+00, 0.45127700E+00, -.66177800E+02, 0.13070800E+03, -.97471100E+01, -.45097700E+02, 0.27791400E+02, 0.52979800E+02, 0.11638000E+03, -.44513900E+02, 0.19184000E+03, -.41672800E+02, -.23694600E+02, -.31959200E+02, -.34420900E+00, 0.67599700E+02, 0.37881400E+01, -.27808900E+02, 0.29371400E+03, -.20690100E+02, -.13686000E+02, -.42621400E+02, -.23503200E+02, 0.19425900E+03, 0.86218800E+02, -.45383900E+02, 0.12244700E+02, -.35813000E+02, -.39190600E+01, 0.41538200E+01, -.91748700E+01, -.40682800E+01, -.19421500E+02, 0.50728500E+01, 0.20896600E+03, -.58511700E+02, -.49232900E+02, -.55931400E+02, -.24539900E+02, 0.85233100E+02, -.20013300E+02, -.48100400E+02, 0.27374200E+03, -.54715400E+02, -.45867100E+02, -.46038100E+02, -.83675000E+02, 0.66557100E+02, -.33630200E+02, -.45475800E+02, -.77256200E+02, 0.44265600E+02, 0.28414200E+01, -.10036800E+01, 0.21601600E+02, 0.59693500E+01, 0.45182100E+02, -.72718200E+01, -.58651600E+00, 0.28232100E+00, 0.24945800E+00, 0.13848300E+00, 0.16870300E+00, -.42496300E+00, -.22532000E+00, 0.17550400E+00, 0.11820000E+03, -.33889300E+02, -.17775000E+02, -.15382200E+02, -.70760200E+01, 0.79357600E+01, -.49892600E+01, -.66247200E+01, -.54293400E+02, 0.79428000E+02, 0.25936000E+02, 0.36180600E+02, -.29115300E+02, -.40341700E+02, -.30844300E+01, 0.38270200E+02, 0.10567300E+02, -.80653400E+01, -.11243100E+02, -.26288200E+01, 0.59012400E+01, 0.12674000E+02, -.18929200E+01, -.35728300E+01, -.42807900E+01, -.19925300E+01, 0.47201000E+00, -.35473500E+00, 0.80027900E+01, -.59758000E+00, -.16455800E+01, 0.31980300E+02, 0.34580700E+00, -.11381700E+02, 0.23639700E+02, 0.25561300E+02, -.15973800E+02, 0.17007500E+02, -.11833100E+02, 0.66169000E+01, 0.54082200E+00, -.52884600E+01, -.10021300E+02, 0.29398600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.55947400E+00, -.12315600E-01, 0.10387800E+00, -.53198900E-01, -.51607000E+00, -.20613600E+00, -.35952600E+00, -.11713700E+00, -.83703300E-01, 0.30001700E+00, -.91389800E-01, -.29014900E-01, 0.18935700E+00, -.45667400E+00, -.92211000E+00, 0.33291900E+00, -.24288800E-01, -.20467300E-01, -.77710400E-01, 0.82427100E+00, -.42096100E+00, 0.61772400E+00, 0.75246600E+00, 0.24557600E+00, 0.18728500E-01, -.15683900E+00, -.69365800E+00, 0.33551400E+00, 0.20027200E+00, 0.33630000E+00, -.18036300E-01, 0.27793200E+00, 0.14722000E-02, -.17143200E+01, 0.15610800E+00, -.15272400E+00, -.36252200E+00, -.21218900E-01, 0.74005400E-01, -.31686600E+00, -.16890400E+00, 0.69721200E-03, 0.75265000E-01, 0.31649400E-01, -.99849200E-01, 0.19238700E+00, 0.51298700E-02, 0.60427900E+00, 0.60183600E-01, 0.14730600E+00, -.69148400E-01, -.30084500E-01, 0.79162400E-01, 0.15143000E+00, 0.19846000E+02, -.11103900E+01, 0.63529500E-01, 0.88398100E-01, 0.56257500E-01, 0.95000300E-01, -.29168500E-01, 0.36051900E-01, -.32291600E-01, 0.12094500E+00, 0.14435900E+03, -.67889500E+02, -.45228800E+02, -.38429200E+02, -.29890900E+02, 0.46210600E+02, -.10349000E+02, -.40718000E+02, -.29253900E+03, 0.36501900E+02, 0.70741600E+02, 0.48120000E+02, 0.43337300E+02, -.96256700E+02, 0.24487300E+02, 0.49107200E+02, 0.21148600E+02, 0.39485300E+02, 0.17543900E+02, -.25068500E+01, -.69267800E+01, 0.13795200E+02, -.20779600E+02, 0.53909000E+01, -.12702800E+02, -.25008000E+01, -.52677400E+01, 0.19467800E+01, -.79194500E+01, -.61359600E+01, -.10329800E+02, 0.56063000E+00, 0.25978600E+03, -.10912100E+03, -.96945100E+02, -.41868500E+02, -.45906800E+02, 0.82425600E+02, -.38922000E+02, -.50094100E+02, 0.30244300E+02, -.10114900E+03, -.73950600E+02, -.30760900E+02, -.35455300E+01, 0.19376600E+02, 0.13857700E+02, -.37840200E+02, -.29470300E+02, 0.40993400E+01, 0.16904800E+02, 0.23490500E+02, -.12658400E+02, -.22830600E+02, -.11248100E+02, 0.26164200E+02, -.31156100E+00, 0.36726900E+00, 0.38138600E+00, 0.22231800E+00, 0.84298400E-01, -.39479800E-01, 0.20058700E-01, 0.27048500E+00, -.76651600E+02, 0.21083500E+01, 0.19116300E+02, -.56974200E+01, 0.17778700E+02, -.92488900E+01, 0.27970000E+02, -.43376100E+01, -.48676500E+02, 0.14814300E+02, 0.14067400E+02, 0.13464000E+02, 0.57241400E+01, -.10123700E+02, 0.80590600E+01, 0.17480200E+02, -.33026000E+01, -.13763900E+02, -.66646300E+01, -.32336800E+01, -.14728800E+00, -.55208900E+01, -.15301800E+01, -.54357200E+01, -.14897900E+01, 0.27725800E+01, 0.12611900E+01, -.11465700E+01, 0.86788500E+01, -.78231100E+00, -.28884800E+01, -.10864800E+02, 0.11465700E+01, 0.13196700E+02, 0.88357000E+01, -.31586800E+01, -.10797300E+02, 0.34804500E+02, -.20453600E+02, -.12804700E+01, 0.11513300E+01, -.34070300E-01, 0.27615200E+01, 0.35445900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.75535100E+01, 0.26188600E+00, -.61683300E+01, -.46445300E+01, -.21829000E+01, -.20299500E+01, 0.66049500E+01, 0.96321100E+01, 0.95202800E+00, -.50142500E+00, -.26527200E+01, -.69322700E+01, 0.55768700E+00, -.87168000E+01, -.63063900E+01, -.36823100E+01, -.25314700E+00, -.13043000E+01, -.43652000E+01, -.45316800E+01, 0.28356500E-02, -.60797600E+00, 0.84350400E+00, -.63733900E+00, 0.28638100E+00, 0.32836900E+01, -.93313200E-01, 0.32907900E+01, 0.11315700E+01, 0.13795600E+01, -.71971500E+00, -.11636300E+01, 0.39394600E+00, 0.71214200E+01, -.13635300E+01, -.90198700E+00, 0.19393700E+01, 0.77322100E+00, -.72112200E+00, 0.15654500E+01, -.16158800E+01, -.19215300E+00, 0.46769400E+00, 0.43012900E+00, -.28229400E+00, 0.14186500E+01, 0.33267100E+00, 0.57549900E+01, 0.23263800E+01, 0.15091100E+02, 0.76986900E+00, -.66818500E+00, 0.92848700E+00, -.56400600E+00, 0.14071800E+01, -.14592300E+03, 0.59261800E+00, -.55768000E+01, 0.20566000E+01, 0.12934200E+01, -.12362600E+01, -.11744000E+00, -.26548600E+01, 0.14405300E+01, -.62123800E+02, 0.81831500E+02, -.60060700E+02, -.10879200E+03, 0.49966100E+02, -.68345000E+02, 0.15361400E+03, -.13864200E+03, -.40760600E+03, 0.53721600E+03, 0.12963100E+02, 0.92774500E+02, 0.14906200E+02, -.22929600E+03, -.71847900E+01, 0.75331100E+01, 0.17678000E+04, -.70523200E+03, -.22177500E+03, -.28702800E+03, -.18759800E+03, 0.49947700E+03, -.51993400E+02, -.21622000E+03, 0.85661800E+02, 0.62736200E+02, -.16195400E+02, -.15227700E+01, -.76678300E+02, -.17471200E+02, -.55677800E+02, -.43610800E+01, 0.23439800E+04, -.10385000E+04, -.25471700E+03, -.39047600E+03, -.34948300E+03, 0.78649000E+03, -.24678800E+03, -.23025000E+03, 0.63693900E+03, -.46322300E+03, -.19725900E+03, -.22976600E+03, -.14059700E+03, 0.23864500E+03, -.97740000E+02, -.14362700E+03, -.16537200E+03, -.18259500E+02, 0.96309700E+02, 0.50741000E+02, 0.70001000E+02, 0.74092300E+02, 0.90789300E+01, 0.51634600E+02, -.28143900E+01, -.22111200E+01, 0.17777800E+01, 0.14122000E+01, 0.29204800E+00, -.42151800E+00, -.95157600E+00, 0.14470700E+01, 0.16025500E+03, 0.21362800E+01, -.19127600E+02, 0.10032200E+03, -.24487600E+03, -.12600400E+03, -.14567200E+03, 0.26028900E+02, -.17820600E+03, -.15129700E+03, 0.17167800E+03, 0.17331700E+03, -.59204000E+02, -.65065900E+02, -.31003900E+02, 0.19503200E+03, 0.15481300E+03, 0.15346100E+03, -.10559100E+03, -.69353000E+02, -.15268000E+02, 0.37286500E+02, 0.15251700E+02, -.71374700E+02, 0.12848400E+01, -.10105400E+02, -.82863600E+01, 0.87947100E+01, -.14143500E+03, 0.60654200E+01, 0.42318500E+01, -.36647200E+02, -.88022400E+01, -.59606600E+01, -.20262100E+03, 0.33498700E+02, -.47463400E+02, -.15332000E+03, -.33414000E+02, 0.43313600E+02, -.77085500E+01, 0.49056400E+02, -.10261600E+03, 0.37240800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.67127700E+01, -.23532300E+00, 0.65088700E+01, 0.37260600E+01, 0.21247500E+01, 0.25194800E+01, -.22618600E+01, -.57751200E+01, 0.16822900E+01, -.12002200E+00, 0.99394500E+00, 0.46427400E+01, -.36944100E+00, 0.35020800E+01, 0.43722900E+01, -.28634200E+01, -.33280700E+00, 0.54394500E+00, 0.17306800E+01, -.34287500E+01, 0.44677000E+00, 0.13061500E+01, 0.41687100E+00, -.28058900E+00, 0.16028400E+00, -.51042500E+00, 0.24028800E+01, -.11811400E+01, -.14114400E+00, -.36282000E-01, 0.22542600E+00, 0.64910600E+00, 0.13201600E+01, -.18602500E+01, -.47933400E+00, 0.29401300E+00, 0.18331100E+01, -.38040100E+00, 0.30644600E+00, -.11720400E+00, 0.82670700E+00, -.27229200E+00, -.52950900E+00, -.14841200E+00, -.52654900E+00, 0.39570000E+00, -.23349600E+00, 0.89559400E+00, 0.28841800E+00, 0.29836700E+01, -.16524200E+00, -.21913100E-01, 0.27198200E+00, -.65421100E-01, -.11981500E+01, -.81024900E-01, 0.39490700E+01, 0.83613700E-01, 0.71782600E+00, 0.38212500E+00, -.14251800E+00, 0.33489600E+00, -.47182700E+00, 0.50808500E+00, 0.39972600E+03, -.99034200E+02, -.82459300E+02, -.94410000E+02, -.90600700E+02, 0.14126500E+03, 0.14078300E+02, -.98332200E+02, -.47766400E+03, 0.19403000E+03, 0.99310200E+02, 0.65081500E+02, 0.95672000E+02, -.14484800E+03, 0.53741300E+02, 0.60262400E+02, 0.23424600E+03, 0.14108700E+03, 0.39102100E+02, -.15794400E+02, -.31141400E+02, 0.89448200E+02, -.21006800E+02, -.15259900E+02, 0.64158700E+01, -.20984500E+02, -.34348100E+02, -.10720400E+02, -.31362600E+02, -.32050700E+01, -.26848400E+02, -.99321800E+01, 0.74289900E+03, -.35881200E+03, -.19394300E+03, -.11718500E+03, -.13895900E+03, 0.23649500E+03, -.96268700E+02, -.11994100E+03, 0.30916000E+03, -.17576400E+03, -.17075000E+03, -.10767500E+03, -.88622000E+02, 0.11607100E+03, -.68078300E+00, -.11898500E+03, -.10055700E+03, 0.47693100E+02, 0.52402300E+02, 0.54041900E+02, -.19953300E+01, -.55570300E+02, -.20431000E+02, 0.56230900E+02, 0.15384300E+00, 0.10779300E+01, 0.12033500E+01, 0.84437600E+00, 0.58157900E+00, -.50392300E+00, 0.18478700E-01, 0.10084000E+01, -.27014900E+02, 0.60574400E+02, -.66916600E+01, -.40612300E+02, 0.29985500E+02, 0.34252400E+02, 0.63367200E+02, -.33118800E+02, -.58299800E+02, 0.83112000E+02, 0.37938400E+02, 0.32790800E+02, 0.42205900E+01, 0.24566600E+01, 0.16216300E+02, 0.45514800E+02, 0.18057800E+02, -.38425600E+02, -.31082400E+02, -.17840000E+02, -.22817400E+01, -.75815000E+01, -.95680000E+01, -.26625200E+02, -.86961200E+01, 0.20639400E+01, 0.34474500E+00, 0.56930400E-01, 0.13909300E+02, 0.35531800E+01, -.54173300E-01, -.60206700E+01, -.71708300E-01, 0.16336200E+02, 0.32074200E+02, -.46378200E+00, -.35600900E+02, 0.73456100E+02, -.43778700E+02, 0.39060000E+01, 0.13298500E+00, -.50473400E+01, -.31235100E+01, 0.15244700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20469800E+01, 0.65581200E+00, 0.97377000E-01, -.26556000E+00, 0.24814000E+00, 0.12591800E+00, -.68608800E+00, 0.16269900E+01, -.67374100E+00, -.49352900E+00, -.53811100E+00, -.14475000E+01, -.24469700E+00, -.37076100E+00, -.38746400E+00, 0.16476100E+01, 0.84409200E-01, -.37014500E+00, -.13929200E+00, -.10436000E+01, -.50341700E-01, 0.79848800E+00, 0.38630500E+00, -.66818600E+00, -.12282100E+00, -.10063600E+00, -.10228300E-01, 0.11738300E+01, -.19901000E+00, 0.57486600E-01, 0.25796400E+00, 0.76140600E+00, 0.25954200E+00, 0.53582600E+00, -.18942700E+00, -.44549700E+00, -.61687900E+00, 0.26657300E+00, 0.15079300E-01, -.13262500E+00, 0.23535600E+00, 0.18396100E+00, 0.27787600E+00, -.13979800E-01, 0.29530700E+00, -.13874900E+00, 0.43386100E-02, -.16512800E+01, -.28799900E+00, -.17624800E+01, 0.47089600E-01, 0.79369800E-02, -.24472000E+00, -.12395300E+00, 0.53543200E-01, -.10588900E+00, 0.23447200E-01, 0.35725800E+01, 0.33324500E-01, -.68319400E-01, -.87226300E-01, 0.74842000E-02, 0.27878300E-01, -.76696000E-01, -.11433300E+03, 0.10233400E+03, 0.17198500E+02, 0.11449000E+02, 0.29035500E+02, -.98561100E+01, 0.31489100E+02, 0.16250400E+02, 0.21395700E+03, 0.17237300E+02, -.34221400E+02, -.27418700E+02, -.37596500E+02, 0.76124600E+02, -.27114600E+02, -.30895300E+02, 0.23325000E+02, 0.51270100E+02, -.27222300E+02, -.21983100E+02, 0.13100200E+02, 0.28819900E+02, 0.22213200E+02, -.32798700E+02, 0.25671300E+02, -.29195900E+02, 0.23680200E+01, -.37851100E+01, 0.31695800E+01, 0.16304500E+02, 0.92377900E+01, 0.75143800E+00, -.11621800E+03, 0.79166300E+02, 0.44036900E+02, 0.83616900E+01, 0.37731900E+02, -.17783300E+02, 0.56632500E+02, 0.24020800E+02, -.35188100E+02, 0.16185900E+03, 0.55800300E+02, 0.32983300E+02, 0.40876900E+01, -.16524300E+02, -.12678900E+02, 0.49982000E+02, 0.14289000E+02, 0.14795600E+02, -.15459900E+02, -.13623700E+02, 0.53088400E+01, 0.53335100E+01, 0.10505300E+02, -.17220600E+02, 0.23885000E+00, 0.23372900E+01, -.39199700E+00, -.33237800E+00, 0.32557200E-01, 0.10380600E+00, 0.95503500E-01, -.41048600E+00, -.18996200E+02, 0.10183600E+02, 0.59190200E+00, 0.71600300E+01, -.71446400E+01, -.17756800E+01, 0.20382700E+01, 0.20374700E+01, 0.33334300E+02, 0.22850700E+02, -.18953800E+02, -.12205300E+02, -.12043800E+02, 0.74152400E+01, 0.27337100E+01, -.13771700E+02, -.39298000E+01, 0.95366300E+01, 0.10841900E+02, 0.63755100E+01, 0.37758500E+01, 0.23667900E+01, -.62873700E+00, 0.74485600E+01, 0.58222500E+00, -.12389400E+01, 0.97533100E-01, -.17391700E+00, -.15377200E+01, -.80281200E+00, -.10155200E+01, 0.31776200E+01, 0.17784200E+00, -.68955400E+01, 0.48979100E+01, 0.37986200E+00, 0.23792700E+01, -.29305900E+02, 0.21656700E+02, -.59604900E+00, 0.13308200E+00, 0.65309200E+00, 0.40282200E+01, -.48747400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.80926500E+00, 0.42601600E-01, 0.21450500E+00, -.13001600E+00, 0.57702300E+00, 0.24149000E+00, 0.22889000E+00, 0.44216400E+00, -.49100900E-01, 0.14531800E+00, -.37166700E-01, -.27785500E+00, 0.76763800E-02, -.18485500E+00, -.26530700E+00, 0.47295300E-01, 0.49796200E-01, -.65696700E-01, -.17991500E+00, 0.13674000E+00, 0.47450700E-02, -.57072300E-01, 0.68712300E-01, 0.42375800E-01, 0.74455500E-02, 0.12297300E+00, -.35132100E+00, 0.36515100E+00, 0.22988200E+00, 0.95086700E-01, -.46419200E-01, -.34839500E+00, -.24458600E+00, -.87986200E+00, 0.35145000E-02, 0.25348200E+00, -.12545300E+00, -.65038700E-01, -.19763800E+00, -.28216100E-01, 0.18466900E+00, 0.79269500E-01, -.26367800E-01, 0.88176100E-02, 0.23368400E-01, -.38804300E-01, -.96270700E-02, -.34233600E+00, 0.97523800E-02, -.49017700E+00, -.37376500E-01, 0.31676600E-01, 0.66300700E-03, 0.11232400E-01, -.22650600E-01, -.23978000E-01, 0.56285000E-01, -.13200100E-01, 0.69480900E+00, 0.51499500E-01, -.13306100E+00, 0.19236700E-01, 0.75824200E-01, 0.44186500E-01, -.43851200E+02, 0.35328200E+02, 0.25948600E+02, 0.14461500E+02, 0.25491800E+01, -.83661400E+00, 0.21258300E+02, 0.16171500E+02, 0.38522400E+02, 0.98923700E+01, -.11447800E+02, -.11372400E+02, 0.41654500E+00, 0.14454800E+02, -.37962500E+01, -.13769900E+02, -.78598300E+01, 0.17062900E+02, 0.13907200E+02, 0.74883100E+01, -.78465500E+00, 0.73279400E+00, -.76282500E+00, 0.65480600E+01, 0.96967400E+01, -.56827300E+01, 0.31213500E+01, -.45377900E+00, 0.10869800E+00, 0.50337800E+01, 0.40165400E+01, 0.91159900E+00, 0.23047200E+02, -.14359100E+02, 0.11249700E+02, 0.80975800E+01, -.14526900E+02, 0.94657700E+01, -.23539000E+00, 0.13354000E+02, 0.31331400E+02, 0.83926800E+01, 0.14714800E+02, 0.37527500E+01, -.11410200E+02, 0.94904800E+01, -.12424700E+01, 0.70174300E+01, 0.13917100E+01, -.91321200E+00, -.17996500E+01, -.43268800E+01, 0.29754900E+01, 0.38006900E+01, 0.63367200E+01, -.50246000E+01, -.59603200E-01, -.54428100E-01, 0.30779300E+00, -.71768700E-01, -.14777100E-02, -.12651100E-01, 0.12725500E-01, -.89936800E-01, 0.99731800E+01, 0.64585700E+01, 0.50274000E+01, 0.33665400E+00, -.29913800E+01, 0.12471800E+01, 0.31239800E+01, -.67138600E+00, 0.28616000E+01, 0.29361400E+01, 0.57697100E+01, 0.33714600E+01, -.78729600E+01, -.36737900E+01, -.15004600E+01, 0.32471500E+01, 0.48984100E+01, 0.11022700E+01, -.27205100E+00, -.49975900E+00, 0.14846300E+01, 0.46222100E+01, 0.18918600E+01, -.28769400E-01, -.78959800E+00, -.41212500E+00, 0.31757100E+00, -.29820500E+00, -.42713500E+01, 0.19765700E+00, -.25876800E-01, 0.27584300E+01, 0.30296800E+00, -.11165200E+02, -.11213100E+01, 0.32700500E+01, 0.37971100E+01, -.56480900E+01, 0.30791800E+01, 0.69577500E+00, 0.36491700E+00, -.19751800E+00, -.42670400E+01, 0.81238700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10622900E+01, 0.56950300E-01, 0.78247600E-01, -.78344200E+00, -.54158400E-01, -.37155900E+00, 0.27448900E+00, 0.66585500E+00, -.25913900E+00, 0.20261600E+00, 0.58971100E-02, -.48255600E+00, 0.33938200E-01, -.29224700E+00, -.46215500E+00, 0.83954200E+00, 0.13296500E+00, -.16243500E+00, -.16465400E+00, 0.65221200E+00, -.27582000E+00, 0.33296100E-01, 0.11208000E+00, 0.14295000E+00, -.60364800E-01, -.26211100E+00, -.47595300E+00, 0.73760700E+00, 0.36984400E+00, 0.84875700E-01, 0.11504900E-02, -.74855700E+00, -.50675900E+00, -.17800500E+01, 0.14841500E+00, -.36019400E-01, -.34831000E+00, -.85547700E-01, -.18937600E+00, -.22639000E+00, 0.96495900E-01, -.94410800E-01, 0.30421700E+00, 0.13626300E+00, -.94635400E-01, 0.26505800E+00, 0.52329200E-01, -.92223500E+00, -.19484700E+00, -.55472800E+00, -.61849600E-01, 0.24065500E-01, -.23578700E-01, 0.44586300E-01, -.34919700E+00, -.22889000E-01, 0.19433700E-01, 0.41612700E-01, -.41574300E-01, 0.37305500E+00, -.65535600E-01, 0.21545600E-01, 0.16812400E+00, -.87339000E-02, -.53902800E+02, 0.59222600E+01, -.12262400E+02, -.34084400E+01, 0.16602500E+02, -.40736100E+01, 0.44499200E+01, -.40180800E+01, -.10516300E+03, 0.15948100E+02, 0.18085500E+02, 0.13257800E+02, 0.23816900E+02, -.30695100E+02, 0.80304200E+01, 0.14925200E+02, -.48194700E+02, -.66907900E+00, 0.42271700E+01, 0.11901000E+02, -.64337900E+01, -.13206800E+02, -.63036900E+01, 0.14271000E+02, -.43614400E+01, -.48040700E+00, 0.51527100E+01, 0.24918800E+01, 0.19410200E+01, 0.23296500E+01, 0.11361700E+01, 0.29477900E+01, -.10099100E+03, 0.29783700E+02, -.26347300E+00, 0.11057100E+02, 0.23589600E+02, -.22678400E+02, 0.27477300E+02, 0.64502800E+01, -.77859800E+02, 0.13645000E+02, 0.12026600E+02, 0.22806900E+02, 0.17702400E+02, -.25931200E+02, 0.57988300E+01, 0.18164600E+02, -.44248600E+01, -.62998700E+01, -.14321200E+01, 0.80528300E+01, -.92569600E+01, -.93425400E+01, -.37362000E+01, 0.83325200E+01, 0.22446800E+00, -.68225600E-01, -.12582200E+00, 0.80557500E-01, 0.18106900E-01, 0.11249600E+00, 0.10104500E+00, -.22684200E+00, -.47275900E+02, -.62115200E+01, 0.39516600E+01, -.68879600E+01, 0.22674300E+02, -.77150900E+01, 0.17092200E+02, -.34021100E+01, -.15512500E+02, 0.90305100E+01, -.55040000E+01, -.24761800E+01, 0.17839000E+01, -.62579300E+01, 0.75917400E+01, -.16014400E+01, -.53453100E+01, -.54341900E+01, 0.99041700E+01, 0.71698700E+01, -.65903600E+00, -.16052500E+01, -.36125900E+01, 0.73316900E+01, 0.33282500E+00, 0.17539200E+01, 0.15008800E+01, -.15354400E+01, 0.98320700E+01, -.17662800E+01, -.18093800E+01, -.19156600E+01, 0.15340900E+01, 0.72932200E+01, 0.15862600E+02, -.10122200E+01, 0.10802100E+01, 0.89582100E+01, 0.12347900E+01, -.18137700E+01, 0.14814800E+01, -.25618300E+01, 0.56984400E+01, -.27497100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.95061100E+00, -.17325000E-01, 0.20455300E+01, 0.50219900E+00, 0.79920900E-01, 0.34832700E+00, -.79102500E+00, -.94515200E+00, 0.47000000E-01, 0.63894100E-01, 0.28851300E+00, 0.72610600E+00, -.12722500E+00, 0.83060300E+00, 0.94096000E+00, -.15035900E+00, 0.57524100E-01, 0.81692500E-01, 0.35201000E+00, 0.16736600E+00, 0.26962500E-01, -.66026500E-01, -.96861300E-01, 0.14586500E+00, 0.35579300E-02, 0.38491500E-02, 0.48174000E-01, -.31019800E+00, 0.84299200E-01, -.19902300E-01, 0.50390500E-01, -.18655200E+00, -.11873700E-01, -.32257600E+00, 0.83026300E-01, 0.16863600E+00, 0.19162200E+00, -.35649900E-01, -.10626400E+00, -.26731200E-01, 0.17804700E+00, -.46694900E-01, -.19807800E+00, -.40788500E-01, -.13740500E+00, -.25425100E-01, -.49458100E-01, 0.39616200E+00, -.81424800E-01, -.67365800E+00, -.11006700E+00, 0.13121400E-01, 0.20851100E-01, 0.29989700E-01, -.23780000E+00, -.49801800E-01, -.14762400E-01, -.10454200E-01, 0.80733400E-02, -.29330000E-01, 0.27802900E+00, 0.78081400E-02, 0.12056700E-01, 0.38153800E-02, 0.72285500E+02, -.17664700E+02, -.15784100E+02, -.14749100E+02, -.16826700E+02, 0.17944800E+02, -.91727400E+01, -.15534600E+02, -.69908300E+02, 0.35120900E+01, 0.18948800E+02, 0.13671300E+02, 0.80827900E+01, -.23375300E+02, 0.66047300E+01, 0.15384100E+02, 0.18774500E+02, 0.13366400E+02, 0.34600200E+01, -.22094100E+01, -.37712900E+01, 0.40736500E+01, -.19996500E+01, 0.56181400E+00, -.78951700E+01, -.43081000E+00, -.50278900E+01, 0.56621700E+00, -.39620200E+01, -.47238100E+01, -.63173800E+01, -.77765000E+00, 0.45089300E+02, -.15701000E+02, -.25759900E+02, -.12374400E+02, -.45196100E+01, 0.12212700E+02, -.11850500E+02, -.17541700E+02, 0.49685200E+01, -.25193200E+02, -.23630900E+02, -.12072200E+02, -.40154100E+00, 0.51332500E+01, 0.42968300E+01, -.16666600E+02, -.99770100E+01, 0.47950100E+01, 0.56939200E+01, 0.63315600E+01, -.43568300E+00, -.62270000E+01, -.49709800E+01, 0.71908900E+01, -.16360200E+00, 0.15662300E+00, 0.15709100E+00, 0.10884700E+00, 0.59167300E-01, -.23552400E-01, 0.63012300E-01, 0.13090300E+00, 0.92464800E-01, 0.24656300E+01, -.23282900E+00, -.38072800E+01, 0.24243900E-01, 0.41831600E+01, 0.57639600E+01, -.17244800E+01, -.15905500E+02, 0.87253600E+01, 0.47807600E+00, 0.27936000E+01, 0.52715100E+01, -.18521700E+01, 0.36817300E+01, 0.36261700E+01, -.28614900E+01, -.54713800E+01, -.10027700E+01, -.43833100E+00, -.14347000E+01, -.39382900E+01, -.23065500E+01, -.12634300E+01, -.72352500E+00, 0.27915500E+00, -.37074000E+00, 0.42771300E+00, 0.34027100E+01, 0.48745900E+00, 0.18656100E+00, -.16936100E+01, -.42640100E+00, 0.41534800E+01, 0.24716800E+01, -.53130100E+00, -.59241300E+01, 0.10851500E+02, -.62745300E+01, 0.30834300E+00, -.46437000E+00, 0.19142200E+00, 0.27011100E+01, -.20401700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23213600E+01, -.83392200E-01, 0.18129900E+01, 0.14169500E+01, 0.76269700E+00, 0.53957300E+00, -.24812200E+01, -.32698300E+01, -.33967500E+00, 0.42272700E+00, 0.10415100E+01, 0.22502300E+01, -.10610100E+00, 0.24247000E+01, 0.21222800E+01, 0.20502800E+01, 0.17545600E+00, 0.27841000E+00, 0.15272100E+01, 0.16519400E+01, -.60345500E-01, -.16600800E+00, -.58895500E+00, 0.41481500E+00, -.22494900E+00, -.11100200E+01, 0.45413000E+00, -.11970000E+01, -.41979400E+00, -.52701200E+00, 0.18237500E+00, 0.18533000E+00, -.16262400E+00, 0.11424400E+00, 0.58989400E+00, -.19660400E+00, -.37552500E+00, -.24709200E-02, 0.45694300E+00, -.23641800E+00, 0.46276400E+00, 0.11983200E+00, -.35103200E+00, -.11083000E+00, 0.82105800E-01, -.20813000E+00, 0.35554300E-01, 0.53133200E+00, -.25959000E+00, -.96678000E+00, 0.23018800E-03, 0.62879100E-02, -.11847500E-01, -.18507100E+00, 0.20460700E+00, -.52240000E-01, -.59977300E-01, -.90164700E-01, 0.10391200E+00, -.70281700E-01, 0.22160500E+00, 0.93625300E+00, -.45874900E+00, -.43566800E-01, 0.76443600E+02, -.24807200E+02, 0.76211200E+01, 0.96416100E+01, -.26870000E+02, 0.20529900E+02, -.26643800E+02, 0.94401500E+01, -.58643700E+02, 0.35803900E+02, 0.17051600E+02, 0.24040900E+02, -.11234000E+02, -.14428600E+02, 0.76436200E+01, 0.22350600E+02, -.27147000E+02, -.12069600E+02, 0.35592800E+01, 0.40963300E+00, 0.13676900E+02, -.29627200E+01, 0.11058000E+02, -.20091100E+01, 0.49365000E+01, -.51922400E+01, -.10833400E+02, -.30969600E+01, -.22741300E+01, 0.36408400E+01, 0.31669000E+01, -.43625000E+01, 0.19916100E+02, -.12382500E+02, -.62148600E+01, -.15154500E+02, -.59846100E+00, 0.72613800E+01, -.62344800E+01, -.15207100E+02, 0.65589900E+02, -.21908600E+02, -.14895000E+02, -.25929700E+02, -.74957800E+01, 0.35273100E+02, 0.63430700E+01, -.27607800E+02, 0.46294100E+01, 0.11348200E+02, -.43770100E+01, -.48918900E+01, 0.11778800E+02, 0.40819600E+01, -.74870800E+01, -.52868500E+01, 0.89564600E-01, 0.14886100E+00, 0.66835800E-01, 0.88978300E-01, 0.14225200E-01, 0.77719600E+00, -.22092500E+00, 0.10286100E+00, 0.12023500E+02, -.65247100E+01, 0.21300300E+02, 0.26741400E+02, -.52466300E+02, -.15767600E+02, -.21114400E+02, 0.24544700E+02, -.10999400E+02, -.12839500E+02, 0.10712600E+02, 0.10322900E+02, -.36671800E+01, -.15467800E+02, -.15015700E+02, 0.99211300E+01, 0.50296100E+01, 0.93519700E+01, -.42606000E+01, -.31252400E+01, -.32380500E+01, 0.56976500E+01, 0.39525200E+01, -.40003000E+01, 0.58140000E+00, -.27827400E+01, -.15917600E+01, 0.16438500E+01, 0.82970200E+01, 0.60263400E-01, 0.85797700E+00, 0.12932100E+01, -.16317600E+01, -.19022900E+01, 0.43418600E+01, 0.33894500E+00, -.41835000E+01, 0.10694500E+02, -.52374600E+01, -.26474900E+00, -.15871800E+01, 0.84950400E+01, -.75601500E+01, 0.43901000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.65157100E-01, 0.36628600E-01, 0.10191800E+01, -.29051700E+00, -.20496300E-02, 0.70264300E-01, -.41020500E+00, -.33005200E-01, 0.24541000E+00, 0.40945000E+00, 0.50255400E-01, 0.28310500E+00, -.43222900E-01, 0.27108500E+00, 0.29733300E+00, -.43418300E+00, -.46334100E-02, -.21661800E-01, -.51492800E-02, -.20351300E+00, -.14469300E+00, 0.54673500E-01, -.41740300E-01, 0.99517000E-02, -.73966500E-02, -.10844800E+00, -.48985100E-01, 0.18660600E+00, 0.12365100E+00, 0.13038700E-01, 0.10849400E-01, -.14908600E+00, -.40962900E-01, -.10240000E+01, -.41864000E-02, -.55454400E-02, 0.36641100E-02, 0.34519900E-02, -.41568300E-02, 0.17455400E-02, 0.17438400E-02, -.26680300E-02, -.58760400E-02, 0.31032300E-03, -.18503800E-01, 0.13128800E-01, 0.14372400E-02, -.78037400E-03, 0.10264200E-01, 0.80720800E-01, -.53753900E-02, -.54144700E-02, 0.32534200E-02, 0.81785600E-02, -.22531400E-01, 0.16203800E-02, 0.14014600E-02, 0.20604400E-02, 0.86610800E-02, 0.15305700E-01, -.20084800E-01, 0.80249500E-02, 0.26031100E+00, 0.88186500E-02, 0.32201000E+01, -.30629300E+01, -.12004900E+01, -.11080500E+01, -.85636500E+00, 0.13684600E+01, 0.66745600E+00, -.11632600E+01, -.14909000E+02, 0.14584500E+01, 0.20708900E+01, 0.14907400E+01, 0.36010100E+01, -.44526500E+01, 0.16431400E+01, 0.15188700E+01, -.33390000E+01, 0.35481300E+01, 0.26364200E+01, 0.22360000E+01, -.12589300E+01, -.12689400E+01, -.17224100E+01, 0.26727800E+01, -.17671000E+01, 0.15534500E+01, 0.46121200E+00, 0.67176200E+00, -.73818000E+00, -.93145000E+00, -.12125800E+01, 0.72605400E+00, 0.11493600E+02, -.66858300E+01, -.45424300E+01, -.25323200E+01, -.14611000E+01, 0.33484900E+01, -.20248200E+01, -.31015700E+01, -.10746500E+01, -.28294600E+01, -.46162300E+01, -.30894500E+01, 0.14863300E+01, 0.61984700E+00, 0.33272500E+01, -.37556100E+01, -.25255200E+01, 0.76058800E+00, 0.15844400E+01, 0.20636400E+01, -.13550000E+01, -.22616600E+01, -.80321600E+00, 0.22245200E+01, -.23077800E-01, 0.15306000E-02, 0.13625300E-01, 0.78333300E-02, 0.58819500E-02, -.97681600E-02, 0.94909800E-01, 0.14613000E-01, -.23521500E+01, -.30551100E-01, -.24352500E+00, -.13853900E+01, 0.23758900E+01, 0.10948100E+01, 0.17558400E+01, -.10000200E+01, -.14186700E+01, 0.18808300E+00, 0.17088800E+01, 0.11612300E+01, -.50026300E+00, -.58598300E-01, -.14168900E+00, 0.15972600E+01, -.78673500E+00, 0.34631800E+00, -.99583000E+00, -.57393300E+00, 0.50927400E+00, -.36926600E+00, 0.42899400E+00, -.78357700E+00, 0.81362300E-01, 0.23701600E+00, 0.11241100E+00, -.10611700E+00, 0.15237300E+01, -.10068600E+00, -.11571200E+00, -.36444100E+00, 0.10459300E+00, 0.34195200E+00, 0.20329100E+01, -.57181300E-01, -.40311800E+00, 0.30046600E+01, -.14091300E+01, -.16838800E+00, 0.11062400E+00, -.43152800E+00, -.37362500E+00, 0.56904100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.93114400E+00, 0.50775400E-01, 0.28169700E+00, -.69801500E+00, 0.11524300E+00, -.28674000E+00, 0.22072200E+00, 0.90629000E+00, -.11290700E+00, 0.26872400E+00, -.10187800E+00, -.58210600E+00, 0.31234000E-02, -.51708300E+00, -.47544400E+00, -.20073100E+00, 0.96485500E-01, -.64556300E-01, -.32256600E+00, 0.62653200E+00, -.93770200E-01, -.28331500E+00, -.68066000E-01, 0.15650200E+00, 0.25051300E-01, 0.43619300E+00, -.68799600E+00, 0.93190200E-01, 0.17350700E+00, 0.75656100E-01, -.12924700E-01, -.21012500E+00, -.31057600E+00, 0.16486100E+00, 0.14934600E+00, 0.45481500E+00, -.56258700E-01, 0.14672500E+00, -.41812700E+00, -.32605600E-02, 0.22939400E+00, 0.10290300E+00, -.47397900E-01, 0.20403100E-01, 0.10256200E+00, -.17906100E+00, -.33047400E-01, 0.55681400E+00, 0.94345400E-01, -.62467200E+00, -.13612800E-01, -.17577900E-01, 0.62719500E-02, 0.96801300E-01, -.43338200E-01, 0.83229700E-02, 0.86332200E-03, 0.18981200E-01, -.11694400E+00, 0.16516700E+00, 0.24386300E-01, 0.13276600E-01, 0.61276600E+00, 0.33324400E+00, 0.48862500E+02, 0.70604700E+01, 0.17685200E+01, -.47744600E+01, -.56901900E+01, 0.56072100E+01, -.16047900E+01, -.30176000E+01, 0.39693000E+02, -.27564600E+02, -.12833900E+02, -.12200300E+02, -.27257500E+00, 0.68016800E+01, -.10171500E+02, -.13040500E+02, 0.68727900E+02, 0.12304800E+02, -.10426800E+02, -.16211500E+02, -.10569600E+00, 0.22480800E+02, 0.97540000E+01, -.11314000E+02, -.46650200E+01, -.43573200E+01, -.49480300E+01, -.29423800E+01, 0.57504200E+01, -.43446500E+01, -.13532300E-01, -.46643000E+01, 0.94626800E+02, -.66510800E+01, 0.80019100E+00, 0.22609800E+01, -.27162000E+02, 0.22128700E+02, -.23754800E+02, 0.46665200E+01, 0.18308200E+02, -.10822800E+02, 0.13671500E+01, 0.56835500E+01, -.56156500E+01, 0.24786900E+01, -.93624700E+01, 0.92782700E+01, -.83569900E+01, 0.50373200E+01, 0.82508200E+01, 0.30598400E+01, -.43095100E+01, 0.17166800E+01, 0.64889400E+01, 0.32701300E+01, -.62418500E-01, -.63185900E-02, 0.59505800E-01, 0.15866300E-01, -.41133800E-01, -.26714500E-01, 0.25870900E-01, 0.25720000E+00, 0.36746800E+02, -.16571200E+02, -.21383700E+02, -.17674300E+02, 0.14125800E+02, 0.15250900E+02, 0.84667600E+00, -.19855100E+02, 0.14612000E+02, 0.36925400E+01, -.97803200E+01, -.84247900E+01, 0.48666500E+01, 0.98449700E+01, 0.64475500E+01, -.10027800E+02, 0.43945200E+01, -.10111500E+02, 0.63785500E+00, 0.20371500E+01, -.18356300E+01, -.10672200E+01, -.34332200E+01, 0.34884700E+01, -.79764700E-01, 0.95996700E+00, 0.51176400E+00, -.49318000E+00, -.19424100E+02, 0.14860600E+00, -.65157500E+00, -.14686400E+00, 0.49026300E+00, -.32508200E+01, -.22811100E+02, 0.10877200E+01, -.15511100E+01, -.20096500E+02, 0.17186600E+01, 0.91735200E+00, 0.44199300E+00, -.23320500E+01, 0.45405700E+01, -.30601900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11258800E+01, 0.17970100E-01, 0.12859800E+00, 0.64277200E+00, 0.69491900E+00, 0.70312200E+00, 0.57798000E-01, -.72383700E+00, 0.60450000E-01, -.18209900E+00, 0.23549400E+00, 0.58960300E+00, 0.84463400E-01, 0.46180900E+00, 0.39610500E+00, 0.94859500E+00, -.73811400E-01, -.54842900E-01, 0.26094300E+00, -.15662900E+01, 0.13876700E+01, -.12923400E+00, 0.11539300E+00, -.62344300E+00, 0.21779400E-01, 0.13157000E+00, 0.56028500E+00, -.98746400E+00, -.34978000E+00, -.31291300E+00, -.10208000E+01, -.50821200E+00, 0.92853000E-01, 0.19309400E+01, -.49701200E+00, -.78543800E-01, 0.40682200E+00, 0.80041300E-01, -.19944400E+00, 0.77871700E+00, 0.31363100E+00, -.27286000E-01, 0.41621900E+00, 0.11297900E-01, 0.15765300E+00, 0.94207900E-01, 0.49737400E-02, -.39299700E+00, -.10598900E+00, 0.83315100E+00, 0.10010900E+00, 0.45163700E-01, 0.13233200E+00, 0.67934200E-01, 0.19726000E-01, 0.40559100E-01, -.11758400E-01, -.13029300E+00, 0.30790700E+00, 0.48782700E+00, -.58179500E+00, -.96667900E-01, -.11576400E+01, 0.53561600E+00, 0.16663200E+03, -.47267700E+02, -.24756000E+02, -.22960200E+02, -.38238400E+02, 0.55651000E+02, -.15992100E+02, -.21620000E+02, -.29122800E+03, -.14853500E+02, 0.56657000E+02, 0.58319300E+02, 0.27544800E+02, -.95945500E+02, 0.33487500E+02, 0.53204800E+02, 0.42130500E+01, 0.47329400E+02, 0.24230900E+02, 0.15577800E+02, -.25151000E+01, 0.43579700E+01, 0.11295100E-01, 0.16089600E+02, 0.47749700E+00, -.86795700E+01, -.12920700E+02, -.42799400E+00, -.10431100E+02, -.46680100E+01, -.10393500E+02, -.17804900E+01, 0.17259200E+03, -.54247100E+02, -.39847800E+02, -.24423800E+02, -.46875200E+02, 0.51567600E+02, -.41399000E+02, -.22192900E+02, 0.46428200E+02, -.96427100E+02, -.49329000E+02, -.39148500E+02, -.13472700E+02, 0.25593400E+02, 0.62305400E+01, -.41219400E+02, -.11741400E+02, 0.13719400E+02, 0.64200700E+01, 0.62631600E+01, 0.49824000E+01, -.70110500E+01, -.59118900E+01, 0.68232200E+01, -.45434100E+00, 0.46075500E+00, 0.17087000E+00, 0.77905400E-01, 0.11066600E+00, -.60319800E-01, 0.48174400E-01, 0.11620100E+00, -.55510800E+02, -.88919200E+01, 0.43376200E+02, 0.46257500E+02, -.54061300E+02, -.40288200E+02, -.23078000E+02, 0.42614500E+02, -.57371100E+02, -.20812900E+01, 0.18995100E+02, 0.19384600E+02, 0.31931300E+01, -.18692300E+02, -.24756500E+00, 0.20053100E+02, 0.81538500E+01, 0.25210300E+01, -.78674000E+01, -.33817500E+01, -.56931700E+01, -.13383200E+01, -.31217100E+01, -.53653700E+01, 0.30208200E+00, -.13799900E+01, -.83835200E+00, 0.92100200E+00, 0.70335800E+01, -.40038500E+00, -.88349900E+00, -.20489200E+01, -.92287300E+00, 0.60205100E+01, -.56392700E+01, -.67930900E-01, -.14202600E+02, 0.21897200E+02, -.16106100E+02, -.26286400E+00, -.85202700E+00, 0.99487000E+01, -.52621500E+01, 0.22571500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.42974800E+01, -.14150400E+01, 0.66273100E-01, 0.88064000E+00, 0.16664200E+00, 0.91594700E-01, 0.14806500E+01, -.39445600E+01, 0.14104700E+01, 0.28720600E+01, 0.10421400E+01, 0.38225600E+01, 0.87388700E+00, 0.11489800E+01, 0.13683300E+01, -.31898400E+01, -.28216500E+00, 0.38793500E+00, 0.28614300E+00, -.11171600E+01, 0.30415000E+01, -.14694100E+01, -.48778000E+00, 0.78714800E+00, 0.27948400E+00, 0.15654700E+01, 0.77024900E-01, 0.66928400E+00, 0.11223500E+01, 0.40746400E+00, -.35402100E+00, -.30427900E+01, -.16309300E+01, -.91909200E+01, 0.91939700E-01, 0.14736900E+01, 0.14524900E+01, -.13876400E+01, -.35245100E-01, 0.79077800E-01, 0.94417100E+00, -.20982500E+00, 0.26373500E+00, 0.36852700E+00, -.91658100E+00, 0.15192600E+01, -.13715300E+00, 0.74646300E+00, 0.44950500E+00, 0.45935800E+01, -.85541000E+00, 0.15822400E+01, 0.63713500E+00, 0.27733700E+00, -.27251500E+01, -.80640600E-01, 0.33403600E+00, -.59579400E-01, 0.85530500E+00, 0.14952000E+01, -.18421100E+01, 0.30931000E+00, -.18977600E+01, 0.17950600E+01, 0.76425400E+00, 0.26062800E+03, -.11499500E+03, -.12381700E+03, 0.56628800E+01, 0.15573300E+02, 0.60827800E+02, -.13773600E+03, -.23363300E+03, 0.17179900E+03, 0.85456100E+02, 0.11316100E+02, 0.63001900E+02, -.88064200E+02, 0.15970500E+02, 0.16468000E+02, 0.31596200E+03, 0.42301700E+02, -.31628300E+02, -.50508300E+02, -.75524600E+02, 0.83446800E+02, -.25188900E+02, -.40666300E+02, 0.39333600E+02, -.54735800E+02, -.11873600E+02, -.70661000E+01, -.20210700E+02, 0.91590800E+01, -.71076100E+00, -.10566500E+02, 0.27074800E+03, -.16595200E+03, -.13310000E+03, 0.10079800E+02, -.86792300E+02, 0.90991800E+02, -.42502300E+02, -.82018800E+01, 0.80235800E+01, 0.28742300E+02, -.68672900E+02, 0.13800400E+02, -.58804900E+02, 0.14839700E+02, -.35053200E+02, -.22100500E+01, -.70240300E+02, 0.25363200E+02, 0.26007200E+02, 0.29302600E+02, -.15190000E+02, -.77718300E+01, -.82452800E+01, 0.36294200E+02, -.11712100E+01, 0.38121500E+00, -.11133500E+00, -.33774200E+00, 0.45470300E+00, -.11709100E+00, 0.43685900E+00, -.28249900E+00, 0.52996100E+02, 0.15395100E+03, -.13687400E+02, -.69906300E+02, 0.70857300E+02, 0.39924200E+02, 0.79384500E+02, -.58077200E+02, -.63287100E+02, 0.11588500E+03, -.95920300E+01, -.70743600E-02, 0.74478700E+01, 0.38260200E+01, 0.43726300E+02, 0.21007200E+01, 0.90012500E+01, -.65612700E+02, 0.76009300E+00, 0.57757000E+01, -.27016800E+01, -.95919300E+01, -.19947300E+02, 0.65161400E+01, -.11536700E+02, 0.26302400E+01, 0.14947700E+01, -.14512400E+01, -.30330000E+02, 0.67212400E+01, 0.18821400E+01, 0.42203000E+01, 0.14472300E+01, 0.26076000E+02, -.14682300E+02, 0.59448500E+01, -.10770400E+02, 0.19288400E+02, -.20070900E+02, 0.43290100E+01, 0.14899700E+01, -.13152400E+02, 0.22949000E+02, -.25949900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.47042300E+01, -.17606400E+01, 0.23611700E+00, 0.82570400E+00, 0.54175100E+00, 0.25372500E+00, 0.14234200E+01, -.24281200E+01, 0.20252400E+01, 0.37078100E+01, 0.93269300E+00, 0.27483400E+01, 0.15207100E+01, -.93255400E+00, -.19523400E+01, -.20867000E+01, 0.54562500E-01, 0.10271500E+01, 0.36635500E-01, 0.88196700E+00, 0.21738600E+01, -.20363300E+01, -.39333000E+00, 0.65762800E+00, 0.73379800E+00, 0.21080500E+01, -.13833100E+01, -.30888800E+01, 0.12741400E+00, -.45306000E+00, -.79812500E+00, -.48885800E+01, -.27992600E+00, -.22732000E+01, -.79216200E+00, 0.19875600E+01, 0.30067400E+01, -.18340900E+01, 0.12296400E+00, 0.44392600E+00, -.38213400E+00, -.10263200E+01, 0.10738100E+01, 0.11745200E+00, 0.33467200E+00, 0.96922300E+00, 0.18328400E+00, 0.31684300E+01, 0.40512600E+00, 0.80113000E+01, 0.95049700E+00, 0.25082600E+00, 0.21433800E+00, -.18217100E+01, -.50984400E+01, 0.50030800E+00, 0.23893400E+00, 0.80978500E-01, 0.85205500E+00, 0.22452300E+01, -.85428100E+00, 0.40576200E+00, -.27428200E+01, 0.31692100E+01, 0.35583100E+01, -.32671700E+00, -.26989800E+03, -.25150800E+03, 0.37843700E+02, -.25565900E+02, 0.10250100E+03, -.29521900E+03, -.92135800E+02, 0.29240000E+03, 0.15956100E+03, 0.18282400E+01, 0.57534400E+02, -.24318200E+02, 0.18695200E+02, 0.51572800E+02, 0.33200100E+02, -.12840600E+03, 0.11759400E+02, -.10451300E+02, -.72211200E+02, -.20812600E+02, -.83745200E+02, 0.56231300E+01, -.69546300E+02, 0.24349000E+02, 0.28984100E+02, 0.11227100E+02, -.15158000E+02, -.39502400E+01, -.11176400E+02, 0.57626000E+01, 0.42013100E+03, -.31010700E+03, -.39323500E+03, -.10327000E+03, -.52993700E+02, 0.11012300E+03, -.71858200E+02, -.19367800E+03, -.19451600E+03, 0.21395600E+03, -.27601800E+03, -.35506000E+02, -.22206200E+02, -.29635300E+02, 0.89723800E+01, -.11775400E+03, -.43346800E+02, 0.41710900E+01, 0.57940500E+02, 0.81066400E+02, -.81135800E+02, -.71763500E+02, -.62411600E+02, 0.94044900E+02, -.20396300E+01, 0.93347000E+00, 0.14354800E+01, 0.53605000E+00, 0.62663500E+00, -.53547600E+00, 0.23049000E+00, 0.78993300E+00, -.35035300E+02, 0.27757700E+03, -.11256200E+03, -.23525200E+03, 0.28438100E+03, 0.19383100E+03, 0.23500000E+03, -.18605700E+03, -.33536200E+02, 0.11831600E+03, 0.41291500E+02, 0.30142900E+02, -.26290600E+02, 0.52596200E+02, 0.11233100E+02, 0.57031800E+02, -.45995900E+02, -.83203400E+02, -.41640400E+02, -.18481100E+02, 0.25743100E+02, -.40287700E+02, -.82863700E+00, -.28779700E+02, -.20529500E+02, 0.13480000E+02, 0.59889200E+01, -.55303200E+01, 0.32604800E+02, 0.68648500E+01, 0.89546500E+00, -.11069600E+02, 0.55354700E+01, 0.74747600E+02, 0.97298700E+02, -.82141300E+01, 0.90893600E+01, 0.16452300E+03, -.71216400E+02, -.99500600E+01, 0.54676800E+01, -.53592300E+02, 0.23727500E+02, 0.17906700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.86557400E+00, -.45637200E-01, -.22306200E+00, 0.13951300E+00, -.61985700E+00, -.25950100E+00, -.24985300E+00, -.48563600E+00, 0.54241000E-01, -.14690800E+00, 0.42841200E-01, 0.31084300E+00, -.38286700E-02, 0.20183000E+00, 0.28533200E+00, -.54961000E-01, -.56369200E-01, 0.73554200E-01, 0.18979100E+00, -.19735700E-01, -.15954900E+00, 0.58123500E-01, -.87160300E-01, -.17819200E-01, -.13424900E-01, -.22741400E+00, 0.41535700E+00, -.51131500E+00, -.27670500E+00, -.13502900E+00, -.81494500E-03, 0.50135900E+00, 0.32377200E+00, 0.13061700E+01, -.23466900E-01, -.14165800E+00, 0.12556800E+00, 0.60914500E-01, 0.26252100E+00, 0.46470100E-01, -.23137100E+00, 0.18939700E-01, -.14364700E+00, -.63343700E-01, 0.20602900E-01, -.87647700E-01, 0.10461800E-01, 0.16854700E+00, 0.14247100E-01, 0.63761500E+00, 0.46145500E-01, -.47049800E-01, -.32869100E-01, -.54629600E-01, 0.14586000E-01, 0.17740900E-01, -.91702200E-03, 0.19339100E-01, 0.79135700E+00, -.26498500E+00, 0.57330900E+00, 0.71273200E-02, -.40296900E+00, -.25755200E+00, -.10119700E+00, -.15259500E+00, 0.14467400E+00, 0.11203300E+02, 0.14099200E+01, -.51672500E+01, -.23086800E+02, 0.13683700E+02, -.48157600E+02, -.24305200E+02, -.39266700E+01, 0.86025100E+01, 0.16219800E+01, -.18938800E+02, 0.27867900E+01, 0.37191800E+01, 0.27792500E+02, 0.55447500E+00, -.18267500E+02, -.65564800E+01, 0.36501200E+00, 0.77785500E+01, 0.66066100E+01, -.69527500E+01, 0.97129800E+01, -.29282900E+01, -.59835300E+01, -.29694400E+01, 0.12548000E+01, 0.12205000E+00, 0.15607700E+01, -.32508200E+01, -.63428400E+02, 0.32659800E+02, 0.32207200E+02, 0.12918300E+02, 0.11986500E+02, -.18379700E+02, 0.82924000E+01, 0.19790000E+02, -.89748500E+01, -.25487700E+02, 0.22501300E+02, 0.85894500E+01, 0.65256600E+01, -.71053700E+01, -.53433000E+01, 0.15933500E+02, -.38131800E+01, 0.20811800E+00, -.33172500E+01, -.31569600E+01, 0.44978700E+01, 0.50770600E+01, 0.19879900E+01, -.36000100E+01, 0.19585800E+00, -.12854100E+00, -.48376400E+00, -.51838200E-01, -.41394000E-01, 0.76242900E-01, -.10884300E-01, -.80753200E-01, -.51017900E+01, -.27223500E+02, 0.88383500E+01, 0.23303300E+02, -.21894200E+02, -.25309300E+02, -.25303200E+02, 0.18302000E+02, 0.11722600E-02, -.69332100E+01, -.10436000E+02, -.75693100E+01, 0.96119900E+01, -.21373700E+01, 0.42240800E+01, -.10821100E+02, 0.33357100E+01, 0.43220400E+01, 0.54273300E+01, 0.33039300E+01, -.39254700E+01, 0.11493500E+01, -.33070600E+01, 0.45461700E+01, 0.21196200E+01, -.98330100E+00, -.62741800E+00, 0.54513600E+00, -.52611900E+01, -.49011700E+00, -.12796200E+00, -.71486100E+00, -.55064900E+00, 0.46691700E+01, -.13970100E+02, -.14799300E+01, -.31343200E+01, -.17014200E+02, 0.61142100E+01, 0.98604200E+00, -.58790700E+00, 0.51896100E+01, 0.21768600E+01, -.30173200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20617500E+01, 0.15457700E+00, 0.83711100E+00, -.28618500E+00, 0.12289600E+01, 0.57722600E+00, 0.46098500E+00, 0.99774200E+00, 0.33489100E+00, 0.16893100E+01, -.15723200E+00, -.36831300E+00, 0.30813600E+00, -.28770200E+00, -.40624100E+00, 0.77030600E+00, -.88208400E-02, -.31757700E+00, -.13864000E+00, -.54102400E+00, 0.19335800E+01, -.62778800E+00, -.68905400E+00, -.17650400E+00, -.10480400E+00, 0.23023200E+00, -.64139000E+00, 0.99033400E-01, -.71620100E-03, -.21981400E+00, -.31882300E+00, 0.17721300E+00, -.46273900E-01, -.24254400E+01, -.27362500E+00, -.12247700E+01, -.94429500E+00, -.30095300E+00, 0.10011100E+01, 0.11055400E+01, -.15143700E+01, 0.48847600E+00, -.23892300E+00, -.54094100E-01, -.26572700E+00, 0.33517300E+00, -.27816700E-01, 0.87583400E+00, -.22883900E+00, -.26223300E+01, -.44618100E+00, 0.49074000E+00, -.19455700E+00, -.41773000E+00, -.10525100E+01, -.69456800E-01, 0.45863200E-01, 0.13912200E+00, -.25059500E+00, -.11997300E+00, 0.52677800E-01, 0.13552500E+00, 0.26246300E+01, -.26917000E+00, -.89022500E+00, 0.83456100E-01, 0.20038000E+00, -.75014300E+00, 0.29963900E+02, 0.46269200E+01, 0.10673500E+02, 0.10256000E+02, -.35102900E+02, -.16711700E+03, -.17479200E+02, 0.10203200E+02, -.11533600E+02, -.24419800E+02, -.88589400E+01, -.32113600E+01, 0.33462000E+02, 0.45951500E+02, -.20793600E+02, -.32937100E+01, 0.10352600E+02, 0.10466500E+02, 0.26969800E+02, -.22634300E+01, 0.15774700E+02, -.24958300E+02, -.34020500E+01, -.45704500E+01, 0.14303700E+02, -.11107200E+00, 0.80345900E+01, -.57102400E+01, -.14122400E+03, 0.14392800E+03, 0.10018400E+03, 0.56232200E+02, -.10090200E+01, -.44359400E+02, 0.13874400E+02, 0.82845400E+02, -.72654700E+02, -.88172000E+02, 0.70314800E+02, 0.49071600E+02, 0.22342100E+02, -.39260000E+02, -.25883200E+02, 0.72676100E+02, 0.22464500E+02, -.64074100E+01, -.12876200E+01, -.16998600E+02, 0.74141300E+01, 0.24889000E+02, 0.21710100E+02, -.19676900E+02, 0.64243100E+00, -.13063400E+00, -.61860600E+00, -.33234700E+00, -.15328600E+00, 0.22746500E+00, 0.30442400E-01, -.41720900E+00, -.54347900E+02, -.11354000E+03, 0.35125300E+02, 0.78987500E+02, -.75362500E+02, -.84177800E+02, -.75452800E+02, 0.56752900E+02, -.12755100E+02, -.31159600E+02, -.30805600E+02, -.20274100E+02, 0.23541200E+02, -.87376400E+01, 0.22275100E+02, -.33675000E+02, 0.11924200E+02, 0.19483700E+01, 0.23241100E+02, 0.16912100E+02, -.15333700E+02, 0.19953800E+01, -.15865100E+02, 0.22842900E+02, 0.56098300E+01, -.17531200E+01, -.19080300E-01, -.17359500E+00, -.26260200E+02, -.31535700E+01, -.36714000E+01, 0.13007900E+01, 0.16650800E+00, 0.46239300E+00, -.55812600E+02, 0.18036500E+01, -.16840300E+01, -.65313500E+02, 0.18290100E+02, 0.21755900E+01, 0.97146200E-02, 0.18673000E+02, 0.79187800E+01, -.10630000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10609200E+01, -.42918100E-01, -.12131900E+00, 0.19988000E+00, -.50395500E+00, -.22826800E+00, -.37771200E+00, -.12700300E+01, 0.11978800E+00, -.40606300E-01, 0.12158100E+00, 0.11261200E+01, 0.11328500E-01, 0.45835300E+00, 0.11411500E+01, -.67187700E+00, -.14788400E+00, 0.46847300E-01, 0.31085300E+00, 0.16849100E+00, -.13510700E+01, 0.31009300E+00, -.20644900E+00, 0.18975000E-01, -.16578800E+00, -.95060200E+00, 0.79269700E+00, -.32378400E+00, -.32658600E+00, -.19855400E+00, -.88686300E-03, 0.10660300E+01, 0.12786900E+00, 0.78786300E+00, 0.18561500E+00, -.40593200E+00, -.31814300E+00, 0.19826100E+00, 0.51711500E+00, 0.11040700E+00, -.47897200E+00, 0.24705400E+00, -.66280100E-01, 0.55814500E-01, 0.57102800E-01, -.52014600E-01, -.13612700E-01, 0.26495100E+00, 0.86749500E-02, 0.25489500E+00, -.47225100E-02, -.14522500E+00, 0.34393500E-01, -.10375800E+00, 0.16950900E+00, 0.45377800E-02, 0.76263700E-01, 0.71628700E-01, 0.13501800E+00, -.38533500E+00, -.10994500E+00, 0.12137100E+00, 0.51102700E+00, -.36122400E+00, -.68753700E+00, -.92632800E-01, 0.15282800E+00, 0.54659600E+00, 0.60844300E-01, 0.29004300E+02, 0.17958700E+02, 0.35743100E+01, -.15244200E+03, 0.92545500E+01, 0.11862800E+02, 0.24580200E+02, 0.19926100E+02, -.44348800E+02, 0.14648300E+02, 0.14563700E+02, 0.17534600E+01, 0.52245800E+02, 0.98938900E+01, 0.10386300E+02, 0.42678000E+01, 0.14585800E+02, 0.95317000E+01, 0.89031800E+01, 0.17795800E+02, -.77888800E+01, -.65787700E+01, -.61323800E+01, 0.54224500E+00, 0.99143700E+01, 0.50406100E+01, -.45040500E+01, 0.16325700E+03, -.66210200E+02, -.67718600E+01, -.25254700E+02, -.29341700E+02, 0.53975900E+02, -.23678200E+02, -.11038000E+02, 0.44836000E+02, -.55550400E+02, -.75727600E+01, -.20007700E+02, -.52969200E+01, 0.11103100E+02, 0.13569200E+01, -.12679500E+02, -.14943300E+02, 0.92932000E+00, 0.26612500E+01, 0.92672200E+00, 0.61091900E+01, -.38434500E+01, 0.52604100E+01, -.10235800E+01, -.27322600E+00, 0.15615800E-01, 0.10387300E+00, -.47411200E-01, 0.18514500E-01, -.69643000E-01, -.39320000E-01, -.74556600E-01, -.41719300E+02, -.54550900E+02, 0.34207300E+02, 0.38141300E+02, -.39682100E+02, -.38837800E+02, -.21891600E+02, 0.31114400E+02, -.23375600E+02, 0.28298100E+01, 0.23572400E+02, 0.15495200E+02, -.97285100E+01, -.18396500E+02, -.10944000E+01, 0.14715800E+02, 0.37239100E+01, 0.98833400E+01, -.12310500E+01, -.46745400E+00, 0.46326600E+00, 0.36992500E+01, -.30083300E+00, -.13014100E+01, 0.76461600E+00, -.16612400E+01, -.36963600E+00, 0.38182100E+00, -.35867700E+01, -.99200000E+00, -.20555300E+01, 0.44739300E+00, -.38189100E+00, -.24252800E+00, -.83449000E+01, 0.19221100E+01, -.44335100E+01, -.48161100E+01, -.22756900E+01, 0.13027100E+01, -.42826800E+00, 0.86768400E+01, -.11645500E+02, 0.40973800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10178200E+01, -.55831800E-01, -.31897200E+00, 0.14779800E+00, -.64371800E+00, -.27813400E+00, -.24742600E+00, -.59163300E+00, 0.48640200E-01, -.29029100E+00, 0.49364900E-01, 0.38105500E+00, -.64601700E-01, 0.26829800E+00, 0.47989800E+00, -.21766700E+00, -.53529200E-01, 0.75323200E-01, 0.14751800E+00, 0.83350800E-01, -.71747800E+00, 0.19647100E+00, -.36963600E-01, -.16710000E-02, -.49115300E-01, -.30766100E+00, 0.49987700E+00, -.61851900E+00, -.25863300E+00, -.20639200E+00, -.11408800E-01, 0.74904200E+00, 0.44929100E+00, 0.20064200E+01, -.19852200E+00, 0.69458500E-02, 0.26646300E+00, -.87741900E-01, 0.39828200E+00, 0.78934800E-01, -.47766700E+00, 0.96671900E-01, -.37657400E+00, -.13813700E+00, 0.76521600E-01, -.25058300E+00, 0.79954700E-02, -.15824000E+00, 0.36144600E-01, 0.89323700E+00, 0.61400200E-01, -.25830100E-01, -.54279500E-01, -.15609900E+00, -.20612400E-01, 0.15764100E-02, 0.57522900E-01, 0.16065900E-01, 0.14298000E+00, -.15984300E+00, -.49099500E-01, 0.60103100E-01, -.35880200E+00, -.16656000E+00, -.55367600E+00, -.82520900E-01, 0.41901200E-01, 0.79716200E-01, -.33166000E+00, 0.49601900E+00, 0.94719100E+01, 0.19478900E+01, -.38300700E+02, -.44060400E+02, 0.10163200E+02, 0.95318700E+01, -.29567100E+01, -.16373900E+02, 0.52586400E+01, 0.49133500E+01, 0.18350300E+01, 0.19626300E+02, 0.81822500E+01, 0.85072800E+01, -.27659000E+00, -.43180800E+01, -.43460000E+00, 0.61832000E+01, 0.15152300E+02, -.13334200E+02, -.79807800E+00, 0.12092900E+00, -.51724800E+01, 0.12880400E+01, -.61631700E+00, 0.44578200E+00, -.33513200E+02, 0.25491000E+02, 0.15998000E+02, 0.21567100E+02, -.13989300E+02, -.10932200E+02, -.27671900E+01, 0.29315900E+02, 0.82387600E+01, -.47751100E+02, 0.52363200E+01, 0.35099800E+01, -.93218400E+01, 0.41204400E+01, -.55849400E+01, 0.95279000E+01, 0.49079800E+01, 0.31891500E+01, -.23798900E+00, -.63904700E+01, 0.72368500E+01, 0.85190500E+01, 0.31220700E+01, -.70013000E+01, -.51839700E-01, 0.10516700E+00, -.41809600E+00, -.77185800E-01, 0.32608800E-01, 0.15502200E-01, 0.22493900E-03, -.82323000E-01, -.17363400E+02, -.34339200E+01, 0.24566000E+02, 0.35894900E+02, -.38674600E+02, -.30492500E+02, -.25229700E+02, 0.29349600E+02, -.19511100E+02, -.76620000E+01, -.50678800E+01, 0.14457800E+00, 0.77147600E+01, -.62191300E+01, 0.48275500E+01, -.37307800E+01, 0.89392300E+01, -.70937000E-01, 0.11600000E+01, 0.11474100E+01, -.57010000E+01, 0.17755800E+01, -.39763200E+01, 0.26071100E+01, 0.26502400E+00, -.16145400E+01, -.82771300E+00, 0.76672800E+00, -.26971700E+01, 0.56326700E+00, 0.21639200E+00, 0.97621400E+00, -.77068000E+00, -.16587300E+00, -.12675000E+02, 0.88394500E+00, -.16820000E+01, -.67122400E+01, -.14245200E+00, 0.11841400E+01, -.72156900E+00, 0.73514900E+01, 0.78765700E+00, -.15962300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14623400E+01, -.13397100E+00, -.52087100E+00, 0.20755800E+00, -.58769000E+00, -.27952100E+00, 0.13416700E+00, -.11852600E+01, 0.34428000E+00, -.12952800E+01, 0.20324800E-01, 0.82978400E+00, -.22487400E+00, 0.25703800E-01, 0.73578500E+00, -.21845100E+01, -.21772900E+00, 0.33953900E+00, -.16550300E+00, 0.60942800E+00, -.24207500E+01, 0.10137800E+00, 0.21048300E-01, 0.18057800E+00, -.48914600E-01, -.78232400E+00, 0.70282800E+00, -.85171800E+00, -.22501200E+00, -.26968100E+00, -.12182500E+00, 0.82099600E+00, 0.98472400E-01, 0.27870500E+01, 0.44860500E+00, -.59340600E-01, -.36052800E+00, 0.56162500E+00, -.16809100E+00, -.14370900E+00, 0.39357600E+00, 0.10878500E+00, -.18742400E+00, -.11534900E+00, 0.15651000E+00, -.34872800E+00, -.26024800E-01, 0.77212400E+00, 0.28402500E-01, 0.16016400E+01, 0.19199400E+00, -.58392200E+00, 0.32604600E-01, 0.36237000E+00, -.45363400E+00, 0.69531400E-01, -.60355400E-01, 0.20455600E-01, -.55916900E+00, 0.90068100E-01, 0.89779300E+00, 0.72012200E-01, 0.48178600E+00, 0.25059000E+00, 0.33036000E+00, 0.54862800E-01, -.10766700E+00, 0.51873700E+00, -.36815800E+00, -.87475300E+00, -.37651800E+00, 0.34252600E+01, -.25013700E+03, -.65579700E+02, 0.36933400E+02, 0.31871500E+02, 0.50412500E+02, -.84780200E+02, 0.14271200E+02, 0.28574700E+02, 0.49698600E+01, 0.10850900E+03, 0.40850900E+01, 0.56938400E+01, 0.40000600E+01, 0.15650100E+02, 0.18688700E+02, 0.17174800E+02, -.12525900E+02, -.14857100E+02, -.90097000E+01, -.51120400E+01, 0.90174500E+01, 0.14979900E+00, -.31105100E+01, -.74124700E+01, 0.14914600E+03, -.12569700E+02, -.33125300E+02, -.20854500E+02, -.24657900E+02, 0.39954800E+02, -.30754500E+02, -.19292600E+02, -.18680900E+03, -.39124600E+02, 0.18577100E+02, 0.31079200E+02, 0.27308900E+02, -.70432100E+02, -.10357200E+02, 0.30016300E+02, -.35228600E+02, -.56192600E+01, 0.27600400E+02, 0.30358700E+02, -.21332800E+02, -.28090800E+02, -.10069900E+01, 0.31773000E+02, -.13398300E+00, 0.14401000E+00, 0.14464700E+00, -.12536600E+00, 0.11361100E+00, -.87595100E-02, 0.36221700E-01, -.18772800E+00, -.90669100E+02, -.75039800E+02, -.17173200E+02, -.15415900E+02, 0.42477300E+02, -.85023900E+01, 0.20662700E+02, -.20393200E+02, -.23573100E+02, 0.20297700E+02, -.36265000E+02, -.15550200E+02, 0.23594400E+02, 0.13401900E+02, 0.39479800E+02, -.17646300E+02, -.77338400E+01, -.20613400E+02, 0.27098800E+02, 0.16036800E+02, -.11354900E+02, -.16155500E+02, -.21740300E+02, 0.16507000E+02, -.90649000E+00, 0.41427100E+01, 0.24482600E+01, -.24442000E+01, -.17308500E+02, -.31643000E+01, -.62064900E+01, -.74695400E+01, 0.24502200E+01, 0.14774500E+01, -.22621200E+02, -.11282700E+01, -.12484600E+02, -.13301400E+02, 0.10939800E+01, 0.18745800E+00, 0.23367300E+01, -.20316300E+01, 0.23328700E+02, -.81383600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.66967100E+00, 0.24385000E-01, 0.14530500E+01, 0.50454000E+00, -.19267900E+00, 0.21740000E+00, -.10893300E+01, -.47021000E+00, 0.34682300E-01, -.98153700E-01, 0.35461200E+00, 0.28586100E+00, -.10968900E+00, 0.70340100E+00, 0.45327100E+00, 0.68757700E+00, 0.21705600E-01, 0.23204500E-01, 0.57770900E+00, 0.73354100E+00, 0.34644000E+00, -.17601400E-01, -.12871900E+00, 0.33341200E+00, -.18648700E-01, -.39149100E+00, 0.42344100E+00, -.54326400E+00, -.11223200E+00, 0.67095900E-01, 0.25151700E+00, -.37212800E-01, 0.42171800E+00, 0.26918000E+00, 0.26380500E+00, 0.20719800E+00, 0.78769100E+00, 0.63687500E-01, 0.26957000E-01, -.17449600E-01, -.27809400E+00, -.26510400E+00, -.29311800E+00, -.43863900E-02, -.13808300E+00, -.10076500E+00, 0.41659400E-01, -.80374700E-02, -.16238000E-01, -.44392700E+00, -.16903400E+00, 0.12164800E+00, 0.17123600E+00, 0.22118700E+00, 0.88850300E+00, -.44840100E-01, -.98424200E-01, -.99978300E-01, -.48598300E-01, -.33719800E+00, 0.36651000E+00, -.16555300E+00, -.12091300E+01, -.41038400E+00, -.31067900E-01, -.51044300E-01, -.15630400E+00, 0.47205300E+00, -.36974600E+00, -.23891900E+00, 0.28808500E+00, -.25261000E+00, -.16913400E+03, 0.37628400E+02, 0.24597500E+02, 0.28177400E+02, 0.25454000E+02, -.54828100E+02, 0.10900200E+02, 0.25767200E+02, -.27466500E+02, 0.22794100E+02, 0.83301400E+01, 0.11263400E+02, -.23157100E+01, -.87844700E+01, -.61294900E+01, 0.12080000E+02, -.90425000E+00, 0.16201400E+01, -.11438600E+01, -.22601100E+01, 0.30182400E+00, 0.38724000E+01, 0.20156400E+01, -.72250200E+00, 0.79315800E+02, -.56087200E+02, -.22318900E+02, -.22067200E+02, -.35104000E+01, 0.26592700E+02, -.47679600E+01, -.20870800E+02, -.65200500E+02, 0.15328700E+02, -.82351400E+00, 0.11103900E+01, 0.17545000E+02, -.16804500E+02, 0.97330000E+01, 0.18592000E+00, -.76419500E+01, -.10290000E+02, 0.99598900E+01, 0.10831400E+02, -.35838100E+01, -.10531900E+02, -.62762200E+01, 0.11314300E+02, -.18496100E-01, -.15994900E-01, 0.33346200E+00, 0.37008800E-01, -.12288600E-01, 0.20594400E-01, -.18863600E-01, 0.28635800E-01, -.67990000E+02, -.48487500E+01, 0.29701200E+01, 0.37545200E+01, 0.70656200E+01, -.13862500E+02, 0.10048500E+02, 0.30146900E+01, -.15010300E+02, -.53865400E+01, 0.40778800E+01, 0.58928000E+01, 0.24190600E+01, -.64814100E+00, 0.30913100E+01, 0.81517800E+01, -.35255100E+01, 0.77404000E+01, 0.15639300E+01, 0.32635100E+00, -.18939400E+00, -.44722600E+01, -.11599400E+01, -.40900400E+00, 0.15753900E+00, 0.75461300E+00, 0.20421900E+00, -.16567500E+00, 0.17842500E+01, -.78753900E+00, -.14295900E+01, -.32914700E+01, 0.17056200E+00, -.92578900E-01, 0.18572200E+01, -.17440900E+01, -.16163000E+01, 0.57363500E+01, -.20781400E-01, 0.51957000E+00, 0.15683200E+00, 0.77694300E+00, 0.44547700E+00, -.15221100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.21931300E+01, -.10699700E+00, -.76964600E-01, 0.19956700E+01, 0.36863200E+00, 0.10531800E+01, -.72345700E+00, -.14406800E+01, 0.53853000E+00, -.25340700E+00, -.86680700E-01, 0.97665500E+00, -.80566300E-02, 0.64831700E+00, 0.71283300E+00, -.17463700E+01, -.22745600E+00, 0.45933400E+00, 0.84642500E+00, -.32492300E+01, 0.41156200E+01, -.23455600E+00, -.13933400E+00, -.73767300E+00, 0.38363000E+00, 0.17728500E+01, -.18396800E-01, 0.10737400E+00, -.44088800E+00, 0.33523800E+00, 0.16540500E+00, -.61046900E+00, -.68328800E-01, -.35437100E+01, 0.22151300E+00, -.32595300E+00, 0.20867600E+00, 0.41614900E+00, -.49284800E+00, 0.50978900E-01, 0.16428500E+01, -.14589000E+00, 0.91544100E+00, 0.24245100E+00, -.31952300E+00, 0.94881900E+00, -.83585100E-01, 0.94292100E+00, 0.99951100E-01, 0.29595500E+00, -.88576000E-01, 0.57431400E-01, -.79189900E-01, -.73182300E-01, -.39904700E+00, 0.95329400E-02, 0.22253100E-01, 0.98501600E-01, -.27155200E+00, -.32043400E+00, 0.53395800E+00, 0.90314700E-01, 0.83196800E+00, -.26273500E+00, -.79220800E+00, -.10651500E+00, 0.13491100E+00, 0.49453300E+00, -.32989300E-01, -.21491300E+00, 0.44852400E+00, -.59915500E+00, 0.12511800E+01, -.10042700E+03, -.43366300E+01, -.74561800E+01, 0.49525600E+01, -.63604500E+01, -.39512300E+01, -.10886300E+02, 0.61640900E+02, 0.61593800E+02, -.11443700E+02, -.10093700E+02, 0.26834200E+01, 0.26561200E+02, 0.21593900E+02, -.26942200E+01, -.62064700E+01, -.10688900E+02, -.71633700E+01, -.38592000E+01, 0.84534400E+01, -.48530700E+01, -.26905500E+01, -.82100100E+01, 0.11062300E+03, 0.26947800E+02, 0.39494200E+01, 0.55770600E+01, -.35040300E+02, 0.27960400E+02, -.32943300E+02, 0.12941400E+02, -.30491500E+02, -.81262400E+02, 0.15650100E+02, 0.19469800E+02, -.63803100E+01, -.23369200E+02, -.22976400E+02, 0.22286500E+02, -.19361400E+02, 0.63028900E+01, 0.89710300E+01, 0.67277900E+01, -.84991000E+01, -.25092200E+01, 0.11583200E+02, 0.67388500E+01, -.14771800E+00, 0.81324000E-01, 0.47434100E-01, -.13856500E+00, 0.46515700E-01, -.37708800E-01, 0.61277800E-01, -.18035200E+00, 0.25423800E+02, -.84824900E+02, -.54202200E+01, -.71127800E+00, 0.31496300E+01, -.47505800E+01, -.16266500E+02, -.67801100E+01, -.12190400E+02, 0.18900500E+02, -.22160300E+02, -.11403300E+02, 0.12256000E+02, -.24451600E+00, 0.21733500E+02, -.16416800E+02, 0.34061800E+01, -.20964300E+02, 0.17876500E+02, 0.10519900E+02, -.80362800E+01, -.39033900E+01, -.14364700E+02, 0.11307200E+02, -.71195700E+00, 0.17396500E+01, 0.14278900E+01, -.14376600E+01, -.25792000E+02, -.15754100E+01, -.33219900E+01, -.18987700E+01, 0.14391800E+01, 0.12916200E+01, -.35902900E+02, 0.10855300E+01, -.80249600E+01, -.30586800E+02, 0.10625500E+01, 0.57867200E+00, 0.12869700E+01, 0.18296300E+01, 0.11642500E+02, -.50878000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11368700E+01, -.61044100E-01, -.74760600E-01, 0.83470000E+00, 0.52752400E-01, 0.39270800E+00, -.29832300E+00, -.73142100E+00, 0.27814900E+00, -.20488500E+00, 0.42884000E-03, 0.53215800E+00, -.31248500E-01, 0.32734800E+00, 0.48900400E+00, -.88943500E+00, -.14609200E+00, 0.18066200E+00, 0.18048400E+00, -.73344500E+00, 0.33712800E+00, 0.22733600E-02, -.11672300E+00, -.11556700E+00, 0.43330200E-01, 0.16926800E+00, 0.63419600E+00, -.56430000E+00, -.30497700E+00, -.99833100E-01, -.28489800E-01, 0.59529100E+00, 0.50433800E+00, 0.15722600E+01, -.13407100E+00, -.14497000E+00, 0.47623300E+00, 0.27564600E-01, 0.21631700E+00, 0.12366500E+00, -.21947700E+00, -.72857600E-01, -.13840900E+00, -.47741100E-01, -.11744600E+00, 0.50590400E-01, -.12707700E-01, 0.40023800E+00, 0.71631200E-01, 0.90357600E+00, 0.41028400E-02, 0.11417000E-01, 0.52945800E-02, -.64373100E-01, 0.13410900E+00, 0.13561400E-01, -.19546400E-01, -.54445300E-02, -.13158600E-01, 0.79822900E+00, 0.52829600E+00, -.33769100E-01, -.12975500E+01, -.12572500E+00, 0.96302600E-01, -.45088800E-01, -.59695800E-01, -.39204600E+00, -.15924500E+00, -.71566300E+00, 0.62374800E+00, -.20057600E-02, -.30371200E+00, -.31619800E+00, -.14587500E+02, -.21060700E+00, -.63116300E+01, -.15676800E+01, -.25713700E+01, -.83325400E+01, 0.63805500E+02, 0.30774000E+02, -.19203900E+02, -.12243100E+02, 0.58465600E+01, 0.26114700E+02, 0.12982100E+02, -.14417200E+02, 0.10968700E+02, 0.46422600E+01, -.86558900E+01, -.98552000E+01, 0.54302600E+01, 0.56093200E+01, 0.66170800E+01, -.96652200E+01, 0.23610300E+03, -.91107500E+02, -.90891800E+01, -.38926300E+02, -.32010500E+02, 0.66937000E+02, -.40886700E+02, -.24383000E+02, 0.43602900E+02, -.30306800E+02, -.39739700E+01, -.20406400E+02, -.64084600E+01, 0.71371700E+01, -.99483000E+01, -.11303500E+02, -.12975500E+02, -.18371600E+01, 0.88213900E+01, 0.73641600E+00, 0.45485000E+01, 0.14451800E+01, 0.49592600E+01, -.15142700E+00, -.33393900E+00, -.11533300E+00, 0.35930500E+00, -.11142900E+00, -.29968800E-01, -.12590900E+00, -.81135600E-01, 0.13570400E+00, 0.61358900E+01, -.57435300E+02, 0.32467200E+01, 0.18750400E+02, -.23292400E+02, -.16078000E+02, -.27756200E+02, 0.10376600E+02, 0.11068700E+02, -.44841800E+01, 0.15505700E+02, 0.73981200E+01, -.63164900E+01, 0.86041600E+00, -.39302800E+01, 0.63374500E+01, 0.26485500E+01, 0.11357600E+02, -.39876600E+01, -.44886500E+01, 0.17009600E+01, 0.29064500E+00, 0.30050400E+00, -.55737600E+01, 0.20618000E+00, -.13181000E+01, -.93121700E+00, 0.98161400E+00, -.19805400E+02, 0.21916900E+00, -.84338500E+00, -.63826700E+00, -.97843100E+00, 0.13523700E+00, -.28159700E+02, -.69241800E+00, -.29531400E+01, -.23065100E+02, 0.15253900E+01, 0.25544300E+01, -.10518900E+01, 0.58028500E+01, -.97706500E+01, 0.15719100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23848300E+01, -.87488900E+00, 0.31632400E+00, 0.20954500E-02, 0.63446300E+00, 0.21256300E+00, 0.27871000E+00, 0.34252900E+00, 0.13355200E+01, 0.20350200E+00, 0.37820100E-01, -.21150800E+00, 0.14897500E+00, -.28625700E+00, -.16116000E+01, -.17032100E+01, -.89387500E-01, 0.43944500E+00, -.43527800E+00, 0.10758700E+01, 0.65786100E+00, -.85528800E+00, -.86169300E+00, 0.22529700E+00, 0.15823200E+00, 0.15323300E+01, -.76243100E+00, -.28760900E+01, -.78011500E+00, 0.21653800E+00, 0.38199000E+00, -.18742300E+01, 0.37913400E+00, -.14593700E+01, -.15677700E+00, 0.28882600E+01, 0.22699900E+01, -.10193500E+01, -.59825900E+00, -.61028300E+00, 0.10024000E+01, -.18110700E+00, -.82799500E-01, 0.27818700E+00, -.37478700E-01, 0.45917300E+00, -.18308000E+00, -.20969800E+01, 0.58870000E+00, 0.44441200E+01, 0.40382000E+00, 0.54476400E-01, -.24482900E+00, -.48099900E+00, -.17541500E+01, 0.68829200E-01, 0.26165500E-01, 0.31471000E+00, -.65179800E-01, -.28332200E+00, 0.61273600E+00, 0.15892400E+00, 0.15064100E+01, -.16277900E+00, -.86036300E-01, -.25912200E+00, 0.30951700E+00, 0.56501900E+00, -.17628900E+00, 0.10452100E+01, -.19738100E-01, -.58006900E+00, -.80806500E+00, -.54557100E+00, 0.97997300E+00, -.43592100E+02, 0.71059900E+02, 0.23036100E+02, 0.91546900E+01, -.49441200E+02, 0.46495000E+02, -.11137500E+02, -.11387800E+00, -.93344100E+01, -.74915800E+01, 0.34242000E+02, -.87790400E+01, -.27480000E+00, -.26596700E+02, -.32633000E+02, -.41970100E+00, 0.24006700E+01, 0.74483800E+01, -.38286400E+01, -.42020100E+01, -.25919500E+01, -.28517600E+03, 0.29551400E+03, -.12505000E+02, 0.54494300E+02, 0.23011100E+02, -.10033200E+03, 0.23039100E+02, 0.47860300E+02, -.23370700E+03, 0.35919800E+02, 0.65607200E+01, 0.46496800E+02, 0.34684700E+02, -.78393900E+02, 0.50290400E+01, 0.29133400E+02, -.26439800E+02, 0.47037800E+02, 0.14117300E+02, 0.25196000E+02, -.33767500E+02, -.33031600E+02, 0.26468200E+01, 0.21651100E+02, 0.35251500E+00, 0.23732900E+00, 0.42603200E-01, -.18311300E-01, 0.18927500E+00, 0.15565500E+00, 0.20563000E+00, -.29177400E+00, 0.55155200E+02, 0.17021300E+02, -.63909900E+02, -.80502800E+02, 0.10681700E+03, 0.88858500E+02, 0.54804700E+02, -.70426900E+02, -.14971500E+00, 0.58061400E+02, -.81713600E+02, -.53637100E+02, 0.43844800E+02, 0.38096600E+02, 0.55497800E+02, -.56224200E+02, -.25593700E+02, -.65576400E+02, 0.33867900E+02, 0.27070800E+02, -.96819700E+01, -.22586900E+02, -.23854200E+02, 0.28925600E+02, 0.38597600E-01, 0.84308800E+01, 0.52244800E+01, -.52331000E+01, 0.13540200E+01, -.34444000E+01, -.50697000E+01, -.62213700E+01, 0.52389500E+01, 0.21114300E+01, 0.33001200E+02, -.39157400E+01, -.63042900E+01, 0.18538500E+01, -.45906100E+01, -.54329400E+01, 0.52875800E+01, -.22619300E+02, 0.51316500E+02, -.11638800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19792400E+01, -.34992900E-01, 0.42166000E+01, 0.88450800E+00, 0.35093400E+00, 0.67045200E+00, -.14566200E+01, -.20786200E+01, -.10900400E+00, 0.17041200E+00, 0.64990200E+00, 0.13300600E+01, -.37545700E+00, 0.21901700E+01, 0.15514700E+01, 0.28936200E-01, 0.17926500E+00, 0.29166700E+00, 0.50267500E+00, 0.15103600E+01, -.11070900E+01, 0.19071600E+00, 0.18236200E-01, 0.53687000E+00, -.12641400E+00, -.40169100E+00, 0.21526800E+00, -.11674900E+01, 0.20041900E+00, -.49443700E-01, -.23504800E+00, 0.20559900E+00, 0.15164000E+00, 0.30135200E+01, -.50312400E+00, 0.53990100E+00, 0.15316200E+00, -.56132900E+00, -.59373500E-01, 0.33877700E+00, -.59764500E+00, 0.46713700E+00, -.91249500E+00, -.32799800E+00, 0.66215400E-01, -.42154600E+00, -.13290800E+00, -.61358900E+00, -.38120200E+00, 0.55229000E+00, -.36875600E+00, 0.50866000E+00, 0.18888400E+00, -.17244900E+00, -.91315200E+00, -.16184000E+00, 0.12794300E+00, -.21430700E-01, 0.39482200E+00, 0.50448700E+00, -.92689600E+00, 0.11573500E+00, -.15185000E+01, 0.62388000E+00, -.81162400E+00, -.13307300E+00, 0.14115800E+00, -.39560000E+00, -.53875800E+00, 0.12880100E+01, -.10804600E+01, 0.14562400E+01, -.32720500E+00, 0.26552800E+00, -.13408700E+01, -.57456400E+00, -.18127000E+02, 0.92282700E+01, 0.18793800E+02, -.25622900E+02, 0.10662600E+03, -.40598400E+02, -.14784600E+02, -.10964900E+02, 0.32106300E+01, 0.29777300E+02, -.69817700E+01, -.31229600E+02, 0.59404700E+02, -.41411600E+02, -.10101700E+02, 0.12077900E+01, -.28181300E+02, 0.24564800E+01, -.65292600E+01, 0.16161900E+01, -.43100800E+02, 0.99245200E+02, 0.32195200E+02, 0.42847700E+02, -.48622900E+02, -.94162700E+01, -.14910600E+02, 0.75710300E+02, 0.20774500E+03, -.16454700E+03, -.49587700E+02, -.68659900E+02, -.36622000E+02, 0.95191800E+02, 0.14576500E+02, -.49306200E+02, 0.12091800E+02, 0.57285200E+02, -.17910100E+02, -.31851600E+02, 0.35730500E+02, 0.34459600E+02, 0.97073400E+01, -.38037800E+02, -.19938200E+00, 0.41449000E+00, -.84991500E+00, -.23767600E+00, 0.65720400E-01, 0.49865300E-01, -.32066200E-01, 0.32943700E-01, 0.63722800E+02, 0.32625700E+02, 0.90737800E+02, 0.12662800E+03, -.16808000E+03, -.72073800E+02, -.11600100E+03, 0.10923700E+03, -.63356300E+02, -.17311800E+02, 0.34945300E+01, 0.82274100E+01, 0.19775600E+02, -.30472000E+02, -.12200300E+02, -.24724100E+01, 0.28077100E+02, 0.39046200E+01, -.19395000E+02, -.84569100E+01, -.10622200E+02, 0.14185100E+02, 0.31528200E+01, -.54061600E+01, 0.39430000E+01, -.60268000E+01, -.34672300E+01, 0.33930400E+01, 0.63733500E+01, 0.24242100E+01, 0.25430200E+01, 0.49747700E+01, -.34084500E+01, 0.11633400E+00, -.10967700E+02, -.24650700E+01, -.11765600E+02, -.60093000E+01, -.15078800E+02, 0.25276100E+01, -.30450100E+01, 0.24831300E+02, -.63233900E+01, 0.17551500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.28895600E+01, 0.24862900E-01, -.29519000E+01, -.19227000E+01, -.20021900E+01, -.13332900E+01, 0.33923800E+01, 0.27519600E+01, 0.73696600E+00, -.21674500E+01, -.56391900E+00, -.26442500E+01, -.31586200E+00, -.86360300E+00, -.97974800E+00, -.50325500E+01, -.38080300E+00, -.25695200E-01, -.20441800E+01, 0.19484100E+01, 0.12252700E+00, -.20413200E+01, -.15862900E+01, 0.25245500E+00, 0.66555900E+00, -.62461900E+00, -.41076600E+00, -.37942200E+01, -.41543300E+00, -.13996800E+01, -.11754200E+01, 0.17032600E+01, 0.76144400E+00, -.14990200E+00, -.47431300E+00, 0.11488700E+01, -.14561100E+00, -.95583900E+00, 0.45177100E-01, -.57021300E+00, 0.18317000E+00, 0.44239600E+00, -.15624700E+01, -.38030100E+00, 0.29923400E-01, -.85961200E+00, -.12604900E+00, 0.39531600E+01, 0.38613300E+00, -.12093100E+01, -.15432600E-01, -.56511900E-01, 0.18705500E+00, 0.62013100E-01, 0.26279100E+01, 0.63538600E-01, 0.13466600E+00, -.26051300E+00, 0.11263800E+00, -.14313900E+00, -.67051400E+00, 0.14783700E+00, 0.20310900E+01, -.14677500E+00, -.15566900E+01, 0.56371900E+00, -.48835100E+00, -.18305600E+01, 0.21799300E+00, 0.85137000E-01, -.74428300E+00, 0.12434600E+01, -.79576600E+00, -.48711200E+00, -.40853500E+00, -.11660300E+01, -.84754500E+00, 0.22192400E+02, 0.22926900E+02, -.19076400E+02, 0.30636000E+02, 0.40175900E+02, 0.12014200E+02, 0.25031500E+02, -.98154600E+01, 0.47835600E+01, -.24109600E+02, 0.80036700E+01, 0.54231000E+02, -.41783900E+02, -.80907400E+01, 0.67707200E+00, -.35006200E+02, 0.54158900E+01, -.15778500E+02, -.77535100E+00, -.45767400E+03, 0.38918100E+03, 0.71460700E+02, 0.82459300E+02, 0.40222600E+02, -.13922500E+03, 0.18246500E+02, 0.98710200E+02, 0.17578900E+01, -.34027900E+02, -.25962500E+02, -.33329500E+02, -.11158800E+02, 0.32813200E+02, 0.20854900E+02, -.32999800E+02, 0.31919100E+02, 0.62065700E+02, -.15447200E+02, -.14771500E+02, 0.14444400E+02, 0.12634000E+02, -.13265300E+02, -.20886000E+02, -.39133900E+00, 0.37378300E+00, -.13497700E+01, -.42042100E-01, 0.17245200E+00, -.71329500E-01, 0.19333300E+00, -.34320400E-01, 0.76670900E+02, 0.15335300E+03, 0.56555500E+02, 0.89787800E+02, -.11327600E+03, -.12961000E+02, -.87741700E+02, 0.87824000E+02, -.57264300E+02, -.18690500E+02, -.16106900E+02, 0.59536400E+01, 0.24920700E+02, -.12562500E+02, -.81777200E+01, -.21334100E+00, 0.15679700E+02, 0.10815400E+02, -.19307100E+02, -.47826300E+01, -.93592600E+01, 0.30296900E+01, -.19017900E+01, -.38823600E+01, 0.31039400E+01, -.22541200E+01, -.28025700E+01, 0.27033100E+01, 0.25691300E+02, 0.14047700E+01, 0.17789800E+01, -.30787100E+01, -.27258900E+01, 0.29746700E+00, 0.21567500E+02, -.73032000E+01, -.18284500E+02, 0.12858200E+01, -.15995400E+02, -.12190000E+01, -.22605100E+01, 0.79835800E+01, 0.47433600E+01, 0.14748300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.19232300E+01, 0.11153600E+00, 0.79927000E+00, -.13511400E+01, 0.13280700E+00, -.60899900E+00, 0.32714700E+00, 0.14924700E+01, 0.74719600E+00, 0.14279100E+01, -.19232200E+00, -.83784500E+00, 0.28610100E+00, -.12605900E+01, -.12433300E+01, -.30488100E+00, 0.85519400E-01, -.76238000E-01, -.64349500E+00, 0.19438200E+01, -.52354200E+00, 0.41455000E+00, -.62376700E+00, 0.51732800E+00, -.38540100E+00, -.77696400E+00, -.12484300E+01, -.19229400E+01, -.10686400E+00, 0.31526300E+00, -.19129100E+01, -.13245900E+00, 0.58393300E+00, 0.68978300E+01, 0.46515300E+00, -.15538100E+01, -.84170900E+00, 0.10929600E+01, -.31238100E+00, 0.92044400E+00, -.28861800E+00, 0.54073800E+00, -.10718700E+01, -.27885400E+00, -.75349800E+00, 0.68196600E-01, 0.51938000E-01, 0.27643800E+01, -.21353900E-01, 0.76727000E+00, -.51760800E+00, -.57337800E-01, -.17298100E+00, 0.20869900E+00, -.13658500E+00, 0.22993400E-01, -.76526000E-02, 0.18921200E+00, -.85169200E+00, -.70472700E+00, 0.65250200E+00, 0.16146200E+00, 0.24922800E+01, -.85144800E+00, -.10111300E+01, -.75376500E-01, -.71062700E-01, 0.87242000E+00, -.78113600E-01, -.64694600E-01, -.47619100E+00, 0.76007000E+00, -.34196000E+00, -.10097000E-01, -.38371900E-01, 0.35901100E+00, 0.61168600E+00, -.35431200E+00, -.16811100E+02, 0.16284500E+02, -.23295700E+03, 0.19618900E+02, 0.61103500E+02, 0.71313500E+02, -.26667200E+02, -.94147100E+02, -.34462400E+02, 0.82679000E+02, -.55214000E+01, 0.37670000E+02, 0.17257800E+02, -.98413500E+00, 0.99229000E+01, 0.11601100E+02, 0.20079400E+02, 0.89036000E+00, -.24508300E+03, 0.11140700E+02, 0.23265700E+02, 0.43913900E+02, 0.56583700E+02, -.79204500E+02, 0.27500300E+02, 0.19733700E+02, -.61491200E+02, 0.16152300E+03, 0.20267000E+02, 0.37524200E+02, 0.16243200E+02, -.14149900E+02, 0.10138600E+02, 0.22061200E+02, 0.43880400E+02, -.40161400E+02, -.45690900E+01, 0.39811700E+01, -.23862200E+02, -.12410400E+02, -.24002400E+02, 0.85708100E+01, 0.13799500E-01, -.62295300E+00, 0.27134700E+00, 0.82045300E-01, -.21139600E+00, -.16381300E+00, -.14127800E+00, 0.30218000E-01, -.34313300E+02, 0.98116600E+02, -.79719500E+01, -.36857700E+02, 0.66237000E+02, 0.36017600E+02, 0.42603200E+02, -.18852600E+02, 0.41733900E+02, -.41467000E+02, 0.52380500E+02, 0.25815500E+02, -.38821100E+02, 0.93664300E+00, -.36068600E+02, 0.34353700E+02, -.45339300E+01, 0.30301900E+02, -.25361500E+02, -.14161600E+02, 0.18484400E+02, 0.59643300E+01, 0.16022200E+02, -.14984500E+02, -.26526600E+01, 0.23657900E+01, 0.91502300E+00, -.93564100E+00, 0.36130300E+01, 0.55557100E+00, 0.21012500E+01, -.18832300E+01, 0.93665600E+00, -.17575700E+01, 0.10865200E+02, 0.28568500E+01, 0.24626300E+02, 0.77516800E+01, 0.49485600E+01, -.63590000E+01, 0.83674800E+00, -.14999300E+02, -.25332400E+02, 0.10698900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.21890000E+01, -.69984800E+00, -.10143900E+00, 0.29297400E+00, -.27247900E+00, -.13310900E+00, 0.71413700E+00, -.17374500E+01, 0.71949100E+00, 0.47090600E+00, 0.58165100E+00, 0.15339600E+01, 0.25527800E+00, 0.38974200E+00, 0.38713700E+00, -.17443800E+01, -.90237300E-01, 0.39820900E+00, 0.17202900E+00, 0.11746200E+01, 0.36902000E-01, -.84164600E+00, -.40487900E+00, 0.73816100E+00, 0.13445700E+00, 0.56659100E-01, 0.22427200E-01, -.13062200E+01, 0.21256100E+00, -.58744000E-01, -.30507300E+00, -.80753300E+00, -.26562900E+00, -.26010700E+00, 0.17859900E+00, 0.40472000E+00, 0.53904400E+00, -.29632400E+00, -.19235500E+00, 0.12970500E+00, -.31577800E+00, -.10844400E+00, -.32798600E+00, 0.32309400E-01, -.25648900E+00, 0.11828700E-01, -.47724000E-01, 0.52016200E+00, -.46492700E-01, -.71635800E+00, -.17269600E+00, 0.74811500E-01, 0.12562400E+00, -.65553500E-01, -.14755900E+00, -.28706700E-01, -.14508800E-01, 0.92734600E+00, -.29670100E-01, 0.58763000E-01, 0.57134100E+00, -.60943200E-02, 0.23326400E+00, 0.10788100E+00, 0.47443600E+00, -.31607900E+00, 0.15166200E+00, -.90910000E-01, -.23056900E+00, -.44123100E+00, -.23695100E+00, 0.26374200E+00, 0.64023800E+00, 0.55716300E+00, 0.10302900E+01, 0.21456400E+00, 0.48769800E+00, -.51991800E+00, -.83136100E+00, 0.21293600E+02, -.25881000E+03, -.63109100E+02, 0.86090000E+02, 0.92209000E+02, -.47630900E+02, -.13127700E+03, -.64778000E+02, 0.10341400E+03, 0.57045700E+01, 0.42704100E+02, 0.24627000E+02, 0.11637200E+02, -.11675800E+02, -.74826700E+00, 0.57156100E+01, 0.11780600E+02, -.70497400E+03, 0.18519000E+03, 0.90832900E+02, 0.12878700E+03, 0.11104600E+03, -.21935700E+03, 0.64387500E+02, 0.88261800E+02, 0.17053500E+02, 0.68642900E+02, 0.16538000E+02, 0.31597200E+02, -.16321200E+00, 0.22197500E+02, 0.26963700E+02, 0.51897400E+01, 0.67754000E+02, -.41988100E+02, -.24213600E+02, -.16212800E+02, -.38412500E+01, 0.14270400E+02, -.28386800E+02, -.10592300E+02, 0.27611000E+00, -.28212500E+01, -.88529200E+00, 0.33754800E+00, -.22295600E+00, -.88441400E-01, -.14501900E-01, 0.20534500E-01, 0.46780200E+02, 0.20490500E+03, 0.22006700E+02, -.70857700E+01, 0.17308000E+02, 0.24267400E+02, 0.16594700E+02, 0.20022400E+02, 0.62104000E+01, -.69250200E+02, 0.57797300E+02, 0.32324600E+02, -.27168800E+02, -.23048100E+02, -.46419100E+02, 0.38138500E+02, 0.93840400E+01, 0.29010800E+02, -.37533700E+02, -.18347600E+02, 0.13478500E+02, 0.18082200E+02, 0.22854900E+02, -.16590200E+02, -.14234000E+01, -.79043200E+00, -.15835100E+01, 0.14104100E+01, 0.31550200E+02, 0.38314700E+01, 0.83003900E+01, 0.43546600E+01, -.14309300E+01, -.18434000E+01, 0.37426900E+02, 0.66916400E+01, 0.26370600E+02, 0.34563900E+02, -.48268800E+01, -.44857500E+01, -.12012700E+01, -.11879400E+02, -.31434200E+02, 0.11915500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20752000E+01, -.38563000E-01, 0.27899100E-01, 0.17705000E+01, 0.31687100E+00, 0.10423000E+01, -.52380300E+00, -.18077000E+01, 0.62298300E+00, 0.18752300E+01, 0.18861500E+00, 0.16913600E+01, 0.70136600E+00, 0.98058200E+00, 0.50094300E+00, 0.13231400E+01, -.39478400E+00, -.22641200E+00, 0.81592400E+00, -.27102000E+01, 0.40433900E+01, -.55821200E+00, -.43321800E+00, -.45989200E+00, 0.19316600E+00, -.11789200E+01, 0.29710500E+01, -.28305600E+00, -.57444400E+00, -.51318100E-01, -.82697300E+00, -.50890100E+00, -.22635100E+00, -.28780800E+01, 0.16278600E+00, -.10083600E+01, -.57589200E+00, 0.54013900E+00, 0.25139700E+00, 0.78917400E+00, 0.16010900E+01, 0.11781000E+00, 0.93605100E+00, 0.55966000E-01, 0.14038100E+00, 0.69950300E+00, 0.21437700E+00, 0.12499400E+01, -.35553200E+00, 0.14381600E+01, 0.29849800E+00, -.15588400E+00, -.17454400E+00, -.43219900E+00, 0.30348000E+00, 0.20658100E+00, -.66616400E-02, 0.49683200E-01, -.23420100E+00, -.22776500E+00, 0.28982300E+00, 0.39654700E-01, 0.12127200E+01, -.15937800E+00, -.36624600E+00, -.18153900E+00, 0.20452600E+00, 0.67638100E+00, 0.12018500E+00, -.65280300E+00, -.56718400E-01, 0.89770300E+00, -.79934400E+00, -.69650400E+00, 0.27439200E+00, -.41910300E+00, 0.28256500E+00, -.20193300E+00, -.64486900E-01, -.19061500E-01, -.12322800E+03, 0.17094700E+01, 0.43720200E+02, 0.55381300E+02, -.20133900E+02, -.57480200E+02, -.17985600E+02, 0.64237000E+02, 0.58513400E+01, -.36928000E+01, 0.30771400E+00, -.51675500E+01, 0.97437000E+01, 0.72111300E+01, 0.16748900E+02, -.73612300E+01, -.31465600E+03, 0.17679000E+03, 0.51135300E+02, 0.55389900E+02, 0.42318000E+02, -.95293900E+02, 0.31368700E+02, 0.50639100E+02, -.12132900E+03, 0.49400600E+02, 0.44223900E+02, 0.49355600E+02, 0.10189000E+02, -.36291300E+02, 0.12697200E+02, 0.40725500E+02, 0.26448900E+02, -.10955200E+02, -.39861800E+01, -.27187900E+01, -.63759700E+01, 0.39823700E+01, -.59608500E+01, -.24287700E+01, 0.19698500E+00, -.21038600E+00, 0.34765500E+00, 0.29947400E-01, -.81872000E-01, 0.81956400E-01, 0.20480200E+00, -.26421500E+00, -.28012600E+02, 0.17533100E+02, 0.14060400E+02, 0.10368400E+02, 0.87056000E+00, -.15167600E+02, -.46456400E+01, 0.15541200E+02, -.34085100E+02, -.15529600E+02, 0.99473800E+01, 0.14678500E+02, -.69506800E+01, -.20646700E+02, -.10952100E+02, 0.17754000E+02, -.26894900E+01, 0.12714700E+02, 0.40342100E+01, 0.55103900E+00, 0.47660000E+01, 0.87515400E+00, 0.37692900E+01, -.16495600E+01, -.41108300E+00, 0.32190500E-01, 0.10166500E+01, -.10281800E+01, 0.13744800E+02, -.10185500E+01, -.46175000E+00, 0.80830400E-01, 0.10315700E+01, 0.12501200E+01, 0.13038100E+02, 0.27534800E+01, 0.86489600E+01, 0.18589600E+01, 0.49409600E+01, -.21721400E+01, 0.10040000E+01, -.10169000E+01, -.27024100E+01, 0.13650200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.42177700E+01, 0.13629300E+01, 0.38392900E+00, -.39838800E+00, 0.47939600E+00, 0.28579100E+00, -.12847200E+01, 0.33211400E+01, 0.17529000E+00, -.37345500E+01, -.48136500E+00, -.31496400E+01, -.45296400E+00, -.29518700E+01, -.17647300E+01, 0.40094400E+01, 0.16278000E+00, -.78111000E-01, -.32852500E+00, -.28169500E+01, -.46433100E+00, 0.66002000E+00, 0.24070700E+00, -.19595600E+01, -.60111100E+00, -.48969900E-02, -.12332900E+01, 0.73991600E+00, -.75536200E+00, 0.42596600E+00, -.19554500E+01, 0.25511600E+01, 0.17792800E+01, 0.35552300E+01, -.13288600E+01, -.24119200E+01, -.28439100E+01, 0.52234800E+00, 0.11727900E+00, 0.86681000E+00, 0.86955200E+00, 0.12683000E+01, 0.34958700E+00, -.48023900E+00, 0.11059300E+01, 0.26211200E+00, -.66057700E-01, 0.11166600E+01, 0.87921800E+00, 0.10369100E+02, 0.81954900E+00, -.13891900E+00, 0.26913700E+00, -.52789700E+00, 0.14973900E+01, 0.39897300E+00, 0.20840500E+00, -.53630100E+00, 0.10717600E+01, 0.16018200E+01, -.29971900E+01, -.28179100E-01, -.48023500E+01, 0.18397000E+01, 0.37581000E+00, 0.54730700E+00, -.18903300E+00, -.19387900E+01, 0.95128100E+00, 0.15908200E+01, 0.92475200E+00, -.13401200E+01, 0.13090800E+01, -.28995100E+00, -.10791200E+01, -.30081400E+00, -.12660700E+01, 0.13474800E+01, -.60039000E+00, 0.69368600E+00, -.10221600E+01, 0.19072000E+03, -.22969600E+02, -.14761300E+02, 0.36711400E+02, 0.42868900E+02, 0.61911200E+02, -.85384600E+01, -.17792500E+02, -.19907900E+02, -.23718200E+02, -.18214600E+02, 0.34683400E+02, 0.17821600E+02, 0.22732500E+02, -.19672400E+02, 0.86941000E+03, -.42164700E+03, -.15552200E+03, -.18422400E+03, -.95732000E+02, 0.25968600E+03, -.99785500E+02, -.17856500E+03, -.14590200E+03, 0.18168700E+02, -.14614200E+02, -.16311200E+02, 0.22917400E+02, -.63166500E+02, -.55168200E+01, -.94772000E+01, -.49073100E+02, -.18491700E+02, 0.39540100E+02, 0.45436300E+02, -.31689900E+02, -.43760200E+02, 0.42615900E+01, 0.50325800E+02, -.80288900E+00, 0.18809200E+01, 0.18582300E+01, -.39464400E+00, 0.73210500E-01, -.24470600E+00, -.43475700E+00, -.17366600E-01, -.14085300E+03, -.15892500E+03, -.46827000E+02, -.56489900E+02, 0.86045300E+02, 0.44181600E+01, 0.51326400E+02, -.60691900E+02, 0.80359800E+01, 0.28806800E+02, -.27848800E+01, 0.13404500E+02, -.22839200E+02, 0.16547800E+02, 0.42295400E+01, 0.23163100E+02, -.82198500E+01, 0.12729100E+02, 0.24698300E+02, 0.49424100E+01, 0.40584700E+00, -.15839300E+02, -.11189700E+02, -.41564700E+01, -.40957400E+01, 0.38670600E+01, 0.39727400E+01, -.37133500E+01, -.27141200E+02, -.61592600E+01, -.12013100E+02, -.11688100E+02, 0.37446300E+01, -.14244400E+01, -.25003200E+02, -.51443400E+01, -.96703700E+01, 0.70866500E+01, 0.97969100E+00, 0.47831700E+00, 0.32719200E+01, -.68204500E+01, 0.59245600E+01, 0.37540100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.99709200E+00, -.54389600E-01, -.29159300E+00, 0.74347000E+00, -.12790200E+00, 0.30228100E+00, -.24061000E+00, -.98844500E+00, 0.12155800E+00, -.27707200E+00, 0.11583000E+00, 0.63816900E+00, 0.68690300E-03, 0.56878000E+00, 0.50618800E+00, 0.22422000E+00, -.10685500E+00, 0.75572500E-01, 0.34907000E+00, -.64534600E+00, 0.10355100E+00, 0.29122800E+00, 0.58615500E-01, -.19707600E+00, -.28943100E-01, -.41912400E+00, 0.65773000E+00, -.17589500E+00, -.23425200E+00, -.95588500E-01, 0.38885500E-01, 0.35515200E+00, 0.35698000E+00, -.96409600E-01, -.15370100E+00, -.39127700E+00, 0.42787400E-01, -.13206000E+00, 0.45207400E+00, 0.38453800E-01, -.15945500E+00, -.38875500E-01, -.33797200E-01, -.54346800E-01, -.10577100E-01, 0.47639200E-01, 0.17073800E-01, -.14118700E+00, 0.24228800E-01, 0.58937100E+00, 0.40353700E-01, -.10822900E-01, 0.46147200E-01, -.46775900E-01, 0.25274800E+00, -.67424100E-03, -.12961500E-01, -.51394100E-01, 0.19278200E+00, 0.33896400E-01, -.75432400E-01, -.45370800E-01, -.10802600E+01, 0.80946500E+00, -.59128200E-01, -.91150500E-01, 0.42660500E-01, 0.31782900E+00, -.37999100E+00, 0.55679500E+00, -.16133900E+00, 0.10494500E+00, 0.52706800E-01, 0.19381700E+00, -.69844200E+00, -.33168600E+00, 0.46347500E-01, 0.27500000E+00, -.14573600E+00, 0.17888800E-01, 0.20506700E+00, -.97036600E-01, -.11870700E+02, -.11694800E+02, 0.90423100E+01, 0.78372600E+01, 0.82502800E+01, -.14605300E+02, -.84614500E+01, 0.46063900E+01, 0.67718700E+00, -.18863700E+01, 0.79959500E+01, 0.33288600E+01, 0.67158900E+01, -.39273400E+00, 0.13935100E+03, -.10113100E+03, -.25544600E+02, -.36043000E+02, -.87253100E+01, 0.40245900E+02, -.36093000E+01, -.33750300E+02, -.31638800E+02, 0.15841500E+02, 0.48628000E+01, -.11140100E+01, 0.10404900E+02, -.17918700E+02, -.72133600E+01, 0.19244300E+01, -.41938000E+01, -.79638400E+01, 0.58995800E+01, 0.28132600E+01, -.15572500E+01, -.58224000E+01, 0.27097300E+01, 0.35045900E+01, 0.81297400E-01, 0.18628400E+00, 0.51766200E+00, -.13685500E+00, 0.22164300E-01, 0.20071000E-01, -.13494600E+00, -.13470800E+00, -.43043100E+02, -.38379500E+02, -.86777500E+01, -.72536400E+01, 0.15244900E+02, -.33076300E+01, 0.12637700E+02, -.10477000E+02, 0.21303400E+02, 0.19918800E+01, -.28475300E+01, -.70687200E+01, -.25348000E+01, 0.12546200E+02, 0.66450700E+01, -.66945100E+01, -.72843400E+01, -.10427200E+00, 0.84353200E+01, 0.27037600E+01, -.35103600E+00, -.48142600E+01, -.29151900E+01, 0.18687000E+01, -.59837200E-01, 0.95749400E-01, 0.42063000E+00, -.37859700E+00, -.41482900E+01, -.90065200E+00, -.99237300E+00, 0.48851500E+00, 0.39103500E+00, -.15256700E+00, -.26043400E+01, -.24940100E+00, 0.32053500E+01, 0.83968800E+00, 0.44674800E+01, 0.34163300E-01, 0.33510400E+00, 0.29349200E+00, 0.13352700E+01, -.22259400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.24804000E+01, -.11737400E+00, -.56423400E+00, 0.50468500E+00, -.26570600E+01, -.10319400E+01, -.15663700E+01, -.16253300E+01, -.84880900E+00, -.23004100E+01, 0.18840100E+00, 0.80413300E+00, 0.16423100E+00, 0.18810500E+00, -.20882000E+01, 0.20148400E+01, -.28181300E+00, 0.96431800E+00, 0.15768500E+01, 0.91634300E+00, -.17220100E+00, -.37798400E-01, 0.22648700E+00, -.35583700E+00, -.77039200E-01, -.33516300E+00, -.25501600E+00, -.12923800E+00, -.58436000E-01, -.79667000E+00, -.67115000E+00, 0.27860900E+01, 0.11931200E+00, 0.17937000E+01, 0.15505800E+00, -.63233300E+00, -.65364400E+00, -.30559500E+00, 0.30497600E+00, -.72724500E+00, -.14114000E+01, 0.30683100E-01, -.47188200E-01, 0.21045500E+00, -.33954100E-01, -.11011300E+00, 0.13194200E+00, 0.24220900E+01, 0.54935400E+00, -.33765000E+01, 0.18551300E+00, -.12937700E+01, 0.15677300E-01, 0.20141800E+00, 0.10902800E+01, 0.35362000E-01, -.12135500E+00, 0.18936300E-02, -.27812200E+00, -.37593400E+00, 0.70141400E+00, -.16538300E+00, -.60959000E+00, -.46225200E+00, 0.35950200E+00, -.58089400E-01, -.12580400E+00, 0.55108800E+00, -.18521800E+00, -.77800800E+00, -.28994800E-02, 0.17221500E+00, -.30451900E+00, -.22419500E+00, 0.86729900E+00, 0.68152900E-01, -.27260300E+00, 0.14394900E+00, 0.19291600E+00, -.34988700E-01, 0.12869200E+00, -.25736700E+00, 0.21666200E+00, -.13182800E+02, 0.13725400E+02, 0.11865200E+02, 0.16931200E+02, -.15417800E+02, -.16114700E+02, -.43261100E+01, -.19436900E+01, 0.56501100E+00, 0.74432800E+01, -.36803500E+01, 0.56411000E-01, 0.28868500E+00, 0.20263300E+03, -.85472700E+02, -.20276200E+02, -.26833000E+02, -.42273200E+02, 0.64159300E+02, -.12614600E+02, -.23664300E+02, 0.11215600E+01, -.28605200E+02, 0.60909500E+01, 0.65981600E+01, -.35316700E+01, -.41774700E+01, -.78457100E+01, 0.98522600E+01, -.14422800E+01, 0.24111800E+01, 0.13113400E+01, -.32119400E+01, 0.43165900E+01, 0.17864000E+01, 0.11174500E+02, -.41052000E+01, 0.13666500E+00, 0.48701000E+00, 0.28002600E+00, -.39670500E-01, 0.36105500E-02, 0.11455200E+00, -.85552600E-01, -.30272500E-01, -.23165200E+02, -.52855400E+02, -.19651700E+01, -.27665900E+00, -.45052900E+01, -.99204900E+01, 0.20640900E+01, -.73063600E+00, -.13478000E+02, 0.10012100E+02, -.75319400E+01, -.34330600E+01, 0.42944100E+00, -.44897000E+01, 0.52682300E+01, -.39269600E+01, 0.28772000E+01, -.11932800E+02, 0.12316500E+02, 0.64352100E+01, -.43977000E+01, -.82032600E+00, -.45440400E+01, 0.59780600E+01, -.27221700E+00, -.15407400E+00, 0.81821900E+00, -.78647400E+00, -.97295000E+01, -.11277000E+01, -.13389000E+01, 0.27013100E+01, 0.79331100E+00, 0.49023900E-01, -.86062700E+01, 0.20058400E+01, -.16082400E+01, -.36002500E+01, 0.27419600E+01, 0.21512600E+00, 0.59473500E+00, 0.25487900E+01, 0.48430100E+01, -.30426400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.39903800E+01, -.45575800E-01, 0.38942600E+01, 0.23122100E+01, 0.12375000E+01, 0.90045600E+00, -.50207700E+01, -.56930700E+01, -.18033400E+01, -.24265000E+01, 0.18367500E+01, 0.38255800E+01, -.30521700E+00, 0.25040500E+01, 0.98197000E+00, 0.62119500E+01, 0.26046300E+00, 0.79088000E+00, 0.38895200E+01, 0.18121200E+01, -.74244400E+00, -.14132800E+00, 0.84055200E+00, 0.29563100E-01, -.16150300E+00, 0.87934900E-01, -.52177100E+00, 0.13647500E+01, 0.12891000E+00, 0.61925900E+00, 0.14527400E+01, -.29518500E+01, -.12047000E+01, -.42284200E+01, 0.18617300E+01, 0.57736900E+00, 0.11762700E+01, 0.80846500E+00, 0.44232200E+00, 0.10421800E+00, 0.10293500E+01, -.69439600E+00, -.78152400E-01, -.16756100E+00, 0.31119000E+00, -.62604500E+00, 0.21427800E+00, -.19990200E+01, -.12808200E+01, -.24559300E+01, -.76397500E-02, -.12120400E+00, -.83399300E-01, -.43750300E+00, -.36411400E+01, -.75967800E-01, 0.46845600E-01, 0.18423300E+00, -.58180400E-01, 0.12629700E+00, 0.52303900E+00, 0.13447800E+00, 0.41979500E+00, 0.45906500E+00, 0.14924800E+01, -.21570000E+00, 0.24599000E+00, 0.53706400E-01, -.19442300E+00, 0.16399300E+01, -.42613800E+00, -.55255600E+00, -.53995300E+00, 0.18240200E+01, -.34628800E+01, 0.33649500E+00, 0.18959900E+00, 0.12920500E+00, 0.98908900E+00, -.19531100E+00, -.15136800E+01, -.15826400E+00, -.23990100E+00, -.85682200E+00, 0.22796500E+02, 0.12739900E+02, 0.36959500E+02, 0.26342700E+02, -.32849300E+02, 0.78866600E+00, -.32131700E+02, -.27979600E+02, 0.46391200E+02, 0.10232800E+02, 0.36993500E+02, -.34550700E+02, 0.36044900E+03, -.18469900E+03, -.11033100E+03, -.12535800E+03, 0.35589400E+01, 0.89161300E+02, -.72985700E+02, -.12984300E+03, -.14408200E+03, -.25887700E+02, -.51569100E+01, -.75758000E+01, 0.55014400E+02, -.74503900E+02, 0.36428800E+02, -.11497300E+02, -.53568400E+02, -.28971500E+02, 0.43577900E+02, 0.19032300E+02, -.22712600E+00, -.18781300E+02, 0.23320000E+02, 0.18953400E+02, -.70534000E-01, -.63817400E-01, 0.22254000E+01, -.13252100E+00, -.23174500E+00, -.35767100E-01, -.44064000E+00, 0.43093100E+00, -.62741400E+02, -.25145700E+03, -.44312700E+02, -.29715800E+02, 0.41105200E+02, -.18380800E+02, 0.85519800E+01, -.33507200E+02, -.33286400E+02, 0.78026500E+01, 0.15707200E+02, 0.18109300E+02, -.11393100E+01, -.16521600E+02, 0.74905600E+01, 0.24760100E+02, -.40699000E+02, 0.16737600E+02, 0.17969100E+02, -.70908000E+00, 0.12729700E+02, -.19841000E+02, 0.34569600E+00, -.73016300E+01, -.83223000E+00, -.10288800E+00, 0.51464700E+00, -.26471800E+00, -.14635200E+02, -.22523900E+01, -.63294300E+01, -.49531400E+01, 0.29874800E+00, 0.19657700E+00, -.14684100E+02, 0.33609000E+01, -.17177000E+01, 0.42367900E+01, 0.57791200E+01, 0.64860100E+01, -.18209500E+00, 0.32045400E+01, 0.87068700E+00, -.33152100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.87586600E+00, -.32042500E-02, 0.18582700E+01, 0.34538500E+00, 0.38296000E+00, 0.35645900E+00, -.48548300E+00, -.88528400E+00, 0.87342900E-02, -.51324200E+00, 0.21708700E+00, 0.50476600E+00, -.38633200E+00, 0.78057100E+00, 0.12303700E+01, -.60301900E+00, 0.16580600E+00, 0.96219800E-01, 0.20325800E+00, -.36709300E+00, -.56292900E+00, 0.43487800E+00, 0.14874300E+00, -.12367700E-01, -.27575200E-01, 0.51996300E+00, -.51045800E+00, -.11836800E+00, 0.34449600E+00, 0.66740100E-01, -.17001600E+00, -.35910000E+00, -.12498000E+00, 0.13060000E+00, -.26552200E+00, 0.17016800E+00, 0.27010800E+00, -.21061900E+00, -.34639700E+00, -.67259400E-01, 0.45908100E+00, -.32798400E-01, 0.16759400E-01, -.33923200E-01, -.13921000E+00, 0.17801900E+00, -.10868000E+00, 0.43452100E+00, -.72948100E-01, 0.27333300E+00, -.38921800E-01, 0.98131000E-01, -.44989600E-02, -.18971500E+00, -.42083400E+00, -.47064400E-01, 0.23618300E-01, -.72281500E-02, 0.19651600E+00, 0.17199300E+00, 0.33530700E-01, 0.27222800E-01, -.35458200E+00, 0.25521600E+00, 0.41060000E+00, 0.22026300E-02, 0.12330700E+00, -.21586900E+00, 0.16281600E+00, -.46395900E-01, -.11914500E+00, 0.13555900E+00, -.75276500E+00, -.35844800E+00, 0.51301200E+00, -.67176900E-02, 0.92227100E-02, -.23613300E-01, 0.10314400E+00, -.16372600E+00, 0.20854300E-01, -.39736900E-02, -.15596400E+00, 0.86681000E-01, -.10943400E+00, -.53642600E+01, -.50920000E+00, 0.15227600E+01, -.15852200E+01, -.52793900E+01, -.27194300E+01, 0.45706500E+00, -.10444200E+01, -.15985300E+01, -.12092900E+01, -.89288600E+00, -.48495900E+02, 0.24399500E+02, 0.48522000E+01, 0.97959300E+00, 0.14869700E+02, -.10645900E+02, 0.11454400E+02, 0.77192900E-02, -.14114600E+02, -.35856500E+02, 0.74055600E+01, 0.52528400E+01, 0.70540700E+01, -.43780800E+01, 0.58414400E+01, 0.38621700E+01, -.36934600E+01, -.16328300E+01, 0.98215700E+00, -.48096400E+00, 0.48716200E+01, 0.25758400E+01, 0.10988400E+01, -.62204200E+00, 0.13852500E+00, -.29943300E+00, 0.57216100E-01, 0.76371000E-01, 0.32730200E-02, 0.70538400E-01, 0.43997300E-01, -.49388900E-01, 0.81796900E+01, -.16710900E+02, 0.29440100E+01, 0.57467800E+01, -.10229500E+02, -.80600100E+01, -.58456100E+01, 0.63101800E+01, -.24802300E+02, 0.44526000E+01, -.79142800E+01, 0.28100800E+00, 0.96815200E+01, -.11397300E+02, 0.41692200E+01, -.11666100E+01, -.28502300E+01, -.24458400E+01, 0.78673300E+01, 0.34469500E+01, -.24171800E+01, -.12415500E+01, -.25483400E+01, 0.37655900E+01, 0.25901100E+00, -.44616600E+00, -.46623400E+00, 0.46499000E+00, 0.58298500E+01, 0.67176700E-01, 0.25315500E-01, -.42997900E+00, -.46231200E+00, 0.53466900E+00, 0.54525900E+01, -.29630200E-01, -.27953600E+01, 0.20162100E+01, 0.10345100E+01, 0.16798900E+01, -.44644900E+00, 0.24740600E+01, 0.46462700E+01, -.32461500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.24804600E+01, 0.89790500E-01, -.19329000E+01, -.15173800E+01, -.80928700E+00, -.57677000E+00, 0.26532100E+01, 0.34969300E+01, 0.35801900E+00, -.46274200E+00, -.11119700E+01, -.24114500E+01, 0.10592100E+00, -.25764600E+01, -.22526100E+01, -.21914300E+01, -.18400000E+00, -.29913300E+00, -.16342400E+01, -.17668100E+01, 0.70253500E-01, 0.23676900E+00, 0.61009100E+00, -.45691600E+00, 0.22433200E+00, 0.12243100E+01, -.51173800E+00, 0.12265400E+01, 0.41888100E+00, 0.54851900E+00, -.20978500E+00, -.14717500E+00, 0.13003800E+00, -.20491900E-01, -.63656900E+00, 0.24939300E+00, 0.49049500E+00, -.43505400E-01, -.57808900E+00, 0.13658000E+00, -.21389900E+00, -.18591500E+00, 0.52398400E+00, 0.16614000E+00, -.76843100E-02, 0.30063900E+00, -.86761200E-02, -.58227000E+00, 0.30030900E+00, 0.16250200E+01, 0.10193300E+00, -.47766800E-01, 0.14750800E+00, 0.24213200E+00, 0.59762900E+00, 0.77490900E-01, 0.21985400E-01, -.45994900E-01, 0.14014400E+00, 0.90562100E-01, -.42815700E+00, 0.10680200E+01, 0.22995900E+01, 0.17098200E+00, -.83737600E+00, 0.67045100E-01, 0.51864800E-01, -.17480100E+00, 0.32991000E+00, 0.22378300E+00, 0.24771800E+00, 0.38884200E+00, -.19302400E+00, -.73314300E-01, 0.84469100E+00, -.42112000E-02, -.34664600E+00, -.10400500E+00, -.12401400E+01, 0.71423500E+00, 0.82954600E+00, 0.12940600E+00, 0.19290000E+00, 0.13983900E+00, -.35527100E+00, -.39979400E+00, -.14567900E+02, -.51716800E+01, -.32581500E+00, 0.10965500E+02, 0.13045900E+01, -.15166800E+01, -.54092500E+01, 0.15540300E+01, -.25237600E+01, 0.24123500E+01, 0.17457900E+03, -.11845000E+03, -.46910600E+02, -.43012100E+02, -.10205400E+02, 0.54778700E+02, -.13264500E+02, -.40023000E+02, 0.54469000E+02, 0.60896000E+02, -.37683800E+02, -.36960500E+02, 0.65318400E+01, 0.17122000E+02, 0.14136100E+02, -.31751700E+02, -.62967500E+01, 0.34843900E+00, -.24856800E+00, -.16500500E+01, 0.22811700E+01, -.73010600E+01, 0.46678400E+01, -.24110300E+01, -.35237300E+00, 0.12292600E+01, 0.39612600E+00, -.67492100E-01, -.77383300E-01, -.91454700E+00, -.17695700E+00, 0.31611400E+00, -.37673000E+02, 0.21896000E+02, -.78172600E+00, 0.22195600E+01, 0.13537200E+02, 0.44570700E+01, 0.36073800E+01, 0.51689300E+01, 0.32190600E+01, 0.42053300E+01, 0.22531500E+02, 0.11815700E+02, -.84086100E+01, 0.71608600E+01, -.98023100E+01, 0.17089200E+02, -.91244200E+01, 0.19648600E+02, -.21307800E+02, -.12852800E+02, 0.12709000E+02, -.46193900E+01, 0.88971900E+01, -.14121500E+02, 0.51710900E+00, 0.57772900E+00, -.74555800E+00, 0.81511200E+00, -.52785300E+00, 0.97852300E+00, 0.82988100E+00, -.38915400E+01, -.81955400E+00, -.13121700E+01, 0.81274100E+00, -.43638600E+01, -.18434600E+00, 0.77045800E+01, -.86742700E-01, 0.16038900E+00, -.80926800E+00, -.36051300E+01, -.81409500E+01, 0.60664500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.66461200E-01, 0.41299500E-01, 0.11298100E+01, -.33104900E+00, -.48968100E-02, 0.79727800E-01, -.48198000E+00, 0.14504100E-02, 0.36672000E+00, 0.49918400E+00, 0.75704500E-01, 0.35535800E+00, -.51945500E-01, 0.23329300E+00, 0.41266400E+00, -.55613200E+00, -.63957300E-02, -.23738200E-01, -.28717000E-01, -.21047600E+00, -.23279500E+00, 0.78148300E-01, -.14131800E-01, 0.36089200E-01, -.19017800E-01, -.19645500E+00, -.28767500E-03, 0.22788400E+00, 0.15610300E+00, 0.10659900E+00, -.24562000E-01, -.19391400E+00, -.35069300E-01, -.93400000E+00, 0.61526900E-01, -.15172000E-01, -.92207400E-01, 0.13202800E+00, -.13603200E+00, 0.35625500E-01, 0.20520800E+00, 0.16050900E-01, -.18911800E-01, -.14184300E-01, -.26097800E-01, -.26760300E-02, -.10805800E-01, 0.37718100E-01, -.26417000E-01, 0.23548700E+00, -.18161100E-01, -.29824600E-01, 0.30425600E-01, 0.82471700E-01, -.10029200E+00, 0.15133900E-02, 0.79127000E-02, -.10899600E-01, 0.17169600E-01, 0.92067700E-01, -.83960500E-01, 0.24286600E-01, 0.60333600E+00, 0.14076800E+00, 0.13991100E+00, -.18694800E-01, 0.11841200E-01, 0.22964100E-01, -.40233900E-01, 0.65430100E-01, -.87442000E-02, 0.71493800E-01, 0.43404700E-01, 0.22064800E-02, 0.10647300E+00, 0.48056600E-01, 0.23662400E-01, -.25095500E-01, 0.55564000E-02, 0.10667200E+00, -.48813000E-01, 0.54027500E-01, -.79801000E-01, 0.45796100E-01, -.38330900E-01, 0.90836600E-01, -.44987200E-01, 0.10349500E+01, -.32341600E+01, 0.18508200E+01, -.22140000E+00, 0.29058800E+00, 0.13086100E+00, -.15324400E+01, -.87624800E+00, 0.28651200E+00, 0.33399800E+01, -.45465000E+01, -.55085600E+01, -.55481000E+01, 0.39603900E+01, 0.10825600E+01, 0.25994500E+00, -.58748300E+01, -.19081900E+01, 0.73784700E+01, -.60272800E+01, -.59306200E+01, 0.57924800E+01, 0.22367800E+00, 0.71517400E+01, -.58863900E+01, -.41945500E+01, 0.18671300E+01, 0.18143700E+01, 0.14453800E+01, -.43554400E+00, -.22138600E+01, 0.94594000E+00, 0.14270600E+01, 0.93216800E-02, 0.23549300E+00, 0.53068900E-01, -.73648900E-02, -.87923600E-02, -.35362700E-01, -.16733200E-03, 0.21592400E-01, -.22051500E+01, -.97946900E+01, -.27375500E+01, -.15085900E+01, 0.18057100E+01, 0.66733200E+00, 0.14100200E+00, -.20634200E+01, -.23603800E+00, 0.14106300E+01, 0.60515600E+00, 0.56680000E+00, 0.64963200E-01, 0.29403400E+00, -.20570400E+00, 0.12462100E+01, -.37222000E+01, 0.31968600E+01, -.13445300E+01, -.14315600E+01, 0.18738000E+01, -.11718400E+01, 0.15040200E+01, -.19206600E+01, 0.45352000E+00, 0.23907600E+00, 0.81422500E-01, -.69792500E-01, 0.25858900E+01, -.22789200E+00, -.23289000E+00, -.43544300E+00, 0.69703300E-01, 0.11314500E+00, 0.27573300E+01, -.92006900E-01, -.75562300E+00, 0.27984600E+01, -.57063700E+00, 0.48238100E-01, 0.79394900E-01, 0.15016100E+00, 0.18671300E+00, 0.64262300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.32034700E+01, -.15057100E+00, -.25560100E+00, 0.27694500E+01, -.66617700E+00, 0.10586600E+01, -.19222700E+01, -.21116500E+01, -.37013000E+00, -.30079800E+01, -.13096800E+00, 0.15831500E+01, 0.13012400E+00, -.28474400E+00, -.12059800E+01, -.93035000E+00, -.59246500E+00, 0.10363000E+01, 0.16945100E+01, -.19412200E+01, 0.88552900E+00, -.58649200E+00, 0.29772700E+00, -.92195600E+00, 0.36968200E+00, 0.17126300E+01, 0.33650300E+00, -.62035600E+00, -.45939000E+00, -.22689400E+00, -.32800300E+00, 0.32516100E+01, 0.81648400E-01, 0.12291500E+01, 0.37972100E+00, -.65964000E+00, -.10645600E+00, 0.14314300E+00, -.52268700E+00, -.95247300E+00, -.56851100E-01, -.37911800E+00, 0.52466500E+00, 0.43152800E+00, -.59969700E+00, 0.86533100E+00, 0.70590300E-01, 0.26605900E+01, 0.95300900E+00, 0.22841200E+01, -.22393300E+00, -.68819800E-01, -.12030900E+00, 0.13254200E+00, -.70214600E+00, -.39145600E-01, -.35085100E-01, 0.55861500E-01, -.33771700E+00, -.45043900E+00, 0.97931900E+00, 0.24493000E-01, -.12427100E+01, -.29742300E+00, -.59005000E+00, -.32342300E+00, 0.29615000E+00, 0.16052800E+01, -.24942000E+00, -.51037600E+00, -.42146200E-01, 0.41807700E+00, 0.90434800E+00, -.21841700E+00, 0.52573100E+00, -.58870400E-01, 0.64320500E+00, -.53831300E+00, -.31463300E-01, -.10458200E+00, 0.22034600E+00, 0.16025000E-01, -.48745600E+00, -.57932900E+00, -.15685000E+00, 0.16711100E+00, 0.27641800E+00, -.50848100E+01, -.35421500E+02, 0.14993500E+02, 0.23776700E+01, 0.25054000E+01, 0.71879200E+01, -.12682500E+02, -.59311500E+01, 0.88902100E+00, -.19951800E+02, 0.18435000E+02, -.48879000E+01, -.14307500E+02, 0.21691200E+02, -.34175400E+01, 0.80495700E+01, -.12822800E+02, -.61499900E+02, 0.72176600E+00, 0.88340600E+01, 0.69219200E+01, 0.23569700E+02, -.22358500E+02, 0.15602300E+02, 0.64508800E+01, -.32905900E+01, -.35021300E+01, 0.54340100E+01, 0.13042700E+01, 0.10842400E+01, -.37309600E+01, 0.78261100E+01, 0.19513500E+00, 0.27545800E+00, 0.96180600E+00, 0.59444500E+00, -.21343900E-01, -.53439300E-01, 0.16701400E+00, 0.12878600E-01, -.16244100E+00, -.12406000E+02, -.77491500E+02, -.84033500E+01, 0.20387300E+01, -.20660400E+01, -.57924000E+01, -.10180200E+02, 0.21809900E+01, -.25696500E+02, 0.22479800E+01, -.44598000E+01, 0.52074200E+01, 0.20867300E+01, -.11463500E+02, 0.29974600E+01, 0.63889000E+01, -.10417600E+02, 0.11948900E+02, 0.10316600E+02, 0.80719500E+00, 0.13281100E+01, -.44013100E+01, -.34981200E+00, -.19612200E+01, 0.14000900E+01, 0.12401800E+01, 0.89753500E+00, -.83621900E+00, -.22427700E+01, -.22486900E+01, -.14930800E+01, -.11812700E+01, 0.84747700E+00, 0.96128000E+00, -.13629500E+01, -.93602200E+00, -.31624700E+01, -.79719900E+01, 0.34290200E+01, 0.60965300E+00, 0.67739700E+00, 0.22766400E+01, 0.40270000E+01, -.10145000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16901400E+01, 0.92708300E-01, 0.61962900E+00, -.17267100E+00, 0.10940900E+01, 0.48833900E+00, 0.32264200E+00, 0.60748300E+00, 0.68180000E+00, 0.10226000E+01, -.86842900E-01, -.15291300E-01, 0.32694400E+00, -.94016800E+00, -.32398000E+00, -.15937200E+00, -.19195400E-01, -.28339900E+00, -.32485700E+00, -.21766500E+00, 0.37578900E+00, 0.44606500E+00, -.19577600E+00, -.32402000E-01, -.22948400E+00, -.43224500E+00, -.45446300E+00, -.20813800E-01, 0.93566200E-01, 0.40037400E+00, -.75558300E+00, -.98695300E+00, -.16091900E+00, -.76586600E+00, 0.19140900E+00, -.10145700E+01, -.72473300E+00, 0.40007700E+00, -.10691500E+00, 0.67060900E+00, 0.36373300E+00, 0.32437900E+00, -.18630100E+00, -.70022800E-01, -.32934900E+00, 0.31454500E+00, 0.36349700E-01, 0.73238800E+00, 0.13862800E-01, 0.92913600E-01, -.26301000E+00, 0.73682700E-01, 0.25511700E-01, 0.51063900E-01, -.14847300E+00, 0.26311200E-01, 0.60436400E-01, 0.31476400E-01, -.16821700E+00, -.58939300E-01, -.51100300E+00, 0.10324100E+00, 0.18888000E+01, -.16671600E+00, -.78795200E+00, 0.10691100E+00, -.37858000E-01, -.78163700E+00, 0.52633900E+00, 0.91685000E+00, -.43637000E+00, -.95813900E-03, 0.22268900E+00, 0.30457700E+00, -.60010900E+00, 0.21124000E+00, 0.36464000E+00, -.42482600E-01, 0.37470900E+00, 0.37231400E+00, -.12697500E+00, 0.25836900E+00, 0.67108200E+00, 0.43973000E+00, 0.28411300E-01, 0.10587100E+01, 0.15720900E+00, -.12289900E+01, -.44456500E+00, 0.11764100E+02, -.10306600E+01, 0.42267800E+00, -.95364400E+01, -.55630700E+01, -.10874600E+02, 0.11680600E+01, -.15411600E+03, 0.90001900E+02, 0.10039700E+02, 0.16656800E+02, 0.33510700E+02, -.50747300E+02, 0.24525500E+01, 0.13583400E+02, -.81732500E+01, 0.64870800E+02, -.21632500E+02, -.18070000E+02, 0.95691700E+01, 0.61251700E+01, 0.19174600E+02, -.19985400E+02, -.14429100E+02, 0.20359600E+02, -.11200900E+01, 0.54234900E+01, -.29946900E+01, -.10844500E+02, -.72501300E+01, 0.48923000E+01, -.32054200E-01, 0.98465100E+00, -.58336500E+00, 0.34581800E-01, 0.40169600E-02, 0.47033300E-01, 0.15734200E+00, 0.19907700E+00, 0.45246100E+02, 0.20069200E+02, -.16997800E+02, -.10404900E+02, 0.58495900E+01, 0.26669900E+02, -.46684200E+01, -.98728900E+01, 0.23275700E+02, -.50047500E+01, -.33100500E+01, -.24614100E+01, -.25398700E+00, 0.12249800E+02, -.39413400E+01, -.49698200E-01, -.67770900E+01, 0.14256900E+02, -.12218400E+02, -.90164600E+01, 0.57677700E+01, -.13281800E+01, 0.81406700E+01, -.10709100E+02, 0.16569700E+01, 0.10852100E+01, -.37092600E+00, 0.35586000E+00, 0.59407000E+01, 0.35987700E+00, 0.17912400E+01, -.39769600E+00, -.36744300E+00, -.13121300E+00, 0.52528300E+01, -.76863200E+00, -.46028600E+01, 0.95660800E+00, -.44369300E+01, -.16861400E+01, -.24259000E+00, -.31728500E+01, -.26480100E+00, 0.49431100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25114700E+01, -.79101700E+00, -.20447800E+00, 0.31779100E+00, -.23844900E+00, -.14281300E+00, 0.80413200E+00, -.20224500E+01, 0.79608400E+00, -.24722200E+00, 0.76129800E+00, 0.16622600E+01, 0.79790800E-01, 0.53931900E+00, 0.56764300E+00, -.21045000E+01, -.93548000E-01, 0.49436900E+00, 0.27387200E+00, 0.15073700E+01, -.17647800E+00, -.87038000E+00, -.41413200E+00, 0.96273500E+00, 0.90432100E-01, 0.85703200E-01, -.34791400E-01, -.13329500E+01, 0.47255700E+00, -.39908700E-01, -.31009900E+00, -.78959400E+00, -.44096000E+00, -.27174300E+00, 0.10209600E+00, 0.55179100E+00, 0.75557200E+00, -.48001800E+00, -.37155300E+00, 0.19740700E+00, -.70952400E+00, -.49484100E-01, -.42985800E+00, 0.88564700E-01, -.24552400E+00, -.78656000E-01, -.12887100E+00, -.29995300E+00, -.23685800E+00, -.28074800E+01, -.36953200E+00, 0.23013600E+00, 0.18157000E+00, -.22176800E+00, -.33793300E-01, -.15675100E+00, -.20508900E-02, 0.50791300E-02, 0.25393700E+00, -.19181600E+00, -.11091200E+00, -.20853000E-01, 0.36463200E+00, -.22984200E+00, -.34325400E+00, 0.15059900E+00, 0.36386400E-02, -.31584900E+00, 0.28457000E+00, 0.76598800E+00, -.15391500E+00, 0.10184500E+00, -.88311100E+00, -.46517300E+00, -.84570100E+00, -.34652100E+00, -.28332700E+00, 0.66475000E+00, 0.43971000E+00, -.51498800E+00, -.57023300E+00, -.77277300E-01, 0.70086500E+00, 0.10221000E+00, 0.93604800E-02, -.86368300E-01, -.61200300E+00, 0.45456100E+01, 0.75363400E-01, -.58023400E+00, -.62567400E+01, -.35523000E+01, -.25697700E+01, -.11711300E+01, -.47399400E+01, -.31925000E+01, -.62641300E+02, 0.63317700E+02, 0.29060200E+01, 0.52278300E+01, 0.21280800E+02, -.17340300E+02, -.17749100E+00, 0.44835200E+01, -.32784300E+02, 0.28322700E+02, 0.11107100E+02, 0.17496700E+02, -.28901200E+01, -.11222000E+02, 0.61361500E+01, 0.16919800E+02, -.84200500E+01, 0.98837900E+01, -.58783500E+01, -.34489800E+01, 0.53888000E+01, -.27780500E+01, 0.41177900E+01, -.48238600E+01, -.89644100E-01, -.18819500E+01, 0.13088400E-01, 0.16352100E+00, -.37131200E-01, -.26530200E+00, 0.21386300E+00, 0.25961500E+00, -.58972400E+01, 0.52257200E+00, 0.18972700E+01, 0.48270100E+01, 0.26220300E+01, -.96938700E+00, -.37008500E+01, 0.11923500E+02, -.19623500E+02, -.18362000E+01, -.17118200E+01, 0.46794800E+01, 0.24003400E+01, -.64749300E+01, 0.43893200E+00, 0.79277100E+01, 0.52419700E+00, -.66896100E+01, 0.14674800E+01, -.45422300E-01, 0.97326900E+00, -.12924500E+01, 0.80281800E+00, -.82472900E+00, -.77641100E+00, -.23149300E+00, -.34817500E+00, 0.29646500E+00, -.31025100E+01, 0.45943800E+00, 0.15820100E+01, -.53515400E+00, -.30500800E+00, 0.17049600E+00, -.39251600E+01, -.88950800E+00, -.39656300E+01, -.80748000E+01, 0.29391300E+01, -.48845100E+00, -.24309200E+00, -.20094700E+01, 0.16537300E+01, -.25882800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13325700E+01, -.73700900E-01, -.15959000E+00, 0.92965000E+00, 0.11733600E+00, 0.45502700E+00, -.31076100E+00, -.89555200E+00, 0.29174500E+00, -.38765400E+00, 0.15580500E-01, 0.60490200E+00, -.11567600E+00, 0.49317500E+00, 0.64355500E+00, -.11756200E+01, -.14164400E+00, 0.24716400E+00, 0.18934700E+00, -.81478100E+00, 0.25567000E+00, 0.15708500E+00, -.55398800E-01, -.12696400E+00, 0.13288500E-01, 0.22599000E+00, 0.65105600E+00, -.34846500E+00, -.19707500E+00, -.10294700E+00, 0.84238900E-01, 0.46916900E+00, 0.53423200E+00, 0.12906100E+01, -.19401400E+00, -.23078400E+00, 0.70592400E+00, -.11205100E+00, 0.24253900E+00, -.23524800E-01, -.36883700E+00, -.28437900E+00, -.64878900E-02, 0.25916900E-01, -.32873900E+00, 0.33291200E+00, -.13496300E-02, -.99798600E-01, -.12037700E-01, 0.12956300E+01, -.35874100E-01, 0.61886100E-01, 0.26847400E-02, -.79826000E-01, -.54985500E-01, 0.19721500E-02, -.15528800E-01, 0.30444500E-01, -.85812700E-01, -.35109400E+00, 0.35937600E+00, 0.14198100E-01, -.44141500E+00, -.36681600E+00, -.51590300E+00, -.14177500E+00, 0.11915800E+00, 0.98759800E+00, -.28362400E+00, 0.27905200E+00, -.50594000E+00, 0.61763900E+00, -.26041100E+00, -.92246800E-01, -.58079500E+00, -.28098800E+00, 0.29179400E+00, 0.18338600E-01, 0.12549800E-01, -.56527100E-01, 0.34112300E+00, -.31367100E-01, 0.47119600E+00, -.21705900E+00, -.23933900E+00, 0.49116200E+00, 0.25616800E+00, 0.10205400E+01, 0.19371600E+00, 0.71197900E-01, 0.22040400E+00, -.41074000E+01, 0.97243000E+01, 0.57019800E+01, 0.11676000E+02, -.45219700E+01, 0.57619900E+02, -.35737800E+02, 0.22451900E+01, -.14325500E+01, -.16722300E+02, 0.13996500E+02, -.67762600E+01, 0.10327000E+01, -.13999400E+02, -.34150900E+02, 0.21425200E+02, 0.19118900E+02, -.68516300E+01, -.12590900E+02, -.18325200E+02, 0.20461100E+02, 0.71232400E+01, -.14207400E+02, 0.45078100E+01, 0.23485300E-01, -.91914300E+00, 0.57028200E+01, 0.93600900E+00, 0.17885900E+00, 0.54182300E-01, -.38945700E+00, 0.39242600E+00, -.23365100E+00, -.89551200E-02, 0.30489100E+00, -.11209600E+00, 0.18019600E-01, -.62778400E+01, -.25142600E+02, -.67129300E-01, -.24762900E+01, 0.89185500E+00, -.87655300E+01, 0.61009300E+00, -.40143800E+01, 0.86556100E+01, -.49401500E+01, 0.19962400E+01, -.35115800E+01, -.22441500E+01, -.35936500E+00, 0.23457000E+01, -.54851000E+01, 0.61146400E+01, -.88102600E+01, 0.94945100E+01, 0.64100000E+01, -.51039500E+01, 0.15389900E+01, -.58491600E+01, 0.76159200E+01, -.11705700E+01, -.21220900E+00, 0.38194200E+00, -.37034600E+00, -.10724100E+02, -.35363900E+00, -.11651200E+01, 0.41828600E+00, 0.38082600E+00, 0.11403600E-02, -.10719300E+02, 0.59087000E+00, 0.50784200E+01, -.89161400E+01, 0.38038800E+01, 0.10335500E+01, 0.23662800E+00, 0.14558300E+01, -.16447500E+01, -.29987500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.34896600E+01, 0.30389100E+00, -.12315600E+01, -.20398100E+01, -.12052100E+01, -.55152200E+00, 0.36391600E+01, 0.59114200E+01, 0.22844500E+00, -.30461900E+00, -.19301400E+01, -.38634600E+01, -.13488500E+00, -.33754400E+01, -.15936900E+01, -.28524600E+01, -.10258100E+00, -.97424200E+00, -.24050100E+01, -.44086800E+01, 0.37328200E+00, 0.24379200E+00, 0.10892700E+01, -.11630700E+01, 0.58000000E+00, 0.31509100E+01, -.66274500E+00, 0.14712800E+01, 0.66442400E+00, 0.13323700E+01, -.60062700E+00, -.54058500E+00, 0.14470300E+01, 0.20234700E+01, -.14278600E+01, 0.10034200E+01, 0.15147400E+01, -.77306800E+00, -.18126000E+01, -.60804700E+00, 0.43878900E+00, -.81008300E+00, 0.10416000E+00, 0.39950300E+00, -.15056500E+01, 0.10852800E+01, -.19420000E+00, -.26883500E+01, 0.26204500E+00, -.14054200E+01, -.74168100E+00, 0.87246200E-01, 0.16076400E+00, 0.12849000E+01, 0.10068900E+01, -.41109800E+00, 0.28738800E-01, -.16041300E+00, 0.87911200E+00, -.28557200E+00, -.54360900E+00, -.81982100E-01, -.21388300E+01, -.24272000E-01, -.25454800E+00, -.22734900E+00, 0.25006600E+00, 0.20247900E+01, -.57596400E+00, 0.80700200E+00, -.32742500E-03, 0.23470900E+00, 0.85294500E+00, -.93436300E+00, 0.29827500E+01, 0.10932500E+00, -.34845200E-01, -.32005900E+00, -.18578700E+01, 0.11938900E+01, 0.13058100E+01, 0.25146700E+00, 0.19288000E+01, 0.41949800E+00, -.36463400E+00, 0.58148200E+00, 0.23369100E+00, -.48524000E+01, 0.24247700E+00, -.57866000E+00, 0.31975600E+00, -.10272400E+01, -.14724000E+02, -.78779400E+01, -.13042300E+02, -.94711100E+00, -.17333600E+03, 0.92462300E+02, 0.20145300E+02, 0.38114100E+02, 0.19757700E+02, -.50212900E+02, 0.13000400E+02, 0.37092400E+02, 0.10722600E+03, 0.99702000E+02, -.43238100E+02, -.34593100E+02, -.85268400E+01, 0.60628500E+02, 0.14764400E+02, -.34647600E+02, -.10081200E+02, 0.43512100E+02, -.72747400E+01, -.12939500E+00, 0.23708900E+00, -.29476500E+01, -.30831400E+01, -.63770100E+00, -.41308500E-01, 0.36621100E+01, -.11985900E+01, -.13469500E+00, 0.66463400E-01, 0.43526000E+00, 0.29160700E+00, 0.40012900E+00, 0.85713800E+02, 0.89152200E+02, -.14323100E+02, 0.42895100E+01, -.21107100E+02, 0.35535600E+02, -.22796400E+02, 0.60876900E+01, 0.64118200E+01, 0.28607700E+02, -.10057500E+02, -.34207200E+00, 0.18371100E+01, 0.65882800E+01, -.72485100E+01, 0.79751600E+00, 0.73720200E+00, 0.15442100E+02, -.25460000E+02, -.10803300E+02, 0.62199200E+01, 0.42510300E+01, 0.10562100E+02, -.89227700E+01, 0.33053300E+01, 0.75630800E+00, -.68852600E+00, 0.67415600E+00, 0.51059200E+01, 0.67052500E+00, 0.31358600E+01, -.16008700E+00, -.69293700E+00, 0.46388700E+00, 0.49770100E+01, -.47046000E+00, -.64390900E+01, -.54653000E+00, -.64739600E+01, -.22004300E+01, -.45436300E+00, -.46532100E+01, 0.38450500E+01, 0.62176800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14162700E+01, 0.17867500E+00, 0.15262300E+01, -.13388700E+01, -.27100100E+00, -.20833000E+00, 0.30770500E+00, 0.14985000E+01, 0.17489200E+01, 0.34208300E-02, -.44268000E+00, -.12003900E+01, -.21994100E+00, -.13039900E+01, -.83231800E+00, -.19143600E+01, 0.74447900E-02, -.86401100E-02, -.72115700E+00, -.64131000E-01, -.65279400E+00, 0.89171700E-01, -.13263800E+00, -.35517800E+00, 0.44819600E-01, 0.18103200E+00, -.75943100E+00, 0.45829100E+00, 0.36211700E+00, 0.35300700E+00, -.69669900E+00, 0.97702600E-01, 0.57100900E+00, 0.16050900E+01, -.38474200E+00, -.24476900E+00, -.53910000E+00, 0.36069400E+00, -.61456300E+00, 0.27944700E+00, 0.10656100E+00, 0.20633300E+00, -.13972600E+00, -.15804700E+00, -.45068900E-02, -.10329200E+00, -.12118300E+00, 0.67397200E+00, 0.18865800E+00, 0.15305200E+01, -.50704900E-01, -.16703200E+00, 0.13829500E+00, 0.54688500E+00, 0.54767300E+00, -.90331700E-02, 0.12027500E-01, -.32269400E-01, -.14466000E-01, -.13124400E+00, 0.13925700E-01, 0.89971100E-01, 0.10833000E+01, -.16270900E+00, -.18159000E+00, 0.16154100E+00, -.13804500E+00, -.68405100E+00, 0.12676600E+00, 0.64840900E-01, -.12365400E+00, 0.44240400E+00, -.27298900E+00, -.21003700E+00, -.14166000E+00, -.27438900E+00, -.31408500E+00, 0.15007600E+00, 0.11095200E+00, -.28729700E+00, 0.26207600E+00, -.80223600E-01, -.72352000E+00, 0.82106700E-01, -.14312200E+00, 0.14797200E+00, 0.27435300E+00, 0.44271500E+00, -.29245500E+00, 0.16544700E+00, 0.33700800E+00, 0.72147600E+00, -.18362500E+00, 0.29398800E+01, 0.39138500E+01, 0.16706500E+00, -.38402100E+02, -.87621800E+01, -.22254400E+02, -.19884900E+02, 0.27304500E+02, -.11649500E+02, 0.11497600E+02, -.25280300E+02, -.21534600E+02, 0.33949800E+02, -.28048300E+02, -.29109300E+02, 0.26666800E+02, 0.18318700E+01, 0.24740900E+02, -.32590600E+02, 0.20856000E-01, 0.64729000E+00, 0.55210800E+01, 0.53454700E+01, -.33296100E+01, -.55370800E+01, -.41348000E+01, 0.64512300E+01, 0.85946800E-01, 0.82965900E+00, -.16845900E+00, -.11489300E-03, 0.54823200E-01, 0.16221900E+00, -.15242600E+00, -.14112300E+00, -.69439800E+00, 0.17905200E+02, -.13673500E+02, -.11184300E+02, 0.83374000E+01, 0.14768900E+02, 0.10222800E+02, -.12150400E+02, 0.21423100E+02, 0.13550000E+01, -.21884300E+01, -.31182900E+01, -.23096200E+01, 0.12768100E+02, -.68441400E+00, -.18092500E+01, -.16114900E+02, 0.13195200E+02, -.61525300E+01, -.29946600E+01, 0.42386400E+01, -.56970600E+01, 0.30388700E+01, -.46107200E+01, 0.14063500E+01, 0.41643000E+00, -.50117000E-01, 0.75453900E-01, 0.22813500E+02, -.72770100E+00, -.40382700E+00, 0.65313000E-01, -.72211800E-01, -.18793500E+00, 0.23905200E+02, 0.10414800E+00, 0.90593200E+00, 0.25171400E+02, -.53505700E+01, -.18264700E+00, 0.17701100E-02, -.13851800E+01, 0.11007200E+01, 0.86889100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26477700E+01, 0.24453400E+00, 0.60081100E+00, -.19693400E+01, 0.87521600E-01, -.77428800E+00, 0.66443600E+00, 0.12623800E+01, 0.57168600E+00, 0.31172300E+01, -.15876600E+00, -.43681100E+00, 0.64191700E+00, -.13619400E+01, -.79154600E+00, 0.23033600E+01, 0.16752100E+00, -.58019400E+00, -.91441200E+00, 0.10705400E+00, -.60808700E+00, 0.43105700E+00, 0.73476100E+00, -.21210100E+00, -.33484200E+00, -.12510000E+01, -.84710700E+00, 0.25833700E+01, 0.56477800E+00, 0.81857600E+00, -.30261400E+00, -.40381100E+00, -.60874600E+00, -.31976400E+01, 0.55286500E+00, -.15213000E+01, -.30514700E+01, 0.83791300E+00, -.50836500E+00, 0.75132100E-01, 0.95828200E+00, 0.47703700E+00, 0.49940300E+00, -.13941800E+00, 0.37275900E+00, -.76639300E-01, 0.10573500E-01, -.92795000E+00, -.31121100E+00, -.56085900E+00, -.43141900E-01, -.11149300E-01, 0.32401100E-02, 0.55922800E+00, -.27450200E+00, -.38269100E-01, 0.29003600E-01, -.65626500E-01, 0.42490500E-01, 0.74555600E+00, -.10933400E+01, -.40707600E-01, 0.25613000E+00, 0.79158100E+00, 0.11325800E+01, 0.61756600E-01, -.10189200E+00, 0.76985600E-01, -.17391000E+00, -.27704400E+00, 0.21507700E+00, -.12378600E+00, 0.23803600E+00, 0.83766200E+00, 0.27768900E+00, 0.30147400E+00, -.28457500E-01, -.19844200E+00, 0.31695400E+00, 0.24017100E+00, -.22104800E+00, -.16730600E+00, 0.19864800E+00, 0.14598900E+00, 0.29344500E-01, -.37608800E+00, -.56286200E+00, -.19880700E+01, -.21838000E+00, -.58319200E+00, 0.74942300E+00, -.71494200E+00, -.98101400E-01, 0.10400400E+01, 0.66992900E+01, 0.26247700E+00, 0.13868300E+03, -.49857700E+02, -.19056900E+02, -.17402700E+02, -.31374300E+02, 0.44158900E+02, -.15893300E+02, -.13998000E+02, 0.68651300E+02, 0.26107400E+02, -.29053400E+02, -.27976500E+02, -.23768200E+00, 0.30236600E+02, 0.17145000E+02, -.22051100E+02, -.23130400E+02, 0.25304600E+02, 0.74528300E+01, 0.73567500E+01, -.58100900E+01, -.96321600E+01, 0.44999500E+01, 0.61206500E+01, -.10029800E+00, 0.32534800E+01, 0.40336800E+00, -.43526900E+00, -.11223700E+00, -.19058400E+00, -.75261600E-01, 0.28290800E+00, 0.33100600E+02, -.43418600E+02, -.22832800E+01, -.18838700E+01, -.85269800E+01, 0.60874500E+01, -.14780300E+02, -.48268900E+01, -.11644500E+02, -.31324700E+00, 0.19867100E+02, 0.14364400E+02, -.10378900E+02, -.10788200E+02, -.16719000E+02, 0.16883600E+02, 0.17486100E+01, 0.23273500E+02, -.15785300E+02, -.12454500E+02, 0.10390000E+02, 0.39581600E+01, 0.12002700E+02, -.13979400E+02, 0.23564000E+01, 0.12448900E+01, 0.97489700E+00, -.88843800E+00, -.63367600E+01, -.13190200E+01, -.18825700E+01, -.15335500E+01, 0.88763200E+00, 0.23659300E+00, -.63987900E+01, -.13537300E+01, 0.11186400E+01, -.19995500E+01, -.27579300E+01, -.12380900E+01, 0.82730600E+00, 0.94994600E+00, -.79524600E+01, 0.80528300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.70185500E+00, -.77007100E-01, -.26416900E+00, 0.58478200E+00, -.35589600E-02, 0.21417600E+00, 0.10147500E+00, -.61600000E+00, 0.32895600E-01, -.91049000E+00, 0.25340700E-01, 0.30181700E+00, -.25494400E+00, 0.53438400E+00, 0.53291900E+00, -.13097700E+01, 0.54689200E-02, 0.21493600E+00, 0.40726800E+00, -.85033500E-01, 0.59080200E+00, -.15044600E+00, -.22676500E+00, 0.11562800E+00, 0.17578500E+00, 0.20578300E-01, 0.13068100E+00, -.67032900E+00, -.17735300E+00, -.35255400E+00, -.31579400E+00, 0.21818700E+00, -.17091700E+00, -.96824900E+00, -.93998000E-01, 0.63627100E+00, 0.39654200E+00, -.18753700E+00, -.32881400E-01, -.31922900E+00, 0.20771800E+00, 0.27849600E-01, 0.20679200E+00, 0.33203600E-01, 0.68011000E-01, 0.21826000E-01, -.55789800E-02, -.25673500E+00, -.41990400E-01, -.30086900E+00, 0.27835200E-01, 0.49331200E-02, 0.16090000E-01, 0.34307200E-01, -.73642100E-01, -.41500600E-01, 0.26972400E-02, -.75394600E-01, 0.21186300E+00, 0.30575300E+00, -.33383800E+00, -.42865900E-01, -.80614700E+00, 0.36444600E+00, 0.41083400E+00, -.38465100E-02, 0.21915600E-01, -.14300900E+00, -.20146300E-01, 0.21695500E-02, -.50503600E-01, -.89039600E-01, 0.31793200E+00, 0.16573600E+00, -.24736300E-01, -.89730000E-01, -.57384800E-01, 0.51749900E-01, -.15882500E+00, 0.50229400E-01, -.20323500E+00, -.49021900E-01, -.41196200E-01, -.10706700E-01, -.18775700E-01, -.25543300E+00, -.25612100E+00, -.30155100E+00, 0.79405700E-01, -.44470600E-01, 0.24770400E+00, 0.18886600E+00, -.23736900E-02, 0.30223700E+00, 0.10009800E+00, 0.15509400E+01, 0.31062000E+02, -.20133100E+02, -.67351600E+01, -.80271300E+01, -.37965400E+01, 0.11152400E+02, -.15616600E+01, -.78780700E+01, -.72201900E+00, 0.10696000E+01, -.18689500E+01, -.35528400E+01, 0.18477900E+01, -.47872100E+00, 0.44467600E+01, -.21778700E+01, -.30646100E+01, 0.12236500E+00, 0.38625700E+00, 0.63862000E+00, 0.53926800E+00, -.29144300E+01, 0.43362200E+00, 0.60451400E+00, -.55762100E-01, 0.45208000E+00, 0.13550000E+00, 0.20299300E-01, -.14813600E-01, -.23779000E+00, -.16659700E-01, 0.79947500E-03, -.13778000E+02, -.81774500E+01, 0.46388200E+01, 0.41882900E+01, -.17232500E+01, -.49823000E+01, -.66058800E+00, 0.40358400E+01, -.11251000E+02, -.10300800E+01, 0.54719500E+01, 0.62441700E+01, -.20339700E+01, -.52974900E+01, -.36784600E+01, 0.74858600E+01, -.55846300E+00, 0.74250200E+01, -.17886100E+01, -.28654500E+01, 0.23980000E+01, -.68586600E-01, 0.23109600E+01, -.36194400E+01, 0.15932300E+00, -.14229200E+00, -.13109800E-01, 0.35339800E-01, 0.11498900E+01, -.10951900E+00, -.35455200E+00, -.42057400E+00, -.35479600E-01, -.76146100E-01, 0.11872900E+01, -.41458500E+00, -.10201000E+00, 0.27976100E+01, 0.45399000E+00, 0.51233000E-03, -.19592300E-01, 0.67610800E+00, -.20114800E+01, 0.13107100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.55601800E+00, -.22343000E-01, 0.26583100E-01, 0.59545200E+00, -.17037500E-01, 0.28728700E+00, -.36923200E+00, 0.12559100E-01, 0.23338400E+00, 0.19054800E+00, -.69017500E-01, 0.13694500E+00, 0.16723000E+00, -.22677800E+00, -.15662400E+00, 0.99424300E-01, -.12059100E+00, -.68752600E-01, 0.64533500E-01, -.71286400E+00, 0.46811700E+00, -.84262200E-01, 0.77916800E-02, -.19959700E-01, 0.57045500E-01, 0.12701900E+00, 0.70702500E+00, -.29954700E+00, -.75920200E-01, 0.64934800E-02, -.77708300E-01, 0.40566200E+00, 0.21993900E+00, 0.12902300E+01, -.10817700E+00, 0.40378600E-01, 0.28830500E+00, 0.43167200E-01, -.83548100E-01, 0.68765000E-01, -.63068200E-01, -.38212800E-01, -.68043000E-01, -.30223200E-01, -.14027700E-01, -.40935900E-01, -.42544400E-01, 0.25903400E+00, 0.87432400E-01, 0.94266700E+00, 0.47877600E-01, -.83607800E-02, 0.39357300E-01, -.32456300E-01, 0.22564800E-01, 0.21658600E-01, -.83997100E-02, -.30072000E-01, 0.76003300E-02, 0.18021900E-01, 0.15114700E+00, 0.22552800E-03, -.32605700E+00, 0.66093900E-01, 0.78658400E-01, 0.92216400E-03, -.16170200E-01, -.17039000E+00, -.10423300E-01, -.12302800E+00, 0.93037000E-01, -.14449800E+00, 0.12959400E+00, 0.10426400E+00, 0.68567200E-01, -.13345200E-01, -.84944200E-01, 0.13010200E+00, -.19345100E-01, 0.38988700E-01, -.11682800E+00, 0.44580800E-01, -.28029000E-02, 0.11144100E-01, 0.15236700E-01, -.14752600E+00, 0.16289600E-01, 0.75364400E+00, 0.22067700E-02, 0.18543600E-01, -.50326400E-01, -.17248700E-01, -.36169200E-01, 0.18153800E+00, -.86641000E-01, -.11653100E+00, 0.27141800E+02, -.83003500E+01, 0.33790800E+01, 0.15331400E+01, -.89969900E+01, 0.99005800E+01, -.18763600E+01, 0.32169200E+01, 0.65129800E+01, -.12275200E+02, 0.83967100E+01, 0.85654700E+01, -.63815200E+01, 0.63117500E+00, -.60519500E+01, 0.91108900E+01, -.22629800E+01, 0.14259000E+01, -.13056500E+00, -.45341100E+00, 0.86380400E+00, 0.64828500E+00, 0.80250200E+00, -.78822200E+00, -.18849500E-01, -.34713400E-01, 0.63649700E-01, 0.41969200E-01, -.90411100E-02, -.16847600E-01, 0.47218800E-01, 0.58134900E-01, 0.45071100E+01, -.13152200E+02, 0.17437900E+01, 0.25217600E+01, -.33624900E+01, -.33000500E+01, -.37572100E+01, 0.27899200E+01, -.72941700E+01, -.78317200E+00, 0.69475400E+00, 0.10315300E+01, 0.71410700E+00, -.42077200E+01, -.27406500E+00, 0.12115300E+01, 0.52300500E+01, -.24596500E+01, 0.22633000E+01, 0.19324100E+01, -.16354500E+01, 0.15068400E+01, -.97941300E+00, 0.13477900E+01, -.30238100E+00, -.15587100E+00, -.40827000E-01, 0.44469400E-01, -.54714900E+01, 0.10300000E+00, 0.50306900E-01, -.21974000E-01, -.44265900E-01, 0.19973900E+00, -.56911700E+01, 0.12421100E-01, -.97531600E-01, -.59478200E+01, 0.18522600E+01, 0.11156600E+00, -.65480200E-01, 0.56622400E+00, -.46468400E+00, -.44381100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11254700E+01, 0.11963600E-01, -.26357600E-01, 0.89609200E-01, 0.35248900E+00, 0.16259600E+00, 0.25104200E+00, 0.59863900E-01, 0.28072400E+00, -.49113600E-01, 0.11352200E-01, 0.21547500E+00, 0.32805800E-01, -.57919200E-01, -.10289500E+00, -.36596100E+00, -.53087100E-02, 0.14593200E+00, 0.55006400E-02, -.10726200E+00, 0.47138800E+00, -.47477200E-02, -.74159600E+00, -.30561800E+00, -.78875400E-01, 0.54568600E-01, 0.63981300E+00, -.12100200E+01, -.54731900E+00, 0.41686200E+00, -.56119800E+00, -.62956400E+00, 0.14823600E+00, 0.28658400E+01, -.41662100E+00, 0.22972400E+00, 0.69265600E+00, 0.82935000E-01, -.25566900E+00, 0.70063500E+00, 0.33115500E+00, -.59943100E-01, 0.10692100E+00, -.61521500E-02, 0.59848200E-01, -.10562900E+00, -.34988800E-01, -.91481800E+00, -.63868800E-01, 0.47301200E+00, 0.70690700E-01, 0.24209500E-01, -.99279600E-02, 0.38213800E-02, -.10046100E+01, -.11383000E-01, 0.19761700E-01, -.37653300E-01, 0.81617000E-01, 0.56838200E-01, -.13792600E+00, 0.64771400E-01, 0.62982200E+00, 0.95991900E-01, 0.20305300E+00, 0.39829700E-01, -.29186500E-01, 0.91471300E-01, -.65536500E-01, 0.17199700E+00, -.32661000E+00, 0.47651700E+00, -.37972200E+00, -.25223000E+00, 0.30540400E+00, 0.10567600E+00, -.10663800E-01, 0.32506800E-01, 0.74214900E-01, -.30634700E-01, 0.76779100E-01, -.84706500E-01, -.54752000E-01, -.28000800E+00, 0.15773700E-01, -.80890200E+00, 0.17387700E+00, -.12322300E+01, 0.51340500E-01, -.40011100E+00, 0.14700500E+00, -.60077900E+00, -.72840300E-01, 0.50417600E+00, -.56316200E-01, -.31400400E-01, 0.11715100E+01, -.23446500E+02, 0.19437700E+02, 0.10096900E+01, -.18355300E+01, 0.43586200E+00, 0.62463500E+01, 0.25188800E+01, 0.40394400E+01, -.20996900E+02, 0.15079000E+02, 0.42335100E+01, -.26038200E+01, -.36634200E+00, -.88185500E+01, 0.74222200E+01, -.16819000E+02, 0.38918500E+01, 0.50717700E+01, 0.73884900E+01, -.84334300E+00, -.47889000E+01, -.14712100E+01, 0.76535700E+01, 0.10569300E+00, 0.51061900E+00, -.52770700E-01, -.19830900E+00, 0.42580000E-01, 0.36629500E+00, 0.53535900E-01, -.41281400E-02, 0.12383000E+02, -.28470200E+02, -.34986900E+01, -.24121400E+01, -.37409200E+01, -.32756600E+01, -.34380200E+01, -.55747900E+01, -.39135100E+01, 0.32530500E+01, -.67300100E+01, -.25321900E+01, 0.39444500E+01, -.32802200E+01, 0.48721400E+01, -.42351200E+01, 0.19312700E+01, 0.19960100E+01, 0.53872900E+01, 0.29029400E+00, -.23621500E+01, 0.15989800E+01, -.12623400E+01, 0.20155100E+01, 0.10871100E+01, 0.57266600E+00, 0.33746100E+00, -.33800600E+00, -.21925500E+01, -.80854400E+00, -.11490800E+01, 0.24730700E+00, 0.34074900E+00, 0.12049600E+01, -.17671800E+01, 0.45375900E+00, -.18858400E+01, -.46815600E+01, 0.23306300E+01, 0.81750900E+00, 0.29280800E+00, 0.18194800E+01, 0.20413700E+01, -.97608300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20239800E+01, 0.18580300E+00, 0.80581500E+00, -.29173200E+00, 0.16125800E+01, 0.74139300E+00, 0.45616800E+00, 0.87887700E+00, 0.79998800E+00, 0.21482500E+01, -.30130600E+00, -.13198100E+00, 0.34787800E+00, -.97846800E+00, -.83604900E-01, -.55640900E+00, 0.63461200E-01, -.21461200E+00, -.61595700E+00, -.52919100E+00, 0.59128400E+00, 0.60376600E-01, 0.45997100E+00, -.17232100E+00, 0.32999600E-01, -.26915700E+00, -.89875900E+00, 0.11781800E+01, 0.31345900E+00, 0.93471500E+00, -.81330900E+00, -.50538000E+00, -.35139400E+00, -.25445700E+01, -.52046400E+00, -.10879600E+01, -.19645600E+01, 0.22707900E+00, -.27225400E+00, 0.92562500E+00, -.60017400E+00, 0.65860600E+00, 0.93199100E+00, 0.51565500E-01, 0.32728400E+00, 0.55593100E+00, -.68559600E-01, -.20540100E+00, -.16082700E+00, 0.25522300E+01, -.18873900E+00, 0.33990500E+00, 0.24609900E+00, 0.32123000E+00, -.10096200E+01, 0.19587000E-01, 0.18736900E+00, 0.20538700E-01, 0.81003500E-01, 0.93817200E+00, -.14972500E+01, 0.24689900E+00, 0.14375500E+01, 0.11466400E+01, 0.19267100E+00, 0.10611400E+00, 0.14929600E+00, -.65452200E+00, 0.44475000E+00, 0.68055700E+00, -.65194300E+00, 0.92903300E+00, -.54183200E+00, 0.27671000E-02, 0.77569900E+00, 0.26255300E+00, 0.18707700E+00, -.31522800E+00, -.15342900E+00, 0.43279500E+00, 0.12171300E+00, 0.59044000E-01, -.24241800E+00, -.99240700E-01, -.15640700E+00, -.24709500E-01, 0.10045100E+00, -.14579600E+01, -.38464600E+00, -.11874500E+01, 0.14655200E+00, -.76283300E+00, 0.44325200E+00, 0.99563300E+00, 0.17413400E+00, 0.47104100E+00, -.15651600E+01, -.15092000E+01, 0.54477200E+02, 0.14845300E+02, -.13663500E+02, 0.10061900E+01, 0.27925200E+01, 0.21777900E+02, -.31430400E+02, -.58368000E+02, 0.55045500E+02, 0.39443100E+02, -.15043000E+02, -.18319100E+02, -.27994800E+02, 0.46841100E+02, -.54439500E+02, 0.19804800E+02, 0.76466200E+01, 0.19057700E+02, -.38883800E+01, -.16017400E+02, -.15225200E+01, 0.16757400E+02, 0.24254300E+00, 0.34199800E+00, 0.13950300E+00, -.42445400E+00, -.13890100E-01, 0.78947200E+00, 0.18131900E+00, 0.74688900E-01, 0.44488000E+02, -.13799300E+03, -.12685500E+02, -.11437400E+02, -.71576300E+00, -.10404100E+02, -.14870500E+02, -.16763200E+02, -.26040300E+02, -.12994000E+01, -.20976300E+02, -.62647700E+01, 0.13993400E+02, -.16024600E+02, 0.12695900E+02, -.81754500E+01, 0.14826800E+02, -.28108100E+01, 0.21605600E+02, 0.44001200E+01, -.84499700E+01, 0.51003300E+01, -.46686200E+01, 0.42395100E+01, 0.12252500E+01, 0.23878100E+01, 0.15104400E+01, -.15444500E+01, -.24848900E+02, -.25334600E+01, -.34332700E+01, -.10698200E+01, 0.15519700E+01, 0.29784200E+01, -.25183100E+02, -.67208100E+00, -.50978700E+01, -.35078500E+02, 0.85748200E+01, 0.65155700E+00, 0.13283200E+01, 0.43297200E+01, 0.75674300E+01, -.21308500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.64214200E+01, 0.14668400E+01, -.18434900E+01, -.15712300E+01, 0.93567100E-01, -.20225600E+00, 0.78465300E-01, 0.62985800E+01, -.86755300E-01, -.66068500E+01, -.10191500E+01, -.57115300E+01, -.13581300E+01, -.60304900E+01, -.21886800E+01, 0.35352100E+01, 0.61111700E+00, -.47944200E+00, -.63804100E+00, -.43337400E+01, -.28054000E+01, 0.32992900E+01, 0.32684200E+01, -.10472500E+01, -.59677900E+00, 0.32534900E+00, -.12191700E+01, 0.71202500E+01, 0.23539700E+01, 0.36492300E+01, -.24643500E+01, -.56400100E+00, 0.30818000E+00, 0.78266700E+01, -.81536200E+00, -.28414500E+01, -.34105800E+01, 0.15514400E+01, -.23418100E+01, 0.77952600E+00, 0.14069200E+01, -.12051600E+00, 0.16251200E+01, 0.37722200E+00, -.46664000E-01, 0.53117100E+00, -.11474300E+00, -.23544800E+01, -.24233500E+00, 0.38069000E+01, 0.28028800E+00, 0.14045100E+00, 0.28931500E+00, 0.94926700E-01, 0.33033900E+00, 0.16356900E+00, 0.34522900E+00, 0.11200100E-01, 0.42694200E+00, 0.90428400E+00, -.29270200E+01, 0.27728100E+00, 0.17754500E+01, 0.11806800E+01, -.14348000E+01, 0.19298100E+00, 0.23318600E+00, -.13488700E+01, 0.11160400E+01, 0.23486700E+01, -.10847000E+01, 0.99826300E+00, -.14807700E+01, 0.60541600E+00, -.34434900E+00, -.68664200E+00, -.97813300E+00, 0.10318200E+01, -.13420000E+01, 0.91737200E+00, 0.10684400E+01, -.16455600E+00, 0.29464000E+01, 0.42652700E+00, 0.53323200E+00, -.33024000E+00, 0.12670100E+01, -.71110100E+01, -.12327700E+00, 0.92658000E-01, -.10163200E+01, -.38060900E+01, -.70206400E+00, 0.72794600E+00, 0.16119100E+01, -.29532600E+01, -.22051600E+01, -.14211100E+01, 0.14939000E+01, 0.50363400E+02, -.44859300E+02, 0.51768900E+01, -.68556300E+01, 0.47852700E+02, 0.15976900E+03, -.32233000E+02, -.19362200E+02, 0.82157400E+01, -.55265100E+02, 0.71707000E+02, -.25665600E+02, 0.24708000E+01, 0.52330700E+02, -.12209700E+02, -.21234900E+02, -.18134700E+02, 0.69850300E+01, 0.31272300E+02, -.38848400E+01, -.15051400E+02, -.23353500E+00, -.32196900E+01, -.14323100E+01, 0.51650300E+00, 0.13476500E+00, 0.75885700E+00, 0.12335900E+00, 0.55660900E+00, -.97071000E+01, 0.19070500E+03, 0.21702400E+02, 0.22011300E+02, -.27838400E+02, -.77478100E+01, 0.33513100E+01, 0.31218100E+02, 0.32861800E+01, 0.21079100E+02, 0.15132000E+00, 0.20621500E+01, -.10025300E+02, -.55535700E+01, -.15112600E+02, 0.14319000E+01, 0.39205300E+02, -.45187100E+02, -.11367600E+02, 0.14343900E+02, -.15689500E+02, 0.17756500E+02, -.78103900E+01, 0.22300800E+02, -.44540800E+01, -.36400300E+01, -.73820900E+00, 0.58304200E+00, 0.37156100E+00, 0.23969000E+01, 0.34036400E+01, 0.64064000E+00, -.60457900E+00, -.15274800E+01, -.87724900E-01, 0.65530200E-01, 0.58414600E+01, 0.11134100E+02, -.94484900E+01, -.12495600E+01, -.26217000E+00, -.41894000E+01, -.27436900E+01, -.21755000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13154000E+01, 0.33027300E+00, -.83506800E+00, -.11207000E+01, 0.23262800E-01, -.23964600E+00, 0.21199700E+00, 0.19929600E+01, 0.88825700E+00, 0.12836000E+00, -.58914200E+00, -.12741400E+01, -.28762100E-01, -.13269100E+01, -.10785200E+01, -.15143700E+01, -.18840900E+00, 0.62418000E-02, -.78884500E+00, -.15588000E+01, -.19617000E-01, 0.63427500E+00, -.11761100E-01, -.50574000E+00, -.25929900E-02, -.17185100E-01, 0.54765000E-01, -.23128000E+00, -.40849400E+00, -.43724200E-01, -.95719700E+00, 0.14042500E+01, 0.39857200E+00, 0.32422200E+01, -.33613100E+00, -.69197800E+00, -.18382900E+00, 0.49539500E+00, 0.35390000E+00, 0.38485700E+00, -.43707000E+00, 0.39668000E+00, 0.49518300E-01, -.40356000E-01, 0.72444500E-01, 0.17793900E-01, 0.29892000E-01, 0.32848400E+00, 0.23532200E-01, 0.17021700E+01, 0.17956600E+00, -.39079100E+00, 0.21306700E-01, 0.14368800E+00, 0.32911200E+00, 0.61302200E-01, 0.86190700E-02, 0.27433100E-02, -.61605600E-01, -.15476300E+00, 0.81994100E-01, 0.26207600E-01, 0.21231100E-02, -.13983500E+00, -.42701400E+00, 0.17833000E-01, -.77572200E-02, 0.21553700E+00, -.23249000E-01, -.16601700E+00, 0.19066400E+00, 0.87807300E-01, 0.27682700E+00, -.62050000E-01, 0.47837800E+00, -.35932600E-01, -.13385300E+00, 0.47713900E-01, -.29565400E+00, 0.20507900E+00, 0.25625900E+00, -.37810600E-02, 0.24864200E+00, 0.28752100E-01, 0.18538000E-01, -.54183000E+00, -.88292200E-02, -.64539400E+00, 0.26959600E-01, -.25839600E+00, 0.26296400E+00, -.33908500E+00, 0.10938100E+00, 0.37434300E-01, -.51026500E-01, -.25157800E+00, 0.18273000E+01, 0.59226300E+00, -.40673200E+00, -.57444000E-01, -.32955300E+01, -.27658900E+01, -.26937800E+01, -.14542100E+00, -.18838200E+01, 0.35970100E+01, -.93013800E+01, -.91558000E+01, 0.48800500E+01, 0.10358100E+01, 0.75771400E+00, -.87752400E+01, -.46240300E+01, 0.40461400E+01, 0.65404600E+00, 0.40672800E+01, -.35278500E+01, -.21096100E+01, -.18242800E+01, 0.37951900E+01, 0.57580300E-01, 0.63700300E+00, -.57385300E-01, -.18457100E+00, 0.11439300E-01, 0.22112300E+00, -.12379500E+00, -.66126500E-01, 0.13357400E+02, -.14030800E+02, -.79435300E+01, -.89796500E+01, 0.30244900E+01, 0.53002900E+01, 0.32191300E+00, -.11270800E+02, 0.89302800E+01, 0.44779000E+01, -.52476600E+01, -.42107900E+01, 0.40865700E+00, 0.40605900E+01, 0.17038500E+01, -.51668600E+01, -.16961300E+01, 0.23012800E+01, 0.81846600E+00, -.80355600E+00, -.31502400E+00, -.65725600E+00, -.13335500E+01, -.35754400E+00, 0.38979600E+00, 0.90301800E+00, 0.58237400E+00, -.58353500E+00, -.24111400E+01, -.89525900E+00, -.11205300E+01, 0.15360800E+00, 0.58643400E+00, 0.57467700E-02, -.22166700E+01, 0.17654800E+00, -.11415600E+01, -.16066100E+01, -.21986200E+01, -.42325200E+00, 0.56579300E+00, 0.35752900E+00, 0.22064000E+01, 0.24536800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14885900E+01, 0.16836000E-01, -.46311200E+00, -.73822700E+00, -.68150300E+00, -.73438000E+00, 0.35891100E+00, 0.49429100E+00, 0.11315000E+00, -.15583700E+00, 0.55386100E-01, -.40208800E+00, 0.50138700E-01, -.25937000E+00, -.11540000E+01, 0.44338000E+00, 0.14663600E+00, 0.24218600E+00, -.23974300E-01, 0.23571400E+01, -.10645400E+01, 0.68925100E-01, -.73467600E+00, 0.12344400E+00, -.54374200E-01, -.10427900E+01, -.30893100E+00, -.15655900E+00, -.12830900E+00, 0.10022500E+01, 0.24959900E-01, -.18697900E+01, 0.23752100E-01, -.68438800E+00, -.11047900E+00, 0.76993400E-01, -.57252000E-01, -.94144800E-01, 0.57666000E-01, -.86573300E-01, -.39785600E-01, -.59650100E-01, 0.24279900E+00, -.85691000E-02, 0.72033000E-01, 0.33594000E-01, -.36140600E-01, -.52526200E+00, -.72963000E-01, 0.73899500E+00, 0.68197600E-01, 0.44136500E-01, 0.58541100E-01, 0.18710700E-01, -.94150800E-01, 0.47346600E-02, -.60155100E-02, -.59284900E-01, 0.12139300E+00, 0.16322800E+00, -.16854400E+00, -.15065500E-01, -.31566500E+00, 0.16744000E+00, 0.33144200E+00, -.20934900E-02, 0.57068900E-02, -.44318400E-01, 0.72768000E-02, 0.82279600E-01, 0.22148700E-01, 0.89513800E-01, 0.23996200E-02, 0.19173600E-02, 0.14989300E+00, 0.25327600E-01, -.25288800E-01, 0.24052000E-01, -.19085100E-01, -.56587000E-01, 0.20824300E+00, -.58423500E-01, 0.56436500E-01, 0.12765500E+00, -.13100800E+00, 0.69042100E-01, 0.13771700E+00, 0.21735900E+01, -.22145300E+00, 0.15103000E+00, 0.52029800E-01, 0.35214900E+00, -.97722900E-01, 0.49959300E+00, -.15076700E+00, -.97282400E-01, 0.18746700E+01, 0.59914300E+00, -.31829700E+00, 0.65867000E-01, -.52534900E+00, -.43095200E+01, -.10589400E+02, -.25397500E+01, -.11812000E+02, 0.16192500E+01, -.43399200E+01, -.32617000E+01, 0.20400400E+01, -.42736300E+01, -.50148300E+00, -.25414000E+01, -.13147700E+02, 0.54717300E+01, 0.13884900E+00, 0.57373100E+01, -.38865000E+01, -.61422300E+01, -.97156900E+00, 0.52760700E+01, 0.17611700E-01, 0.43444800E+00, 0.10717200E+00, -.20744100E+00, -.48621200E-01, 0.11908100E+00, -.12833400E+00, -.45947900E-01, 0.15574400E+02, -.26651800E+02, -.65018300E+01, -.10197000E+02, 0.81867900E+01, 0.52733500E+01, -.47041800E+00, -.10458900E+02, -.19002100E+01, -.32891400E+01, -.14085200E+01, 0.18530700E+01, -.11966500E+00, -.17431400E+01, -.42775500E+00, 0.20723900E+01, 0.55709700E+00, 0.70178400E+01, 0.91960800E-01, -.44974400E+01, 0.11649800E+01, 0.41422000E+00, 0.11425200E+01, -.45208100E+01, 0.13338300E+00, 0.13187900E+01, 0.66204400E+00, -.66053500E+00, -.10023900E+02, -.90380500E+00, -.12757400E+01, -.73943800E+00, 0.66362000E+00, -.34618600E+00, -.10247500E+02, -.69520900E+00, -.10309300E+01, -.76964100E+01, -.15586700E+01, -.53520900E+00, 0.56261200E+00, -.59890800E+00, 0.49315700E+00, 0.19328100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23074500E+01, 0.21929300E+00, 0.10731600E+01, -.17462500E+01, 0.52173400E+00, -.56917700E+00, 0.47344600E+00, 0.17021700E+01, 0.92734900E+00, 0.39146800E+01, -.41974200E+00, -.50939600E+00, 0.69358300E+00, -.16224400E+01, -.91499000E+00, 0.45957200E+00, 0.83012800E-01, -.39567800E+00, -.12642400E+01, -.17488500E+00, -.86445300E-01, 0.38042600E+00, 0.36921300E+00, -.78706700E-01, -.34072600E+00, -.26297700E+00, -.99938200E+00, 0.15804300E+01, 0.32586700E+00, 0.94443700E+00, -.73983900E+00, -.78080700E+00, 0.33124500E-01, 0.19019600E+01, 0.62866500E+00, -.15755000E+01, -.15040200E+01, 0.14503100E+01, -.45232000E+00, 0.10410800E+01, 0.49753000E+00, 0.45309000E+00, -.73138400E-01, -.24350500E+00, 0.36966100E-01, -.15635200E-01, 0.90420200E-01, 0.19376800E+00, -.42657300E+00, 0.52913900E+00, -.17052700E+00, -.81615200E-01, -.14211800E+00, 0.39794900E+00, -.34969100E+00, 0.41537400E-01, 0.70894300E-02, 0.15783900E+00, -.54626900E+00, -.14794100E+00, 0.30245700E-01, 0.79885000E-01, 0.17570500E+01, -.23999200E+00, -.10304200E+00, -.59223200E-01, -.47331400E-01, 0.66165000E+00, -.20457800E+00, -.22764000E+00, -.44935500E-01, 0.72460500E+00, -.94250100E+00, -.93749000E-01, 0.14777200E+00, 0.34217800E+00, 0.56364300E+00, -.60700500E+00, 0.81667200E+00, -.10085400E+00, 0.58779600E+00, -.84797600E-01, 0.15807100E-01, 0.18203600E-01, 0.94669000E-02, 0.42176900E+00, 0.22235400E+00, -.21505700E+01, -.26294400E+00, -.51028200E+00, -.46750900E-01, -.94250400E+00, 0.14208300E+00, 0.12455200E+00, 0.33699000E+00, 0.10934200E+00, -.17513800E+00, -.14852300E+01, 0.64273600E+00, -.87471700E-01, -.74527100E+00, 0.14924600E+01, 0.13690200E+02, 0.18159000E+01, 0.42362900E+02, -.10051200E+02, -.13337100E+02, -.15892000E+02, 0.30701800E+01, 0.16648500E+02, -.26611900E+01, -.19575900E+02, 0.27701000E+02, -.94012500E+01, 0.44975300E+01, -.67375200E+01, 0.32953400E+01, 0.16214200E+02, -.46416700E-01, -.46573100E+01, 0.13391300E+00, -.98948500E+00, -.58856900E+00, 0.63449000E-01, 0.16566000E+00, 0.52523600E+00, 0.56189200E-01, 0.24888100E-01, 0.61744500E+01, 0.76903500E+02, -.80621000E+01, -.31575400E+01, -.66465100E+01, 0.93987900E+01, 0.98522300E+01, -.56800300E+01, 0.48521300E+02, 0.99395000E+01, -.10457900E+02, -.20936000E+02, 0.14763600E+01, 0.23699900E+02, 0.93983800E+01, -.24921100E+02, -.54035000E+01, -.22959300E+02, 0.47921500E+00, 0.11617600E+02, -.68020400E+01, -.19600700E+01, -.76696100E+01, 0.15435000E+02, 0.43787600E+00, -.14832700E+01, -.82739000E+00, 0.79255200E+00, 0.19697900E+02, 0.10519100E+01, 0.16522500E+01, 0.28810600E+01, -.79571200E+00, 0.33218200E+00, 0.20486500E+02, 0.29489700E+01, 0.11373100E+01, 0.17444700E+02, -.34590500E+01, 0.16277000E+01, -.66908400E+00, -.21322000E+00, 0.29202700E+01, -.57553600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.53117500E+01, 0.85293600E-01, -.62923600E+01, -.32374400E+01, -.13926600E+01, -.23325800E+01, 0.42643600E+01, 0.27750100E+01, 0.37661900E+00, -.84638200E+00, 0.67875500E+00, -.22978200E+01, 0.27008300E+00, -.10073500E+00, -.11276900E+01, -.20925700E+01, -.15659500E+00, 0.52498600E-01, -.21005200E+01, 0.24551900E+01, 0.79291400E+00, -.42149500E+01, -.32388700E+01, 0.25906200E+00, 0.47106400E+00, -.35190000E+01, 0.45635200E+00, -.21640700E+01, 0.44969900E+00, -.12197500E+01, -.24533200E+01, -.61641000E+00, 0.29148100E+00, 0.90171300E+01, -.59868900E+00, -.91455400E+00, -.11474400E+01, -.48220900E+00, -.20911200E+00, 0.13772800E+01, -.70991900E+00, 0.78789100E+00, -.18548600E+01, -.39636500E+00, -.85641400E+00, -.32382100E+00, -.34611700E-01, 0.18333700E+01, 0.29945100E+00, -.18004000E+01, -.67928400E+00, -.10846300E+00, -.18258600E+00, 0.92575600E-01, 0.46915400E+00, -.17696900E+00, -.11661100E+00, 0.17474500E+00, -.15568700E+00, -.11856600E+01, 0.13843300E+01, 0.51665000E-01, 0.17693800E+01, -.14084300E+01, -.70147500E+00, -.37107200E-01, -.19540700E+00, -.68266900E+00, -.45075700E+00, 0.23414400E+00, 0.25091400E-01, -.48238000E+00, -.95866400E-01, 0.78097400E-01, -.11727000E+01, -.42921000E+00, -.10275500E+01, 0.74097500E+00, 0.19154400E+00, -.11490500E+01, 0.86024200E+00, -.56339500E+00, 0.71802000E-01, 0.13918100E+00, 0.12281700E+00, -.27925400E+00, 0.49377000E+00, -.39901700E+01, -.57179300E+00, 0.81566800E+00, 0.23265500E+00, -.23674600E+00, -.11340800E+01, 0.74954300E+00, 0.16114200E+01, -.70968300E+00, 0.65059700E+00, 0.46779400E+01, -.19888500E+01, 0.31591800E+00, -.22544200E+01, 0.10153500E+01, -.92845700E-01, 0.10016600E+02, -.54502600E+02, -.70688100E+02, -.27594600E+01, 0.31206000E+01, 0.22855400E+02, -.11390700E+02, 0.12862500E+02, 0.39254300E+01, -.22206600E+02, 0.51249300E+01, 0.65338500E+01, 0.10390000E+02, -.24998700E+01, -.64561600E+01, -.37463600E+01, 0.74072700E+01, 0.35266200E+00, -.27066500E+01, -.62545200E+00, 0.18422300E-01, 0.38504100E-01, 0.83701400E+00, -.99860800E-01, -.87485300E-01, 0.26274900E+02, -.12873800E+03, -.28779000E+02, -.20690600E+02, 0.90019700E+01, 0.19659700E+01, -.35356600E+01, -.25848800E+02, 0.31537900E+02, -.37836000E+01, -.35674000E+02, -.30051900E+02, 0.17985000E+02, 0.15677700E+02, 0.21962700E+02, -.33468600E+02, -.18756100E+01, -.22437700E+02, 0.21132000E+02, 0.15127500E+02, -.13559900E+02, -.44469800E+01, -.13215300E+02, 0.11499600E+02, 0.10105400E+00, 0.17116400E+01, 0.73945700E+00, -.89154700E+00, -.24417800E+01, -.19772600E+01, -.19189000E+01, 0.13700000E+01, 0.89369800E+00, 0.15062400E+01, -.26933300E+01, 0.15968700E+01, -.36375200E+01, -.89868400E+01, -.36170900E+01, 0.60036500E+00, 0.92600000E+00, 0.46597700E+01, 0.13842200E+02, -.70444400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.74505600E+01, 0.15938200E+00, -.65020700E+01, -.42044800E+01, -.15693500E+01, -.13713800E+01, 0.87372400E+01, 0.10926700E+02, 0.31878400E+01, 0.46358100E+01, -.34801300E+01, -.68514100E+01, 0.83636600E+00, -.72556400E+01, -.33795500E+01, -.93387000E+01, -.40754600E+00, -.17566700E+01, -.68182700E+01, -.51793200E+01, -.14638100E+01, 0.20013800E+01, 0.12327400E+01, -.11242000E+01, 0.27451500E+00, 0.24638100E+01, -.31512500E+00, 0.11326200E+01, 0.45410400E+00, 0.17896400E+01, -.11006200E+01, 0.18315200E+00, 0.21577400E+01, 0.10224500E+02, -.29931000E+01, -.83426600E+00, 0.39978800E+00, 0.24733400E+00, -.82177900E+00, 0.24330500E+01, -.16092800E+01, 0.44209600E+00, 0.28629300E+00, -.16010400E+00, -.13153800E+00, 0.37751400E+00, -.28848600E+00, -.27520800E+01, 0.22619100E+00, 0.47965000E+01, 0.41565900E+00, -.13432800E+00, -.33591900E-01, 0.11516600E+01, 0.50657800E+01, 0.16350200E+00, 0.19491600E-01, 0.24910200E-01, -.74402300E+00, -.11572600E+01, -.33639800E+00, 0.18672400E+00, 0.49042700E+01, -.18738800E+01, -.43928400E+01, 0.43063200E+00, -.51470700E+00, 0.56794500E-01, 0.65287600E+00, -.11742700E+01, 0.94092300E+00, 0.38664300E+00, -.86787900E+00, -.19467600E+01, 0.37304000E+01, 0.77133000E-01, 0.96950000E-01, -.97937800E-01, -.45439000E+00, 0.48851100E+00, 0.16376300E+01, 0.42807300E+00, -.12488700E+01, 0.21168400E+00, -.60681400E+00, -.59780100E+01, 0.85558500E+00, 0.66752400E+01, -.27177200E+00, -.31408300E+01, 0.59921000E+00, -.21043900E+01, 0.33318200E+00, 0.27550700E+01, -.12649800E+01, -.15701100E+01, -.13439400E+01, -.36247800E+01, 0.36482600E+01, 0.31140900E+00, 0.79279500E+00, -.19553100E+01, 0.79145800E+00, -.35661200E+00, -.19517500E+03, -.93179600E+01, 0.37097700E+02, 0.30681800E+02, 0.30418200E+02, -.71799900E+02, -.96005400E+01, 0.28695500E+02, 0.81114000E+01, -.23831400E+02, 0.11435300E+02, 0.58251100E+01, -.13007500E+01, -.50027900E+01, -.13045300E+02, 0.72128500E+01, 0.11633800E+00, 0.31608700E+01, 0.13659700E+01, -.12927500E+00, 0.37922400E-03, -.67772900E+00, 0.13186200E+00, -.48871500E+00, 0.13285200E+01, -.34979000E+02, -.45557400E+01, 0.10309700E+01, -.45982600E+01, 0.40971700E+01, -.44540500E+01, -.52300900E+01, -.19742300E+02, -.21576300E+02, -.64734700E+01, 0.70771800E+00, 0.12046800E+02, 0.68179000E+00, 0.96776200E+01, -.37825800E+01, -.18693300E+01, 0.18940000E+02, 0.30458800E+02, 0.14911200E+01, -.55029000E+01, -.86318800E+01, -.78575600E+01, 0.28478200E+01, -.73624000E+00, -.10926000E+00, -.77596400E+00, 0.97853500E+00, -.17544800E+02, 0.11908800E+01, 0.42548800E+00, 0.47784100E+00, -.95449900E+00, -.21091100E+01, -.19587900E+02, 0.95181400E+00, -.78845300E+00, -.17091300E+02, 0.96292300E+01, 0.28025600E+01, -.10300600E+01, 0.37286500E+01, 0.50387400E+01, -.55537300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.19543700E+01, 0.10232900E+00, -.43125200E+01, -.95596900E+00, 0.16432600E-01, -.45763800E+00, 0.20334200E+01, 0.27221300E+01, 0.35517700E+00, -.15939700E+01, -.82605500E+00, -.24282000E+01, -.63042800E-01, -.25326200E+01, -.21835400E+01, -.14482800E+01, -.97125800E-01, -.41982500E+00, -.13684900E+01, -.16746400E+01, -.75286200E+00, 0.65121500E+00, 0.10804000E+01, -.24177500E+00, 0.21248200E+00, 0.57610600E+00, 0.52991800E-01, 0.14249500E+01, 0.70527100E+00, 0.59185400E+00, 0.47400300E+00, -.52065800E+00, -.63657400E+00, -.12543800E+01, -.65270200E+00, -.23078400E-01, 0.48334800E+00, 0.77487900E-01, -.75968800E+00, 0.25782000E+00, -.19927500E+00, -.28831000E+00, 0.93694600E+00, 0.94065800E-01, 0.54391300E+00, 0.92880100E-01, -.30908100E-01, -.45778100E+00, 0.24535400E+00, 0.26362000E+01, 0.38590800E+00, -.19952000E+00, 0.41333900E+00, 0.35868500E+00, 0.99295700E+00, 0.18134100E+00, -.62393100E-01, -.17445000E+00, 0.11514800E+00, 0.32699900E+00, -.28045300E+00, -.17138100E+00, -.68480000E+00, 0.33208700E+00, 0.65773700E+00, 0.14569500E+00, -.20722400E+00, -.14219300E+00, -.11259500E+00, -.56473500E+00, 0.88632600E-01, 0.14549800E+00, -.23008900E+00, 0.38418200E-01, -.15970800E+00, -.27829500E+00, -.36665700E+00, 0.34008200E+00, -.15866400E+00, 0.67522200E-01, 0.15715800E+00, -.15529100E-01, 0.78508800E+00, 0.22494100E+00, 0.31128200E-01, 0.22263500E+00, 0.46916400E-01, -.10643000E+01, 0.10645400E+00, 0.18133800E+00, -.16714000E-01, -.97907900E-01, 0.26479700E-01, -.17110700E+00, 0.10360200E+00, 0.36307700E+00, 0.27383400E+00, -.21404500E+00, -.15704800E+00, -.64466900E-01, 0.53508600E+00, -.25784600E+00, -.31155600E+00, -.25495300E+00, -.86226700E-01, -.31599500E+02, -.53622800E+01, -.50913200E+01, 0.67090300E+01, 0.58844100E+01, 0.56618900E+01, -.67581800E+01, -.36906000E+01, -.37577700E+01, 0.60806100E+01, 0.37064300E+01, 0.18366300E+01, 0.24776600E+01, -.33778300E+01, 0.44013500E+01, 0.14892700E+00, -.15786600E+01, -.36468000E+00, 0.49731300E-01, 0.58190300E-01, 0.59084000E+00, 0.85724400E-01, 0.13370400E+00, 0.10980300E+02, -.26329100E+01, -.99395700E+01, -.86145700E+01, -.91736800E+00, 0.19643000E+01, 0.50999300E+01, -.96653000E+01, 0.17871500E+02, -.35042700E+01, -.81195100E+01, -.10412900E+02, 0.41547800E+01, 0.69340700E+01, 0.63375100E+01, -.11916700E+02, 0.11585100E+01, -.15314400E+02, 0.51766700E+01, 0.70868400E+01, -.65452500E+01, 0.16549700E+00, -.43520600E+01, 0.82274800E+01, 0.17665200E+00, -.18097800E+00, -.15198300E+00, 0.10580700E+00, 0.58707600E+01, 0.14490600E+00, -.30129200E-01, 0.10926000E+01, -.10820800E+00, 0.32347200E+00, 0.57699200E+01, 0.11711800E+01, -.43514000E+00, 0.57754500E+01, -.37102500E+01, 0.14112800E+01, -.41803500E-02, 0.10582000E+01, 0.25291500E+01, -.30833700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18347700E+01, -.33577800E-01, 0.59378900E-01, 0.35365300E+00, -.10161200E+01, -.36573500E+00, -.60460900E+00, -.62548500E+00, 0.39364300E+00, 0.14424100E+01, 0.49136200E-04, 0.60024300E+00, 0.45074100E+00, 0.32255300E+00, -.26025100E+00, 0.26318000E+00, -.17489900E+00, 0.64253000E-01, 0.65036700E+00, -.10265100E+01, 0.37907900E+01, -.68306400E+00, -.55874900E+00, -.23770600E+00, 0.24936700E+00, 0.15107100E+00, 0.57563400E+00, -.28773300E+00, -.53222000E+00, 0.29102400E+00, -.86998900E-01, -.21077100E+00, -.25654900E+00, -.30177200E+01, 0.51420200E+00, -.39186800E+00, -.75443500E+00, 0.69842400E+00, -.36959800E+00, 0.10578300E+00, 0.16578600E+01, 0.17195500E+00, 0.79034800E+00, 0.16868800E+00, 0.26484200E-02, 0.67707900E+00, 0.33595800E-01, 0.15031000E+01, -.79534800E-01, 0.14951300E+01, 0.13410200E+00, 0.19125200E-01, -.20512000E+00, -.30077300E+00, -.25851000E+00, 0.14763300E+00, 0.80923900E-01, 0.13990400E+00, -.44504000E+00, -.53152500E+00, 0.55793700E+00, 0.27871000E+00, 0.28566200E+01, -.40273300E+00, -.10560700E+01, -.27324200E-01, 0.22756500E+00, 0.11485700E+01, 0.39497100E+00, -.37609100E+00, 0.40303200E+00, 0.27860600E+00, -.55713300E-01, -.50446900E+00, 0.42304300E+00, 0.18754900E-01, -.28226500E-01, -.12307100E+00, 0.10673900E+00, 0.57518300E-01, 0.35252300E+00, 0.25334400E+00, -.71489500E+00, -.28102800E+00, 0.45527100E-01, -.38157500E+00, 0.48889600E-01, -.35887600E+00, 0.19257700E+00, 0.10716800E+00, -.53017100E+00, -.57126200E-01, -.30531100E-02, -.13884800E+00, -.20457700E+00, -.13758600E+00, 0.20994100E+00, 0.49764700E+00, -.10359700E+00, -.97223000E-02, -.47947200E+00, -.49001200E+00, -.18916700E+00, 0.88403700E-01, -.91238300E-01, -.10436100E+00, 0.11365000E+02, 0.20426800E+01, -.21666600E+01, -.51962600E+01, -.25233800E+01, 0.21392600E+01, -.33778300E+01, 0.34953100E+00, -.18861300E+01, -.10339100E+01, 0.14497900E+01, 0.55378500E+00, 0.19970600E+01, -.15939300E+01, -.18792400E-01, -.17392800E+00, 0.41796100E+00, -.15761400E+00, -.14333300E-01, -.36728700E-01, 0.54380300E-01, -.96403500E-01, 0.12929100E+02, -.22377400E+02, 0.25469500E+01, 0.13194800E+01, -.41747200E+01, -.14108700E+01, -.50415100E+01, 0.12543000E+01, -.11193600E+02, 0.30930400E+01, 0.28777100E+01, 0.33530000E+01, 0.21032200E+00, -.63495900E+01, -.13312900E+00, 0.27847000E+01, -.28638800E+00, 0.21373700E+00, 0.18358300E+01, -.16448700E+01, 0.11748900E+01, 0.28329400E+00, 0.16829100E+00, -.52155600E+00, -.13701000E+00, 0.64513600E-01, 0.96137100E-01, -.81003100E-01, -.30842600E+01, -.90891900E-01, 0.98657600E-01, -.10968600E+00, 0.86067100E-01, -.12839300E+00, -.30336000E+01, -.38793200E-01, 0.80420600E-01, -.34099700E+01, 0.26564300E+01, 0.18318200E+00, 0.83918800E-01, 0.11049500E+01, -.63728200E+00, -.40594000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17167800E+01, 0.16162400E+00, -.92217000E+00, -.11076300E+01, -.79083500E+00, -.36508400E+00, 0.12068000E+01, 0.24968300E+01, 0.20367800E+00, -.66750000E+00, -.84766400E+00, -.20533500E+01, 0.24264600E-01, -.26572100E+01, -.22224100E+01, -.30916800E+00, -.60370000E-01, -.61339500E-01, -.99878400E+00, -.14899300E+01, -.78336500E+00, 0.55735700E+00, 0.10573300E+01, -.34542900E+00, 0.20563400E+00, 0.81400000E+00, -.24376900E+00, 0.11332400E+01, 0.40900900E+00, 0.98220900E+00, -.51725900E+00, 0.10687400E+00, 0.50949400E+00, 0.26736800E+01, -.37720600E+00, -.98832400E-01, -.50952200E+00, 0.22627600E+00, -.10128400E+01, -.29637600E+00, 0.61014300E+00, -.27834200E+00, 0.52205700E+00, 0.13826300E+00, -.23459500E+00, 0.15770700E+00, -.15901000E+00, -.13427700E+01, -.23293500E+00, 0.49592100E-01, -.21015500E-01, 0.58831700E-01, -.57536300E-01, 0.20425900E+00, -.62483300E+00, -.12464900E+00, 0.75327300E-01, 0.23143700E-01, 0.35017400E-01, 0.20024000E+00, -.17623700E+00, 0.11351700E+00, 0.17593100E+00, 0.49687900E+00, -.82301400E-02, -.74897900E-01, 0.18049000E+00, 0.27327400E+00, 0.13488800E+00, 0.31006300E+00, -.37215100E+00, 0.14610600E+00, -.31263000E+00, 0.11022500E+00, 0.37305000E+00, -.26810500E-01, -.21743100E+00, 0.23412800E+00, -.35992500E+00, 0.26098700E+00, 0.94622700E-03, 0.36948700E-01, 0.33154100E+00, -.13657500E-02, 0.11206700E+00, -.33157600E+00, 0.37062900E+00, -.57565300E+00, 0.23805800E+00, -.36256100E+00, -.35639500E+00, -.10650000E+01, -.97730400E-01, 0.75598800E+00, -.43758200E+00, -.79431000E+00, 0.25101500E+01, -.79120400E+00, 0.54475900E+00, 0.22796600E+00, 0.84316500E+00, -.37709300E+00, -.35268600E+00, 0.88247500E-01, -.19720000E+00, -.67094100E+00, -.76351500E+00, -.13617700E+02, 0.67486500E+01, 0.38084300E+01, 0.83824900E+01, -.11852600E+02, 0.22650500E+01, -.54436300E+01, 0.75869800E+01, 0.67589600E+00, 0.24083200E+01, 0.26516900E+01, -.56922100E+00, 0.19072100E+01, 0.28321500E-01, 0.69200900E+00, 0.47118200E+00, -.41053600E+00, 0.84251800E-02, 0.13968900E+00, 0.22703300E+00, 0.32431200E-01, 0.26641200E+02, 0.11825300E+02, 0.15091100E+00, 0.53065600E+00, -.12471600E+02, 0.76137700E+01, -.45589600E+01, -.19576800E+01, -.49708500E+01, -.14093000E+01, 0.97104300E+01, 0.55714100E+01, -.17136700E+01, -.45060100E+01, -.28085300E+01, 0.27813600E+01, -.35471200E+01, 0.31660200E+01, -.72811800E-01, -.58588400E+01, 0.26682000E+01, 0.11729800E+01, 0.37501700E+01, -.49735900E+00, 0.90037600E+00, -.31745500E+00, -.20553400E+00, 0.26257100E+00, 0.60044300E+01, 0.70012800E+00, 0.88612100E+00, 0.52735100E+00, -.25882000E+00, -.49405600E+00, 0.56116900E+01, 0.65336900E+00, 0.83927900E+00, 0.60635100E+01, -.56914300E+00, 0.17487400E+01, -.13323500E+00, 0.14997800E+01, -.32985700E+01, 0.75997900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14368800E+02, 0.45710400E+00, -.14890800E+02, -.84755100E+01, -.56956100E+01, -.59291400E+01, 0.49811700E+01, 0.13474700E+02, -.31101200E+01, -.76729000E+00, -.24131100E+01, -.99299000E+01, 0.75535300E+00, -.94254300E+01, -.75058600E+01, 0.37340500E+01, 0.47820400E+00, -.19798000E+01, -.48242700E+01, 0.11309500E+02, -.10692000E+02, -.26876000E+01, -.14623800E+01, 0.20379200E+01, -.54406900E+00, -.25182400E+01, -.15448500E+01, -.19107200E+01, -.46479300E+00, -.12203300E+01, -.64512700E+00, 0.27522300E+01, 0.48752200E+00, 0.19537700E+02, 0.16378800E+01, 0.99565800E-02, -.13369100E+01, 0.15771300E+01, 0.61650100E+00, -.70742100E+00, -.52296400E+01, -.71385200E+00, -.17705400E+01, -.13741700E+00, -.99716400E-01, -.27902400E+01, 0.46109100E+00, 0.71479900E+00, -.31979000E-01, -.82677000E+01, 0.72533700E+00, -.14023600E+01, -.13052300E+01, 0.45817100E+00, 0.34875800E+01, 0.15684400E+00, -.86100700E+00, 0.17273300E-01, -.33277000E+01, -.26738900E+01, 0.51809300E+01, -.75283600E+00, 0.54872400E+01, -.34558200E+01, 0.29485400E+01, 0.56282600E+00, -.13234700E+01, 0.21040000E+01, 0.30137800E+01, -.52997800E+01, 0.47558700E+01, -.10085300E+02, 0.61893900E+01, 0.74062000E+00, -.10218400E+01, 0.35467200E+01, -.31235800E+01, 0.53500800E+00, 0.29486300E+01, -.39577300E+00, -.49942600E+01, 0.16933300E+01, -.44156100E+01, -.20006300E+01, 0.13931000E+01, -.51816700E+01, -.19239100E+00, 0.92433500E+00, 0.20373900E+01, 0.51298300E+00, -.12733100E+01, 0.80830500E+00, -.16898300E+00, 0.15266700E+01, -.31500200E+01, 0.49293600E+00, 0.15636300E+02, -.55513600E+01, 0.19954300E+01, -.12511300E+01, 0.60382100E+01, -.60952300E+01, -.49560200E+00, -.20552100E+01, 0.32034300E+00, 0.32495100E+01, -.19724400E+01, 0.22533600E+01, -.32468100E+02, -.33048300E+01, -.15538700E+02, 0.60016700E+01, -.26296300E+02, 0.39856100E+01, -.37124600E+02, 0.78263400E+01, -.11147300E+02, -.18761200E+02, -.33633200E+00, 0.47218500E+01, -.30632000E+00, -.54542700E+01, -.15979400E+01, -.58604900E+00, 0.17439900E+00, -.30590200E+00, -.21169000E+00, -.80766500E+00, -.10739700E+03, -.14763100E+02, 0.27873700E+02, 0.57590900E+01, 0.30749200E+02, -.19958200E+02, 0.13464500E+02, 0.77912200E+01, -.27009200E+02, 0.81555900E+02, -.51272900E+02, -.93567900E+01, 0.11489000E+02, 0.53776000E+01, 0.27275800E+02, -.13122100E+02, -.12231700E+02, -.36618300E+02, 0.12625400E+02, -.41869100E+01, -.22302900E+01, -.50535200E+01, -.12379800E+02, 0.36035600E+01, -.40228100E+01, 0.26543700E+01, 0.32088400E+01, -.36607400E+01, 0.12648100E+02, -.36566000E+01, -.31477900E+01, -.37081800E+01, 0.36399300E+01, 0.28259600E+01, 0.12866900E+02, -.40228900E+01, -.31295400E+01, 0.12165800E+02, -.70785600E+01, -.58729100E+01, 0.39994800E+01, -.14562600E+01, 0.28575200E+02, -.19985000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.58851800E+01, 0.91758800E-01, -.60784100E+01, -.41205800E+01, -.31652800E+01, -.22531000E+01, 0.65798400E+01, 0.69214000E+01, 0.28168300E+00, -.41091600E+01, -.20999800E+01, -.53628600E+01, -.61534400E+00, -.51383400E+01, -.32748000E+01, -.68046700E+01, -.40953200E+00, -.21950600E+00, -.36056900E+01, -.12478900E+01, -.21304900E+01, -.14764100E+01, 0.46814700E+00, -.53533700E+00, 0.73015800E+00, 0.17509500E+01, -.17457300E+01, 0.11792300E+01, 0.27367400E+00, 0.18633100E+00, -.13981400E+00, 0.72610500E+00, 0.20018500E+00, -.19498400E+01, -.29639400E+00, 0.15871500E+00, -.12939900E+01, 0.40588100E+00, -.26395400E+00, 0.62364200E+00, -.13364200E+01, 0.33819800E+00, -.20078400E+00, -.20551700E+00, -.72486100E-02, -.57241300E+00, -.15921100E+00, -.84785900E+00, 0.41917900E-01, -.19412100E+01, -.33126100E+00, -.24125100E+00, -.30032000E+00, 0.18168500E+01, -.65262800E+00, -.76939600E-01, -.52184500E-01, 0.28682700E+00, -.16729500E+01, -.62025000E+00, 0.13439200E+01, 0.19943300E+00, 0.79036000E+01, -.10677800E+01, -.15499800E+01, 0.39393500E+00, -.29286900E+00, 0.32145200E+00, 0.97815100E+00, -.19511700E+01, 0.12842900E+01, 0.35418200E+00, -.66706000E+00, 0.34458000E+00, 0.10585400E+01, 0.96881700E+00, -.70210700E-01, -.11300100E+01, -.46686400E+00, 0.90478400E+00, 0.16465800E+00, 0.27828800E+00, -.14393200E+01, -.49111000E+00, -.32734300E+00, -.56228200E+00, 0.73009900E+00, 0.34714200E+01, 0.42064600E-01, -.82352800E+00, 0.42606200E+00, 0.85414200E+00, 0.74108600E+00, 0.58515200E+00, -.16343700E+01, 0.10018900E+01, 0.43115700E+01, -.26667900E+01, 0.64615700E+00, -.38766000E+00, 0.27563400E+01, 0.13386100E+01, 0.31022300E+00, -.33401800E+00, -.38329300E+00, -.14303600E+01, -.77669800E+00, 0.11535000E+01, -.99283200E-01, 0.14964600E+02, 0.34456500E+00, -.30283000E+01, 0.58647500E+01, -.13127900E+02, 0.31585300E+00, -.36424200E+01, 0.63768300E+01, 0.92496400E+01, -.19873300E+01, -.19655200E+01, 0.73471800E-01, -.16583200E+01, 0.31693100E+00, 0.12936200E+00, 0.10052900E+00, 0.65576900E+00, 0.17481300E+00, -.91834800E-01, -.41555900E+02, 0.34935300E+02, 0.76284900E+01, 0.85222200E+01, -.60792200E+01, -.14349400E+02, 0.10150500E+02, 0.78328500E+01, 0.20189900E+02, 0.15084100E+01, -.72291200E+01, -.12679100E+02, 0.74019100E+01, 0.12494900E+02, 0.15091200E+02, -.14402100E+02, -.38088100E+01, -.21023500E+02, 0.91805700E+01, 0.10581400E+02, -.72517100E+01, -.20571000E+01, -.74754400E+01, 0.11281400E+02, -.12939100E+01, -.11928000E+01, -.95780400E+00, 0.99522200E+00, 0.81211200E+01, 0.12211300E+01, 0.74031800E+00, 0.98599300E+00, -.98289400E+00, -.62560400E+00, 0.73778500E+01, 0.11895100E+01, 0.63873300E+00, 0.87786000E+01, -.23105500E+01, 0.20772700E+01, -.86232100E+00, 0.25644000E+01, 0.37655700E+01, -.61294200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.46653400E+01, 0.43041800E+00, -.33417900E+01, -.27542900E+01, -.21078600E+01, -.16583200E+01, -.28556800E+00, 0.39994800E+01, -.88571900E+00, -.14350300E+01, -.55329800E+00, -.44148200E+01, 0.14444100E+00, -.42024700E+01, -.46019400E+01, 0.46619100E+01, 0.41822300E+00, -.22647500E+00, -.82753900E+00, 0.26854800E+01, -.26257600E+01, 0.49578900E+00, 0.85672800E+00, 0.46681000E+00, -.20653900E+00, -.72866400E+00, -.11027600E+01, 0.75042000E+00, 0.55380600E+00, 0.62521300E+00, -.76254600E+00, 0.88237800E+00, -.38775600E-01, 0.77256300E+01, 0.61458200E+00, -.37072100E+00, -.29016600E+01, 0.62576300E+00, -.12424800E+01, -.76876600E+00, 0.10344700E+01, 0.21756600E+00, -.38628000E+00, 0.14451700E-02, -.11844200E-01, -.91004700E+00, -.13708700E+00, -.17264500E+01, -.83076500E+00, -.53356800E+01, -.86494100E-01, 0.82156800E-01, -.61510900E+00, 0.11372200E+00, -.36495400E+00, -.26243200E+00, 0.16119300E+00, 0.29056300E+00, -.82658200E+00, -.46432500E+00, -.10849200E+00, 0.32391700E+00, 0.30056800E+01, -.47394300E+00, -.22105800E+01, 0.10358700E+00, -.19918300E-01, 0.20548900E+00, 0.42635200E+00, 0.11197300E+00, -.23020700E+00, 0.55149200E+00, -.11874700E+01, -.38860800E+00, -.55308700E+00, -.13557400E+00, -.53196200E-01, -.70696200E-01, 0.22331100E+00, -.39439900E+00, 0.29420300E+00, 0.65927100E-01, -.15176100E+01, -.34777900E+00, 0.24409200E-01, -.16310400E+01, 0.26419900E+00, 0.57331400E+01, -.23706300E+00, 0.31902200E+00, -.85590800E+00, 0.17569900E+00, -.76379200E+00, -.65351300E+00, -.44559500E+00, -.26046600E+01, -.20479800E+01, 0.35682100E+00, 0.84807100E-01, 0.23669800E+00, -.10071500E+01, -.83010800E+00, -.88121800E+00, 0.23666200E+00, -.13079300E+00, -.10179800E+01, -.11274800E+01, 0.10123600E+01, -.11360200E+00, -.22053300E-01, -.15541800E+02, -.47679600E+01, -.82701700E+01, 0.73402800E+01, -.66952000E+01, 0.20976900E+01, 0.24226100E+00, 0.15255400E+01, 0.14479200E+01, 0.60714300E+00, 0.53888200E-01, -.78247600E-01, -.73815700E-01, -.16649200E+00, 0.42206000E-01, 0.40503000E+00, -.28960200E+00, -.30232800E+00, 0.41386100E+02, -.27545700E+02, -.53754100E+01, -.14446700E+01, -.11497500E+02, 0.81948100E+01, -.12048000E+02, 0.17091000E+01, -.26228000E+02, 0.24627100E+02, -.13031200E+02, 0.70606500E+00, 0.50155600E+01, -.82828200E+01, 0.48637000E+01, 0.18802900E+00, 0.39622700E+01, -.36896300E+01, 0.65305600E+01, 0.65209400E+01, -.55694400E+01, -.13518600E+01, -.90342800E+01, 0.55533200E+01, -.60078600E+00, 0.10610500E+01, 0.66801400E+00, -.71948300E+00, -.12285800E+02, -.18520300E+01, -.11520100E+01, -.17798200E-01, 0.72930700E+00, 0.48434500E+00, -.11757600E+02, 0.69508000E-01, -.24893700E+01, -.12789100E+02, -.34249100E-01, -.28476700E+00, 0.74403100E+00, 0.20679900E+00, 0.75310300E+01, -.29466500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11783500E+01, -.65675100E-01, -.39371200E+00, 0.83073100E+00, -.90444900E-01, 0.35308400E+00, -.25441100E+00, -.12003100E+01, 0.11234900E+00, -.46727100E+00, 0.14954100E+00, 0.74083700E+00, -.72571400E-01, 0.75266900E+00, 0.65674300E+00, 0.19391200E+00, -.97411100E-01, 0.11698600E+00, 0.37107600E+00, -.78321900E+00, -.80135900E-01, 0.52595400E+00, 0.16907000E+00, -.31834800E+00, -.69642900E-01, -.26461800E+00, 0.44724200E+00, -.99851900E-01, -.19651000E+00, -.10374900E+00, 0.12708000E+00, 0.51449000E+00, 0.41532500E+00, -.19090400E+00, -.28846900E+00, -.32936000E+00, 0.10908200E+00, -.24771700E+00, 0.48714100E+00, 0.44649900E-01, -.70607100E-01, -.14871400E-01, -.10552000E+00, -.90546100E-01, 0.73966400E-01, -.49742300E-01, -.11662900E-01, 0.24041600E+00, 0.17500300E+00, 0.61667200E+00, 0.67088600E-01, -.23476200E-01, 0.13241900E+00, -.20175600E-01, 0.46068000E+00, -.44424200E-02, -.26739000E-01, -.11947700E+00, 0.39597500E+00, 0.36979100E+00, -.27223400E+00, -.10197700E+00, -.20513500E+01, 0.38050700E+00, 0.79541800E+00, 0.38240500E-01, -.78307400E-01, -.60111200E+00, -.83601500E-01, -.31622500E+00, 0.27278900E+00, -.37930500E+00, 0.24000000E+00, -.72205000E-01, 0.64906100E+00, 0.36080000E-02, -.21716100E+00, 0.11321200E+00, -.17902200E+00, -.12117900E-01, -.16449700E+00, -.50484600E-01, 0.45745500E-01, 0.12957700E+00, 0.17985800E-01, -.11553500E+00, -.22984200E+00, -.16717000E+01, -.76035900E-01, 0.88789900E-02, 0.28219600E+00, -.38377500E+00, -.93241200E-01, 0.10144400E+00, 0.34094900E+00, 0.16248100E+00, -.54776300E+00, 0.69949700E+00, -.29979000E+00, 0.18243200E-01, -.32710800E+00, -.29688600E+00, -.70234900E-02, -.99749800E-02, 0.55529300E-01, 0.32657800E+00, 0.19315900E+00, -.34554600E+00, -.27460400E-01, 0.28940500E-01, -.89900100E-01, 0.16518400E+01, -.85283000E+01, 0.61261300E+01, 0.72095200E+00, 0.46552700E+01, -.32970300E+01, -.36148500E+01, 0.15825700E+00, 0.40307900E+01, -.14098400E-01, 0.78734600E+00, 0.63847700E-01, -.17229500E+00, -.13904400E-02, 0.46056200E-01, -.99645000E-01, -.16407100E+00, 0.90650300E+01, -.21576800E+02, -.51801500E+01, -.60026900E+01, 0.34108500E+01, 0.19602200E+01, -.23108900E+01, -.73749800E+01, -.29448700E+01, 0.69000900E+01, -.33552100E+01, -.30697200E+00, 0.14302600E+00, -.15700500E+01, 0.66380400E-01, -.86470400E+00, 0.14206700E+01, 0.30552200E+01, 0.14082100E+01, -.16932200E+01, 0.39238300E+00, 0.54111400E+00, -.42467300E+00, -.14906500E+01, 0.98205600E-01, 0.11613500E+01, 0.80087300E+00, -.81522100E+00, -.35653900E+01, -.92206200E+00, -.11329500E+01, -.62969300E+00, 0.81860200E+00, 0.46576900E+00, -.35322800E+01, -.60230100E+00, -.12885700E+01, -.38945400E+01, 0.84353000E-01, -.39197800E+00, 0.83403600E+00, 0.45097700E+00, 0.19873200E+01, 0.97960000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.86207600E+01, 0.16702000E+00, -.91819900E+01, -.53810900E+01, -.51609000E+01, -.48663200E+01, 0.42653000E+01, 0.42004900E+01, -.17780500E+01, -.24228100E+01, -.13809400E+00, -.49766100E+01, -.95955100E+00, -.29729000E+01, -.14907800E+01, -.61537500E+01, 0.24937800E+00, 0.41707100E+00, -.28802600E+01, 0.10067400E+02, -.23749700E+01, -.74754500E+01, -.22968700E+01, 0.19376300E+01, 0.21984500E+01, -.13921400E+01, -.38035300E+01, -.62677400E+01, -.39709300E+00, -.70143600E+00, -.52436000E+01, 0.83725700E+00, -.15281000E+01, -.20485100E+01, 0.88755000E+00, -.28394800E+00, -.63439600E+01, -.63491000E+00, -.53973300E+00, -.14792600E+01, 0.66045500E+00, 0.17231900E+01, -.12883100E+01, -.75540200E+00, 0.32796000E+00, -.16830100E+01, -.14949500E+00, 0.23990100E+01, -.15754900E+01, -.67444100E+01, -.59104600E+00, 0.26296100E+00, -.10204900E+01, 0.30572800E+00, -.73509900E+00, -.36881700E+00, 0.19715900E+00, 0.67418700E+00, -.25746900E+01, -.16650400E+01, 0.14892500E+01, 0.89045900E+00, 0.13148400E+02, -.19467700E+01, -.51320400E+01, 0.54559500E+00, -.35762300E+00, -.12525000E+01, 0.13238100E+01, -.92195900E+00, -.34194100E+00, 0.17346900E+01, -.31804100E+01, 0.57704800E-01, -.11292800E+01, -.26150200E+00, 0.32312500E+00, -.54458600E+00, 0.20980400E+01, -.73680000E+00, -.19710300E+00, 0.32128200E-01, -.42735300E+01, -.63359700E+00, 0.20148100E+00, -.17560200E+01, 0.19308400E+00, -.16093400E+01, 0.14563900E+00, -.20233600E+01, 0.17095000E+01, -.60741200E+00, -.21948000E+00, 0.32439000E+01, 0.21418900E+00, 0.42734900E+00, 0.41878500E+00, -.33230600E+01, 0.21281200E+01, -.18856400E+00, -.27107300E+01, 0.21454100E+01, 0.27608500E+01, 0.27374100E+00, 0.60564200E+00, -.37293500E+01, -.43140100E+01, 0.31356900E+01, 0.13953200E+00, 0.11896600E+00, -.12579200E+00, -.59454300E+01, -.92492500E+02, 0.50143900E+02, -.11952700E+02, 0.40785600E+02, -.22685500E+02, -.29635300E+02, -.30726200E+01, 0.33414200E+02, -.63309900E-01, 0.75928000E+00, 0.64593000E-01, -.73050600E+00, 0.69507200E-01, 0.13336500E+01, -.92643400E+00, -.12317400E+01, 0.79019900E+02, -.24331300E+03, -.57767900E+02, -.72836200E+02, 0.50000300E+02, 0.99264600E+01, 0.37269500E+01, -.76328200E+02, -.17499800E+02, 0.68525600E+02, -.48412600E+02, -.19170200E+02, 0.11975100E+02, -.90269500E+01, 0.12047300E+02, -.17192700E+02, 0.16140400E+02, -.81707600E+01, 0.17140000E+02, 0.81250000E+01, -.88520700E+01, 0.18705100E+01, -.14706800E+02, -.52283400E+00, -.22563800E+01, 0.92257100E+01, 0.65395400E+01, -.67642400E+01, -.21667800E+02, -.84467700E+01, -.10436100E+02, -.46012200E+01, 0.67943300E+01, 0.37367100E+01, -.20653700E+02, -.46751300E+01, -.10880900E+02, -.24650800E+02, -.39371500E+01, -.43105000E+01, 0.70153900E+01, 0.15195300E+01, 0.25390300E+02, 0.21493200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.71679300E+01, 0.25306700E+00, -.69299500E+01, -.39969600E+01, -.22500600E+01, -.26922700E+01, 0.24475600E+01, 0.61732400E+01, -.18051900E+01, 0.10497500E+00, -.10647500E+01, -.49705600E+01, 0.37067200E+00, -.37199600E+01, -.46247600E+01, 0.30101200E+01, 0.36938000E+00, -.59052100E+00, -.18498800E+01, 0.36345000E+01, -.57898600E+00, -.13066700E+01, -.34116200E+00, 0.32622900E+00, -.16509200E+00, 0.47691900E+00, -.25515300E+01, 0.13839600E+01, 0.32036600E+00, 0.23824600E-01, -.41776900E+00, -.63680600E+00, -.13320100E+01, 0.21284400E+01, 0.51201600E+00, 0.31946400E+00, -.19051000E+01, 0.36370800E+00, -.51210000E+00, 0.31454800E-01, -.55288700E+00, 0.60041300E+00, 0.14696600E+00, 0.10783600E+00, 0.42291600E+00, -.47554400E+00, 0.15886900E+00, -.13911100E+01, -.19098900E+00, -.29691300E+01, -.48022800E-01, -.31604500E-01, -.39620100E+00, 0.89426200E-01, -.39460500E+00, 0.72780200E-02, 0.86275300E+00, 0.23284200E+00, -.14218400E+01, -.81745800E+00, -.78790600E+00, -.10254000E+00, 0.50281300E+01, -.15067700E+01, -.31892800E+01, 0.14661500E+00, -.19924200E+00, 0.61121600E+00, 0.60669300E+00, 0.40631100E+00, -.64494800E+00, 0.94507500E-01, 0.87255100E+00, 0.19348500E+01, -.32710400E+01, -.55743600E+00, 0.20695600E+00, 0.41954100E+00, 0.43505800E+00, -.26540900E+00, 0.86102500E+00, -.69373700E+00, 0.33850400E+01, 0.16817900E-01, 0.12194200E+01, -.31458500E+01, 0.65861400E+00, -.49153400E+01, -.95639900E-01, -.93505100E+00, -.26170600E+01, -.49053500E+01, -.15755500E+00, -.77774400E+00, -.51789400E+00, -.30057000E+01, 0.22263000E+01, -.69202900E+01, 0.26541500E+01, 0.60395500E-01, 0.44128600E+01, -.57004800E+00, -.13603300E+01, -.10175400E+01, -.27762200E+00, 0.29326000E+01, -.14924300E+01, 0.19050500E+01, 0.18688300E+00, 0.38313300E+00, -.65688600E-01, -.30932600E+01, -.32381100E+00, 0.38314300E+02, -.14960600E+02, 0.14197700E+02, -.25830200E+02, -.40274900E+00, -.47492800E+00, 0.11531100E+02, -.19991100E+01, 0.24078600E+01, -.64021500E+00, -.74321900E+00, 0.87886100E-01, 0.50125300E-01, -.58863400E+00, -.55778100E+00, 0.11224500E+03, -.86900200E+01, -.91204800E+01, -.17140200E+02, -.70204300E+01, 0.30703900E+02, -.26641200E+02, -.12879100E+02, -.13017600E+02, 0.23841100E+02, -.85671000E+01, 0.44659100E+01, -.18684900E+02, -.12959600E+02, -.20819400E+02, 0.24487500E+01, 0.11827100E+02, 0.23165100E+02, -.70710700E+01, 0.64646000E+01, -.24036800E+01, 0.59452200E+01, -.29702200E+01, 0.78276900E+01, 0.24839800E+01, 0.55381700E+01, 0.33182600E+01, -.34808500E+01, -.25283100E+01, -.65669900E+01, -.62730400E+01, -.32502900E+01, 0.34941200E+01, 0.15123600E+01, -.20874200E+01, -.35816000E+01, -.52289200E+01, -.35981900E+01, -.25661900E+01, -.51321000E+01, 0.35815900E+01, -.35971500E+01, 0.19171000E+01, 0.84070800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49828900E+01, 0.16558700E+00, -.41663000E+01, -.32735800E+01, -.20134500E+01, -.14417600E+01, 0.50746100E+01, 0.71079700E+01, 0.64460700E+00, -.10021600E+01, -.22249400E+01, -.46547800E+01, 0.17868900E+00, -.59224000E+01, -.38899800E+01, -.45977500E+01, -.37594800E+00, -.83450300E+00, -.35600500E+01, -.18424200E+01, -.38595700E+01, 0.56425100E+00, 0.12346600E+01, -.34367100E+00, 0.33483600E+00, 0.13237000E+01, 0.24181600E+00, 0.10310900E+01, 0.51525900E+00, 0.11679500E+01, -.10196000E+01, 0.11229600E+01, 0.13162100E+01, 0.73211500E+01, -.12370800E+01, 0.36431500E+00, 0.21469200E+01, 0.27104000E+00, -.61914400E+00, 0.45774600E-01, -.19604900E+01, -.10126400E+01, 0.37755700E+00, 0.21411200E+00, -.35140300E+00, 0.70705400E-01, 0.15399800E+00, -.95896600E+00, 0.96591400E+00, 0.56190100E+01, 0.54766900E+00, -.52123200E+00, 0.29401500E+00, 0.69525000E+00, 0.43004200E+01, 0.21467900E+00, -.19411900E+00, -.41506200E+00, 0.30109000E+00, -.89069300E+00, -.28120000E-01, -.42841800E+00, -.16158700E+01, -.11150700E+01, 0.18335200E+00, 0.21613800E+00, -.62613200E+00, 0.41789200E+00, 0.20620500E+00, 0.72400200E+00, 0.70495800E+00, -.32785000E+01, 0.18508700E+01, 0.78024900E+00, -.81759000E+00, 0.33026800E+00, -.11227700E+01, 0.95936000E+00, -.85268100E-01, 0.65405000E+00, -.86481400E+00, 0.56011400E+00, 0.13257200E+01, -.75343300E+00, 0.70957600E+00, -.17144700E+01, 0.12168100E+01, -.71679500E+01, 0.88084100E+00, -.23866100E+00, -.88584900E+00, -.16484000E+01, 0.48766200E+00, 0.65517000E+00, -.98471000E+00, 0.11208200E+01, 0.30478800E+01, -.35326100E+01, 0.19655300E+01, -.16803800E+00, 0.29623700E+01, -.17625400E+01, 0.34689100E+00, -.88460600E+00, 0.60485900E+00, 0.16666600E+01, 0.21540900E+00, -.44499100E+00, 0.20501700E+00, 0.67118900E+00, -.10357300E+01, 0.73189000E-01, 0.22902100E+00, 0.28797300E+00, 0.13439100E+02, -.46115900E+01, 0.10002000E+02, 0.24472500E+01, 0.64318200E+01, -.30443000E+01, 0.61088300E+00, -.23170800E+01, -.74474100E+00, 0.18489600E+00, 0.15875900E-02, 0.14848900E+00, 0.36800000E+00, 0.70274400E+00, 0.97360500E+01, 0.22534400E+02, 0.19825000E+01, 0.16319000E+02, -.22509700E+02, 0.34946000E+01, -.11844300E+02, 0.19253600E+02, -.11506900E+02, -.13573300E+02, 0.57067400E+01, 0.82327100E+01, -.52534900E+00, -.35833700E+01, -.17521000E+01, 0.85092900E+01, 0.15417300E+01, -.11083500E+02, -.31111800E+01, -.26293100E+01, -.13084100E+01, 0.59724500E+00, 0.19142500E+01, 0.15155500E+01, 0.97268400E+00, -.26025300E+01, -.11237800E+01, 0.10599600E+01, 0.25598400E+01, 0.14258900E+01, 0.32163500E+01, 0.17866900E+01, -.10853900E+01, 0.10960800E+01, 0.30071300E+01, 0.16724700E+01, 0.14493800E+01, 0.29183600E+01, 0.36686700E-02, 0.15036700E+01, -.10868300E+01, 0.40377300E-01, -.34524000E+01, 0.35984200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.89096500E+00, 0.15780400E-01, -.19283700E+01, -.46695800E+00, -.73513800E-01, -.32324100E+00, 0.74086800E+00, 0.89792000E+00, -.44584200E-01, -.63773800E-01, -.27273100E+00, -.68913700E+00, 0.11738600E+00, -.78474700E+00, -.87142900E+00, 0.14297200E+00, -.52514900E-01, -.83867000E-01, -.32993700E+00, -.17419500E+00, -.41533000E-01, 0.82217200E-01, 0.99667900E-01, -.13537600E+00, -.34935500E-02, -.23462200E-02, -.30717200E-01, 0.29411300E+00, -.66237300E-01, 0.15753200E-01, -.66437100E-01, 0.18507000E+00, 0.44877300E-01, 0.36423900E+00, -.81804500E-01, -.81607200E-01, -.83622100E-01, 0.18781300E-01, 0.10373400E+00, -.79765000E-02, -.15002000E+00, 0.38941100E-01, 0.15344400E+00, 0.47586800E-01, 0.95770700E-01, 0.50842800E-01, 0.45948700E-01, -.37826400E+00, 0.12236400E+00, 0.91250100E+00, 0.90866000E-01, -.31656600E-01, -.11906000E-01, -.67927200E-02, 0.16279500E+00, 0.46540400E-01, 0.49414500E-01, 0.27286800E-01, -.18849900E-01, -.93616600E-02, 0.44739300E+00, 0.33061500E-01, -.33491900E-01, -.41879000E-01, -.67005100E+00, -.27766800E-01, -.11673000E-01, -.24558100E-01, 0.55129100E-01, 0.34312500E+00, 0.66257100E-01, -.21232900E+00, 0.67757700E+00, 0.23749200E+00, -.23321900E+00, 0.22870200E-01, 0.45177300E-01, -.58737900E-01, -.34523200E+00, 0.19677000E+00, 0.17747800E+00, 0.79223200E-01, -.65915900E-01, -.11807000E-01, 0.36322500E-01, -.87018200E+00, 0.18592500E+00, -.20045700E+01, 0.17891400E-01, 0.23069500E+00, -.19475000E+00, -.78452200E-01, -.33542600E-01, 0.42746200E-01, 0.64071000E-01, -.57687900E-01, 0.47731200E+00, 0.21388500E+00, -.74796900E-01, -.20971600E-03, -.15421800E+00, -.42772600E+00, -.35980600E-01, -.31632500E-01, 0.79708700E-02, -.23419000E-01, -.31180200E+00, 0.16466400E+00, 0.86921700E-03, -.35430600E-01, 0.52560500E-01, 0.44239600E+00, 0.42718700E-01, -.84747200E-02, -.10359800E+00, -.23591200E+01, 0.17437700E+01, 0.10405200E+01, 0.24989900E+01, -.21904600E+01, 0.85378300E-02, -.12311100E+01, -.11259800E+00, 0.15110300E-01, 0.14497700E+00, 0.56826000E-01, 0.25226900E-01, 0.74952400E-01, -.72939200E+01, -.12797800E+01, 0.18581500E+01, 0.27452900E+01, 0.57545300E+00, -.38126400E+01, -.10893200E+01, 0.31989900E+01, 0.56800200E+01, -.55201700E+01, -.78022200E+00, -.15714900E+01, 0.28018300E+00, 0.19101500E+01, 0.16430500E+01, -.14426700E+01, -.23499400E+01, -.47756500E+01, -.16607600E+00, -.43842000E+00, 0.85906900E+00, -.27246400E+00, -.31580300E+00, 0.23550500E+00, -.50693600E+00, -.40088800E+00, -.42476500E-01, 0.38793200E-01, 0.62112600E+00, 0.17467900E+00, 0.46570900E+00, 0.31990500E+00, -.34377300E-01, 0.69289100E-01, 0.72699300E+00, 0.36292800E+00, 0.37180600E+00, 0.65146000E+00, -.41241200E+00, -.18392300E+00, 0.25034700E-01, -.55231200E-02, -.46907100E+00, -.22467300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10253500E+01, -.17565100E-01, 0.23089600E+01, 0.58458200E+00, 0.37182500E-01, 0.37832800E+00, -.98278200E+00, -.11282500E+01, 0.10596900E+00, 0.19160500E+00, 0.36307300E+00, 0.91568300E+00, -.64548300E-01, 0.91376000E+00, 0.94681900E+00, -.18146900E-01, 0.25992100E-01, 0.12941100E+00, 0.46836300E+00, 0.37255100E+00, 0.44443800E-01, -.12395900E+00, -.20582400E+00, 0.18617100E+00, -.31368500E-01, -.27948000E+00, 0.16035500E+00, -.38121700E+00, -.65667000E-02, -.63454000E-01, 0.25281200E-02, -.12277100E+00, 0.83086100E-01, -.32259600E+00, 0.20971000E+00, 0.95924600E-01, 0.14255000E+00, 0.35959000E-01, 0.91797900E-02, -.52212800E-01, 0.13890900E+00, -.22947800E-01, -.25165100E+00, -.33055900E-01, -.16310100E+00, -.11015800E-01, -.19474600E-01, 0.42518600E+00, -.21552500E-01, -.23934300E+00, -.12352900E+00, -.49614000E-01, 0.49791400E-01, 0.99038000E-01, -.14767100E+00, -.36992000E-01, 0.81420200E-02, -.46314000E-02, -.21531900E-01, -.10702300E+00, 0.22333700E+00, 0.30699600E-01, -.31360000E-01, -.75837000E-01, 0.20708500E+00, -.43721000E-02, -.16822600E-01, 0.81661600E-01, -.10368100E+00, -.26578300E-01, -.10968400E-01, 0.72422600E-01, 0.12719700E+00, -.11502400E+00, 0.11797000E+00, 0.84978200E-01, 0.31981600E-01, -.92387700E-01, 0.50257000E-01, 0.18328400E-01, -.12720300E+00, 0.31848200E-01, -.44684200E+00, -.30471500E-01, -.82924200E-01, 0.61043500E-01, -.73179000E-01, 0.15975000E+01, -.85647200E-01, -.99701700E-02, 0.25354300E+00, 0.65321200E+00, 0.31155800E-01, 0.21504500E+00, -.62321800E-01, 0.20654100E+00, 0.78079200E-01, 0.64500800E-01, -.35236400E-02, -.21935000E-01, -.29323500E+00, 0.16557100E+00, 0.17547100E+00, 0.44392800E-01, 0.26873500E-01, -.37715600E+00, -.12500400E+00, 0.27120800E-01, -.42035800E-01, -.22863500E-01, -.51874400E-01, 0.30752900E-01, 0.49583600E-01, -.75724400E-01, -.22513400E+00, 0.81227900E+00, 0.14140100E+01, -.39220900E+00, -.74348200E+00, -.21618000E-01, -.59991500E-01, 0.33760100E+00, -.20568200E+00, 0.47415900E-01, -.16134600E+00, -.52123500E-01, 0.43494800E-01, 0.13544800E-01, 0.54281900E+01, 0.83833000E+01, 0.65425400E+00, 0.21974800E+01, -.52904000E+01, 0.33671700E+01, -.50206500E+00, 0.35203600E+01, -.88757800E+01, 0.72701500E+01, -.94283100E+00, 0.27874100E+01, -.88761200E+00, -.29646400E+01, -.80666500E+00, 0.25651700E+01, 0.47039500E+00, 0.49189200E+00, -.44012600E+00, 0.92757100E-01, -.30512400E+00, -.25844200E+00, -.14810800E+00, 0.89441700E+00, 0.17333500E+00, -.19386600E+00, -.31403500E+00, 0.26236900E+00, 0.20067200E+00, 0.31207200E+00, 0.35717500E+00, 0.54766000E-01, -.27142200E+00, 0.15258500E+00, 0.37548100E+00, -.19162700E-01, 0.88792500E-01, 0.31613800E+00, 0.43851800E+00, 0.40068400E+00, -.35130900E+00, -.82142700E-01, 0.57093700E+00, -.43759300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17664500E+01, -.15699600E+00, -.50590900E+00, 0.89932000E+00, -.71485200E-02, 0.35896400E+00, 0.29258100E+00, -.21555800E+01, 0.41594000E+00, -.22012900E+01, 0.26964700E+00, 0.10501500E+01, -.45570400E+00, 0.11580800E+01, 0.38946100E+00, -.15999300E+01, -.23129200E+00, 0.82942100E+00, 0.23681800E+00, -.27435700E+00, -.59763800E+00, 0.60891900E+00, 0.30666700E+00, -.34872300E+00, -.14311200E+00, -.34985600E+00, -.55866900E+00, 0.34708600E+00, 0.15155200E+00, -.51233000E-01, -.25320500E+00, 0.61535300E+00, -.62335600E-01, -.15290000E+01, -.34026700E+00, -.36403600E+00, -.92531100E+00, -.38406600E+00, 0.57587100E-02, -.51829300E+00, 0.42090200E+00, 0.40064100E-01, 0.34325200E+00, -.27468300E-01, 0.18977800E+00, 0.23818500E-01, -.11043800E+00, -.10377800E+01, 0.72085800E-01, 0.21197200E+01, 0.23687600E+00, -.13746100E-01, 0.18017300E+00, -.63644700E-01, 0.60937400E-01, 0.90557900E-02, 0.26825000E-01, -.23274100E+00, 0.61232500E+00, 0.78585200E+00, -.86184200E+00, -.64059000E-01, -.18823300E+01, 0.91187900E+00, 0.10968700E+01, 0.10922300E+00, -.74013300E-01, -.95477800E+00, -.21690300E-01, 0.39133400E+00, 0.63901900E-01, -.44421500E+00, 0.24471500E+00, 0.32031700E+00, -.31308100E+00, -.94253700E-01, -.38143000E+00, 0.55007500E+00, -.25177800E+00, 0.29875000E+00, -.65424300E+00, 0.18140200E+00, 0.45876900E+00, 0.11143500E+00, 0.17508900E-01, -.11691300E+00, -.29268600E+00, 0.14438700E+01, -.67503800E-01, 0.36086000E+00, -.14071200E+00, 0.91145000E-02, -.22524000E+00, 0.29217600E+00, 0.23163300E+00, -.42658200E+00, -.35205800E+00, 0.67379300E+00, -.87753600E-01, 0.12190300E+00, -.30531700E+00, -.93494000E+00, -.46323600E+00, 0.11265400E+00, 0.23569700E-01, -.24298100E+00, 0.25254400E+00, -.20842600E+00, -.23475000E-01, 0.16384100E-01, -.26859500E-01, 0.97442300E+00, -.53066700E-01, -.79733200E-01, -.50926300E-01, 0.49365900E+00, 0.60035400E+00, 0.32075000E+01, 0.82360500E+00, -.53292000E+00, -.11939300E+00, -.46745800E+00, 0.74215400E-01, 0.19354900E-01, 0.33353100E-01, 0.30892600E-01, 0.99820100E-02, 0.17332300E+00, 0.18066000E+02, -.72041900E+01, -.10576600E+01, -.11882900E+01, -.39443000E+01, 0.23294700E+01, -.34975800E+01, -.44416400E+00, -.10058800E+01, -.19766800E+01, 0.27803900E+01, 0.16293000E+00, 0.22533900E+00, -.10138700E+01, -.25760800E+00, -.10223700E+01, 0.22025900E+01, -.10789700E+01, -.10069100E+01, 0.20282600E+01, -.19667100E+01, 0.62201200E+00, -.14306400E+01, 0.35832100E+01, 0.19990200E+00, -.82739000E-01, -.25024000E-01, 0.48436400E-01, 0.72976100E+00, -.18217800E+00, -.10369000E+00, 0.49866100E+00, -.48766500E-01, -.71862000E-01, 0.64857300E+00, 0.54209800E+00, -.15780900E+00, 0.53643000E+00, -.17307800E+00, 0.21809100E+00, 0.27002600E-01, 0.73021700E-02, -.66264200E+00, -.89897100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.22348300E+01, 0.14669200E+00, -.44838900E+01, -.82949300E+00, 0.19103800E-01, -.46086000E+00, 0.16378400E+01, 0.27632800E+01, 0.65238800E+00, -.91878400E+00, -.72251500E+00, -.21117800E+01, 0.57091300E-01, -.30387100E+01, -.19374200E+01, -.61916300E+00, -.19553200E+00, -.49669600E+00, -.92251300E+00, -.24777300E+01, -.87524400E+00, 0.26946600E+00, 0.52413700E+00, -.81876000E+00, 0.19189700E+00, 0.13115100E+01, 0.64990100E-01, 0.47493700E+00, -.96268800E-01, 0.44411700E+00, -.36557000E+00, 0.84772700E+00, 0.91653700E-02, 0.14832700E+01, -.61568600E+00, -.33880300E+00, -.90753300E-01, -.25011600E-01, -.53071800E+00, 0.20693400E+00, -.12755000E+00, -.45729500E-01, 0.77320400E+00, 0.23100000E+00, -.90551100E-01, 0.49374000E+00, -.91630000E-01, -.16641500E+01, 0.90799000E-01, 0.22721600E+01, -.12822500E+00, 0.16042400E+00, 0.24192200E-02, 0.13974800E+00, -.74032000E+00, -.80036800E-01, 0.77700400E-01, 0.51136100E-01, -.54055000E-01, 0.18960700E+00, -.34350100E+00, 0.13790900E+00, 0.18366100E+00, 0.42683300E+00, -.61966300E+00, -.44850600E-01, 0.21193400E+00, 0.14921000E+00, 0.58986900E+00, 0.66691300E+00, -.16111000E+00, -.60410900E+00, 0.11668400E+01, 0.21824700E+00, 0.27224200E+00, 0.32456300E+00, -.18356100E+00, 0.14092500E+00, -.88246800E+00, 0.68045900E+00, -.33416200E+00, 0.42804200E+00, 0.72886700E-01, -.24897500E+00, 0.12699100E+00, -.75197100E+00, 0.63338300E+00, -.29094600E+01, 0.56710600E+00, -.37879900E+00, -.37392300E+00, -.12935600E+01, -.11458600E+00, -.10713400E+00, -.88890500E-01, -.10137100E+01, -.80825600E+00, -.59464100E+00, 0.63625100E+00, 0.16356900E+00, 0.14908500E+00, -.17052100E+01, -.40827000E+00, -.10707100E+00, -.20576800E-01, -.31092300E+00, -.11325000E+01, 0.91957000E+00, 0.12980100E+00, 0.49767200E-01, 0.35100000E+00, -.52864000E+00, 0.12265800E+00, 0.21676200E+00, 0.40150500E+00, -.30384800E+00, -.81273300E+00, -.97975000E+00, -.72298100E+01, -.38748400E+00, 0.92978900E-01, 0.83095600E+00, 0.12142900E+00, 0.13280200E+00, -.60281200E-01, 0.25164100E+00, 0.91369100E-01, 0.13009700E+00, 0.27631900E+02, -.27045300E+02, -.11950200E+02, -.11193900E+02, 0.66524300E+01, 0.79804500E+01, 0.25145500E+01, -.14053700E+02, 0.30456900E+02, -.99561100E+01, -.18755200E+01, -.10553600E+02, 0.22186500E+01, 0.10367800E+02, 0.18744900E+01, -.11745200E+02, -.43812700E+00, 0.31419900E+01, 0.13645000E+01, 0.64258600E+00, -.14366100E+01, 0.11509900E+00, -.42153200E+00, -.47189800E+00, -.42437500E+00, -.66846700E+00, -.87708800E+00, 0.94339400E+00, 0.10635800E+01, 0.11712900E+01, 0.11635400E+01, 0.10348600E+01, -.94098700E+00, -.10002800E+01, 0.51109500E+00, 0.11363100E+01, 0.15762100E+01, 0.30521600E+00, 0.48580800E+00, 0.29230900E-01, -.90595600E+00, 0.34853400E+00, -.11818900E+01, -.11107800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23693300E+01, 0.17712400E+00, 0.10397000E+01, -.16712600E+01, 0.14691700E+00, -.66785300E+00, 0.59376500E+00, 0.20546600E+01, 0.42686000E+00, 0.29465900E+01, -.32662100E+00, -.81866400E+00, 0.56791600E+00, -.95978900E+00, -.78736300E+00, 0.10620400E+01, -.59368700E-01, -.61690500E+00, -.87941700E+00, 0.62945200E-01, 0.60336400E+00, -.82228600E+00, -.11144900E+01, 0.14902400E+00, -.39404700E+00, -.17739400E-01, -.18299700E+00, -.17718300E+00, 0.84824000E-01, -.44240200E+00, -.73759300E+00, 0.58475200E+00, 0.52579000E+00, 0.29036000E+01, 0.27572300E+00, -.14118600E+01, -.19421200E+00, 0.23756900E+00, 0.11443400E+01, 0.13422000E+01, -.17486200E+01, 0.49921900E+00, -.15756400E+01, -.26783500E+00, -.82370500E+00, 0.96561200E-02, 0.12165600E+00, 0.21773400E+01, -.40285100E-01, -.24144500E+01, -.75114200E+00, 0.25292100E+00, -.31717200E+00, -.19620300E+00, -.38941800E+00, -.63102600E-01, 0.25686400E-01, 0.29051800E+00, -.74607200E+00, -.87713900E+00, 0.80955600E+00, 0.22815600E+00, 0.35552000E+01, -.11352600E+01, -.19044100E+01, -.10114800E+00, 0.71738000E-01, 0.43898500E+00, 0.67780000E-01, 0.19070800E+00, -.52293700E+00, 0.12023400E+01, -.11183100E+01, -.60595700E+00, -.18750900E+00, 0.52933700E-02, 0.65037500E+00, -.49759200E+00, 0.38317100E+00, -.25301200E+00, 0.82270000E+00, -.98792500E-01, -.15464300E+00, -.30909400E+00, -.11217200E+00, 0.16334100E+00, 0.74721300E+00, -.58867300E+00, -.43384000E-01, -.13205700E+00, -.36835600E+00, -.11843200E+00, -.54444100E-01, -.54635800E+00, 0.19217800E-01, -.42608500E+00, -.29092100E+01, -.41507300E+00, 0.57359100E+00, 0.15424200E+00, -.12436400E+01, 0.13383300E+01, 0.68841300E+00, 0.28914600E+00, 0.50206000E-01, -.82109200E+00, 0.31565300E+00, -.23767100E+00, -.45482300E-01, 0.10639200E+00, 0.11018300E+00, -.55507600E+00, 0.91017600E-01, -.36699300E-01, 0.40133300E+00, -.18865200E+01, -.52435700E+00, -.11819800E+00, 0.30651700E+00, 0.18543700E+01, -.37714900E+00, -.10816000E+01, -.21500100E+00, 0.51668300E-01, 0.24322200E+00, -.91307800E-01, 0.90937500E-01, -.41997700E-01, -.19221100E+02, 0.32511000E+02, 0.97667700E+01, 0.97708900E+01, -.24297000E+01, -.66591700E+01, -.13118800E+01, 0.10466900E+02, 0.29929000E+01, -.40568600E+01, 0.13156000E+01, 0.15190500E+01, -.29344400E+01, 0.62952500E+00, -.15083000E+01, 0.13127700E+01, -.33891100E+01, -.97154500E+00, -.22361800E+01, -.91148000E+00, 0.25865800E+01, -.12861500E+00, 0.11924600E+01, 0.38130900E+00, -.29411200E+00, -.24457000E+00, -.12845800E-01, 0.11464900E-01, 0.36705000E+01, 0.27672300E+00, 0.44487600E+00, -.17716800E+00, -.34742100E-02, 0.56421000E-01, 0.36566400E+01, -.26067200E+00, 0.55232200E+00, 0.42953900E+01, -.64702600E+00, -.27825700E+00, 0.10502000E+00, -.62901600E+00, -.15245600E+01, 0.17617300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.72361800E+01, 0.26035800E+00, -.68879800E+01, -.40062400E+01, -.22832700E+01, -.27031400E+01, 0.24599800E+01, 0.62892800E+01, -.18091400E+01, 0.15795600E+00, -.11013500E+01, -.50557300E+01, 0.41033900E+00, -.38490900E+01, -.47791900E+01, 0.30897400E+01, 0.37213000E+00, -.61124200E+00, -.18602500E+01, 0.35712100E+01, -.49638400E+00, -.12886300E+01, -.30338500E+00, 0.33435800E+00, -.14429600E+00, 0.48189100E+00, -.25370700E+01, 0.13983300E+01, 0.33517100E+00, 0.46254300E-01, -.47692800E+00, -.67248300E+00, -.13559400E+01, 0.21809800E+01, 0.50844900E+00, 0.34032000E+00, -.18897200E+01, 0.38810600E+00, -.55660600E+00, 0.16350300E-01, -.52629600E+00, 0.60259400E+00, 0.19562200E+00, 0.11734900E+00, 0.43073600E+00, -.45673100E+00, 0.15936300E+00, -.14166000E+01, -.19035000E+00, -.28618400E+01, -.43015000E-01, -.36514200E-01, -.39239100E+00, 0.11265700E+00, -.37543100E+00, 0.11458800E-01, 0.80322100E-01, 0.25606000E+00, -.63084500E+00, -.12950200E+00, -.62691400E+00, 0.14056700E+00, 0.33483900E+01, -.32919000E+00, -.13358400E+01, 0.32658800E-01, -.22008100E-01, 0.53499100E-01, 0.42100300E+00, 0.51651900E+00, -.12614300E+00, -.23432100E-01, 0.13349800E+00, 0.45503600E+00, -.92583000E+00, 0.24096600E+00, 0.17396200E+00, -.32199500E+00, 0.22406100E+00, -.13096600E+00, 0.21506000E+00, -.73337700E-01, -.75052800E+00, -.12148400E+00, 0.26127800E+00, -.16922100E+01, 0.41706100E+00, -.12969300E+01, -.10892900E+00, -.33421900E+00, -.37588000E+00, -.64608400E+00, -.75372100E-01, 0.98649800E-01, -.15808900E+00, -.57540800E+00, -.29942600E+00, -.89076700E+00, 0.56533500E+00, 0.45505600E-01, 0.75258300E+00, -.45056100E+00, -.14452800E+00, -.14793400E+00, 0.17212900E-01, 0.31898200E+00, -.42696200E+00, 0.38277000E+00, 0.25600500E-01, -.13071100E+00, 0.20188000E+00, -.50706700E+00, -.25636600E-01, 0.84899800E-01, 0.99138000E-01, -.78023600E+00, -.11855800E+01, -.46657600E+00, -.27451800E-01, 0.11196100E+00, 0.31507900E+01, -.85713000E+00, -.16501400E+00, -.48177000E-01, -.96922800E-01, 0.55946200E-01, 0.23513000E-01, -.98467500E-01, -.32689800E+01, -.17450900E+01, -.15512200E+00, 0.18440500E+00, 0.37175900E+00, 0.23707000E+00, 0.22137600E+01, 0.43413900E+00, 0.32144000E+01, -.18169900E+01, -.26890600E+01, -.19890500E+01, 0.12793100E+01, 0.25156900E+01, 0.36281300E+01, -.24080400E+01, -.19931800E+01, -.13276600E+01, -.87439200E+00, 0.58244400E+00, -.25627700E+00, -.87931200E+00, -.11667000E+01, 0.13449700E+01, -.68344300E-01, 0.21320000E+00, -.10148600E+00, 0.21095800E-01, 0.11003200E+01, 0.27316100E-01, 0.84501900E-01, 0.27560100E+00, -.26229700E-01, 0.10010800E+00, 0.12190300E+01, 0.32794400E+00, -.64777800E-01, 0.11356500E+01, -.48236400E+00, 0.64784100E-01, 0.51546800E-01, 0.30963800E+00, 0.66951700E+00, -.52532300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22186500E+01, -.70533200E+00, -.12338800E+00, 0.28754600E+00, -.26207500E+00, -.13625100E+00, 0.72161700E+00, -.17646200E+01, 0.71403200E+00, 0.29861200E+00, 0.61017400E+00, 0.15281600E+01, 0.20101600E+00, 0.43378400E+00, 0.46032600E+00, -.18141400E+01, -.86411800E-01, 0.40926300E+00, 0.18282700E+00, 0.12334200E+01, -.17710600E-01, -.84746000E+00, -.41230200E+00, 0.76996700E+00, 0.12197900E+00, 0.87527600E-01, 0.50700100E-02, -.13037900E+01, 0.25917200E+00, -.59351800E-01, -.28491100E+00, -.77094100E+00, -.29354800E+00, -.23906300E+00, 0.17011300E+00, 0.45974500E+00, 0.59999400E+00, -.32408000E+00, -.21948800E+00, 0.13040400E+00, -.36375900E+00, -.11029300E+00, -.35539800E+00, 0.41130400E-01, -.26766100E+00, 0.78189300E-02, -.61128800E-01, 0.55849400E+00, -.29489100E-01, -.75418900E+00, -.19386400E+00, 0.94282500E-01, 0.15157600E+00, -.71955800E-01, -.13514600E+00, -.33693200E-01, -.13635000E-01, 0.12096400E-01, 0.47814000E-01, -.88257600E-01, 0.22562300E+00, 0.11288300E-02, 0.35743100E+00, -.84130000E-01, 0.55346400E-02, -.51144000E-01, 0.55714800E-01, -.86462900E-01, 0.16596400E-01, 0.13762800E+00, -.15807500E+00, 0.17164800E+00, -.23098900E+00, -.22913300E-01, -.16579900E-01, -.50504500E-01, 0.77468100E-01, 0.57276600E-01, -.54745100E-01, 0.99255200E-01, -.15488400E+00, -.26504700E-01, 0.29310600E+00, 0.73853800E-01, 0.65694200E-02, 0.15827200E+00, -.16481300E+00, 0.16464600E+01, 0.16455400E-01, -.70566900E-01, 0.15690700E+00, -.16419800E-01, 0.75350900E-02, -.65787700E-01, -.36942600E-01, -.57622300E-02, -.22812800E+00, -.15288500E+00, 0.87753400E-01, 0.23813800E-01, -.25338600E+00, 0.18548300E+00, 0.36792600E-01, 0.30741900E-01, -.18179700E-01, -.97227600E-01, 0.68912800E-01, -.24479200E-01, -.95003100E-03, 0.20620400E-01, -.67254000E-02, -.49121000E-01, -.14296800E-01, -.15205300E-01, 0.29121000E-01, -.28002000E+00, -.18013600E+00, 0.13907900E+00, -.24698000E-02, -.13818900E-01, -.19689200E-01, 0.39665300E+01, -.39004000E-01, -.18031100E-01, 0.15434800E-01, -.11385400E-01, -.64253900E-02, -.21867800E-01, 0.12164300E+00, 0.19852500E+01, 0.10432100E+01, 0.46031200E+00, -.95240300E+00, -.40228400E+00, -.75132100E+00, 0.75236500E+00, -.64916500E+00, 0.15340400E+01, -.82090300E-01, 0.44903500E+00, -.91218400E+00, -.61228000E+00, -.52878600E+00, 0.42036000E+00, 0.15262300E+00, -.29290600E+00, 0.22496800E+00, -.21094800E-01, 0.18940600E+00, 0.10994200E+00, -.23430300E+00, 0.25096000E+00, -.20376900E+00, 0.61628900E-01, 0.33791500E-02, 0.97774800E-02, -.11709200E+00, 0.13236500E+00, -.10274000E+00, -.48387600E-02, -.78003900E-02, -.34890700E-01, -.87860700E-01, -.35037300E-01, -.14060900E+00, -.77340200E-01, 0.16002500E+00, 0.88017600E-01, 0.15563900E-01, 0.64134300E-01, -.51080400E-01, -.90960600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.88288100E+00, -.47296500E-01, -.24530300E+00, 0.13625400E+00, -.61111000E+00, -.25865600E+00, -.23961000E+00, -.49340800E+00, 0.48693900E-01, -.18520700E+00, 0.43186200E-01, 0.31158600E+00, -.23285100E-01, 0.21508200E+00, 0.33332900E+00, -.94769600E-01, -.51824200E-01, 0.69388300E-01, 0.17194900E+00, -.88707000E-02, -.27886500E+00, 0.94166200E-01, -.68999600E-01, -.15263600E-01, -.20443300E-01, -.22124900E+00, 0.42283900E+00, -.51779700E+00, -.26212800E+00, -.14039500E+00, 0.72347500E-02, 0.52986100E+00, 0.34604000E+00, 0.14321100E+01, -.61435000E-01, -.12110500E+00, 0.17216300E+00, 0.27660000E-01, 0.27553600E+00, 0.48951000E-01, -.27549500E+00, 0.13646500E-01, -.17087300E+00, -.71558400E-01, 0.22007300E-01, -.10278100E+00, 0.90888300E-02, 0.14145200E+00, 0.16236500E-01, 0.67044100E+00, 0.46791300E-01, -.40423000E-01, -.27215300E-01, -.65288600E-01, 0.22932600E-01, 0.14764500E-01, -.49932100E-03, 0.14614800E-01, -.89699900E-03, -.14145000E+00, 0.19180700E+00, 0.20187000E-01, -.28541300E+00, -.13607200E+00, -.17367400E+00, -.80874700E-01, 0.56695500E-01, 0.35628600E+00, -.13034300E+00, 0.11831300E+00, 0.28380900E+00, 0.36180300E-01, -.36595800E-01, -.20384400E-01, 0.48865200E-01, -.24750600E-02, 0.66991100E-02, -.68765800E-02, -.13180500E-02, -.18856700E-02, 0.17813500E-01, -.78628800E-02, -.26396100E-01, -.19088400E-01, -.46589300E-02, -.21379000E-01, 0.99294200E-02, 0.41358500E-01, 0.20597100E-01, -.51167400E-01, 0.14171400E-01, 0.21066300E-01, 0.71015600E-02, -.11378500E-01, 0.14750000E-01, 0.30194100E-01, -.22011300E+00, 0.46024100E-01, 0.73229300E-02, 0.13359800E-01, -.45250500E-01, 0.24683100E-01, 0.37063500E-01, 0.10212500E-01, 0.13270500E-01, -.42001700E-01, 0.72145400E-01, -.48651300E-01, -.63777400E-02, 0.17476900E-01, -.21581000E-01, 0.97341300E-03, 0.79337600E-02, 0.58094400E-02, 0.15033500E-01, 0.31757100E-01, 0.61410800E-01, -.36525900E-01, -.92912000E-02, 0.40856400E-03, -.25540800E-03, 0.62957900E-02, 0.73135500E+00, 0.13744500E-01, 0.47429400E-02, -.76791800E-02, -.10171600E-02, 0.10012400E-01, 0.79202800E+00, -.13208500E+01, -.24310700E+00, -.51377700E+00, 0.42139800E+00, 0.23164500E+00, 0.17411700E+00, -.69436300E+00, 0.61038700E+00, -.79062000E+00, 0.36999500E+00, -.20506800E+00, 0.25226900E+00, 0.24677300E+00, 0.13630700E+00, -.16707100E+00, 0.32127300E-01, 0.31186400E+00, 0.94264400E-01, -.39866300E-01, -.96136800E-02, -.27002400E-01, 0.65980900E-01, -.24048700E+00, -.12892700E-01, 0.42757800E-01, 0.37092600E-01, -.11831200E-01, -.15642300E+00, -.34099300E-01, -.46111400E-02, 0.66540800E-01, 0.13917200E-01, -.19410900E+00, -.18310700E+00, 0.70499700E-01, 0.29198000E-01, -.17362500E+00, 0.77891100E-01, -.63848700E-02, 0.29880000E-01, 0.34315000E-01, -.10959200E+00, 0.39800500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11579400E+01, -.62947900E-01, -.99160500E-01, 0.83642000E+00, 0.66824100E-01, 0.39809400E+00, -.29037800E+00, -.74477900E+00, 0.27140300E+00, -.25426900E+00, 0.24630600E-02, 0.52972600E+00, -.56158300E-01, 0.35391000E+00, 0.53476500E+00, -.93812700E+00, -.13898600E+00, 0.18403200E+00, 0.17213600E+00, -.74852400E+00, 0.28357700E+00, 0.44864600E-01, -.94162300E-01, -.12264800E+00, 0.38312300E-01, 0.20858000E+00, 0.60689100E+00, -.53957900E+00, -.28216500E+00, -.95594200E-01, -.53749800E-02, 0.58610700E+00, 0.50996500E+00, 0.15683900E+01, -.16117700E+00, -.12631000E+00, 0.52386400E+00, -.10670000E-02, 0.21446700E+00, 0.11913900E+00, -.22517500E+00, -.88316200E-01, -.14310200E+00, -.47191900E-01, -.12442900E+00, 0.56947700E-01, -.15311800E-01, 0.40513800E+00, 0.74936900E-01, 0.89375400E+00, 0.16967200E-02, 0.17662900E-01, 0.10336300E-01, -.71772800E-01, 0.13099100E+00, 0.10570800E-01, -.20136300E-01, -.73692000E-02, 0.13643400E-03, -.16237500E+00, 0.29893300E+00, -.12437500E-01, -.67903100E+00, -.15923600E+00, -.11908700E+00, -.66191400E-01, 0.28019200E-01, 0.22715900E+00, -.13820300E+00, -.12092600E+00, 0.98195600E-01, 0.57760600E-01, -.13248400E-01, -.45498000E-01, 0.10084100E+00, -.82977800E-01, 0.61386700E-01, 0.20406800E-01, -.56740400E-02, -.29126100E-01, 0.79563500E-01, -.12281700E-01, 0.13704600E+00, -.70392500E-01, -.37953700E-01, 0.97011000E-01, 0.52372500E-01, -.25386800E+00, 0.95004600E-01, 0.21095900E-01, 0.25916900E-01, 0.12289500E+00, -.43386800E-02, 0.14792300E-01, 0.98275900E-03, 0.34712900E-01, 0.16406900E+00, 0.34025200E-01, -.21541300E-01, -.57430500E-02, -.17522500E-01, 0.29095600E-02, 0.40549500E-01, -.55358500E-02, 0.14060200E-01, 0.35721600E-02, 0.17080100E-01, -.44658100E-01, 0.20917500E-04, 0.18869500E-01, -.40003100E-01, 0.42003800E-01, 0.19037400E-01, -.54335600E-02, 0.58512500E-02, 0.86136600E-01, 0.50622700E-01, 0.18270700E-01, -.48138000E-02, 0.17482700E-01, -.67591400E-03, 0.19770000E-01, 0.52275500E-01, 0.40426900E+00, -.91939200E-02, -.33869500E-02, -.28649700E-02, 0.27928900E-01, 0.64286700E+00, 0.52454200E+00, 0.12719000E+00, 0.27945100E+00, -.44002900E+00, 0.18807900E+00, -.38371000E+00, 0.19001000E+00, -.64444400E+00, 0.39248000E+00, 0.23324000E+00, 0.26253500E+00, -.28435700E-01, -.31583100E+00, -.28917200E+00, 0.13656100E+00, 0.23504100E+00, 0.77392300E-01, 0.11125300E+00, -.34849300E-01, -.10981900E+00, 0.12071800E+00, 0.82868600E-01, 0.11192900E+00, 0.85094800E-01, -.28637300E-01, -.78467600E-02, 0.19538300E-01, -.75061800E-01, -.46536400E-03, 0.21188400E-01, -.41386400E-01, -.19938900E-01, 0.62454900E-02, -.83780200E-01, -.43792100E-01, 0.81979100E-02, -.82953600E-01, 0.70342800E-01, -.16450600E-01, -.17332000E-01, -.10764800E-01, 0.14116500E-02, -.33467900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.94610200E+00, -.17049600E-01, 0.20656500E+01, 0.50904000E+00, 0.60976200E-01, 0.34351800E+00, -.82320700E+00, -.97430500E+00, 0.58926000E-01, 0.10178800E+00, 0.30128300E+00, 0.76104600E+00, -.10501300E+00, 0.83552800E+00, 0.90962400E+00, -.10637700E+00, 0.47527800E-01, 0.96537400E-01, 0.37309200E+00, 0.23224200E+00, 0.42356100E-01, -.92678100E-01, -.13082000E+00, 0.15278200E+00, -.65426100E-02, -.71491100E-01, 0.64821700E-01, -.32709100E+00, 0.53334300E-01, -.33653500E-01, 0.39321300E-01, -.16730400E+00, 0.55310500E-04, -.32724500E+00, 0.12066400E+00, 0.12699900E+00, 0.14103200E+00, -.11237400E-01, -.72606200E-01, -.27928100E-01, 0.16559400E+00, -.35018400E-01, -.20608000E+00, -.40587300E-01, -.13452300E+00, -.30132000E-01, -.40986300E-01, 0.40537300E+00, -.74785900E-01, -.62976500E+00, -.10791500E+00, 0.12272300E-02, 0.20630100E-01, 0.39436100E-01, -.21079500E+00, -.45453400E-01, -.14362100E-01, -.89356000E-02, 0.99689900E-04, -.40644900E-01, 0.27368500E+00, 0.72487100E-02, 0.53403500E-01, -.67743000E-02, 0.27972300E+00, 0.51213300E-02, 0.43822700E-02, 0.31364500E-01, -.41056900E-01, -.12028300E+00, -.29768200E-01, 0.97463800E-01, -.20358400E+00, -.13115100E+00, 0.13397900E+00, 0.29771200E-01, 0.18851800E-02, -.28467300E-01, 0.12842300E+00, -.63681900E-01, -.95707600E-01, -.81053000E-02, -.19285300E+00, -.79523500E-02, -.47351400E-01, 0.32858700E+00, -.84006400E-01, 0.11072600E+01, -.27653200E-01, -.31873400E-01, 0.12959800E+00, 0.29194000E+00, 0.23231500E-01, 0.80996100E-01, -.46626700E-01, 0.13371100E+00, -.57120900E-01, 0.55976200E-01, -.20151600E-01, -.46777900E-02, -.13211500E+00, 0.26365000E+00, 0.89543100E-01, 0.51840200E-01, 0.57891200E-02, -.19733000E+00, 0.86466700E-01, -.63942700E-01, -.18739800E-01, 0.60617300E-02, -.36000600E-01, -.10414900E+00, 0.60943800E-02, -.43537100E-01, -.54891500E-01, -.24335400E-01, 0.37547900E+00, 0.10358500E+00, -.44732700E-01, 0.37084500E-01, -.27744400E-02, 0.28991000E-02, 0.59909800E-02, -.23776000E-01, 0.25408400E+00, 0.53835200E-02, 0.56674400E-03, -.34657700E-02, -.92792400E-01, -.49328200E+00, -.29460200E+00, -.42981700E+00, 0.38731200E+00, -.20506900E-01, 0.73180300E-01, -.59911200E+00, 0.97613100E+00, -.15747200E+00, -.69899500E-01, -.33532600E+00, -.57601700E-02, 0.33399500E+00, -.49089500E-01, -.27624200E+00, 0.58268300E-01, -.24497300E+00, 0.15974400E+00, -.28846200E-02, -.67371700E-02, 0.44859900E-01, 0.60992300E-01, -.88879000E-01, -.25540100E-01, -.26601300E-01, 0.44111200E-01, -.32209700E-01, -.21383700E-01, -.40730300E-01, 0.10154800E-01, -.29311900E-01, 0.34397300E-01, -.99145800E-04, -.37307400E-01, -.30988600E-01, 0.35130600E-01, -.35658600E-01, -.10280200E-01, -.50903200E-01, 0.38838600E-01, -.15737300E-01, 0.41966500E-01, 0.39924000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.25071100E+01, 0.92510000E-01, -.19167000E+01, -.15245100E+01, -.82033700E+00, -.58439000E+00, 0.26430500E+01, 0.35291400E+01, 0.35131300E+00, -.43641800E+00, -.11138000E+01, -.24371600E+01, 0.12257100E+00, -.25973100E+01, -.22929800E+01, -.21282400E+01, -.18294400E+00, -.31319000E+00, -.16330500E+01, -.17428800E+01, 0.10899400E+00, 0.24233100E+00, 0.59107800E+00, -.44519200E+00, 0.22136300E+00, 0.12046600E+01, -.49092500E+00, 0.11777000E+01, 0.40510300E+00, 0.55158200E+00, -.24229100E+00, -.15877300E+00, 0.13137000E+00, 0.93778600E-01, -.63072400E+00, 0.26237700E+00, 0.53320300E+00, -.32794900E-01, -.58778500E+00, 0.13144000E+00, -.19547400E+00, -.18910100E+00, 0.52859800E+00, 0.17253900E+00, -.88967300E-02, 0.31231300E+00, -.22200400E-02, -.55104800E+00, 0.31604700E+00, 0.17574200E+01, 0.10977100E+00, -.50207000E-01, 0.15895400E+00, 0.23108300E+00, 0.68022300E+00, 0.84855700E-01, 0.21580900E-01, -.53309500E-01, 0.16556700E+00, 0.77682800E-01, -.45010100E+00, -.24621100E-01, 0.26503100E+00, 0.68287500E-01, -.27813300E+00, 0.41217600E-01, -.17533300E-01, -.10178000E-01, 0.58062100E-01, 0.84362700E-01, 0.10087000E+00, 0.90370800E-01, 0.81750000E-01, -.82066400E-01, 0.42169400E+00, -.12161600E+00, -.20067100E+00, 0.48325000E-01, -.60964400E+00, 0.30000200E+00, 0.50783200E+00, 0.42782600E-01, 0.53880700E+00, 0.78610900E-01, -.52853700E-01, -.42205200E-01, 0.39286100E+00, -.19124600E+01, 0.11472700E-01, -.29507300E-01, -.13628700E+00, -.43049800E+00, 0.11513100E+00, -.34868400E-01, -.24490300E-01, 0.30881000E-01, 0.27836000E+00, -.31115200E+00, 0.89977400E-01, 0.32182500E-02, 0.46807200E+00, -.82934800E-01, -.40948100E-01, -.94769900E-01, -.47187500E-01, 0.24673000E+00, -.61976300E-02, 0.24922700E-01, -.21493200E-01, 0.72785300E-01, -.26767200E-01, 0.13122500E+00, 0.17779500E-01, 0.47443100E-01, 0.10099300E+00, 0.23013900E-01, -.35945200E+00, 0.57492700E-02, 0.41679900E-01, 0.81800400E-01, 0.22169500E-01, 0.26248300E-01, -.70118200E-01, 0.17006300E-01, -.32039900E+00, 0.10765800E+01, 0.34813200E-01, -.15041800E-01, -.28369100E+01, -.13598200E+01, 0.13903400E+01, 0.11468100E+01, -.14140500E+01, -.14976700E+01, 0.16617500E+00, 0.11266700E+01, -.15263000E+01, 0.44789500E+00, 0.83207700E-01, 0.73377200E+00, -.51622100E+00, -.91587200E+00, 0.38129000E-01, 0.76043800E+00, -.15386500E+00, 0.39025300E+00, 0.31878900E+00, -.53921300E-01, -.19979000E+00, 0.11436100E+00, 0.13283000E+00, 0.78250200E-01, 0.14717300E+00, -.33046600E-01, -.35741700E-01, 0.21193900E-01, -.13086000E+00, -.46893200E-01, -.12212000E-01, -.57971600E-01, -.24164300E-01, 0.49715800E-01, -.16513600E+00, -.21503700E-01, -.54008900E-01, -.85112800E-01, -.57531300E-01, -.31954300E-02, -.84350000E-01, 0.40194900E+00, -.86894500E-01, -.46073700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.64298500E-01, 0.36773500E-01, 0.10221900E+01, -.29536500E+00, -.18332200E-02, 0.70009800E-01, -.41584900E+00, -.27535800E-01, 0.26755400E+00, 0.41984900E+00, 0.55578600E-01, 0.29491400E+00, -.44669100E-01, 0.25971900E+00, 0.31250200E+00, -.45482700E+00, -.49008100E-02, -.18979100E-01, -.12462500E-01, -.18957000E+00, -.16033800E+00, 0.52987500E-01, -.34025900E-01, 0.18112500E-01, -.10462000E-01, -.13007800E+00, -.43189400E-01, 0.19989900E+00, 0.13374500E+00, 0.34114600E-01, 0.53729300E-02, -.16044600E+00, -.38628200E-01, -.10043000E+01, 0.11097300E-01, -.60939000E-02, -.22274200E-01, 0.29399400E-01, -.36839400E-01, 0.76497300E-02, 0.43757500E-01, 0.81393300E-03, -.12580500E-01, -.37273200E-02, -.19512600E-01, 0.67341900E-02, -.13575900E-02, 0.12716600E-01, 0.34614800E-02, 0.10334300E+00, -.78653800E-02, -.11069900E-01, 0.96046200E-02, 0.26570800E-01, -.33802200E-01, 0.18494500E-02, 0.32096600E-02, -.26796500E-02, 0.12268800E-01, 0.34883200E-01, -.39173300E-01, 0.10218800E-01, 0.54564500E+00, 0.42724800E-01, 0.37997000E-01, -.64751000E-02, 0.40409000E-02, 0.80478400E-02, -.17454200E-01, 0.23655300E-01, 0.33933000E-02, 0.27635600E-01, 0.10290200E-01, -.57131500E-03, 0.38715100E-01, 0.14176800E-01, 0.67114400E-02, -.77837900E-02, -.49052100E-02, 0.37358900E-01, -.11826700E-01, 0.13270200E-01, -.10659100E-01, 0.13387700E-01, -.15803900E-01, 0.22189200E-01, -.11608700E-01, 0.30837700E+00, 0.16051900E-02, -.61248900E-02, -.11356100E-03, -.67037800E-02, -.17955600E-02, -.41351400E-02, 0.78959100E-02, 0.35931000E-02, -.27261100E-01, -.42962300E-03, 0.14992600E-02, 0.46736200E-04, -.31574000E-01, 0.10955900E-01, 0.53663000E-02, 0.29445200E-02, 0.50555800E-03, -.23270300E-03, 0.10885100E-01, -.53256700E-02, 0.96709600E-03, 0.95924000E-02, -.97538300E-02, 0.11923600E-01, 0.20594200E-02, 0.55788600E-02, 0.69948300E-02, 0.23370700E-01, 0.20531200E-01, -.20648100E-01, 0.20234900E-01, -.13885400E-02, 0.15876700E-02, 0.77820300E-02, 0.16035300E-01, -.47371800E-02, 0.40928000E-02, -.19713500E-02, 0.15555800E+00, 0.25639000E-02, 0.25046800E+00, 0.45335000E+00, 0.26136000E+00, 0.19352400E+00, -.25342100E+00, -.50423100E-02, -.55620500E-01, 0.28077600E+00, -.98482300E+00, 0.47895300E-01, 0.39017500E+00, 0.43109200E+00, -.10228900E+00, -.45537300E+00, -.20161100E+00, 0.46444100E+00, 0.10789800E+00, 0.28256800E+00, -.99873800E-01, -.59136900E-01, 0.73555600E-01, 0.48563000E-01, 0.11621800E+00, -.70020100E-01, 0.28935200E-01, -.26130500E-01, -.64491700E-02, 0.86962000E-02, -.45796200E-01, -.60440300E-02, 0.16403600E-01, 0.21518800E-01, -.90685800E-02, -.25594700E-01, -.39461000E-01, 0.16383600E-01, 0.18475300E-01, -.32241700E-01, 0.20847800E-01, -.15276300E-01, -.11888800E-01, -.48128200E-01, -.11641700E+00, 0.56462700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10179200E+01, -.56098900E-01, -.31476800E+00, 0.74572700E+00, -.11587400E+00, 0.30724500E+00, -.23460100E+00, -.10069800E+01, 0.11369800E+00, -.32680600E+00, 0.11933800E+00, 0.63934400E+00, -.22448900E-01, 0.59502500E+00, 0.54667000E+00, 0.19473300E+00, -.99345200E-01, 0.78431900E-01, 0.34203900E+00, -.66322800E+00, 0.42094200E-01, 0.34391900E+00, 0.87627200E-01, -.21293800E+00, -.35573700E-01, -.37390400E+00, 0.61381700E+00, -.15106600E+00, -.21440700E+00, -.88271200E-01, 0.64518000E-01, 0.35606300E+00, 0.36601500E+00, -.10788100E+00, -.18652800E+00, -.37447300E+00, 0.83670400E-01, -.16211100E+00, 0.44906300E+00, 0.31810900E-01, -.15878100E+00, -.53331400E-01, -.35520100E-01, -.55594200E-01, -.98683600E-02, 0.47924000E-01, 0.11743500E-01, -.15093700E+00, 0.30130200E-01, 0.60757100E+00, 0.43444500E-01, -.67891700E-02, 0.54861400E-01, -.53421800E-01, 0.25276000E+00, -.30572200E-02, -.13527200E-01, -.56307000E-01, 0.21203200E+00, 0.50670200E-01, -.84542400E-01, -.48539800E-01, -.11540800E+01, 0.51094100E-01, 0.19773700E+00, -.22910000E-01, -.11256900E-01, -.73352000E-01, -.16144900E+00, 0.92512800E-01, 0.36801800E-01, -.24768800E-01, 0.14877000E-01, -.14737800E-01, -.12041200E-01, -.10983000E+00, -.41143300E-01, 0.11806900E+00, -.10300400E+00, 0.54037200E-02, 0.35531300E-01, -.42226600E-01, 0.33758900E+00, 0.42789900E-01, -.93838700E-02, 0.11831800E-01, -.54333600E-01, -.26877600E+00, -.38126700E-01, 0.35645400E-01, 0.93871400E-01, -.16804800E-01, -.25770200E-01, 0.41762200E-01, 0.10242100E+00, 0.42559700E-01, -.15826800E+00, 0.23366300E+00, -.94447500E-01, 0.14187600E-01, -.10813700E+00, -.41627000E-01, -.71008500E-02, 0.13542500E-01, 0.10289700E-01, 0.65052000E-01, 0.73145000E-01, -.10589500E+00, -.75116800E-02, 0.33428000E-02, -.27490600E-01, 0.28178200E+00, -.76524400E-02, -.11110500E-01, -.80076300E-02, 0.66375800E-04, 0.11952600E-02, 0.45934800E-01, -.31232000E-02, -.71987800E-02, -.61410400E-02, 0.12024500E-02, 0.31390100E-02, 0.53872600E-01, 0.53577200E-02, -.85729900E-02, -.27914900E-01, 0.31018900E+00, -.67500100E-01, 0.74714500E+00, 0.15898700E+00, 0.81535500E-01, -.12415600E+00, 0.24358800E-01, -.75937100E-01, 0.20353400E+00, -.45305100E+00, 0.42103100E+00, 0.28995000E-01, 0.17799600E+00, -.17584800E+00, -.14670200E+00, -.13614300E+00, 0.26041600E+00, 0.38667200E-01, 0.33652700E-01, -.23276200E-01, 0.49035500E-01, 0.72508600E-01, -.10381400E-01, -.86978200E-02, 0.21030900E-01, -.14428200E-01, -.29602100E-01, -.70054100E-02, 0.14309100E-01, 0.91922000E-02, 0.51380200E-02, 0.16187900E-01, 0.34933000E-01, -.14669900E-01, -.63324500E-02, 0.11480200E-01, 0.31313500E-01, 0.97270600E-02, 0.27343100E-01, 0.51023200E-01, -.18542700E-01, -.81514100E-02, -.73727300E-01, -.26149400E-01, -.27323000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.47928200E+01, -.16530700E+00, 0.37330200E+01, 0.28083400E+01, 0.15820800E+01, 0.11386200E+01, -.49424200E+01, -.63504200E+01, -.22493600E+01, -.69597900E+00, 0.19057300E+01, 0.40778600E+01, -.87605100E+00, 0.62957800E+01, 0.46878100E+01, 0.32003200E+01, 0.52904100E+00, 0.10720800E+01, 0.34808400E+01, 0.44763600E+01, 0.71403100E+00, -.18304500E+01, -.12527000E+01, 0.10178400E+01, 0.18834800E+00, -.10784600E+01, -.22484600E+00, -.26240600E+01, -.85613400E+00, -.13500300E+01, 0.33665100E+00, 0.34847500E-02, -.92904100E+00, -.22724100E+01, 0.95833600E+00, 0.16578900E+01, -.32631800E+00, -.47710500E+00, 0.55417000E+00, -.11355600E+01, 0.56901400E-02, 0.22343800E+00, -.37767300E+00, -.11458800E+00, 0.32988000E+00, -.91029100E+00, -.24597300E-01, -.11551400E+01, -.71484600E+00, -.74343200E+01, -.17288800E+00, 0.15123800E+00, -.50478900E+00, -.39004300E-01, -.61189500E+00, -.33140000E+00, -.20145000E-01, 0.52788300E-01, -.17613400E+00, -.10654900E+00, 0.47799200E+00, -.11553400E-01, 0.35178100E+00, -.16331400E-01, 0.11145500E+00, -.51548900E-01, -.14816400E-01, 0.38579200E-01, -.17961400E+00, -.29354600E+00, 0.20021700E+00, -.70364900E+00, 0.76265300E+00, 0.11130100E+01, -.33837700E+00, 0.30495500E-01, -.50450300E+00, 0.43340900E+00, 0.25016400E+00, -.21739200E+00, -.88282000E+00, -.45029500E+00, -.50600900E+00, -.20207500E+00, 0.45051000E+00, -.23377800E+01, -.71949300E+00, 0.12655900E+01, -.43065600E-01, -.13461900E+01, 0.61263500E+00, -.70835100E+00, 0.12843600E+00, 0.37581800E+00, 0.70921500E-01, 0.62102300E+00, 0.15424300E+01, 0.16426700E+01, -.64145700E+00, -.34041200E-01, 0.12732400E+01, -.37995400E+00, -.22108600E+00, 0.11346500E+00, 0.24725700E+00, 0.72140900E+00, 0.10869400E+01, -.81064200E+00, 0.84128400E-01, 0.24301000E+00, -.67607500E+00, 0.15587000E+00, 0.75956300E-02, 0.20819200E+00, 0.35139300E+00, 0.59181000E+00, 0.21748500E+00, -.12679300E+01, -.31173900E+00, -.56071500E+00, -.36241800E-01, 0.45784200E+00, 0.11635300E+01, -.26255600E+00, 0.12265000E-01, -.13622600E+00, -.45485300E+00, 0.18788000E+00, 0.54680500E+02, -.12948800E+02, -.15151700E+01, -.65103700E+01, -.52353100E+01, 0.16862700E+02, -.22007700E+01, -.38249700E+01, -.20287700E+02, -.10458000E+02, 0.16370900E+02, 0.12000500E+02, -.33695600E+01, -.13269800E+02, -.97358000E+01, 0.12632900E+02, 0.21867800E+01, 0.16937200E+02, -.37037900E+01, -.33900300E+01, 0.35603300E+01, 0.18221800E+01, 0.47760800E+01, -.51398500E+01, 0.28041800E+00, 0.45075100E+00, -.12297400E-01, 0.13329200E+00, -.16705000E+01, -.13814200E+00, -.38852500E+00, -.60296100E+00, -.12271700E+00, -.10515300E+01, -.13371900E+01, -.58362300E+00, 0.38841300E+00, -.15479600E+01, 0.76625800E+00, 0.24445900E+00, -.17502500E+00, -.14930600E+01, -.58053800E+01, 0.22690300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18133200E+01, 0.21938600E-01, -.42412200E+01, -.99541400E+00, 0.91381100E-02, -.58252100E+00, 0.18117900E+01, 0.21769300E+01, 0.15178300E+00, 0.24247500E+00, -.46642600E+00, -.14324000E+01, 0.19163800E+00, -.14656600E+01, -.70445300E+00, 0.32202400E+00, -.16069200E+00, -.65702000E+00, -.10577600E+01, -.26930300E+01, -.44778400E-01, -.81318500E-01, 0.47721900E+00, -.63506000E+00, -.53628800E-01, 0.78219000E+00, 0.62389000E+00, 0.31152800E+01, 0.71974900E+00, 0.33536700E+00, 0.87230500E+00, -.35856400E+00, -.31222900E+00, -.26351000E+01, -.27570400E+00, -.25889000E+00, -.90448200E-01, -.18390300E+00, -.26433500E+00, 0.48958200E-01, 0.19190700E+00, -.24653100E+00, 0.49549900E+00, 0.22135900E+00, 0.64521700E-01, 0.38753400E+00, 0.74802600E-01, -.51768800E+00, 0.44269700E+00, 0.25085300E+01, 0.14015200E+00, -.36347700E-01, 0.35014400E+00, -.24833300E-01, 0.57661500E+00, 0.13654100E+00, 0.26337600E-01, -.12815200E+00, 0.55720300E+00, 0.60440900E+00, -.95001700E+00, -.80972000E-01, -.12213100E+01, 0.66395600E+00, 0.73040300E+00, 0.25270800E-01, -.12454400E-01, -.53248600E+00, -.10360000E+00, 0.38275100E+00, -.28662400E+00, 0.15935000E+00, -.46876500E+00, -.59427800E+00, -.97062700E-02, -.22182400E+00, -.15886300E-01, 0.44241900E-01, -.40431900E+00, -.41678800E-01, 0.37129300E+00, 0.60639600E-01, 0.15451300E+00, -.30186100E-01, -.76109300E-01, 0.12630200E+00, 0.42547000E+00, -.64600000E+00, -.51114500E-02, -.22178000E-01, -.25063500E+00, -.68853800E+00, -.29753900E+00, 0.51551000E-01, 0.21279000E+00, -.99570800E+00, -.24983100E+01, -.89903200E+00, 0.88980500E+00, 0.25552400E+00, -.86206000E+00, 0.69916600E-01, 0.26738300E+00, 0.86558200E-01, 0.46291300E-02, -.44087200E+00, -.24837300E+00, 0.17831400E+00, -.52627000E-01, -.10732100E+00, 0.28129800E+00, 0.11425000E+00, -.12659300E-01, -.10182900E+00, 0.43952200E-01, -.14823700E+01, -.14241200E+01, -.28238800E+00, 0.28651600E+00, -.49048700E-01, -.12544300E+00, -.36760800E+00, -.10180600E+01, 0.14498800E+00, 0.21472100E+00, -.10520400E+00, 0.94980600E+00, 0.20306200E+00, -.33156100E+00, 0.17479000E+02, 0.79696500E+01, 0.87647800E+01, -.67927700E+01, 0.27552800E+00, -.35473200E+01, 0.12064900E+02, -.92505800E+01, 0.33221200E+01, 0.16293400E+01, 0.48714300E+01, -.33962500E+01, -.34547400E+01, -.11145800E+01, 0.40567700E+01, -.20768800E+01, 0.19427800E+01, -.37331900E+01, -.37444100E+00, 0.16501300E+01, -.35530500E+00, 0.33121500E-01, 0.21039600E+01, -.71849700E-01, -.24316200E+00, -.19848000E+00, 0.14308400E+00, 0.24136400E+01, 0.17683900E+00, 0.42328400E+00, 0.38908000E+00, -.14598700E+00, 0.17771900E+00, 0.27658200E+01, 0.28454200E+00, 0.24603600E+00, 0.27130700E+01, -.21316600E+00, -.71721400E-01, 0.17547200E-01, -.11427000E+01, -.99191600E+00, -.44401100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25434900E+01, -.13106000E+00, -.55929500E+00, 0.51282300E+00, -.20560200E+01, -.84282400E+00, -.14643000E+01, -.18824200E+01, -.33172500E+00, -.48905900E+00, 0.26386800E+00, 0.11264800E+01, 0.18886200E+00, 0.59195700E+00, -.43585400E+00, 0.88468900E+00, -.51948000E-01, 0.39775300E+00, 0.77267700E+00, 0.11943700E+01, -.13942500E+01, 0.19026500E+01, 0.97230600E+00, 0.16461200E+00, -.11134300E+00, -.13861000E+01, 0.50609200E+00, 0.20141700E+00, -.16227400E+00, 0.49102900E+00, -.11869500E-01, 0.67713100E+00, -.22540400E+00, -.14694300E+01, 0.23984800E+00, 0.10012400E+01, 0.82385300E+00, 0.93566300E-01, 0.15384900E+00, -.81058100E+00, 0.11137000E+01, -.48760000E+00, 0.12066500E+01, 0.23621900E+00, 0.82616400E+00, -.11135300E+00, 0.91484400E-01, -.26311800E+01, -.21357600E+00, 0.34884600E+01, 0.69679400E+00, -.19729800E+00, 0.34187100E+00, 0.78728500E-01, 0.20274900E+01, 0.33441500E-01, 0.71519700E-01, -.20150500E+00, 0.10746500E+01, 0.14447900E+00, -.12780900E+01, -.93226500E-01, -.37925700E+01, 0.20970500E+00, 0.46767800E+00, -.12373800E+00, -.49158800E-01, 0.47111700E+00, -.82829600E+00, 0.13230200E+01, 0.55461200E-01, -.42825400E-01, -.83493800E-01, -.54873100E+00, 0.69564300E-01, -.33280500E+00, -.18493500E+00, 0.12160200E+00, -.35014100E+00, -.20031500E+00, 0.23319500E+00, -.79941400E-01, -.30032300E+00, -.61857000E+00, -.51595500E-01, -.90684700E+00, -.11867800E+00, -.13228100E+01, -.24790500E-01, -.12349200E+01, 0.53312900E+00, -.30052400E+00, 0.23067800E+00, -.47430300E-01, 0.33701400E+00, 0.60825700E+00, -.91712800E+00, 0.37853300E+00, -.66875500E-01, -.20396800E+00, -.31109000E+00, 0.43949800E+00, 0.55970100E+00, -.81680600E-01, 0.85585900E-01, 0.96520700E+00, 0.76579200E+00, -.86391400E+00, 0.48072200E-01, -.95623800E-01, -.13644100E+00, 0.19706700E+00, 0.36900500E-01, 0.41664500E-01, 0.37979600E+00, -.14807000E+01, -.18454200E+01, -.83854500E+00, 0.10035200E+00, -.21760500E-01, -.11062400E+00, 0.13091900E+00, -.17922700E+00, 0.66509200E-01, -.27646100E+00, -.13408300E+00, 0.20699500E+00, 0.65077500E-01, -.33666500E-02, 0.59948300E+00, 0.14788200E+02, 0.61820900E+01, -.74086200E+01, -.29380100E+01, -.17887800E+01, 0.71993900E+01, -.11747400E+02, -.21599500E+01, 0.35443800E+01, 0.55211600E+01, -.14182200E+01, -.68457700E+01, -.28620000E+01, 0.50556300E+01, -.55590700E+00, 0.59918700E+01, -.28740200E+00, -.13192600E+01, 0.56819700E+00, 0.39669300E+00, 0.30774000E+00, -.22790600E+00, -.13907500E-01, 0.18492400E+00, -.11760300E+00, 0.14043500E+00, -.18797300E+01, 0.18068500E-01, -.32677700E+00, -.66297600E+00, -.13913500E+00, -.33339200E+00, -.17672600E+01, -.55729000E+00, -.15047700E+00, -.13053500E+01, 0.18565000E+00, 0.80509900E-01, -.33763300E+00, 0.98660800E+00, -.15264700E+01, -.51523300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.57669600E+01, 0.14662800E+01, -.81513500E+00, -.11429000E+01, -.81001700E-01, 0.47816500E-01, -.11729600E+00, 0.52469200E+01, -.75402000E+00, -.29869000E+01, -.13878600E+01, -.45316500E+01, -.42046000E+00, -.31580100E+01, -.24342400E+01, 0.35975500E+01, 0.27907500E+00, -.22238100E+00, -.57876200E+00, -.31201400E+01, -.18616800E+00, 0.11649300E+01, 0.13843700E+00, -.17193900E+01, -.56379100E+00, -.48892100E+00, -.70640500E+00, 0.23735200E+01, -.44231700E+00, 0.35803700E+00, -.14574700E+01, 0.12414100E+01, 0.28460400E+01, 0.64939700E+01, -.10264100E+01, -.30001700E+01, -.30127500E+01, 0.47785300E+00, 0.12887700E+01, 0.20777000E+00, 0.82854000E-02, 0.45937200E+00, -.75014100E+00, -.40415100E+00, -.51851800E+00, 0.25120600E+00, 0.19652100E+00, 0.15399400E+01, 0.44423200E+00, 0.75894400E+01, 0.80153100E+00, -.34605600E+00, -.77717600E+00, -.93334200E+00, -.16141000E+01, 0.41141200E+00, 0.17039000E+00, 0.31530900E+00, -.33918500E+00, -.40651100E-01, 0.15898500E+00, 0.37369900E+00, 0.43047800E+01, -.15616300E+00, -.13090700E+01, -.27111200E+00, 0.40275700E+00, -.40384700E+00, 0.82366900E-01, 0.10655900E+01, -.65958700E+00, 0.16253500E+01, -.28271500E+01, -.82985500E-01, 0.57558800E-01, 0.18119200E+00, 0.82769000E+00, -.11906500E+00, 0.57406200E+00, 0.43384500E+00, 0.23499100E+00, -.25809700E+00, 0.15850700E+01, 0.47831700E+00, -.12587300E+00, -.78784400E-02, -.65822100E+00, 0.71993600E+01, -.45640200E+00, 0.28120500E+00, -.34894900E+00, 0.70411700E+00, 0.30520600E+00, -.50108800E+00, 0.19488200E+00, 0.24960800E+00, 0.10843600E+01, 0.23651600E+01, -.92941200E+00, 0.25251100E+00, -.20119900E+01, 0.28020000E+01, 0.21825800E+00, 0.58804300E+00, 0.58845900E-01, -.10126600E+01, 0.13425100E+01, -.10113800E+01, 0.93464300E-01, -.63959100E-01, -.11485100E+00, -.72944300E+00, -.69865400E-01, 0.20963200E+00, 0.66045500E+00, 0.72147300E+00, 0.18751400E+01, 0.60880800E+00, 0.64064700E+00, 0.76693600E+00, 0.80975100E-01, 0.59998200E+00, 0.28669600E+01, 0.81122500E-01, -.28807300E-01, -.41033700E+00, -.11930200E+01, -.12407000E+01, -.63714400E+00, 0.57009900E+00, -.65036200E+00, -.19545600E+02, 0.21315500E+02, -.75428600E+00, 0.24551500E+02, -.22623400E+02, -.32482500E+02, -.77000200E+01, 0.21629600E+02, 0.93676400E+01, 0.98824200E+01, -.15144100E+02, -.35104500E+01, 0.13070400E+02, 0.26302600E+01, 0.20467200E+02, 0.28928700E+01, -.35389100E+01, 0.47778300E+01, -.35967800E+00, 0.53458300E+01, -.10635500E+02, -.73885900E+00, 0.18008400E+01, 0.23308500E+00, 0.99505600E-01, -.70721500E+01, 0.66894700E+00, -.18145200E+01, -.24768400E+01, -.71954500E-01, -.25202600E+01, -.68973200E+01, -.21410900E+01, -.50556400E+00, -.62322600E+01, 0.24399200E+01, 0.14437300E+01, -.51402800E+00, -.50493300E+00, -.34674600E+01, 0.33810600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.22005400E+01, 0.12274700E+00, 0.37565600E+00, -.15243500E+01, -.22435300E+00, -.79095900E+00, 0.42881200E+00, 0.10007300E+01, 0.46971000E+00, 0.12816700E+01, 0.61738200E-01, -.61840900E+00, 0.40824600E+00, -.95259400E+00, -.14005600E+01, 0.16190300E+01, 0.15791400E+00, -.25331600E+00, -.30813800E+00, 0.25013100E+01, -.87893200E+00, 0.64535200E+00, -.30862300E+00, 0.36072800E+00, -.45123200E+00, -.18310500E+01, -.10884700E+01, -.10159500E+01, -.11955500E+00, 0.36666200E+00, -.97659600E+00, -.67602700E+00, 0.14408900E+00, 0.18816400E+01, 0.59872600E+00, -.15506700E+01, -.18157800E+01, 0.76941800E+00, 0.81575600E-01, 0.56027800E+00, -.27904600E-01, 0.54590400E+00, -.75380300E+00, -.26914100E+00, -.28916500E+00, -.18399900E+00, 0.44522000E-01, 0.84949000E+00, -.21390800E+00, -.78441100E+00, -.29370200E+00, -.64333700E-01, -.15455100E+00, 0.16705700E+00, -.11389600E+00, -.11985800E-01, 0.32547500E-01, 0.15467400E+00, -.65419300E+00, -.50677700E+00, 0.10130500E+00, 0.18485000E+00, 0.32540500E+01, -.68838700E+00, -.95643300E+00, 0.71035000E-01, -.16439800E+00, 0.20306200E+00, 0.13285600E-01, 0.57115100E+00, -.62874400E+00, 0.66998700E+00, -.45644800E+00, 0.10933800E+00, -.60509900E+00, 0.31061400E+00, 0.37246100E+00, -.65335900E-01, 0.96229900E+00, 0.55171900E-01, -.97572200E-01, 0.11146600E-01, 0.45074300E+00, 0.20082300E+00, -.16073900E-01, 0.14829300E+00, 0.21418100E-01, 0.12509400E+01, -.30435100E+00, 0.28816800E+00, 0.13969600E+00, 0.22698400E+00, -.18667900E+00, 0.10184000E+00, 0.22048700E+00, -.19361600E+00, -.15214900E+01, 0.50498200E+00, -.62463300E-01, 0.15441100E+00, -.64235700E+00, 0.28221600E+00, -.86068800E-01, 0.24863300E+00, -.31684200E-01, -.45403800E+00, 0.10782200E-01, 0.29585400E-02, -.39945300E-01, -.22853000E-01, 0.10082400E+00, 0.15905800E+00, -.26214600E-01, -.10348000E+00, 0.28273400E-01, -.85973000E+00, -.56434600E+00, 0.21790500E+00, 0.13017800E+00, 0.34373400E+00, -.41078800E-01, -.48317600E-01, -.34207700E+00, 0.76041400E-01, -.13529500E+00, -.20116400E-01, 0.30781700E+00, 0.98869300E-01, 0.83770500E-01, 0.38078900E+00, -.42685400E+00, 0.15756400E+00, -.27204600E+01, 0.10147500E+01, -.85966100E+00, -.10607900E+01, 0.24290600E+01, 0.66261000E+01, -.57965800E+01, -.17806200E+01, -.12075100E+01, 0.18709000E+01, 0.16256700E+01, -.19294500E+01, -.62441700E+00, -.56959200E+01, 0.27863400E+00, 0.12731500E+01, -.79888900E+00, -.34634900E+00, -.13330900E+01, 0.22652200E+01, -.82295100E-01, -.29284400E+00, -.36842100E-01, -.29852200E-01, 0.51874100E+00, 0.41200800E-02, 0.15224500E+00, 0.17332400E+00, 0.22872500E-01, 0.43654600E+00, 0.46976400E+00, 0.16288500E+00, -.73207900E-01, 0.43398000E+00, -.28019700E+00, -.11393200E+00, -.39107000E-01, 0.76248000E+00, 0.17023900E+01, -.89021300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.28300700E+01, 0.10788100E+00, -.20675500E+01, -.17147700E+01, -.95813000E+00, -.68533200E+00, 0.28760800E+01, 0.39844400E+01, 0.33634900E+00, -.40807500E+00, -.12246500E+01, -.27692700E+01, 0.16015200E+00, -.28696100E+01, -.25202900E+01, -.21857400E+01, -.18481000E+00, -.40587100E+00, -.18063600E+01, -.17872600E+01, 0.19318000E+00, 0.29089400E+00, 0.55535100E+00, -.45162600E+00, 0.22682400E+00, 0.13227000E+01, -.49505000E+00, 0.10355000E+01, 0.36682500E+00, 0.64258800E+00, -.38443800E+00, -.21614600E+00, 0.14300300E+00, 0.72357400E+00, -.66646200E+00, 0.36394700E+00, 0.81182800E+00, -.34698300E-02, -.76321000E+00, 0.69729700E-01, 0.71438600E-02, -.27196700E+00, 0.64391400E+00, 0.23396000E+00, -.78160200E-02, 0.42905000E+00, 0.42317300E-01, -.44733200E+00, 0.45158500E+00, 0.27103900E+01, 0.20004100E+00, -.94016900E-01, 0.30185500E+00, 0.25139000E+00, 0.17422200E+01, 0.13325900E+00, 0.70790700E-02, -.18757800E+00, 0.43286200E+00, 0.13040900E-01, -.77006500E+00, -.16806200E+00, -.11321300E+01, -.16788900E-01, -.26331200E+00, 0.46034700E-01, -.10624200E+00, 0.96192400E-01, -.18646400E+00, 0.11633800E+00, 0.15807800E+00, -.22231700E-01, 0.42931900E+00, -.78707000E-01, 0.58409600E+00, -.36689000E+00, -.41529800E+00, 0.39691400E+00, -.72589000E+00, 0.34288800E+00, 0.69371900E+00, -.80584000E-01, 0.16179400E+01, 0.11328900E+00, 0.18767500E+00, -.20192700E-01, 0.31321100E+00, -.51661100E+01, -.37939000E-01, -.36315600E+00, -.28863300E+00, -.16896400E+01, 0.17417600E+00, -.62032800E-01, 0.57986100E-01, 0.93007800E-01, 0.73908800E+00, -.41160200E+00, 0.11706100E+00, 0.94082700E-01, 0.11045200E+01, 0.82226200E-01, 0.13238800E-02, -.44242400E-01, -.15322300E+00, 0.21933800E+00, 0.94934200E-01, 0.21767900E-01, -.76582400E-01, 0.23755300E+00, -.17183100E+00, 0.40334400E+00, 0.13551800E+00, 0.14529100E+00, 0.55790700E+00, -.53755300E+00, -.12184600E+01, 0.53731900E+00, 0.34638900E+00, 0.60684100E+00, 0.89242900E-01, 0.33815000E+00, 0.25275400E-01, -.16993700E+00, -.10946500E+01, -.56282200E+00, 0.69797500E+00, -.35731000E+00, -.23838900E+00, -.40833200E+00, 0.61867200E+00, -.94026400E-01, 0.10854200E+01, -.36233100E+01, 0.54578400E+01, 0.23335400E+01, -.17466300E+02, -.35609000E+01, 0.13434500E+02, 0.10246900E+02, -.40919100E+01, -.12218200E+02, -.46639700E+01, 0.12141000E+02, -.64453900E+00, 0.13408700E+02, 0.97187700E+00, -.28313800E+01, 0.35007100E+01, 0.69314300E+00, 0.52300300E+01, -.52106200E+01, 0.60223300E+00, 0.39103100E+00, -.27466300E-01, 0.82575200E-01, -.56511400E+00, -.43273900E+00, -.41587400E+00, -.85668500E+00, -.85273900E-01, -.53359000E+00, -.31120500E+00, -.75235700E+00, 0.36031100E-01, -.27416200E+00, 0.97941100E+00, 0.36676200E+00, -.21505100E+00, -.40123200E+00, -.47284800E+01, 0.20016800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.81377600E+01, 0.30187800E+00, -.74627600E+01, -.44906200E+01, -.26693500E+01, -.30596100E+01, 0.27842200E+01, 0.72805800E+01, -.20756700E+01, 0.31205800E+00, -.13145400E+01, -.58445300E+01, 0.49475100E+00, -.44922500E+01, -.53951900E+01, 0.34690600E+01, 0.45621700E+00, -.77667900E+00, -.21111700E+01, 0.38971900E+01, -.45545600E+00, -.14191800E+01, -.23931800E+00, 0.43708500E+00, -.85764000E-01, 0.61254800E+00, -.27604800E+01, 0.14421100E+01, 0.47049000E+00, 0.62830500E-01, -.72223300E+00, -.75568100E+00, -.15110000E+01, 0.30902800E+01, 0.59879200E+00, 0.97145000E+00, -.19833000E+01, 0.48762100E+00, -.97916900E+00, -.11323100E+00, -.60985800E-01, 0.88207000E+00, -.22000400E-01, 0.95670800E-01, 0.37944700E+00, -.51772200E+00, 0.12095600E+00, -.18937400E+01, -.12245900E+00, -.29588700E+01, -.18698100E+00, -.14578300E+00, -.43743600E+00, 0.25845400E+00, -.13806600E+01, -.36593600E-01, 0.23730000E+00, 0.38327400E+00, -.27009200E+00, 0.44723500E+00, -.10232100E+01, 0.36617400E+00, 0.35664600E+01, 0.52280900E+00, -.30175700E+00, -.83579400E-01, 0.10129200E+00, -.23714900E+00, 0.38840700E+00, 0.10627200E+01, 0.62306800E-01, -.45767000E-01, -.39042000E+00, -.47221100E+00, 0.14178200E+00, 0.94884500E+00, 0.45061300E+00, -.12034500E+01, 0.38500100E+00, -.17849000E+00, -.16348700E+00, 0.38635700E+00, -.44468300E+01, -.28244000E+00, -.30960900E+00, -.18333100E+01, 0.20118000E+00, 0.16379300E+01, -.22985400E+00, -.32093000E+00, 0.16561900E+01, 0.28411400E+01, 0.23768200E+00, 0.55335100E+00, -.39034500E-01, 0.10009100E+01, -.23838300E+01, 0.27878100E+01, -.72750500E+00, -.19208900E+00, -.31087800E+00, -.20591500E+01, 0.36441500E+00, -.14628700E+00, 0.35307500E+00, 0.43377800E+00, -.25073700E+00, -.53363500E+00, -.21300900E-01, -.94788300E+00, 0.71918800E+00, 0.13973900E+01, 0.54207800E-01, -.40377200E+00, 0.51176000E-01, -.21723300E+01, -.38703900E+01, -.28848900E+01, -.23713000E+00, -.29159400E+00, -.76249800E+00, -.11098900E+01, -.10002000E+01, 0.38123000E+00, -.10000900E+01, 0.65727500E-01, 0.69770800E+00, -.60927400E+00, -.18198500E+00, -.12540400E+01, 0.46196100E+00, -.40118200E+00, -.24249500E+01, -.27311000E+01, 0.26463800E+02, 0.85421400E+01, -.51921100E+02, -.74431800E+01, 0.21275600E+02, 0.22837600E+02, -.35542400E+01, -.25445800E+02, 0.63253700E+01, 0.25762800E+02, -.14495300E+02, 0.27478800E+02, -.69224300E+01, -.45117700E+01, 0.10156000E+02, -.41344400E+01, 0.73458100E+01, -.52572400E+01, -.15080100E+01, 0.17986500E+01, -.84583800E+00, 0.82173400E+00, 0.47882200E+01, -.65888700E+00, -.14515300E+00, -.64600300E+00, -.83674800E+00, -.10715500E+01, 0.64615100E+01, -.18593600E+00, -.31864700E-01, 0.57596900E+01, 0.73748800E+00, 0.16273400E+01, -.88623900E+00, -.44908100E+00, -.73138900E+01, 0.10105400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16332100E+01, 0.55514100E-01, 0.93145800E-01, -.15451500E+01, 0.28887400E+00, -.66620100E+00, 0.11923600E+01, 0.81515700E+00, 0.14941900E+00, 0.19158600E+01, 0.22822800E-01, -.66774900E+00, -.27530900E+00, 0.60903400E+00, 0.15270100E+01, -.46873900E+00, 0.36314000E+00, -.46284500E+00, -.93576200E+00, 0.91869500E+00, 0.17890700E+00, -.25866400E+00, -.50739900E+00, 0.72430200E+00, -.83296700E-01, -.78425700E+00, -.71677100E-01, 0.73690400E+00, 0.14318900E+00, -.86715000E-01, 0.32905200E+00, -.40430800E+00, -.28478800E+00, -.31758000E+01, -.12743400E+00, -.75213500E-01, -.85841700E+00, -.37949100E+00, 0.15706600E+00, -.34150300E+00, 0.60849200E-01, 0.12002700E+00, 0.23623400E+00, 0.39942800E-01, 0.26028300E+00, -.75849400E-01, -.17450200E-01, -.53553100E+00, 0.17268000E+00, -.69253900E+00, 0.84448900E-01, 0.64391100E-01, 0.10967000E+00, -.39323300E-01, 0.45757000E+00, 0.75716700E-01, -.85398900E-04, -.47653000E-01, 0.23322200E+00, 0.40819400E+00, -.67335100E+00, -.80494800E-01, 0.86984500E-01, 0.32622100E+00, 0.69037400E+00, 0.12128400E+00, -.12898400E+00, -.61452700E+00, 0.66495500E-01, 0.10652700E+00, -.27020900E-01, -.15155100E+00, -.49779100E+00, 0.21103500E+00, -.23862100E+00, 0.26692000E-01, -.25857100E+00, 0.22042000E+00, -.57492100E-01, 0.14795600E+00, 0.49890500E-01, 0.16780500E-01, 0.84447400E+00, 0.36499100E+00, 0.48673400E-01, 0.64813500E+00, -.18517900E-01, -.13283300E+01, -.23120500E+00, 0.32768400E+00, -.22123800E+00, -.24902400E+00, -.15461000E-01, -.77739700E+00, 0.41621600E+00, 0.54868100E+00, -.26375300E+01, 0.39202000E-01, -.11070500E+00, 0.27862700E-01, -.37478500E+00, -.11166900E+00, 0.52357900E-01, -.72395800E-01, -.21881500E-01, 0.44179100E+00, 0.16063100E+00, -.29195300E+00, -.58576100E-01, 0.60796800E-01, -.19046900E+00, -.59627800E-01, 0.15013600E+00, 0.61457800E-01, 0.98448400E-01, 0.14748600E+01, -.11147600E+00, -.16703000E+00, 0.20500600E+00, -.30515700E+00, -.28804000E-01, 0.30786600E+00, 0.16621100E+00, -.33335300E-01, -.64351900E+00, -.19741000E+00, 0.49586900E+00, -.70257500E-02, 0.72203200E-01, 0.39910500E+00, 0.81310400E-01, -.94534500E-01, 0.47907900E+00, -.11735700E+00, 0.74430900E-01, -.24013900E+01, -.93379700E+01, 0.65217500E+01, 0.40680500E+01, 0.65830000E+00, 0.45324700E+01, -.23821900E+01, -.79574300E+00, 0.60277000E+00, 0.82010400E+00, 0.50472300E+01, 0.32602800E+01, -.27289300E+00, -.31910800E-01, -.38168500E+00, 0.21278300E+01, -.26015000E+01, 0.10601500E+01, 0.28668800E+00, -.74864300E-01, 0.16188500E+00, -.97540700E+00, 0.12092400E+00, -.21280000E+00, -.53328500E+00, -.16171400E+00, -.18848200E+00, -.14352500E+01, -.64854100E+00, -.21946100E+00, -.12508700E+01, 0.12990000E+01, 0.55469700E+00, -.35176000E+00, 0.61291300E+00, 0.10448800E+01, 0.55102500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26912700E+01, 0.20209400E+00, 0.60351700E+00, -.18739900E+01, -.27559800E+00, -.87805700E+00, 0.66294900E+00, 0.14852400E+01, 0.16756000E-01, 0.23778800E+01, -.38713000E-01, -.65623700E+00, 0.56946300E+00, -.62598300E+00, -.81205900E+00, 0.34245300E+01, 0.54781700E-01, -.80384100E+00, -.46913100E+00, 0.40693200E+00, 0.63690700E-01, -.48809300E+00, -.70324700E+00, -.58675500E-01, -.46077900E+00, -.98676200E+00, -.29263800E+00, 0.64082600E+00, 0.19135300E+00, -.45890900E+00, -.33921000E+00, 0.61691300E+00, 0.31262900E-02, -.15991900E+01, 0.18747100E+00, -.14618300E+01, -.15224300E+01, -.20557700E+00, 0.12881000E+01, 0.71004900E+00, -.12278600E+01, 0.57454700E+00, -.99868700E+00, -.25245700E+00, -.32563000E+00, -.10104400E+00, 0.58883200E-01, 0.45397000E+00, -.84036800E-01, -.21798500E+01, -.44822000E+00, 0.24995000E+00, -.16572200E+00, -.17581300E+00, -.31631700E+00, -.86327200E-01, 0.48755400E-01, 0.62563100E-01, -.84182100E-01, -.16917100E-01, -.31850000E+00, 0.11373200E+00, 0.18002700E+01, -.16120600E+00, -.67226700E+00, -.36039500E-02, 0.80766900E-02, -.39771900E+00, 0.57191700E-01, 0.55670300E+00, -.31464800E+00, 0.47263600E+00, -.29973000E+00, 0.18347200E-02, -.45534600E+00, -.44911100E-01, 0.22420600E+00, -.43284000E-01, 0.13331100E+00, -.27235700E-01, 0.79375500E-01, -.74815600E-01, 0.57540200E-01, -.11109500E+00, -.26292800E-01, -.34150200E+00, 0.23595600E+00, -.22329700E+00, -.11250100E+00, 0.47838500E-02, -.13691000E+00, -.23267400E+00, -.29370900E+00, 0.28791300E-01, 0.42455100E+00, -.58643200E+00, -.36434800E+01, 0.26311000E+00, 0.46269800E+00, 0.26909900E+00, -.12378600E+01, 0.12568700E+00, 0.89537900E-01, 0.30280400E+00, 0.10371300E+00, -.80704400E+00, 0.37198500E+00, -.35509600E+00, -.63677500E-01, 0.88789600E-01, 0.11839300E+00, 0.12782200E+00, 0.44357700E-01, -.49644600E-01, 0.32655100E+00, -.15532100E+01, 0.10740800E+00, 0.32874300E+00, 0.19814000E+00, 0.23035400E+00, -.57808900E-01, -.26378600E+00, -.15173700E+00, -.12108800E-01, 0.85450300E+00, -.30116800E-01, 0.54022100E+00, 0.29519800E-01, -.27591000E+00, 0.68547500E+00, -.26803900E-01, 0.13509500E+00, -.45312900E+00, 0.15784600E+00, -.10906300E+00, 0.44465100E+00, 0.16929600E+02, -.10690000E+02, -.33036600E+01, -.31147300E+01, -.37247900E+01, 0.51706800E+01, 0.18419400E+01, -.30336500E+01, -.36461400E+01, -.48864200E+01, -.24198200E+01, -.17523600E+00, 0.13199100E+01, 0.15396000E-01, -.41276300E+00, 0.94391800E+00, -.88856300E+00, -.29707700E+00, -.73391000E-02, -.39294200E-01, 0.25741400E+01, -.68069000E-01, 0.40941300E+00, 0.65262500E+00, 0.42116600E-01, 0.58290000E-01, 0.26355700E+01, 0.73315000E+00, 0.50072300E+00, 0.26846000E+01, -.13401100E+01, -.48206200E+00, 0.15806800E+00, 0.28446300E+00, -.15305100E+01, -.30781700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.97766200E+01, -.15710600E+00, 0.10601800E+02, 0.59008800E+01, 0.42778800E+01, 0.48747000E+01, -.63798300E+01, -.50194800E+01, -.36080400E+00, 0.50302000E+00, -.18123100E+00, 0.44487900E+01, -.21314500E+00, 0.40409000E+01, 0.48224900E+01, 0.64994900E+01, -.12220900E-01, -.69526900E+00, 0.40045200E+01, -.86496100E+01, 0.15233200E+01, 0.62885900E+01, 0.31815600E+01, -.10124200E+01, -.21937300E+01, 0.38337200E+01, 0.18952700E+01, 0.77018400E+01, -.39591600E-02, -.16147800E+01, 0.87890600E+01, 0.11253800E+01, -.88738700E+00, -.17108200E+02, 0.20235300E+01, 0.13028200E+01, 0.26261500E+01, 0.12187800E+01, 0.51619800E+00, -.22381400E+01, 0.14109900E+01, -.13134000E+01, 0.18083500E+01, 0.82295900E+00, 0.76901100E+00, 0.10031600E+01, 0.33414100E+00, -.97925900E+00, 0.72058700E+00, 0.22552400E+01, 0.95689500E+00, -.23653400E+00, 0.61967500E+00, -.29104200E+00, 0.79703000E+00, 0.50046300E+00, 0.33539000E-01, -.58037000E+00, 0.14507200E+01, 0.24976200E+01, -.24832900E+01, -.76872800E+00, -.97974700E+01, 0.29195800E+01, 0.35965000E+01, -.14320200E+00, 0.26411100E+00, 0.10742200E+01, -.18026200E+00, -.93869900E+00, 0.67613700E+00, -.14201900E+01, 0.14166600E+01, -.70047900E-02, 0.46280000E+00, 0.62773800E-01, 0.15290800E+00, 0.20769800E+00, -.15161600E+01, 0.15235900E+01, -.11752900E+01, 0.68921000E+00, 0.32676200E+01, -.10651200E+00, 0.47488400E+00, 0.65100500E+00, -.17837300E+01, 0.56326800E+01, 0.86500600E+00, 0.68474800E+00, -.22634200E+01, -.94855500E+00, 0.12658700E+01, -.65122500E+01, -.58729100E+00, -.15163200E+01, -.12550000E+00, -.16569100E+01, -.20342200E+00, -.16015300E+00, 0.30123100E+00, 0.20926700E+01, 0.90924400E+00, -.44595100E+00, -.30320700E+00, 0.13673200E+01, 0.32164800E+01, -.19444100E+01, -.91062700E-01, -.14110600E+00, -.41913600E+00, 0.27926700E+01, -.53946700E+00, -.13867800E+00, -.13116500E+01, 0.34030400E+01, 0.55570100E+01, -.20181000E+01, -.42894100E+00, -.14130200E+01, -.27295600E-01, -.25214800E+00, 0.10985800E+01, 0.28022100E+00, 0.28019200E+01, -.55342800E+00, -.17184900E+00, 0.97715400E+00, 0.14832700E+00, -.14099800E+01, 0.32898600E+01, -.16938200E+01, -.45531000E+01, 0.21624100E+01, -.40121200E+00, 0.33053000E+01, -.19125800E+01, -.32229900E+02, -.68072700E+01, 0.62034200E+01, -.54705600E+01, 0.27796700E+01, 0.92943400E+01, 0.81138100E+01, -.65055800E+01, -.29720800E+02, -.27856900E+02, 0.13132000E+01, 0.68687300E+01, -.15297900E+01, -.10083100E+02, 0.92425800E+01, -.76455100E+01, -.21913700E+01, 0.59855100E+00, -.80969300E+00, 0.82873700E+01, 0.84345000E-01, 0.18225100E+01, 0.31966800E+01, 0.83375800E+00, 0.85215200E+00, 0.10753500E+02, 0.37025800E+01, 0.94488500E+00, 0.69411800E+01, -.66248600E+01, -.28129700E+01, 0.25896900E+01, -.61748400E-01, -.32285800E+01, -.10160800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.25742600E+01, 0.49510800E-01, -.14882900E+01, -.15820200E+01, -.57663900E+00, -.62761200E+00, 0.19509700E+01, 0.35535100E+01, -.31870900E+00, 0.11326600E+00, -.87343800E+00, -.26286700E+01, 0.37876900E-01, -.20907000E+01, -.16661800E+01, -.81357000E+00, 0.13913600E+00, -.47761500E+00, -.15303700E+01, -.16312000E+00, -.69365900E-02, -.43096200E+00, 0.13812400E+00, -.19216800E+00, 0.30376000E+00, 0.18013100E+01, -.96213000E+00, -.47623300E+00, 0.14951600E-01, 0.32166500E+00, -.37356400E+00, -.61639400E+00, 0.87242900E-01, 0.34432800E+01, -.81740400E+00, 0.90467600E+00, 0.10094900E+01, -.19334600E+00, -.10017500E+01, 0.81124800E-01, 0.97566800E-01, -.19124200E+00, 0.50719900E+00, 0.10217100E+00, 0.37851700E+00, 0.16605600E+00, 0.11958100E+00, 0.17916500E+00, 0.46383500E+00, 0.26992300E+01, 0.46711700E+00, -.26890100E+00, 0.21206800E+00, -.37514400E+00, 0.13680800E+01, 0.20859000E+00, 0.17178600E-02, -.22992400E+00, 0.75368500E+00, 0.37904200E+00, -.82566300E+00, -.10009400E+00, -.27960700E+01, 0.44397100E+00, 0.42897900E+00, 0.56939300E-01, -.46023900E-01, -.81721900E+00, -.90248800E-01, 0.39433100E+00, -.13204200E+00, 0.15062400E+00, 0.14911200E+00, -.51163200E+00, -.14945900E+00, -.72960100E+00, -.53679500E+00, 0.64366500E+00, -.71408600E+00, -.77139600E-01, 0.60649900E+00, -.69576000E-01, 0.81605300E+00, -.28049500E-02, 0.11991900E+00, -.73614500E+00, 0.46711400E+00, -.26076000E+01, -.15367800E+00, -.15465100E+00, -.87213600E-01, -.97621500E+00, -.16562800E+00, 0.49560500E+00, 0.76245900E-01, -.19220500E+00, 0.68783700E-01, -.64638300E+00, 0.55289400E+00, 0.17945600E+00, 0.25654400E+00, 0.96895600E-01, 0.38710200E+00, -.38479000E-01, 0.11467200E+00, 0.35374600E+00, 0.23442500E+00, -.35183800E+00, -.92069200E-01, -.23001300E-01, -.20531300E+00, 0.96321300E+00, -.25795200E-01, -.54593600E-01, -.10988600E+00, -.22693000E+00, -.87473700E-01, -.20259900E+00, -.28823700E+00, 0.22001200E-01, 0.78346500E-02, -.19541700E+00, -.58070100E+00, -.30984200E-01, 0.11544300E+00, 0.95245600E-01, 0.57079700E+00, 0.67500400E+00, -.98081700E-01, -.23526000E+00, 0.27082900E+00, -.20969000E+00, 0.46604300E+00, -.16050500E-01, 0.40423400E-01, -.12781500E+00, -.14922000E-01, 0.15347600E+00, 0.78249100E+01, 0.79412200E+00, 0.47090000E+00, 0.89386800E+00, -.34888700E+01, 0.16367800E+01, 0.23904700E+01, 0.10206400E+02, 0.38472300E+01, -.18420800E+00, -.95302400E+00, 0.49024400E+00, 0.31674300E+01, -.15474700E+01, 0.18845400E+01, 0.34472200E+00, -.19158200E-01, 0.12533000E+00, -.97927100E+00, -.14257200E+00, -.61151700E+00, -.36606900E+00, -.12550000E+00, -.50512600E+00, -.14833300E+01, -.41717500E+00, -.33291600E+00, -.85606800E+00, 0.12660800E+01, 0.43151600E+00, -.31365100E+00, -.58644500E+00, -.14387000E+01, 0.91088400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25388900E+01, -.36693800E-01, 0.51948000E+01, 0.15303300E+01, 0.54138500E+00, 0.10943500E+01, -.23324300E+01, -.21302700E+01, 0.13533700E+00, 0.32216800E+00, 0.40182900E+00, 0.15003700E+01, -.29288400E+00, 0.18679900E+01, 0.16324700E+01, 0.10505700E+01, 0.29690000E+00, -.54288600E-01, 0.67595500E+00, -.58740100E+00, -.19423100E+01, 0.23282400E+01, 0.92365800E+00, 0.17119500E+00, -.43147700E+00, 0.51317200E+00, -.24661200E+00, 0.23526200E+00, 0.13416900E+01, -.24946400E-01, -.22885000E+00, 0.24996300E+00, -.18144900E+00, 0.38408700E+01, -.10435300E+01, 0.12856400E+01, 0.16332200E+01, -.93981500E+00, -.67592600E+00, -.19815400E+00, -.11138300E+00, -.30249300E+00, -.14525600E+00, -.45903300E-01, 0.16462600E+00, -.18762500E+00, -.30215000E+00, 0.12169200E+01, 0.11309800E+00, 0.27735300E+01, 0.17873700E+00, 0.17406800E+00, 0.49418000E+00, -.74614700E+00, -.10931500E+01, 0.27556600E-01, 0.66654600E-01, -.24709000E+00, 0.71077000E+00, 0.13299100E+01, -.68836600E+00, 0.21343500E-01, -.33139600E+01, 0.17207000E+01, 0.18924800E+01, 0.22506800E+00, 0.51813600E-01, -.20388000E+01, 0.35649900E+00, 0.16057100E+00, -.84598500E+00, 0.15811100E-01, -.37348500E+00, -.21922900E+00, -.30210400E-01, -.26878400E+00, -.48835500E+00, 0.85890400E+00, 0.29279500E+00, -.47703900E+00, -.96136700E+00, 0.64356600E-01, -.25479700E+00, 0.30374400E+00, -.81421800E-01, 0.15388400E+01, 0.24563100E+00, 0.10339900E+01, -.93510700E-01, 0.39513700E+00, -.48062000E+00, -.36289200E+00, -.68508400E+00, 0.18824400E+00, 0.22744000E+00, -.85978500E+00, -.15568000E+01, 0.28377300E+00, 0.35476400E+00, 0.31324500E+00, -.37769700E+00, -.11057500E+01, -.33406000E+00, 0.12284900E+00, 0.12664600E+00, 0.93857600E-01, -.17504000E+00, -.12254800E+00, -.10907900E+00, -.48255800E-01, 0.12109400E+00, 0.16373900E+01, -.60904600E-01, -.43798300E-01, -.45460300E+00, 0.19674200E+01, 0.20234900E+01, -.91441800E-01, -.77657800E-01, -.24211900E+00, 0.64756600E-01, -.18942500E+00, -.29595200E+00, 0.17326900E+00, 0.42181600E+00, 0.50962800E-01, 0.11729100E+01, 0.93889800E+00, 0.10612400E+00, -.32965000E+00, 0.24866100E+00, -.27398800E+00, -.91225700E+00, -.73585100E-01, 0.14856800E-01, 0.10139800E+01, 0.12764700E+00, 0.13201900E+00, 0.31908800E+00, 0.23123500E+01, -.42064600E+01, -.13575000E+01, -.17323300E+01, 0.33233300E+01, 0.23633500E+01, -.33934800E+01, -.40734700E+01, -.71736900E+00, -.75112600E+00, 0.16424800E+01, 0.15472700E+01, -.26225100E+00, 0.18227300E+00, -.78448900E+00, 0.16240200E-01, -.84726700E-01, 0.30357500E+01, -.19978700E+00, 0.58452400E+00, 0.35138600E+00, 0.71721900E-01, 0.45282600E+00, 0.29257000E+01, 0.40133900E+00, 0.76601900E+00, 0.32250000E+01, -.11267400E+01, -.53825000E+00, 0.10562400E+00, -.69962200E+00, -.11709300E+01, 0.88498000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.69636000E+01, 0.88706100E-01, -.49708700E+01, -.41294800E+01, -.13234800E+01, -.21212200E+01, 0.39539000E+01, 0.73835300E+01, -.18953800E+01, 0.67511300E+00, -.15541500E+01, -.56895300E+01, 0.13157300E+00, -.42493400E+01, -.34563700E+01, 0.50582700E+00, 0.74386700E+00, -.87978600E+00, -.30915200E+01, 0.24614000E+01, -.99441600E+00, -.26169800E+01, -.46070900E-01, -.67390300E-01, 0.64155900E+00, 0.34961400E+01, -.36501000E+01, -.39888800E+00, 0.22562300E+00, 0.21735000E+00, -.42605800E+00, -.16592400E+01, -.69978500E+00, 0.46501200E+01, -.13634200E+01, 0.15230700E+01, -.15527500E+01, -.55341100E+00, -.18540900E+01, 0.42361600E+00, -.48703000E+00, 0.70526600E+00, 0.17744300E+00, -.34053200E+00, 0.10203100E+01, -.88728900E+00, -.10728600E-01, -.15769800E+01, -.49679000E+00, -.48597600E+01, 0.24317000E+00, -.19619900E+00, -.68279400E+00, -.42486100E+00, -.16492800E+01, -.86165200E-01, 0.15175600E+00, 0.21607900E+00, -.20700400E+00, 0.39346100E+00, -.50016100E+00, 0.32527600E+00, 0.36866900E+01, 0.26207200E+00, -.66518700E+00, 0.31189900E+00, 0.67990000E-01, -.18536900E+01, 0.10760600E+01, 0.60286600E+00, -.92106700E-02, -.36076900E-01, -.16504300E+01, 0.79316900E+00, -.17061600E+01, -.32561100E+00, -.66370600E+00, 0.56085700E+00, 0.14529400E+00, -.46728200E+00, -.19622800E+00, -.22992100E+00, -.49769200E+00, -.36881100E+00, 0.42398200E+00, -.17016100E+01, 0.60834500E+00, 0.12901300E+01, -.31374200E+00, -.51859400E+00, -.62675400E-02, -.48027700E+00, -.35295500E+00, 0.10115400E+01, -.20418000E+00, -.25603600E+00, 0.31674100E+00, -.17556800E+01, 0.11500900E+01, 0.23791400E+00, 0.71500000E+00, 0.46230300E+00, 0.39795300E+00, -.21364100E+00, 0.26259700E+00, -.16879500E+00, -.34259400E+00, 0.78664600E-01, -.90523300E-01, 0.16449200E+00, -.28247000E+00, -.74453000E+00, 0.11287400E+00, 0.13194600E-01, -.11842200E+00, -.19764400E+00, 0.11928100E+01, -.13293100E+00, -.28411600E+00, 0.38165300E+00, 0.13529300E+00, -.26578900E+00, -.87349600E-01, -.39125400E+00, 0.71185700E+00, 0.30258600E+00, -.44901000E-01, 0.30215700E+00, -.49435800E-01, -.43659800E+00, -.14977500E+00, -.50301100E-01, 0.40354700E+00, -.49390700E+00, 0.55893400E-01, 0.31178600E-01, 0.10063800E+01, -.16766400E+00, 0.84844800E+00, 0.86267500E+00, 0.49271300E+01, -.58000600E+00, 0.45302500E+01, 0.15495600E+00, -.17575200E+01, -.23124800E+01, -.13177200E+00, 0.18335900E+01, 0.40718500E+00, -.16646500E+01, -.44803600E+01, 0.32743000E+01, -.12701300E+01, 0.47247400E+00, 0.40782200E+00, -.35779700E+00, -.24741800E+01, -.17853600E+00, -.36586400E+00, 0.19147000E-01, 0.37542400E+00, -.14535600E+00, -.14933700E+01, 0.13445200E+00, -.99318100E+00, -.33142900E+01, -.19451800E+00, -.75730000E-02, 0.10427400E+01, 0.35221700E+00, 0.11302400E+01, -.87512600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.21376400E+02, 0.65433700E+00, -.21366500E+02, -.11652000E+02, -.61747400E+01, -.68046500E+01, 0.12286900E+02, 0.22244200E+02, -.87199600E+00, -.65644300E+00, -.45431600E+01, -.17079100E+02, 0.18001900E+01, -.16628700E+02, -.14849800E+02, 0.12112900E+01, 0.34360100E+00, -.27000600E+01, -.84910300E+01, 0.15403600E+01, -.15193400E+01, -.57679800E+01, -.15656500E+01, 0.46078300E+00, -.28945200E+00, 0.21577400E+01, -.33489800E+01, 0.41901700E+01, 0.20138300E+01, 0.14312600E+01, -.18043100E+01, -.49306300E+01, 0.12899900E+01, 0.18333500E+02, -.99495100E+00, -.44500600E+01, -.46429900E+01, 0.64526400E+00, -.91108400E+00, 0.29176900E+01, -.66326400E+01, 0.21489700E+01, -.50812000E+01, -.18943300E+00, -.35032900E+01, 0.63665100E+00, 0.13366700E+00, 0.78144500E+01, 0.21725000E+01, -.10556500E+01, -.19816800E+01, -.25791600E+00, -.26316800E+00, 0.57397400E+00, -.31187700E+01, 0.36637300E+00, 0.17721700E+00, 0.12951900E+01, -.31841600E+01, -.21025600E+01, 0.23305400E+01, 0.89613100E+00, 0.18045000E+02, -.26723400E+01, -.37721500E+01, -.48939900E-01, 0.13058100E+00, 0.36825000E+01, 0.38676700E+00, 0.29775900E+00, -.49582200E+00, 0.10045500E+01, -.28291500E+01, 0.76920100E+00, 0.17222000E+01, 0.31114700E+01, 0.15390700E+01, -.25316100E+01, 0.21329600E+01, 0.40510600E+00, -.84906400E+00, -.38974400E-01, -.19664200E+01, 0.98702600E+00, -.80743800E+00, 0.53868800E+00, -.19208600E+01, 0.14727100E+02, -.61855300E+00, 0.73345400E+00, 0.23810400E+00, 0.31130300E+01, 0.35354100E+00, -.77513600E+00, 0.19824800E+00, -.22920800E+01, -.40947700E+01, 0.53529600E+01, -.26528400E+01, -.49345700E-01, -.49363800E+01, 0.27789600E+00, -.27900400E+01, 0.11355100E+01, -.61264200E+00, -.29166600E+01, -.75000300E-01, 0.10012700E+01, 0.28837800E+00, -.19380600E+00, 0.19065000E+01, -.32252100E+01, -.23995300E+00, -.16945800E+00, 0.11236900E+01, -.62472700E+01, -.41712000E+01, 0.42914900E+01, 0.13814100E+01, 0.24274700E+01, -.83510000E-01, 0.77056200E+00, 0.15041800E+01, -.12827900E+01, -.17291600E+01, -.23493000E+00, -.36890800E+01, -.39782900E+01, 0.10857100E+00, 0.27609900E+01, -.25978300E+01, 0.20453700E+01, 0.21329100E+01, 0.13797600E+01, -.55852200E+00, -.19134200E+01, 0.14005100E+01, -.14498800E+01, -.54065000E+01, -.62520100E+00, 0.79559500E+00, 0.16894000E+02, 0.14372600E+01, 0.41421800E+01, -.24992200E+00, -.59817700E+01, -.89558300E+01, -.17835100E+01, 0.93648300E+00, -.31111000E+01, 0.87552600E+00, -.68067700E+00, -.13381000E+01, 0.45913600E+00, 0.26558300E+00, -.35996200E+00, 0.40967900E+01, 0.66821700E+00, -.28337300E+00, 0.24034200E+01, 0.35680000E+00, 0.12187700E-01, 0.33769800E+01, 0.18598500E+01, 0.86020700E-01, 0.37064300E+01, -.16757700E+01, -.17610400E+00, 0.79198800E+00, -.15855600E+00, 0.72567900E+00, 0.20528900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.32341600E+01, -.11942300E-01, 0.67069200E+01, 0.99778900E+00, 0.68744200E+00, 0.10158200E+01, -.17673800E+01, -.31186300E+01, -.85296000E-01, -.29451900E+01, 0.13142900E+01, 0.11109000E+01, -.12112700E+01, 0.20721000E+01, 0.27864500E+01, -.25526500E+00, 0.41203900E+00, 0.24661000E+00, 0.12946700E+01, -.36350200E+00, 0.52933400E+00, -.43256400E+00, 0.68760000E+00, 0.66782000E+00, 0.30547700E+00, 0.13724800E+01, 0.31459400E+00, 0.13244100E+01, 0.99843700E+00, 0.46341900E+00, 0.20203800E+01, -.21837700E+01, 0.15502700E+00, -.62697300E+01, 0.18980800E+00, 0.19881300E+01, 0.27115400E+01, -.53693200E+00, -.13471200E+01, -.94254400E+00, 0.15510000E+01, -.14630600E+01, 0.56757800E+00, 0.12644600E+00, -.61922200E-01, 0.37957100E+00, -.67152700E-01, -.82314700E+00, -.66944200E-01, 0.14303000E+01, -.42432900E-01, 0.21986900E+00, 0.16830400E+00, 0.85567400E-01, -.97963000E+00, -.12407900E+00, -.59680200E-01, -.17494600E+00, 0.57745600E+00, 0.45066300E+00, -.30928900E-01, -.18593100E+00, -.33198600E+01, 0.68460400E+00, 0.14293500E+01, -.30190800E+00, 0.27319400E+00, 0.63445400E+00, -.37425800E+00, 0.34586000E+00, 0.23154000E-01, -.17729000E+00, 0.66805900E+00, -.78437800E-01, -.31731500E+00, -.12766700E+00, 0.29256900E+00, -.19263500E+00, -.12407200E+00, -.21433500E+00, -.34030600E+00, -.41266900E-01, -.13994300E+00, -.87602600E-01, 0.30518400E-01, 0.13283100E+01, 0.41563900E+00, -.24234500E+01, 0.41007800E+00, 0.43374600E+00, -.62739400E+00, -.26007700E+00, -.14538900E+00, -.32475600E+00, -.50464300E-01, -.65616800E+00, -.57737900E+01, -.17339100E+01, 0.12863400E+01, 0.27035400E+00, -.12700600E+01, -.14120200E+01, -.63875000E+00, -.24250700E+00, 0.27320200E-01, 0.81310100E+00, -.12301700E+00, 0.58278100E-01, -.11457400E+00, -.11770100E+00, 0.32435900E+00, 0.14044400E+01, -.24450800E+00, 0.13688600E+00, -.21415600E+00, 0.31055000E+00, -.15541200E+00, -.33273900E+00, -.95231600E-01, -.55306700E+00, 0.30315300E-01, -.28935700E+00, -.13950500E+00, 0.10174600E+00, 0.38486600E+00, 0.38558200E-01, 0.49396500E+00, 0.14334800E+00, -.19359900E+00, -.61942800E+00, 0.56020000E+00, -.17891800E+00, -.64537100E+00, -.18370500E+00, 0.76126400E-01, -.57588000E+00, -.21509700E+00, -.48401600E-01, 0.58732400E+00, 0.58143000E+00, -.10683900E+00, 0.83234100E-01, 0.53278500E+01, -.42514000E+00, -.30635700E+01, -.28674900E+01, -.11947700E+01, 0.12420200E+01, 0.20903800E+01, -.20129400E+01, -.43516800E+01, -.39575900E+00, -.19672500E+01, -.13637100E+00, 0.18383900E+00, -.16929900E+00, -.49001100E+00, 0.13470500E+00, 0.27367400E+00, 0.22144500E+01, 0.18050600E+00, -.20111900E+00, -.72954800E-01, 0.16924600E+01, -.25375200E+00, -.91519400E+00, -.17962300E+00, -.25143700E+00, 0.43463900E+00, 0.70622100E+00, -.18663100E+00, -.66580100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13713900E+01, -.54899400E-01, 0.52389100E-01, 0.78564200E+00, 0.93789300E-01, 0.30675000E+00, -.45404700E+00, -.18305800E+01, 0.30128700E+00, 0.51155000E-01, 0.19765400E+00, 0.14384500E+01, -.14798700E-01, 0.10522800E+01, 0.10872300E+01, -.11442200E+01, -.23714800E+00, 0.33005500E+00, 0.41998700E+00, -.51304100E+00, 0.32061500E-01, 0.34293800E+00, -.31459300E+00, -.17649800E+00, -.24408400E+00, -.48062000E+00, 0.64107100E+00, 0.33286300E+00, -.24460000E+00, -.35649600E+00, 0.37535700E+00, 0.11132000E+01, 0.11203400E+00, -.59662100E+00, 0.46915100E+00, -.50331100E+00, 0.61460400E-01, 0.29273400E+00, 0.66521600E+00, -.37365600E-01, -.83915100E-01, -.31349000E-01, -.12121500E+00, 0.75474600E-01, -.29483400E+00, 0.16541200E+00, -.12198700E-01, 0.86135900E+00, 0.72821700E-01, -.22690100E+00, -.17743200E+00, 0.50236700E-01, -.75438300E-01, 0.74706600E-01, -.21212900E+00, -.22569100E-01, -.12303400E-01, 0.76850100E-01, -.28390900E+00, -.32610900E+00, 0.45636800E+00, 0.32126900E-01, 0.47712100E+00, -.32867100E+00, -.40768200E+00, -.97368100E-01, 0.10294600E+00, 0.91507600E+00, -.17590600E-01, -.32985300E+00, 0.10642600E+00, 0.11957300E+00, 0.33451000E+00, -.80036500E-01, 0.42529500E+00, 0.12210300E+00, 0.22303500E+00, -.33924900E+00, 0.81335900E-01, -.44316700E-01, 0.58303300E-01, 0.66297500E-02, -.45685800E+00, -.22354800E+00, -.12842000E+00, 0.24406500E+00, 0.21781400E-02, -.16187200E+01, 0.34759400E+00, -.77120300E-01, 0.14048800E+00, 0.35927000E+00, 0.65467800E-01, -.63074100E-01, 0.79512400E-01, 0.13379100E+00, -.47408100E+00, 0.90955600E-01, -.98123400E-01, -.62009100E-01, 0.25244900E+00, -.32777600E+00, -.87540800E-01, -.23764600E-01, 0.98022000E-02, -.87916700E-01, -.55350500E-01, 0.48643600E-01, 0.24586200E-01, 0.34981000E-01, -.41522700E-01, -.23730200E+00, 0.40807100E-01, 0.34872000E-02, -.18378200E-01, 0.38222000E+00, 0.22348900E+00, 0.56357500E-01, -.15456800E-01, -.49398500E-01, 0.11197400E-01, 0.51112300E-01, 0.10325000E+00, 0.68055200E-01, -.76160000E-01, 0.19868600E-01, 0.83041700E-02, -.13240400E+00, 0.84199100E-01, 0.15368500E-01, 0.14671800E-02, -.29320600E-01, -.31945900E-01, 0.10142900E+00, -.23022000E-01, 0.22062100E+00, 0.12409400E+00, 0.12257600E-01, -.13277100E+00, 0.16402900E+00, 0.18520400E+00, 0.26171700E-01, -.21069500E+00, -.13781500E+01, 0.11199600E+00, 0.11203800E+01, 0.11917000E+01, 0.28534500E+00, -.16123600E+00, -.87610200E-02, -.19311800E+00, -.75742100E+00, 0.99796600E-01, 0.52023300E-01, -.35457300E-01, 0.49271700E-01, -.93377300E+00, 0.40284100E-01, -.22271200E-01, 0.15991500E+00, -.48602300E-01, -.95679900E-01, -.10408200E+01, 0.10948000E-01, -.33753300E-01, -.81805000E+00, 0.31485300E+00, 0.69054600E-01, -.17105400E+00, 0.14853200E+00, 0.12172000E+00, -.15515200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.57385500E+01, -.37069900E+00, 0.36383400E+01, 0.32607900E+01, 0.18819200E+01, 0.13040200E+01, -.45912000E+01, -.73534400E+01, -.10048300E+01, 0.18831600E+00, 0.22532800E+01, 0.53518800E+01, -.37178200E+00, 0.64814100E+01, 0.49637700E+01, 0.22270200E+01, 0.27038900E+00, 0.10933200E+01, 0.32496900E+01, 0.42655500E+01, 0.20174500E+00, -.88941400E+00, -.99965200E+00, 0.83460300E+00, -.12148200E+00, -.24948100E+01, 0.46334800E+00, -.17130700E+01, -.77462100E+00, -.92322900E+00, 0.14686200E+01, -.12655600E+01, -.63765900E+00, -.40572900E+01, 0.14758800E+01, 0.79670900E+00, -.17482300E+01, -.15055900E+00, -.18270600E+00, -.13127500E+01, 0.12334900E+01, 0.30574300E+00, -.86757000E+00, -.16204500E+00, -.43465900E-01, -.10106300E+01, -.13660100E+00, -.18520900E+01, -.94189200E+00, -.10410500E+02, -.55146600E+00, 0.24501100E-01, -.43836600E+00, 0.41348100E+00, -.12121500E+01, -.46890300E+00, -.44182200E-01, 0.12142000E+00, -.39012200E+00, -.10715200E+00, 0.57313000E+00, 0.34701900E-01, 0.18469800E+01, -.13481700E+00, 0.76637500E+00, 0.20508900E+00, -.17769800E+00, -.83072600E-01, 0.16756000E+00, -.49849000E+00, 0.24883900E+00, -.64532600E+00, 0.98894200E-01, 0.10312300E+00, 0.24619700E+00, 0.70953700E+00, -.26260900E+00, -.28370100E+00, 0.44454500E+00, -.11561200E+00, -.56734800E+00, 0.57799200E-01, -.11265300E+01, 0.43029000E+00, -.58349400E-01, 0.50524400E+00, -.53816500E+00, 0.39143500E+01, -.52965100E+00, 0.37039400E+00, 0.34949200E+00, 0.76284200E+00, -.38883100E-01, 0.64607900E-01, -.22685900E+00, -.35566200E+00, 0.56956400E+00, 0.95393500E+00, -.72334400E+00, -.13274100E+00, -.46003100E+00, 0.85248400E-01, -.23297600E+00, 0.20767900E+00, -.16357000E+00, -.70490200E+00, -.30411100E+00, 0.47885000E+00, -.27903600E-01, -.37076700E-03, 0.28985300E+00, 0.48636700E+00, -.14421300E+00, -.11390200E+00, -.40158700E+00, 0.10171900E+00, 0.41967900E+00, 0.11964300E+01, -.99330200E-01, -.38608700E-01, 0.41646800E-01, 0.25682700E-01, -.20926400E+00, -.36167100E+00, 0.44381500E-01, 0.63051200E-01, -.59251400E+00, -.35428500E+00, 0.41170500E-01, -.56968400E+00, -.65601300E-01, 0.44752800E-01, -.57471100E+00, -.80507700E+00, 0.15361800E+00, -.91251900E+00, -.10041100E+01, -.13550900E+00, -.46260500E-01, 0.14691100E+01, 0.55205700E-01, -.15983600E-02, 0.15904500E+00, -.75028500E+00, -.74829000E+01, 0.22882700E+01, 0.49929800E+01, -.18749900E+01, 0.60957900E+01, -.25499600E+01, 0.16310100E+01, -.55403900E+01, -.85742000E+00, 0.70302800E+00, 0.11845800E+00, -.77194600E-01, -.30573500E+01, 0.20594900E+00, -.48770700E+00, -.42252500E+00, 0.95725800E-01, -.42474400E+00, -.31343800E+01, -.65991200E+00, -.19857100E+00, -.33554000E+01, 0.11988800E+01, 0.27148700E+00, -.32450400E-01, 0.10884900E+01, 0.29876000E-01, 0.49106000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.12056600E+02, -.18127800E+00, 0.14386900E+02, 0.59518900E+01, 0.36404800E+01, 0.44099700E+01, -.50154300E+01, -.11329100E+02, 0.10860400E+01, -.10395400E+02, 0.28564300E+01, 0.81293900E+01, -.70009500E+00, 0.36972700E+01, 0.10381300E+01, 0.23677900E+01, -.11251300E+01, 0.17126300E+01, 0.59113400E+01, -.82290000E+01, -.15849600E+00, 0.39796100E+01, 0.37031500E+01, -.21999900E+01, -.24097000E+00, 0.13222100E+01, 0.16966000E+01, 0.55369000E+01, 0.13272500E+01, 0.11593000E+01, 0.44221700E+01, -.47767200E+01, 0.33891000E+00, -.17688200E+02, 0.15371500E+01, 0.12827700E+01, 0.91704500E+01, 0.10407600E+01, 0.20139900E+01, 0.13237200E+01, 0.21921300E+01, -.28214900E+01, -.15048200E+00, -.51774600E+00, 0.74251100E+00, -.49096900E+00, 0.42372600E+00, -.87416800E+00, -.19118400E+01, 0.34101500E+01, 0.50272300E+00, -.93429500E+00, 0.10463700E+01, 0.87446400E+00, -.14387800E+01, 0.18863100E+00, -.11256500E+00, -.46015900E-01, -.47585300E+00, -.78331300E+00, 0.20181800E+01, 0.49427000E-01, 0.20320500E+01, -.72392900E+00, 0.14135300E+01, 0.43518300E+00, -.43867800E+00, -.24364100E+00, -.17638900E+00, 0.62562300E-01, 0.38589400E-01, 0.38433900E+00, -.12489900E+01, 0.10290800E+01, -.25328000E+01, 0.37530000E+00, -.48124100E+00, 0.61505500E+00, 0.78971400E+00, 0.76181200E+00, -.13207900E+01, -.42364400E-01, 0.37191100E+00, -.14133700E+01, 0.18886100E+01, -.12464000E+01, 0.14828300E+00, 0.23224700E+00, -.52745700E+00, -.19177800E+01, 0.83019800E+00, -.13012600E+01, 0.16086000E+01, -.53322600E+00, -.23175000E+01, -.11093200E-01, 0.58231200E+01, -.10711000E+01, 0.17604900E+00, -.39305100E+00, 0.94333400E+01, -.16814800E+01, 0.69643300E+00, -.88121500E+00, 0.60234600E+00, -.99669200E+00, 0.15215800E+00, -.48475600E+00, -.47229200E+00, 0.83003100E+00, -.17276700E+01, 0.63305400E+00, 0.51931700E+00, -.35950900E-01, -.91072800E+00, 0.69421600E+01, 0.37678700E+01, -.12628500E+01, -.88845600E+00, -.15826200E+01, 0.10990600E-04, -.47453900E+00, -.84541100E+00, 0.11487700E+00, 0.11954200E+00, -.39060100E+00, 0.32150900E+01, 0.22913500E+01, 0.34699300E+00, 0.16031400E+01, 0.86125100E+00, -.70405800E+00, 0.13979900E+01, -.50290300E+00, 0.17727600E+00, 0.22951600E+01, -.17638200E+00, 0.56508900E+00, 0.25080400E+01, -.22156700E+01, -.64159800E+00, -.21914500E+00, 0.18619700E+01, -.14794000E+01, -.20996200E+01, -.23611000E+02, 0.72193300E+01, -.20579500E+01, -.68052600E+00, 0.32781700E+00, 0.79912100E+01, -.93088100E+01, 0.28957100E+01, 0.83203400E+00, 0.35388400E+00, -.42494700E+00, -.54875900E+01, -.37016500E+00, 0.15038800E+00, -.53133200E+01, 0.40681900E+00, 0.11901600E+01, -.59035000E+01, -.38805200E+01, 0.13875400E+01, -.51296400E+01, 0.20802700E+00, -.18835000E-01, -.38229900E+00, 0.18337200E+00, 0.16794100E+01, 0.28549400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16795900E+02, -.13090100E+01, 0.14051100E+02, 0.78685400E+01, 0.41008400E+01, 0.44931600E+01, -.42546700E+01, -.15345100E+02, -.15545200E+01, -.34528100E+01, 0.33938000E+01, 0.11904400E+02, -.16008000E+01, 0.15472000E+02, 0.10395000E+02, -.44696900E+01, -.48822300E+00, 0.21910600E+01, 0.61646100E+01, 0.21289400E+01, 0.44350600E+01, 0.31683700E+00, -.29793800E+01, 0.18037800E+01, -.17974800E+00, -.20791800E+01, 0.52172500E+01, -.45625800E+01, -.79367000E+00, -.37344600E+01, 0.55662000E+01, -.16066500E+01, 0.59964300E+00, -.13706200E+02, -.22769600E+00, 0.43282100E+01, 0.10098800E+02, -.32987400E+01, 0.51329800E+01, -.21335600E+00, -.32580900E+01, -.17595200E+01, -.24876900E+01, -.22629600E+00, -.53451900E+00, -.17680100E+00, 0.22403500E+00, 0.63310300E+01, 0.11248300E+01, -.12725100E+01, 0.45120300E+00, -.24741600E+00, 0.10357300E+01, -.15458500E+01, 0.26566200E+01, 0.36510600E+00, -.50674700E+00, -.54925000E+00, 0.15781500E+01, -.88755800E+00, 0.26847300E+01, -.77165100E+00, -.65466800E+01, -.16084300E+01, 0.30127600E+01, -.62925400E-01, -.39896300E+00, -.12486000E+01, -.16535100E+01, -.19512700E+01, 0.63806600E+00, 0.76587600E-01, 0.71388100E+00, -.13650200E+01, 0.29728700E+00, -.96865500E+00, 0.85099600E+00, -.16770400E+00, 0.10765000E+01, -.15502400E+01, -.62554000E-01, -.58992600E+00, -.18437000E+00, 0.50015600E+00, -.78474100E+00, 0.40192400E+01, -.13313200E+01, 0.46772200E+01, -.65295700E+00, 0.22619300E+01, 0.12476900E+01, 0.55379200E+01, 0.54753600E+00, -.20626500E+01, -.10682100E+01, 0.53713400E+01, 0.25606500E+01, 0.25279800E+01, -.29221800E+01, -.13234900E+01, 0.21566300E+01, -.86142000E+00, 0.35280300E+00, -.95767600E+00, 0.24689500E+00, 0.33506000E+01, 0.11675800E+01, -.22673900E+01, -.27241800E+00, 0.79894000E-01, -.11648900E+01, 0.42139500E+01, 0.42254200E-01, -.12038400E+00, -.15682500E+01, 0.80435600E+01, 0.57139400E+01, 0.32052200E+00, -.10378900E+01, -.18910000E+00, 0.41982400E+00, 0.49073800E+00, 0.37729700E+00, 0.26592500E+00, -.10114100E+01, 0.30755500E+00, 0.18577000E+01, 0.24557600E+01, 0.30931600E+00, -.10450600E+01, -.20186800E+00, -.72003000E+00, 0.54656700E+00, 0.24757300E-01, 0.14525000E+00, 0.22795300E+01, -.34641700E+00, 0.94070500E+00, 0.31341900E+00, -.24566700E+01, 0.59669300E-01, -.24877900E+00, -.14015600E+01, -.27740700E+01, -.19025400E+01, -.11073800E+01, 0.26833600E+02, -.54182600E+01, -.11667400E+01, -.75737800E+00, 0.18146300E+02, -.30498100E+02, 0.80958900E+01, 0.10701800E+01, 0.14002900E-01, 0.12721900E+00, -.17201100E+02, -.12180900E+01, -.12062400E+01, -.43903700E+01, -.15969900E+00, -.27066400E+00, -.19950100E+02, -.41518300E+01, 0.91113200E+00, -.15800600E+02, 0.48110500E+01, 0.98078000E+00, -.28268000E+01, 0.17301200E+00, 0.23637200E+01, 0.62137900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.24738900E+01, -.57704700E-01, 0.63985800E+00, 0.20381500E+01, 0.81965500E+00, 0.13010100E+01, -.70644700E+00, -.12152600E+01, 0.10191300E+01, 0.19532000E+01, -.99961000E-01, 0.14762300E+01, 0.61441300E+00, 0.37026800E+00, 0.47253800E+00, -.12760600E+01, -.49731100E+00, 0.28578400E-01, 0.38927600E+00, -.32228100E+01, 0.43812200E+01, -.97976900E+00, -.75912100E+00, -.46976000E+00, 0.29561700E+00, 0.71214800E+00, 0.24253800E+01, -.12680700E+01, -.80955400E+00, -.72200700E-01, -.81615800E+00, 0.12839900E+01, 0.40774800E+00, 0.15414900E+01, -.80869300E-01, -.53326800E+00, 0.45923700E+00, 0.75366800E+00, -.24778000E+00, 0.93664800E+00, 0.11836100E+01, 0.72362900E-01, 0.56247500E+00, 0.24467700E-01, 0.75375000E-01, 0.45564300E+00, 0.28372300E-01, 0.24064100E+01, 0.64681000E-03, 0.26974400E+01, 0.34088900E+00, -.10377300E+00, -.14784600E+00, -.57568700E+00, 0.11726900E+00, 0.24051800E+00, -.64502900E-02, 0.83278300E-01, -.51933200E+00, -.49682800E+00, 0.10537900E+01, 0.13014600E+00, 0.19443500E+01, -.35082200E+00, -.84199500E+00, -.15620200E+00, 0.18640000E+00, 0.43510000E+00, 0.19245500E+00, -.10524600E+01, 0.37093800E+00, 0.22611200E+00, -.27771400E-01, 0.20696400E-01, 0.39187500E+00, -.35545000E+00, -.11970400E-01, 0.13896000E+00, 0.11746300E+00, -.50767500E-02, 0.47014900E+00, 0.82223300E-01, -.12359300E+00, -.23693500E-01, 0.60057800E-01, -.10989100E+00, -.12646600E-01, 0.10510700E+01, 0.90356700E-01, 0.36584500E-01, -.76551000E-01, -.77578100E-01, -.16839800E+00, 0.34406000E+00, -.10099100E-01, -.48682000E+00, 0.14389100E+01, 0.78361500E-01, 0.15392500E-01, 0.22431500E-01, 0.21554000E+00, -.40290200E+00, -.92183500E-01, -.91931200E-02, 0.40397100E-01, -.10548900E+00, -.28063600E-01, -.74942600E-01, -.10804400E-01, 0.76107200E-01, -.11748500E+00, -.98377200E+00, 0.13771200E+00, 0.23435500E-01, 0.13970400E+00, -.34679800E+00, -.62836000E+00, -.27098000E+00, -.79785400E-01, -.20998700E+00, -.58112800E-01, 0.31658500E-01, -.12930700E+00, -.13897800E+00, -.55047900E-01, -.92446600E-01, 0.48789500E+00, -.32112400E-01, 0.15373800E+00, 0.54688900E+00, -.21947100E-01, -.28194200E-01, 0.20774700E+00, 0.17477300E+00, -.83391600E-01, 0.70424600E+00, 0.44525600E+00, -.67109400E-01, -.35088800E+00, 0.27983100E+00, 0.23333600E+00, 0.67052500E-01, 0.11499800E+00, 0.11868400E+01, 0.34482300E-01, -.50748700E-01, -.13930000E-01, -.29526300E+01, -.33643800E-01, 0.67009400E+00, 0.11654300E+01, 0.11455700E+01, 0.45356000E+00, 0.19085900E+00, -.18750700E-01, 0.17322600E-02, -.35975900E+00, 0.30799600E-01, 0.76946300E-01, -.98869400E+00, -.58675900E-02, 0.95940500E-01, -.25945100E+00, -.46924300E+00, 0.13900200E+00, -.14624900E+00, 0.22589000E-01, 0.17223700E+00, -.44524100E-01, -.11414100E+00, 0.30632100E-02, 0.22688500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49439300E+01, 0.68869400E-01, -.69804500E+01, -.27869200E+01, -.22814800E+01, -.22026400E+01, 0.22724000E+01, 0.37697200E+01, -.11930500E+01, 0.81490300E+00, -.73197800E+00, -.29597100E+01, 0.67609500E+00, -.24249000E+01, -.34503300E+01, 0.19193400E+01, -.81143500E-01, -.34129400E+00, -.13200700E+01, 0.31862800E+01, 0.70970400E+00, -.23686100E+01, -.11078700E+01, 0.26270200E+00, -.51675000E-01, -.68955900E+00, -.56704200E+00, 0.23158300E+00, -.69733900E+00, -.51743300E+00, -.54108700E-01, 0.72979200E+00, -.76936700E+00, 0.11289800E+01, 0.98959500E+00, -.16203400E+00, -.24565600E+01, 0.71351600E+00, 0.20701500E+00, 0.33959300E+00, -.68995600E+00, 0.79886100E+00, -.27020200E+00, -.38253000E-01, 0.46300700E+00, -.77598300E+00, 0.22290900E+00, -.13596700E+01, -.27532200E+00, -.40117200E+01, -.69417400E-01, -.17731800E+00, -.46754500E+00, 0.25388400E+00, -.60644500E-01, 0.19176200E-01, 0.51797000E-01, 0.12361000E+00, -.64656400E+00, -.74317700E-01, -.68929400E+00, 0.78208100E-01, 0.30610300E+01, -.21266700E+00, -.13544800E+01, -.62037800E-01, -.95346000E-01, 0.55241400E+00, 0.38623400E-01, 0.43104300E+00, 0.31411900E+00, -.36661100E+00, 0.14515000E+01, 0.11813900E+01, -.14825600E+01, 0.13703100E+00, 0.22387300E+00, -.71070000E-01, 0.15515500E+00, 0.36255000E+00, -.31100400E+00, 0.75616200E-01, -.32794200E-01, -.24859000E+00, 0.41853400E+00, -.27498300E+01, -.97909500E-01, 0.10530500E+01, 0.97718400E-01, -.40138600E+00, -.50888400E+00, -.82249300E+00, -.30722200E-01, -.18036500E+00, -.19751400E+00, -.22304700E+00, -.32586900E+00, -.13513800E+01, 0.75485900E+00, 0.85179100E-03, 0.25226900E+00, -.56348500E+00, -.13649600E+00, -.20692300E+00, -.12409100E-01, 0.37655800E+00, -.26280500E+00, 0.31592900E+00, 0.47261100E-01, -.22986600E-01, 0.18355900E+00, 0.70510500E-01, -.58268300E-01, 0.67397600E-01, 0.26250400E-01, -.47163900E+00, -.33650100E+00, -.22036600E+00, 0.70902900E-01, 0.13906000E+00, 0.36715900E-01, -.83334200E-01, -.27821500E-01, -.12396900E+00, -.34243500E-01, 0.15236500E-02, 0.33497900E+00, 0.10103600E+00, 0.27196100E-01, -.13166600E+00, -.12341900E+00, -.19949000E-01, 0.55650100E-02, -.12916300E+00, 0.47145300E-01, -.71268500E-01, -.10621400E+00, 0.15136100E+00, 0.60362100E-01, -.48700200E+00, -.60635800E-01, -.61694200E-01, -.13695700E+00, -.30348300E+00, -.78796100E+00, -.24238200E+00, 0.26121100E+00, 0.57164600E+00, 0.44747100E+01, -.11545000E+01, -.54071900E+00, -.12394400E+01, -.16217900E+01, 0.37238200E+00, 0.12468800E+00, -.14761100E+00, 0.13177700E+01, 0.31160400E+00, 0.91717400E-01, 0.58969600E+00, 0.16001200E+00, -.16283600E+00, 0.15111900E+01, 0.24397200E+00, 0.57399600E-01, 0.91499000E+00, 0.11316800E+00, -.38804800E-01, 0.44471700E+00, 0.77716800E+00, -.57993300E+00, 0.21379500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16218900E+01, 0.21906600E-01, -.19661900E+01, -.10507100E+01, -.75150200E+00, -.50706100E+00, 0.20246600E+01, 0.19344600E+01, 0.28406100E+00, -.19494900E+00, -.69961000E+00, -.13456300E+01, 0.17904100E+00, -.16568800E+01, -.15028400E+01, -.17897100E+01, -.21459700E+00, -.13148600E+00, -.10715100E+01, -.94618500E+00, 0.22483700E+00, -.17569800E+00, 0.18496400E+00, -.24169400E+00, 0.16378900E+00, 0.27855700E+00, 0.31318000E-01, 0.73211100E+00, 0.17449300E-01, 0.71439100E-01, 0.27502200E-01, 0.49078500E+00, -.51234800E-01, -.92932800E+00, -.17818500E+00, -.11429000E+00, -.23569500E+00, 0.26998600E+00, 0.93141800E-01, 0.40176600E+00, -.43216400E+00, 0.16821300E+00, 0.27839500E+00, -.21457300E-01, 0.29039100E+00, -.91050800E-01, 0.26159700E-01, -.13167200E+00, 0.92844600E-01, 0.66372200E+00, 0.13702200E+00, -.68085400E-01, -.55594900E-01, 0.16416400E+00, 0.18777600E+00, 0.99824100E-01, 0.23910200E-01, 0.48154400E-01, -.31258200E+00, -.11101600E-01, -.18362000E+00, 0.37674400E-01, 0.18502400E+01, -.15571400E+00, -.72126700E+00, 0.86018400E-01, -.81006700E-01, -.95017100E-01, 0.19846400E+00, -.27228200E+00, 0.38424900E+00, -.58905200E-01, 0.97872100E-01, 0.47251200E+00, -.33222600E+00, -.35133500E-02, 0.10762600E-02, -.89245900E-01, -.69278700E-01, 0.15711400E+00, 0.51459100E-01, 0.25616600E-01, -.92121300E-01, -.17360900E+00, 0.63372000E-02, -.53666500E+00, 0.19129100E+00, 0.28551000E+00, 0.61116000E-01, -.78923400E-01, -.93278700E-01, 0.35748000E-01, -.12003500E-01, -.82220700E-01, -.15391800E+00, 0.32809200E+00, 0.25634600E+00, -.76896000E+00, 0.24865000E+00, -.67348500E-01, 0.47343400E+00, 0.37121700E-01, 0.38599500E-01, -.15992200E+00, -.35117900E-01, 0.93279100E-02, -.20233000E+00, 0.20461200E+00, -.17752900E-01, 0.18258100E+00, -.16106600E-01, -.44266300E-01, 0.41994600E-01, 0.55389500E-01, 0.39654100E-01, 0.32319600E+00, 0.13734100E+00, 0.48801500E-01, 0.42342600E-01, 0.46742000E-01, 0.44856800E-01, 0.39230900E-01, 0.27042100E-01, 0.48846900E-01, -.13198300E+00, 0.79374500E-01, 0.18142300E+00, 0.20750000E-01, -.44043300E-01, -.94912900E-01, 0.59340500E-02, -.21009200E-01, 0.18126900E-01, 0.74100400E-01, -.10623100E-01, 0.19664300E+00, 0.11114000E+00, 0.37799300E-01, -.29978700E-01, -.61669400E-01, 0.36401200E-01, -.29979700E-01, -.88707900E-01, 0.51467000E-01, -.16308000E+00, -.58587100E-01, 0.52178900E-01, 0.69715300E-01, 0.10832200E+00, 0.14173500E+01, -.91119100E-01, -.36711700E-01, -.66331700E-01, 0.22219800E-01, 0.29193600E-01, -.28153400E-01, -.70100100E-01, -.27653800E-01, 0.36078400E-02, 0.26931300E-01, 0.28289800E-01, 0.42237900E-03, -.24793200E-01, 0.49691300E-01, -.12170800E-01, -.10560000E+00, -.10953700E+00, -.16805700E-01, 0.29762200E-01, 0.80474800E-02, -.87832000E-01, 0.46674000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.33277800E+01, -.17508900E+00, -.16866400E+00, 0.26936700E+01, -.47266100E-01, 0.11424400E+01, -.19200100E+01, -.26794900E+01, 0.10031900E+00, -.67772900E+00, 0.86860200E-01, 0.18622400E+01, 0.63264100E-01, 0.93279400E+00, 0.41758300E+00, -.20364900E+01, -.21669900E+00, 0.68931000E+00, 0.10172800E+01, -.65928600E-01, -.32378000E+00, 0.20971500E+01, 0.10029100E+01, 0.78627000E-01, 0.17498400E+00, -.35505100E+00, 0.96724400E+00, -.59525000E+00, -.54419500E+00, 0.44835300E+00, 0.49070900E+00, 0.11327600E+01, -.14989000E+00, -.14996300E+01, 0.36045900E+00, 0.11820700E+01, 0.16165700E+01, 0.47231900E+00, 0.36483100E-01, -.65853700E+00, 0.12621700E+01, -.83883300E+00, 0.17167700E+01, 0.26582800E+00, 0.82442000E+00, -.56813100E-01, -.35890700E-01, -.19272800E+01, -.56826700E+00, 0.28304200E+01, 0.76101500E+00, 0.23220100E-01, -.46220500E-01, -.31191900E-01, 0.88897500E-01, 0.44795900E-01, -.42438300E-01, 0.44947400E-01, -.27921200E+00, -.43056000E+00, 0.75362600E+00, 0.11717000E-01, -.57561100E+00, -.44575600E+00, -.48392200E+00, -.15233200E+00, 0.99058400E-01, 0.79003000E+00, -.74567900E-01, -.60925800E+00, 0.21778800E+00, 0.13984500E+00, 0.27434300E+00, -.38763900E-01, 0.32483000E+00, -.97842200E-01, 0.22068300E+00, -.19902000E+00, 0.26364300E-01, -.14934000E+00, 0.23722300E+00, -.24232000E-01, -.38361600E+00, -.50393500E+00, -.40620700E-01, -.27917100E+00, 0.31447400E+00, -.15713600E+01, 0.40678800E+00, -.27624800E+00, -.65783600E-01, 0.11915700E+00, 0.13409300E-01, 0.19566700E+00, -.18954700E+00, 0.23557700E+00, 0.10923600E+01, -.73673000E+00, 0.32343800E+00, -.55374700E-01, 0.78870300E+00, -.34144100E+00, 0.16185700E+00, -.19014100E+00, 0.63314000E-01, 0.10264400E+00, -.20074100E+00, 0.91515000E-01, -.61776500E-02, 0.43030600E-01, -.11887100E+00, 0.28065100E-02, 0.69021200E-01, 0.47444700E-01, -.61001800E-01, 0.94627600E+00, 0.32963300E+00, -.37256200E+00, -.33664100E-01, 0.41499600E-02, 0.48613000E-01, -.21620400E-01, 0.18228200E-01, 0.25299400E+00, -.25493000E+00, 0.59039100E-01, 0.12558800E+00, 0.21818100E+00, -.31258200E-01, -.28737300E+00, 0.24031500E+00, -.22515900E+00, -.26598900E+00, -.89256100E-01, 0.84360000E-01, 0.11843500E+01, 0.46500100E+00, 0.82347200E-01, 0.63938800E-01, 0.29588800E+00, -.20165500E-01, -.21116500E-01, -.17775500E+00, 0.32790500E+00, -.32704700E+00, 0.19051300E-01, 0.69051500E-01, -.40958000E+00, 0.48716000E-01, -.11425600E+00, -.29203500E+01, 0.36998200E+01, -.71604500E+00, 0.34807200E+00, 0.14702600E+00, -.14550500E+00, -.17875800E+01, 0.10740100E+00, -.50507000E+00, -.14969800E+00, 0.15368500E+00, -.17588600E+00, -.12496400E+01, 0.12301500E-01, -.63776900E+00, -.18474700E+01, 0.48775500E-01, 0.27717500E-03, 0.33817100E+00, -.11763100E+00, -.49545400E-01, -.85561600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16159200E+02, -.10316200E+01, 0.13056500E+02, 0.80757800E+01, 0.52802300E+01, 0.49543100E+01, -.55412300E+01, -.15355400E+02, 0.76556100E+00, -.55728100E+00, 0.31165800E+01, 0.12601100E+02, -.12336700E+01, 0.10881600E+02, 0.11145500E+02, -.59599000E+01, -.32040500E+00, 0.25901100E+01, 0.53286600E+01, -.18387500E+01, 0.15898900E+01, 0.12536500E+01, 0.11199400E+01, -.19603700E+00, 0.81388900E+00, -.26014100E+00, 0.30003400E+01, -.47044600E+00, -.10161000E+01, 0.68768900E+00, 0.23925800E+01, -.23466300E+01, 0.68103600E-01, -.10644200E+02, 0.75134400E+00, 0.34999100E+01, 0.30895700E+01, -.27211500E+00, -.16621000E+01, -.30186900E+01, 0.50580800E+01, -.18175600E+01, 0.23229700E+01, 0.72902700E+00, 0.43830500E+00, 0.48094800E+00, -.10742700E+00, -.26630000E+01, 0.33007600E-01, 0.10838400E+01, 0.77770900E+00, -.49138600E+00, 0.71558300E+00, 0.20223700E+00, 0.19278800E+00, -.91421000E-01, -.16826000E+00, -.60490800E+00, 0.19014400E+01, 0.97963500E+00, -.13615800E+00, -.51594500E+00, -.88041700E+01, 0.16414900E+01, 0.45961800E+01, 0.10067500E+00, -.22069200E-01, -.87267900E+00, -.25870200E+00, 0.72304900E-01, 0.11204300E+01, -.31675500E+01, 0.33286400E+01, 0.48551600E+00, 0.67136000E+00, 0.17741100E+00, -.11162600E+01, 0.81653400E+00, -.74898400E+00, 0.41383900E+00, -.14603700E+01, 0.49201600E+00, 0.44494200E+00, 0.90473300E+00, 0.22993600E+00, 0.24661900E+01, -.11121100E+01, 0.21793100E+00, -.45703800E+00, 0.79518600E+00, 0.11053800E+01, 0.50670300E+00, 0.58997900E+00, 0.57135100E+00, -.48201600E+00, 0.14415300E+01, 0.62138400E+01, -.17283100E+00, -.92890200E+00, -.51043400E+00, 0.12622200E+01, -.50608000E+00, 0.57270800E+00, -.42156700E+00, -.21822600E-02, 0.12456800E+01, -.70830600E+00, 0.45545900E+00, 0.26426200E-01, -.29244300E+00, -.66430900E+00, 0.13775400E+01, -.23806400E+00, 0.55983100E-01, -.15936500E+01, 0.40717600E+01, 0.41032900E+01, -.92911200E+00, -.13190200E+01, -.23940400E+01, 0.13176000E+00, -.45780600E+00, -.99801100E-01, 0.17201200E+00, 0.22037700E+01, 0.34227000E+00, 0.58487800E+00, 0.13454900E+01, 0.33457900E+00, -.39015100E+01, 0.12884400E+01, -.99742600E+00, -.50712200E+01, -.10616800E+01, 0.30506300E+00, -.10831800E+00, -.10484600E+01, -.64196700E+00, -.18769200E+01, 0.27047700E+01, -.67025600E-01, 0.43713400E+00, 0.17098200E+01, -.36370500E+00, 0.12372000E+01, 0.15242000E+00, -.21295500E+00, -.14585400E+01, -.16451600E+00, 0.13851100E+01, -.10426900E+01, 0.17110300E+02, 0.20681300E+01, -.11950800E+01, -.28416400E+00, 0.36167900E+00, -.41766200E+00, 0.22910300E+00, -.29213600E-01, -.37634800E+01, -.35699400E+00, 0.71490400E-02, 0.86718600E+00, -.16421500E+01, -.39170400E+00, -.24930300E+00, 0.69804900E+00, -.16722000E+00, -.68707900E-01, -.32947100E+01, 0.24118700E+00, -.31878800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.29043800E+01, -.29850300E-01, 0.60893300E+01, 0.12909300E+01, 0.46665800E+00, 0.79052200E+00, -.28438500E+01, -.33001400E+01, -.53312800E+00, 0.57510200E+00, 0.11368600E+01, 0.23585700E+01, -.84684500E+00, 0.40227000E+01, 0.45150000E+01, 0.10242300E+01, 0.29743300E+00, 0.23390600E+00, 0.16558000E+01, 0.98783900E+00, 0.11188900E+01, -.11954400E+01, -.14695200E+01, 0.33571100E+00, -.56043200E-01, 0.79193900E+00, -.44520200E-01, -.28188700E+01, -.65339800E+00, -.14405000E+01, 0.30493900E-01, 0.15034800E+01, 0.34862800E+00, 0.34585200E+01, 0.38673300E+00, 0.89339900E+00, 0.59330300E+00, -.25312900E+00, -.41494200E-01, -.14132900E+00, 0.46975100E+00, 0.37921000E+00, -.12311400E+01, -.29106000E+00, -.30759600E+00, -.42336700E+00, -.88362800E-01, 0.11714600E+01, -.40091800E+00, -.57150900E+01, -.57845800E+00, 0.39803200E+00, -.45046900E+00, -.44009600E+00, -.12326600E+00, -.30338300E+00, 0.32274300E-01, -.60840400E-01, 0.14187600E+00, -.49214000E-02, 0.48840500E-01, -.15787500E-01, -.21139100E+01, 0.14229200E+00, -.39505900E+00, -.76211300E-01, 0.13459800E+00, -.16872100E+00, 0.17767400E+00, -.57361700E-01, -.26471500E-01, -.16177000E+00, 0.33718100E+00, -.20256500E+00, -.11994000E+00, -.41247800E+00, -.65567400E-01, 0.22448200E+00, -.15335100E+00, -.19229200E+00, 0.87606900E-01, 0.76175000E-01, -.25753800E+00, -.31116900E+00, 0.14597300E+00, 0.30575000E+00, 0.33740400E+00, -.31981400E+01, 0.35774600E+00, 0.71446900E-02, -.60584100E+00, -.88353100E+00, -.12916200E+00, -.64845300E+00, 0.27911300E-01, -.16395200E+00, 0.51979100E+00, -.53130400E+00, 0.30310800E+00, 0.34182200E-01, 0.14393500E+00, 0.10609900E+00, 0.49454400E+00, -.22139900E-01, 0.76935200E-01, 0.85045300E-01, 0.72420700E-01, -.57182500E-01, 0.50254900E-01, 0.86239300E-01, -.18322300E+00, -.87537000E-01, 0.59332400E-01, 0.12950600E+00, 0.97926300E-01, 0.96375200E+00, 0.36799800E-01, -.98785700E+00, 0.57840700E-01, -.49328500E+00, -.25673600E-01, 0.66825000E-01, 0.16333800E+00, 0.87627200E-01, -.37539100E-01, -.67117100E-01, -.87676300E-01, 0.18945500E+00, 0.13604000E+00, -.77910200E-01, 0.28789200E+00, -.27871900E+00, -.11296900E+01, -.70116300E-01, -.32670800E-01, 0.59782200E+00, -.17161400E+00, 0.99960600E-01, 0.58581900E-01, 0.67540000E+00, 0.40575400E-01, -.51997700E-01, -.46088100E-01, 0.60041100E-01, 0.16266300E+00, -.16010000E+00, 0.93095700E-01, -.32159100E+00, -.19778300E+00, -.40468600E-01, 0.28223900E+00, 0.13146900E+00, -.43690300E+00, 0.51569000E+00, -.27025500E-01, -.12552800E-01, 0.23651100E+00, 0.52007100E-01, -.37725400E-01, -.32299700E+00, 0.10628400E-01, 0.44075300E-01, 0.20751600E+00, -.26565400E+00, -.35301900E-01, 0.12808000E+00, -.90040000E-01, 0.35651900E+00, 0.52347000E-01, 0.12114700E+01, -.12590100E+00, -.35693500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.97488400E+01, 0.85726300E+00, -.49099700E+01, -.56110900E+01, -.29979400E+01, -.37774200E+01, -.26331200E-01, 0.74592400E+01, -.47998700E+01, 0.17023900E+01, -.69223000E+00, -.63930500E+01, -.39679100E+00, -.17227500E+01, -.26862700E+00, 0.97487800E+01, 0.15522900E+01, -.25294300E+01, -.11028400E+01, 0.49020700E+01, -.89479800E+00, -.18251900E+01, -.13324800E+01, 0.52799400E+00, -.46752700E+00, 0.19553000E+01, -.32722600E+01, 0.97146900E+00, 0.62577600E+00, -.37386500E+00, 0.38137700E-01, -.95338500E+00, -.13481800E+01, 0.48568500E+01, 0.10958100E+01, 0.19596400E+01, -.69975000E+00, 0.21780700E+00, -.75443000E+00, -.43732800E+00, 0.53568000E+00, 0.55277100E+00, -.16576100E+01, 0.27011900E-01, -.99737900E+00, -.43234700E+00, 0.13582500E-01, 0.74947400E+00, -.37746300E+00, -.86814100E+01, -.10327700E+01, 0.10818600E+00, -.11010900E+01, -.31016500E-02, -.26726500E+01, -.41595200E+00, 0.14132900E+00, 0.60272600E+00, -.96414300E+00, -.11596600E+01, 0.10734500E+01, 0.49496700E+00, 0.56261100E+01, -.13157100E+01, -.25170200E+01, -.15051900E+00, 0.50164200E+00, 0.14278500E+01, 0.76247400E+00, 0.68016600E+00, 0.68984800E+00, 0.32063200E+00, -.59634000E+00, -.12754100E+01, 0.15224300E+01, 0.99905600E+00, 0.74939400E+00, -.18066400E+01, 0.12085300E+00, -.52626300E+00, 0.90299600E+00, 0.12167500E+00, -.43553100E+01, -.46047800E+00, -.53623400E+00, 0.58033000E+00, 0.15122100E+01, 0.10481800E+01, -.18401600E+00, -.78731700E+00, 0.29283500E+00, 0.98723600E+00, -.26663400E-01, 0.10630800E+01, -.83196500E+00, -.11126400E+00, -.43838700E+01, -.13614900E+01, 0.16533800E+01, 0.37000300E+00, -.95434900E+00, 0.25700000E+01, 0.13252000E+01, 0.73035300E+00, 0.28116900E+00, -.39270900E+01, -.55867300E+00, 0.56775600E+00, -.23973500E+00, 0.78038700E-01, 0.38654600E+00, -.28874700E+01, 0.21784600E+00, -.21021400E+00, 0.16383500E+00, -.14863900E+01, 0.29976900E+01, 0.15488900E+01, -.31485900E+00, 0.11808100E+01, 0.14863700E+00, -.17951700E+00, 0.29343600E+00, -.94662700E+00, 0.17932600E+01, 0.60195900E+00, -.38767700E+00, -.18811800E+01, -.83084000E+00, -.14405800E+01, -.71897300E-01, 0.29180200E+00, -.27403400E+00, -.43235300E+00, 0.35306500E-01, 0.43756400E-01, 0.22031700E+01, -.33971400E+00, 0.64455100E+00, 0.79883300E+00, -.23849600E+00, 0.44317800E-01, 0.70517600E+00, 0.27750100E+00, 0.31322800E+00, -.25666000E+00, -.16729000E+00, -.15537100E+00, 0.62384600E-01, 0.52124800E+00, -.15161900E+01, 0.13963700E+00, -.21432700E+01, 0.22274000E+01, 0.11648000E+01, -.12771100E+01, -.43699600E+01, -.11337600E+01, -.16200200E+01, -.38418300E+01, 0.12939000E+01, 0.53709600E+00, -.35607700E+01, -.27678700E+01, -.83444100E+00, -.52067400E+01, -.10590900E+01, 0.43537800E+00, 0.24837400E+01, 0.18460600E+01, 0.11602400E+01, 0.95540800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13915500E+02, -.47364000E+00, 0.13408700E+02, 0.73046100E+01, 0.45731200E+01, 0.50833200E+01, -.47033100E+01, -.11489400E+02, -.90941200E+00, -.45976500E+01, 0.15678300E+01, 0.81198100E+01, -.27587300E+01, 0.10087300E+02, 0.10223700E+02, -.89519800E+01, 0.88733700E-01, 0.26652100E+01, 0.51759900E+01, -.17531600E+01, 0.30655100E+01, -.88200000E+00, 0.38711800E+00, 0.21561600E+00, 0.20886600E+01, 0.26315000E+01, 0.13659700E+01, -.55354100E+01, -.16448400E+01, -.18017300E+01, 0.14994100E+01, 0.23463900E+01, 0.19830200E-01, -.80527100E+01, -.89724000E+00, 0.58359700E+01, 0.50845100E+01, -.14136200E+01, -.41207000E-01, -.23628100E+01, 0.13178000E+01, -.10569700E+01, 0.18724200E+01, 0.15635100E+00, 0.11879500E+01, -.51122100E+00, -.39875400E+00, -.30769800E+01, -.69772800E+00, -.51449300E+01, 0.70000500E+00, -.15249900E+00, -.32260700E+00, 0.47295900E+00, -.96495600E+00, -.43362200E+00, -.17102700E+00, -.44687200E+00, 0.11217800E+01, 0.62927800E+00, 0.13067400E+01, -.44876300E+00, -.69681500E+01, 0.11954700E+01, 0.26156300E+01, 0.18277300E-01, 0.23083000E+00, 0.12271600E-01, -.17945300E+00, -.27351200E+01, 0.27925800E+01, -.24218100E+01, 0.30145600E+01, 0.12634300E+01, 0.10068400E+01, -.82307800E+00, -.15150500E+01, 0.38481900E+00, -.18453600E+01, -.16120300E+00, -.51857900E+00, -.63572300E-01, -.17671400E+01, -.54831700E+00, -.18627500E-01, -.13116400E+00, -.14906500E+01, 0.13963100E+01, 0.23911000E+00, -.18780600E+00, 0.15678500E+01, 0.42393800E+01, 0.17437900E+01, 0.99178400E+00, -.13084600E+01, 0.48511500E+01, 0.13508300E+02, 0.10075400E+01, -.27158300E+01, -.14742600E+01, 0.45515600E+01, 0.66565200E+00, -.59481200E-01, -.95998900E+00, 0.49372400E-01, 0.27887900E+01, 0.52145100E+00, -.67310200E+00, 0.15231300E+00, -.26461500E-01, -.12475000E+01, -.18357500E+01, 0.16143400E+00, 0.20032800E+00, -.84244900E+00, 0.56300800E+01, 0.51193100E+01, -.36442700E+00, -.17066200E+01, -.77167400E+00, 0.33846200E+00, 0.42006400E+00, 0.25077600E+01, 0.20827900E+00, 0.10048200E+00, 0.21270600E+00, -.15915300E+01, -.58802800E+00, 0.68102900E+00, -.26136400E+01, 0.11724600E+01, -.38088500E+00, -.86029900E+00, -.57831000E+00, 0.35354700E+00, 0.28942500E-01, -.83044800E-01, 0.20954000E+00, 0.10898800E+01, -.52176300E+00, -.15196700E+00, -.24469300E+00, -.73320900E+00, 0.13582300E+01, -.64568500E+00, 0.59121500E+00, -.14333000E+00, 0.32806600E+00, 0.69476000E+00, -.37938500E+00, 0.19145600E+01, -.43800000E+00, -.20163400E+01, -.11553000E+01, 0.13496300E+01, -.14582500E+01, -.46719600E+01, -.15720700E+01, -.94771800E+00, -.32792500E+01, 0.14750500E+01, 0.83287700E+00, -.42509300E+01, -.24841200E+01, -.28038100E+00, -.59892800E+01, -.12815900E+01, 0.14638300E+00, 0.32976500E+01, 0.34203900E+01, 0.13120900E+01, 0.10705700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16872200E+00, -.59763600E-01, -.82659000E+00, 0.11089600E+00, -.76045700E-02, 0.59816100E-01, -.48715700E-01, -.15748300E+00, 0.65237700E-01, -.25741600E-01, 0.15891500E-01, 0.12860300E+00, -.12240100E-01, 0.88288000E-01, 0.12763000E+00, -.15806200E+00, -.18695600E-01, 0.20921000E-01, 0.35718700E-01, -.13685300E+00, 0.12781800E-01, 0.34946900E-01, 0.78523700E-02, -.15466300E-01, 0.86349600E-02, 0.48171800E-02, 0.92098800E-01, -.62625400E-01, -.17281600E-01, -.34610400E-03, 0.47816600E-02, 0.46179800E-01, 0.66723600E-01, 0.46012500E-01, -.30259500E-01, -.98592400E-02, 0.83480600E-01, -.11498100E-01, 0.20084400E-01, 0.92439400E-02, -.10664600E-01, -.21247800E-01, -.14942600E-01, -.60244500E-02, -.19360400E-01, 0.13010800E-01, -.54320700E-02, 0.51409000E-01, 0.10450000E-01, 0.13362900E+00, 0.35453600E-03, -.16166200E-02, 0.12678000E-01, -.77070700E-03, 0.20438400E-01, 0.33239500E-03, -.27130400E-02, -.69154500E-02, 0.19670100E-01, -.85770600E-02, 0.33548200E-01, -.30167900E-02, -.10140600E+00, -.27464500E-02, 0.25918900E-01, -.62558100E-02, 0.43285800E-02, 0.23801900E-01, -.21369800E-01, -.11357200E-01, 0.21439200E-01, 0.11517100E-01, -.16473000E-01, -.20746000E-01, 0.42707400E-01, -.10109400E-01, -.66273500E-02, 0.80288500E-02, -.15283400E-01, 0.68253600E-02, 0.68194100E-02, 0.45077200E-03, 0.27277800E-01, 0.21030800E-02, -.10405600E-01, 0.50004300E-01, -.23783000E-02, 0.37654300E-01, 0.45108300E-02, 0.14407200E-02, 0.14433000E-01, 0.20223900E-01, 0.52443100E-02, 0.22263100E-02, 0.18798100E-02, 0.21010600E-01, 0.22945100E-02, 0.18979600E-01, -.11036600E-01, -.14999200E-03, -.14325300E-01, 0.20142000E-01, 0.89043400E-02, 0.36971700E-02, -.26687000E-03, -.11427400E-01, 0.17803800E-01, -.14796500E-01, -.23717900E-02, 0.63394200E-02, -.88460300E-02, 0.14670300E-01, 0.18847000E-02, -.27617000E-02, -.11793600E-02, 0.16429300E-01, 0.33769300E-01, 0.12984900E-01, -.88261000E-03, 0.15697600E-02, -.43737500E-03, 0.65358500E-02, 0.16129000E-01, 0.73580500E-02, 0.93493800E-02, -.18941800E-03, 0.37508700E-02, 0.11212900E-01, 0.79730700E-03, -.15205500E-02, 0.30723500E-02, -.32383300E-03, 0.35112800E-02, 0.89259200E-02, -.28462700E-02, 0.29568200E-02, -.24499800E-02, 0.32175700E-03, 0.65778200E-03, 0.38361900E-02, -.25353700E-03, 0.20123400E-03, 0.12986200E-02, 0.22635500E-02, 0.14284900E-02, 0.55848600E-03, -.20373400E-03, -.22722000E-03, -.14781800E-02, 0.89552200E-03, 0.11373500E-02, 0.50286000E-03, 0.20785200E-01, -.54196100E-02, 0.57515200E-02, 0.58467000E-01, -.25681900E-02, 0.30340600E-03, 0.86262400E-03, 0.93614100E-02, -.26668700E-02, -.98918900E-02, -.11547100E-02, 0.84713100E-02, 0.68814600E-03, 0.25690600E-02, 0.71217200E-02, -.79309000E-02, 0.48186900E-01, -.33979000E-01, 0.28244200E-02, -.65183400E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17256700E+02, 0.29575300E+00, -.20208800E+02, -.11202300E+02, -.85130200E+01, -.86343500E+01, 0.79004800E+01, 0.11738300E+02, -.53772600E+01, -.76183900E+01, -.12257600E+01, -.10870600E+02, -.12187300E+01, -.70475100E+01, -.58882600E+01, 0.86636400E+00, 0.63146600E+00, 0.64281500E-02, -.44564000E+01, 0.16654600E+02, -.76162700E+01, -.92574100E+01, -.37248700E+01, 0.20711400E+01, 0.26884000E+00, -.21843600E+01, -.72138300E+01, -.23351600E+01, -.15662300E+01, -.10136400E+01, -.24361800E+01, -.23352500E+00, -.20954800E+01, 0.15272100E+01, 0.37984100E+01, -.22089900E+01, -.95380800E+01, 0.20054900E+01, 0.21415500E+01, 0.67067600E+00, -.42213300E+01, 0.29833600E+01, -.35619100E+01, -.11070800E+01, -.62435100E+00, -.31454600E+01, 0.32908200E+00, -.72577200E+01, -.25065800E+01, -.21549300E+02, -.24500000E+01, -.88701100E-01, -.26933500E+01, 0.37925200E+01, -.13597900E+01, -.11700500E+01, -.23204300E+00, 0.16592500E+01, -.54403800E+01, -.61171000E+01, 0.53410200E+01, 0.63682900E+00, 0.22964500E+02, -.82890800E+01, -.95153400E+01, 0.14875600E+00, -.90802000E+00, 0.42213400E+01, 0.90243200E+00, 0.48987200E+00, 0.33295200E+01, -.19414200E+01, 0.13968700E+00, 0.29932300E+01, -.32517400E+01, 0.34528400E+01, 0.17294300E+01, -.35275700E+01, 0.19643500E+01, 0.86747800E+00, -.19241400E+00, 0.26309000E+00, -.46773600E+01, -.18664100E+01, 0.86014800E+00, -.58752300E+01, 0.13416800E+01, 0.64750700E+01, -.55329200E+00, -.28725600E+01, 0.15227900E+01, 0.16260200E+01, 0.20049400E+01, 0.12698200E+01, -.30160900E+01, 0.26301700E+01, 0.62331800E+01, -.61532600E+01, 0.21182900E+01, -.98261000E+00, 0.40173000E+01, 0.54801000E+01, 0.30886200E+01, -.42598400E+00, 0.75714900E-01, -.33966000E+01, -.73982100E+00, 0.17437700E+01, -.42667400E-01, 0.74377500E+00, -.49796200E+00, -.72953000E+01, 0.57365100E+00, -.24989400E+00, 0.65542500E+00, -.65861100E+01, -.46017400E+00, 0.23330500E+01, -.34537700E+00, 0.31745700E+01, 0.20873900E+00, 0.23286900E-01, 0.35695700E+00, -.15078800E+01, 0.92525900E+00, 0.69070000E+00, -.33250900E+01, -.29036200E+01, -.29862500E+00, -.17254400E+01, -.10722000E+01, 0.50529000E+00, 0.16655900E+01, -.25388300E+01, 0.57433900E+00, -.29596900E+01, -.14873600E+00, -.56537200E+00, -.47713300E+00, -.13401400E+01, 0.16884600E+00, -.70483100E-01, 0.87863900E+00, -.16524400E+01, 0.31085400E+00, -.36166000E+00, 0.54163800E+00, -.50576600E+00, -.25633500E+00, 0.89942900E+00, 0.12360500E+01, 0.34337700E+00, 0.35630700E+01, -.87238400E+00, 0.12085400E+01, 0.19813700E+01, 0.15242700E+02, -.34623700E-01, 0.12888400E+01, 0.12130600E+01, -.98694600E-01, -.31576100E+00, 0.15390600E+02, 0.11505600E+01, 0.12800800E+01, 0.15894800E+02, -.11038500E+01, -.16632600E+01, -.90127900E-01, -.63073500E+01, 0.28801000E+00, 0.42224900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26131200E+01, -.42664100E-01, -.41186400E+01, -.15391000E+01, -.44794600E+00, -.82896400E+00, 0.24241700E+01, 0.31053100E+01, -.14029800E+00, -.85940200E+00, -.82891700E+00, -.25824100E+01, -.68576600E-01, -.21887100E+01, -.22219900E+01, -.13364300E+01, -.11811300E-02, -.22078600E+00, -.13702500E+01, -.18984900E+00, 0.27064300E+00, -.31867800E+00, 0.29531600E+00, 0.39078300E-01, 0.18168100E+00, 0.13306900E+01, -.93051900E+00, 0.73256000E+00, 0.57341400E+00, 0.44125700E+00, -.24631500E+00, -.79392000E+00, -.49844200E+00, 0.51638000E+00, -.35952400E+00, 0.59103100E+00, 0.59136300E+00, -.23477000E+00, -.64324600E+00, 0.15871700E+00, -.42377300E+00, -.14101000E+00, 0.25012200E+00, 0.20828800E+00, -.17976900E+00, 0.26433200E+00, -.43433700E-02, -.64521600E+00, 0.78811900E-01, -.93110800E+00, -.17098300E+00, 0.18669400E+00, 0.57572200E-01, 0.13014600E+00, 0.37294600E+00, -.33097200E-01, 0.37488600E-01, 0.24078300E-01, 0.10202400E+00, -.11604100E+00, -.42466600E+00, -.36088100E-02, 0.41544600E+00, -.15147600E+00, -.60561000E+00, -.33347000E-01, 0.77939500E-01, 0.31189300E+00, 0.13319200E+00, 0.33643000E+00, -.34970100E-01, 0.28966400E-01, 0.80585200E-02, -.16580400E+00, 0.35726200E+00, -.56634100E-01, 0.18341100E-01, -.10704000E+00, -.38046800E+00, 0.15506700E+00, 0.49011300E+00, 0.46226100E-02, 0.38934300E+00, 0.33595500E-01, -.94816100E-02, -.82431700E-01, 0.28100400E+00, -.21620800E+01, 0.96930400E-01, -.16422900E+00, -.13591300E+00, -.54552000E+00, 0.16480900E+00, -.14988900E+00, -.38707200E-01, -.94407500E-01, -.83847000E-01, -.41555800E+00, 0.17967700E+00, 0.70493600E-02, 0.27124500E+00, -.58533700E-01, -.40149600E-01, -.81997400E-01, -.28060900E-01, 0.28094700E+00, -.84953200E-01, 0.10162000E+00, 0.14408500E-01, -.11841400E-01, 0.59870000E-01, -.16649000E+00, -.35381400E-02, 0.51941600E-01, 0.13256900E+00, -.47005100E+00, -.77311500E+00, -.18514000E+00, 0.33756300E-01, 0.95791200E-01, 0.31858700E-02, 0.80004700E-02, -.10164300E+00, -.32312200E-01, -.29587500E+00, 0.22661800E-01, -.23987700E-03, -.12067400E+00, -.12985600E-01, -.26205400E-01, 0.53020300E-01, -.12352900E-01, 0.98550700E-01, 0.37367500E-01, 0.17511400E-01, -.47764300E-01, 0.15991400E-01, -.10266300E-01, -.32210400E-01, -.57501800E-01, 0.26627900E-02, 0.15418500E-01, -.25711600E-02, 0.49857500E-01, -.48551700E-01, -.14504600E-01, 0.35098100E-02, 0.29706900E-02, 0.94876600E-02, -.80098200E-02, -.25901100E-01, 0.40726200E-02, -.40612800E-02, 0.31676800E-01, -.25594400E-01, -.18954200E+00, -.47789600E-02, 0.21387900E+00, -.30077600E-01, 0.16519300E-01, 0.97543300E-02, -.14375400E-01, 0.29175500E-02, 0.57871100E-02, -.18415600E-01, -.29620100E-01, -.24663400E-01, 0.33369200E-01, 0.91171100E-01, 0.45529900E-01, 0.52640200E-02, 0.50465400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.58785900E+01, -.46084500E+00, 0.37843800E+01, 0.32261900E+01, 0.15124600E+01, 0.92652500E+00, -.52725900E+01, -.77246300E+01, -.26871900E+01, 0.47324500E-01, 0.23852200E+01, 0.53761500E+01, -.65772000E+00, 0.66301800E+01, 0.45000300E+01, 0.45509500E+01, 0.57658800E+00, 0.90519800E+00, 0.41369800E+01, 0.51015600E+01, 0.34938000E+00, -.15977700E+01, -.82535600E+00, 0.14961700E+01, -.21128300E-01, -.10381200E+01, 0.35819100E+00, -.47511700E+00, 0.14756400E+00, -.81769700E+00, 0.16960500E+01, -.18186000E+01, -.18342400E+01, -.53584200E+01, 0.12753000E+01, 0.10630900E+01, -.11920200E-02, -.92584200E+00, 0.92114500E+00, -.49793600E+00, -.96511600E+00, -.13569000E+00, -.78488900E+00, 0.30757000E-01, -.25502500E+00, -.41197800E+00, 0.17074500E+00, -.12775700E+01, -.26543300E+00, -.71218200E+01, -.45093000E+00, -.66525400E-01, -.20610700E+00, 0.58251300E+00, 0.23207300E+00, -.21629300E+00, -.18620600E+00, 0.24842800E+00, -.73345200E+00, -.94082600E+00, 0.11113200E+01, -.10449800E+00, 0.20358900E+01, -.15506300E+01, -.62238600E+00, -.14648400E+00, -.22489000E+00, 0.77524200E+00, -.57643100E+00, -.92982100E+00, -.65205300E-01, 0.27717700E+00, -.18791400E+00, 0.53153400E-01, 0.21760600E+00, 0.55774600E+00, 0.12618000E+01, -.12587500E+01, 0.86245100E+00, -.49435500E+00, 0.40478300E+00, -.32601700E+00, -.87576500E+00, 0.40544800E-01, -.29567900E+00, -.34469900E+00, -.27251500E+00, 0.18231000E+01, -.40431400E+00, 0.83315800E-01, 0.51766100E+00, 0.92335100E+00, 0.41137500E-01, 0.38537700E+00, -.61440200E+00, 0.82990900E+00, -.12743800E+01, -.33823300E+00, 0.15942900E+00, -.19519200E+00, 0.31981000E+00, -.55265600E+00, -.44086400E+00, 0.13843500E-02, -.16861300E-01, -.52025300E+00, -.54917000E+00, 0.46635700E+00, -.14945600E+00, -.59661700E-01, 0.44204500E+00, 0.48727400E+00, -.79273600E-01, -.25326100E-01, 0.28859800E+00, -.15205100E+01, -.23179700E+01, 0.67860100E+00, -.20590100E+00, 0.25469500E+00, -.52168000E-01, -.23832500E+00, -.94917100E+00, 0.84717400E-01, -.70630300E+00, 0.12391800E+00, -.30388500E+00, -.21587800E+00, -.60842200E+00, 0.50507800E+00, -.19102100E+00, 0.26252400E+00, 0.14615600E+01, -.29182900E-01, 0.29638100E-01, -.33449300E+00, 0.12257400E+01, -.12461700E+00, 0.76191200E+00, -.85613900E+00, -.11243600E+00, -.15002000E-01, 0.30282100E+00, 0.15485700E+00, -.48569700E+00, 0.31578200E+00, -.21304900E+00, -.10290700E+00, 0.17623100E-01, -.24789700E+00, -.39056600E+00, -.14602600E+00, -.33394200E+00, 0.11526100E+00, -.18930100E+00, -.42944700E+00, -.31374900E-01, 0.20698100E+00, -.19397900E+01, -.39046600E+00, 0.20816600E-01, -.14837900E+00, 0.54716200E-01, -.27643800E+00, -.12770800E+01, -.35195000E+00, 0.15388100E+00, 0.25260600E+00, -.38494100E-01, 0.18767800E+00, 0.10732400E-01, -.12511000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.22043800E+02, 0.47375800E+00, -.24117800E+02, -.10908100E+02, -.47535200E+01, -.70206000E+01, 0.95502500E+01, 0.21041800E+02, -.60780400E+00, 0.16820700E+02, -.45023500E+01, -.13962200E+02, 0.24877800E+01, -.72758500E+01, -.43043300E+01, 0.11643000E+01, 0.12714300E+01, -.43592300E+01, -.10856700E+02, 0.12643700E+02, -.52585800E+01, -.78883200E+00, -.49012300E+01, 0.15695900E+01, -.17283800E+01, -.25686400E+01, -.47244000E+01, -.78964900E+01, -.25336900E+01, -.61143000E+00, -.25000900E+01, -.26436600E+00, 0.26760600E+01, 0.38984700E+02, -.16444400E+01, -.25476200E+01, -.70602300E+01, 0.11510900E+01, 0.88282700E+00, 0.48039700E+01, -.56063900E+01, 0.41121700E+01, -.50921500E+01, -.14379800E+01, -.73006900E-01, -.38434800E+01, -.59704400E+00, -.48777900E+01, -.17714500E+01, -.18099100E+02, -.19595900E+00, 0.74341700E+00, -.20624700E+01, -.18017900E+01, 0.40642000E+01, -.11919200E+00, 0.25836600E+00, 0.64177000E+00, -.17514000E+01, -.20300800E+01, -.33282400E+00, 0.80669200E+00, 0.14231900E+02, -.31418700E+01, -.71171800E+01, 0.71951000E+00, -.73340300E+00, -.21922600E+01, 0.16630600E+01, 0.32168400E+00, 0.13750200E+01, -.12289700E+01, -.20026200E+01, -.91944700E+00, 0.23887000E+00, -.15489800E-01, -.13166400E+01, 0.10812200E+01, 0.15493700E+01, -.16950600E+01, 0.21046500E+00, 0.75953200E-01, -.49550600E+01, -.20603100E+00, -.65507100E+00, -.82951700E+01, 0.38897000E-01, 0.15966600E+02, -.56384900E+00, -.12173100E+01, -.61983400E+00, 0.16156100E+01, -.21008100E+01, 0.55421900E+01, 0.58909000E+00, -.50753600E+00, 0.57932300E+01, 0.57926300E+00, 0.15823300E+01, 0.45791300E+00, -.85999800E+01, 0.25907600E+01, 0.22420000E+01, 0.11545000E+01, 0.71361500E+00, -.42702000E+01, -.12809900E+01, 0.70265400E+00, 0.55752800E+00, 0.69762300E-01, 0.15942000E+00, -.22673500E+01, 0.47951500E+00, -.34196700E+00, 0.50875900E+00, -.41855600E+01, 0.21902600E+01, 0.14113100E+01, 0.95156500E+00, 0.32560800E+01, 0.28143300E+00, -.50773100E+00, 0.11648000E+01, -.97485600E+00, 0.48771500E+00, 0.74855700E+00, -.47503400E+00, 0.89003700E+00, 0.21655600E+00, -.84236200E-01, -.19764700E+01, 0.11832600E+01, 0.20879800E+01, 0.88995400E+00, -.38673800E+00, -.28999800E+01, 0.14265500E+00, 0.73058400E+00, 0.42828200E+00, -.31429700E+01, -.36562200E+00, -.71643500E+00, -.34531300E+01, -.18547200E+01, -.29023000E+00, 0.26542300E+00, 0.12892500E+00, 0.12284100E+01, 0.49370700E+00, 0.36915000E+00, 0.33958200E-01, -.21146300E+00, 0.13664000E+00, -.60440700E+00, 0.91483200E+00, 0.11610000E+01, 0.21884500E+00, 0.62649800E+00, -.58797600E+00, 0.92530500E+01, -.46567700E-01, -.12730200E+01, -.45054800E+00, 0.57664000E+01, -.52555600E+00, 0.35247800E-01, -.88139400E-01, -.44844000E+00, -.61337100E-01, -.13437400E+01, -.39017400E+00, 0.13409400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11039400E+00, 0.57085700E-01, 0.91324000E+00, -.84275300E-01, 0.94775200E-02, -.43668800E-01, 0.31682100E-01, 0.11757800E+00, -.52654400E-01, 0.21046800E-01, -.86023700E-02, -.96531000E-01, 0.71375400E-02, -.62682900E-01, -.89454800E-01, 0.11788700E+00, 0.17434600E-01, -.15947700E-01, -.26252900E-01, 0.11797900E+00, -.93245900E-02, -.31850000E-01, -.63932400E-02, 0.17662300E-01, -.55442100E-02, 0.44982200E-02, -.80750000E-01, 0.45474100E-01, 0.19636200E-01, 0.27332100E-02, -.31312900E-02, -.47036800E-01, -.58103500E-01, -.43251900E-01, 0.26763500E-01, 0.18264500E-01, -.60741800E-01, 0.93185400E-02, -.26538700E-01, -.88283000E-02, 0.16515900E-01, 0.15340500E-01, 0.92664000E-02, 0.49602700E-02, 0.12230800E-01, -.10614000E-01, 0.25828000E-02, -.30304000E-01, -.10277700E-01, -.12871400E+00, -.32677300E-02, 0.16496500E-02, -.93496700E-02, 0.28384800E-02, -.24453000E-01, -.14265900E-02, 0.19755600E-02, 0.55024900E-02, -.16981800E-01, 0.66816500E-02, -.19544600E-01, 0.29191500E-02, 0.90101400E-01, 0.32921600E-02, -.13056400E-01, 0.59519600E-02, -.30974300E-02, -.18960000E-01, 0.19240000E-01, 0.36180400E-02, -.17714800E-01, -.66710400E-02, 0.55453600E-02, 0.11821400E-01, -.26941100E-01, 0.10192500E-01, 0.43938200E-02, -.83014400E-02, 0.14984100E-01, -.64961700E-02, -.79729500E-02, 0.30989900E-03, -.30257200E-01, -.15499100E-02, 0.66306000E-02, -.27203200E-01, 0.78496500E-03, -.36086400E-03, -.39686500E-02, -.22803100E-02, -.91195800E-02, -.91142100E-02, -.28186200E-02, -.14527900E-03, -.42778000E-02, -.13213600E-01, -.21189700E-03, -.17149500E-01, 0.94033200E-02, -.16652500E-03, 0.10443000E-01, -.83380100E-02, -.50251800E-02, -.18221300E-02, -.10474600E-03, 0.25513600E-02, -.12798200E-01, 0.11821000E-01, 0.13698500E-02, -.45773100E-02, 0.66480600E-02, -.17882000E-01, -.12906800E-02, 0.11458400E-02, -.19064400E-03, -.14184200E-01, -.17268400E-01, -.67201100E-02, -.48650400E-03, -.15000400E-03, 0.34297100E-03, -.48852100E-02, -.12758200E-01, -.76275900E-02, -.18645700E-02, 0.61114900E-03, -.53626900E-02, -.12190600E-01, -.96611600E-03, -.44773800E-03, -.20703000E-02, 0.32003000E-03, -.34138600E-02, -.68791600E-02, 0.20674000E-02, -.24217800E-02, 0.31858600E-02, -.70346600E-03, -.56716700E-03, -.13553800E-02, 0.37050700E-03, -.35574600E-05, -.52662800E-03, -.80018000E-03, -.32550200E-03, -.27207000E-03, -.17539700E-03, 0.13533700E-03, 0.85615700E-03, -.70515100E-03, -.16529900E-02, -.27784000E-03, -.13860100E-01, 0.38536800E-02, -.34440200E-02, -.34238200E-01, 0.17463500E-03, 0.32393200E-03, 0.65129500E-03, -.65796300E-03, 0.57367200E-01, 0.59407900E-02, -.82792700E-03, -.20247500E-02, -.62147600E-03, -.28623800E-02, -.45654100E-02, 0.47124100E-02, -.49768600E-01, 0.19359700E-01, -.17027000E-02, 0.45176600E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16527500E+01, -.74521700E-01, -.32441600E+00, 0.52302000E+00, -.98553200E+00, -.30302400E+00, -.57250500E+00, -.10264500E+01, 0.97296300E-01, -.16868600E+00, 0.57568300E-01, 0.59869900E+00, 0.25194800E-01, 0.55427700E+00, 0.38780200E+00, -.30261100E-02, -.76623700E-01, 0.25878500E+00, 0.79286000E+00, -.18690800E+01, 0.31183400E+01, -.19464300E+00, -.13348800E+00, -.55348000E+00, 0.19019100E+00, 0.92464600E+00, -.28955700E+00, 0.47231000E+00, -.29974500E+00, 0.20921900E+00, 0.24787800E+00, -.72094200E+00, -.38318800E+00, -.41218700E+01, 0.39867900E+00, -.42402000E+00, -.52009900E+00, 0.31957000E+00, -.32064800E+00, -.75493600E-01, 0.15175000E+01, 0.15292700E-03, 0.79739900E+00, 0.21077300E+00, -.12502700E+00, 0.69747400E+00, -.35548700E-01, 0.43652700E+00, -.84567400E-02, -.72411700E+00, -.69401100E-01, 0.53766100E-01, -.86917300E-01, -.49735000E-01, -.47531200E+00, -.99541300E-02, 0.33888300E-01, 0.85564100E-01, -.17561800E+00, -.73934700E-01, 0.13884800E+00, 0.76732300E-01, 0.74774500E+00, -.37716800E-01, -.46800600E+00, 0.14421800E-01, 0.32835900E-01, -.57939000E+00, 0.37095700E-01, -.25872800E+00, -.10340600E+01, 0.72739600E+00, -.33229300E-01, 0.28131200E+00, -.68522500E-01, -.28961100E+00, 0.30397300E+00, -.85419800E-01, -.11769300E+00, -.92613300E-01, 0.46329800E+00, -.19241600E+00, 0.45446000E+00, -.12412900E+00, -.84743600E-01, 0.27240300E+00, 0.79784700E-02, -.77180700E+00, -.94348800E-01, 0.13785600E+00, 0.53502000E-01, 0.30228800E+00, -.21965300E-02, -.45396900E-01, 0.25663000E+00, 0.34487700E-01, -.22432400E+00, 0.70524700E+00, -.39000400E+00, 0.49558000E-01, -.64333200E+00, 0.67759600E+00, 0.43094200E-01, 0.20631000E+00, -.40657100E-01, -.40708100E+00, -.56893100E-01, -.13706200E+00, -.70483900E-01, -.19502100E-01, -.70663800E-01, -.27043300E+00, 0.64854200E-01, -.34091600E-01, -.11349700E+00, 0.62558700E+00, 0.46594300E+00, 0.94028300E-01, 0.90575900E-02, 0.32769800E-01, 0.20786000E-01, 0.28930800E-01, -.48479500E+00, 0.26383300E-01, -.87374700E-01, -.66575600E-02, -.16864500E+00, 0.10114300E+00, 0.76546800E-01, 0.25027300E+00, -.21492700E+00, -.16739000E-02, 0.34027600E+00, 0.17147900E+00, -.46531600E-01, 0.28374100E+00, -.10272700E-01, 0.76533100E-01, -.89188200E-01, -.31113300E+00, 0.20043000E-01, -.49663900E-01, -.30006200E+00, 0.36822000E-01, -.12471300E+00, -.67235700E-02, 0.30126800E-01, 0.13192800E+00, 0.37451500E-01, -.24393900E-01, 0.18707600E+00, -.47537400E-01, -.42503900E+00, -.70151300E-02, -.62387300E-01, -.81984300E+00, -.15375600E-01, -.35178100E+00, -.36206700E-01, -.27039600E-01, 0.74503900E+00, 0.10714200E+01, -.13858200E-01, -.13198100E+00, -.63868300E-01, -.61681600E-01, -.28267100E+00, 0.11153700E+00, 0.19857400E+00, 0.49455300E+00, 0.51492900E-02, 0.11975800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.32658900E+01, -.25045800E-01, 0.34351500E+01, 0.20546400E+01, 0.16806600E+01, 0.13082400E+01, -.41566000E+01, -.31545700E+01, -.15219900E+01, 0.15210400E+01, 0.53892800E+00, 0.25452000E+01, -.38950300E-01, 0.18238500E+01, 0.23087000E+01, 0.55563400E+01, 0.43730400E+00, -.14770900E+00, 0.24013600E+01, -.11384900E+01, -.48714000E+00, 0.19387100E+01, 0.15353000E+01, 0.22042800E+00, -.82340800E+00, 0.85132800E+00, -.18422600E+00, 0.32984300E+01, -.12811100E-01, 0.73615800E+00, 0.20176300E+01, -.12538500E+01, -.11835500E+01, -.52582200E+01, 0.13836500E+01, -.10744800E+01, -.10115400E+01, 0.97502800E+00, 0.20808800E+00, -.76459100E+00, 0.10689400E+00, -.26746800E+00, 0.12705800E+01, 0.34832400E+00, 0.42997800E-02, 0.56207700E+00, 0.18033300E+00, -.33901700E+01, -.62521600E+00, -.15865900E+01, -.16576800E-01, 0.32946700E+00, -.39328400E+00, -.30626900E+00, -.14247900E+01, -.10202200E+00, -.44533800E-01, 0.24301300E+00, -.36859500E+00, 0.46300100E-01, 0.11384300E+00, -.92908000E-01, -.30917500E+00, 0.21547800E-01, -.19909900E-01, -.45630700E+00, 0.34493300E+00, 0.16969700E+01, -.13163400E+00, 0.85818300E-02, 0.41805900E+00, -.11918400E+01, 0.18661200E+00, 0.93599700E+00, 0.16117400E+00, 0.90615100E+00, 0.10032400E+01, -.66684200E+00, 0.25940100E+00, 0.40314400E+00, -.41427400E+00, 0.70536400E-01, 0.62724700E+00, -.15459900E+00, 0.34613200E+00, -.10767300E+01, -.31234100E+00, -.14451800E+01, 0.55445900E+00, -.93117600E+00, -.13713300E+00, -.18300400E+01, 0.18618200E+00, -.47137100E+00, 0.12843600E+00, 0.75809900E-01, 0.38285200E+00, -.94266100E+00, 0.68759800E+00, 0.10838500E+00, -.82797600E+00, 0.12582500E+00, 0.25851600E+00, 0.81317700E-01, 0.23353400E+00, -.98887300E+00, -.17941200E+01, 0.12867200E+01, 0.22802800E-01, -.86533600E-01, 0.18919000E+00, -.19284900E+01, 0.28895300E+00, 0.43462300E-01, 0.19992800E+00, -.67460600E+00, -.14720700E+01, 0.22641400E+00, 0.72921300E-01, 0.37010500E-01, -.12546200E-01, -.13438800E+00, -.47602600E+00, 0.60401800E-01, -.44343800E+00, 0.14058300E+00, 0.94862100E-01, -.30408200E+00, -.23862200E+00, 0.37195100E+00, -.62224200E+00, 0.35863500E+00, 0.10169400E+01, -.66074700E+00, 0.16328800E+00, -.68167700E+00, 0.77340700E+00, -.29006800E+00, 0.20321500E+00, -.98763900E-01, 0.77850700E-02, -.32154200E-02, 0.16772100E+00, 0.38350700E+00, -.52882000E-01, 0.18034700E+00, -.10405500E+00, -.11650900E+00, -.45120600E-01, -.61700800E-01, 0.14538900E+00, -.24745400E-01, -.31386000E+00, -.52538300E-01, 0.28325900E-01, -.12546200E+00, 0.89035800E-01, -.82267700E-01, 0.15690600E+00, -.81492500E-02, 0.22472300E+00, 0.33610600E-01, 0.12078700E+01, -.20986500E-01, -.89704800E-01, -.13457600E+01, 0.84453700E-01, 0.13038500E+00, 0.46763700E-01, 0.65108000E+00, 0.98214600E-02, -.39259000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11066500E+01, 0.21540600E+00, -.13129200E+01, -.10920600E+01, -.50088500E+00, -.37249700E+00, 0.60509500E+00, 0.14014500E+01, 0.60766000E+00, 0.62578900E-01, -.41052000E+00, -.85463800E+00, 0.12077200E+00, -.96352500E+00, -.10134700E+01, -.12533100E+00, -.18055300E+00, -.21539700E+00, -.54833800E+00, -.16513900E+01, -.48607900E+00, 0.92359500E+00, 0.46894500E+00, -.75978800E+00, -.50863600E-01, -.43352700E+00, 0.11718300E+00, 0.84717900E+00, -.80219200E-01, -.20263300E-01, -.20199700E+00, 0.98073100E+00, 0.21705900E+00, -.65906500E+00, -.50014400E+00, -.62399900E+00, -.62302800E+00, 0.59685600E-02, 0.41391300E+00, 0.66268700E-01, -.28352500E+00, 0.25604100E+00, 0.30626100E+00, 0.12956900E-01, 0.29644800E+00, -.10973800E-01, 0.18635400E-01, -.37069500E+00, 0.21984100E+00, 0.10036700E+01, 0.27074500E+00, -.31895700E+00, 0.99269600E-01, 0.14131100E+00, 0.95037700E+00, 0.95596000E-01, 0.13503200E-01, -.51035300E-01, 0.14776200E+00, 0.12716800E+00, -.49923700E+00, -.25660800E-01, 0.26486700E+00, 0.49592500E-01, -.99811600E-01, 0.15185200E+00, -.14377000E+00, -.43867600E+00, 0.76163800E-01, -.74931600E-01, 0.25553900E+00, -.99276300E-01, -.56844900E-01, -.42387100E-01, 0.51400700E+00, -.31536100E-01, -.40895300E+00, 0.25801500E+00, -.38301300E+00, 0.28650000E+00, 0.30219600E+00, 0.46565100E-02, 0.64119200E+00, 0.38442300E+00, 0.30238800E-02, -.44723300E+00, -.67018400E-01, 0.31416600E+00, -.31324200E+00, -.18045200E+00, 0.19124800E+00, -.49731400E+00, 0.73925500E-01, -.12049400E+00, 0.91443100E-01, -.12756000E+00, 0.80957700E+00, 0.49789900E+00, -.33677200E+00, -.29182500E-01, 0.77203400E+00, -.97942400E-01, 0.79751000E-02, -.24065900E-01, 0.51824300E-02, 0.16546300E+00, 0.28120800E-01, -.66086700E-01, -.18526200E-01, 0.90483300E-02, -.27674700E-01, 0.11338600E+00, 0.27872800E-01, 0.11789400E-01, 0.16968900E-01, 0.31804600E+00, -.71293200E-01, -.52654400E-03, 0.52153300E-01, -.65494100E-01, -.57088800E-02, 0.66352800E-01, 0.57468500E-02, -.83377400E-02, -.16989300E+00, -.35572600E-01, 0.16535600E+00, 0.38239800E-01, -.32926800E-02, 0.62704700E-01, 0.17864100E-01, -.27050900E-01, 0.82618800E-01, -.35194100E-01, 0.20509100E-01, 0.23828200E+00, -.18570900E-03, -.14545800E-03, -.13942000E-01, 0.37364400E-01, 0.27550800E-02, -.13890400E-02, -.89935400E-02, -.51834300E-01, 0.22496000E-01, -.17773700E-01, 0.47680300E-02, -.18172500E-01, -.15287700E-02, 0.29991300E-01, -.35256900E-01, 0.77459000E-02, 0.31599300E-01, 0.33087400E-02, -.93965400E-02, -.78872800E-02, -.48214300E-03, -.15445900E-01, 0.14128700E-01, -.19034600E-01, -.95573300E-02, -.35797300E-01, 0.24409800E-02, 0.19352500E+00, -.14184100E-01, -.68654400E-02, -.16510500E-01, -.22228400E-02, 0.13158400E-01, -.22409400E-01, -.22438600E-01, 0.36633400E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.27726600E+01, 0.33610800E-01, 0.32746800E+01, 0.11867900E+01, 0.49120800E+00, 0.86213900E+00, -.24819500E+01, -.27545000E+01, -.87683700E+00, -.13183900E+01, 0.68937600E+00, 0.19615800E+01, -.71384800E+00, 0.32344400E+01, 0.26314600E+01, 0.11730100E+00, 0.10493600E+00, 0.48965400E+00, 0.15613700E+01, 0.19519400E+00, 0.78490400E+00, -.30117000E+00, -.52714400E+00, 0.17092300E+00, 0.99357800E-01, -.14861000E-01, 0.51458300E+00, -.10697800E+01, -.36297000E+00, -.69065100E+00, 0.43424700E+00, -.38325800E-01, -.43993800E-01, -.13045100E+01, 0.28733900E+00, 0.91748400E+00, 0.10792100E+01, -.13285400E+00, 0.21863400E+00, -.41123100E+00, 0.55184700E+00, -.12868300E+00, -.27077200E+00, -.46698700E-01, 0.17389000E-01, -.18021400E+00, 0.10837100E-01, 0.48633000E+00, 0.17323600E-01, -.10467300E+01, 0.75653100E-01, -.66182000E-01, -.20419500E-01, -.13381300E+00, 0.20086800E+00, -.30291500E-02, -.69150000E-01, -.57978200E-01, 0.85498500E-01, -.10418300E+00, 0.43694000E+00, -.10226100E+00, -.82428300E+00, -.15181500E+00, 0.48858900E+00, -.15319900E-02, -.55883900E-01, 0.45898700E-01, -.14865100E+00, -.45842500E+00, 0.32725300E+00, -.29399600E+00, 0.19234200E+00, -.12553000E+00, -.82666100E-01, -.59998000E-01, -.62564000E-01, -.13129000E-01, 0.14477300E+00, -.23249000E+00, -.15654600E+00, -.13727500E-01, -.36224900E+00, 0.14237700E-01, -.59607000E-01, 0.31928100E+00, -.29749400E+00, 0.13622300E+01, -.27681500E-01, 0.41492900E+00, 0.19242000E+00, 0.85628900E+00, -.17751400E-01, -.25032000E+00, -.14523200E+00, 0.43914800E+00, 0.74724500E+00, 0.64645600E+00, -.53461200E+00, -.13821800E+00, 0.19108900E+00, 0.12776100E+00, 0.38353700E-01, -.21991700E-01, -.13654300E-01, 0.13241600E+00, 0.26309900E+00, -.20325500E+00, -.25165100E-01, -.10664400E-01, -.63329600E-01, 0.23432000E+00, -.31878200E-01, -.57593600E-01, -.18634700E+00, 0.36937300E+00, 0.45189100E+00, 0.10782000E+00, -.21283800E+00, -.66019700E-01, 0.68807300E-02, 0.14361500E-02, 0.31804900E-01, -.61370900E-02, 0.62851200E-01, 0.17613900E-02, 0.48777300E-01, 0.69622700E-01, 0.52144500E-01, -.13180400E+00, 0.13665000E+00, -.96415800E-01, -.26898700E+00, -.22700000E-01, 0.12270200E-01, 0.15732600E+00, -.11262500E+00, 0.28351200E-01, -.71754400E-01, 0.76976300E-01, -.69051700E-02, 0.78992100E-02, -.10904900E-01, -.12210200E+00, -.89663400E-02, -.44547800E-01, 0.38420800E-01, -.48546100E-01, 0.19359500E-02, 0.66172400E-02, 0.56784400E-01, 0.15802200E-01, 0.47813000E-02, 0.67625900E-03, 0.21164100E-01, 0.35683100E-01, 0.10276600E-02, 0.96712400E-02, -.12418000E-01, -.77577000E-02, -.31753600E-01, -.33859000E-01, -.47027100E-01, -.77924100E-01, 0.30035200E+00, -.36965300E-02, 0.58021300E-02, 0.14451900E-02, -.11997500E-01, 0.14862700E-01, -.96363100E-02, -.11485200E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12740800E+01, 0.26296700E+00, 0.17147100E+01, -.11927300E+01, 0.46998000E+00, -.36789700E-01, -.50651600E+00, 0.91323100E+00, 0.14738100E+01, 0.41681300E+00, -.24362800E+00, -.72079400E+00, -.25378000E+00, -.28040100E+00, -.53061900E-01, -.11973400E+01, 0.84242100E-01, -.11365800E+00, -.42044100E+00, 0.29478300E+00, -.68522000E+00, 0.71064100E+00, -.38610500E-01, 0.49051500E-01, -.81278500E-01, -.57995400E+00, -.63117300E+00, 0.47213300E+00, -.32070300E-01, 0.30690800E+00, 0.30104500E+00, -.19074600E+00, 0.41858100E+00, -.84420600E+00, 0.23792300E+00, -.32196900E+00, -.30881300E+00, 0.54920300E+00, 0.43070600E-01, -.62157200E-01, 0.50792800E-02, 0.17385900E+00, -.17670700E+00, -.12910000E+00, 0.66515600E-01, -.17471200E+00, -.70224000E-01, -.75476000E-02, -.13226400E+00, -.86440000E-01, -.13564100E-01, 0.40661100E-01, 0.68016600E-02, 0.55112300E-01, 0.16409900E+00, -.25826800E-01, 0.75986100E-02, -.72879700E-02, -.45350900E-01, -.49003900E-01, -.23782000E-01, 0.64981700E-01, 0.95297900E+00, -.65300200E-01, -.62398700E-01, 0.96086700E-01, -.79222000E-01, -.38430000E+00, 0.11447300E+00, 0.14756500E-01, -.48198200E-01, 0.25312800E+00, -.29022400E+00, -.11617800E+00, -.12668200E-01, -.98481400E-01, -.18371600E+00, 0.81663900E-01, 0.14792600E+00, -.17925900E+00, 0.12336500E+00, -.63295100E-01, -.55985600E+00, 0.48012000E-01, -.63919300E-01, -.35384400E-01, 0.12188100E+00, 0.33600700E+00, -.17204800E+00, -.33908700E-01, 0.29196200E+00, 0.33510700E+00, -.12708300E+00, 0.76015600E+00, 0.64330200E-02, 0.95226800E-01, 0.54579700E+00, 0.13231100E-01, -.97795900E-02, -.59346300E-02, -.12120800E+00, 0.14894500E+00, 0.12005500E+00, 0.21838600E-01, 0.34078200E-01, -.30725600E+00, -.37197400E+00, 0.25062200E+00, 0.60997700E-02, 0.15482700E-01, -.11661200E-01, -.27084600E+00, 0.75339900E-01, -.26339700E-02, -.21263600E-01, 0.19777100E+00, 0.64034600E-01, 0.87024600E-01, 0.12442000E-01, 0.21129300E-01, 0.15328000E-01, -.14091000E-02, -.29449100E-01, -.13321000E-01, -.90135400E-01, 0.37607500E-01, 0.88814400E-01, 0.56242000E-01, -.91626500E-02, 0.28455000E-01, -.12387400E+00, 0.41561100E-01, 0.17368900E+00, -.85395300E-01, 0.18628600E-01, -.52361500E-01, 0.49922800E-01, 0.58064700E-02, 0.84711200E-01, -.54475100E-01, -.20071000E-01, -.19076600E-01, -.29416100E-01, -.15145600E+00, -.31617000E-01, -.14118100E-02, 0.20625500E-01, -.40062500E-01, -.12972400E-01, -.51607500E-03, 0.16465100E-01, 0.18437100E-02, 0.15392900E-01, 0.91187800E-02, 0.50100000E-02, 0.26121300E-01, 0.20821300E-01, 0.22725000E-01, -.89626600E-02, 0.12516800E-01, 0.17032200E-01, -.10765500E-02, -.12316800E+00, -.11919000E-01, -.80515900E-01, -.47942600E+00, 0.31898200E-01, 0.43372000E-01, -.45818800E-02, 0.19255000E+00, 0.82046600E-02, -.15483000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14388300E+01, -.25497900E+00, -.10916500E+01, 0.56905600E+00, -.87090900E+00, -.40467800E+00, -.16422000E+01, -.21178700E+01, -.62732100E+00, 0.62214200E+00, 0.82304000E+00, 0.12987600E+01, 0.16968600E+00, 0.15229400E+01, 0.90643500E+00, 0.27374900E+01, 0.18817700E+00, 0.17052500E+00, 0.11265300E+01, 0.24883800E+01, 0.40613500E+00, -.85358800E+00, -.79282100E+00, 0.53840700E+00, -.15893000E+00, -.11059600E+01, 0.20407900E+00, -.13726000E+01, -.38377400E+00, -.40219500E+00, -.35328200E+00, -.40121300E+00, -.44561100E+00, 0.76469400E+00, 0.65481600E+00, -.27253700E+00, -.84394600E+00, 0.11423100E+00, 0.44129800E+00, 0.64654000E-01, 0.19081600E+00, 0.30324300E+00, -.35620300E+00, -.14082300E+00, 0.12970000E-02, -.19440000E+00, 0.67808100E-01, 0.44545300E+00, -.45569100E+00, -.14038500E+01, -.12018500E+00, 0.35670600E-01, -.26464300E+00, -.31626100E+00, -.78705300E+00, -.58935900E-01, 0.46457200E-02, 0.14509400E+00, -.28505000E+00, -.38217200E+00, 0.57021200E+00, 0.11679200E+00, 0.73167100E+00, -.37631700E+00, -.26191400E+00, -.13559600E+00, 0.13292600E+00, 0.51591000E+00, 0.11597600E-01, 0.26946500E+00, 0.89126400E-01, 0.12880800E-01, -.25199500E+00, -.75270100E-01, -.45360800E+00, 0.17402900E+00, 0.26890000E+00, -.17521100E+00, 0.57262400E+00, -.24008400E+00, -.20826900E+00, -.25997200E-02, -.71276000E+00, -.14766700E+00, 0.15003500E+00, -.35285200E+00, -.13998700E+00, 0.15628100E+01, -.73622000E-01, -.23078000E+00, 0.33245500E-01, 0.13142900E+00, -.20634800E-01, 0.91756200E-01, -.11162500E+00, -.91792400E-02, -.39348800E+00, -.80030100E-01, 0.19314200E+00, 0.48496800E-02, -.25226900E+00, 0.17121900E+00, 0.23761100E+00, 0.77837800E-01, 0.75548100E-01, -.23275300E+00, 0.18716200E+00, -.18325300E-01, 0.28495900E-02, -.11465600E+00, -.45995200E-02, -.40682500E+00, 0.15356700E-01, -.62350900E-01, -.92768300E-01, -.34188600E+00, 0.44481300E+00, 0.49801900E-01, -.83596600E-01, 0.20949400E+00, 0.11942300E-01, -.30045700E-01, 0.13263700E+00, -.94758800E-01, 0.32369000E+00, 0.19836300E-01, -.20354800E+00, -.16036200E-01, 0.37652900E-01, -.25174600E+00, -.90061200E-01, -.60516300E-02, -.69917300E-01, -.28698000E+00, 0.62106000E-01, -.18727400E+00, -.11383200E+00, 0.33541800E-02, 0.39863200E-01, -.61835800E-01, -.37387300E-01, -.15902600E-01, 0.91223300E-01, -.26704600E+00, 0.89309200E-02, -.59129500E-01, 0.60890400E-01, -.32418300E-01, 0.14382200E-02, 0.39167000E-01, 0.94010800E-02, 0.41893600E-01, 0.27415900E+00, -.31652600E-01, 0.83567400E-01, 0.33038600E+00, 0.81313600E-01, -.50109500E-01, -.29940800E-01, 0.38134600E-02, -.13007000E+00, -.69031800E-01, -.11205000E-01, -.96915700E-01, 0.17355600E-01, 0.25928300E-01, 0.27922100E+00, 0.12160600E-01, 0.59652100E-01, 0.58773400E-01, -.28493100E-01, -.18200500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.98793600E+00, -.15729400E+00, -.23880900E+01, -.69130100E+00, 0.22783500E+00, -.57168900E+00, 0.10271900E+01, 0.51583900E+00, -.20177600E+00, 0.48373400E+00, 0.48003300E-01, -.45835500E+00, 0.26326100E+00, -.49518600E+00, -.68376000E+00, 0.10668000E+01, 0.48910700E-01, -.33012400E+00, -.26782700E+00, 0.78079200E+00, -.11788900E+00, -.32696400E+00, -.50807900E-01, 0.23278500E+00, -.24876100E-01, -.26668400E+00, -.14670700E+00, 0.32423300E+00, 0.23627300E+00, -.10409600E+00, 0.34470200E+00, -.47325500E+00, -.74528300E+00, -.18148400E+01, 0.19255300E+00, 0.36922700E-01, -.41215300E+00, -.14729900E+00, -.35272900E-01, 0.45098200E-01, -.24256100E+00, 0.10468100E+00, 0.67011200E-01, 0.53480400E-01, 0.15030200E+00, -.10031800E+00, 0.95725600E-02, -.42028400E+00, -.72171000E-01, -.17220300E+01, -.93209100E-01, 0.87984500E-01, 0.47293300E-01, 0.29102300E-01, 0.79602800E-01, -.25450100E-01, 0.42783100E-02, -.40764800E-02, -.30784300E-01, 0.97739200E-01, -.26282400E+00, -.16453600E-01, 0.54217400E+00, 0.48726600E-01, -.48586400E-01, 0.95537600E-01, -.71594200E-01, -.29449600E+00, 0.17528000E+00, 0.57686900E-01, -.50342300E-01, -.13391500E+00, 0.10049800E+00, 0.96976500E-01, -.28861600E+00, 0.12841100E-01, -.12081500E+00, 0.56724800E-01, -.28421100E-01, -.20671400E-01, -.69802400E-01, 0.84441400E-02, -.43026600E-01, 0.30112500E-01, 0.77308800E-01, -.15395600E+00, 0.50075100E-01, -.75952400E+00, -.33424800E-01, 0.47802100E-01, -.10022300E+00, -.31367500E+00, -.98182200E-01, -.10291600E+00, 0.85756900E-01, -.18165800E+00, -.87503200E+00, -.85795300E-01, 0.11516900E+00, 0.38435200E-01, -.11013400E+00, -.23454500E+00, -.86566300E-01, 0.36897500E-02, -.99444000E-02, 0.15635300E-01, -.38199600E-01, 0.60503500E-01, -.83276800E-02, 0.29830400E-01, 0.80675600E-01, 0.51432400E-01, 0.19493100E-03, -.25260600E-02, 0.54237300E-01, -.34888900E+00, -.30257700E+00, -.16717300E-04, 0.69197000E-01, -.15029700E-01, -.19463200E-01, -.50361400E-01, -.20629500E+00, -.12293900E+00, 0.39158700E-01, -.67515600E-02, 0.44724700E-01, 0.17770400E-01, 0.17602100E-02, 0.13122300E+00, 0.10460600E-01, -.21628800E-01, -.78433100E-01, 0.31853700E-01, -.24743700E-01, -.10473800E-01, 0.35969000E-01, -.41443500E-02, -.37845100E-01, 0.30467200E-01, -.16983300E-02, 0.67222400E-02, 0.27789600E-01, -.13176000E+00, 0.47889000E-01, -.61794200E-02, 0.48180600E-02, 0.56159500E-02, -.16428400E-01, 0.60421000E-02, -.74756700E-01, 0.80402100E-02, 0.30312000E-01, 0.33844200E-01, -.31197200E-01, -.12406000E+00, 0.60276300E-03, 0.10265000E+00, 0.83890400E-02, 0.62425000E-02, 0.10035000E+00, 0.46465300E-02, -.15472700E-01, -.56475700E-02, -.49697900E-02, 0.46349800E-01, -.35300900E-01, 0.15502500E+00, 0.54644500E-01, 0.72015000E-01, 0.33652400E-03, 0.11621400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.76998500E+00, 0.41132200E-02, 0.14912100E+01, 0.37415100E+00, 0.30062800E-01, 0.18009500E+00, -.27532500E+00, -.62053300E+00, 0.11352700E+00, -.60166700E-01, 0.12476300E+00, 0.46256800E+00, -.37366400E-01, 0.38881700E+00, 0.44043500E+00, -.21165500E+00, -.29446700E-01, 0.81827700E-01, 0.19473500E+00, -.12575100E+00, 0.97432200E-02, 0.44982000E-01, -.35162200E-01, 0.83241100E-02, -.20523700E-02, -.70124100E-01, 0.22051700E+00, -.23084100E+00, -.60152000E-01, -.43801200E-01, 0.26109100E-01, 0.10675200E+00, 0.13919500E+00, 0.11312100E+00, -.22060600E-01, -.34399400E-01, 0.15728100E+00, -.40176500E-01, 0.92075200E-01, 0.12811900E-01, -.34912200E-01, -.36239000E-01, -.85928400E-01, -.24488700E-01, -.50871400E-01, 0.60108400E-02, -.12088200E-01, 0.15881200E+00, 0.43922000E-02, 0.13985900E+00, -.15692900E-01, 0.21631900E-02, 0.23926200E-01, -.15978700E-01, 0.61647200E-02, -.76693900E-02, -.80722700E-02, -.12965400E-01, 0.37603200E-01, -.24612900E-01, 0.98540300E-01, -.69896500E-02, -.28110600E+00, -.14943100E-01, 0.73730500E-01, -.13340300E-01, 0.61402900E-02, 0.36917800E-01, -.57343400E-01, -.21578200E-01, 0.26306000E-01, 0.24116100E-01, -.29380100E-01, -.37333200E-01, 0.46923400E-01, -.20539300E-01, 0.26222300E-02, 0.17216000E-01, 0.68302900E-02, -.11065400E-01, -.19873900E-01, -.56656700E-02, 0.30288600E-01, -.14152300E-02, -.21315200E-01, 0.11210300E+00, -.30520300E-01, 0.20609300E+00, 0.48164400E-02, 0.94436600E-02, 0.51756300E-01, 0.89463400E-01, -.32640300E-03, 0.15185100E-01, 0.10797700E-01, 0.45992700E-01, -.42633600E-01, 0.60437800E-01, -.28225300E-01, -.10496900E-03, -.74470200E-01, 0.55428400E-01, 0.24926500E-01, 0.15314500E-01, 0.45442800E-02, -.44589600E-01, 0.35509500E-01, -.38645800E-01, -.53712400E-02, 0.81798000E-02, -.18547500E-01, 0.28602100E-01, 0.33338100E-02, -.11335500E-01, -.14853000E-01, 0.37028200E-01, 0.12104700E+00, 0.44730400E-01, -.86113800E-02, 0.45474400E-02, -.34414300E-03, 0.13132500E-01, 0.24665500E-01, 0.13606300E-01, 0.50228300E-01, 0.31869700E-03, -.80983300E-02, 0.31168100E-01, 0.20434300E-02, 0.30143200E-02, -.58613300E-02, 0.28084900E-02, 0.14096100E-01, 0.16935200E-01, -.92068200E-02, 0.39118900E-02, 0.43705000E-02, -.18501900E-03, 0.21838900E-02, 0.19410000E-02, 0.17343600E-02, 0.15596900E-03, 0.27408000E-02, 0.10838500E-02, 0.13639600E-02, -.32413700E-03, -.42184600E-04, 0.75131200E-04, -.27755300E-02, 0.38289700E-02, -.50535300E-02, 0.17533000E-02, 0.42626900E-01, -.99228600E-02, 0.54078200E-01, 0.11442900E+01, 0.13006000E-01, 0.29660700E+00, -.16077200E-01, 0.12664800E-01, -.11303500E+01, -.73321200E-02, -.94418100E-02, 0.56829600E-01, -.54341700E-01, -.82993100E-01, 0.29620100E+00, 0.89933600E-01, -.36741300E+00, -.68706300E-01, -.42998000E-01, -.63335200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.46562200E+01, 0.16316500E+00, -.43862200E+01, -.24269000E+01, -.15629400E+01, -.16993600E+01, 0.13750400E+01, 0.40274100E+01, -.11220500E+01, 0.48412200E+00, -.74063600E+00, -.31608600E+01, 0.48782100E+00, -.26781000E+01, -.34169200E+01, 0.23223600E+01, 0.18713200E+00, -.41784900E+00, -.10921900E+01, 0.25920800E+01, -.48969400E+00, -.82708100E+00, -.35151600E+00, 0.29924200E+00, -.90974500E-01, -.18132200E+00, -.12755800E+01, 0.33277400E+00, -.73701900E-01, -.74537400E-01, -.56055500E+00, -.16993700E+00, -.66538000E+00, 0.26140200E+01, 0.40711900E+00, 0.68949100E-01, -.11828100E+01, 0.36576500E+00, -.12900300E+00, -.56512600E-01, -.59197000E+00, 0.42396900E+00, 0.10520100E+00, 0.79277500E-01, 0.29493700E+00, -.30377600E+00, 0.16223000E+00, -.96311800E+00, -.52463800E-01, -.75352700E+00, 0.30984300E-01, -.91023600E-01, -.26097800E+00, 0.70378600E-01, 0.11959800E+00, 0.42938800E-01, 0.36528100E-01, 0.18360600E+00, -.47600400E+00, -.32686800E+00, -.27877500E+00, 0.75908200E-01, 0.18567600E+01, -.48726700E+00, -.12035400E+01, -.20593600E-01, -.68036500E-01, 0.23915400E+00, 0.75386700E-01, 0.50220200E+00, -.14044300E+00, -.94825000E-01, 0.55903200E+00, 0.47781600E+00, -.92693800E+00, 0.12794400E+00, 0.13670100E+00, -.13867600E+00, 0.10968400E+00, -.63219900E-01, 0.16793300E+00, -.74409400E-01, -.24386400E+00, -.16093700E+00, 0.28046200E+00, -.16817800E+01, 0.25808500E+00, -.18092100E+01, -.68565100E-01, -.20897100E+00, -.31556800E+00, -.47054200E+00, 0.14559000E-01, -.11530900E-01, -.97715200E-01, -.29762100E+00, 0.24871200E+00, -.30029200E+00, 0.20492100E+00, -.84790000E-02, 0.58077400E+00, -.39971800E+00, -.81616000E-01, -.11170700E+00, 0.31655500E-01, 0.45538300E+00, -.14371700E+00, 0.11619700E+00, 0.42688300E-01, -.10828100E+00, 0.44829400E-01, -.15962100E+00, -.15510500E-01, 0.75533800E-01, 0.61811400E-01, -.21779500E+00, -.70490000E+00, -.54810200E+00, -.13398200E-01, 0.15049000E-01, 0.12434900E-01, -.13768200E+00, -.68171600E-01, -.25752900E-01, -.31631500E+00, -.16111400E-01, 0.71641700E-01, -.33345000E-01, 0.40993100E-01, -.99594200E-01, 0.87131100E-01, -.49426100E-01, -.73422000E-01, -.23947200E+00, 0.11341500E+00, -.44216800E-01, -.11228200E+00, 0.57525000E-01, 0.12970000E+00, -.22599800E+00, -.70132700E-01, -.38083800E-01, -.10085400E-01, -.18422100E+00, -.64588200E-01, 0.46975800E-01, 0.88904800E-03, 0.12878500E-01, 0.29972400E-01, -.33488900E-01, 0.64091400E-01, -.23858300E-01, -.10399800E+01, 0.20839700E+00, -.22421100E+00, -.11554600E+01, 0.21775300E-01, -.20554600E+00, -.77728400E-01, -.11751100E-01, 0.11198500E+01, 0.11454500E+00, -.13712400E+00, -.44976200E+00, -.22548200E-01, 0.80020500E+00, -.41278400E+00, 0.20017700E+01, -.80249900E+00, 0.13271800E+01, -.18703800E+00, -.25452400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22832900E+01, -.16281500E+00, 0.35201000E+01, 0.13097000E+01, 0.62025400E+00, 0.90719600E+00, -.69749500E+00, -.16607900E+01, 0.73474900E+00, -.57908000E+00, 0.50966800E+00, 0.12404000E+01, -.14276200E+00, 0.95038900E+00, 0.79310700E+00, -.10874400E+01, -.12525000E+00, 0.34098700E+00, 0.62907500E+00, -.50597700E+00, 0.84649300E+00, 0.81826200E-01, -.41019700E-01, 0.30104800E+00, 0.88306000E-01, 0.29245100E-01, 0.59745300E+00, -.74920200E+00, 0.14692200E+00, 0.87767700E-01, -.12018900E+00, -.54335000E+00, 0.29347000E+00, -.60971200E+00, 0.58399200E-02, 0.22363900E+00, 0.13473300E+01, -.19266900E+00, -.10026400E+00, -.42788300E-01, 0.93935300E-01, -.44239800E+00, -.91936800E-01, 0.50454300E-01, -.33496300E+00, 0.29968600E+00, -.90604200E-02, 0.72514900E+00, 0.19986300E+00, 0.13533000E+01, -.81734300E-01, 0.90678800E-01, 0.31819500E+00, 0.89461100E-01, 0.69433700E+00, 0.20871500E-01, -.88551600E-01, -.15347500E+00, 0.23575600E+00, 0.11106600E-01, 0.23899700E+00, -.16625000E+00, -.20665200E+01, 0.45874400E-01, 0.68958500E+00, -.10158000E-01, -.10368600E+00, 0.30866000E-01, -.34705600E+00, -.45709800E+00, -.70330800E-01, 0.76943400E-01, 0.29246900E+00, -.34727500E+00, 0.33365600E+00, -.16065800E+00, -.41022400E-01, 0.93313600E-01, -.18471500E+00, 0.46383600E-01, 0.12208700E+00, -.57010300E-02, 0.34967700E+00, 0.42193900E-01, -.80742000E-01, 0.42406500E+00, -.56046400E-01, -.60992000E+00, 0.58564600E-01, 0.90397600E-01, 0.21507700E+00, 0.18145100E+00, 0.48742700E-01, 0.15069500E-01, 0.94210900E-01, 0.11403300E+00, 0.14098000E-01, 0.35250100E+00, -.21151600E+00, -.18482800E-01, -.37046400E-01, -.15410800E-02, 0.42159300E-01, 0.38499700E-01, -.15307800E-02, 0.25881800E-01, 0.14808800E+00, -.17595700E+00, -.15451600E-01, -.80601600E-03, -.88791600E-01, 0.24198700E+00, 0.54799800E-02, -.44463000E-01, -.44960900E-01, 0.18099600E+00, 0.14033600E-01, 0.49933700E-01, -.39147000E-01, -.10958400E+00, -.30326000E-01, 0.50801100E-01, -.14835500E+00, 0.91621800E-01, -.17164500E-01, -.30673700E-01, 0.59517400E-01, 0.11267700E+00, 0.20909500E-01, 0.10493400E+00, 0.10377700E+00, -.49138900E-01, 0.11146700E+00, 0.13927800E+00, -.26816500E-01, -.32901900E-02, -.13658800E+00, 0.37064300E-01, 0.99271400E-01, -.56166300E-01, -.77214100E-01, -.10145400E-01, 0.11767300E-01, 0.99543200E-01, 0.51452400E-01, 0.51360200E-01, -.33629800E-01, -.20529400E-01, -.70582200E-01, -.11080400E+00, 0.30012400E-01, -.16361000E-01, 0.44498700E-01, -.27243600E-01, 0.20665300E-02, 0.13538800E+00, -.12042400E-01, 0.41611300E-01, 0.10077000E-01, -.29285900E-02, -.15111300E+00, 0.74228000E-02, -.92312000E-02, -.10939400E+00, -.35282800E-01, -.75803800E-03, -.21566500E-01, -.66297300E-01, 0.24936000E+00, -.51023700E-01, 0.27982400E+00, -.45187800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27432100E+01, 0.14851200E+00, -.11531800E+01, -.17149300E+01, -.49594900E+00, -.99330300E+00, 0.76358500E+00, 0.18981400E+01, -.74513100E+00, 0.21529500E+00, -.23052400E+00, -.15407900E+01, 0.45208600E-01, -.91350900E+00, -.12804900E+01, 0.97960900E+00, 0.19427500E+00, -.14972100E+00, -.61656200E+00, 0.19649600E+01, -.48021100E+00, -.68815500E+00, -.38939000E+00, 0.19539800E+00, -.11227700E+00, 0.48957400E-01, -.13251100E+01, 0.34667700E+00, 0.33785100E-01, -.12372300E+00, -.12717300E+00, -.25601600E+00, -.60036300E+00, 0.15911800E+00, 0.36207400E+00, 0.95718300E-01, -.94942000E+00, 0.16805500E+00, -.94674300E-01, -.18752900E-02, -.20823900E+00, 0.31493300E+00, -.41233300E-01, 0.20712300E-01, 0.18217800E+00, -.25596200E+00, 0.74503100E-01, -.53260400E+00, -.12849700E+00, -.17516100E+01, -.49385100E-01, -.86363600E-02, -.19975800E+00, -.14255400E-02, -.21043400E+00, -.14387500E-01, 0.28394100E-01, 0.96080200E-01, -.26483000E+00, -.51027300E-01, -.26129300E+00, 0.51157800E-01, 0.15541800E+01, -.14443200E+00, -.57182700E+00, 0.22553800E-01, -.27304800E-01, -.31715700E-01, 0.16460800E+00, 0.26185900E+00, -.77741200E-01, -.10760300E+00, 0.28842500E+00, 0.31568000E+00, -.61410600E+00, 0.78890100E-01, 0.79943500E-01, -.74542900E-01, 0.14705400E+00, -.64548100E-01, -.30782400E-01, -.21288700E-01, -.23687300E+00, -.76708900E-01, 0.14484700E+00, -.76171500E+00, 0.10604500E+00, -.35152400E+00, -.27533400E-01, -.85264800E-01, -.18276900E+00, -.28064600E+00, -.63630000E-01, -.13931300E-01, -.38855600E-01, -.22685300E+00, -.29498100E+00, -.39647800E+00, 0.25871600E+00, 0.26936100E-01, 0.12534100E+00, -.11084400E+00, -.27396100E-01, -.45133400E-01, 0.26221500E-01, 0.10477000E+00, -.13451800E+00, 0.10859300E+00, 0.14247800E-01, -.44519000E-01, 0.66624000E-01, -.20720400E+00, -.95154400E-02, 0.30851400E-01, 0.41507100E-01, -.33596500E+00, -.27414000E+00, -.55310600E-01, -.11406500E-01, 0.88442100E-01, 0.19549600E-01, -.59986500E-01, -.11331700E+00, -.11412200E+00, -.43639800E-01, 0.26808100E-01, 0.11992500E+00, -.11753700E+00, -.28071400E-01, -.24629700E-01, -.41636100E-01, 0.12873000E-01, 0.47394900E-01, -.99876200E-01, 0.31348400E-01, -.88913700E-02, 0.11989300E+00, -.27361300E-02, 0.44090300E-01, -.59370500E-01, 0.23050100E-01, -.12548600E-02, 0.10575700E-01, -.14043400E-01, -.52319800E-01, -.30167100E-01, 0.18165800E-01, 0.61676600E-01, 0.58013600E-01, 0.46688700E-01, -.56314600E-01, 0.67789700E-02, -.17350500E+00, 0.62162800E-01, -.38581500E-01, -.36946700E+00, 0.13407800E-01, 0.14399000E+00, -.76171900E-02, -.17754000E-02, 0.32517300E+00, 0.59646000E-01, -.16911800E-01, -.56534800E-01, -.42881100E-02, 0.11066600E+00, -.13439900E+00, 0.33698000E+00, -.24137400E-01, 0.15299600E+00, -.16148700E+00, 0.15067800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 } },
        { { -.34945800E+05, 0.48804800E+04, 0.65101400E+03, 0.69497500E+03, 0.90892500E+04, -.10698300E+05, 0.36507500E+04, -.42498700E+03, -.25107000E+06, 0.29100100E+05, 0.28575000E+04, 0.11359600E+04, 0.66118300E+05, -.74136600E+05, 0.30933500E+05, -.63464700E+04, 0.15070200E+06, -.40313600E+05, -.11933100E+05, -.17218600E+05, -.29485400E+05, 0.53025800E+05, -.10422600E+04, -.12681700E+05, -.43646800E+05, 0.60742100E+04, 0.82715400E+03, 0.89211800E+03, 0.11335100E+05, -.13373000E+05, 0.45396600E+04, -.50662700E+03, 0.23669300E+06, -.39610000E+05, -.46477600E+04, -.41514200E+04, -.61957400E+05, 0.72112000E+05, -.25257500E+05, 0.33201300E+04, -.12651300E+06, 0.25840700E+05, 0.34744200E+04, 0.45242600E+04, 0.31329100E+05, -.39685100E+05, 0.11046900E+05, 0.58358600E+03, 0.52707600E+05, -.73177800E+04, -.10153700E+04, -.11069100E+04, -.13669400E+05, 0.16163100E+05, -.54569100E+04, 0.58242900E+03, 0.11609600E+06, -.19745700E+05, -.26854500E+04, -.34336500E+04, -.29449900E+05, 0.36105200E+05, -.10906300E+05, 0.26891300E+03, -.36666800E+05, 0.51167700E+04, 0.67921300E+03, 0.72151000E+03, 0.95383200E+04, -.11221500E+05, 0.38352600E+04, -.45239100E+03, 0.11205200E+06, 0.13495500E+05, -.25503400E+04, -.40856900E+04, -.28890900E+05, 0.37150000E+05, -.69265500E+04, 0.48604900E+03, -.11278300E+06, 0.12855600E+05, -.55673600E+03, -.19425800E+04, 0.30879200E+05, -.32331000E+05, 0.15849500E+05, -.55604600E+04, -.22256300E+06, -.13397200E+05, 0.77407100E+04, 0.86631100E+04, 0.54791800E+05, -.70030400E+05, 0.18733100E+05, 0.12953400E+04, 0.78889300E+05, -.29848000E+04, -.21677900E+04, -.31133800E+04, -.21524300E+05, 0.25146700E+05, -.60100900E+04, -.45383900E+02, -.25472400E+06, 0.21272500E+05, 0.25468200E+04, 0.69580400E+03, 0.67977600E+05, -.74453900E+05, 0.32713400E+05, -.71529300E+04, 0.15966800E+06, 0.54228400E+03, -.82044300E+04, -.11483800E+05, -.38210500E+05, 0.52419300E+05, -.97311700E+04, -.62760500E+04, 0.11391700E+06, -.17158200E+05, -.24340600E+04, -.58354200E+04, -.29942900E+05, 0.36691000E+05, -.93568500E+04, -.15336300E+04, -.26604000E+06, 0.53225900E+04, 0.38467700E+04, 0.20417900E+04, 0.68813700E+05, -.82738900E+05, 0.26019600E+05, -.71102300E+04, -.20640400E+05, 0.29060900E+04, 0.35969900E+03, 0.36529600E+03, 0.53913500E+04, -.62981400E+04, 0.21902000E+04, -.29357000E+03, -.20577600E+05, 0.28944900E+04, 0.36159000E+03, 0.37000300E+03, 0.53729300E+04, -.62816700E+04, 0.21792900E+04, -.28740300E+03, -.26257900E+06, 0.47577100E+05, 0.59712600E+04, 0.59390200E+04, 0.67126200E+05, -.80619500E+05, 0.27543400E+05, -.20843200E+04, 0.72221900E+05, -.22094100E+05, -.60967100E+04, -.87619400E+04, -.13727800E+05, 0.25788600E+05, 0.55207000E+03, -.66164000E+04, -.90121100E+05, 0.12418200E+05, 0.17709700E+04, 0.19726000E+04, 0.23345600E+05, -.27674400E+05, 0.92621200E+04, -.92037700E+03, -.26664500E+06, 0.29576400E+05, 0.12311800E+05, 0.18618300E+05, 0.64862300E+05, -.86040900E+05, 0.19195500E+05, 0.99361700E+04, 0.38806200E+05, -.54085500E+04, -.72910300E+03, -.78243300E+03, -.10085900E+05, 0.11884900E+05, -.40453300E+04, 0.46129000E+03, -.78205800E+05, 0.10790200E+05, 0.15493200E+04, 0.17281600E+04, 0.20243700E+05, -.24023000E+05, 0.80248800E+04, -.78222600E+03, -.64657500E+05, 0.17317800E+04, 0.10659600E+05, 0.39934400E+05, 0.19758100E+04, -.95097500E+04, 0.13482000E+05, -.24137500E+04, -.15654400E+05, 0.17474200E+04, -.52554800E+05, 0.40946100E+05, 0.39634000E+05, 0.56347800E+05, -.15877600E+05, 0.39740000E+05, 0.55194000E+05, -.31668000E+05, -.43801400E+02, 0.69082200E+03, -.11743100E+05, -.42412300E+05, 0.50176200E+04, 0.44505000E+05, -.18513700E+04, 0.43238900E+04 }, { 0.66777100E+00, 0.17677500E+05, 0.75094900E+03, 0.13512400E+04, -.12898000E+04, 0.29843100E+03, -.87727500E+03, 0.15106200E+04, 0.11944100E+05, 0.12814000E+06, 0.20495200E+04, 0.51194900E+04, -.72466700E+04, 0.90389400E+04, 0.10222500E+04, 0.64655400E+04, 0.24502400E+05, -.61746100E+05, -.34327400E+04, -.53153800E+04, -.12884600E+04, 0.63142000E+04, 0.16289700E+03, -.44605400E+04, 0.69067000E+02, 0.22074000E+05, 0.92376100E+03, 0.16674100E+04, -.16113100E+04, 0.39969200E+03, -.10834400E+04, 0.18670600E+04, 0.12779500E+05, -.11684700E+06, -.49899800E+04, -.98494700E+04, 0.57877400E+04, 0.18629300E+04, 0.46586800E+04, -.10484500E+05, -.12742200E+05, 0.59289600E+05, 0.22601400E+04, 0.39577300E+04, -.18286800E+03, -.19204000E+04, 0.23091300E+03, 0.39594700E+04, -.13361700E+03, -.26655900E+05, -.11044600E+04, -.19965900E+04, 0.19452000E+04, -.50183500E+03, 0.12972100E+04, -.22376700E+04, 0.67987800E+04, -.57370100E+05, -.26342100E+04, -.44837700E+04, 0.24672900E+04, 0.90072800E+03, 0.17925400E+04, -.47390500E+04, 0.38626200E+02, 0.18537000E+05, 0.77641400E+03, 0.14022100E+04, -.13489300E+04, 0.33130200E+03, -.90718100E+03, 0.15695500E+04, -.45598900E+05, -.75597900E+05, -.44938800E+04, -.66287200E+04, 0.20207500E+05, -.10513800E+05, 0.13958400E+05, -.86126800E+04, 0.96707400E+04, 0.55818700E+05, -.16821400E+04, -.40188900E+03, -.18738400E+04, 0.68421800E+04, 0.13965600E+04, 0.47470100E+03, 0.10778800E+06, 0.11864000E+06, -.85324000E+02, 0.20756600E+04, -.30986400E+05, 0.35885100E+05, -.17052700E+05, 0.64820600E+04, 0.36797800E+04, -.54864700E+05, -.60365600E+04, -.85095600E+04, 0.82691700E+04, 0.22675800E+04, 0.84366500E+04, -.90157300E+04, 0.19932900E+05, 0.13701300E+06, 0.38719200E+04, 0.75212200E+04, -.11968600E+05, 0.99143300E+04, -.41406800E+04, 0.96343000E+04, -.42427700E+05, -.90698400E+05, -.46607600E+04, -.68255300E+04, 0.18710900E+05, -.12662100E+05, 0.12779200E+05, -.93459300E+04, 0.30990700E+05, -.74442400E+05, -.91266100E+04, -.12220900E+05, 0.48986200E+04, 0.12426600E+05, 0.81540900E+04, -.12050800E+05, 0.95481700E+05, 0.12973600E+06, 0.34790100E+04, 0.78044800E+04, -.33096200E+05, 0.25271100E+05, -.21932500E+05, 0.11534600E+05, -.68264500E+01, 0.10416700E+05, 0.43513300E+03, 0.78849300E+03, -.74912100E+03, 0.18114700E+03, -.50205400E+03, 0.88185700E+03, -.14507000E+02, 0.10392100E+05, 0.43768400E+03, 0.79095100E+03, -.74981500E+03, 0.17588400E+03, -.50586300E+03, 0.88412200E+03, -.33066300E+04, 0.11840500E+06, 0.48895100E+04, 0.96624100E+04, -.77284800E+04, -.13829500E+04, -.60423500E+04, 0.10237900E+05, 0.14810200E+05, -.27786800E+05, -.18033800E+04, -.27360200E+04, -.13060500E+04, 0.36939900E+04, -.45143200E+03, -.22171500E+04, 0.26047000E+03, 0.45702500E+05, 0.19134600E+04, 0.34356400E+04, -.33711100E+04, 0.84868500E+03, -.22605200E+04, 0.38510900E+04, -.15270700E+05, 0.15428000E+06, 0.11909300E+05, 0.16737800E+05, -.13220500E+05, -.32645000E+04, -.12614900E+05, 0.18134300E+05, -.31500400E+02, -.19629900E+05, -.82804100E+03, -.14920900E+04, 0.14332500E+04, -.34351800E+03, 0.96961000E+03, -.16694600E+04, 0.24187100E+03, 0.39628100E+05, 0.16498100E+04, 0.29683300E+04, -.29143600E+04, 0.74681500E+03, -.19469500E+04, 0.33275500E+04, -.43775900E+02, 0.28773800E+04, 0.19497500E+05, -.16234200E+05, 0.14399200E+04, 0.84654400E+04, -.20016100E+05, -.47148300E+03, 0.10700400E+05, 0.13183800E+04, -.54587600E+04, 0.15494000E+04, 0.15660700E+05, -.16911000E+04, -.16656800E+05, 0.76802200E+04, -.41936600E+04, -.17189500E+05, 0.63252800E+03, 0.17399000E+04, 0.12012400E+05, 0.17901700E+05, 0.20642500E+03, -.38015600E+04, -.21784600E+04, 0.72984500E+02 }, { 0.15533800E+00, -.23858300E+00, -.41839900E+04, -.50795900E+04, 0.52960000E+04, 0.29725300E+04, 0.52684400E+04, -.55196400E+04, -.48781800E+05, 0.25220800E+05, -.20229400E+05, -.24505000E+05, 0.37021500E+05, 0.23704000E+04, 0.33495700E+05, -.28271400E+05, -.86579800E+03, -.37241900E+04, 0.10603500E+05, 0.12582800E+05, -.12354900E+05, -.94895500E+04, -.15553000E+05, 0.14258100E+05, -.11592000E+03, 0.60142800E+02, -.51898200E+04, -.62983000E+04, 0.65993900E+04, 0.36572700E+04, 0.65523500E+04, -.68481900E+04, 0.15106000E+04, -.55368700E+03, 0.29250600E+05, 0.35460100E+05, -.37368200E+05, -.20097800E+05, -.36546800E+05, 0.38506200E+05, -.10887400E+05, 0.71020700E+04, -.12685000E+05, -.15188000E+05, 0.18360900E+05, 0.66489400E+04, 0.18155800E+05, -.16972100E+05, 0.21310800E+03, -.11423900E+03, 0.62425000E+04, 0.75726200E+04, -.79581000E+04, -.43771600E+04, -.78870100E+04, 0.82368800E+04, 0.38776800E+02, -.88854400E+03, 0.13932400E+05, 0.16794200E+05, -.17369800E+05, -.10007400E+05, -.17589800E+05, 0.18323600E+05, -.74159300E+02, 0.48781400E+02, -.43740000E+04, -.53109700E+04, 0.55552800E+04, 0.30886700E+04, 0.55191600E+04, -.57730800E+04, -.75459300E+05, 0.33153700E+05, 0.25318400E+05, 0.31484600E+05, -.12930600E+05, -.36153200E+05, -.21281000E+05, 0.32235900E+05, -.50343700E+05, 0.21753300E+05, -.40765600E+04, -.48758900E+04, 0.17745700E+05, -.92680400E+04, 0.14596700E+05, -.64524500E+04, 0.69815000E+04, -.51081800E+04, -.15315700E+05, -.19550100E+05, 0.16587900E+05, 0.16694900E+05, 0.23825700E+05, -.21602000E+05, -.77659400E+05, 0.33042300E+05, 0.27736600E+05, 0.33891300E+05, -.15617000E+05, -.38897900E+05, -.19718000E+05, 0.34645000E+05, -.26047200E+05, 0.10151600E+05, -.24297100E+05, -.29996300E+05, 0.35440900E+05, 0.12210600E+05, 0.38469100E+05, -.33697600E+05, -.68158700E+05, 0.34219600E+05, 0.27080300E+05, 0.33363500E+05, -.15532600E+05, -.38994100E+05, -.25654500E+05, 0.34707700E+05, -.85002900E+05, 0.34693600E+05, 0.35404500E+05, 0.42794100E+05, -.22720900E+05, -.45032800E+05, -.28121900E+05, 0.44478400E+05, 0.65348700E+04, -.64002000E+04, -.19396100E+05, -.25032800E+05, 0.21348800E+05, 0.15608600E+05, 0.29967100E+05, -.27585700E+05, -.49281800E+02, 0.42583200E+02, -.24738500E+04, -.30072200E+04, 0.31431700E+04, 0.17448200E+04, 0.31223400E+04, -.32675200E+04, -.12073200E+02, 0.21978100E+02, -.24733300E+04, -.30062500E+04, 0.31330100E+04, 0.17539300E+04, 0.31157800E+04, -.32656700E+04, -.26494800E+05, 0.10030800E+05, -.24889800E+05, -.29451100E+05, 0.37973200E+05, 0.65539300E+04, 0.30983100E+05, -.32990500E+05, -.45895700E+04, -.14605100E+04, 0.56770700E+04, 0.67600600E+04, -.53821700E+04, -.62235300E+04, -.65495100E+04, 0.75340400E+04, 0.28243300E+03, -.81726300E+02, -.10811700E+05, -.13109400E+05, 0.13614500E+05, 0.77328000E+04, 0.13524000E+05, -.14242900E+05, 0.99832000E+05, -.43567300E+05, -.51334500E+05, -.62394100E+05, 0.38512300E+05, 0.65614700E+05, 0.51461900E+05, -.65576600E+05, 0.47003600E+02, -.24095700E+02, 0.46313000E+04, 0.56215900E+04, -.58745800E+04, -.32783300E+04, -.58388200E+04, 0.61103400E+04, 0.20337400E+02, 0.25415700E+02, -.93226200E+04, -.11301800E+05, 0.11799300E+05, 0.66124900E+04, 0.11700600E+05, -.12286200E+05, 0.45152900E+01, 0.50106300E+04, -.64120700E+04, 0.40956300E+05, 0.56264700E+04, 0.33352800E+04, 0.16348300E+05, -.60991600E+04, -.11751400E+05, 0.49754400E+04, -.11096800E+05, -.10383700E+05, 0.65640200E+03, 0.14582800E+05, -.20055900E+04, 0.17742700E+05, 0.14266900E+05, -.97971500E+03, 0.30190000E+04, 0.31386100E+04, 0.18354100E+05, -.42699700E+05, 0.60717400E+04, 0.20566900E+05, -.53077600E+04, 0.64450700E+04 }, { -.28557700E+00, 0.10028500E+00, 0.19538700E+00, -.79119400E+03, 0.85548900E+03, 0.59031700E+03, 0.13016600E+04, -.78534600E+03, -.67026300E+04, 0.32826200E+04, 0.44264400E+03, -.50628600E+04, 0.68652000E+04, 0.11885700E+04, 0.65947000E+04, -.49675300E+04, -.65264700E+04, -.54210700E+04, -.77973000E+03, 0.18833300E+04, -.20996800E+04, -.39052000E+04, -.31710600E+04, 0.14681000E+04, 0.38554000E+01, 0.59776400E+01, 0.31633200E+01, -.98084300E+03, 0.10623200E+04, 0.73368200E+03, 0.16133200E+04, -.97333400E+03, 0.31968800E+04, -.27203000E+03, -.41998900E+03, 0.47752600E+04, -.59732200E+04, -.26803400E+04, -.83599100E+04, 0.47851400E+04, 0.10043100E+04, 0.21193700E+04, 0.34150500E+03, -.22717500E+04, 0.24842800E+04, 0.20643200E+04, 0.35681400E+04, -.21585600E+04, -.14389000E+02, -.14529000E+02, -.77929700E+01, 0.11760800E+04, -.12749000E+04, -.88443000E+03, -.19361100E+04, 0.11667100E+04, -.15033300E+04, -.65861500E+03, -.74466600E+02, 0.24792100E+04, -.24381400E+04, -.23546500E+04, -.39576400E+04, 0.24020400E+04, 0.76376100E+01, 0.12646500E+02, -.32251300E+01, -.83434100E+03, 0.89755100E+03, 0.62163500E+03, 0.13625100E+04, -.82828000E+03, -.22718900E+05, 0.57112900E+04, 0.45231600E+04, 0.83130800E+04, -.27307600E+04, -.11427300E+05, -.78174200E+04, 0.81765200E+04, -.41138500E+04, -.40617000E+04, 0.26439700E+03, -.18237900E+04, 0.25502900E+04, -.44797000E+03, 0.21930300E+04, -.18402700E+04, -.30750000E+04, -.13816300E+04, -.18174700E+04, -.62279800E+04, 0.76135400E+04, 0.25759800E+04, 0.77984900E+04, -.67474300E+04, -.12642900E+05, -.40293800E+03, 0.17251000E+04, 0.45877800E+04, -.18090700E+04, -.72557500E+04, -.65331100E+04, 0.45703200E+04, -.64766600E+04, -.48290900E+03, -.82102500E+02, -.58382900E+04, 0.79228900E+04, 0.17168200E+04, 0.84724400E+04, -.57965200E+04, -.12909100E+04, -.27037400E+04, 0.22240300E+03, 0.35153100E+04, -.48943300E+04, -.36807200E+04, -.68673500E+04, 0.36969400E+04, -.22708500E+05, 0.65165100E+03, 0.21399800E+04, 0.60502300E+04, -.99907600E+03, -.11374700E+05, -.80734900E+04, 0.57843800E+04, 0.50294200E+04, -.77618900E+04, -.45090600E+04, -.11194500E+05, 0.92896000E+04, 0.71783900E+04, 0.11773200E+05, -.11235100E+05, 0.30884000E+01, 0.18584600E+02, -.88358000E+01, -.48243100E+03, 0.51218400E+03, 0.35396600E+03, 0.77501600E+03, -.47928100E+03, 0.51900200E+01, 0.14921200E+02, -.80480800E+01, -.47978200E+03, 0.51005400E+03, 0.35372100E+03, 0.77360100E+03, -.47662800E+03, -.13978500E+05, 0.25314000E+04, 0.26186300E+04, -.23890200E+04, 0.62823600E+04, -.18045200E+04, 0.67381900E+04, -.24487100E+04, -.31666500E+04, -.37014600E+04, -.44379000E+03, 0.84296400E+03, -.98180000E+03, -.19417100E+04, -.13348100E+04, 0.63427100E+03, 0.15381800E+03, 0.30418100E+02, 0.94914800E+01, -.20129600E+04, 0.21603300E+04, 0.15595000E+04, 0.33159400E+04, -.19967400E+04, 0.12747400E+05, 0.59892800E+04, -.30374800E+03, -.65382600E+04, 0.63015200E+04, 0.10049100E+05, 0.12629900E+05, -.65434000E+04, -.18845500E+01, -.19691900E+01, -.13535200E+01, 0.87541000E+03, -.94735000E+03, -.65408500E+03, -.14402800E+04, 0.86884000E+03, 0.99252600E+02, 0.24723000E+02, 0.16077700E+02, -.17340100E+04, 0.18722500E+04, 0.13356700E+04, 0.28651400E+04, -.17196400E+04, 0.37186400E+02, 0.94787900E+03, -.38073400E+04, 0.48683900E+04, 0.10835300E+04, 0.46240500E+04, 0.41627600E+04, -.12015100E+04, -.31710800E+04, 0.95374600E+03, -.43258500E+04, -.24846700E+04, -.57794200E+03, 0.22683000E+04, 0.24690700E+04, 0.28249900E+04, 0.23035200E+04, -.40123300E+03, 0.59213600E+03, 0.60218600E+03, 0.52497500E+04, -.50277500E+04, 0.12996900E+04, 0.17333200E+04, -.10105500E+04, 0.13326200E+04 }, { -.24035900E+00, 0.40049900E-01, -.34145300E+00, 0.43694000E+00, -.15346000E+04, 0.28053900E+03, 0.12689300E+04, -.15706000E+03, 0.55973800E+04, -.26182000E+04, -.67184600E+04, -.73972000E+04, -.10024600E+04, 0.41486200E+04, 0.79522000E+04, -.84459900E+04, -.35848900E+05, 0.16932300E+05, 0.74826100E+04, 0.84331400E+04, 0.55833100E+04, -.12044900E+05, -.31861100E+04, 0.85357300E+04, 0.18863200E+02, -.89879100E+01, -.10325200E+02, -.10139200E+02, -.19001700E+04, 0.35627900E+03, 0.15811100E+04, -.20582300E+03, -.32087500E+03, -.46153300E+03, -.14021700E+03, 0.11424600E+02, 0.10972600E+05, -.22651900E+04, -.91958200E+04, 0.10932500E+04, 0.59881600E+04, -.31399300E+04, -.25171800E+04, -.28021100E+04, -.32665500E+04, 0.29774000E+04, 0.46195300E+04, -.32702100E+04, -.34622300E+02, 0.16410800E+02, 0.15742800E+02, 0.14363000E+02, 0.22894100E+04, -.43371000E+03, -.19062900E+04, 0.25068300E+03, -.25022200E+04, 0.13367000E+04, 0.75653000E+03, 0.85212200E+03, 0.47404500E+04, -.17436000E+04, -.43071000E+04, 0.13495600E+04, -.11085600E+02, 0.53952800E+01, -.50331200E+01, -.56045800E+01, -.15956400E+04, 0.29243700E+03, 0.13317300E+04, -.17023100E+03, 0.75836900E+04, -.34918400E+04, -.63335700E+04, -.73376800E+04, 0.12505400E+05, 0.16595900E+04, -.24543800E+04, -.67951000E+04, -.85159500E+04, 0.39527500E+04, -.29403600E+04, -.31295400E+04, 0.41703900E+04, -.11722200E+04, 0.48769800E+04, -.34960200E+04, 0.25378500E+05, -.11288500E+05, -.71193600E+04, -.79389000E+04, -.27138000E+04, 0.82685200E+04, 0.46957900E+04, -.79321700E+04, 0.55630300E+04, -.26430000E+04, -.76945200E+04, -.85753900E+04, 0.16327900E+05, 0.25340300E+04, -.34662200E+04, -.79086100E+04, 0.14913700E+05, -.73681300E+04, -.90033400E+04, -.10105300E+05, -.38821900E+03, 0.71504200E+04, 0.78779400E+04, -.10852700E+05, -.28751400E+05, 0.13875600E+05, 0.26859400E+04, 0.31996200E+04, 0.12483300E+05, -.10277600E+05, -.37130700E+04, 0.35169400E+04, 0.51517400E+04, -.11538700E+04, -.71043200E+04, -.78364400E+04, 0.17317100E+05, 0.13139500E+04, -.45177400E+04, -.68444100E+04, 0.11153900E+05, -.56952600E+04, -.60352000E+04, -.65914100E+04, -.42814100E+03, 0.64406200E+04, 0.62105400E+04, -.67265400E+04, -.48776700E+02, 0.23482800E+02, 0.10506000E+01, -.35524700E+00, -.89299600E+03, 0.15405700E+03, 0.75506300E+03, -.93366500E+02, -.41773800E+02, 0.20100400E+02, 0.29900600E+01, 0.19011700E+01, -.89660800E+03, 0.15497700E+03, 0.75217200E+03, -.90881400E+02, 0.14831500E+04, -.35757100E+03, -.10090800E+04, -.11136000E+04, -.10219000E+05, 0.34381700E+04, 0.10077700E+05, -.23519600E+04, -.19276100E+05, 0.93017700E+04, 0.37352200E+04, 0.42516900E+04, 0.32722900E+04, -.64312500E+04, -.15583400E+04, 0.42982400E+04, 0.65982000E+02, -.33056400E+02, 0.28032400E+02, 0.38696200E+02, -.40252900E+04, 0.74192300E+03, 0.32593200E+04, -.36854800E+03, 0.35262600E+05, -.17246700E+05, -.93669800E+03, -.13086900E+04, -.25117900E+05, 0.11433900E+05, 0.74724300E+04, -.25361800E+04, -.77916000E+01, 0.37719200E+01, 0.40200700E+01, 0.38691400E+01, 0.16976500E+04, -.31379800E+03, -.14073700E+04, 0.17808400E+03, 0.81798200E+02, -.39701200E+02, 0.72479800E+01, 0.15604600E+02, -.34647300E+04, 0.64938100E+03, 0.28237300E+04, -.33688900E+03, -.21171800E+03, 0.27941600E+03, -.10273100E+05, 0.11727600E+04, 0.38427600E+03, -.13907200E+04, -.14021800E+04, -.49567100E+03, 0.15035200E+04, 0.31974200E+03, 0.14445900E+04, -.25976000E+04, 0.30557000E+04, -.43901100E+04, 0.85724700E+04, 0.70828300E+04, -.67308700E+04, -.15365200E+04, 0.21572800E+03, 0.17161000E+03, 0.14559500E+03, -.15227300E+04, 0.61438600E+03, -.17327900E+04, -.33847900E+03, 0.63433800E+03 }, { 0.37486100E-01, 0.37524200E-01, -.98788400E-01, -.14402900E+00, 0.44023100E-01, -.58912200E+03, -.14157000E+04, -.10345200E+03, 0.96241900E+04, -.77126900E+04, -.50887800E+03, -.11126300E+04, -.22380100E+04, -.47264000E+02, -.73267600E+04, -.14368900E+04, 0.31329600E+04, -.31781500E+04, -.70610200E+03, -.10581700E+04, 0.59086000E+03, 0.42530400E+04, 0.85857100E+04, -.24548600E+03, 0.12583200E+02, -.46344300E+01, -.81651400E+00, -.11989700E+01, -.34393500E+01, -.73099800E+03, -.17666800E+04, -.13022600E+03, -.98068400E+03, -.97214700E+02, 0.61370900E+02, 0.16117900E+03, 0.41272100E+02, 0.35963500E+04, 0.96194100E+04, 0.81483500E+03, 0.97129000E+03, -.30669200E+03, 0.13552000E+03, 0.12783800E+03, -.53292800E+03, -.19357200E+04, -.54028000E+04, -.24094900E+03, -.27498700E+02, 0.93662200E+01, 0.22263800E+01, 0.29300800E+01, 0.66531200E+01, 0.87877600E+03, 0.21338200E+04, 0.15868700E+03, 0.10639600E+03, -.16740200E+03, -.10960400E+03, -.14242100E+03, 0.12990400E+03, 0.21309900E+04, 0.49889700E+04, 0.22165200E+03, 0.92947500E+01, -.26591300E+01, -.12323600E+01, -.19095100E+01, -.15937900E+01, -.61346200E+03, -.14826700E+04, -.11025200E+03, 0.19846500E+05, -.68258900E+04, -.21457900E+04, -.31325300E+04, -.29595900E+04, 0.89695100E+04, 0.52212600E+04, -.23002800E+04, -.46085200E+03, -.12692800E+04, 0.44494800E+03, 0.35751300E+03, -.39514800E+03, -.11493100E+04, -.20310000E+04, 0.22878900E+03, -.15594500E+05, 0.47159000E+04, 0.23078800E+04, 0.28662100E+04, 0.14499200E+04, -.79732400E+04, -.60595700E+04, 0.19579000E+04, 0.81237500E+04, -.37936400E+04, -.42833100E+03, -.90002300E+03, -.20815800E+04, 0.48695400E+04, 0.54369500E+04, -.31251100E+03, 0.39710700E+04, -.53564300E+04, 0.28226500E+03, -.18785800E+02, -.17160200E+04, -.15332200E+04, -.78467700E+04, -.42143000E+03, 0.81087200E+04, -.45818700E+04, -.10067400E+04, -.14725300E+04, -.95041200E+03, 0.67365500E+04, 0.79245400E+04, -.59809400E+03, 0.11347500E+04, -.23949200E+04, 0.43480800E+03, 0.13097800E+03, -.91683300E+03, 0.34674400E+04, 0.84373100E+04, 0.79583500E+03, -.26702600E+05, 0.84840300E+04, 0.37668900E+04, 0.47616000E+04, 0.26802600E+04, -.11848600E+05, -.66349400E+04, 0.36863800E+04, 0.74219200E+01, -.17748400E+01, -.18703000E+01, -.30054900E+01, 0.24886900E+00, -.34271800E+03, -.83145200E+03, -.63738400E+02, 0.35929100E+01, -.18526800E+00, -.13900300E+01, -.22060800E+01, 0.87411100E+00, -.34367000E+03, -.83037200E+03, -.62907700E+02, 0.64110200E+04, -.14766100E+04, -.78842100E+03, -.12142800E+04, -.42165800E+03, -.42377100E+03, -.88114900E+04, -.16314000E+04, 0.24077000E+04, -.17224500E+04, -.39326700E+03, -.59231100E+03, 0.41099300E+02, 0.26262900E+04, 0.39998800E+04, -.16177800E+03, 0.59480600E+01, 0.12662000E+02, -.23754100E+01, -.26945800E-01, 0.97899800E+00, -.15275300E+04, -.36702300E+04, -.26935700E+03, 0.32732700E+04, 0.15412600E+04, -.53067200E+03, -.31504600E+03, -.59080900E+03, -.58416300E+04, -.16693900E+05, -.15730000E+04, -.50308500E+01, 0.19633300E+01, 0.32104000E+00, 0.45719400E+00, 0.13974900E+01, 0.65231300E+03, 0.15715000E+04, 0.11527200E+03, 0.24808300E+02, -.57985700E-01, -.29995500E+01, -.17928100E+01, -.46762600E+01, -.13169300E+04, -.31811700E+04, -.23472400E+03, 0.13611100E+02, -.29420900E+03, 0.72175900E+04, -.25482900E+04, -.34721000E+03, -.17219000E+04, -.13848000E+04, 0.40520700E+03, 0.79875100E+03, -.29959300E+03, 0.28436900E+04, -.21951600E+03, -.19594800E+04, -.88798600E+03, -.64093800E+04, -.13610400E+04, 0.52857500E+03, 0.37860600E+04, -.19416200E+03, -.18922800E+03, -.48726500E+04, 0.45148900E+04, -.42503700E+03, 0.20486400E+04, 0.31668800E+03, -.46027800E+03 }, { 0.69962900E-03, 0.19760300E-01, 0.17626000E+00, 0.16476000E+00, 0.86029500E-01, 0.44176100E+00, 0.43421700E+03, 0.43553500E+02, -.36182900E+04, 0.29712300E+04, 0.39530500E+03, 0.54675700E+03, 0.41931300E+03, -.12940100E+04, 0.23058100E+04, 0.70910200E+03, -.37922200E+03, 0.71501900E+02, -.25499000E+03, -.28137900E+03, 0.32186400E+03, -.64645800E+02, -.27327900E+04, -.57803100E+03, -.14217100E+01, 0.86411000E+00, 0.72772300E+00, 0.10606600E+01, -.43588100E+00, -.22387400E-01, 0.54160200E+03, 0.55382000E+02, 0.29345500E+03, 0.81150400E+02, -.24858600E+02, -.50840300E+02, -.14654900E+02, 0.14232000E+03, -.29185500E+04, -.34063100E+03, -.13063100E+03, 0.14275200E+03, 0.62576900E+02, 0.78888000E+02, -.57733500E+02, -.66276200E+02, 0.16392500E+04, 0.24058100E+03, 0.29551300E+01, -.18225000E+01, -.16522500E+01, -.24624200E+01, 0.96928800E+00, -.14440100E+00, -.65368600E+03, -.68052500E+02, -.26648200E+02, -.21525300E+02, -.18556400E+02, -.24456500E+02, 0.34754300E+02, -.38450800E+01, -.15065900E+04, -.17757400E+03, -.14319200E+01, 0.10382000E+01, 0.12251300E+00, 0.79378200E-01, 0.18859600E+00, -.44902100E-01, 0.45511300E+03, 0.45730800E+02, -.61029800E+04, 0.14658700E+04, 0.87790800E+03, 0.11340900E+04, 0.52253800E+03, -.25598500E+04, -.15531000E+04, 0.84904200E+03, 0.11233200E+04, -.49930600E+03, -.22755500E+03, -.28669300E+03, -.15281700E+03, 0.30291400E+03, 0.59996600E+03, -.21919900E+03, 0.64877500E+04, -.19787400E+04, -.85020300E+03, -.11389000E+04, -.93178400E+03, 0.17365000E+04, 0.20063600E+04, -.79828600E+03, -.27669300E+04, 0.84487500E+03, 0.30429700E+03, 0.40611800E+03, 0.32855300E+03, -.60854000E+03, -.15164300E+04, 0.17590700E+03, -.29658000E+04, 0.26381700E+04, 0.36044000E+03, 0.46753800E+03, 0.28138500E+03, -.12693100E+04, 0.25690700E+04, 0.64533900E+03, -.16710300E+04, 0.52577500E+03, 0.22428800E+02, 0.12884300E+02, 0.36174800E+03, -.70384900E+03, -.22246600E+04, -.31047200E+03, 0.15314400E+04, -.51284700E+03, -.39176700E+03, -.50838400E+03, -.12721500E+03, 0.49272500E+03, -.24521700E+04, -.75091500E+03, 0.78541100E+04, -.23090100E+04, -.12952500E+04, -.17465300E+04, -.81722300E+03, 0.34871800E+04, 0.24269400E+04, -.13763800E+04, -.21076700E+01, 0.13357400E+01, -.55288400E+00, -.10051100E+01, 0.10315000E+01, -.23070300E+00, 0.25608600E+03, 0.24653200E+02, -.12952700E+01, 0.90011900E+00, -.55438000E+00, -.96851400E+00, 0.86074600E+00, -.10759100E+00, 0.25557000E+03, 0.24658400E+02, -.27346600E+04, 0.45010900E+03, 0.28921400E+03, 0.42242100E+03, 0.27897000E+03, -.82979400E+03, 0.28519400E+04, 0.65780700E+03, -.41968600E+03, 0.55056800E+02, -.12364700E+03, -.13074700E+03, 0.24254700E+03, -.13865100E+03, -.12392200E+04, -.28177600E+03, 0.63626000E+01, -.95490800E+00, 0.26211000E+01, 0.46353400E+01, -.35225500E+01, 0.58844400E+01, 0.11216100E+04, 0.11787800E+03, -.28617600E+04, 0.12413900E+04, 0.80874100E+03, 0.10472800E+04, 0.89183900E+02, -.15222400E+04, 0.49156300E+04, 0.15324200E+04, 0.42226900E+00, -.30130700E+00, -.29387900E+00, -.43459800E+00, 0.20766200E+00, -.86314900E-02, -.48187500E+03, -.48770300E+02, 0.21982600E+01, 0.33648100E+00, 0.31426400E+01, 0.51615200E+01, -.32672700E+01, 0.34199100E+01, 0.97220700E+03, 0.10314500E+03, -.54327200E+01, 0.97541300E+02, -.21721200E+04, 0.98552400E+02, 0.12019500E+03, 0.44376600E+03, 0.33253800E+03, -.14334800E+03, -.23903200E+03, 0.10333900E+03, -.95791200E+03, -.22449800E+02, 0.87536500E+03, 0.51201500E+03, 0.19357500E+04, 0.69866400E+03, -.11170600E+03, -.11753900E+04, 0.64546000E+02, 0.61764400E+02, 0.11778000E+04, -.94616200E+03, 0.17180800E+03, -.57544000E+03, -.10737700E+03, 0.17439000E+03 }, { 0.79175100E-01, 0.47541600E-01, -.32359400E+00, -.43214600E+00, -.42758800E+00, -.77304400E+00, -.22164500E+00, -.23485700E+03, 0.26699200E+04, -.30117600E+04, 0.11373100E+03, 0.52776800E+03, -.15119100E+03, -.28734300E+03, -.22475400E+04, -.87574200E+03, 0.57808700E+04, -.55504600E+04, 0.15266200E+04, 0.19840900E+04, -.34144300E+04, 0.11889100E+04, 0.77115000E+02, 0.31456100E+04, -.23813500E+02, 0.13198700E+02, 0.63311900E+00, 0.28594000E+00, 0.63908800E+01, -.92238300E+01, -.27988500E+01, -.29273000E+03, -.24020400E+03, -.12738000E+03, -.22319200E+03, -.27027700E+03, 0.32041400E+03, 0.40547100E+02, 0.20386900E+03, 0.13230600E+04, -.76593100E+03, 0.11505300E+04, -.18767500E+03, -.20191900E+03, 0.62143700E+03, -.37182100E+03, -.38294000E+03, -.10460700E+04, 0.54244000E+02, -.31483100E+02, -.93442000E+00, 0.54606500E+00, -.14151900E+02, 0.19624700E+02, 0.39116200E+01, 0.35442700E+03, -.24546300E+02, -.40341300E+03, 0.20406800E+03, 0.27281400E+03, -.26463200E+03, -.71664500E+02, -.21949800E+02, 0.10754000E+04, 0.57558300E+01, 0.27919400E+01, 0.17310200E+01, 0.29844100E+01, -.24773800E+01, -.14123300E+01, -.64203800E+01, -.24326200E+03, -.92275700E+03, 0.98900800E+03, 0.16648900E+04, 0.24969700E+04, -.10743300E+04, -.19475800E+04, -.31296500E+04, 0.36138800E+04, -.21787800E+04, -.10277200E+04, 0.18790500E+04, 0.26608000E+04, -.98911500E+03, -.25962400E+04, -.26868200E+04, 0.22479900E+04, -.33834500E+04, -.11024100E+04, -.15096600E+04, -.18615600E+04, 0.34444300E+04, -.12858800E+03, 0.99455700E+03, -.31378800E+04, -.47738600E+04, 0.44127600E+03, 0.16747100E+04, 0.26274800E+04, 0.17959700E+03, -.37684300E+04, -.32184300E+04, 0.36420000E+04, 0.68140300E+04, -.69705000E+04, -.11223900E+04, -.98029100E+03, 0.37316700E+03, 0.17058500E+04, -.12226300E+04, -.23603800E+04, -.56322700E+04, 0.31445500E+04, 0.35382600E+04, 0.48968500E+04, -.24293600E+04, -.41268700E+04, -.31869800E+04, 0.61414000E+04, -.10361500E+05, 0.87252900E+03, 0.33129100E+04, 0.47723800E+04, -.14040200E+03, -.60075300E+04, -.38690200E+04, 0.61358700E+04, -.62469100E+04, -.16165300E+04, -.47744600E+03, -.17713100E+02, 0.31952200E+04, -.23799200E+04, 0.47604400E+03, -.14839500E+04, 0.34549800E+02, -.87193300E+01, 0.45312700E+01, 0.81312500E+01, -.13068800E+02, 0.50601600E+01, -.11483800E+02, -.13037900E+03, 0.32808100E+02, -.88140200E+01, 0.30795000E+01, 0.58314100E+01, -.11389000E+02, 0.62345900E+01, -.84369000E+01, -.13243200E+03, -.53471600E+04, 0.25951500E+04, 0.10126600E+04, 0.13468500E+04, 0.25621400E+03, -.22207400E+04, -.63182400E+03, -.24256300E+03, 0.22480900E+04, -.29792600E+04, 0.82812500E+03, 0.10717600E+04, -.15682400E+04, 0.43058000E+03, 0.21936100E+03, 0.16592800E+04, -.66882700E+02, 0.62650100E+02, -.18045400E+02, -.33264100E+02, 0.31753000E+02, -.59581600E+01, 0.24019300E+02, -.64260600E+03, 0.13040000E+05, -.23248200E+04, -.59472400E+04, -.83435300E+04, 0.26616500E+04, 0.85990400E+04, 0.53987400E+04, -.10743200E+05, 0.10495300E+02, -.55550200E+01, -.21387300E+00, -.14306800E-02, -.28368700E+01, 0.39020300E+01, 0.94828700E+00, 0.26067200E+03, -.10133600E+03, 0.68864400E+02, -.11357400E+02, -.22947200E+02, 0.35622400E+02, -.22105100E+02, 0.16525700E+02, -.55067200E+03, 0.17165000E+03, 0.12272700E+03, 0.42726700E+03, 0.40909400E+04, 0.15239300E+03, 0.13515900E+03, 0.43073300E+03, -.17842500E+03, -.44402400E+03, 0.12968400E+03, -.22036900E+03, 0.13603100E+04, -.85948400E+03, 0.29409300E+03, -.14789900E+04, 0.32745000E+04, 0.16143800E+03, 0.13470300E+04, 0.80881900E+02, 0.73094800E+02, -.12993500E+03, -.35458700E+04, 0.23765100E+03, 0.24913200E+04, -.13867300E+03, 0.22496000E+03 }, { -.27207400E+00, -.45320700E+00, 0.10880000E+01, 0.72402300E+00, -.12417600E+00, -.48457100E+01, 0.32790700E+01, 0.18654900E+01, 0.19036400E+05, -.80561700E+04, -.56131600E+03, -.11496500E+04, -.58527200E+04, 0.62678400E+04, -.58776800E+04, 0.65951700E+03, 0.33293700E+05, -.78517300E+04, -.90611400E+04, -.12381300E+05, 0.18464200E+04, 0.18144600E+05, 0.14057900E+05, -.11819500E+05, -.25506300E+02, 0.81312800E+01, 0.18017200E+02, 0.24110700E+02, -.18282700E+02, -.23232200E+02, -.33283800E+02, 0.27007700E+02, 0.29446800E+03, -.30051200E+03, 0.20751200E+03, 0.27361600E+03, -.24927100E+03, -.27666900E+03, 0.20582100E+03, 0.20290100E+03, -.43368500E+04, -.47022100E+03, 0.17010700E+04, 0.21647200E+04, -.10140300E+04, -.26923700E+04, -.30375400E+04, 0.23639400E+04, 0.60482400E+02, -.15194300E+02, -.42124000E+02, -.56582100E+02, 0.41663100E+02, 0.54560100E+02, 0.74659400E+02, -.62568800E+02, 0.25640900E+04, 0.13087000E+03, -.76441200E+03, -.10124300E+04, 0.23826600E+03, 0.14115400E+04, 0.11206000E+04, -.10133700E+04, -.32953200E+02, -.33157800E+01, 0.53467800E+01, 0.61952300E+01, -.26826700E+00, -.11731500E+02, -.37082200E+01, 0.83370200E+01, 0.67413200E+04, 0.12127500E+04, 0.15519100E+04, 0.81322700E+03, -.40988600E+04, 0.18659000E+04, -.47840500E+04, 0.24683000E+04, 0.15081900E+04, 0.61663500E+04, -.24671500E+04, -.33618900E+04, 0.15942400E+04, 0.32903600E+04, 0.12467900E+04, -.29167600E+04, -.38601900E+04, 0.55498700E+04, 0.10901900E+04, 0.20118600E+04, 0.58068700E+03, -.11918100E+04, -.11842600E+04, 0.18121500E+04, 0.60009600E+04, 0.60848200E+04, 0.41262400E+03, -.60135000E+02, -.29789100E+04, 0.52662300E+03, -.59337800E+04, 0.11218600E+04, 0.23238400E+05, -.48999700E+04, -.41587400E+04, -.55054600E+04, -.17289900E+04, 0.11093300E+05, -.69488000E+02, -.44076900E+04, 0.67814700E+04, -.23968900E+04, -.17639200E+04, -.29064600E+04, -.13227300E+04, 0.49842300E+04, 0.46585500E+02, -.20807600E+04, 0.31050300E+04, 0.11430100E+05, -.17130100E+03, -.74132100E+03, -.18542900E+04, 0.78274400E+03, -.60674900E+04, 0.27735600E+03, -.40573500E+04, 0.10835000E+05, -.96253000E+03, -.78395100E+03, 0.26187200E+04, -.15415900E+04, -.75508200E+02, -.19707300E+04, -.38548700E+02, -.99982100E+01, -.90980200E+01, -.14454800E+02, 0.18968700E+02, 0.17114400E+01, 0.27069700E+02, -.13089300E+02, -.29382700E+02, -.11276900E+02, -.96560500E+01, -.14693500E+02, 0.18298600E+02, 0.40544500E+01, 0.27391100E+02, -.14077600E+02, 0.40441900E+04, 0.21563000E+04, 0.36340300E+04, 0.41455900E+04, -.56224800E+04, 0.54200600E+02, -.79742200E+04, 0.53046900E+04, 0.22662600E+05, -.50283300E+04, -.54611500E+04, -.74431400E+04, 0.50208400E+03, 0.11831200E+05, 0.78593300E+04, -.70939100E+04, -.18286500E+03, -.12951500E+02, 0.92954900E+02, 0.13072600E+03, -.67252700E+02, -.13742100E+03, -.11952500E+03, 0.13399400E+03, -.18585900E+03, -.13957700E+05, 0.18845900E+04, 0.32331300E+04, 0.41595200E+03, -.26992500E+04, 0.24877800E+04, 0.23711400E+04, 0.93099000E+01, -.32911000E+01, -.73845500E+01, -.99581200E+01, 0.77816900E+01, 0.92536500E+01, 0.13838600E+02, -.11119600E+02, -.14007300E+03, 0.57508400E+01, 0.94456400E+02, 0.13101500E+03, -.83441300E+02, -.12684800E+03, -.14449400E+03, 0.13722900E+03, -.15097900E+03, 0.23184000E+02, 0.96962300E+03, -.72816700E+04, 0.21616400E+02, -.13297200E+02, -.48668100E+03, -.18177000E+02, 0.13941900E+02, 0.23488300E+02, -.16887700E+04, -.22519100E+04, -.51221800E+02, 0.12824700E+04, 0.39197800E+03, -.53434400E+03, -.67129100E+02, 0.13743900E+03, 0.18625800E+02, 0.18560000E+02, -.11630400E+04, 0.93543100E+04, 0.21124300E+02, -.85385400E+03, -.22831700E+02, 0.16151800E+02 }, { -.92648600E-01, -.31416000E+00, 0.62745900E+00, 0.57208400E+00, 0.22701800E+00, -.14866200E+01, 0.61245800E+00, -.47092400E-01, -.23473900E-01, 0.40322200E+04, 0.19162300E+04, 0.20965200E+04, -.25174300E+04, -.97567900E+03, -.26669800E+04, 0.26560300E+04, 0.50447700E+04, -.46596600E+04, -.25256600E+04, -.35512200E+04, 0.23409700E+04, 0.41318500E+04, 0.56988000E+04, -.35463100E+04, -.32363000E+01, 0.52792400E+01, 0.47809100E+01, 0.62813600E+01, -.65236000E+01, -.47071200E+01, -.11906000E+02, 0.74190500E+01, 0.24108600E+04, 0.14659900E+03, -.34251400E+03, -.48417300E+03, -.22045200E+03, 0.98648300E+03, 0.42529200E+03, -.46922400E+03, 0.21319600E+03, 0.44583800E+03, 0.54281500E+03, 0.70088000E+03, -.86055100E+03, -.42924400E+03, -.15057600E+04, 0.83101200E+03, 0.97464700E+01, -.13066400E+02, -.11509200E+02, -.15281700E+02, 0.14679000E+02, 0.12103100E+02, 0.27183600E+02, -.17747800E+02, 0.37288100E+03, -.45797600E+03, -.29945300E+03, -.40287100E+03, 0.30209800E+03, 0.37116000E+03, 0.54025500E+03, -.43665400E+03, -.65358900E-01, 0.79492100E+00, 0.12475000E+01, 0.13083500E+01, -.21399900E+01, 0.12078600E+00, -.17418100E+01, 0.23165100E+01, -.33806700E+04, -.51430300E+04, 0.71299700E+03, 0.82059700E+03, -.11171700E+03, -.20647700E+04, -.54822600E+04, 0.11130800E+04, -.64817100E+03, 0.47602900E+03, -.80241200E+03, -.11793000E+04, 0.10126400E+04, 0.87562100E+03, 0.14012100E+04, -.11403000E+04, 0.48521000E+04, 0.19806500E+04, -.95288400E+03, -.14696300E+04, 0.63616800E+03, 0.31208100E+04, 0.61459300E+04, -.13227400E+04, 0.96376300E+03, -.15610300E+04, 0.49205100E+02, -.49790200E+02, -.84401100E+03, 0.10854800E+03, -.35115500E+04, 0.15786800E+03, -.34796200E+03, 0.45410900E+04, 0.10235800E+04, 0.99565000E+03, -.12084800E+04, -.42911200E+03, -.88972000E+03, 0.12984800E+04, 0.47946000E+04, -.53680000E+04, -.14382200E+04, -.18191400E+04, -.35023100E+03, 0.19605900E+04, -.22968300E+04, -.17895400E+04, 0.31023700E+04, 0.23671200E+03, -.69590200E+03, -.11061500E+04, -.26265400E+03, 0.16096300E+04, -.87644400E+03, -.83813900E+03, 0.46626500E+04, 0.39670700E+04, -.13469800E+04, -.18778000E+04, 0.79533700E+03, 0.33535900E+04, 0.68326700E+04, -.22367200E+04, 0.18110000E+01, -.38508400E+01, -.26350900E+01, -.41421400E+01, 0.28929400E+01, 0.46857600E+01, 0.78638100E+01, -.33919800E+01, 0.18886900E+01, -.37920400E+01, -.27132500E+01, -.41085300E+01, 0.32601700E+01, 0.44569500E+01, 0.85637100E+01, -.36380100E+01, -.72373400E+04, -.30890100E+03, 0.21201000E+04, 0.26737100E+04, -.42093200E+03, -.36454800E+04, -.35697200E+04, 0.28475100E+04, 0.58631800E+04, -.38346400E+04, -.18294900E+04, -.25374800E+04, 0.85059500E+03, 0.34047100E+04, 0.27689500E+04, -.25254400E+04, -.54449200E+02, 0.48459900E+02, 0.30009000E+02, 0.41027400E+02, -.22721500E+02, -.37775000E+02, -.32077900E+02, 0.44670600E+02, 0.37846400E+03, -.99830500E+03, 0.10986900E+04, 0.15679500E+04, -.10516400E+04, -.12318100E+04, -.68184700E+03, 0.15161200E+04, 0.93651900E+00, -.21068700E+01, -.18849800E+01, -.24825400E+01, 0.26870300E+01, 0.17750200E+01, 0.47838000E+01, -.29358400E+01, -.39811800E+02, 0.39864100E+02, 0.28487500E+02, 0.38847400E+02, -.27297600E+02, -.34484900E+02, -.46138400E+02, 0.42710000E+02, 0.95403800E+01, 0.73037400E+01, 0.80695900E+03, -.31728700E+04, 0.67050700E+01, -.75636300E+02, -.38620600E+03, -.52869700E+01, 0.89744000E+02, 0.72556100E+01, -.26833000E+04, -.65048000E+03, 0.13174800E+04, 0.81833900E+03, 0.21776600E+02, 0.54238800E+03, -.90762200E+02, -.21902400E+04, 0.63931200E+01, 0.60549700E+01, -.10331600E+04, 0.42553600E+04, 0.55302900E+01, -.31697200E+03, -.71736600E+01, 0.40105100E+01 }, { -.10480700E+01, -.21924000E+01, 0.14641100E+01, -.11452600E+00, -.38322500E+00, -.30849600E+01, -.16102800E+01, -.15095700E+01, -.17369200E+01, -.29658900E+01, 0.94517500E+04, 0.10683900E+05, -.14740300E+05, -.60734600E+04, -.24267200E+05, 0.15863200E+05, 0.11700700E+06, -.42377300E+04, -.30664600E+05, -.41991200E+05, 0.66445600E+04, 0.63252600E+05, 0.52529600E+05, -.40005700E+05, -.16732100E+03, 0.45496900E+02, 0.75527400E+02, 0.10089200E+03, -.60632200E+02, -.11427800E+03, -.13405500E+03, 0.10978800E+03, 0.75335100E+04, -.46666400E+04, 0.78941200E+03, 0.76968200E+03, -.27224800E+04, 0.12847400E+04, -.16324700E+03, 0.81686600E+03, -.28331800E+05, -.29865000E+04, 0.69586700E+04, 0.89338900E+04, -.14552100E+04, -.14215000E+05, -.11114100E+05, 0.93044300E+04, 0.39246600E+03, -.80781700E+02, -.17587800E+03, -.23525100E+03, 0.13727400E+03, 0.26601200E+03, 0.29742200E+03, -.25360100E+03, 0.13536700E+05, 0.22919800E+04, -.30334600E+04, -.39821600E+04, 0.92178600E+02, 0.64885400E+04, 0.35216000E+04, -.39151000E+04, -.20581600E+03, -.24136000E+02, 0.37262000E+02, 0.46247400E+02, -.23226500E+00, -.78853600E+02, -.24736500E+02, 0.52888000E+02, 0.53770100E+04, 0.40443400E+05, 0.19939100E+04, -.47935900E+03, -.59981500E+04, -.31706500E+04, -.30981200E+05, 0.30384300E+04, -.73969900E+01, 0.44316200E+05, -.84186800E+04, -.11222500E+05, 0.78932500E+04, 0.98135000E+04, 0.67212400E+04, -.98804300E+04, 0.45993600E+04, 0.16336900E+05, 0.73229600E+04, 0.11292700E+05, -.57305900E+04, 0.18140800E+04, 0.38703800E+04, 0.12436600E+05, 0.23277100E+05, 0.49891900E+05, -.18045000E+04, -.35648600E+04, -.74015800E+04, 0.18782700E+04, -.29237600E+05, -.43917500E+03, 0.48021100E+05, 0.81519700E+04, -.72299600E+04, -.10050400E+05, -.46882200E+04, 0.23526600E+05, -.48454300E+04, -.67856400E+04, 0.10654700E+05, 0.72743600E+04, -.85857200E+04, -.12398200E+05, 0.18177600E+04, 0.13405800E+05, -.34342700E+04, -.10330600E+05, 0.12938500E+05, 0.75227600E+05, -.26804000E+04, -.45281200E+04, -.33259500E+04, 0.30986800E+04, -.22365400E+05, -.15911600E+04, 0.19148500E+05, 0.29999600E+05, -.22524100E+04, -.15822600E+04, 0.13832700E+04, 0.10602100E+05, 0.17022700E+05, -.36332000E+04, -.22812200E+03, -.65937500E+02, -.99773900E+01, -.21234600E+02, 0.65707200E+02, -.32812900E+02, 0.88288000E+02, -.17261100E+02, -.17196800E+03, -.72687200E+02, -.16568800E+02, -.28447200E+02, 0.62658600E+02, -.14309400E+02, 0.93934400E+02, -.26641400E+02, -.13235500E+05, 0.37421000E+05, 0.14695400E+05, 0.17692000E+05, -.13754900E+05, -.10263900E+05, -.30154700E+05, 0.20727400E+05, 0.90299600E+05, -.55343700E+04, -.20917500E+05, -.28334000E+05, 0.12624600E+04, 0.45666000E+05, 0.27558300E+05, -.27209400E+05, -.10234700E+04, -.19981100E+03, 0.41047200E+03, 0.56041000E+03, -.24365500E+03, -.63319700E+03, -.42791100E+03, 0.57494900E+03, 0.14561000E+05, -.94892400E+05, 0.61737800E+04, 0.98771400E+04, -.55042400E+04, -.62129100E+04, 0.46028400E+03, 0.70986700E+04, 0.63016400E+02, -.18644900E+02, -.30826600E+02, -.41405700E+02, 0.26170600E+02, 0.45367700E+02, 0.55672900E+02, -.44991700E+02, -.83401000E+03, -.37812800E+02, 0.39412700E+03, 0.53646200E+03, -.28665300E+03, -.58168500E+03, -.53858300E+03, 0.55792700E+03, -.87731600E+03, 0.33455800E+02, 0.67762600E+04, -.22993900E+05, 0.27014600E+02, -.18086800E+03, -.13485300E+04, -.13613200E+02, -.20961400E+03, 0.35617700E+02, -.95748100E+04, -.72018200E+04, 0.32667800E+04, 0.43534700E+04, -.55196200E+03, -.37469600E+04, -.44135500E+03, -.81026500E+04, 0.27949800E+02, 0.25037900E+02, -.44944700E+04, 0.29754500E+05, 0.33611500E+02, -.34572900E+04, -.32014100E+02, 0.11385300E+02 }, { 0.20363500E+00, -.60315600E-01, 0.82218500E+00, 0.78035800E+00, 0.41752200E+00, -.15292700E+01, 0.78711800E+00, -.69827200E+00, 0.16606400E+00, -.17701100E+00, 0.53568000E-01, -.33355800E+03, 0.56276100E+03, 0.12794300E+04, 0.42662400E+04, -.13678900E+03, -.29483600E+04, -.46067500E+04, -.89469500E+03, -.10446800E+04, 0.18957100E+04, -.10496500E+03, 0.12865100E+04, -.12032500E+04, 0.15088700E+02, -.14847500E+01, -.13803100E+01, -.24255800E+01, -.20491600E+01, 0.62750100E+01, 0.29547700E+01, -.19848200E+01, -.35913600E+03, 0.41320800E+03, 0.73776300E+02, 0.90861500E+02, -.27789100E+02, -.27678600E+03, -.24767400E+03, 0.74549400E+02, 0.22643200E+04, 0.93997500E+02, 0.72568100E+02, 0.40079900E+01, -.60488000E+03, 0.68023100E+03, 0.15014300E+01, 0.12757900E+03, -.34910500E+02, 0.20611000E+01, 0.30430500E+01, 0.52432000E+01, 0.49668000E+01, -.14172400E+02, -.55652100E+01, 0.42797800E+01, -.83544700E+03, -.22782300E+03, -.50783600E+02, -.46855900E+02, 0.25807200E+03, -.18777700E+03, 0.13030100E+03, -.87361700E+02, 0.12047500E+02, 0.17467600E+01, -.15720900E+01, -.23315600E+01, -.13118100E+01, 0.55728100E+01, 0.20073400E+01, -.20077400E+01, 0.13909100E+04, -.47900100E+04, -.48661300E+03, -.93973700E+03, 0.78824600E+03, 0.10767300E+04, 0.21707300E+04, -.76408600E+03, 0.40586000E+03, -.34920600E+04, -.36414900E+03, -.66868900E+03, 0.42030100E+03, 0.84418200E+03, 0.15929200E+04, -.54543500E+03, -.43721000E+03, 0.39770600E+03, -.93245600E+01, -.73313300E+01, -.11187200E+03, -.97795800E+03, -.10160100E+03, -.57426500E+02, 0.32364500E+03, -.34114600E+04, 0.30714800E+02, -.27587600E+03, 0.15736500E+03, 0.10869500E+04, 0.19614300E+04, -.88504500E+02, -.41473800E+04, 0.49931600E+03, -.29087600E+03, -.52006800E+03, 0.19735800E+04, 0.27614400E+03, 0.46283300E+04, -.54734100E+03, 0.19496000E+04, -.46627200E+04, 0.32812100E+02, -.24155600E+03, -.43774100E+03, 0.14914400E+04, 0.97648500E+03, 0.19388200E+02, 0.15072200E+04, -.39483400E+04, -.15683900E+03, -.56532600E+03, 0.44195800E+01, 0.10893600E+04, 0.22254000E+04, -.34082500E+03, -.31558300E+03, -.15482000E+04, 0.84724900E+03, 0.11705900E+04, -.13137400E+04, -.38198700E+03, -.16799900E+04, 0.12635000E+04, 0.75278200E+01, 0.31496100E+01, -.16732900E+01, -.21554200E+01, -.19353200E+00, 0.46334800E+01, 0.15375500E+01, -.19414400E+01, 0.44988800E+01, 0.35729800E+01, -.11963000E+01, -.14122800E+01, -.89573300E-02, 0.29475500E+01, 0.52174700E+00, -.13093900E+01, 0.19570000E+04, -.36742900E+04, -.55325100E+02, -.26568300E+03, -.31151900E+02, 0.18377600E+04, 0.14296500E+04, -.10832500E+03, -.21684400E+04, -.19517000E+04, -.43158900E+03, -.47280600E+03, 0.10418900E+04, -.18446800E+03, 0.44215800E+03, -.59077500E+03, 0.60258700E+02, 0.30230500E+02, -.57487900E+01, -.76557000E+01, -.93578100E+01, 0.19939700E+02, -.23714300E+01, -.73005700E+01, -.53206700E+04, 0.90416100E+04, 0.73280600E+03, 0.13293300E+04, 0.30325200E+03, -.34602000E+04, -.20604000E+04, 0.94744200E+03, -.58805600E+01, 0.60277100E+00, 0.55672200E+00, 0.98036200E+00, 0.78666800E+00, -.24267800E+01, -.12292700E+01, 0.81451600E+00, 0.64097000E+02, 0.13908900E+02, -.50795900E+01, -.77813800E+01, -.10458600E+02, 0.22055900E+02, 0.17347700E+01, -.67707400E+01, 0.21528200E+02, 0.35544400E+01, -.16381700E+04, -.17736000E+04, 0.36591900E+01, 0.18838900E+02, -.10952500E+03, -.37691600E+01, 0.65548100E+02, 0.34078200E+01, 0.56935400E+03, -.91752800E+02, 0.18440000E+03, -.22392200E+03, 0.92239900E+03, 0.49982200E+03, -.82789100E+02, -.10295700E+01, 0.26494300E+01, 0.29628200E+01, 0.39943100E+03, 0.20795200E+04, 0.21962100E+01, 0.27408300E+03, -.35778300E+01, 0.27448600E+01 }, { -.22223500E+00, -.39019700E+00, 0.96049500E+00, 0.10451900E+01, 0.53010800E+00, -.64015000E+00, 0.20857800E+01, -.52000100E+00, -.61311400E+00, 0.48483100E+00, 0.23046900E+00, 0.40656000E+00, -.98863800E+03, -.15032700E+04, -.33144600E+04, -.91975000E+02, 0.16293100E+04, -.34255300E+04, 0.37124200E+03, -.13526800E+02, -.13696700E+04, -.11986600E+04, -.10702100E+04, -.76788200E+02, 0.10490300E+02, -.27946900E+01, -.43545100E+00, 0.11910300E+01, -.29102700E+01, -.58170000E+00, -.48961700E+01, 0.12177200E+01, 0.96323400E+03, -.73198500E+03, -.48394000E+03, -.53645500E+03, 0.36656300E+03, 0.46163400E+03, 0.74898900E+03, -.54704800E+03, 0.26447600E+03, 0.71554100E+03, -.38653800E+02, 0.73571000E+02, -.83272100E+02, -.23635200E+02, -.48974400E+03, 0.67846200E+02, -.22657900E+02, 0.42153300E+01, 0.56455900E+00, -.34134100E+01, 0.65280800E+01, 0.14097800E+01, 0.10343300E+02, -.35397000E+01, 0.48292900E+01, -.43618100E+03, 0.17778000E+01, -.57050500E+02, -.22900700E+02, -.18480600E+02, 0.94719300E+02, -.62204500E+02, 0.11886600E+02, 0.10724600E+01, -.28113600E+01, -.40379300E+01, -.65290300E+00, 0.19636900E+01, -.16412900E+01, -.39197700E+01, -.68242500E+04, 0.18137300E+03, 0.21298200E+04, 0.29518000E+04, -.17575700E+04, -.43858300E+04, -.43706100E+04, 0.26801700E+04, 0.35068700E+04, -.42135300E+04, 0.53030000E+03, 0.67771700E+03, -.18923100E+04, -.18748300E+03, -.25406000E+04, 0.60395300E+03, -.15032600E+04, -.49939000E+03, -.12809600E+04, -.14360500E+04, 0.24439500E+04, 0.26118300E+04, 0.14714000E+04, -.16528900E+04, -.19423100E+04, -.30930800E+04, 0.58503400E+03, 0.74655500E+03, -.10313400E+04, -.32071800E+04, -.20668700E+04, 0.62780500E+03, -.30310500E+04, 0.60187300E+02, 0.80256000E+03, 0.10519400E+04, -.65300300E+03, -.13488400E+04, -.29454500E+04, 0.10117100E+04, 0.11404800E+04, -.18045700E+04, 0.16147800E+02, -.24166600E+03, -.10132800E+04, 0.25538100E+03, -.10233900E+04, -.34248600E+03, -.10215500E+04, -.41603400E+04, 0.29831300E+03, 0.25195900E+03, -.10516100E+04, -.16871000E+04, -.26763500E+04, 0.65912400E+02, 0.41685600E+03, -.14756500E+04, -.37955900E+04, -.55489200E+04, 0.49276200E+04, 0.32647900E+04, 0.64242200E+04, -.54707400E+04, 0.11089200E+02, 0.42670100E+01, -.49189300E+01, -.92826900E+01, 0.14725000E+01, 0.33302000E+01, 0.12829500E+01, -.90810800E+01, 0.81177100E+01, 0.44953700E+01, -.40951400E+01, -.78828600E+01, 0.17709100E+01, 0.32018700E+01, 0.20463400E+01, -.77080300E+01, -.98732800E+04, 0.30768500E+04, 0.74794400E+03, 0.10490800E+04, 0.10445000E+04, -.28333300E+04, -.82056900E+03, 0.93867800E+03, 0.50230500E+03, -.22820100E+04, 0.28566400E+03, 0.12332500E+03, -.66147100E+03, -.35740600E+03, -.20230100E+03, 0.11960000E+03, 0.62042800E+02, 0.10168300E+02, -.67511400E+00, 0.10388200E+02, -.11603600E+02, 0.54194300E+01, -.10331600E+02, 0.11604200E+02, -.18538400E+04, 0.58255000E+04, 0.69120100E+03, 0.15737400E+04, 0.91966700E+03, 0.10117900E+04, 0.13477600E+04, 0.16405900E+04, -.46986000E+01, 0.14121800E+01, 0.12684700E+00, -.62609800E+00, 0.13124900E+01, 0.84427300E-01, 0.20818000E+01, -.63296600E+00, 0.47204700E+02, 0.31566300E+01, 0.12581800E+01, 0.12778200E+02, -.12041500E+02, 0.86398300E+00, -.14349600E+02, 0.13478000E+02, 0.41863500E+02, 0.12888800E+02, 0.12315400E+04, 0.11830900E+03, 0.12816400E+02, -.62561700E+01, -.13869400E+03, -.12474000E+02, 0.22820400E+02, 0.12785600E+02, -.22681100E+04, -.40907000E+03, -.52295300E+03, 0.53832300E+03, -.55158400E+03, -.23695500E+03, 0.13030000E+02, -.17696500E+03, 0.10214000E+02, 0.10625400E+02, -.50905600E+03, -.68032300E+01, 0.11149300E+02, -.55128200E+03, -.12871800E+02, 0.11234100E+02 }, { -.10340400E+00, 0.16936100E+00, -.21577000E+00, -.20758700E+00, 0.10607300E+00, 0.18731300E+00, -.48773400E+00, 0.35539300E-01, 0.21932800E-01, -.24939300E+00, 0.53461000E-01, 0.21649300E+00, -.14716900E+00, -.61661100E+03, -.95541400E+03, -.23040700E+03, -.70182800E+04, -.43271800E+04, 0.22622300E+04, 0.26849300E+04, -.93556100E+03, -.42389900E+04, -.28923400E+04, 0.24780500E+04, 0.15800700E+02, -.12837400E+01, -.49972000E+01, -.58338400E+01, 0.22215500E+01, 0.75247000E+01, 0.35012200E+01, -.62647300E+01, 0.16290700E+03, 0.63332800E+02, -.43280100E+03, -.48985700E+03, 0.46272600E+03, 0.37220500E+03, 0.52805400E+03, -.51295700E+03, 0.26843600E+04, 0.92789700E+03, -.44073600E+03, -.48420300E+03, -.18628000E+03, 0.10700900E+04, 0.92038200E+02, -.46457400E+03, -.35000400E+02, -.11972900E+01, 0.11219000E+02, 0.13007000E+02, -.50342900E+01, -.17129600E+02, -.82497900E+01, 0.13843000E+02, -.10504100E+04, -.66971900E+03, 0.17246000E+03, 0.18431000E+03, 0.70768200E+02, -.45523900E+03, -.74446700E+02, 0.16098000E+03, 0.25936100E+02, 0.35144100E+01, -.42732600E+01, -.55727000E+01, -.14421000E+01, 0.85371100E+01, -.88067900E+00, -.58294800E+01, -.49700100E+04, -.39208300E+04, 0.18953900E+04, 0.26954700E+04, -.12208900E+04, -.27757500E+04, -.19176500E+04, 0.24893800E+04, 0.12960800E+04, -.66651100E+04, 0.93941000E+03, 0.11600200E+04, -.13669500E+04, -.10217400E+04, -.18432600E+04, 0.10172400E+04, -.46455200E+03, -.19719900E+04, -.21822200E+04, -.29597200E+04, 0.28936400E+04, 0.14819400E+04, 0.27742900E+04, -.32423400E+04, -.35490200E+04, -.63288500E+04, 0.82207600E+03, 0.11614200E+04, -.17317300E+03, -.19892300E+04, -.63592200E+03, 0.91804200E+03, -.45263000E+04, -.13490000E+04, 0.12468200E+04, 0.15708800E+04, -.30812200E+03, -.29947200E+04, -.17236100E+04, 0.14426700E+04, 0.25323800E+04, -.42176400E+04, 0.69775400E+03, 0.84525600E+03, -.15813500E+04, -.63971500E+03, -.16809700E+04, 0.68489200E+03, -.18723900E+04, -.92695900E+04, 0.49814300E+03, 0.58995400E+03, -.20150200E+03, -.12434700E+04, -.46637300E+03, 0.33646800E+03, -.17384400E+04, -.34674200E+04, -.26059100E+04, -.37344600E+04, 0.37090800E+04, 0.93465900E+03, 0.39269300E+04, -.38298400E+04, 0.32879300E+02, 0.52394100E+01, -.24363300E+01, -.39658500E+01, -.56894400E+01, 0.77739400E+01, -.60646200E+01, -.40266200E+01, 0.25839300E+02, 0.60241000E+01, -.16020300E+01, -.28129200E+01, -.48859000E+01, 0.58883400E+01, -.52919200E+01, -.27849200E+01, -.60302800E+04, -.12637800E+04, 0.14920000E+03, 0.26153900E+03, 0.11307700E+04, -.23656400E+04, 0.56335600E+03, 0.19198600E+02, -.45151100E+04, -.30039400E+04, 0.13553400E+04, 0.16320400E+04, -.48200700E+03, -.26789900E+04, -.15362100E+04, 0.15354300E+04, 0.84152900E+02, 0.58400300E+02, -.27229700E+02, -.31407000E+02, 0.12589000E+02, 0.45544400E+02, 0.21934300E+02, -.31592000E+02, -.14401500E+03, 0.12038600E+05, -.76163100E+03, -.70631800E+03, 0.10251700E+04, 0.18758100E+04, 0.14550800E+04, -.40147300E+03, -.62228700E+01, 0.69302300E+00, 0.20564700E+01, 0.23893300E+01, -.10065700E+01, -.30617200E+01, -.15249900E+01, 0.25670400E+01, 0.63493400E+02, 0.35541100E+02, -.24339400E+02, -.27662800E+02, 0.14201000E+02, 0.37796800E+02, 0.22770600E+02, -.28377400E+02, 0.13212500E+03, 0.54863100E+01, 0.42096200E+03, 0.12452100E+04, 0.57034300E+01, 0.67310200E+01, -.11236100E+03, -.59859500E+01, 0.68273800E+02, 0.51816100E+01, -.11945300E+04, 0.33121800E+03, -.32712900E+03, 0.35714700E+03, -.29520600E+03, 0.79617900E+03, -.50263300E+02, 0.45672100E+03, 0.48040500E+01, 0.48734800E+01, -.33194800E+03, -.13676200E+04, 0.37595400E+01, 0.29791900E+02, -.55373100E+01, 0.51232000E+01 }, { -.84009500E-01, 0.15945400E+00, -.73965100E+00, -.76715300E+00, -.37826400E+00, 0.24195100E+01, -.77112000E+00, 0.31423100E+00, -.25323400E+00, 0.61857100E-03, -.89450300E-02, -.53118800E+00, -.37343300E+00, 0.22455500E-01, 0.11564200E+04, -.27885400E+02, -.35674100E+04, -.31179300E+04, 0.11472800E+04, 0.14606300E+04, -.86013600E+03, -.25115900E+04, -.25531300E+04, 0.12386100E+04, 0.10745800E+02, -.15300000E+01, -.33763600E+01, -.36339500E+01, 0.16926100E+01, 0.46573300E+01, 0.36863000E+01, -.37031900E+01, 0.81762200E+02, 0.65953800E+02, -.33579200E+03, -.41152200E+03, 0.41707500E+03, 0.25090200E+03, 0.51752900E+03, -.40154500E+03, 0.14392500E+04, 0.48573500E+03, -.27967000E+03, -.31202800E+03, 0.45029800E+02, 0.56467200E+03, 0.23258100E+03, -.27828300E+03, -.24058300E+02, 0.14544900E+01, 0.75756900E+01, 0.81378900E+01, -.36980000E+01, -.10790300E+02, -.82229800E+01, 0.82538700E+01, -.62892300E+03, -.30448700E+03, 0.12974000E+03, 0.14607700E+03, -.34730000E+02, -.26868300E+03, -.90382500E+02, 0.12477200E+03, 0.14495700E+02, 0.17531700E+01, -.22744800E+01, -.30184300E+01, -.82941000E+00, 0.45972900E+01, 0.43320500E+00, -.29457500E+01, -.25381700E+04, -.34454100E+04, 0.32813500E+03, 0.79323000E+03, 0.16360600E+03, -.15421300E+04, -.87167500E+03, 0.58986700E+03, 0.12201400E+04, -.38711900E+04, 0.50208800E+03, 0.69597100E+03, -.95783200E+03, -.57671600E+03, -.11240500E+04, 0.61540500E+03, -.59270400E+03, 0.30249900E+01, -.97260700E+03, -.12201300E+04, 0.14508300E+04, 0.46021700E+03, 0.11320500E+04, -.12735100E+04, -.29031100E+04, -.35272600E+04, 0.44622800E+03, 0.72141800E+03, 0.11396500E+03, -.15349200E+04, 0.28041200E+03, 0.56978300E+03, -.15298600E+04, -.86683300E+03, 0.37424500E+03, 0.48174800E+03, 0.10464100E+03, -.69137500E+03, 0.74573900E+03, 0.47760800E+03, 0.59551700E+02, -.24286300E+04, 0.53148100E+03, 0.66320200E+03, -.79564700E+03, -.70076300E+03, -.91529300E+03, 0.54219500E+03, -.17655600E+04, -.42296400E+04, 0.49614700E+03, 0.68739400E+03, -.36581200E+03, -.12364200E+04, -.15579700E+03, 0.52019600E+03, -.92834500E+03, -.91925200E+03, -.14333300E+04, -.20807100E+04, 0.21709700E+04, 0.51777100E+03, 0.19711000E+04, -.20154000E+04, 0.16392400E+02, 0.33227600E+01, -.62257700E+00, -.17642100E+01, -.36620900E+01, 0.35330700E+01, -.33439500E+01, -.15960700E+01, 0.12536500E+02, 0.37715900E+01, -.17175800E+00, -.11134500E+01, -.32143200E+01, 0.25643800E+01, -.32040600E+01, -.94278800E+00, -.38128900E+04, -.12160800E+04, -.27136000E+03, -.14213200E+03, 0.10257800E+04, -.99699200E+03, 0.67489300E+03, -.32751100E+03, -.28372500E+04, -.17156200E+04, 0.78547300E+03, 0.10178800E+04, -.43498500E+03, -.16722600E+04, -.13558000E+04, 0.89441500E+03, 0.58869400E+02, 0.25731500E+02, -.16808600E+02, -.18141200E+02, 0.65236900E+01, 0.28821800E+02, 0.15621500E+02, -.17502300E+02, -.12943600E+04, 0.72040100E+04, 0.27380300E+02, 0.93521700E+02, 0.56631500E+03, 0.72474200E+03, 0.11891500E+04, 0.28907500E+03, -.42799200E+01, 0.66919900E+00, 0.13616100E+01, 0.14466200E+01, -.69933200E+00, -.18909900E+01, -.15532900E+01, 0.14769000E+01, 0.46845800E+02, 0.13840900E+02, -.15899900E+02, -.16791700E+02, 0.85546700E+01, 0.24578300E+02, 0.17617800E+02, -.16573200E+02, 0.64026200E+02, 0.22076200E+01, -.51497500E+03, 0.81601000E+03, 0.23871300E+01, -.12581100E+02, -.75459500E+01, -.26713400E+01, 0.21694200E+02, 0.20527100E+01, -.70780000E+03, 0.19593700E+03, -.10083100E+03, -.16308000E+02, 0.31964700E+03, 0.34966800E+03, 0.22489000E+02, 0.78717000E+02, 0.19070200E+01, 0.19911800E+01, -.13591800E+03, -.11465600E+04, 0.12107100E+01, -.53145200E+02, -.22464700E+01, 0.21625300E+01 }, { 0.10547200E+00, 0.37953500E-01, -.28069200E+00, 0.22307800E-01, -.24435900E+00, -.36343200E+00, -.16149900E+00, 0.73274500E+00, -.13915000E+00, 0.28619000E+00, 0.19748600E-01, 0.25026700E+00, 0.20671100E+00, -.59611600E+00, -.14367700E+00, -.32960600E+03, -.78428600E+03, 0.48905000E+03, 0.15277100E+04, 0.18897700E+04, -.12501800E+04, -.19461300E+04, -.40248300E+04, 0.19342300E+04, -.55418700E+00, -.31293400E+00, -.21872100E+01, -.31174100E+01, 0.33216600E+01, 0.25493400E+01, 0.66734200E+01, -.37314600E+01, -.71192000E+03, 0.43139000E+03, 0.57874400E+02, 0.60504000E+02, 0.12269300E+03, -.13906500E+03, 0.13714400E+02, 0.71304900E+02, 0.25228700E+03, 0.16947300E+03, -.23907200E+03, -.28297900E+03, 0.17364200E+03, 0.39745300E+03, 0.72248100E+03, -.35470700E+03, -.34647500E+00, 0.78423100E+00, 0.61144700E+01, 0.83351300E+01, -.83463400E+01, -.66677600E+01, -.15292700E+02, 0.96193700E+01, -.26048100E+03, -.36037600E+02, 0.15788400E+03, 0.18289200E+03, -.82328900E+02, -.24004200E+03, -.27537400E+03, 0.20007000E+03, 0.52683200E+01, 0.11408100E+00, -.16157800E+00, -.32565700E+00, -.37414900E+00, 0.14236800E+01, 0.28929000E+00, -.70844500E+00, 0.33490200E+03, -.22356900E+03, 0.50719400E+03, 0.72338400E+03, -.62259100E+03, 0.43014600E+03, 0.15307500E+04, 0.57914400E+03, 0.70739800E+03, -.10925700E+04, 0.11051300E+04, 0.11974600E+04, -.12736600E+04, -.77874000E+03, -.14998900E+04, 0.10903300E+04, 0.54793000E+03, -.12540200E+04, -.13594500E+03, -.45066000E+03, -.42971700E+03, 0.29095900E+03, -.86474900E+03, -.43750500E+03, -.18441900E+04, -.49302400E+03, 0.10323600E+04, 0.11727500E+04, -.53831800E+03, -.72954700E+03, 0.96555200E+03, 0.97326100E+03, -.48574900E+03, -.43295600E+03, 0.85206600E+03, 0.98780300E+03, -.11245300E+04, -.11214200E+04, -.10686900E+04, 0.80646200E+03, -.26443700E+04, 0.21532500E+04, 0.11653700E+04, 0.14377900E+04, -.57175400E+02, -.20829600E+04, -.43443700E+03, 0.11796800E+04, -.11745700E+03, -.25160100E+04, 0.89293500E+03, 0.92513600E+03, -.81157700E+03, -.27397000E+03, 0.76056000E+02, 0.72437600E+03, -.17036400E+04, -.28428000E+03, 0.43934900E+03, 0.26585200E+03, -.43450600E+03, -.13780000E+04, -.17879300E+04, 0.23379000E+03, 0.11666800E+02, -.35084800E+00, 0.23291700E+01, 0.30802500E+01, -.46163500E+01, 0.75670300E-01, -.65851900E+01, 0.29377500E+01, 0.98908600E+01, -.14967800E-01, 0.19978800E+01, 0.27083500E+01, -.41179400E+01, -.11820600E+00, -.63505700E+01, 0.26970400E+01, 0.22376900E+04, -.13239100E+04, -.96298500E+03, -.11385300E+04, 0.36995500E+03, 0.46328900E+03, 0.11559100E+04, -.13292600E+04, -.19303300E+04, 0.45186200E+03, 0.11115300E+04, 0.13715800E+04, -.56198200E+03, -.17796400E+04, -.19640000E+04, 0.14013700E+04, 0.29023900E+02, -.43201000E+01, -.24112400E+02, -.30334900E+02, 0.20399800E+02, 0.26986600E+02, 0.25814100E+02, -.30969400E+02, -.52717000E+03, 0.20048800E+04, -.13405200E+04, -.14681100E+04, 0.11080500E+04, 0.16901600E+04, 0.21927500E+04, -.11191700E+04, 0.46445100E+00, 0.74949500E-01, 0.90298000E+00, 0.13009400E+01, -.14331100E+01, -.10114500E+01, -.27734400E+01, 0.15421600E+01, 0.11207500E+02, -.20535200E+01, -.20797800E+02, -.26622600E+02, 0.21863000E+02, 0.21331800E+02, 0.31422600E+02, -.28017700E+02, 0.51088900E+02, -.53848300E+01, -.77485100E+02, 0.20365400E+04, -.51302300E+01, 0.20902100E+01, 0.88236900E+02, 0.44832900E+01, -.10185900E+02, -.54100900E+01, 0.68472800E+03, 0.75374900E+03, -.21136800E+03, 0.11110700E+03, -.82908100E+00, 0.10716200E+03, 0.28700700E+03, 0.76748000E+03, -.39236600E+01, -.42358900E+01, 0.14982300E+03, -.27441700E+04, -.47920600E+01, 0.22495300E+03, 0.53284700E+01, -.37439100E+01 }, { 0.20653300E+00, 0.31261000E-01, 0.26807800E+00, 0.30615000E+00, 0.28876900E+00, -.61327500E+00, -.10662700E+01, -.95633000E+00, -.45684000E-01, -.39020600E-01, -.54043200E-02, -.33480900E+00, -.14103500E-01, -.13264500E+01, 0.55727100E+00, 0.36116700E+00, -.12600600E+05, -.60221400E+04, 0.62567000E+03, 0.85139200E+03, 0.28601000E+04, -.35219400E+04, 0.24675900E+04, 0.59954100E+03, 0.27537500E+02, -.16713900E+01, -.55151000E+01, -.75466600E+01, -.14756300E+01, 0.11598100E+02, 0.33276900E+00, -.74068000E+01, 0.68255600E+03, -.11773000E+03, -.38455400E+03, -.45569600E+03, 0.22693600E+03, 0.37818600E+03, 0.33407600E+03, -.52197400E+03, 0.46673400E+04, 0.75592500E+03, -.22487400E+03, -.29647800E+03, -.10431600E+04, 0.14591800E+04, -.64401800E+03, -.15595700E+03, -.61024800E+02, -.16568000E+01, 0.11345400E+02, 0.15691600E+02, 0.42166000E+01, -.25111600E+02, 0.45694600E+00, 0.15269000E+02, -.15484300E+04, -.86395500E+03, -.30317300E+02, -.31803000E+02, 0.46829900E+03, -.40820700E+03, 0.34413600E+03, -.91604400E+02, 0.31496200E+02, 0.52640900E+01, -.59588300E+01, -.73479500E+01, -.17454300E+01, 0.12792700E+02, 0.37081000E+00, -.73588200E+01, -.18552700E+04, -.71241600E+04, 0.84290900E+03, 0.11538800E+04, -.66316600E+03, -.98909900E+03, -.11204100E+04, 0.12631500E+04, -.20156200E+04, -.74206500E+04, -.72970300E+03, -.96667400E+03, 0.13817600E+04, 0.31150200E+03, 0.21007900E+04, -.98489400E+03, 0.17085700E+03, -.23242100E+04, -.22132700E+04, -.31008900E+04, 0.28341900E+04, 0.12423300E+04, 0.39611400E+04, -.35325400E+04, 0.36040700E+03, -.91704100E+04, -.49933900E+03, -.55762800E+03, 0.28570600E+03, 0.85477900E+03, 0.39840400E+03, -.52406200E+03, -.10492300E+05, 0.45930600E+03, 0.11985100E+04, 0.15898800E+04, 0.13899200E+04, -.38355600E+04, 0.33591500E+03, 0.14793000E+04, 0.69721000E+04, -.94753400E+04, -.87821900E+03, -.10477300E+04, -.10652000E+04, 0.28483000E+04, 0.39904600E+03, -.85266400E+03, 0.11827500E+04, -.12043800E+05, -.11590000E+04, -.14482500E+04, 0.96678000E+03, 0.14124900E+04, 0.20330200E+04, -.13966900E+04, 0.62399400E+03, -.64922100E+04, -.13917200E+04, -.18389500E+04, 0.17111500E+04, 0.17830500E+04, 0.38438000E+04, -.19892200E+04, 0.30933000E+02, 0.81508700E+01, -.55270200E+01, -.59015300E+01, -.18584400E+01, 0.12330200E+02, 0.42950900E+00, -.59941000E+01, 0.22763600E+02, 0.89852700E+01, -.38809300E+01, -.39580000E+01, -.14810600E+01, 0.88539900E+01, 0.14331300E+00, -.40647500E+01, -.27182200E+04, -.39004900E+04, 0.93577400E+03, 0.11151200E+04, -.24257900E+03, -.10174800E+04, -.62228200E+03, 0.11770200E+04, -.62463300E+04, -.39456800E+04, 0.25021100E+03, 0.34907900E+03, 0.14223700E+04, -.17486800E+04, 0.11167800E+04, 0.22094500E+03, 0.98757400E+02, 0.94962600E+02, -.16799400E+02, -.25152300E+02, -.70676700E+01, 0.38350700E+02, -.57397300E+01, -.25041500E+02, -.19074700E+04, 0.17293500E+05, 0.11064600E+04, 0.13557500E+04, -.75163400E+03, -.25106500E+04, -.33679900E+04, 0.11768400E+04, -.10838300E+02, 0.89960600E+00, 0.23278200E+01, 0.32044500E+01, 0.39964500E+00, -.46455600E+01, -.30484700E+00, 0.31651600E+01, 0.99110900E+02, 0.54236900E+02, -.16348600E+02, -.24466900E+02, -.85254900E+01, 0.38547200E+02, -.52904100E+01, -.23833800E+02, 0.11493400E+03, 0.10493900E+02, 0.14564700E+03, -.20801800E+04, 0.10644000E+02, 0.13400800E+02, -.33237100E+03, -.10598100E+02, 0.15767900E+03, 0.10060000E+02, -.10313300E+04, -.39854700E+03, 0.16925600E+02, 0.11540200E+03, -.76150500E+02, 0.11092100E+04, -.35614900E+03, -.19720000E+03, 0.83240800E+01, 0.89050400E+01, -.33198800E+03, 0.31496400E+04, 0.74638700E+01, 0.19047700E+03, -.10537100E+02, 0.84803100E+01 }, { 0.43119100E-01, 0.94436600E-01, -.20802400E+00, -.27939200E+00, 0.15542000E+00, 0.18949200E+01, -.17867100E+01, -.29183800E+00, -.25431100E+00, 0.27966200E-01, 0.75046900E-01, 0.26207200E+00, -.84284900E-01, 0.18452900E-03, -.10098200E+00, 0.24895900E+00, -.60915900E-01, -.40116900E+04, 0.30551300E+02, 0.39402100E+02, -.17815500E+03, -.35521300E+03, -.61998900E+03, -.36277000E+02, 0.65830100E+01, 0.10977500E+00, -.73865700E+00, -.56723900E+00, -.11017800E+01, 0.28802800E+01, -.62018600E+00, -.56532400E+00, -.97144000E+02, 0.22253600E+01, -.24363700E+03, -.25775600E+03, 0.29195400E+03, 0.16373000E+03, 0.23858400E+03, -.29040800E+03, 0.10474600E+04, 0.61847800E+03, -.62199500E+01, -.65639800E+00, -.29889400E+03, 0.38530800E+03, -.12508400E+03, 0.35858500E+02, -.14075100E+02, -.26081400E+01, 0.15746800E+01, 0.11252600E+01, 0.21284000E+01, -.64429600E+01, 0.85138100E+00, 0.10964300E+01, -.26140300E+03, -.47034800E+03, -.13413700E+02, -.20326200E+02, 0.80788600E+02, -.11663100E+03, -.19489900E+01, -.33557500E+02, 0.13559200E+02, 0.20016800E+01, -.23275300E+01, -.30680400E+01, -.10905100E+01, 0.47733000E+01, -.72033400E+00, -.30543100E+01, -.26611900E+04, -.20472900E+04, 0.16786500E+04, 0.21514400E+04, -.17257400E+04, -.13662800E+04, -.10437600E+04, 0.22772000E+04, 0.16258800E+04, -.41501600E+04, 0.28853000E+03, 0.41844200E+03, -.96124100E+03, -.19475100E+03, -.10897000E+04, 0.40517400E+03, -.41333700E+03, -.86539100E+03, -.11973600E+04, -.15663000E+04, 0.16049100E+04, 0.17989900E+03, 0.11998400E+04, -.17660400E+04, -.15498200E+04, -.36283800E+04, 0.61390000E+03, 0.86737500E+03, -.70851600E+03, -.74432200E+03, -.10190100E+04, 0.87504700E+03, -.15380200E+04, -.11954000E+04, 0.35564300E+03, 0.43467800E+03, -.56131600E+02, -.11059700E+04, -.22304700E+03, 0.39818600E+03, 0.33116500E+04, -.32927700E+04, 0.14056000E+03, 0.15826900E+03, -.14831400E+04, 0.21709900E+03, -.11896600E+04, 0.16213500E+03, -.36642800E+03, -.51941800E+04, 0.29436500E+03, 0.39127000E+03, -.61229000E+03, -.53774800E+03, -.10193900E+04, 0.41714700E+03, -.18993300E+04, -.13777300E+04, -.16358700E+04, -.22370200E+04, 0.23430800E+04, -.71705700E+02, 0.16197800E+04, -.24627700E+04, 0.18704200E+02, 0.23214500E+01, -.34528500E+01, -.50305700E+01, -.12908100E+01, 0.58074200E+01, -.11280200E+01, -.49665200E+01, 0.14966800E+02, 0.27276100E+01, -.28955800E+01, -.42575100E+01, -.77772400E+00, 0.46432900E+01, -.66355300E+00, -.42125700E+01, -.35543200E+04, -.43499300E+03, 0.58840100E+03, 0.70740500E+03, 0.45557700E+02, -.16593900E+04, 0.24433200E+03, 0.68746400E+03, 0.38414600E+03, -.27888900E+04, -.25528700E+02, -.63424500E+01, -.22041400E+03, -.27685500E+03, -.65771700E+03, -.45936200E+02, 0.25030700E+02, 0.39840500E+02, -.57651600E+01, -.50773500E+01, 0.39169400E+01, 0.16137600E+02, 0.70745800E+01, -.52890800E+01, -.14196200E+04, 0.73668900E+04, -.85729100E+02, -.49002300E+02, 0.10844900E+04, 0.45945500E+03, 0.10923700E+04, -.51824800E+01, -.26856700E+01, 0.99327900E-01, 0.30885500E+00, 0.22141100E+00, 0.42044100E+00, -.11818400E+01, 0.24502800E+00, 0.22198700E+00, 0.18812700E+02, 0.25489000E+02, -.32964500E+01, -.19252800E+01, 0.10899900E+01, 0.12578100E+02, 0.42358300E+01, -.19984300E+01, 0.76323400E+02, 0.71489000E+01, 0.43634700E+02, -.16019400E+03, 0.71126500E+01, 0.17628200E+02, -.13073200E+03, -.69381200E+01, 0.40284400E+02, 0.69777300E+01, -.69402800E+03, -.15256400E+01, -.19516300E+03, 0.49166300E+03, -.31871300E+02, 0.45882400E+03, 0.77385400E+02, 0.57242600E+03, 0.60229000E+01, 0.60701900E+01, -.22401700E+03, 0.10514000E+03, 0.60272900E+01, -.79051600E+01, -.71421900E+01, 0.62930200E+01 }, { 0.25960100E+00, -.98117200E-01, 0.49305000E+00, 0.64480800E+00, 0.43755300E+00, -.16315500E+01, 0.18889900E+01, -.44105300E+00, 0.22278400E+00, 0.52812600E+00, -.17929300E+00, 0.22509500E+00, 0.21720800E+00, 0.23745000E+00, -.92819700E+00, -.13282800E+01, -.10937300E+01, 0.33945700E+00, -.84738300E+03, -.10889400E+04, 0.16350800E+04, 0.51438500E+03, 0.25557800E+04, -.99976100E+03, 0.12690900E+01, 0.10989100E+01, 0.66972300E+00, -.15742100E+00, -.19538400E+01, -.90329600E+00, -.66578500E+00, -.37541300E-01, -.34283500E+03, 0.39055200E+02, 0.25042800E+03, 0.26156200E+03, -.27999500E+03, -.42858400E+03, -.37505800E+03, 0.23859100E+03, 0.12488000E+03, -.13577600E+03, 0.21411900E+03, 0.23321900E+03, -.42282600E+03, -.59437200E+02, -.24876100E+03, 0.23779900E+03, -.41821600E+01, -.17373700E+01, -.12239300E+01, 0.63636200E+00, 0.43795500E+01, 0.20025700E+01, 0.17905100E+01, 0.28877400E+00, -.20855800E+02, 0.32426700E+02, -.10464700E+03, -.12743100E+03, 0.20353000E+03, 0.70492500E+02, 0.17013200E+03, -.12778400E+03, -.18233600E+01, -.40870600E+00, 0.78435100E+00, 0.11325500E+01, -.79318500E+00, -.98103700E+00, -.36242200E+00, 0.11315400E+01, 0.12244400E+04, 0.11199000E+04, 0.66055400E-01, -.30854100E+03, -.11611600E+03, 0.10243900E+04, 0.20030300E+04, -.22893500E+03, -.18200400E+04, 0.92532000E+03, -.31492500E+03, -.61320300E+03, 0.10083400E+04, 0.46188900E+03, 0.14650600E+04, -.60379100E+03, -.44326300E+03, -.32014000E+03, 0.69902800E+03, 0.76028700E+03, -.10682400E+04, 0.54361300E+03, -.15979200E+04, 0.63405900E+03, 0.28889800E+04, 0.50027000E+03, -.23442000E+03, -.61062600E+03, -.28034600E+03, 0.86003600E+03, 0.11390200E+04, -.48549800E+03, -.34391900E+04, 0.16955200E+04, 0.94895100E+02, 0.18113100E+03, 0.74575000E+03, 0.22807800E+03, 0.56515600E+03, 0.94956300E+02, -.17528300E+04, 0.33971800E+03, 0.76233200E+02, 0.33573400E+02, 0.89826100E+03, 0.90397500E+03, 0.16188800E+04, 0.16261500E+03, 0.20700200E+04, 0.13120600E+03, -.35000600E+03, -.67287000E+03, 0.19554500E+03, 0.11722300E+04, 0.91205300E+03, -.62250000E+03, 0.16280500E+04, -.14244000E+04, 0.14509900E+04, 0.18877400E+04, -.24673800E+04, 0.23105900E+03, -.23032100E+04, 0.19261200E+04, -.41183400E+01, -.19485600E+01, 0.72277000E+00, 0.22865800E+01, 0.63966000E+00, -.64809800E+00, 0.55591200E+00, 0.21993900E+01, -.35914400E+01, -.18978800E+01, 0.52464800E+00, 0.19511100E+01, 0.70777500E+00, -.51267800E+00, 0.30698800E+00, 0.18583700E+01, 0.30395700E+04, -.10982400E+03, -.21750000E+02, -.12601700E+03, -.42263500E+03, 0.23928500E+04, 0.88501100E+03, 0.11528300E+03, -.36810200E+03, 0.63685800E+03, -.49458500E+03, -.64112700E+03, 0.10755500E+04, 0.57933500E+03, 0.15689000E+04, -.59428900E+03, 0.14033700E+02, -.36773300E+01, -.57011000E+00, -.41888400E+01, -.89773600E+01, -.89782900E+01, -.11299300E+02, -.34757200E+01, -.22555900E+03, -.19037900E+03, -.27895400E+03, -.12788700E+03, -.19840700E+03, -.12109700E+04, -.19948500E+04, -.33080300E+03, -.35110000E+00, -.48817400E+00, -.22951400E+00, 0.14900400E+00, 0.70660700E+00, 0.41134500E+00, 0.27461600E+00, 0.10906100E+00, 0.14387300E+02, -.59740000E+00, 0.53293800E+00, -.36182000E+01, -.94168400E+01, -.63296400E+01, -.88152200E+01, -.28404100E+01, -.18482300E+02, -.32131100E+01, 0.54098000E+02, -.11470200E+04, -.32266800E+01, 0.19699300E+02, -.10829400E+03, 0.32292000E+01, 0.41422600E+02, -.31797100E+01, 0.86783900E+03, -.63458600E+01, -.19042300E+03, -.14255000E+03, -.27651900E+02, 0.33813600E+02, -.10195400E+01, 0.62961600E+02, -.25463800E+01, -.26705800E+01, 0.53695300E+03, 0.18577400E+04, -.31122500E+01, 0.26270400E+03, 0.32127300E+01, -.31946800E+01 }, { -.41471200E+00, -.14324000E+00, 0.55371700E+00, -.75419300E-02, 0.31341000E+00, 0.12601100E+01, 0.76711200E+00, -.51128700E+00, 0.29617400E+00, -.40775100E+00, -.60542200E-01, 0.16003100E+00, -.51474600E+00, 0.30482700E+01, -.58668400E+00, -.19604600E+01, -.60795900E+00, -.17234800E+01, -.91942300E+00, -.42398400E+03, 0.11465900E+04, -.24435200E+02, 0.13998400E+04, -.45127900E+03, -.83426500E+00, 0.20290900E+01, 0.63585400E+00, 0.26147600E+00, -.19528700E+01, -.10945900E+01, -.11220400E+01, 0.45422100E+00, 0.73837500E+02, 0.41949500E+02, 0.57517800E+02, 0.80306400E+01, -.11868500E+03, -.63099000E+02, -.14745100E+03, 0.19114300E+01, 0.61788300E+02, 0.11531900E+03, 0.17926200E+03, 0.26121600E+03, -.46812000E+03, -.27142600E+02, -.26429700E+03, 0.27148000E+03, 0.76088600E+00, -.43790000E+01, -.85344600E+00, -.15591600E+00, 0.40165900E+01, 0.22684200E+01, 0.21611800E+01, -.69838900E+00, 0.84899000E+02, -.14136600E+03, -.96404800E+02, -.15745200E+03, 0.19893900E+03, 0.72478000E+02, 0.13584900E+03, -.16389600E+03, 0.14057000E+01, -.25629900E-01, 0.57707500E+00, 0.67544800E+00, -.11181700E+01, -.17913600E+00, -.10610300E+01, 0.77432700E+00, 0.54521700E+02, 0.47572500E+03, 0.95012000E+03, 0.10067900E+04, -.16789000E+04, 0.43784100E+03, 0.11965900E+04, 0.10810400E+04, -.11990400E+04, 0.12589600E+03, 0.37740000E+03, 0.59653800E-01, 0.22767200E+03, -.84463400E+02, 0.31134500E+03, -.64398700E+02, -.65087100E+03, -.77475100E+03, 0.23906300E+03, 0.59681600E+02, -.25146500E+03, 0.44660900E+03, -.12342400E+04, -.77234000E+02, 0.15239400E+04, -.41639900E+03, 0.44677200E+03, 0.20595300E+03, -.99842300E+03, 0.13395700E+03, -.18726700E+02, 0.25168500E+03, -.13820200E+04, 0.45374500E+03, 0.12259000E+03, 0.11583000E+03, 0.16490300E+03, 0.26548200E+03, 0.14152400E+03, 0.34988400E+02, -.19083000E+04, 0.54772700E+03, 0.69968000E+03, 0.56668700E+03, 0.24783300E+03, -.79116800E+02, 0.69998200E+03, 0.53555200E+03, 0.16852000E+04, -.15049900E+04, 0.18673400E+03, -.17438800E+03, -.52884400E+03, 0.57413700E+03, -.48341800E+03, -.22400900E+03, 0.22662600E+03, -.72556400E+03, 0.78561000E+03, 0.66157600E+03, -.72861600E+03, -.36334800E+03, -.16115000E+04, 0.52222600E+03, 0.43306300E+01, -.24535300E+01, 0.69087300E+00, 0.12681700E+01, -.41909300E+00, 0.86558000E+00, -.85814600E+00, 0.12735400E+01, 0.37583800E+01, -.22825800E+01, 0.36598900E+00, 0.92728500E+00, -.35092100E-02, 0.88731100E+00, -.56727300E+00, 0.91585500E+00, 0.98956000E+03, 0.45307400E+01, 0.24541900E+03, 0.33393100E+03, -.71375700E+03, 0.81082100E+03, 0.77303100E+03, 0.48341200E+03, -.20376500E+03, 0.30970500E+03, -.46151300E+02, -.28625600E+03, 0.73303400E+03, 0.73905200E+02, 0.58949300E+03, -.31931500E+03, 0.11675000E+02, 0.65972900E+01, -.53490700E+01, -.52474500E+01, -.40374000E+01, -.33877000E+01, -.43961900E+01, -.32444800E+01, 0.14648500E+04, 0.38399100E+03, -.14284100E+04, -.10106900E+04, 0.41606900E+03, 0.68569200E+03, -.51280900E+03, -.95217700E+03, 0.40093500E+00, -.84420300E+00, -.18214600E+00, 0.12994700E-01, 0.68543400E+00, 0.42164700E+00, 0.43781700E+00, -.62467300E-01, 0.42665600E+01, 0.84475800E+01, -.29481600E+01, -.36059500E+01, -.51456100E+01, -.39368500E+01, -.36412600E+01, -.19685700E+01, 0.19559300E+02, -.17948000E+01, 0.70781600E+02, -.48994900E+03, -.18663600E+01, 0.56148300E+01, -.16294000E+03, 0.19906700E+01, 0.53894300E+02, -.17991900E+01, 0.24360300E+03, 0.21613000E+03, -.36040700E+03, 0.34786500E+03, -.45812500E+02, 0.96205900E+02, 0.93752100E+02, 0.46348000E+03, -.10646700E+01, -.13814600E+01, 0.22301200E+03, 0.87120600E+03, -.21119900E+01, 0.20019800E+03, 0.18067900E+01, -.20503900E+01 }, { -.37304200E+00, -.17959900E+00, 0.18209100E+00, 0.25309900E+00, 0.43805200E+00, 0.98831800E+00, 0.77658600E+00, -.46530300E+00, -.64563200E-01, 0.19674900E+00, -.10689800E-01, 0.16554800E+00, 0.43000600E+00, -.88264700E+00, -.72796700E-01, 0.73909700E+00, 0.50601400E+00, -.77982700E+00, -.40812000E+00, -.36955700E+00, 0.73301700E+03, -.55655300E+03, 0.20881300E+03, -.52174500E+02, -.41533500E+01, 0.20354500E+01, 0.15628400E+01, 0.18781800E+01, -.18348900E+01, -.19503300E+01, -.11561200E+01, 0.19035800E+01, -.33052200E+03, 0.16772200E+03, -.24224700E+02, -.29847100E+02, 0.66524800E+02, -.50827900E+02, -.11407800E+02, -.43186600E+02, -.61298800E+03, 0.35284900E+03, 0.21443500E+03, 0.26005600E+03, -.30498500E+03, -.14911700E+03, -.77642700E+02, 0.24332100E+03, 0.90717300E+01, -.45323900E+01, -.29806200E+01, -.36540800E+01, 0.32658100E+01, 0.40888700E+01, 0.14492100E+01, -.38081800E+01, 0.37768600E+03, -.21547500E+03, -.98534100E+02, -.12634400E+03, 0.96793800E+02, 0.90839900E+02, -.15176900E+02, -.12160300E+03, 0.11750600E+01, -.20667900E+00, 0.59066600E+00, 0.62193700E+00, -.12598100E+01, -.76728000E+00, -.15096300E+01, 0.64641900E+00, -.15280000E+04, 0.85164200E+03, 0.16976000E+04, 0.19362800E+04, -.24228800E+04, -.28972700E+03, 0.46219000E+03, 0.19771000E+04, 0.45806500E+03, -.39940700E+03, 0.55876300E+03, 0.67116300E+03, -.74736700E+03, -.52936300E+03, -.12341800E+04, 0.57913000E+03, -.67573400E+03, -.17902900E+03, -.15046100E+03, -.23967100E+03, 0.12625100E+03, 0.35066900E+03, -.93073400E+03, -.37850500E+03, 0.63264300E+03, -.53397600E+03, 0.48977600E+03, 0.52795900E+03, -.11962800E+04, -.41026600E+03, -.94729300E+03, 0.49045900E+03, 0.16194600E+04, -.85067900E+03, 0.42248300E+02, 0.18458200E+02, -.61803700E+03, 0.59826600E+03, -.34460200E+03, -.20430600E+02, -.11756600E+04, 0.96007800E+03, 0.57770300E+03, 0.69154600E+03, -.19761400E+03, -.87743400E+03, -.52080000E+03, 0.60422600E+03, 0.11643400E+04, -.12348600E+04, 0.18584400E+03, 0.16993500E+03, -.74802500E+03, -.79304100E+02, -.16074600E+04, 0.95837300E+02, -.23310800E+04, 0.10472300E+04, -.40667900E+03, -.62654300E+03, 0.98395700E+03, -.12271100E+04, -.88137400E+03, -.86638300E+03, 0.68930200E+01, -.26518400E+01, -.28643300E+00, -.53278600E+00, -.84549200E+00, 0.30937800E+00, -.20018400E+01, -.50376100E+00, 0.63174500E+01, -.24670300E+01, -.56924200E+00, -.83051900E+00, -.28660700E+00, 0.63508000E+00, -.13091400E+01, -.79944300E+00, -.13438900E+04, 0.78973900E+03, 0.25295100E+03, 0.24466600E+03, -.25387800E+03, -.48116100E+03, 0.11519700E+04, 0.29142900E+03, 0.15854700E+03, -.50618000E+02, -.13475600E+03, -.14228400E+03, 0.47888300E+03, -.29405800E+03, -.20801200E+03, -.19831200E+03, -.52042700E+01, 0.40694200E+01, -.59328900E+00, 0.44448500E+00, 0.88086200E+00, -.20837600E+01, 0.58371600E+01, 0.17961500E+01, 0.19588000E+04, -.41557200E+03, -.10694100E+04, -.11785700E+04, 0.64087300E+03, 0.22041800E+04, 0.11384800E+04, -.10132200E+04, 0.15888700E+01, -.78351800E+00, -.58975500E+00, -.71558500E+00, 0.69659100E+00, 0.72145900E+00, 0.49796800E+00, -.72880800E+00, -.14582900E+02, 0.78471300E+01, 0.19076500E+01, 0.30769100E+01, -.95748000E+00, -.45144300E+01, 0.40106400E+01, 0.40028900E+01, 0.32981800E+02, 0.33338900E-01, 0.62048100E+02, 0.31979200E+01, -.77986200E-01, 0.12616900E+02, -.12930700E+03, 0.24432500E+00, 0.25087700E+02, 0.43059500E-01, -.12206900E+03, 0.22272900E+03, -.32077100E+03, 0.54743400E+03, -.39554900E+02, 0.48719300E+02, 0.21176000E+03, 0.76246700E+03, 0.52517300E+00, 0.14178100E+00, 0.81401300E+02, 0.13352400E+03, 0.66303400E-01, -.25745500E+01, -.10021100E-01, -.15664800E-01 }, { 0.12463000E+01, 0.51719400E+00, -.20536000E+01, -.12862200E+01, -.14075200E+01, -.45351000E+01, -.22356600E+01, 0.25102800E+01, -.14864200E+01, -.12397900E+00, 0.48574000E+00, -.81221800E+00, 0.96493200E+00, -.76526300E+01, 0.27652900E+01, 0.58236700E+01, 0.49403200E+01, 0.60459900E-01, -.83020300E+00, -.90882000E+00, -.23244000E+00, -.22077200E+04, -.13948300E+04, 0.20568600E+03, 0.12459400E+02, -.60179600E+01, -.15139300E+01, -.99221800E+00, -.18858400E+01, 0.29455900E+01, 0.18118900E+01, -.16400400E+01, -.23251100E+04, 0.17511300E+03, 0.87735800E+02, 0.25358500E+03, 0.31977000E+03, -.11237200E+04, -.35984600E+03, 0.92929500E+02, 0.11294700E+04, 0.32599700E+03, -.94148400E+02, -.12758900E+03, -.40203300E+03, 0.66678200E+03, 0.33986300E+03, -.19835400E+03, -.29157600E+02, 0.12129800E+02, 0.37504800E+01, 0.26809500E+01, 0.33002000E+01, -.69319600E+01, -.47199100E+01, 0.39515900E+01, -.27680500E+03, -.31534500E+03, 0.44844600E+01, 0.13452000E+02, 0.15450100E+03, -.21146000E+03, -.95105300E+02, 0.45392000E+02, 0.12758500E+02, 0.11101800E+01, -.44335300E+01, -.54549700E+01, 0.11535600E+01, 0.38586000E+01, 0.55699200E+00, -.61792300E+01, 0.13267500E+03, -.14591900E+04, 0.24475300E+04, 0.24859400E+04, -.30252600E+04, 0.97487000E+03, 0.46210200E+04, 0.30152700E+04, 0.28692300E+04, -.34947200E+04, 0.11721200E+03, 0.45791600E+03, -.16451500E+04, 0.11061300E+03, -.21545900E+04, 0.38996400E+03, -.20819900E+04, -.27883800E+04, -.79405200E+03, -.54094300E+03, 0.27558200E+03, 0.14129700E+04, -.33995500E+04, -.13157600E+04, 0.20345100E+04, -.48543000E+04, 0.33260600E+03, 0.29679000E+03, -.14103000E+04, -.49261200E+03, 0.19063900E+04, 0.51080800E+03, -.72539400E+04, 0.34041000E+03, 0.19646000E+04, 0.24780300E+04, -.69519200E+03, -.11740400E+04, -.64926100E+03, 0.25204800E+04, 0.22032500E+04, 0.76909300E+03, -.38350500E+03, -.40137200E+03, -.21731700E+03, 0.15459200E+04, 0.49039000E+03, -.32375400E+03, 0.29635200E+04, -.78939200E+04, -.46713200E+03, -.45038700E+03, -.89276100E+03, 0.51937400E+03, -.53387900E+03, -.39790200E+03, -.38395200E+04, -.14409100E+04, -.17235500E+04, -.19913500E+04, 0.87713400E+03, -.13172100E+04, -.37530400E+04, -.26043500E+04, 0.11979400E+02, 0.72955600E+01, -.71002600E+01, -.97693900E+01, 0.41021200E+01, 0.40441400E+01, -.14572700E+00, -.10321100E+02, 0.86157000E+01, 0.74917200E+01, -.58274200E+01, -.81344700E+01, 0.38334600E+01, 0.31976900E+01, -.48691800E+00, -.85460300E+01, 0.19450800E+04, -.12933500E+04, -.41530600E+03, -.85287200E+03, 0.21205400E+03, 0.35246900E+04, 0.42887200E+04, -.36823800E+03, -.31123300E+04, -.13992500E+03, 0.42315100E+03, 0.60215800E+03, 0.43142000E+03, -.17422200E+04, -.41036300E+03, 0.72692700E+03, 0.79285100E+02, -.75960200E+01, -.14195200E+02, -.12717000E+02, 0.16700300E+01, 0.16356700E+02, 0.31257600E+01, -.15335800E+02, -.53668100E+04, 0.55785000E+04, 0.11499100E+04, 0.12706300E+04, 0.16549100E+04, -.10732900E+03, 0.20661200E+04, 0.12549500E+04, -.51632400E+01, 0.27181400E+01, 0.58118800E+00, 0.29279400E+00, 0.78778000E+00, -.11966100E+01, -.52839100E+00, 0.56705700E+00, 0.65256200E+02, -.15725200E+02, -.86203500E+01, -.59771400E+01, -.25668500E+01, 0.14658900E+02, 0.65907300E+01, -.82500900E+01, 0.44111400E+02, 0.13872100E+02, 0.74911400E+02, 0.57259000E+02, 0.14106000E+02, 0.12458100E+03, -.61362100E+02, -.14530200E+02, 0.22777400E+02, 0.13758000E+02, 0.14876500E+04, -.28117700E+03, -.11305000E+04, 0.17475000E+03, 0.23714500E+03, -.18422900E+03, 0.32440100E+03, 0.23654400E+04, 0.10527300E+02, 0.11390100E+02, 0.11199300E+04, 0.15032200E+03, 0.13419700E+02, -.20111000E+03, -.13923800E+02, 0.14119600E+02 }, { -.29782600E+00, 0.16965800E+00, -.26241900E+00, 0.51205200E+00, 0.71153900E+00, -.64468800E+00, -.17966900E+01, -.31429200E+00, -.10979600E+00, 0.49688100E+00, -.27746500E-02, 0.38942600E+00, 0.25038600E+00, -.10558100E+00, 0.11125400E+00, 0.32240800E+00, -.27822400E+00, 0.61771200E-01, 0.36199800E+00, -.25737500E+00, -.58125300E+00, 0.15609100E+00, -.56187500E+03, -.14420800E+03, -.15493800E+01, 0.89069100E+00, 0.60836400E+00, 0.89225000E+00, 0.24031400E-01, -.39186600E+00, -.44199100E+00, 0.10321300E+01, -.55477600E+02, -.17784000E+02, -.12782200E+01, 0.39317300E+01, 0.31512700E+02, 0.74524500E+02, 0.23606900E+02, 0.82681000E+01, -.25295700E+03, 0.39979400E+02, 0.78227100E+00, 0.21019600E+02, 0.13079100E+03, -.98442800E+02, 0.57807900E+02, 0.42237900E+02, 0.35255200E+01, -.18788400E+01, -.12241700E+01, -.18970900E+01, 0.85982700E-02, 0.62434100E+00, 0.90546300E+00, -.21653500E+01, 0.92612600E+01, 0.30445600E+02, 0.25476500E+02, 0.18199800E+02, -.55333200E+02, -.50975400E+01, -.18930100E+02, 0.80040900E+01, -.80998400E+00, -.26367000E+00, 0.68990500E+00, 0.75272400E+00, -.62990700E+00, -.91178000E+00, -.99716200E+00, 0.74492700E+00, 0.23495700E+03, 0.82420700E+03, -.51673300E+03, -.51761800E+03, 0.83602500E+03, 0.84743800E+02, 0.27060300E+03, -.50262100E+03, 0.87479000E+03, -.52887400E+03, 0.34463300E+03, 0.38493800E+03, -.40742200E+03, -.21381000E+03, -.57909400E+03, 0.39465100E+03, -.20916500E+03, 0.75742700E+02, -.34249800E+02, -.13812000E+03, 0.21701500E+03, -.36258200E+03, -.13022700E+03, -.13894100E+03, -.82317000E+03, 0.11999400E+04, 0.29391100E+03, 0.31756700E+03, 0.86355000E+02, -.23815600E+03, 0.69933500E+02, 0.34916200E+03, 0.21841400E+04, -.10888900E+04, -.27670100E+03, -.35870200E+03, -.16293200E+03, 0.19888300E+03, -.10421300E+03, -.34853400E+03, 0.41349600E+03, 0.96783200E+02, 0.22828300E+03, 0.19341900E+03, -.23946700E+03, -.49260600E+03, -.67480800E+02, 0.19650900E+03, -.86684400E+03, 0.97189600E+03, 0.42930600E+03, 0.43344100E+03, -.17306400E+03, -.49843600E+03, -.26458200E+03, 0.45135000E+03, -.46186400E+03, -.22657500E+03, -.18653900E+03, -.43467700E+03, 0.56889000E+03, -.23683800E+03, 0.11607600E+03, -.40521000E+03, -.21770900E-01, -.13149800E+01, 0.74388300E+00, 0.55126100E+00, -.12664700E+01, -.14272700E+01, -.15452800E+01, 0.40008000E+00, 0.20937600E+00, -.12782500E+01, 0.51000700E+00, 0.31809000E+00, -.10645100E+01, -.10860600E+01, -.12059200E+01, 0.16597300E+00, -.10921400E+03, 0.67951200E+03, -.49364100E+03, -.57761500E+03, 0.55732600E+03, -.43107400E+03, 0.19805400E+03, -.61376800E+03, 0.10810500E+03, 0.34019300E+03, -.52309000E+01, -.11668800E+02, -.37819800E+02, -.17709600E+03, -.38521300E+03, -.10157400E+03, -.31834200E+01, -.13845600E+01, 0.18240600E+01, 0.39104200E+01, -.27439200E+01, 0.27687700E+01, -.34442100E+01, 0.40151100E+01, -.83126500E+03, 0.70245600E+03, -.10872700E+03, 0.10876200E+02, 0.50840800E+02, 0.28254300E+03, 0.71679300E+03, 0.13159800E+02, 0.70473600E+00, -.37436700E+00, -.29277600E+00, -.42235300E+00, 0.25416300E-01, 0.17769600E+00, 0.17992300E+00, -.48087500E+00, -.55534900E+01, 0.16546300E+01, 0.15969300E+01, 0.33865400E+01, -.79435500E+00, 0.16365800E+01, -.15781700E+01, 0.37151000E+01, 0.10656300E+01, -.13665400E+01, -.57462800E+02, 0.12002600E+03, -.14341400E+01, -.57697600E+01, 0.19575800E+02, 0.15690800E+01, -.56204200E+01, -.13465900E+01, 0.27974700E+03, 0.14255100E+03, -.68955500E+02, -.74030400E+02, 0.23526900E+01, -.12125400E+02, -.22841000E+02, 0.20471800E+03, -.91582700E+00, -.11169800E+01, -.42533700E+02, -.32968000E+03, -.15878500E+01, -.24681200E+02, 0.13835000E+01, -.17148900E+01 }, { 0.25188800E+00, 0.36468000E+00, -.65592000E+00, -.39472600E+00, -.48430900E-02, 0.25314200E+01, -.19306700E+00, -.71956800E+00, -.25948600E+00, -.74502200E+00, 0.23613700E-01, -.81575800E-01, 0.12585400E+00, -.70008600E+00, 0.16104500E+00, 0.74622100E+00, 0.10976800E+01, -.13245800E+01, -.10757800E+01, -.37170600E-01, 0.46086500E+00, 0.12915600E+00, -.59014100E+00, -.11912500E+03, -.10236000E+01, 0.16157300E+01, 0.30365900E+00, 0.30819300E+00, 0.16969900E+00, -.12958200E+00, -.27381000E+00, 0.49441300E+00, -.22688600E+03, 0.72942300E+00, 0.48647000E+02, 0.42761900E+02, 0.59102700E+01, -.23205100E+02, 0.40076300E+02, 0.45222600E+02, -.12281800E+03, -.34568700E+02, 0.49666100E+01, 0.15200000E+02, 0.88790600E+02, -.39783400E+02, 0.36813200E+02, 0.40086000E+02, 0.19208600E+01, -.33358300E+01, -.46220800E+00, -.49876000E+00, -.25674000E+00, 0.91908700E-01, 0.87450300E+00, -.90976800E+00, -.59799600E+02, 0.67828700E+02, 0.22341000E+02, 0.15904600E+02, -.20064400E+02, -.15928300E+02, 0.26779900E+02, 0.21178400E+01, -.10140800E+01, -.25672400E+00, 0.10231600E+01, 0.12791300E+01, -.90834100E+00, -.94453000E+00, -.10900000E+01, 0.13212000E+01, 0.11557200E+04, 0.20506300E+03, -.97060800E+03, -.11181100E+04, 0.13340900E+04, 0.75726900E+03, 0.90604300E+03, -.11564500E+04, 0.33652500E+03, -.35366700E+03, 0.31544800E+03, 0.29228900E+03, -.19792800E+03, -.67874400E+02, -.49464900E+02, 0.30942800E+03, 0.10220300E+03, -.63789400E+02, 0.13781100E+03, 0.70603800E+02, -.17445900E+03, 0.23084700E+02, 0.57554600E+02, 0.84220300E+02, -.53762300E+02, 0.11331000E+04, 0.10559200E+03, 0.32495600E+02, 0.25784300E+03, 0.16338100E+03, 0.61006100E+03, 0.64913400E+02, -.32887200E+02, -.59405000E+01, 0.43415100E+01, -.44671400E+01, 0.27951300E+02, -.30521400E+03, -.44618700E+02, -.39529500E+02, -.23137300E+03, -.42811600E+03, 0.22363400E+03, 0.16765300E+03, 0.18500900E+03, -.15328500E+03, 0.67753700E+03, 0.22224100E+03, -.61051700E+03, 0.12234000E+04, 0.38726300E+03, 0.32943100E+03, 0.34911200E+01, -.11648300E+03, 0.37421600E+03, 0.33153500E+03, 0.90789800E+03, -.76014000E+03, 0.37295900E+03, 0.27424400E+03, -.57434100E+03, 0.22017500E+03, -.47751700E+01, 0.37659700E+03, -.69794000E+00, -.21318100E+01, 0.17192400E+01, 0.22104300E+01, -.19468200E+01, -.16533900E+01, -.18366700E+01, 0.21028000E+01, -.42283800E+00, -.20677600E+01, 0.13617800E+01, 0.17786600E+01, -.16829200E+01, -.13488200E+01, -.15501500E+01, 0.16623000E+01, 0.11494600E+04, 0.13928400E+03, -.74758400E+03, -.87448200E+03, 0.65861600E+03, 0.48501000E+03, 0.35305100E+03, -.87229100E+03, -.38202900E+03, 0.71528600E+03, 0.47015900E+02, 0.54271300E+02, 0.41455300E+02, -.21683400E+03, 0.43394100E+02, -.28112500E+02, 0.13927400E+01, 0.98682100E+00, -.34558200E+00, 0.49006500E+00, -.33768700E+01, 0.13770000E+01, -.76304800E+01, 0.10908600E+01, -.75383800E+03, 0.68190100E+03, -.39979500E+03, -.31145000E+03, 0.14535100E+03, -.92682300E+02, 0.64105100E+02, -.39742400E+03, 0.56542400E+00, -.71367400E+00, -.14901000E+00, -.14962700E+00, -.71263600E-01, 0.89075700E-01, 0.89793400E-01, -.22132600E+00, -.84523300E+00, 0.42830900E+01, -.65804700E+00, -.38170000E+00, -.76498200E+00, 0.14369200E+01, -.41379600E+01, 0.36433600E+00, -.22222500E+01, -.37181200E+01, -.25605600E+02, 0.82875300E+02, -.37868200E+01, -.64698600E+01, 0.11805300E+02, 0.39276600E+01, 0.48905100E+01, -.36986200E+01, 0.48276300E+03, 0.24314900E+03, 0.39066800E+02, -.18014600E+03, 0.83953800E+01, 0.58568900E+02, -.24535200E+02, -.71351200E+02, -.27336000E+01, -.30375900E+01, 0.87261000E+02, -.91054400E+02, -.41472000E+01, 0.13044700E+03, 0.37345300E+01, -.41375600E+01 }, { 0.97083400E+00, 0.28216000E+01, -.75130400E+00, 0.56023500E+00, -.94155800E+00, 0.85926400E+00, -.33036500E+01, 0.85162900E+00, 0.17189500E+01, 0.78774700E+00, -.74255200E+00, 0.11231900E+01, -.23521500E+00, 0.62185500E+01, -.15312100E+01, -.41392900E+01, -.19654300E+01, 0.83716200E-01, 0.22333100E+01, 0.27140400E+00, -.23495200E+01, 0.22783900E+00, 0.18496700E+01, 0.52264400E+00, -.17654700E+02, 0.44269100E+01, 0.49106000E+01, 0.71472400E+01, -.43172400E+01, -.72010300E+01, -.49943200E+01, 0.65824000E+01, 0.40196600E+03, -.10033400E+04, -.31765400E+03, -.44586500E+03, 0.16023200E+03, 0.66662300E+03, 0.70148600E+03, -.41097100E+03, -.41136700E+04, 0.73942000E+02, 0.76876100E+03, 0.94746600E+03, 0.10278600E+03, -.14125700E+04, -.32146600E+03, 0.84471700E+03, 0.41669300E+02, -.83549100E+01, -.11393600E+02, -.16653500E+02, 0.87908900E+01, 0.16600600E+02, 0.88730600E+01, -.15470100E+02, 0.17079400E+04, 0.17170600E+03, -.34284500E+03, -.41313800E+03, -.82234500E+02, 0.52197200E+03, -.16237900E+03, -.38283300E+03, -.14230700E+02, -.23302900E+01, 0.50553500E+01, 0.56220300E+01, -.36016700E+01, -.65781400E+01, -.21014900E+01, 0.54626200E+01, -.64224100E+04, 0.10399800E+05, 0.26433000E+04, 0.33560300E+04, -.30744700E+04, -.29661500E+04, -.67848300E+04, 0.30315500E+04, -.22617200E+04, 0.29157000E+04, -.59941500E+02, -.91951600E+02, 0.54403100E+03, -.14353600E+04, -.10838500E+04, -.30162400E+03, 0.13180300E+04, 0.83361100E+04, -.63255900E+03, -.55994700E+03, -.37608900E+03, -.69288200E+03, 0.17780000E+04, -.49592500E+03, -.40074300E+03, 0.48928700E+04, -.96678200E+03, -.80401800E+03, 0.39022400E+03, -.27289900E+03, -.53125600E+04, -.12057400E+04, 0.12479500E+05, -.23309800E+04, -.16185900E+04, -.21706100E+04, -.16280300E+04, 0.32044500E+04, -.56269400E+03, -.20148200E+04, -.60026200E+03, -.10532000E+04, -.31275700E+03, -.68025600E+03, 0.28511300E+03, -.17184800E+04, -.31774100E+04, -.96549600E+03, 0.17073700E+04, 0.94878600E+04, -.16557200E+04, -.17063700E+04, 0.88856100E+03, 0.23452100E+03, -.36346300E+04, -.19896700E+04, -.39791300E+04, 0.39032500E+04, -.16518100E+04, -.21248500E+04, 0.31178000E+04, -.18635500E+04, 0.40212500E+04, -.24777100E+04, -.10337900E+02, -.78989100E+01, 0.46032100E+01, 0.32493500E+01, -.20353900E+01, -.56132900E+01, 0.84100100E-01, 0.34228400E+01, -.66495300E+01, -.77854700E+01, 0.33602400E+01, 0.20012400E+01, -.11361900E+01, -.38202800E+01, 0.13906200E+01, 0.22610000E+01, -.66783700E+04, 0.66935100E+04, 0.16518400E+04, 0.23592000E+04, -.90201900E+03, -.55391700E+04, -.27315700E+04, 0.19519100E+04, 0.60374100E+04, -.13005000E+04, -.10994000E+04, -.13238200E+04, -.56617800E+03, 0.15455000E+04, -.12912800E+04, -.13371200E+04, -.10003700E+03, -.12350000E+02, 0.31249600E+02, 0.45534600E+02, -.14350300E+02, -.33860600E+02, 0.18739300E+02, 0.45415300E+02, 0.11454000E+05, -.74867300E+04, -.29576400E+03, -.18726300E+03, -.28451900E+04, 0.53164300E+04, 0.25220700E+03, 0.34603800E+03, 0.67702300E+01, -.16220200E+01, -.18970000E+01, -.28402700E+01, 0.17761000E+01, 0.27800400E+01, 0.20342000E+01, -.26251800E+01, -.91077900E+02, 0.28105000E+01, 0.25486200E+02, 0.38574400E+02, -.13476900E+02, -.31845700E+02, 0.46367000E+01, 0.37456000E+02, -.33709100E+02, -.55290900E+01, 0.81624000E+02, -.32758300E+02, -.58703600E+01, -.57266800E+01, -.52108900E+02, 0.64103400E+01, -.52172300E+02, -.53059300E+01, -.20595800E+04, -.51511500E+03, 0.12455400E+04, 0.86156300E+03, -.18995100E+03, 0.95630600E+02, -.20955500E+03, -.38928800E+03, -.36817700E+01, -.45738400E+01, -.94562800E+03, -.41206000E+03, -.38596400E+01, -.87642000E+03, 0.55997700E+01, -.52801000E+01 }, { 0.38939000E+00, 0.51258300E+00, -.30927600E+00, 0.20509900E-01, -.99663000E-01, -.30366100E+00, -.14928000E+00, 0.41534700E+00, -.63407000E-01, -.22955800E+00, 0.63880800E-01, 0.22799200E+00, 0.35734200E-01, -.34482800E-01, 0.10979500E+00, 0.71851900E+00, 0.65401600E+00, 0.20798300E+00, 0.22169900E-01, -.16401800E+00, -.13450100E+00, 0.11873300E+00, 0.26731400E+00, -.25098300E+00, 0.43738700E-01, -.31962400E+01, -.16524100E+00, -.28295600E+00, 0.24889000E+00, 0.13144300E+00, 0.41979200E+00, -.24086700E+00, -.13875200E+03, 0.93670500E+02, 0.30389100E+02, 0.15049300E+02, 0.20319300E+01, -.48321700E+02, 0.41044900E+02, 0.14867800E+02, 0.36157900E+02, -.68391500E+02, -.95003000E+01, -.10192100E+02, 0.16308400E+02, 0.20585700E+02, 0.40588900E+02, -.51407400E+01, -.26128000E+00, 0.37245300E+01, 0.45823100E+00, 0.73140100E+00, -.53022900E+00, -.33360100E+00, -.70456900E+00, 0.63717800E+00, -.43056100E+02, 0.51585600E+02, 0.99538900E+01, 0.99367400E+01, 0.14171200E+01, -.10940300E+02, 0.95480300E+01, 0.82760300E+01, -.49353500E+00, -.30466100E+01, 0.31872500E+00, 0.40443900E+00, -.17600700E+00, -.18890200E+00, 0.26551400E-02, 0.43769700E+00, 0.88679100E+03, -.24787200E+03, -.45710500E+03, -.52052300E+03, 0.53310600E+03, 0.49024600E+03, 0.44860700E+03, -.51323500E+03, -.15178900E+03, 0.90015500E+02, 0.75920200E+01, -.10509200E+02, 0.51627300E+02, 0.52970300E+02, 0.20479500E+03, -.35551300E+01, 0.31860100E+03, -.52035200E+02, 0.14123400E+03, 0.12219000E+03, -.31765600E+03, 0.15374300E+03, 0.58355500E+02, 0.15791200E+03, 0.21500500E+03, 0.27661400E+03, -.63443200E+02, -.87798900E+02, 0.14792600E+03, 0.18927600E+03, 0.44560500E+03, -.70423100E+02, -.57548200E+03, 0.38962700E+03, 0.69382500E+02, 0.82502900E+02, 0.61637600E+02, -.16556500E+03, 0.16148500E+02, 0.71273800E+02, -.41897500E+03, -.77608500E+02, 0.18328400E+02, 0.38564200E+02, 0.20577100E+03, -.98747300E+01, 0.27708600E+03, 0.47424800E+02, 0.78847000E+02, 0.33066300E+03, 0.32186400E+02, 0.19606900E+02, 0.45390200E+02, 0.16800900E+03, 0.41641600E+03, 0.36324500E+02, 0.60582600E+03, -.19362200E+03, 0.35565500E+03, 0.41229000E+03, -.70629400E+03, 0.14315600E+03, -.18817800E+03, 0.44201800E+03, -.81421500E+00, -.21896500E+01, 0.77709400E+00, 0.10844600E+01, -.57423800E+00, -.43765700E+00, -.39363300E+00, 0.11017400E+01, -.67996600E+00, -.21696200E+01, 0.67057900E+00, 0.93959500E+00, -.53456300E+00, -.39808100E+00, -.43452400E+00, 0.94946700E+00, 0.10297600E+04, -.34900000E+03, -.29480500E+03, -.31033500E+03, 0.13500600E+03, 0.52280200E+03, 0.49142900E+02, -.29102700E+03, -.34122400E+03, 0.27080100E+03, 0.55553800E+02, 0.63689500E+02, 0.39087900E+02, -.89192500E+02, 0.94074400E+02, 0.60517100E+02, 0.17067700E+01, -.80613400E+01, -.12861100E+01, -.19032100E+01, -.78320200E-01, 0.17495600E+00, -.18362600E+01, -.17508500E+01, -.29063000E+03, 0.40435900E+02, -.57009100E+02, -.81912700E+02, 0.63543400E+02, -.23882200E+03, -.12961500E+03, -.10389600E+03, 0.62024100E-01, 0.29623500E+01, 0.66311700E-01, 0.11999000E+00, -.11156400E+00, -.34865300E-01, -.18390800E+00, 0.10478100E+00, 0.17199000E+01, -.62653000E+01, -.14640700E+01, -.21758400E+01, 0.61779000E+00, 0.58898700E+00, -.41495100E+00, -.20126800E+01, -.35358600E+01, -.23001600E+01, -.58375800E+01, 0.29067800E+02, -.20962400E+01, -.73837000E+01, 0.12943800E+02, 0.19478100E+01, 0.28951300E+00, -.20472800E+01, 0.23938300E+03, 0.73511500E+02, 0.81209000E+02, -.11615700E+03, 0.13323300E+02, 0.15219900E+02, 0.10552800E+02, -.11356300E+03, -.14980800E+01, -.17472600E+01, 0.61240600E+02, -.51627600E+01, -.20443000E+01, 0.66559000E+02, 0.22028900E+01, -.19203600E+01 }, { 0.15818300E+00, 0.65644000E-01, -.28622900E+00, 0.30230000E-01, -.61611700E-01, -.54300500E+00, -.46664100E+00, 0.24567000E+00, -.81559700E-01, 0.16505700E+00, -.37872600E-02, -.10953200E+00, 0.19098200E+00, -.10999900E+01, 0.18886700E+00, 0.64859200E+00, 0.31806500E+00, 0.26960100E+00, 0.36702700E-01, -.12408800E+00, 0.48809100E-01, 0.11067500E-02, -.96361200E-01, -.63951700E-01, -.15112300E-02, -.13810300E-01, -.68854800E+00, -.69001800E-01, 0.91584800E-01, 0.15782500E-01, 0.11095500E+00, -.73948000E-01, -.10725400E+03, 0.30356700E+02, 0.28037800E+02, 0.30534000E+02, -.72691100E+01, -.55988800E+02, -.31654600E+02, 0.24012100E+02, 0.19789800E+02, -.81093800E+01, -.10886100E+02, -.86649800E+01, 0.11450300E+02, 0.89713700E+01, 0.19884000E+02, -.73699900E+01, -.10551200E+00, -.14553800E-01, 0.89396600E+00, 0.20222700E+00, -.19188600E+00, -.81340000E-01, -.19009100E+00, 0.21559100E+00, -.23123100E+02, 0.84805100E+01, 0.10069400E+02, 0.87649000E+01, -.33754200E+01, -.79011500E+01, 0.96471600E+00, 0.84632700E+01, -.28346000E-01, -.66358800E-01, -.49605600E+00, 0.77812400E-01, -.74517500E-01, -.48463400E-01, -.83218900E-01, 0.41387600E-01, 0.29083400E+03, 0.13485800E+03, -.12981200E+03, -.15873400E+03, 0.20331300E+03, 0.15521600E+03, 0.25940600E+03, -.13732000E+03, 0.55433900E+02, -.50172500E+02, 0.64799100E+01, 0.22349300E+02, -.25619700E+02, 0.20689500E+02, 0.15277700E+02, 0.32784300E+02, 0.24727800E+02, -.96827300E+02, 0.45165100E+02, 0.38911800E+02, -.10056400E+03, -.36636000E+01, -.11448400E+03, 0.20682500E+02, 0.17512200E+02, 0.19252500E+03, 0.19602000E+02, 0.17410800E+02, 0.27289800E+02, 0.27828100E+02, 0.19107400E+03, 0.36650400E+02, -.26203400E+03, 0.47013400E+02, 0.22220400E+02, 0.36281000E+02, 0.49482600E+02, -.77195300E+02, 0.25746600E+02, 0.35493900E+02, 0.14324800E+03, -.13723700E+01, -.22983800E+02, -.13245500E+02, 0.31306100E+02, 0.93147000E+02, 0.12617100E+03, 0.12640700E+02, -.49823700E+02, 0.53507100E+02, 0.57068400E+02, 0.59946700E+02, -.11048900E+02, -.17351800E+01, 0.12472100E+03, 0.77284600E+02, 0.17002700E+03, -.28441000E+03, 0.87710800E+02, 0.11823400E+03, -.22649100E+03, 0.19538800E+02, -.20219800E+03, 0.12600900E+03, -.17534200E-01, -.13998000E+00, -.16590000E+00, 0.23565900E+00, -.23689000E+00, -.94493300E-01, -.24033500E+00, 0.18089700E+00, -.58984100E-02, -.12868500E+00, -.18987000E+00, 0.19699100E+00, -.21543100E+00, -.79081000E-01, -.23759600E+00, 0.14793700E+00, 0.41338500E+03, -.20747800E+02, -.11061100E+03, -.14084100E+03, 0.72454700E+02, 0.24214200E+03, 0.11218200E+03, -.11724300E+03, -.18237600E+03, 0.10748900E+03, 0.26814400E+02, 0.31304200E+02, 0.24734300E+02, -.51662700E+02, 0.46470100E+02, 0.29845800E+02, 0.62393700E+00, -.36782900E+00, -.17907800E+01, -.79551200E+00, 0.28044900E-01, 0.20406400E+00, -.91745700E+00, -.99257600E+00, -.38435900E+03, 0.20493900E+03, -.67807100E+00, -.20556700E+02, 0.93695400E+02, -.15255700E+03, 0.21300900E+02, -.55436200E+02, 0.40721200E-01, 0.20085000E-01, 0.59122600E+00, 0.21213700E-01, -.38518500E-01, 0.86123800E-02, -.44786800E-01, 0.24194700E-01, 0.56872800E+00, -.16120300E+00, -.15809000E+01, -.74226900E+00, 0.25793500E+00, 0.26988100E+00, -.28404900E+00, -.84067000E+00, -.58077500E-01, -.42594300E+00, -.57570500E+01, 0.15609400E+02, -.43892800E+00, 0.47988400E-01, 0.29690600E+01, 0.45004100E+00, 0.12193900E+01, -.42840600E+00, 0.16011900E+03, 0.33197600E+02, -.83971100E+01, -.50607700E+02, 0.63017400E+01, 0.20856300E+02, 0.73599100E+01, 0.34082900E+02, -.32329400E+00, -.33958500E+00, 0.52911100E+02, -.17047600E+01, -.51841700E+00, 0.38739800E+02, 0.43218400E+00, -.49496800E+00 }, { 0.12070400E+01, 0.31598000E+00, 0.12373300E+00, -.23001100E-01, -.39813000E+00, -.19302000E+01, -.19781400E+01, -.72742400E+00, -.56887400E+00, -.90589500E+00, 0.15090500E+00, 0.25743400E+00, -.54366300E+00, 0.10760100E+01, -.12939200E+01, -.17518800E+01, 0.32675500E-01, 0.13945400E+01, -.96716800E-01, 0.33335600E+00, -.11442700E+00, 0.26833200E+00, 0.17086500E+01, -.19951400E+01, -.11503100E+00, -.44872400E+00, 0.28079900E+01, -.30479200E+01, 0.21991600E+01, 0.36134000E+00, 0.37942800E+01, -.26300900E+01, -.24906400E+03, 0.53717800E+02, 0.67086800E+02, -.80580900E+02, 0.55215700E+02, -.69615100E+02, 0.65785700E+03, -.26600400E+02, 0.20562000E+03, -.74820600E+03, -.39812300E+02, -.10107400E+03, 0.19972600E+03, 0.10354900E+03, 0.23886400E+03, -.63684200E+02, -.21302300E+01, 0.52951500E+00, 0.25808100E+01, 0.74505100E+01, -.44886300E+01, -.85692000E+00, -.63555900E+01, 0.65274700E+01, -.30679500E+03, 0.51048200E+03, 0.52821700E+02, 0.70314800E+02, -.15466700E+02, -.57069000E+02, 0.98568500E+02, 0.55299600E+02, -.52823700E+01, -.22128200E+01, 0.41379300E+01, 0.32623600E+01, -.64734500E+00, -.17854400E+01, 0.18519200E+01, 0.38402000E+01, 0.70265800E+04, -.37158900E+04, -.33780600E+04, -.39826000E+04, 0.36573600E+04, 0.33703500E+04, 0.90420700E+03, -.41002700E+04, -.27329700E+04, 0.21465700E+04, 0.11684300E+02, -.47285900E+03, 0.11008800E+04, 0.43796300E+03, 0.22478900E+04, -.48666000E+03, 0.30599100E+04, 0.14530100E+04, 0.90951200E+03, 0.92235100E+03, -.22243100E+04, 0.19750600E+04, 0.14148900E+04, 0.14076900E+04, 0.12472400E+04, 0.10428900E+04, -.32829700E+03, -.71092300E+03, 0.10703600E+04, 0.88882400E+03, 0.26738000E+04, -.70062700E+03, -.45538800E+04, 0.44059900E+04, 0.47189700E+03, 0.59858000E+03, 0.63576200E+03, -.82108200E+03, 0.26516200E+03, 0.55659700E+03, -.57942800E+04, -.16698900E+03, 0.58406000E+03, 0.53212200E+03, 0.18385000E+04, -.52801800E+03, 0.18541800E+04, 0.36424700E+03, 0.36654400E+03, 0.39911700E+04, 0.36683200E+03, 0.54407800E+02, 0.24976200E+03, 0.13016800E+04, 0.29658600E+04, -.34375800E+01, 0.55092000E+04, 0.30539400E+03, 0.27866200E+04, 0.32123500E+04, -.50089400E+04, 0.15643100E+04, 0.10280300E+03, 0.35200500E+04, -.89860300E+01, -.41573800E+01, 0.77985000E+01, 0.95276500E+01, -.34107600E+01, -.33472100E+01, -.40190400E+00, 0.10078500E+02, -.75541300E+01, -.41239000E+01, 0.68958300E+01, 0.83853000E+01, -.33245000E+01, -.30006100E+01, -.11572500E+01, 0.88333000E+01, 0.77122100E+04, -.35095100E+04, -.16184200E+04, -.15827500E+04, 0.81727200E+02, 0.33549900E+04, -.17751200E+04, -.15665000E+04, -.20895700E+04, 0.17621600E+04, 0.37280700E+03, 0.42854900E+03, 0.21486000E+03, -.34058400E+03, 0.82773500E+03, 0.42225800E+03, 0.18841600E+02, -.20191900E+02, -.90119100E+01, -.16801900E+02, -.20157600E+01, -.26467800E+01, -.96784600E+01, -.13931400E+02, -.15336800E+03, -.12808900E+04, -.58180600E+03, -.30512000E+03, -.51296100E+03, -.14233600E+04, -.13423200E+04, -.21619400E+03, 0.36374400E+00, 0.35127700E+00, -.83855800E+00, 0.13565600E+01, -.98542100E+00, -.81734800E-01, -.17213300E+01, 0.11980900E+01, 0.16768200E+02, -.11333400E+02, -.11047800E+02, -.19805200E+02, 0.38834400E+01, 0.42888700E+00, -.13498200E+01, -.17651200E+02, -.38830400E+02, -.13217500E+02, -.32572300E+02, 0.22399400E+03, -.12957000E+02, -.54612200E+02, 0.14184900E+03, 0.12529400E+02, -.94410700E+01, -.13011900E+02, 0.61301400E+03, 0.47803500E+03, 0.91164600E+03, -.71653800E+03, 0.11565300E+03, 0.18486300E+02, 0.18468400E+01, -.17037700E+04, -.10302500E+02, -.10826600E+02, 0.68261400E+01, -.39233900E+02, -.12908000E+02, 0.35397700E+03, 0.13126800E+02, -.12211600E+02 }, { 0.15531100E+00, 0.36923000E-01, 0.40917800E-01, -.58319000E-01, -.14142200E+00, -.17349100E+00, -.65811800E-01, -.47788200E-01, 0.17214500E-01, -.32927200E-01, -.10023700E-01, -.46323800E-01, -.81791600E-01, 0.11601400E+00, -.25099700E-02, -.21054000E+00, 0.12142700E-01, -.71268500E-01, 0.16081300E-01, 0.63945700E-01, -.81738700E-01, 0.25394300E-01, 0.11615800E+00, -.76604200E-01, 0.12680000E-01, -.33070200E-01, 0.65948600E-01, 0.27739500E-01, -.29500900E+00, 0.25401300E-01, 0.52903600E-01, 0.92060000E-02, -.12941400E+02, 0.77617500E+01, 0.86591100E+01, 0.97398800E+01, -.61282300E+01, -.75302600E+01, -.27826100E+01, 0.10370000E+02, -.15565000E+01, -.10434400E+02, 0.42569200E+00, 0.66639700E-01, 0.19837300E+01, 0.16840100E+01, 0.72714800E+01, 0.11996900E+01, -.28173100E-01, -.40539900E-01, -.20646200E-03, 0.11040200E-01, 0.34336600E+00, -.56714300E-01, -.84348500E-01, -.84571800E-02, -.46125900E+01, 0.79848300E+01, 0.13771400E+00, 0.72378500E+00, 0.21785700E+01, -.13954000E+01, 0.94761600E+00, 0.39809800E+00, -.16004000E+00, -.84003600E-01, 0.57380100E-01, 0.85232000E-01, -.29463000E+00, -.62790500E-01, -.15113900E-01, 0.95389400E-01, 0.13402800E+03, -.36727000E+02, -.88653300E+02, -.10287200E+03, 0.10982700E+03, 0.87044500E+02, 0.89998600E+02, -.10468000E+03, 0.16180600E+02, 0.44363900E+01, 0.47865100E+01, 0.54864900E+01, -.18564800E+00, 0.13958400E+02, 0.22414900E+02, 0.79478200E+01, 0.40038400E+02, -.42495900E+01, 0.23232000E+02, 0.25337600E+02, -.49235700E+02, 0.19015500E+02, 0.15237000E+02, 0.35220200E+02, 0.80858500E+02, 0.51867700E+02, -.37606100E+02, -.44011200E+02, 0.53725400E+02, 0.60368200E+02, 0.79859200E+02, -.40515200E+02, -.47027400E+02, 0.52377100E+02, 0.73738800E+01, 0.54953300E+01, -.16828200E+01, -.17682100E+02, -.34153600E+01, 0.20155800E+01, -.10205400E+03, -.10039500E+02, 0.10650400E+02, 0.17583400E+02, 0.34439600E+02, -.26596100E+02, 0.40777000E+02, 0.19882700E+02, 0.40327300E+02, 0.76500500E+02, -.19567300E+02, -.19680600E+02, 0.37754000E+02, 0.44266900E+02, 0.81458100E+02, -.14586800E+02, 0.65017500E+02, -.28181000E+01, 0.54545000E+02, 0.64210200E+02, -.11231400E+03, 0.19114000E+02, -.21461400E+02, 0.72713500E+02, -.29553800E+00, -.14238500E+00, 0.10139200E+00, 0.15548500E+00, -.21225700E+00, -.13657000E+00, -.69563300E-01, 0.16444600E+00, -.24812700E+00, -.14329500E+00, 0.85893600E-01, 0.13238600E+00, -.21023900E+00, -.12129800E+00, -.74914700E-01, 0.13890100E+00, 0.15734200E+03, -.39717700E+02, -.59207600E+02, -.68964000E+02, 0.40259500E+02, 0.81838900E+02, 0.26965100E+02, -.68321500E+02, -.39362900E+02, 0.54095100E+02, 0.55457200E+01, 0.65959500E+01, 0.59868100E+01, -.11764300E+02, 0.10879500E+02, 0.62330400E+01, 0.12262700E+00, -.30858900E+00, 0.54587200E-01, -.93367400E-02, -.84333100E+00, -.24760200E-01, -.36764000E+00, 0.17576800E-01, -.47980600E+02, -.75528600E+01, 0.16082100E+01, -.51620700E+01, -.10349200E+02, -.37901300E+02, -.34827000E+02, -.11350800E+02, 0.74346700E-02, 0.30149100E-01, 0.23832800E-02, -.12104900E-02, 0.27026800E+00, -.74235000E-02, -.22241500E-01, -.46356200E-02, 0.23107900E+00, -.98399100E-01, -.10650100E-01, -.77391100E-01, -.62020900E+00, 0.86691300E-01, -.12648000E+00, -.48846700E-01, -.12882400E+01, -.31443000E+00, -.11840700E+01, -.15230000E+00, -.30973000E+00, -.12037800E+01, 0.10857000E+01, 0.30580600E+00, 0.67517700E+00, -.30392900E+00, 0.46545400E+02, 0.92029700E+01, 0.15177400E+02, -.25602500E+02, 0.18130900E+01, 0.83598700E+00, -.33276100E+01, -.21405500E+02, -.23377900E+00, -.25347300E+00, 0.12404600E+02, 0.24319700E+01, -.31608400E+00, 0.75155300E+01, 0.31025600E+00, -.30715400E+00 }, { -.43498300E+00, -.14969300E+00, 0.43199700E+00, 0.22594800E+00, 0.14424900E+00, 0.10577200E+00, -.14812300E+01, -.48532200E+00, 0.79454000E-01, -.14764500E+00, 0.32668300E-01, 0.45599800E+00, 0.61533900E-01, 0.10695600E+01, -.41119100E+00, -.20265400E+00, -.25112000E+00, -.15674800E+00, -.12998700E+00, 0.52329900E-02, 0.85648200E-02, 0.25090000E-01, 0.25908300E+00, -.23796600E-01, 0.22209800E-01, -.18419000E-02, -.21025400E+00, -.84476400E-01, -.76826000E-01, -.14164400E+01, 0.14336700E+00, 0.40492800E-01, 0.72488300E+02, 0.52998900E+02, -.16610400E+02, -.45816000E+02, 0.21765800E+02, 0.80294900E+02, 0.11593900E+03, -.31333300E+02, 0.15434400E+02, -.41509700E+02, 0.41437400E+01, 0.17214400E+01, -.87940200E+01, 0.73155300E+01, 0.37671200E+01, 0.38140800E+01, -.36821500E-01, -.98094800E-02, 0.48664200E-01, 0.26163800E-02, -.23553400E-01, 0.16444600E+01, -.19844300E+00, -.90125400E-01, -.41055500E+01, 0.24724400E+02, -.42605900E+01, -.55965800E+01, 0.90115600E+01, 0.55009000E+01, 0.70646600E+01, -.67589800E+01, -.50960800E+00, -.18886600E+00, 0.24581600E+00, 0.25391300E+00, -.39780500E-01, -.14114400E+01, 0.15207400E+00, 0.34140800E+00, 0.26180800E+03, -.56757800E+03, -.22839600E+03, -.24935700E+03, 0.15974200E+03, 0.17375300E+03, -.67315900E+02, -.30025800E+03, -.93255400E+02, 0.17978400E+03, 0.11911100E+02, -.20519800E+02, 0.46761100E+02, 0.28223800E+02, 0.11963700E+03, -.27149400E+02, 0.31346800E+03, 0.13109500E+03, 0.45087900E+02, 0.44639200E+02, -.10954300E+03, 0.18285900E+03, 0.32016600E+03, 0.11068200E+03, 0.13980200E+03, -.91428100E+02, -.92269100E+02, -.11640200E+03, 0.95326200E+02, 0.12589600E+03, 0.56336100E+02, -.14105000E+03, -.13309100E+03, 0.30885400E+03, 0.49264700E+02, 0.47842500E+02, -.51121800E+02, -.75196700E+02, -.47052100E+02, 0.38231500E+02, -.55356300E+03, -.60173200E+02, 0.57815700E+02, 0.42519500E+02, 0.13042300E+03, -.15551100E+03, 0.32694500E+02, 0.15901400E+02, 0.20920700E+03, 0.21507800E+03, -.73077700E+02, -.10440200E+03, 0.61619400E+02, 0.18809000E+03, 0.16864100E+03, -.12284900E+03, 0.14018500E+03, 0.44705700E+03, 0.17193900E+03, 0.16099000E+03, -.18669000E+03, 0.81950600E+02, 0.27210800E+03, 0.19275100E+03, -.93946800E+00, -.31848800E+00, 0.44766400E+00, 0.45515800E+00, -.44039500E-01, -.10584000E+01, 0.11357200E+00, 0.56099800E+00, -.80280200E+00, -.32753700E+00, 0.38717500E+00, 0.39725600E+00, -.54387400E-01, -.10351700E+01, 0.69327400E-01, 0.48770500E+00, 0.12508900E+03, -.32478700E+03, -.12320500E+03, -.84205900E+02, 0.45654800E+02, 0.13287100E+02, -.14246700E+03, -.11978000E+03, 0.38212500E+01, 0.49435100E+02, 0.33024300E+01, 0.28055000E+01, -.57344400E+01, 0.28041600E+01, 0.13818200E+02, 0.19786800E+01, 0.46193800E+00, -.13190900E+01, 0.29554400E-01, 0.55498100E+00, -.56857900E+00, -.33579600E+01, -.47367900E+00, 0.97532400E+00, 0.22197300E+03, -.39460700E+03, -.37947600E+02, 0.51279700E+01, -.12269700E+03, -.17076500E+02, -.15174700E+03, 0.26473200E+02, -.24279500E-01, 0.46056200E-01, -.13039400E-02, 0.92878000E-02, 0.95338600E-02, 0.13035800E+01, -.68761100E-01, -.73360400E-02, 0.59822900E+00, -.66225600E+00, -.22352800E+00, 0.11496400E+00, -.24292500E+00, -.26050900E+01, -.20578900E+00, 0.38950900E+00, -.41151400E+01, -.63208700E+00, 0.89548600E+01, -.35492500E+01, -.57409300E+00, -.15275900E+02, 0.23542800E+01, 0.53048600E+00, 0.80115500E+00, -.58526700E+00, -.10068200E+03, 0.10758500E+02, 0.10365000E+03, -.12694500E+02, -.79831400E+00, -.20588800E+02, -.78778200E+01, -.20119100E+03, -.50372300E+00, -.54395900E+00, -.52846800E+02, 0.48573000E+01, -.38545100E+00, -.82060800E+01, 0.60355000E+00, -.45052500E+00 }, { 0.97500100E-02, -.24878700E-01, 0.10718800E+00, 0.11484900E+00, 0.48726100E-01, -.36518100E+00, 0.13098400E+00, -.27814700E-01, 0.43846000E-01, -.90138400E-02, 0.86094900E-03, 0.32661200E-01, 0.61880400E-01, -.79663100E-01, -.68252500E-01, 0.19220300E-01, 0.57931900E-01, -.14816100E-01, -.85521200E-02, -.42784100E-02, 0.23141500E-01, -.32782700E-02, -.50452900E-02, -.51397400E-02, 0.17527400E-02, -.31710400E-02, -.75390100E-02, -.87395800E-02, -.35603500E-01, -.12809700E-01, -.23949400E+00, 0.55155000E-02, -.32703200E+02, 0.10593500E+02, 0.18952300E-02, -.36123900E+01, 0.91756600E+01, -.25774600E+01, 0.25806600E+02, -.28709200E+01, -.30535400E+01, -.12661000E+02, 0.11009400E+01, 0.83385100E+00, 0.16830200E+01, -.20920300E+00, 0.35695200E+01, 0.14385500E+01, -.28732500E-01, 0.11251000E-01, 0.23261800E-01, 0.90727600E-02, -.95018200E-02, -.19594900E-01, 0.27354400E+00, -.31965700E-02, -.17536600E+01, 0.91688400E+01, 0.14998800E+00, -.49490400E-01, 0.50653500E+00, 0.34833800E+00, 0.26470800E+01, -.24935800E+00, -.13135600E+00, -.49881800E-01, 0.68106500E-01, 0.71214800E-01, -.35065400E-01, -.61444800E-01, -.22756200E+00, 0.79626000E-01, 0.11579600E+03, -.82213800E+02, -.71300500E+02, -.84147200E+02, 0.80063700E+02, 0.67412200E+02, 0.41788800E+02, -.86063600E+02, 0.55969900E+01, 0.21995400E+02, 0.63140600E+01, 0.31777000E+01, -.29256200E+01, 0.10305400E+02, 0.21806900E+02, 0.38774900E+01, 0.63894400E+02, 0.38561400E+02, 0.19754100E+02, 0.25495800E+02, -.51541200E+02, 0.31434700E+02, 0.36970600E+02, 0.35370600E+02, 0.27230400E+02, 0.25707000E+02, -.15069600E+02, -.20034800E+02, 0.25609600E+02, 0.29856300E+02, 0.53640100E+02, -.20253400E+02, -.65040900E+02, 0.67570300E+02, 0.11502900E+02, 0.11931600E+02, 0.76263300E+00, -.27000700E+02, -.29877100E+01, 0.95733200E+01, -.80550800E+02, -.19657800E+02, 0.50858700E+01, 0.19107700E+01, 0.32407100E+02, -.18658800E+02, 0.27399800E+02, 0.13692200E+01, 0.26414800E+02, 0.93714300E+02, -.14636600E+00, -.39740600E+01, 0.57856500E+01, 0.33730200E+02, 0.61399600E+02, -.26628300E+01, 0.35739000E+02, 0.52442900E+02, 0.50990700E+02, 0.61094700E+02, -.90285900E+02, 0.80716200E+01, 0.97154400E+01, 0.65822100E+02, -.23777400E+00, -.88120800E-01, 0.12493100E+00, 0.13069300E+00, -.58520600E-01, -.10784600E+00, -.15652100E+00, 0.13935800E+00, -.20086900E+00, -.87488000E-01, 0.10804400E+00, 0.11151200E+00, -.55167800E-01, -.97530000E-01, -.16570000E+00, 0.11859900E+00, 0.13243600E+03, -.67280200E+02, -.51655400E+02, -.49510000E+02, 0.23537300E+02, 0.55028100E+02, -.11355800E+02, -.50071000E+02, -.33520800E+02, 0.32329300E+02, 0.53887200E+01, 0.59802000E+01, 0.40784800E+01, -.99208800E+01, 0.11406900E+02, 0.53803600E+01, 0.21536400E+00, -.46338700E+00, -.56423600E-01, 0.47590500E-01, -.19039800E+00, -.60795200E-01, -.90766600E+00, 0.79956100E-01, -.25831800E+02, -.49908900E+02, -.65314600E+01, -.40376600E+01, 0.10267300E+01, -.25871000E+02, -.32558000E+02, -.55956800E+01, 0.30198800E-02, 0.91336100E-02, -.56053200E-02, -.35785100E-03, 0.55362800E-02, 0.10283100E-01, 0.23587600E+00, -.23667700E-02, 0.24569700E+00, -.25246100E+00, -.10958700E+00, -.41712800E-01, -.66696500E-01, 0.27634900E-01, -.63432500E+00, -.15741600E-01, -.10397400E+01, -.27167400E+00, 0.17181800E+01, 0.19901400E+01, -.28443300E+00, -.16831600E+01, 0.15882300E+01, 0.29748100E+00, 0.13893800E+00, -.27080200E+00, 0.17938400E+02, 0.85758100E+01, 0.23269400E+02, -.14233000E+02, -.68437400E+00, -.27982300E+01, 0.10322500E+01, -.32329200E+02, -.20348900E+00, -.21133600E+00, -.10170400E+00, 0.88796300E+00, -.32835200E+00, 0.47144300E+01, 0.27733600E+00, -.32362800E+00 }, { 0.20565700E+00, 0.85662400E-01, -.34188100E+00, -.15876400E+00, -.11974700E+00, -.74768500E+00, -.54475100E+00, 0.35182000E+00, -.43726700E-01, 0.94285100E-01, -.81298300E-02, -.38614900E-01, 0.20530200E+00, -.90607900E+00, 0.46991700E-01, 0.47130900E+00, 0.37231700E+00, 0.76393700E-01, -.67591700E-01, -.82220000E-01, 0.56409700E-02, 0.42249900E-01, 0.33199100E-01, -.93963900E-01, 0.59105000E-02, -.36594900E-01, 0.13117200E+00, 0.21724000E+00, 0.14233100E+01, 0.42438600E-01, 0.33242900E+01, 0.40620600E+00, 0.92459500E+02, -.32768300E+02, -.20950900E+02, 0.19855100E+02, -.22955800E+02, 0.72230400E+01, -.21398200E+03, -.41470000E+00, -.39714900E+02, 0.20982400E+03, 0.48645300E+01, 0.22534100E+02, -.51857900E+02, -.25535200E+02, -.66128700E+02, 0.11468300E+02, 0.51796700E+00, -.17779400E+00, -.52389800E+00, -.71270600E+00, 0.38994500E+00, 0.12181500E+00, 0.39901700E+00, -.10801200E+01, 0.73077700E+02, -.14439000E+03, -.10120000E+02, -.15380600E+02, -.58865100E-01, 0.12148200E+02, -.30077400E+02, -.12434000E+02, 0.17437200E+01, 0.64995800E+00, -.10490000E+01, -.14044400E+01, 0.59451700E+00, 0.70296500E+00, 0.33141700E+00, -.11314000E+01, -.19465400E+04, 0.12336700E+04, 0.10371000E+04, 0.12237800E+04, -.11337800E+04, -.98427700E+03, -.34366400E+03, 0.12608600E+04, 0.39435400E+03, -.50479500E+03, -.43323600E+02, 0.58172900E+02, -.18126700E+03, -.16340500E+03, -.51918200E+03, 0.51155200E+02, -.86322600E+03, -.44357600E+03, -.26288700E+03, -.30670300E+03, 0.63468600E+03, -.55064000E+03, -.47614300E+03, -.45851400E+03, -.45924000E+03, -.25982600E+03, 0.17847000E+03, 0.28399200E+03, -.38348800E+03, -.34558800E+03, -.78582300E+03, 0.27486400E+03, 0.11524800E+04, -.11862900E+04, -.13633500E+03, -.16230100E+03, -.12598900E+03, 0.25669300E+03, -.41756500E+02, -.13991500E+03, 0.15880600E+04, 0.59901500E+02, -.17443800E+03, -.15917600E+03, -.48792600E+03, 0.22794500E+03, -.47313100E+03, -.12823000E+03, -.19508900E+03, -.12139200E+04, -.40274200E+02, 0.29233300E+02, -.12342700E+03, -.41614600E+03, -.88345100E+03, 0.25430300E+02, -.12515900E+04, -.36549500E+03, -.76971800E+03, -.89684000E+03, 0.13701700E+04, -.37978200E+03, -.11642600E+03, -.99484500E+03, 0.30751100E+01, 0.11698600E+01, -.19519000E+01, -.26171600E+01, 0.10191900E+01, 0.12153800E+01, 0.52347000E+00, -.25356800E+01, 0.25886500E+01, 0.11731500E+01, -.17111600E+01, -.23165800E+01, 0.10107200E+01, 0.10890300E+01, 0.73072400E+00, -.22010500E+01, -.20819700E+04, 0.10364900E+04, 0.55690300E+03, 0.55628500E+03, -.14003600E+03, -.90336800E+03, 0.41295500E+03, 0.56298600E+03, 0.59747200E+03, -.52165000E+03, -.10247200E+03, -.11859100E+03, -.67434400E+02, 0.11971100E+03, -.22343800E+03, -.11523200E+03, -.44554700E+01, 0.62544100E+01, 0.16485000E+01, 0.16845600E+01, 0.23346200E+01, 0.11514000E+01, 0.53596500E+01, 0.20515000E+01, 0.27619500E+03, 0.48526700E+03, 0.11389100E+03, 0.42765000E+02, 0.13078200E+03, 0.43982900E+03, 0.40092700E+03, 0.48848200E+02, -.81528400E-01, -.97839500E-01, 0.15899800E+00, 0.24239500E+00, -.21842900E+00, -.78910700E-01, -.42437000E+00, -.18482500E+00, -.43169400E+01, 0.35236100E+01, 0.22970400E+01, 0.27681700E+01, 0.49192200E+00, 0.86290300E-01, 0.26373200E+01, 0.31500200E+01, 0.13343200E+02, 0.36997400E+01, 0.41420600E+01, -.45851700E+02, 0.36805000E+01, 0.20635900E+02, -.37706300E+02, -.36275800E+01, 0.19712100E+01, 0.36401500E+01, -.18366500E+03, -.13338600E+03, -.28107700E+03, 0.21966700E+03, -.23955100E+02, 0.79512900E+01, 0.43080900E+01, 0.50980000E+03, 0.28451900E+01, 0.29892700E+01, 0.45736000E+01, -.58502000E+01, 0.37532100E+01, -.90568000E+02, -.36928200E+01, 0.36157700E+01 }, { 0.44882700E+00, 0.37635300E+00, -.79704100E+00, -.53133500E+00, -.10743600E+00, 0.81182100E+00, -.24852500E+01, -.74336800E+00, 0.18201000E+00, -.34067200E-01, -.16989500E+00, 0.27085400E+00, -.11131100E+00, -.98362200E+00, -.82384200E+00, 0.11773000E+01, 0.64692500E+00, -.59878000E+00, -.14212800E+01, -.19935600E+00, 0.95538100E+00, 0.19269800E+00, -.31030900E+00, -.26166500E+00, -.11030200E+00, -.40172800E+00, 0.16500700E+00, 0.38054800E-01, -.13183800E+01, -.12516800E+00, -.45827700E+01, 0.31068600E+00, -.11788100E+04, 0.89377400E+02, 0.25181000E+03, 0.22413400E+03, -.67128200E+01, -.39621100E+03, 0.24440200E+03, 0.21783700E+03, -.26712400E+03, -.50671700E+03, 0.45553000E+02, 0.40191700E+02, 0.14763100E+03, -.89731700E+02, 0.19814200E+03, 0.63905700E+02, -.14983400E+01, -.48668400E-01, 0.62642000E+00, 0.58200300E+00, -.25806800E+00, -.58976800E+00, -.28289400E+00, 0.41676900E+00, -.16711900E+03, 0.41842700E+03, 0.20433500E+02, 0.20514600E+02, 0.19038000E+02, -.17482100E+02, 0.84175900E+02, 0.10385100E+02, -.66614600E+01, -.27554600E+01, 0.29675800E+01, 0.35906600E+01, -.20086100E+01, -.33581400E+01, -.21881400E+01, 0.34981600E+01, 0.56931000E+04, -.65733100E+02, -.33810700E+04, -.41280500E+04, 0.41193700E+04, 0.33214500E+04, 0.33933900E+04, -.41781900E+04, 0.57828800E+02, 0.65130100E+03, 0.24659100E+03, 0.13257300E+03, 0.14519800E+03, 0.33758200E+03, 0.88755500E+03, 0.19241900E+03, 0.15420300E+04, 0.86703400E+03, 0.83832400E+03, 0.10118200E+04, -.20217200E+04, 0.68664800E+03, -.95492000E+02, 0.11356300E+04, 0.17049600E+04, 0.30367400E+04, -.73269900E+03, -.10765900E+04, 0.14889600E+04, 0.14127900E+04, 0.29816500E+04, -.99258000E+03, -.20408000E+04, 0.17856200E+04, 0.16551800E+03, 0.20439300E+03, 0.29519700E+03, -.61199800E+03, 0.86836700E+02, 0.14196000E+03, -.26160400E+04, -.14324000E+03, 0.27599800E+03, 0.15940800E+03, 0.14515000E+04, -.37434300E+03, 0.17079900E+04, 0.29025100E+03, 0.77372800E+03, 0.43736100E+04, -.14117600E+03, -.34739200E+03, 0.82760100E+03, 0.11378300E+04, 0.26360400E+04, -.26563700E+03, 0.19596900E+04, -.49870500E+03, 0.21015400E+04, 0.24957300E+04, -.38054800E+04, 0.33362900E+03, -.10986500E+04, 0.27216400E+04, -.12213600E+02, -.47369100E+01, 0.54855000E+01, 0.66446800E+01, -.33226300E+01, -.60717500E+01, -.35601400E+01, 0.64878500E+01, -.10223500E+02, -.47134600E+01, 0.46813500E+01, 0.56758000E+01, -.31596600E+01, -.52513100E+01, -.36934600E+01, 0.55072900E+01, 0.64730100E+04, -.96375600E+03, -.23363000E+04, -.26388500E+04, 0.14195300E+04, 0.32842000E+04, 0.79135400E+03, -.25671200E+04, -.14403400E+04, 0.18594400E+04, 0.20502000E+03, 0.23193600E+03, 0.22787700E+03, -.36600400E+03, 0.54936200E+03, 0.21527700E+03, 0.12469100E+02, -.22941900E+02, -.74426100E+00, 0.12894000E+01, -.12602000E+02, -.17626400E+01, -.22168900E+02, 0.11711500E+01, -.17863700E+04, -.94294500E+03, -.30762700E+03, -.16862000E+03, -.20152900E+03, -.12672600E+04, -.10479700E+04, -.37750900E+03, 0.36231300E+00, 0.66696800E+00, -.13807800E+00, -.13813500E+00, 0.28558800E+00, 0.27390600E+00, 0.74339900E+00, -.47255900E-01, 0.13515500E+02, -.11510700E+02, -.34209400E+01, -.27656700E+01, -.53508600E+01, 0.20953800E+01, -.10973300E+02, -.25706900E+01, -.52969400E+02, -.11405000E+02, -.25648100E+02, 0.10042600E+03, -.11387800E+02, -.18847400E+02, 0.82127700E+02, 0.11390600E+02, 0.21692100E+01, -.11181100E+02, 0.17762900E+04, 0.37094700E+03, 0.53977100E+03, -.90826200E+03, 0.39081800E+02, 0.24206200E+02, -.10167800E+03, -.65692800E+03, -.88080600E+01, -.93309000E+01, 0.47525900E+03, 0.22582900E+02, -.11802400E+02, 0.26757600E+03, 0.11389100E+02, -.11702300E+02 }, { 0.73136300E+00, 0.13152000E+00, -.11459800E+01, -.89072700E-01, -.67867700E+00, -.22109000E+01, -.36651300E+01, 0.26409400E+00, -.30205500E+00, 0.91548100E+00, -.13659400E+00, -.91253000E+00, 0.78966500E+00, -.52761300E+01, 0.11479400E+01, 0.19636300E+01, 0.66452900E+00, 0.13834100E+01, 0.37726500E+00, -.38761200E+00, 0.32020800E+00, -.19291100E+00, -.48854300E+00, -.70252100E+00, -.10861000E-01, -.35234000E+00, -.62908400E+00, 0.75416800E-01, -.13279200E+01, -.51854800E+00, -.43936000E+01, -.94224700E-03, 0.84495700E-01, 0.79451600E+03, 0.23918000E+03, 0.23153600E+03, -.29627100E+03, -.86731400E+02, -.24878700E+03, 0.22980500E+03, 0.33504800E+03, 0.32130000E+02, -.11372400E+03, -.89683800E+02, 0.61139300E+02, 0.17527200E+03, 0.17865400E+03, -.63359400E+02, -.10068000E+01, -.89692700E+00, -.49450700E-01, 0.50461000E+00, -.44869200E+00, -.12698200E+01, -.55601200E+00, 0.54279500E+00, -.28433800E+03, 0.52690600E+01, 0.93566200E+02, 0.84645600E+02, -.49257000E+01, -.10866800E+03, 0.12978800E+02, 0.73880200E+02, -.13753600E+01, -.14656700E+01, 0.75422700E+00, 0.14490500E+01, -.14297100E+01, -.14981500E+01, -.19567800E+01, 0.12594500E+01, 0.26585100E+04, 0.40169100E+03, -.19057200E+04, -.19863500E+04, 0.23154900E+04, 0.16525000E+04, 0.23887200E+04, -.19216500E+04, 0.13188000E+04, -.40142600E+03, 0.30717100E+03, 0.37066300E+03, -.56102000E+03, 0.30360200E+03, 0.83540200E+02, 0.47638200E+03, 0.20938300E+03, -.10834400E+04, 0.12984000E+04, 0.73455300E+03, -.11637000E+04, -.10126300E+03, -.39954100E+03, 0.75475900E+03, 0.81716800E+03, 0.21315600E+04, -.14033400E+03, -.19384100E+03, 0.46036600E+03, 0.82414900E+03, 0.18481500E+04, -.59708400E+02, -.20950400E+04, 0.64508500E+03, 0.39195400E+03, 0.42481900E+03, 0.14161900E+03, -.10230900E+04, -.12017300E+02, 0.38713400E+03, 0.79107500E+02, -.38713400E+02, -.21559600E+03, 0.13053300E+03, 0.24132000E+03, 0.82394000E+02, 0.11900700E+04, 0.31997200E+03, -.35624800E+03, 0.59478900E+03, 0.54853200E+03, 0.44263100E+03, -.15032000E+01, 0.25567200E+03, 0.15361900E+04, 0.58510700E+03, 0.83525600E+03, -.16500500E+04, 0.16547800E+04, 0.14275500E+04, -.23538600E+04, 0.19995400E+02, -.11447100E+04, 0.16147100E+04, -.23503100E+01, -.27473900E+01, 0.13118600E+01, 0.27240500E+01, -.25382600E+01, -.26085900E+01, -.32808400E+01, 0.24058800E+01, -.19328200E+01, -.26323300E+01, 0.99494600E+00, 0.22474100E+01, -.22848400E+01, -.23759300E+01, -.32039100E+01, 0.19626700E+01, 0.31512400E+04, -.74592900E+03, -.14858400E+04, -.17640000E+04, 0.12448400E+04, 0.17701400E+04, 0.11361100E+04, -.16822000E+04, -.15283400E+04, 0.11403900E+04, 0.22449700E+03, 0.24823200E+03, 0.21959400E+03, -.52644800E+03, 0.39259500E+03, 0.22523500E+03, 0.48640300E+01, -.22991600E+01, -.99848500E+00, -.34116200E+01, -.23531300E+01, 0.27256800E+01, -.11551900E+02, -.46355400E+01, -.37338700E+04, 0.10923800E+04, 0.44997300E+02, -.87575800E+02, 0.80268500E+03, -.14350300E+04, -.28387000E+03, -.39775500E+03, 0.28775100E+00, 0.58459400E+00, 0.16146600E+00, -.69107000E-01, 0.21133100E+00, 0.51842900E+00, 0.54545000E+00, -.68302700E-01, 0.56481800E+01, 0.24281400E+00, -.12385700E+01, -.37356700E+01, 0.12021200E+00, 0.42057800E+01, -.46969800E+01, -.43067900E+01, -.10184800E+02, -.54876800E+01, -.26297600E+02, 0.10843100E+03, -.54701400E+01, -.44620000E+02, 0.71320300E+01, 0.54725500E+01, 0.17587900E+02, -.53668100E+01, 0.13374600E+04, 0.36329300E+03, 0.43393200E+02, -.48639400E+03, 0.37049400E+02, -.36095800E+02, 0.31129800E+02, -.58237800E+02, -.40770200E+01, -.44226600E+01, 0.36600900E+03, 0.12782900E+02, -.54830700E+01, 0.31056100E+03, 0.54727000E+01, -.55976300E+01 }, { 0.12682900E-01, -.30741500E-01, 0.13266700E+00, 0.14213300E+00, 0.60001300E-01, -.45676500E+00, 0.16051200E+00, -.34797000E-01, 0.55664400E-01, -.94777600E-02, 0.93072100E-04, 0.38362200E-01, 0.76411400E-01, -.10066400E+00, -.82564100E-01, 0.20753800E-01, 0.71398200E-01, -.20546200E-01, -.67375100E-02, -.57917000E-02, 0.28432200E-01, -.48349300E-02, -.26137100E-02, -.10772400E-01, 0.25176100E-02, -.47714400E-02, -.93245100E-02, -.10577700E-01, -.43181600E-01, -.17194600E-01, -.12192700E+01, 0.33166400E-01, 0.71426600E-01, 0.26892300E-01, -.23716600E+02, -.31699100E+02, 0.31911800E+02, 0.23918900E+02, 0.57710900E+02, -.28768200E+02, 0.49881100E+01, -.21705800E+01, 0.22445900E+01, 0.69459700E+00, -.66685500E+01, 0.26361200E+01, -.70184600E+01, 0.16254100E+00, 0.46232500E-01, 0.56219600E-01, 0.30849900E-01, -.90032300E-02, -.60609600E-02, 0.22092800E-01, 0.26697100E+00, -.16181800E-01, 0.12589300E+02, -.31860500E+01, -.32519700E+01, -.33253300E+01, 0.15309400E+00, 0.44687800E+01, 0.19722100E+00, -.29151400E+01, 0.14180900E+00, 0.92804800E-01, -.32894900E-01, -.76436800E-01, 0.76605900E-01, 0.10853000E+00, -.61490000E-01, -.53275100E-01, -.13186200E+03, -.25175200E+03, 0.85356200E+02, 0.10339400E+03, -.12446100E+03, -.83666200E+02, -.19203200E+03, 0.99473200E+02, -.37545200E+02, 0.32142000E+02, -.86397400E+01, -.13137300E+02, 0.24868700E+01, -.14237100E+01, 0.47320800E+01, -.18308900E+02, 0.72992000E+02, 0.71101200E+02, -.38975800E+02, -.21154300E+02, 0.28854200E+02, 0.50731700E+02, 0.12648700E+03, -.15087700E+01, -.62256800E+02, -.20596800E+03, 0.13951000E+02, 0.24418600E+02, -.44150300E+02, -.38008000E+02, -.10646900E+03, 0.14593500E+02, -.25592600E+01, 0.60991200E+02, 0.12203600E+02, 0.10813400E+02, -.19593700E+02, -.70927300E+01, -.12153200E+02, 0.96230200E+01, -.63114300E+02, -.41309600E+02, 0.41238500E+01, -.51320400E+01, -.14855600E+02, -.27957200E+02, -.71170400E+02, -.21800300E+02, 0.26461300E+02, -.64747200E+02, -.35108900E+01, 0.23602800E+01, -.41360900E+02, 0.91247000E+01, -.51680500E+02, -.39687300E+01, -.29582800E+02, 0.21722100E+03, -.45419300E+02, -.38800900E+02, 0.68183200E+02, 0.95567200E+01, 0.13853800E+03, -.45402900E+02, 0.26745900E+00, 0.15777000E+00, -.60323200E-01, -.14432900E+00, 0.12853600E+00, 0.20364800E+00, 0.10926100E+00, -.10613100E+00, 0.21830200E+00, 0.15426600E+00, -.43309500E-01, -.11894100E+00, 0.11877500E+00, 0.16722600E+00, 0.87646400E-01, -.85782600E-01, -.15274000E+03, -.11298700E+03, 0.61779100E+02, 0.95979700E+02, -.72780500E+02, -.11703900E+03, -.12609800E+03, 0.87206700E+02, 0.40574400E+02, -.66944900E+02, -.39061300E+01, -.44295500E+01, -.97929700E+01, 0.11277800E+02, -.14310800E+02, -.42569200E+01, -.33469500E+00, 0.39240100E+00, -.12078600E+00, 0.50015100E-01, 0.42929100E+00, -.12616400E+00, 0.22087300E+00, 0.15923600E+00, 0.15484600E+03, -.96574300E+02, 0.62670300E-01, 0.17929200E+01, -.70598000E+01, 0.51284500E+02, -.64363900E+01, 0.20892200E+02, -.23580000E-01, -.36228500E-01, -.13283500E-01, 0.28880600E-02, -.54457300E-02, -.46705300E-02, 0.20773900E+00, 0.56529700E-02, -.37101500E+00, 0.10535100E+00, -.69738600E-01, 0.99217900E-01, 0.20518900E+00, -.19256100E+00, -.10098100E+00, 0.15230400E+00, 0.11407300E+01, 0.25865800E+00, 0.58063200E+01, -.33776900E+01, 0.24502300E+00, -.19347800E+01, -.75320200E+00, -.23337200E+00, -.51468300E+00, 0.24828200E+00, -.11317000E+03, -.10551200E+02, 0.26802300E+02, 0.36730700E+02, -.37155200E+01, -.69527100E+01, 0.89422400E+01, -.47538600E+02, 0.20304600E+00, 0.22286400E+00, -.43383800E+02, 0.20829700E+00, 0.20829000E+00, -.12724500E+02, -.25199900E+00, 0.22072800E+00 }, { -.10808600E+01, -.40581200E+00, 0.17756700E+01, -.16976700E+00, 0.49001200E+00, 0.31669400E+01, 0.34539100E+01, -.38311500E+00, 0.51956700E+00, -.13155900E+01, 0.14809600E+00, 0.13641100E+01, -.11540700E+01, 0.73719500E+01, -.12107500E+01, -.28071700E+01, -.19067900E+01, -.18177400E+01, 0.47307900E+00, 0.53017300E+00, -.23683600E+00, -.17062500E-01, 0.17514000E+01, -.53271300E+00, -.34221800E-01, -.22769500E+00, 0.15628700E+00, -.10356500E+00, 0.16346800E+01, -.24430700E+00, 0.38125800E+00, 0.73460500E+00, -.77823700E+00, -.35346700E+00, -.26926500E+01, -.18141300E+03, 0.11112400E+03, 0.31342300E+03, 0.99457700E+03, -.61399200E+02, -.28209800E+03, -.69609900E+03, 0.13534500E+03, 0.10273300E+03, 0.45586500E+02, -.54004400E+02, 0.80447000E+02, 0.13821700E+03, -.11245900E+01, -.68923500E+00, 0.10154800E+01, 0.69519000E+00, -.17942800E+00, -.65489600E+00, 0.16228600E+00, 0.12901300E+00, -.16442900E+02, 0.49149300E+03, -.64404200E+02, -.69218600E+02, 0.71288800E+02, 0.45366800E+02, 0.11757800E+03, -.86841100E+02, -.84577500E+01, -.35343500E+01, 0.39129600E+01, 0.46577400E+01, -.12525700E+01, -.36106500E+01, -.11884100E+01, 0.52284500E+01, 0.45153600E+04, -.48948300E+04, -.33240500E+04, -.40421300E+04, 0.34780300E+04, 0.27947600E+04, 0.43393400E+03, -.45550200E+04, -.17650300E+04, 0.22327500E+04, -.53571600E+01, -.41098400E+03, 0.91082300E+03, 0.42891300E+03, 0.19265600E+04, -.46718300E+03, 0.30759300E+04, 0.23201700E+04, 0.74030100E+03, 0.10924100E+04, -.19795500E+04, 0.18255200E+04, 0.29184900E+04, 0.18794000E+04, 0.20248900E+04, 0.50440900E+03, -.11439200E+04, -.16265700E+04, 0.15551300E+04, 0.17342800E+04, 0.17632800E+04, -.18458800E+04, -.18176800E+04, 0.39778700E+04, 0.37661100E+03, 0.33073100E+03, -.24607400E+03, -.62203100E+03, -.24934800E+03, 0.19289100E+03, -.83064500E+04, -.74968900E+03, 0.10329100E+04, 0.81279800E+03, 0.19580800E+04, -.22028600E+04, 0.11561100E+04, 0.52361100E+03, 0.19950000E+04, 0.50150000E+04, -.67408100E+03, -.10693600E+04, 0.90777600E+03, 0.21973200E+04, 0.28917900E+04, -.12199700E+04, 0.32385400E+04, 0.38842400E+04, 0.23867600E+04, 0.27102100E+04, -.37554200E+04, 0.12553600E+04, 0.21783300E+04, 0.31359700E+04, -.15489500E+02, -.59633500E+01, 0.72035100E+01, 0.84919400E+01, -.18852000E+01, -.63497700E+01, -.13547000E+01, 0.94196000E+01, -.13136500E+02, -.60698900E+01, 0.62693800E+01, 0.74240100E+01, -.19093000E+01, -.57723000E+01, -.18997300E+01, 0.81695000E+01, 0.42540400E+04, -.30195000E+04, -.17413200E+04, -.16405500E+04, 0.80928200E+03, 0.15315900E+04, -.13925800E+04, -.19471800E+04, -.26629900E+03, 0.13304500E+04, 0.87027400E+02, 0.78936300E+02, -.40202900E+01, 0.40497500E+01, 0.25993200E+03, 0.62714700E+02, 0.10942300E+02, -.21762800E+02, -.79330100E+00, 0.45161400E+01, -.11256400E+02, -.51632800E+01, -.16583600E+02, 0.82909800E+01, 0.26000200E+04, -.40879100E+04, -.50582500E+03, -.85796500E+02, -.14988400E+04, -.40738100E+03, -.24049200E+04, 0.10191000E+03, -.67616200E-01, 0.10011100E+01, -.21577600E+00, -.14749500E+00, 0.17207900E+00, 0.43359700E+00, 0.15218800E+01, 0.11745300E+00, 0.12740100E+02, -.10079000E+02, -.44467600E+01, -.16208900E+01, -.51410400E+01, -.29304000E+00, -.93010000E+01, 0.72958100E+00, -.67640200E+02, -.13921900E+02, 0.85269800E+02, -.40616800E+02, -.13903100E+02, -.97963300E+02, 0.76937900E+02, 0.13958600E+02, 0.27707400E+01, -.13627700E+02, -.20524500E+03, 0.19293900E+03, 0.12877400E+04, -.51260600E+03, -.23005800E+02, -.25086600E+03, -.13091700E+03, -.23080800E+04, -.10738200E+02, -.11309100E+02, -.25484300E+03, 0.59981600E+02, -.14804800E+02, 0.11333500E+02, 0.13896300E+02, -.14380300E+02 }, { -.20343300E+01, -.24838100E+01, 0.13919800E+01, 0.47947300E+00, 0.14890600E+01, 0.15478000E+01, -.12165800E+01, -.44164900E+01, 0.32984500E-01, 0.13308200E+01, -.51782100E+00, -.15014500E+01, 0.53178100E+00, -.63400500E+00, -.28532400E+01, -.54233100E+01, -.32327000E+01, -.46276500E+01, -.36910100E+01, 0.16445800E+01, 0.24901800E+01, -.53527500E+00, -.32883700E+01, 0.38856800E+01, -.68722800E+00, 0.10318100E+01, -.17713200E+01, -.78068200E+00, 0.36475300E+01, 0.79556200E+00, 0.67319900E+01, -.14158600E+01, 0.33694100E-01, -.15987300E+01, 0.45110800E+01, -.45896300E+00, -.11117000E+03, -.63364500E+01, -.29417700E+03, -.56958900E+02, 0.29371200E+02, 0.26420000E+03, -.29478000E+02, -.69373200E+01, 0.72800700E+02, 0.50570200E+02, -.39151700E+02, -.13526400E+02, -.58723600E+00, -.82196100E+00, -.49118500E+00, -.24706400E+00, 0.75454700E+00, -.88800700E+00, -.10152200E+01, 0.36364100E+00, -.11080700E+03, -.14737600E+03, 0.66317000E+02, 0.44505500E+02, -.64787700E+02, -.86066400E+02, -.35811800E+02, 0.42369500E+02, 0.45347900E+01, 0.23040100E+00, -.96614000E+00, -.10221100E+01, -.61643900E+00, 0.76440200E+00, -.61973100E+00, -.13600200E+01, -.12595900E+04, 0.42510900E+04, 0.12145400E+04, 0.15968100E+04, -.98017600E+03, -.84758100E+03, -.60693600E+03, 0.20184600E+04, 0.13942200E+04, -.18938200E+04, 0.66229900E+03, 0.51349700E+03, -.93157800E+03, -.32488900E+03, -.10533700E+04, 0.55406700E+03, -.14095500E+04, 0.38481000E+03, 0.58494900E+03, -.25196500E+03, 0.36839000E+02, -.11159100E+04, -.13094200E+04, -.61580000E+03, -.10083700E+04, 0.14306200E+04, 0.94137100E+03, 0.90236800E+03, -.65020200E+03, -.66555300E+03, -.52947700E+03, 0.10978200E+04, 0.24820900E+03, -.18130400E+04, -.16501700E+02, 0.19151000E+02, 0.11854800E+03, -.50214800E+03, 0.25313800E+02, 0.13268100E+03, 0.28111000E+04, -.72666000E+03, -.54127400E-03, -.18903100E+02, -.10642900E+04, 0.21574800E+03, -.42120600E+03, 0.10388300E+03, -.17702200E+04, -.44396900E+03, 0.12947800E+04, 0.96802900E+03, -.86892900E+03, -.11728000E+04, -.92135700E+03, 0.10419100E+04, -.18235500E+04, -.30623200E+04, 0.27669000E+02, -.85153600E+03, 0.66168900E+03, -.11730500E+04, -.93832400E+03, -.10909300E+04, 0.86099500E+01, -.22406700E+00, -.15955300E+01, -.17007100E+01, -.14974900E+01, 0.13324200E+01, -.21205700E+01, -.23088900E+01, 0.73220500E+01, 0.11275500E+00, -.16627900E+01, -.16573500E+01, -.94616000E+00, 0.11949600E+01, -.15397700E+01, -.20888600E+01, 0.10419800E+03, 0.15540000E+04, 0.12436200E+03, 0.20776500E+02, -.13942600E+03, -.65673600E+03, 0.26063200E+03, 0.17787600E+03, -.42473500E+02, -.27262700E+03, -.22616000E+02, -.33048200E+02, 0.55401100E+02, -.15834000E+03, 0.18488600E+03, -.23984600E+02, 0.61457900E+01, 0.10026600E+02, -.38078000E+01, -.31046500E+01, 0.15578800E+01, 0.83580900E+01, 0.52870200E+01, -.60674200E+01, -.28158700E+04, 0.34882500E+04, -.24104700E+03, 0.28257100E+03, 0.90188000E+03, 0.11162000E+03, 0.11903000E+04, 0.23484300E+03, 0.28661200E+00, 0.19302200E+00, 0.40421900E+00, 0.19511300E+00, -.47888900E+00, 0.21682500E+00, -.93508200E+00, -.75229900E-01, 0.70374200E+00, 0.72613000E+01, -.13427600E+01, -.11143100E+01, 0.97361200E+00, 0.54662300E+01, 0.51098700E+01, -.31811800E+01, 0.37351700E+02, 0.22141800E+01, -.56193600E+02, 0.13898600E+03, 0.22538400E+01, 0.25291500E+02, -.14376800E+02, -.22996100E+01, 0.39320800E+01, 0.21872400E+01, 0.55771100E+03, 0.22760000E+03, -.32517200E+03, 0.22522900E+03, 0.31121200E+02, 0.19160100E+03, 0.28246300E+00, 0.11123500E+04, 0.19949300E+01, 0.18430600E+01, 0.43557600E+02, -.51801500E+02, 0.30381000E+01, 0.32475500E+02, -.22290700E+01, 0.24035200E+01 }, { -.72277300E+00, -.18770200E+00, 0.28231300E+00, 0.42397100E+00, 0.11520000E+00, -.97615100E+00, -.43150000E+01, -.10996700E+01, 0.13566700E+00, -.12885600E+00, 0.41995200E-01, 0.11647800E+01, 0.64939200E+00, 0.88820500E+00, -.15053500E+01, 0.33126100E+00, -.31752500E+00, 0.29756500E+00, -.88685200E+00, 0.11041200E+00, -.12990600E+00, 0.46401700E-01, -.13360200E+00, -.36254700E+00, 0.19800400E-01, 0.12520300E-01, -.63334000E+00, -.24881700E+00, -.21237100E+01, -.91871200E-01, -.40577900E+01, 0.37957700E+00, 0.38683900E+00, 0.17938900E+00, 0.34506700E+01, 0.36699900E+00, -.58480300E-01, -.62452500E+02, -.13679900E+03, -.25492400E+02, 0.29334700E+03, 0.14253500E+02, -.10456600E+03, -.11460500E+03, 0.76049800E+02, 0.81588200E+02, 0.37470800E+02, -.11223300E+03, -.12239600E+00, 0.76179400E+00, -.95577500E-01, 0.37950300E-03, -.25661200E+00, 0.26279800E+00, -.11175900E+01, 0.16663500E+00, -.17812100E+03, -.51518200E+01, 0.64178600E+02, 0.69327800E+02, -.31976900E+02, -.59668000E+02, -.42158800E+01, 0.69040200E+02, 0.10914500E+01, 0.77324000E+00, -.46534900E+00, -.66588300E+00, -.21852900E+00, 0.44349700E+00, 0.66844100E+00, -.90671200E+00, 0.10373300E+03, 0.10785300E+04, -.25123100E+03, -.20915100E+03, 0.49996300E+03, -.13105000E+02, 0.57545000E+03, -.86335100E+02, 0.11153800E+04, -.62886300E+03, 0.23485100E+03, 0.25766200E+03, -.35016100E+03, 0.20183400E+03, -.40054600E+03, 0.36116800E+03, -.54383000E+03, -.60080200E+03, -.69286200E+02, -.17666500E+03, 0.33955400E+03, -.74875800E+02, -.77543800E+03, -.41115300E+03, -.37836200E+03, 0.53669800E+03, 0.29091200E+03, 0.31958500E+03, 0.20828700E+02, -.34873500E+03, 0.37806400E+03, 0.46760400E+03, -.77031500E+03, -.58032500E+03, 0.27318800E+02, 0.11989800E+03, 0.27808900E+03, -.13524000E+03, 0.13373100E+03, 0.16678600E+03, 0.23394600E+04, 0.60508800E+03, -.26329900E+01, -.56203100E+02, -.40068800E+03, 0.93466100E+03, 0.21834700E+03, 0.14527800E+03, -.82447000E+03, -.45493700E+03, 0.38605400E+03, 0.41190100E+03, -.69360200E+02, -.48801100E+03, -.14553000E+03, 0.49810500E+03, 0.29239700E+03, -.17484100E+04, -.26973800E+02, -.16402000E+03, 0.20246000E+03, 0.10457500E+03, -.73172900E+03, -.10915000E+03, 0.20151800E+01, 0.12829100E+01, -.80216800E+00, -.11754800E+01, -.43179800E+00, 0.72212700E+00, 0.13158800E+00, -.15612800E+01, 0.17615200E+01, 0.13110700E+01, -.76448200E+00, -.10714000E+01, -.44221000E+00, 0.74330600E+00, 0.19713100E+00, -.14081200E+01, 0.27398200E+03, 0.39026200E+03, -.26484700E+03, -.31342700E+03, 0.29579800E+03, 0.48100800E+03, 0.54135700E+03, -.20667900E+03, -.79299200E+03, 0.22455900E+03, 0.97728500E+02, 0.12550400E+03, 0.13507900E+03, -.21070900E+03, 0.18491400E+03, 0.12551900E+03, 0.14074400E+01, -.15328000E+01, -.14827000E+01, -.18561000E+01, -.70720200E+00, 0.22554400E+00, -.50852800E+00, -.37048900E+01, -.29950400E+04, 0.14326200E+04, -.14935700E+02, 0.11343300E+03, 0.43418800E+03, -.86492100E+03, 0.70698400E+03, -.16341200E+03, 0.18806900E+00, -.39204400E+00, 0.30690400E-01, -.29019400E-01, 0.21413900E+00, -.12207100E+00, -.10206800E+01, -.79794300E-01, 0.24413900E+00, -.18902200E+01, -.44472200E+00, -.63557400E+00, -.19022900E-01, -.23872600E+00, 0.42625600E+00, -.17182200E+01, 0.89213500E+01, 0.22413400E+01, -.70386300E+02, 0.84835100E+02, 0.22668400E+01, 0.88906200E+01, 0.22867600E+02, -.23396100E+01, -.25888700E+01, 0.21868900E+01, 0.45917300E+03, 0.12878800E+03, -.32042100E+03, -.14452500E+03, 0.74046100E+02, 0.21056000E+03, -.29618000E+02, 0.36839200E+03, 0.16775900E+01, 0.17670600E+01, 0.17635700E+03, -.20394500E+02, 0.27052400E+01, 0.17205200E+03, -.22457700E+01, 0.24656000E+01 }, { 0.30291100E+00, 0.30107300E+00, -.72967000E+00, -.48435200E+00, -.32242200E-01, 0.20600700E+01, -.31513800E+01, -.13276400E+01, -.42031200E+00, 0.35010100E+00, -.35175300E-01, 0.54884100E+00, -.20403600E+00, 0.20255200E+00, -.52321700E+00, 0.11240900E+01, 0.29003600E+00, -.10061400E+01, -.68649500E+00, -.51698800E+00, 0.43723400E+00, 0.21209100E+00, 0.27425200E+00, -.42618000E+00, -.65381400E-01, -.24603300E+00, 0.20936600E+00, 0.14804300E+00, -.66627900E-01, -.12685700E+00, -.13262000E+01, 0.60556600E-02, 0.46846200E+00, 0.38202100E-02, 0.13502200E+01, -.12095500E+00, -.41443300E-01, -.40582000E+00, -.95663500E+02, -.10294600E+02, 0.85185900E+02, 0.15146400E+02, -.41782500E+02, -.43354400E+02, 0.38224000E+02, 0.38562100E+02, 0.52296900E+01, -.37727500E+02, -.14962300E+00, -.44824800E-01, -.21062300E+00, -.17734000E-01, 0.12478000E+00, -.11630400E+00, -.69932400E+00, 0.92626400E-01, -.76009800E+02, -.68582800E+01, 0.28562200E+02, 0.26144800E+02, -.11110600E+02, -.33092800E+02, -.93047300E+00, 0.22351200E+02, 0.32677500E+00, 0.23877800E-01, -.22140600E+00, -.12754900E+00, -.95947300E-01, -.12904000E+00, 0.27746400E+00, -.22125300E+00, -.35283100E+03, 0.12593100E+04, -.16684900E+02, -.26687700E+02, 0.16652000E+03, -.11753400E+03, 0.67992400E+02, -.16453400E+02, 0.38604000E+03, -.35320500E+03, 0.12144500E+03, 0.96700500E+02, -.10070300E+03, 0.51076200E+02, -.13837400E+03, 0.13542600E+03, -.42881600E+03, -.33487200E+03, -.10445400E+02, -.64408400E+02, 0.18513500E+03, -.15604700E+03, -.42694400E+03, -.16803500E+03, -.42276900E+02, 0.53406800E+03, 0.11685300E+03, 0.65943200E+02, 0.49521900E+02, -.62112900E+02, 0.39483500E+02, 0.11332000E+03, 0.28722400E+02, -.51957200E+03, -.70168800E+01, 0.22841700E+02, 0.39676200E+02, -.64488900E+02, 0.29625600E+01, 0.54606200E+02, 0.60594500E+03, 0.24229000E+03, 0.16890900E+03, 0.10785100E+03, -.26100600E+03, 0.16404700E+03, 0.14085300E+03, 0.16835400E+03, -.40248600E+03, -.95560800E+02, 0.14178000E+03, 0.11192900E+03, 0.25720800E+02, -.14922200E+03, -.12667400E+02, 0.12376200E+03, 0.37556800E+03, -.12745700E+04, -.13339400E+03, -.19937500E+03, 0.23039400E+03, 0.11205300E+03, -.19079600E+03, -.14659400E+03, 0.61962100E+00, 0.35622100E-02, -.39096500E+00, -.22093300E+00, -.19487100E+00, -.25343400E+00, -.20769100E+00, -.37833300E+00, 0.54766000E+00, 0.31513500E-01, -.40838500E+00, -.21998800E+00, -.15696800E+00, -.20407900E+00, -.10309600E+00, -.34642300E+00, 0.19592900E+02, 0.50918900E+03, -.11951400E+03, -.16437100E+03, 0.11539800E+03, -.25973000E+02, 0.23207700E+03, -.16296700E+03, -.17046500E+02, 0.11447600E+03, 0.77422800E+01, -.61130100E+01, 0.13385700E+02, -.39323600E+02, 0.65524100E+00, -.95638300E+01, 0.16084900E+01, -.17631400E+00, -.61058700E+00, -.64074300E+00, -.10099800E+01, 0.84664300E+00, 0.11518800E+00, -.13661500E+01, -.11333200E+04, 0.90205200E+03, 0.54464700E+02, 0.14125700E+03, -.27884600E+02, -.24483000E+03, 0.26231400E+03, 0.51278500E+02, 0.90219900E-01, 0.57628500E-02, 0.11692300E+00, 0.13228200E-01, -.26455200E-01, 0.39400400E-01, -.72630000E+00, -.28277700E-01, 0.79653100E+00, 0.10075500E+00, 0.27222800E-01, -.26466700E+00, -.63173900E+00, 0.75581000E+00, 0.65618500E+00, -.74010400E+00, 0.27258000E+01, 0.33358400E+00, -.45519300E+02, 0.20371300E+02, 0.37010900E+00, 0.28963800E+01, 0.51147100E+01, -.40854600E+00, 0.19188300E+01, 0.33948400E+00, 0.19398700E+03, 0.49956700E+02, -.17259800E+03, -.35553200E+02, 0.45670100E+02, 0.45583100E+02, -.37509300E+02, 0.20207000E+03, 0.24871400E+00, 0.23321900E+00, 0.53363100E+02, -.18272100E+02, 0.61827500E+00, 0.42446500E+02, -.34994700E+00, 0.46410600E+00 }, { 0.22815500E+01, 0.33171800E+01, -.13059900E+01, 0.94744300E+00, -.73218800E+00, -.23355500E+01, 0.18404000E+01, 0.23594300E+01, -.20101600E+01, 0.71564100E+00, 0.58384500E+00, 0.93695600E+00, 0.14119800E+01, -.51181000E+01, 0.17632900E+01, 0.62898900E+01, 0.43425800E+01, 0.52912300E+01, 0.25190300E+00, -.81120500E+00, -.20235700E+01, 0.92108500E+00, -.10574000E+01, 0.13205800E+01, 0.24052600E+00, 0.36296300E+00, 0.90416700E+00, 0.31935800E+00, -.34973500E+01, 0.12085100E+01, -.37737400E+00, -.90045400E-01, 0.13425400E+01, -.53158000E+00, 0.17737600E+00, -.12500700E+01, -.20993100E+00, 0.25045300E+01, -.94831700E+00, 0.63116800E+02, -.43517600E+03, -.63757400E+02, 0.12679100E+03, 0.13421700E+03, -.86435700E+01, -.10309900E+03, -.53033000E+02, 0.14542100E+03, -.17769100E+00, -.20135400E+01, 0.22800700E+00, 0.47635700E+00, 0.85963100E-01, -.58288000E+00, 0.14133200E+01, 0.21399900E-01, 0.23865800E+03, 0.53562400E+02, -.71829000E+02, -.77104000E+02, 0.47383200E+01, 0.54846400E+02, 0.19802300E+01, -.73129500E+02, -.17691400E+01, -.19707300E+01, 0.71210000E+00, 0.13952400E+01, 0.41736200E+00, -.80563900E+00, -.26030600E+01, 0.20035900E+01, -.11441000E+03, -.13548500E+04, 0.11889100E+04, 0.12357400E+04, -.16250100E+04, -.25864000E+03, -.11718400E+04, 0.11887200E+04, -.20428000E+04, 0.89880300E+03, -.30684300E+03, -.35290800E+03, 0.55570500E+03, -.56191400E+03, 0.31670100E+03, -.55194300E+03, -.86275800E+03, 0.80470500E+03, 0.40884500E+03, 0.49570500E+03, -.39038100E+03, -.63703400E+03, -.24405900E+03, 0.11099800E+04, 0.73317100E+03, -.10921500E+04, -.23708600E+03, -.34015900E+03, -.64002100E+02, 0.21493700E+03, -.51118800E+03, -.51102800E+03, 0.46162600E+04, 0.22432200E+03, -.78018700E+03, -.11095100E+04, -.40150800E+03, 0.17400500E+04, 0.75416500E+02, -.11559600E+04, -.81137300E+04, 0.22994600E+03, 0.12128300E+04, 0.15631500E+04, 0.14640100E+03, -.34081900E+04, -.80393200E+03, 0.10340000E+04, 0.11430800E+03, 0.37697600E+03, -.12130500E+03, -.14536600E+03, -.18918400E+03, 0.58400900E+02, 0.39960000E+02, -.27905400E+03, -.66095700E+03, 0.37110700E+04, -.92580100E+02, -.78403800E+02, -.95831500E+02, -.70985200E+03, -.70727200E+03, -.14395100E+03, -.29555600E+01, -.32280600E+01, 0.12572100E+01, 0.25303100E+01, 0.71737300E+00, -.13237800E+01, -.18850600E+01, 0.35356600E+01, -.25852800E+01, -.33374300E+01, 0.11295500E+01, 0.22725900E+01, 0.69523400E+00, -.12649400E+01, -.20480500E+01, 0.30938600E+01, 0.81032200E+03, -.65753900E+03, 0.70845600E+03, 0.70287900E+03, -.11994900E+04, -.50356000E+03, -.97381600E+03, 0.54053700E+03, 0.97067300E+03, -.31319600E+03, -.84562800E+02, -.15292200E+03, -.99324800E+02, 0.32158100E+03, 0.56331600E+02, -.12483100E+03, 0.86050400E+01, 0.88835800E+00, -.19854100E+01, -.24726300E+01, 0.26039900E+01, 0.57102300E+01, 0.29797200E+01, 0.10861200E+01, 0.58614600E+04, -.19147500E+04, -.54810000E+02, -.26507100E+03, -.84947200E+03, 0.23885600E+04, -.14505700E+03, 0.45260500E+03, -.31168300E+00, 0.95363500E+00, 0.35141100E-01, -.62830300E-01, -.18223700E+00, 0.13504800E+00, 0.29658000E+01, 0.15196200E+00, 0.52679200E+01, 0.36353300E+01, -.17080700E+01, -.26454500E+01, 0.11842400E+01, 0.38232000E+01, 0.20849800E+01, -.61204200E+00, -.12940900E+02, -.58901900E+01, -.19448900E+02, -.10017100E+03, -.59830900E+01, -.32603000E+01, -.39506500E+01, 0.61254400E+01, -.35096200E+01, -.57709100E+01, -.52798500E+03, -.17551900E+03, 0.97063100E+02, 0.20280900E+03, -.72473500E+02, -.50696400E+03, 0.49159900E+02, 0.56807800E+02, -.43321200E+01, -.45632500E+01, -.23313900E+03, 0.99283200E+02, -.73208000E+01, -.39125800E+03, 0.59201400E+01, -.63410700E+01 }, { 0.85703800E+00, 0.29743200E+00, -.15461000E+01, 0.13148400E+00, -.76558500E+00, -.32961600E+01, -.19706400E+01, 0.17789000E+01, -.16178500E+01, 0.38205500E+00, 0.58930300E+00, 0.42822800E+00, 0.90938800E+00, -.63443700E+01, 0.17674900E+01, 0.69652500E+01, 0.32360800E+01, 0.45214800E+00, -.16420400E+00, -.20990500E+01, 0.79409700E+00, 0.45855900E+00, -.83379700E+00, 0.10627300E+01, -.21684300E+00, 0.16715300E+00, 0.94905700E+00, 0.18063700E+00, 0.21045000E+01, 0.50862000E+00, 0.43282500E+01, -.24387400E+00, -.27833200E+00, -.41848100E+00, -.10007600E+01, -.41158000E-01, 0.16189100E+00, 0.14220600E+01, 0.16155100E+00, 0.15398900E+00, -.55959200E+03, 0.19266800E+03, 0.16233600E+03, 0.21529500E+03, -.18077000E+03, -.21342600E+03, -.11482800E+03, 0.20137900E+03, 0.80983800E+00, -.10081200E+01, -.69160800E-02, -.24721600E+00, 0.61786900E+00, 0.26684700E+00, 0.17622700E+01, -.46435800E+00, 0.40624100E+03, -.14682500E+03, -.12328100E+03, -.12832000E+03, 0.55490900E+02, 0.14262500E+03, -.96115300E+01, -.11935900E+03, -.39998400E+00, -.24159600E+00, -.26804000E+00, -.17487300E+00, 0.93805000E+00, 0.24301600E+00, -.78656600E+00, -.95084100E-02, -.11712100E+04, 0.25069300E+02, 0.78133400E+03, 0.11139900E+04, -.15596800E+04, -.42661600E+03, 0.86350900E+02, 0.10428300E+04, -.18280800E+04, 0.73934100E+03, -.75982300E+03, -.56660300E+03, 0.72564900E+03, -.32270300E+03, 0.46589200E+03, -.70594800E+03, -.42011400E+03, 0.52345200E+03, 0.71236200E+02, 0.21392700E+03, -.88630800E+02, -.59764100E+03, -.38616900E+03, 0.30174200E+03, 0.93969400E+03, -.94466400E+03, -.80457600E+03, -.54640500E+03, -.16284000E+03, 0.53203700E+03, -.55382900E+03, -.69122900E+03, 0.22394700E+04, -.51405400E+03, -.24561300E+03, -.50700600E+03, -.34289300E+03, 0.93832200E+03, -.54408100E+02, -.56196100E+03, -.14737200E+04, -.41297400E+03, -.58736700E+03, -.20622200E+03, 0.29160300E+03, -.61166100E+03, -.42615500E+03, -.39591100E+03, 0.97568600E+03, -.52268500E+03, -.94308300E+03, -.57840100E+03, 0.17902100E+03, 0.25257100E+03, -.61514100E+03, -.62828600E+03, -.14086000E+04, 0.16792200E+04, -.32611100E+03, -.44951300E+02, 0.43584700E+03, -.58624600E+03, -.31665200E+03, -.24925600E+03, -.99891000E+00, -.20320500E+00, -.76560300E+00, -.41873800E+00, 0.18051800E+01, 0.48702400E+00, 0.38380000E+00, -.13614000E+00, -.90834000E+00, -.28893700E+00, -.40334400E+00, -.24901500E+00, 0.16994800E+01, 0.34867800E+00, 0.32089100E+00, -.12988400E-01, -.17461100E+04, 0.65711800E+03, 0.75018200E+03, 0.10048100E+04, -.59235300E+03, -.80767400E+03, 0.12402600E+03, 0.95332100E+03, 0.13124100E+04, -.62744800E+03, -.17003500E+03, -.20171500E+03, -.21130500E+03, 0.36137000E+03, -.52181200E+03, -.19196100E+03, -.12628300E+02, 0.87490900E+01, 0.55350100E+01, 0.30688200E+01, 0.37828600E+01, -.35434600E+01, 0.44646700E+01, 0.49061400E+01, 0.44920800E+04, -.16200400E+04, 0.56350900E+03, -.17345000E+03, -.50762700E+03, 0.12631100E+04, -.10039700E+04, 0.14392900E+03, -.28227500E+00, 0.34925600E+00, -.17016100E+00, 0.47288800E-01, -.43500500E+00, -.64961000E-01, 0.13206100E+01, 0.10260700E+00, -.68629900E+01, 0.55866300E+01, 0.36554800E+01, 0.23833200E+01, 0.50849200E+00, -.24991400E+01, 0.11587100E+01, 0.35735100E+01, -.44256500E+01, 0.20070300E+00, 0.89927800E+02, -.24421800E+03, 0.14928400E+00, 0.69161300E+00, -.81440600E+02, -.45579000E-01, 0.55852600E+01, 0.20552200E+00, -.31811600E+03, -.40900600E+03, 0.15257300E+01, 0.15838800E+03, -.12116100E+03, -.29794200E+03, 0.91115900E+02, 0.19502800E+03, 0.14159900E+00, 0.22205800E+00, -.36417900E+02, 0.88065200E+02, 0.54997800E-02, -.25403600E+03, -.18336400E+00, 0.34028600E-01 }, { -.67946300E+00, -.75614900E-02, 0.82700500E-01, 0.59248800E+00, 0.11732700E+01, 0.19858500E+01, 0.13925500E+01, -.66099500E+00, -.29165000E+00, 0.29542700E+00, 0.10881500E+00, 0.75734100E-01, 0.74509900E+00, -.18964500E+01, 0.10225300E+01, 0.26058000E+01, 0.74347700E+00, -.43524700E+00, 0.54543800E-01, -.67160700E+00, 0.10402600E+01, -.79992900E-01, -.68557200E+00, 0.45840400E+00, -.72896300E-01, -.48977400E-02, -.11894600E+01, -.47066700E+00, -.75167000E+00, 0.11722900E+00, -.18531800E+01, 0.30191900E+00, 0.39346800E+00, -.15431400E+00, -.49219100E+00, -.44907500E-01, -.10430700E+00, -.28808200E+00, -.10631700E+01, -.17682400E+00, 0.40155400E-01, -.92195500E+02, -.25445200E+02, -.39434400E+02, 0.11751200E+03, 0.52581800E+02, 0.95347000E+02, -.24293300E+02, -.56016400E+00, -.48781500E+00, -.15201100E+00, 0.25172500E+00, -.99426700E-01, -.18216700E+00, -.87170800E+00, 0.25828600E+00, -.90551800E+02, 0.76494800E+02, 0.35677400E+02, 0.39302600E+02, -.41631700E+02, -.54068100E+02, -.90615800E+01, 0.30670700E+02, -.10090600E+00, -.74226800E+00, 0.37464700E+00, 0.80127700E+00, -.68895500E+00, -.47413800E+00, -.46851700E-01, 0.81005200E+00, 0.73160100E+03, 0.74954300E+03, -.30805200E+03, -.35170600E+03, 0.48205500E+03, 0.27221700E+03, -.51166600E+03, -.33241200E+03, 0.40672200E+03, -.54444400E+03, 0.23918300E+03, 0.21275700E+03, -.20365200E+03, 0.39324700E+02, -.78915200E+02, 0.24134200E+03, 0.40159400E+03, 0.24002700E+03, 0.89399600E+02, -.16559800E+02, -.35648300E+03, 0.30149200E+03, 0.51355800E+02, -.77803400E+01, -.89142300E+02, 0.74658800E+03, 0.16443700E+03, 0.84656100E+02, 0.94886000E+02, -.15607100E+03, 0.25258100E+03, 0.10505600E+03, -.14163000E+03, 0.21289700E+03, -.69085400E+02, -.11605800E+02, 0.12880900E+03, -.17602800E+03, 0.69442900E+02, 0.50894200E+01, -.13392500E+04, -.36100900E+03, 0.32223800E+03, 0.31125900E+03, 0.36711500E+03, -.44432000E+03, 0.34625000E+03, 0.34124700E+03, -.43580300E+03, 0.78142900E+03, 0.28059400E+03, 0.20220000E+03, -.98496000E+02, -.11801800E+02, 0.40766400E+03, 0.17462200E+03, 0.10047100E+04, -.10242200E+04, 0.70604200E+02, -.42291700E+02, -.40850200E+03, 0.13923700E+03, 0.18329800E+03, 0.33715500E+02, -.63473400E-01, -.14732000E+01, 0.75136100E+00, 0.15450600E+01, -.12905700E+01, -.89433900E+00, -.73690600E+00, 0.15560000E+01, -.16882900E-01, -.13889400E+01, 0.53040100E+00, 0.12779800E+01, -.11431000E+01, -.73137800E+00, -.70479400E+00, 0.12848800E+01, 0.17098100E+04, -.28853000E+03, -.34189000E+03, -.49969000E+03, -.53963000E+02, 0.30182900E+03, -.50716200E+03, -.49620700E+03, -.47998600E+03, 0.58898900E+03, 0.85200200E+02, 0.79561400E+02, 0.73211000E+02, -.16808900E+03, 0.24466700E+03, 0.67686900E+02, 0.70083600E+01, -.18596500E+01, -.15805200E+01, -.22899500E+01, -.22772300E+01, 0.21523300E+01, -.20951800E+01, -.24896000E+01, -.71933500E+03, 0.11809300E+04, -.92594700E+02, 0.21113100E+02, -.11343400E+03, 0.33683900E+02, 0.32137500E+03, -.11952600E+02, 0.16008600E+00, 0.26783600E+00, 0.15383200E+00, -.26725000E-01, 0.72769600E-01, 0.25988400E-01, -.37639700E+00, -.14497000E-01, 0.42573600E+01, 0.16265500E+00, -.10338200E+01, -.21593400E+01, -.57289900E+00, 0.17639800E+01, -.27230200E+00, -.22924400E+01, -.18163000E+00, -.25467700E+01, -.75259000E+02, 0.62871700E+02, -.25112000E+01, -.51746400E+01, 0.41434700E+02, 0.24770500E+01, -.45411700E+01, -.24849200E+01, 0.13704400E+03, 0.17157400E+03, 0.10788600E+03, -.11264800E+03, 0.64056200E+02, 0.11870300E+03, 0.72945400E+00, -.47958400E+02, -.18483300E+01, -.20505800E+01, -.73498700E+02, 0.77474000E+00, -.24288200E+01, 0.50658300E+02, 0.25284000E+01, -.24647800E+01 }, { 0.63960400E-01, -.35695900E-01, 0.33426100E+00, 0.33364300E+00, 0.13949200E+00, -.13211200E+01, 0.39114300E+00, -.18707000E+00, 0.14955200E+00, -.13806700E+00, 0.10245400E-02, 0.14441500E+00, 0.11199000E+00, -.47336700E-01, -.31001900E+00, 0.50402800E-01, 0.21403800E+00, -.22430500E+00, 0.38048100E-01, -.22205800E+00, 0.16403700E+00, 0.22630800E-01, 0.38475800E-01, 0.99089800E-01, 0.12631600E-01, 0.23092600E-01, 0.15049400E+00, 0.50560500E-01, -.14022200E+00, -.26445400E-01, -.19555700E+00, 0.19915000E-01, -.12357300E-01, 0.77664200E-01, 0.20058900E+01, -.21667100E-01, -.18232000E-01, -.77914600E-01, -.19298600E-02, -.68710300E-03, -.35800100E-03, 0.21516000E-01, -.87250800E+01, -.15172400E+02, 0.15401300E+02, 0.59674500E+01, 0.23874100E+02, -.13868700E+02, 0.52567900E-02, 0.82758900E-01, -.27511900E-01, 0.15498600E-01, -.76487900E-01, 0.12397100E-01, -.68383800E+00, 0.21752100E-01, -.54777900E+01, 0.25751600E+01, 0.48236700E+01, 0.86185500E+01, -.50622400E+01, -.63860200E+01, -.10279100E+02, 0.80879800E+01, 0.53965100E-01, 0.65225400E-01, -.80282200E-01, -.65743400E-01, -.21316200E-01, -.24241400E-01, 0.39255600E+00, -.76598900E-01, 0.68675000E+02, 0.45337500E+02, -.34986300E+02, -.26648400E+02, 0.21730100E+02, 0.34307100E+02, 0.10698000E+03, -.21425100E+02, 0.16138800E+03, -.68135100E+02, 0.46549300E+02, 0.51123400E+02, -.64003700E+02, 0.24055800E+01, -.78761700E+02, 0.56260700E+02, -.38287700E+02, -.36335600E+02, -.19282900E+02, -.17410100E+02, 0.38028300E+02, 0.77077200E+01, -.90040300E+02, -.38248500E+02, 0.75251500E+00, 0.20437200E+02, 0.12096300E+02, 0.18361500E+02, 0.68547300E+01, -.27864800E+02, 0.36012800E+02, 0.24393300E+02, 0.12440000E+03, -.16261700E+03, -.18265700E+02, -.99291200E+01, -.14006900E+02, 0.28066600E+02, -.16657700E+02, -.74001800E+01, 0.14330800E+03, 0.72136500E+02, 0.26752200E+02, 0.15424100E+02, -.25321000E+02, -.26896400E+01, -.35961200E+02, 0.27062200E+02, 0.53678900E-01, -.54774500E+02, -.20732800E+02, -.70560900E+01, 0.37805500E+02, -.31309800E+02, -.43866500E+02, -.67167100E+01, -.13090000E+03, -.34550700E+02, -.25482700E+02, -.32860600E+02, 0.70435200E+02, -.50816900E+02, -.57628900E+02, -.36250000E+02, 0.90642400E-01, 0.12467400E+00, -.16080000E+00, -.12801100E+00, -.27849800E-01, -.69430500E-01, 0.15265200E+00, -.14329800E+00, 0.83985000E-01, 0.12135300E+00, -.14279600E+00, -.11338900E+00, -.39590700E-01, -.40396200E-01, 0.16532800E+00, -.12673200E+00, 0.66054600E+01, 0.20745800E+02, -.61008800E+02, -.69913400E+02, 0.57786400E+02, 0.21570600E+02, 0.99786700E+02, -.68661300E+02, -.38338900E+02, 0.21649800E+02, 0.10822100E+01, 0.24234800E+01, 0.87765500E+01, -.18868600E+02, 0.53136500E+01, -.55874500E+00, 0.60399800E+00, -.58841600E+00, -.12555300E+00, -.36017600E+00, 0.23226100E-01, 0.42869300E+00, 0.10685100E+01, -.41111100E+00, -.61983600E+02, 0.18868500E+02, -.53342100E+02, -.47044300E+02, 0.41261300E+02, 0.62175900E+02, 0.10207000E+03, -.53714200E+02, 0.91791400E-02, -.41380300E-01, 0.85126000E-02, -.55523900E-02, 0.37103000E-01, -.14864600E-01, -.46726900E+00, -.89712100E-02, 0.22853400E+00, -.40517800E+00, 0.37507200E-01, -.15866100E+00, 0.11936900E+00, 0.26481600E+00, 0.10479000E+01, -.18976000E+00, 0.44708300E+00, 0.25903400E+00, -.63772200E+01, 0.14996000E+02, 0.28299700E+00, -.82970100E+00, 0.57081800E+01, -.31371400E+00, -.16045600E+01, 0.25984600E+00, 0.45861700E+02, 0.12785900E+02, -.33439600E+02, -.14043600E+02, 0.50640800E+01, 0.12187100E+02, -.27454800E+01, 0.48033100E+02, 0.17718600E+00, 0.18597700E+00, 0.15566600E+02, -.12361300E+02, 0.38614700E+00, 0.35810600E+01, -.26905900E+00, 0.35829300E+00 }, { 0.90086900E+00, -.71646300E-01, -.20110100E+00, -.23123300E+00, -.45358000E+00, -.24955500E+01, -.44251000E+01, 0.29000000E+00, 0.51258400E-01, -.38803400E-01, -.30801900E-01, 0.54842100E-01, -.36520400E-01, -.30394200E+00, -.22385500E+00, -.20279100E+00, 0.49243700E+00, 0.56214900E-01, 0.23364000E+00, 0.10383200E+00, -.55382400E+00, 0.20938500E+00, 0.10497600E+01, -.45339800E+00, 0.59373000E-01, 0.22102300E-02, 0.10104600E+01, 0.35633600E+00, 0.45757800E+00, 0.71603500E-02, 0.32375000E+01, -.19216300E-01, -.52175800E+00, 0.24446600E+00, 0.20629200E+01, 0.65309300E-01, -.84004000E-02, 0.38962300E+00, 0.56018700E+00, 0.10511900E+00, -.78305900E-02, -.28269900E+00, -.46760200E+01, -.25967500E+02, -.52569900E+01, 0.15641900E+02, 0.71406700E+02, -.24075100E+02, 0.46991900E+00, 0.88584600E-02, -.15610800E+00, -.71032900E-01, -.31896100E+00, 0.38797400E+00, -.31153500E+01, -.15365900E+00, 0.21860900E+02, -.99562800E+01, -.16449500E+02, -.49502400E+00, 0.20528700E+02, -.51671200E+01, -.52324000E+02, -.68615500E+00, 0.46367400E+00, 0.35519200E+00, -.39272600E+00, -.42964100E+00, 0.10592300E+00, 0.18141500E+00, 0.23892600E+01, -.43684800E+00, 0.10975100E+03, -.21224800E+03, 0.58514100E+02, 0.10377900E+03, -.27165200E+03, 0.16489100E+03, 0.51742800E+03, 0.97386400E+02, 0.45388600E+02, -.15615900E+03, 0.16317400E+02, 0.57230900E+02, 0.59330900E+02, -.89691800E+02, -.20027200E+03, 0.44349400E+02, -.14390600E+03, -.30107600E+02, -.40175200E+03, -.37120100E+03, 0.57309000E+03, 0.11873000E+03, -.13093100E+02, -.47602800E+03, 0.33340300E+03, -.47128100E+03, -.21060800E+03, -.16418300E+03, 0.14089100E+03, 0.53524800E+02, -.16356600E+03, -.17389500E+03, 0.10756300E+04, -.88496100E+03, -.15142300E+03, -.15623000E+03, -.21788600E+03, 0.35793900E+03, -.16309900E+03, -.17423700E+03, 0.70887700E+03, 0.22719700E+02, -.52758300E+02, -.76397300E+02, 0.74179400E+02, 0.50296800E+02, -.40141900E+03, -.45018500E+02, 0.82084300E+03, -.77054400E+03, -.62770400E+03, -.57159800E+03, 0.66000100E+03, 0.22209100E+03, -.39829900E+03, -.56865100E+03, -.86737000E+03, 0.30644200E+03, -.33989400E+03, -.31065000E+03, 0.64033100E+03, -.24301600E+03, 0.38735600E+02, -.40879400E+03, 0.66336600E+00, 0.72422300E+00, -.79061200E+00, -.82804200E+00, 0.31481800E+00, 0.19774200E+00, 0.15022700E+01, -.81568000E+00, 0.57740800E+00, 0.68081800E+00, -.63541800E+00, -.68203800E+00, 0.18224000E+00, 0.25546600E+00, 0.15798000E+01, -.68356500E+00, -.74150500E+03, 0.20839100E+03, 0.63195800E+01, 0.32507100E+02, 0.15826500E+03, -.16393400E+03, 0.51035700E+03, 0.31239800E+02, 0.40164700E+03, -.11909600E+03, -.85487100E+02, -.82141800E+02, -.52216100E+02, 0.85563600E+02, -.22955400E+03, -.89829200E+02, -.24889900E+01, 0.11986600E+01, 0.12254900E+01, 0.18753700E+00, 0.64907100E+00, -.51250900E+00, 0.81788000E+01, 0.56663700E+00, 0.14704700E+04, -.39330600E+03, -.30675700E+03, -.39070300E+03, -.13045000E+03, 0.71445600E+03, 0.14112400E+03, -.36698200E+03, -.27020800E-01, -.11140100E+00, -.17756300E-01, -.26589400E-01, 0.13491100E+00, -.14796400E+00, -.25012200E+01, -.73654700E-02, -.24576400E+01, 0.64724100E+00, 0.13096400E+01, 0.63419800E+00, 0.58664200E+00, -.80028400E+00, 0.61941500E+01, 0.93947600E+00, 0.30638600E+01, 0.18538500E+01, 0.15178300E+02, -.34669900E+01, 0.19903200E+01, -.30597100E+00, 0.58928800E+01, -.21270900E+01, -.31777200E+01, 0.18637100E+01, 0.31154800E+02, -.74587800E+02, -.13603700E+03, 0.11748400E+01, -.17137400E+02, 0.12596200E+03, -.85811400E+02, 0.19310500E+03, 0.13236500E+01, 0.13861900E+01, 0.60717500E+02, -.63886600E+02, 0.26529900E+01, -.41486000E+02, -.19157600E+01, 0.23783900E+01 }, { 0.78385600E+00, 0.22568000E+00, -.13010400E+01, -.25352600E+00, -.60251100E+00, -.11875900E+01, -.19629900E+01, 0.99003600E+00, -.32319000E+00, 0.10350800E+01, -.16354600E+00, -.13518800E+01, 0.65974100E+00, -.71907600E+01, 0.18759600E+01, 0.34412800E+01, 0.18181100E+01, 0.13999200E+01, -.13158000E+00, -.13757800E+00, 0.38046100E+00, -.17761300E+00, -.72705400E+00, -.10012800E+01, 0.20490600E-01, -.41517800E+00, -.61991100E+00, -.98930700E-02, -.29072300E+01, -.46088800E+00, -.64027300E+01, 0.39148800E-01, -.46353900E-01, 0.79284300E+00, -.83656400E+01, 0.51599600E+00, -.13804500E+00, 0.48259400E+00, -.95406800E-02, -.25023200E+00, 0.50993600E-01, -.14672600E+01, 0.47390600E+01, -.89144100E+00, 0.93688000E+02, 0.83282600E+02, 0.10224600E+03, 0.67753600E+01, -.44825200E+00, -.13601600E+01, -.66296200E-01, 0.21109000E+00, -.28283200E+00, -.21456100E+00, 0.16871200E+01, 0.22487500E+00, -.58640700E+02, 0.91643600E+01, 0.22666000E+02, 0.19724000E+02, -.44320300E+02, -.67711600E+02, -.40205900E+02, 0.15573300E+02, 0.20884400E+01, -.83417500E+00, 0.29449600E+00, 0.58015000E+00, -.92172800E+00, 0.30111600E+00, -.22065300E+01, 0.65703100E+00, -.58486700E+02, 0.47107500E+03, 0.58495800E+03, 0.76386700E+03, -.49986500E+03, -.26332200E+03, -.13672800E+04, 0.94217000E+03, 0.53180800E+02, -.10076800E+04, 0.19256500E+03, 0.27103300E+03, -.24540100E+03, -.25771300E+03, -.34088800E+03, 0.24874100E+03, 0.37064700E+03, 0.55899600E+03, -.19056400E+03, -.39187700E+03, -.16160400E+03, 0.28908900E+03, 0.37663100E+03, -.38184300E+03, -.52322300E+03, 0.55849100E+02, 0.38146200E+03, 0.37288200E+03, -.17788700E+03, -.47613100E+03, -.35028600E+03, 0.39904400E+03, 0.78352300E+03, -.10297300E+03, -.23805000E+03, -.21508900E+03, -.29057600E+02, 0.52290800E+01, 0.23023600E+02, -.20784600E+03, -.18730900E+04, -.11124300E+04, 0.34806500E+03, 0.39878500E+03, 0.45903600E+03, -.91027700E+03, -.17602300E+03, 0.38373000E+03, -.34745400E+03, 0.49488200E+02, 0.29579500E+03, 0.21399100E+03, -.21034600E+03, -.13175300E+03, 0.53694600E+02, 0.18019300E+03, -.17258100E+03, -.46445400E+03, -.77205600E+02, -.42031600E+03, -.22055700E+02, -.43597200E+03, 0.24200900E+03, -.54771200E+03, 0.40881300E+01, -.18630600E+01, 0.73080800E+00, 0.12543300E+01, -.18598300E+01, 0.50458600E+00, -.22232700E+01, 0.13740900E+01, 0.34700100E+01, -.16837900E+01, 0.49269400E+00, 0.98949400E+00, -.15663900E+01, 0.48519400E+00, -.20689300E+01, 0.10998300E+01, 0.14162800E+04, -.53932100E+03, 0.93547800E+02, -.93007000E+02, -.45054100E+03, -.18851600E+03, -.90554300E+03, -.52034600E+02, -.20578400E+03, 0.33337100E+03, 0.48634500E+02, 0.31058800E+02, 0.40146600E+02, -.11762700E+03, 0.21672000E+03, 0.29698700E+02, 0.82020000E+01, 0.55714300E+01, -.30766700E+01, -.35653700E+01, 0.62170100E+00, 0.46030500E+01, -.11852700E+01, -.35927700E+01, 0.80836000E+03, 0.16133100E+04, -.35334000E+03, -.26729800E+03, -.34165600E+02, 0.90405400E+03, 0.58267200E+03, -.14668600E+03, 0.14638000E+00, 0.49846400E+00, 0.14267500E+00, 0.12921100E-01, 0.61560300E-01, 0.11257800E-01, 0.19130800E+01, 0.15560600E-01, 0.28217900E+01, 0.56882100E+01, -.19646800E+01, -.27365200E+01, 0.16189500E+01, 0.25623800E+01, -.62072000E+00, -.28078700E+01, 0.17764000E+02, -.27189800E+01, -.53794000E+02, 0.84642400E+02, -.28015200E+01, -.10517900E+01, 0.29122000E+02, 0.29031500E+01, -.34467000E+01, -.26841300E+01, -.96886300E+02, 0.16211100E+03, 0.16635800E+03, 0.71522300E+02, 0.25427400E+02, 0.26077200E+03, 0.29958500E+02, 0.17894000E+03, -.17071500E+01, -.19908100E+01, -.19417000E+03, -.23494000E+02, -.31781800E+01, -.12359400E+02, 0.27509800E+01, -.30236500E+01 }, { 0.33477700E+00, 0.74365800E-01, 0.60733500E+00, 0.68340600E+00, 0.40938800E+00, -.17191600E+01, -.10850700E+01, -.12001000E+01, 0.80575600E-01, -.18806500E-01, -.85458600E-02, 0.92048000E+00, -.22074300E-01, -.57877500E-01, -.21534200E+00, -.65304000E-01, -.11992600E+00, 0.48884800E+00, 0.34719000E-01, -.74231100E-02, 0.15371500E+00, -.49695700E-01, -.32787800E+00, 0.22894400E+00, 0.32915000E-01, 0.10273400E+00, 0.48460300E-01, 0.39604100E-02, -.11167900E+01, -.11117900E+00, -.91915700E+00, -.95141000E-01, 0.93446700E-01, 0.13013100E-01, 0.65381500E+00, -.11534000E+00, -.39473900E-01, -.34811500E+00, 0.26823400E-01, -.15179900E+00, -.27288000E+00, 0.50992400E-01, 0.18148400E+01, -.37052600E+00, -.13852300E-01, 0.21612200E+02, 0.12996700E+01, -.48938000E+00, 0.22330500E+00, -.29833100E+00, 0.10077700E+00, 0.14541300E-01, -.15982700E+00, -.10642900E+00, 0.27351100E+00, -.44593600E-01, 0.36001800E+02, -.90498600E+01, -.13963200E+02, -.91108800E+01, 0.58376200E+01, 0.15765100E+01, -.71772700E+01, -.55740800E+01, 0.17314500E+00, -.12331500E-01, -.80284300E-01, -.87995200E-01, 0.14123000E+00, 0.11669700E-01, -.36326500E+00, -.29730300E-01, 0.49549800E+03, -.69130800E+03, 0.53772300E+02, 0.12159400E+03, -.23420800E+03, 0.25810700E+03, 0.13980000E+03, 0.18515200E+03, -.20925900E+03, 0.37518400E+02, -.11918900E+03, -.35625700E+02, 0.83940200E+02, -.11195700E+03, -.32425300E+02, -.66698600E+02, -.14251200E+03, 0.25176800E+02, -.13618800E+02, -.43043800E+02, 0.74066900E+02, -.85355600E+02, 0.41427600E+02, 0.25347100E+02, 0.31246700E+03, -.49762900E+03, -.20156300E+03, -.13978200E+03, 0.10765400E+03, 0.16406300E+03, -.64225800E+00, -.12976000E+03, 0.89336500E+03, -.18795600E+03, -.39039900E+02, -.94153200E+02, -.25201500E+03, 0.21276000E+03, -.17597600E+03, -.95744700E+02, -.73008300E+03, 0.16692600E+02, 0.56317900E+02, 0.20595300E+03, -.48415100E+02, -.48954300E+03, -.31135300E+03, 0.12913500E+03, 0.17227700E+03, -.35197500E+03, -.19158600E+03, -.99701700E+02, 0.15074600E+03, 0.41214600E+02, -.27641900E+02, -.74624000E+02, -.55445400E+03, 0.75465300E+03, -.29811300E+02, -.56898100E+02, 0.47242400E+02, -.32818900E+03, -.21679500E+03, -.13179800E+03, 0.26978900E+00, 0.45725600E-01, -.20925100E+00, -.17397800E+00, 0.30994600E+00, 0.29733500E-02, -.21891700E+00, -.75134200E-01, 0.22285100E+00, 0.84056600E-02, -.11618800E+00, -.12932100E+00, 0.23550200E+00, -.24846500E-01, -.23007400E+00, -.53823800E-01, 0.28873400E+03, -.25236500E+03, 0.56601200E+02, 0.57664200E+02, -.14339200E+03, -.97700200E+01, 0.20254700E+02, 0.66585200E+02, 0.12101700E+03, -.16716200E+03, -.54127600E+01, -.12753500E+02, -.14676900E+02, 0.18174300E+02, -.46307600E+01, 0.16778700E-01, -.14714600E+01, 0.21294500E+01, 0.62362000E+00, 0.51376100E-01, 0.84351800E+00, 0.52408300E+00, 0.87261900E+00, 0.36656900E+00, 0.83971300E+03, -.25798200E+03, 0.13064000E+03, -.52914000E+02, -.14829700E+03, 0.47761000E+03, 0.14017600E+03, 0.70692900E+02, -.43332000E-01, 0.66172400E-01, -.76073600E-01, -.14207200E-01, 0.49500800E-01, 0.66358800E-01, 0.45244100E+00, 0.15898400E-01, -.12685400E+01, 0.15371800E+01, 0.36093200E+00, 0.10739800E+00, 0.53330900E+00, 0.35046000E+00, 0.49166100E+00, 0.29995400E+00, 0.12000600E+01, 0.39497300E-01, 0.24324000E+02, -.14253400E+02, 0.25016300E-01, -.32623500E-01, 0.28448900E+00, 0.14532500E-02, -.12883700E+01, 0.40359900E-01, 0.31866900E+02, -.55825700E+02, -.78681900E+01, -.12455700E+02, -.18622000E+02, -.48994800E+02, 0.13627100E+01, 0.10976100E+03, 0.46803100E-01, 0.64922400E-01, -.89874300E+01, 0.19867700E+02, -.36504200E-01, -.74995000E+02, -.35223600E-01, -.22022300E-01 }, { -.10962000E+01, -.47063900E+00, 0.19926800E+01, -.23249800E+00, 0.42441900E+00, 0.37744500E+01, 0.31276700E+01, -.18066900E+01, 0.57336100E+00, -.12360800E+01, 0.46155900E-01, 0.97191300E+00, -.13640600E+01, 0.79660400E+01, -.16159800E+01, -.43838400E+01, -.23088600E+01, -.20393300E+01, -.30166500E+00, 0.79663000E+00, -.27568500E+00, 0.13521100E-01, 0.78985600E+00, 0.37220500E+00, -.10611500E-02, 0.25544900E-01, -.23019400E+00, -.12541400E+00, 0.99311900E+00, 0.17854100E-01, 0.51444800E+00, 0.20600800E+00, -.47903800E+00, -.99277300E-01, -.38055500E+01, 0.64391400E+00, -.34023700E+00, -.16613900E+00, 0.10399200E+01, -.29004100E+00, 0.32161200E+00, -.99392700E+00, 0.21594000E+01, 0.58983400E+00, 0.12912700E+01, -.37114700E+01, -.16574500E+03, -.11390400E+02, 0.54883200E+00, 0.29286300E+00, 0.39346400E+00, -.49181600E-01, 0.77500800E-01, -.53176700E+00, 0.20315400E+01, -.59018500E-01, 0.12295800E+03, -.20886500E+02, -.28343000E+02, -.19365000E+02, -.10789700E+02, 0.34911200E+02, 0.38266200E+02, -.11336500E+01, -.10345400E+00, 0.62884300E+00, -.56431900E+00, -.77968700E+00, 0.11687000E+01, 0.10528000E+00, -.15133800E+01, -.61062200E+00, 0.15793800E+04, -.20385900E+04, 0.53092100E+03, 0.68156900E+03, -.10959700E+04, 0.49030800E+03, -.11188400E+03, 0.95115800E+03, -.44762100E+03, 0.64742400E+03, -.23313400E+03, -.16928600E+03, 0.65871700E+02, -.34175200E+03, -.19231100E+03, -.28135300E+03, -.10635700E+04, 0.32452100E+03, 0.62751000E+03, 0.35108100E+03, -.21170600E+01, -.85760600E+03, -.44135600E+03, 0.67997200E+03, 0.59769400E+03, -.14411900E+04, -.33260800E+03, -.20475600E+03, 0.54351100E+02, 0.26563600E+03, -.13224000E+03, -.14523900E+03, 0.27597600E+04, -.24527000E+03, -.74473500E+02, -.30797800E+03, -.56364400E+03, 0.78885300E+03, -.39214800E+03, -.23980400E+03, -.20820600E+04, 0.10046400E+04, 0.16873200E+03, 0.70624500E+03, -.98063500E+03, -.15483600E+04, -.12020000E+04, 0.32193600E+03, -.72931700E+03, -.51080500E+03, 0.29831200E+03, 0.43910100E+03, -.35205400E+03, -.57914800E+03, -.38152300E+03, 0.53265500E+03, -.19996600E+04, 0.29554700E+04, -.40106500E+02, -.22380800E+03, 0.24450000E+03, -.11619900E+04, -.11131800E+04, -.42758400E+03, -.27611100E+00, 0.14067000E+01, -.12656900E+01, -.15623500E+01, 0.22055000E+01, 0.19132200E+00, -.31112700E+00, -.13104700E+01, -.27147600E+00, 0.12462400E+01, -.90603600E+00, -.12679500E+01, 0.19366600E+01, 0.50528400E-01, -.47639000E+00, -.10571900E+01, 0.92632000E+03, -.65061800E+03, 0.41931500E+03, 0.54093000E+03, -.87902000E+03, -.13899400E+03, -.38309100E+03, 0.58329200E+03, 0.22889700E+03, -.98780500E+03, 0.40972500E+01, -.78408200E+01, 0.55070700E+00, 0.99365300E+02, 0.25420700E+03, 0.59607600E+02, -.36464400E+01, 0.21680700E+01, 0.14578500E+01, 0.10322700E+01, 0.27223200E+01, 0.28729300E+01, 0.73608200E+00, 0.14600200E+01, 0.11892700E+04, -.12895600E+04, 0.83956700E+03, 0.48518100E+03, -.20566900E+03, 0.10409100E+04, 0.75648400E+03, 0.98817800E+03, -.22480400E+00, -.22838900E+00, -.21003500E+00, -.28852000E-03, -.83557500E-01, 0.23435200E+00, 0.22268900E+01, 0.35951700E-01, -.26465000E+01, 0.27425800E+00, 0.79199600E+00, 0.12121600E+01, 0.60021200E+00, 0.19527700E+01, -.53782600E+00, 0.12950300E+01, -.11709700E+01, 0.17962300E+01, 0.65105600E+02, -.35019600E+02, 0.16707200E+01, 0.19297900E+01, -.24237100E+01, -.15588600E+01, -.87611900E+01, 0.17217700E+01, -.64701700E+02, -.19426400E+03, -.11247400E+03, 0.70298200E+02, -.51637900E+02, -.52095300E+03, 0.48571100E+02, 0.40117000E+03, 0.12789800E+01, 0.15357100E+01, -.10632500E+03, 0.14172800E+03, 0.11933400E+01, -.33624100E+03, -.17364800E+01, 0.14071700E+01 }, { 0.14787700E+00, 0.61864400E-01, -.33222000E+00, -.48549500E+00, -.41930600E+00, -.72975900E+00, -.52004700E-01, 0.11914100E+01, -.35120800E-01, 0.87705000E-01, -.72868900E-02, -.39459800E-01, 0.13187000E+00, -.55224300E+00, 0.14216400E+00, 0.32017600E+00, 0.26790100E+00, -.94273700E-01, 0.62534200E-01, -.99824200E-01, 0.15482400E-02, 0.68155700E-01, 0.19075700E+00, 0.10757900E+00, 0.19836000E-01, -.86714000E-03, -.37062400E-01, -.27980300E-01, 0.51385100E+00, 0.51013500E-02, 0.37533600E+00, -.38606000E-01, -.73712600E-01, 0.34167900E-01, 0.57572300E+00, 0.84600300E-02, 0.66093700E-02, -.37102600E-01, -.99401800E-02, 0.43760100E-01, 0.12384800E+00, 0.14299300E+00, -.33590000E+00, 0.78848600E-02, -.98318400E-01, -.97515600E-01, -.29366200E-01, -.48283700E+01, 0.20283100E-01, 0.13873000E+00, -.58358600E-02, -.62486100E-01, -.21717900E-01, 0.47881900E-01, -.29245900E+00, -.21940100E-01, -.43843200E+01, 0.22912000E+01, 0.14128000E+01, -.50244300E-01, -.10655500E+00, -.38048800E+01, -.72000300E+01, 0.10254600E+01, 0.87491000E-01, 0.92962300E-01, 0.47789600E-02, -.87954600E-01, 0.22375300E-02, 0.37454600E-01, 0.27772400E+00, -.76450200E-01, -.57079600E+02, 0.19158800E+02, 0.14119000E+03, 0.14120700E+03, -.14443200E+03, -.68648400E+02, -.17488200E+03, 0.15453200E+03, -.15332000E+02, 0.23790800E+02, 0.33555500E+02, 0.36205300E+02, -.29211500E+02, -.63844400E+02, -.92731300E+02, 0.12237600E+02, 0.63177300E+02, 0.27753000E+02, -.65092700E+02, -.82681500E+02, 0.60123500E+02, 0.46715500E+02, 0.83101700E+02, -.94970200E+02, -.15182900E+03, 0.25598400E+01, 0.76450000E+02, 0.71061900E+02, -.41108200E+02, -.11121700E+03, -.14208600E+03, 0.55366500E+02, 0.26088400E+03, -.10861300E+03, -.32393900E+02, -.22196100E+02, -.42279900E+02, 0.54372400E+02, -.42982000E+02, -.67184500E+01, 0.93261200E+02, 0.23603700E+02, -.49663900E+01, -.30976600E+02, -.13491800E+02, -.40105000E+02, -.16597100E+03, -.60081600E+02, 0.72048300E+02, -.54553600E+02, 0.35736100E+01, -.31600600E+02, 0.94292800E+01, -.17697300E+02, -.10385700E+03, -.55947400E+02, -.29457600E+03, 0.17541100E+03, -.81384700E+02, -.13125200E+03, 0.17318500E+03, -.98611000E+02, 0.99838100E+02, -.17884500E+03, 0.15601200E+00, 0.15621900E+00, 0.33350300E-01, -.16109500E+00, -.41430800E-02, 0.43289000E-01, 0.16606400E+00, -.15122000E+00, 0.12917500E+00, 0.16245800E+00, 0.18897400E-01, -.14564300E+00, -.92199000E-04, 0.56950100E-01, 0.19826100E+00, -.12359100E+00, -.99194200E+02, 0.17161700E+02, 0.56968000E+02, 0.42359900E+02, -.38357000E+02, -.82328100E+02, -.52851600E+02, 0.38664000E+02, 0.11759800E+03, -.92183200E+02, -.22607500E+02, -.26103600E+02, -.10001000E+02, 0.42343100E+02, 0.16131900E+02, -.24401600E+02, 0.10353800E+01, -.78314000E+00, -.13778200E+00, 0.27318500E+00, -.45018800E-01, 0.51562000E+00, 0.12853100E+01, 0.37438800E+00, 0.33640200E+03, -.17807500E+03, -.77051200E+02, -.27419600E+02, -.19395200E+02, 0.21784700E+03, 0.15720600E+03, 0.42769100E+02, -.16242700E-01, -.58349900E-01, 0.78357300E-02, 0.22261400E-01, 0.67899000E-02, -.35432800E-01, -.28535300E+00, -.23284200E-02, 0.29579400E+00, -.55271300E+00, -.10245900E+00, 0.26309300E+00, 0.64388100E-01, 0.19403400E+00, 0.88099000E+00, 0.27279700E+00, 0.68838100E+00, 0.33413600E+00, 0.35090100E+01, 0.18884100E+02, 0.34511000E+00, 0.12721300E+01, 0.18522900E+01, -.36094400E+00, -.99028200E+00, 0.32893100E+00, -.61859100E+02, -.77644500E+01, 0.85653100E+01, 0.36356100E+02, -.30866800E+00, -.35716700E+01, -.87794900E+01, 0.31283700E+02, 0.24385900E+00, 0.25477200E+00, -.19454200E+02, -.15084900E+02, 0.39351300E+00, -.41042200E+02, -.33814100E+00, 0.37764200E+00 }, { -.15640200E+01, -.52553300E+00, 0.13071500E+01, 0.64825500E+00, 0.47066400E+00, 0.34416200E+01, 0.31095000E+01, -.97219400E+00, 0.42076200E+00, -.60893200E+00, -.45447300E-01, 0.15506400E+00, -.98763700E+00, 0.52474400E+01, -.73353500E+00, -.37210500E+01, -.20523700E+01, -.15526800E+01, -.23496000E+00, 0.82271500E+00, -.14958100E+00, -.13294700E+00, 0.72149800E-01, 0.57310200E+00, -.16948200E+00, 0.75673300E-02, -.14249800E+01, -.45134000E+00, 0.52176700E+00, 0.64960600E+00, 0.16567600E+00, 0.74858800E-01, -.46951800E+00, -.26751700E+00, -.30358300E+01, 0.69973000E+00, 0.27397200E+00, 0.94875400E+00, -.83938600E+00, -.38014400E-01, 0.99395700E+00, 0.18467000E+01, 0.31961700E+01, -.67274900E+00, -.79419000E+00, -.65774000E+00, 0.16003900E+00, 0.48341700E+01, 0.52183000E+01, -.63229700E+00, -.90262000E-01, 0.90594600E-01, -.50131900E+00, 0.89349000E+00, 0.37750800E+01, -.86887200E-02, 0.15487300E+02, -.10279500E+02, 0.14095000E+00, -.27157100E+01, 0.14182300E+01, 0.42977900E+01, -.11835600E+02, 0.13359300E+01, 0.29244300E+00, -.26888200E+00, 0.38293700E-01, 0.15503800E+00, -.41601900E+00, 0.87024800E+00, -.24329900E+01, 0.84515900E-01, -.39940400E+03, -.59240000E+02, 0.23803700E+03, 0.25154700E+03, -.68596100E+02, -.19154600E+03, -.27236700E+03, 0.31886700E+03, -.67492700E+03, 0.22092400E+03, -.70824200E+02, -.11370400E+03, 0.27734500E+03, -.81893500E+02, 0.13199800E+03, -.47695400E+02, -.40907800E+02, 0.16686600E+03, -.41045400E+03, -.37988200E+03, 0.50659300E+03, 0.42045200E+02, 0.47391800E+03, -.40759600E+03, -.18767300E+03, -.22576900E+03, 0.11746500E+03, 0.92996800E+02, 0.22523400E+02, -.34481800E+02, -.44828200E+03, 0.17583400E+03, -.21996000E+03, 0.15564100E+03, -.11757900E+02, -.17051000E+02, -.22485900E+02, -.17251100E+02, 0.49962900E+02, -.60994900E+02, 0.13320300E+04, -.22428900E+03, -.65410600E+02, -.15708000E+03, -.12042900E+03, 0.60022300E+03, -.42912500E+02, -.42966600E+02, 0.82410700E+02, -.18450100E+03, -.10122200E+03, -.12442000E+03, 0.28205600E+03, 0.79660700E+02, -.14392300E+03, -.12526000E+02, 0.46865300E+03, -.39711400E+03, 0.14106700E+02, 0.10435300E+03, -.26246000E+02, 0.18833600E+03, 0.12553800E+03, 0.99778800E+02, 0.27790200E+01, -.56399400E+00, 0.28078700E+00, 0.50359400E+00, -.86809100E+00, 0.15417500E+01, -.12542400E+01, 0.41779600E+00, 0.26128600E+01, -.53417200E+00, 0.16921000E+00, 0.39618200E+00, -.78970400E+00, 0.14554300E+01, -.11792700E+01, 0.28262200E+00, -.57939800E+03, 0.11295600E+03, 0.29212600E+03, 0.37993300E+03, -.56727300E+02, -.23126900E+03, -.21248500E+03, 0.43421000E+03, 0.26366000E+03, -.64140900E+02, -.54107700E+02, -.60451500E+02, -.37347500E+02, 0.59951100E+02, -.24852900E+03, -.58099300E+02, -.14529600E+02, 0.43419300E+01, -.90980700E+00, -.12289400E+01, 0.28081500E+01, -.30280900E+01, -.23473800E+01, -.17477000E+01, 0.34713500E+03, 0.10661200E+03, -.32422300E+03, -.34275900E+03, 0.80410600E+02, -.76391200E+02, -.16045900E+03, -.55648800E+03, 0.96884500E+00, 0.21784400E+00, 0.56016600E-01, -.29543700E-01, 0.19190900E+00, -.34376700E+00, 0.27733600E+01, 0.29888500E-01, -.13597800E+02, 0.32244600E+01, -.53470300E+00, -.97659700E+00, 0.23816600E+01, -.32777400E+01, -.33504900E+01, -.11236200E+01, 0.13452900E+02, -.96343500E+00, 0.29330400E+02, 0.60533600E+02, -.11271000E+01, 0.24965700E+01, -.28744400E+01, 0.12873100E+01, 0.16891100E+01, -.98715000E+00, -.96960600E+02, 0.44598500E+02, 0.83399200E+01, 0.10000500E+03, -.31717800E+02, 0.25766100E+03, -.58447400E+02, -.72008900E+02, -.45911800E+00, -.56220900E+00, -.27225400E+02, -.13578300E+03, -.16429200E+01, 0.15246400E+03, 0.10323300E+01, -.13011700E+01 }, { 0.48427200E+00, 0.63926200E+00, -.38318200E+00, 0.25671400E-01, -.12499700E+00, -.37453200E+00, -.17258000E+00, 0.52203200E+00, -.78656700E-01, -.28242500E+00, 0.78925800E-01, 0.28077400E+00, 0.42546600E-01, -.42508600E-01, 0.13716500E+00, 0.88584900E+00, 0.81212600E+00, 0.27247700E+00, 0.22950500E-01, -.19923500E+00, -.16888100E+00, 0.14706700E+00, 0.32375700E+00, -.31038100E+00, 0.55231200E-01, -.10069300E+01, 0.54701300E+00, 0.20058600E+00, -.27618500E+00, -.15061000E+00, -.71653200E+00, 0.65280200E-01, 0.19817400E+00, 0.20319700E+00, 0.22646700E+01, -.56159100E-01, -.24062500E-02, 0.44753100E-01, 0.46280600E+00, 0.65950500E-01, 0.75662800E-01, -.20931800E+00, -.93149400E+00, 0.25383200E+00, 0.77250300E-01, 0.77115000E-01, -.82598200E-01, 0.41852600E+00, -.79153500E-03, 0.32904500E+01, 0.70204800E-01, 0.55551600E-01, -.65039900E-01, -.12793300E+00, -.28125600E+00, 0.29416800E-01, 0.11588500E+02, 0.28697700E+01, -.15426100E+01, 0.54294500E+00, -.42081200E+01, 0.62023700E+01, 0.58288300E+01, 0.13740000E+01, 0.25622000E-01, -.24164900E+01, 0.27881700E-01, 0.24102200E-01, -.12753400E-01, 0.78488400E-02, 0.18472800E+00, 0.35637900E-01, 0.18789700E+03, -.31033000E+03, -.87796400E+02, -.87429800E+02, 0.91732300E+02, 0.90755900E+02, 0.11480600E+03, -.87301100E+02, 0.92939800E+02, -.41961800E+02, -.71138100E+01, 0.13621200E+01, -.55654100E+02, 0.33139200E+02, 0.21494700E+02, 0.10264500E+02, 0.16686600E+03, -.16814100E+03, 0.38296800E+02, 0.50779700E+02, -.14540300E+03, 0.66582700E+01, 0.66459500E+02, 0.90678300E+02, 0.15143800E+02, -.85549300E+02, -.19156300E+02, 0.88867800E+01, -.10001900E+02, 0.57077700E+02, 0.12080400E+03, 0.14890500E+02, -.30377200E+03, 0.21781500E+03, 0.61183900E+02, 0.68278500E+02, 0.16637700E+02, -.12442000E+03, -.46926900E+01, 0.61390500E+02, -.75191100E+02, -.56392500E+02, -.13869000E+02, 0.74774500E+01, 0.12968200E+02, 0.33426400E+01, 0.75690300E+02, 0.81568300E+01, -.69845600E+02, -.39652700E+02, 0.56953000E+02, 0.96725300E+02, -.11837600E+03, -.23410000E+02, 0.88360700E+02, 0.11254100E+03, 0.29665900E+03, 0.58379400E+02, 0.29306900E+02, 0.55382700E+02, -.20471800E+03, 0.10137700E+03, -.31588300E+02, 0.80848800E+02, 0.86958500E-01, -.14194900E+01, 0.43357500E-01, 0.45827100E-01, -.36062800E-01, 0.46998800E-01, 0.82876400E-01, 0.68341300E-01, 0.69984900E-01, -.14232700E+01, 0.50124200E-01, 0.40910600E-01, -.32052700E-01, 0.10828400E-01, 0.66444300E-01, 0.52960000E-01, 0.15255600E+03, -.13372500E+03, -.38443000E+02, -.32027800E+02, 0.18696900E+02, 0.11153200E+03, 0.21505000E+02, -.25212000E+02, -.22546400E+03, 0.40977800E+02, 0.34524400E+02, 0.45214100E+02, 0.23470600E+02, -.66103400E+02, 0.52643200E+02, 0.45661500E+02, -.57572500E+00, -.51020500E+01, -.57148700E-01, -.31397300E+00, 0.47366600E+00, 0.10834300E+00, -.21777600E+00, -.31023400E+00, -.34768700E+03, 0.83018100E+02, 0.55473000E+02, 0.19106000E+02, 0.11244800E+03, -.15848800E+03, 0.27603500E+02, -.17994100E+01, -.58631600E-02, 0.25441600E+01, -.30925800E-01, -.14369000E-01, 0.23241600E-01, 0.60277000E-01, -.18419100E+00, 0.26754700E-02, -.22077700E+00, -.45584700E+01, -.14094200E+00, -.27055200E+00, 0.33294500E+00, 0.18997100E+00, -.10281100E-01, -.25069800E+00, 0.35489200E+00, -.58813500E+00, 0.15313600E+01, 0.37613700E+01, -.41254400E+00, -.59844000E+00, 0.17531900E+01, 0.30033500E+00, -.17772400E+01, -.38150400E+00, 0.25906000E+02, 0.19467000E+02, 0.39896900E+02, -.16109800E+02, 0.18752900E+01, -.94024400E+01, 0.36000800E+02, -.44567000E+02, -.21578600E+00, -.37275200E+00, 0.10799300E+02, 0.15340800E+02, -.44896000E+00, 0.21807400E+02, 0.50187200E+00, -.27592600E+00 }, { 0.19693200E+00, 0.81313900E-01, -.35576500E+00, 0.36828400E-01, -.77165500E-01, -.67645500E+00, -.57775300E+00, 0.30623500E+00, -.10143400E+00, 0.20616500E+00, -.41968200E-02, -.11917200E+00, 0.24062000E+00, -.13457000E+01, 0.20872300E+00, 0.80915800E+00, 0.38824200E+00, 0.31913200E+00, 0.45425600E-01, -.17707800E+00, 0.76513100E-01, 0.14094100E-02, -.12410000E+00, -.63526300E-01, -.40641600E-02, -.15658000E-01, -.68816700E+00, 0.48424100E-01, -.20755000E+00, -.79759400E-02, -.14358200E+00, -.67017700E-01, 0.15250600E+00, 0.45222100E-01, 0.31941600E+00, -.12720400E+00, -.26825300E-01, 0.15562400E-01, 0.21196100E+00, 0.79179400E-02, 0.16645500E-01, -.22763700E+00, 0.40350100E-01, -.27331300E-01, 0.12457500E+00, 0.21151400E+00, -.24931700E-01, -.22864700E+00, -.67672500E-02, 0.88069700E-02, 0.62735100E+00, -.71098600E-03, 0.23537600E-01, -.11509800E-01, -.40972500E+00, 0.86560700E-02, -.10199700E+01, 0.14624500E+00, 0.29815600E+01, 0.10129600E+01, -.26252900E+01, 0.48534100E+00, -.38997900E-01, 0.81720900E-01, 0.99878400E-02, 0.25223100E-01, -.43802400E+00, 0.10721100E-02, 0.38082800E-03, 0.24943800E-01, 0.38436800E+00, 0.73230100E-02, -.10380500E+03, 0.83917200E+01, 0.28684700E+02, 0.66146900E+01, 0.14664600E+02, -.63570200E+02, -.11804700E+03, -.16714000E+02, 0.42290700E+02, 0.29117000E+01, 0.15847900E+02, 0.24476000E+01, -.28973000E+02, 0.24177800E+02, 0.98751800E+01, 0.48799600E+01, 0.10750600E+03, -.51188800E+01, 0.37754000E+01, 0.66969700E+01, -.37095900E+02, 0.43137700E+02, 0.92282700E+02, 0.13304900E+02, -.11772800E+03, 0.29857100E+02, 0.64513800E+02, 0.57319800E+02, -.60273800E+02, -.54460700E+02, -.44417800E+02, 0.43167800E+02, -.26603400E+03, 0.12986700E+03, 0.34658600E+02, 0.55575900E+02, 0.35460800E+02, -.97939800E+02, 0.18072200E+02, 0.55729800E+02, 0.52536000E+02, -.51204900E+02, -.56025600E+01, -.31952600E+02, 0.94341800E+01, 0.62500000E+02, 0.40932900E+02, -.29865000E+02, -.10764200E+02, 0.35932300E+02, 0.61707500E+02, 0.36323500E+02, -.75944300E+02, 0.54189500E+01, -.37074000E+01, 0.25469600E+02, 0.21083100E+03, -.61602300E+02, -.33576500E+02, -.23422200E+02, -.16656100E+02, 0.10406200E+03, 0.14552600E+03, -.12120300E+01, 0.52605500E-01, 0.52497800E-02, -.22745000E+00, 0.28678200E-02, -.16321800E-01, 0.58832600E-01, 0.26903200E+00, 0.11286900E-01, 0.43091900E-01, 0.10374800E-01, -.23973700E+00, -.71617700E-03, -.26653300E-02, 0.45532600E-01, 0.26585600E+00, 0.99332600E-02, -.88588400E+02, -.51318100E+01, 0.25138500E+02, 0.21820600E+02, 0.34380700E+01, -.37390600E+02, -.58355600E+02, 0.13947300E+02, -.38355900E+02, 0.26328800E+01, 0.39231700E+01, 0.69467800E+01, 0.45312500E+00, -.84620600E+01, 0.97051900E+01, 0.36045500E+01, 0.12583000E+00, 0.30637000E-02, -.12437800E+01, -.47511600E-01, 0.78546500E-01, 0.48963300E-02, 0.66140700E+00, -.16422100E-01, -.15260500E+03, 0.42916100E+02, -.15874200E+02, 0.20951900E+02, 0.39755600E+02, -.88388100E+02, -.10730600E+02, 0.73299400E+01, 0.23522200E-02, -.27587500E-01, 0.48112800E+00, 0.60605700E-02, -.11711900E-01, 0.10803600E-03, -.37021000E+00, 0.74030900E-03, 0.73495900E-01, -.30658500E-01, -.10390800E+01, -.35020700E-01, 0.29974200E-01, -.90774100E-02, 0.50350900E+00, -.29262500E-01, 0.22138800E+00, 0.87968500E-01, 0.49062300E+00, 0.28031500E+01, 0.91678900E-01, -.97258000E+00, -.21579700E+00, -.92862000E-01, 0.40172500E+00, 0.84519100E-01, -.59773000E+02, 0.92337300E+01, 0.29997900E+02, 0.22754600E+02, 0.17689700E+01, 0.30924100E+01, 0.86873000E+01, -.59331500E+02, 0.56809700E-01, 0.58955800E-01, -.14348400E+02, -.18954400E+00, 0.89260800E-01, 0.88928100E+01, -.89954900E-01, 0.73755500E-01 }, { 0.25610400E+00, 0.10615400E+00, -.42502300E+00, -.19685500E+00, -.14902900E+00, -.93015600E+00, -.67519200E+00, 0.43525500E+00, -.54733900E-01, 0.11790300E+00, -.94769900E-02, -.62616600E-01, 0.24541400E+00, -.11323900E+01, 0.82217100E-01, 0.59871900E+00, 0.45791400E+00, 0.11943600E+00, -.44774500E-01, -.93394500E-01, -.31694200E-01, 0.54604800E-01, 0.40499300E-01, -.10575400E+00, 0.16326000E-01, -.36774700E-01, 0.12159200E+00, -.10551100E+00, -.98971100E+00, -.84857300E-01, -.22612900E+01, -.88178200E+00, 0.10292900E+00, 0.56993200E-01, 0.16775500E+01, -.12361400E+00, 0.34342700E-01, -.18693600E+00, 0.38853500E+00, 0.15125600E-01, 0.43308600E-01, -.71872200E-01, -.34600900E+00, -.94694600E-01, -.47322600E-01, 0.68767900E-01, -.12069300E+00, 0.40957900E+00, 0.21337700E-01, -.40974500E-01, 0.11840900E+00, 0.53046500E+00, -.10247600E+00, -.36864100E-01, -.50777800E+00, -.33854600E-01, 0.95843300E+01, 0.36792300E+00, -.46944400E+01, -.28122100E+01, 0.21261900E+01, 0.27984200E+01, -.26555100E+01, -.25370400E+01, -.53770000E-02, -.13813100E+00, 0.74626600E-01, -.36515100E+00, 0.30038100E-01, -.27242500E-01, 0.32096800E+00, 0.23109300E-01, 0.21008600E+03, -.32496900E+03, -.23203700E+02, -.54501100E+01, -.44587000E+02, 0.11233700E+03, 0.16573500E+03, -.18016300E+01, -.75331600E+02, 0.24306200E+02, -.33171500E+02, -.21056000E+02, 0.35672000E+02, -.39982800E+02, -.12345900E+02, -.28894100E+02, -.40561500E+02, -.37965700E+02, -.69881900E+01, -.34709000E+02, 0.39924900E+02, -.30724200E+02, 0.57527600E+01, -.59146300E+01, 0.74616000E+02, -.16838500E+03, -.65265200E+02, -.39009100E+02, 0.30779300E+02, 0.33109800E+02, 0.31325800E+02, -.43666400E+02, 0.34456700E+03, -.53543500E+02, -.28392700E+02, -.48134500E+02, -.73627800E+02, 0.10710400E+03, -.53865900E+02, -.51929000E+02, -.31548300E+03, 0.32983800E+02, 0.25444100E+02, 0.75354600E+02, 0.33010800E+02, -.16491600E+03, -.80413500E+02, 0.53486400E+02, 0.68040900E+02, -.13749800E+03, -.64873600E+02, -.47799700E+02, 0.57930400E+02, -.26389600E+01, -.46564700E+02, -.45498300E+02, -.13803700E+03, 0.34322500E+03, -.87425600E+01, -.37650200E+02, 0.40289700E+02, -.89425900E+02, -.10044800E+03, -.50292800E+02, -.82687900E-01, -.78892400E-01, 0.52236100E-01, -.21697200E+00, 0.79170700E-01, -.62524600E-01, 0.16662600E+00, 0.36197500E-01, -.76105600E-01, -.10152900E+00, 0.78738800E-01, -.20179500E+00, 0.42392500E-01, -.59001100E-01, 0.17148600E+00, 0.35736200E-01, 0.19008100E+01, -.49667200E+02, 0.36712000E+01, 0.76058000E+01, 0.20172500E+01, 0.31629400E+02, 0.94974200E+02, 0.10583100E+02, 0.27341600E+01, -.46975900E+02, -.30827000E+01, 0.96126400E+00, 0.25104200E+01, 0.32127500E+01, 0.49439900E+01, 0.51226300E+01, -.21771600E+00, 0.32087200E+00, 0.29416700E+00, -.74164300E+00, 0.16124400E+00, 0.30690800E+00, 0.11659800E+01, 0.34122000E+00, 0.39192500E+03, -.17895700E+03, -.21223000E+02, -.65972900E+02, -.37384000E+02, 0.18696400E+03, 0.59099900E+02, -.31763200E+02, -.41812700E-01, 0.14339700E+00, -.10469900E+00, 0.36670900E+00, 0.48627200E-01, 0.19181500E-01, -.33491600E+00, 0.65980800E-02, -.17686100E+00, 0.28887100E+00, 0.13199400E+00, -.68566300E+00, 0.17109000E+00, 0.20855800E+00, 0.95558100E+00, 0.21971800E+00, -.35623200E+00, 0.45276100E-01, 0.83674300E+01, -.15223800E+01, 0.73415000E-01, 0.76853700E+00, 0.23788600E+00, -.86864900E-01, -.57371900E+00, 0.61009100E-01, 0.16604000E+02, -.21955600E+02, -.12944600E+02, -.11910400E+02, -.83748900E+01, -.75013200E+01, -.58965200E+01, 0.37149500E+02, 0.27116100E-01, 0.24447100E-01, 0.15485000E+02, 0.51934400E+01, 0.53312500E-01, -.22553600E+02, -.59585500E-01, 0.78071500E-01 }, { 0.19410000E+00, 0.46064100E-01, 0.50208300E-01, -.73489200E-01, -.17617700E+00, -.21871700E+00, -.83132300E-01, -.57740500E-01, 0.21285500E-01, -.41297700E-01, -.12432800E-01, -.60558700E-01, -.10581300E+00, 0.14729600E+00, -.26847700E-03, -.26441200E+00, 0.14356200E-01, -.87335800E-01, 0.26104500E-01, 0.78197800E-01, -.10586000E+00, 0.32747400E-01, 0.14812000E+00, -.92743400E-01, 0.16297100E-01, -.39743800E-01, 0.83803000E-01, 0.35222300E-01, -.90927500E+00, -.37315400E-01, -.48037600E+00, 0.60388500E-01, 0.33610600E-01, 0.28161800E-01, -.12031200E+00, 0.16310200E-01, -.17348800E-01, -.18469900E-01, -.64592100E-01, 0.30014600E-02, -.28318200E-01, 0.21136900E-01, -.97813500E-01, 0.36641100E-01, -.12492100E-01, 0.16658900E+00, -.16452500E-01, -.17611300E+00, -.67652700E-02, 0.78468100E-02, -.33096600E-01, -.30445000E-02, 0.32917900E+00, -.36819600E-03, -.22789100E-01, 0.16964900E-01, -.30270300E+01, 0.15328500E+00, 0.16047700E+01, 0.14456800E+01, -.27524800E+00, -.88853800E+00, 0.28439900E+00, 0.13560300E+01, 0.23356600E-01, 0.24465800E-01, -.25888900E-01, -.79570100E-02, -.22424800E+00, 0.17905500E-01, 0.21089700E-03, -.96333800E-02, -.64569100E+02, 0.85923500E+02, 0.15573600E+02, 0.19472600E+02, 0.11420200E+02, -.35167100E+02, -.57672100E+02, 0.24590900E+02, 0.47619500E+02, -.26818500E+02, 0.24506700E+02, 0.14752300E+02, -.27884000E+02, 0.13821000E+02, -.90964900E+01, 0.17074400E+02, 0.20030700E+02, 0.51763100E+01, 0.10852600E+02, 0.72484400E+01, -.22832300E+02, 0.79662000E+01, 0.16008900E+01, 0.66256200E+01, -.24111200E-02, 0.37204900E+02, 0.11039100E+02, 0.60020100E+01, 0.58186400E+01, 0.14920100E+01, -.22243000E+01, 0.11254900E+02, -.83705500E+02, 0.21457700E+02, 0.76850000E+01, 0.91694600E+01, 0.20664300E+02, -.24401900E+02, 0.12864100E+02, 0.11948600E+02, 0.64330900E+02, -.60738700E+01, 0.22187300E+01, -.59095600E+01, -.23567900E+02, 0.32846700E+02, 0.88178200E+01, -.44062700E+01, -.25167800E+02, 0.31491100E+02, 0.27624500E+02, 0.20887200E+02, -.19087300E+02, -.32482300E+01, 0.14108600E+02, 0.22624700E+02, 0.58158300E+02, -.88962500E+02, 0.72013900E+01, 0.32502400E+01, -.36872600E+02, 0.32095800E+02, 0.16650300E+02, 0.58963300E+01, 0.70535200E-01, 0.46864100E-02, -.23783700E-01, -.12072500E-01, -.15233600E+00, 0.39509700E-01, -.13577100E-01, -.17913300E-01, 0.60868800E-01, 0.12351600E-01, -.32543000E-01, -.15450300E-01, -.13773400E+00, 0.33012500E-01, -.13867800E-01, -.17271300E-01, 0.22651100E+02, 0.12763900E+02, -.50836800E+01, -.10365500E+01, -.54812700E+01, 0.16559200E+01, -.30116300E+02, 0.10446000E+00, -.20483200E+02, 0.18294600E+02, 0.14192300E+01, 0.24507400E+01, 0.39617800E+01, -.43355600E+01, 0.10235400E+02, 0.21685000E+01, 0.92252400E-01, -.13583800E-01, -.14592100E+00, -.13566700E+00, -.49420700E+00, -.36464200E-01, -.19273500E-02, -.20402600E+00, -.14091000E+03, 0.79820800E+02, 0.37360500E+01, 0.22241600E+02, 0.18901300E+02, -.59178700E+02, 0.63330900E+01, 0.18501300E+02, 0.12342800E-01, -.25071000E-01, 0.32225100E-01, 0.65424700E-02, 0.20743000E+00, 0.17825900E-03, -.77308000E-02, -.23592400E-02, 0.50258400E-01, -.29107900E-01, -.74583100E-01, -.72159400E-01, -.44975100E+00, -.30976300E-01, 0.17103500E-01, -.12726000E+00, 0.29890400E+00, -.51450400E-02, -.48688000E+01, 0.25934000E+01, -.60841000E-02, -.36851300E+00, -.34288900E+00, 0.23561700E-02, 0.48758600E+00, -.55615700E-02, 0.20017100E+01, 0.10490800E+02, 0.60617000E+01, 0.12792200E+01, 0.53014300E+01, 0.23075400E+01, 0.16285300E+01, -.73015200E+01, 0.31081700E-02, -.14942400E-02, -.35318800E+01, -.16265700E+00, 0.52748000E-02, 0.55057500E+01, 0.47693100E-02, 0.57347300E-02 }, { -.54221800E+00, -.18566600E+00, 0.53754200E+00, 0.28240000E+00, 0.18052100E+00, 0.13662800E+00, -.18407700E+01, -.60737800E+00, 0.10002100E+00, -.18520900E+00, 0.40245900E-01, 0.56748000E+00, 0.73552700E-01, 0.13260200E+01, -.52584300E+00, -.24640200E+00, -.30190000E+00, -.18990800E+00, -.19205100E+00, 0.15959700E-01, 0.48437700E-02, 0.43340200E-01, 0.26851300E+00, 0.58736600E-01, 0.34383600E-01, 0.11481000E-01, -.25145000E+00, -.10047800E+00, -.15415700E+00, -.93366700E+00, -.12930000E+01, 0.23708600E+00, -.11257700E+00, 0.18748200E+00, 0.20920300E+01, 0.34553000E+00, -.78081700E-01, 0.29947000E+00, 0.44844200E+00, -.18504700E-01, 0.17443400E+00, -.59757100E-01, -.17635300E+00, 0.23153800E+00, 0.10500800E+00, -.83405400E+00, 0.86298000E-01, 0.12748700E+01, 0.59716000E-02, -.26735800E-01, 0.14193300E+00, 0.14209200E+00, -.23422400E+00, 0.13482800E+01, 0.44915000E+00, 0.34313000E-01, 0.15608000E+02, -.20788500E+01, -.41930400E+01, -.95175400E+00, -.15548900E+01, 0.71018900E+01, 0.61553400E+01, 0.19521700E+01, 0.53683500E-01, -.70659700E-01, 0.67085200E-01, 0.90451200E-01, -.40324100E-01, -.10414900E+01, -.50678700E+00, 0.36987200E-01, 0.50490900E+03, -.37279700E+03, -.75959500E+02, -.51490500E+02, -.31583000E+02, 0.20005600E+03, 0.16488300E+03, -.63046400E+01, -.10902500E+02, -.51122400E+01, -.32059900E+02, -.33672000E+01, -.12018700E+02, -.39617100E+02, 0.32726800E+01, 0.61302800E+00, 0.35442600E+02, -.77388200E+01, 0.74675200E+02, 0.61016000E+02, -.14088900E+03, -.81229100E+02, -.83382100E+02, 0.99812100E+02, 0.15890900E+03, -.16179100E+03, -.90835800E+02, -.58635900E+02, 0.45194400E+02, 0.10394800E+03, 0.15292600E+03, -.31472600E+02, 0.30771700E+02, 0.12935300E+03, 0.35611700E+01, -.14853300E+02, -.10742300E+02, 0.25958900E+00, -.10626800E+01, -.23663500E+02, -.20713100E+03, -.28866900E+02, -.24108000E+02, 0.47968200E+02, 0.51181000E+00, -.13261600E+03, -.20551600E+02, 0.45091500E+02, -.66251300E+02, -.50945800E+02, 0.83737600E+01, 0.65578400E+02, -.50143800E+02, -.58587200E+02, 0.83807400E+02, 0.10223200E+03, -.19281500E+03, 0.26705800E+03, 0.97816400E+02, 0.11030000E+03, -.18351700E+03, -.15277700E+03, -.27881700E+03, 0.10284600E+03, 0.10654700E+00, -.62662000E-01, 0.34399100E-01, 0.10643000E+00, -.48935700E-02, -.59431700E+00, -.34910100E+00, 0.77613400E-01, 0.91541600E-01, -.70243000E-01, 0.56271500E-01, 0.10068500E+00, -.17061300E-01, -.60839200E+00, -.38646000E+00, 0.58688800E-01, 0.44637000E+03, -.21169900E+03, -.32220700E+02, -.33265100E+02, -.92328500E+02, 0.15827000E+03, -.29604800E+02, -.90716900E+01, -.16817500E+03, -.83267600E+01, 0.32440000E+02, 0.38061600E+02, 0.21952500E+02, -.47393400E+02, 0.79539500E+02, 0.47443300E+02, -.50266800E+00, 0.52314400E+00, 0.34022000E+00, -.14298200E+00, 0.21193400E+00, -.21601700E+01, -.13280400E+01, -.37603900E+00, -.18597800E+03, 0.38576500E+02, 0.12274100E+03, 0.49853500E+02, 0.40427000E+02, -.27975100E+02, 0.43713700E+02, 0.49679400E+02, 0.11540500E-02, 0.68906700E-01, -.93229300E-01, -.77479600E-01, 0.73797800E-01, 0.11501500E+01, 0.56107400E+00, 0.26708600E-02, -.20330100E+00, 0.28982700E+00, 0.12515900E+00, -.17644600E+00, 0.13941000E+00, -.18095300E+01, -.86420500E+00, -.30592000E+00, 0.48256400E+00, -.20266800E+00, 0.37010600E+01, 0.79150500E+00, -.18004000E+00, -.67723600E+00, 0.26054100E+00, 0.16359700E+00, -.95557000E+00, -.17569200E+00, 0.75888600E+02, 0.10130200E+02, 0.16446900E+02, -.37035500E+02, -.77033300E+01, -.15167900E+02, 0.26766500E+02, 0.42222000E+02, -.13370300E+00, -.14860300E+00, 0.26325500E+01, 0.27064400E+02, -.85661000E-01, 0.15844700E+01, 0.19090200E+00, -.10193200E+00 }, { -.15666500E-01, 0.36879700E-01, -.15907400E+00, -.17020000E+00, -.71483600E-01, 0.55283200E+00, -.19233900E+00, 0.41139500E-01, -.68314800E-01, 0.10062400E-01, 0.85336600E-03, -.43951200E-01, -.91107800E-01, 0.12132500E+00, 0.98379600E-01, -.20858500E-01, -.85113900E-01, 0.26972400E-01, 0.46343600E-02, 0.76525000E-02, -.34206000E-01, 0.62167300E-02, 0.24075900E-02, 0.12662800E-01, -.33215400E-02, 0.53082400E-02, 0.10893300E-01, 0.12373100E-01, 0.48690700E-01, 0.20729700E-01, 0.28966000E+00, -.22956700E-01, -.50317600E-01, -.20130000E-01, -.73361400E+00, 0.81703800E-03, 0.72491600E-04, 0.33663000E-02, -.12607400E-01, -.13568900E-02, 0.60902500E-03, 0.26439200E-02, 0.17745100E-01, -.67331300E-02, -.11016900E-02, 0.35328700E-02, 0.35298900E-02, -.17147200E-01, -.12699300E-03, -.26211200E-03, -.60279500E-02, -.27477200E-02, 0.20560200E-02, 0.27415500E-02, 0.40992400E+00, -.82493500E-03, -.62753400E+00, 0.56957300E-01, 0.12561300E+00, 0.10250300E-01, 0.12686800E+00, -.28280800E+00, 0.27438900E-01, -.64886300E-01, 0.33755400E-02, -.22366600E-02, -.20158400E-02, -.66147400E-03, -.27527200E-02, 0.30018900E-02, -.12192800E+00, 0.18487800E-03, -.14093100E+02, 0.17891000E+02, 0.40708700E+01, 0.32814700E+01, -.15886300E+01, -.63177800E+01, -.49307900E+01, 0.21391200E+01, -.13274200E+01, -.25235200E+01, 0.13857500E+01, 0.73892600E+00, 0.92800600E+00, -.75471500E+00, -.13175600E+01, 0.65642100E+00, -.13407100E+01, -.49058400E+00, -.49759200E+01, -.42494800E+01, 0.55103300E+01, 0.16361800E+01, 0.56794600E+00, -.60460100E+01, -.41886700E+01, 0.67222800E+01, 0.28284400E+01, 0.15964700E+01, -.66778900E+00, -.35763400E+01, -.52339200E+01, 0.96377900E+00, 0.56699100E+01, -.78669000E+01, -.26158900E+01, -.19104800E+01, 0.88040700E+00, 0.20280600E+01, 0.59926300E+00, -.17689300E+01, 0.79637800E+01, -.17272200E+01, 0.15393400E+01, -.15396200E+01, 0.16081800E+01, 0.34110300E+01, -.14351600E+00, -.83241500E+00, 0.53183600E+01, -.17319300E+01, -.26865900E+01, -.45723200E+01, 0.42475100E+01, 0.22382800E+01, -.19689700E+01, -.55110000E+01, 0.16080500E+01, -.11910000E+02, -.44337700E+01, -.46556900E+01, 0.78078700E+01, 0.25010400E+01, 0.57296500E+01, -.46884500E+01, 0.64560000E-02, -.41872100E-02, 0.11501300E-02, 0.66538900E-03, -.61189000E-02, 0.13079800E-02, -.70849800E-01, 0.81087700E-03, 0.54490200E-02, -.33484000E-02, -.43990100E-03, 0.19101200E-03, -.51317400E-02, 0.23249000E-02, -.68635100E-01, 0.67758500E-03, -.12755800E+02, 0.91744500E+01, 0.15852700E+01, 0.94198900E+00, 0.19041300E+01, -.50726000E+01, 0.92969100E+00, 0.31770300E+00, 0.68356000E+01, 0.87803500E+00, -.12018900E+01, -.14603300E+01, -.91355200E+00, 0.17754500E+01, -.26190900E+01, -.16875300E+01, 0.25023200E-01, -.12979800E-01, -.13645200E-01, 0.16760900E-02, -.11028200E-01, 0.60513600E-02, -.28176600E+00, 0.58896300E-02, 0.88268800E+01, 0.35965700E+01, -.52682100E+01, -.23842500E+01, -.25422300E+01, 0.33488800E+01, -.12507200E+01, -.26794300E+01, 0.61101900E-03, 0.11452100E-02, 0.47082600E-02, 0.16958100E-02, -.82040700E-03, -.50799700E-02, 0.12535100E+00, -.11208700E-03, 0.62200000E-02, -.19968000E-02, -.59920100E-02, 0.18003100E-02, -.31715400E-02, 0.79383300E-03, -.25049900E+00, 0.45044100E-02, 0.27049000E-01, -.35239000E-01, 0.12057700E-01, 0.64928900E-01, -.42931400E-01, -.89779800E-01, -.12811500E+00, 0.50639600E-01, 0.13587600E+00, -.37162500E-01, -.13966500E+01, 0.73529700E-02, -.10998500E+01, 0.87889800E+00, -.18512000E+00, 0.18104600E+01, -.11198200E+01, 0.80437300E+00, -.23021000E-01, -.22600400E-01, -.28904700E+00, -.10200200E+01, -.59436500E-01, 0.10813000E+00, 0.38727200E-01, -.61427300E-01 }, { 0.22662300E+00, 0.94864800E-01, -.41590700E+00, -.17919200E+00, -.16055400E+00, -.95806600E+00, -.72549200E+00, 0.28553700E+00, -.24018200E-01, 0.59728900E-01, -.77733300E-02, -.13371300E+00, 0.73030400E-01, -.67111000E+00, 0.13448500E+00, 0.28392900E+00, 0.26442400E+00, 0.10577900E+00, 0.39101000E-01, -.44093700E-01, -.23252900E-02, 0.45299300E-02, -.62184600E-01, -.66257500E-01, -.31043200E-02, -.18793100E-01, 0.11476600E+00, 0.40492800E-01, 0.88308900E-02, 0.10104100E-02, 0.12770500E+00, 0.30256700E+00, 0.89110800E-01, 0.37378600E-02, 0.29024600E+00, -.26468500E-02, 0.10291800E-01, 0.17078800E+00, -.22500700E+00, 0.27184400E-01, -.18520900E-01, 0.29295700E-01, -.18130700E+00, 0.35491400E-01, -.24195000E-01, 0.33678300E+00, -.21894000E-01, -.22191400E+00, -.20446400E-01, 0.90004000E-02, 0.62941400E-01, 0.27010400E+00, 0.12633600E+00, 0.80375500E-03, 0.16356700E+00, 0.34236100E+00, -.94829800E+01, -.67510800E+00, 0.49932500E+01, 0.27526300E+01, -.31423100E+01, -.21026100E+01, 0.21170700E+01, 0.18059000E+01, 0.78658300E-01, 0.49106900E-01, 0.59497500E-01, 0.22720900E+00, -.46869900E-01, 0.46902500E-01, 0.11577500E-04, -.31632600E-02, -.17888700E+03, 0.27746200E+03, 0.47438700E+02, 0.27534900E+02, 0.11513400E+02, -.10745900E+03, -.20317400E+03, 0.15889200E+02, -.95557900E+02, 0.30890700E+02, 0.18920500E+02, -.16039800E+02, 0.15527900E+02, 0.19762500E+02, 0.70993700E+02, -.14960000E+02, 0.95144200E+02, 0.20408900E+00, 0.45068900E+01, 0.13670400E+02, -.44877800E+02, 0.47654000E+02, 0.38157500E+02, -.53658200E+01, -.11870000E+03, 0.14347600E+03, 0.96988400E+02, 0.68914000E+02, -.70951100E+02, -.55930500E+02, -.58411000E+02, 0.63683400E+02, -.39663500E+03, 0.11396200E+03, 0.41142900E+02, 0.63123200E+02, 0.75311300E+02, -.12065200E+03, 0.48151600E+02, 0.67977800E+02, 0.21403300E+03, -.62361600E+02, -.28856600E+02, -.79866600E+02, -.33323800E+01, 0.16287500E+03, 0.10660400E+03, -.73562400E+02, -.77424000E+02, 0.97174300E+02, 0.88128200E+02, 0.56158700E+02, -.86265100E+02, 0.54065800E+01, 0.33149900E+02, 0.42780900E+02, 0.31887000E+03, -.37751900E+03, 0.45814200E+01, 0.32908600E+02, -.66152400E+02, 0.14124400E+03, 0.13807500E+03, 0.43120900E+02, 0.25817700E+00, -.23938200E-01, 0.11815400E+00, 0.31237900E+00, -.15960100E+00, 0.11037300E+00, -.36616900E-02, 0.16026000E+00, 0.22250000E+00, 0.18839400E-03, 0.85365700E-01, 0.28573000E+00, -.11614800E+00, 0.91017400E-01, -.64772700E-02, 0.14688800E+00, -.38872800E+01, 0.40273500E+02, 0.33832700E+02, 0.37510100E+02, -.36388500E+02, -.39020800E+02, -.13792900E+03, 0.32164200E+02, 0.15122400E+02, 0.35834300E+02, 0.50675000E+00, -.25333100E+01, -.96971600E+01, 0.55612400E+01, -.12689300E+02, -.74331200E+01, 0.42984600E+00, 0.19762500E-02, -.48401900E+00, -.36578500E+00, 0.18602800E+00, -.14021800E+00, -.23393400E+00, -.94266300E+00, -.17118100E+03, 0.16940800E+03, -.20391700E+02, 0.26136100E+02, 0.33946700E+02, -.13216200E+03, -.66524800E+02, 0.11546200E+02, 0.41624900E-01, -.56999900E-01, -.51756500E-02, -.14829200E+00, -.51499700E-01, -.72444400E-02, 0.82762900E-03, 0.60878300E-01, 0.24010800E+00, -.55167400E-01, -.34558300E+00, -.39007300E+00, 0.14502400E+00, -.10570700E+00, -.19175400E+00, -.89603000E+00, 0.11341000E+01, -.18107400E+00, -.60432200E+01, 0.89930300E+01, -.17647400E+00, 0.31504600E+00, -.21571300E+00, 0.15795200E+00, 0.57875000E+00, -.18372700E+00, -.45296800E+02, 0.21390000E+02, 0.20575900E+02, 0.28099700E+02, 0.87435800E+01, 0.28976100E+01, 0.90222200E+01, -.53371600E+02, -.12976300E+00, -.14485800E+00, -.21219900E+02, -.15731600E+02, -.10545700E+00, 0.22557600E+02, 0.18069900E+00, -.11652800E+00 }, { -.23300300E+01, -.28656700E+01, 0.26380500E+01, 0.37306800E+00, 0.32370600E+00, 0.17974500E+01, 0.12501000E+01, -.31986300E+01, 0.46047900E+00, 0.11339800E+01, -.35761600E+00, -.19684500E+01, -.10901800E+01, 0.22840900E+01, -.21194600E+00, -.75191800E+01, -.68597400E+01, 0.34403100E+00, 0.16111300E+01, 0.85706600E+00, 0.20707000E+00, -.11041100E+01, -.16810100E+01, 0.29742800E+01, -.18685900E+00, 0.39581100E+00, -.22027900E+01, -.10128200E+01, 0.11869900E+01, 0.83720800E+00, -.29747100E+01, 0.43373300E+00, 0.42874600E+00, -.21330300E+01, -.19191100E+02, -.57436300E-01, -.14907400E+00, -.24997200E+01, -.50363800E+01, -.50112800E+00, -.15986400E+01, 0.23235700E+00, 0.14145400E+02, -.29511800E+01, 0.36059300E+00, -.18761800E+00, 0.98520300E+00, -.11130800E+02, -.65711100E-01, 0.84801800E-01, -.10659500E+01, -.89750600E+00, 0.16517000E+01, 0.10731200E+01, -.13004300E+02, -.60664200E+00, -.17246000E+03, 0.16849100E+02, 0.44626600E+02, 0.15918400E+02, 0.27736300E+02, -.68839900E+02, -.57159000E+02, -.61085300E+01, -.11262600E+00, 0.61582700E-02, -.69739300E+00, -.16418600E+00, -.35906300E-01, 0.13226800E+01, 0.29380500E+01, 0.53317000E-01, -.30154200E+04, 0.35268800E+04, 0.10514100E+04, 0.76296900E+03, -.60312300E+03, -.12679000E+04, -.20278500E+04, 0.59484900E+03, -.45648300E+03, -.29534800E+01, 0.33186700E+03, 0.93187300E+02, 0.25939600E+03, 0.74153500E+02, -.15348800E+03, -.17327500E+02, -.60940000E+03, 0.11262000E+04, -.60101300E+03, -.61011500E+03, 0.13478700E+04, 0.77714300E+03, 0.28134500E+03, -.11026400E+04, -.79058500E+03, 0.11308300E+04, 0.73815700E+03, 0.27337000E+03, -.23453000E+03, -.92183400E+03, -.14831100E+04, 0.10577600E+03, 0.13332400E+04, -.16217200E+04, -.37342000E+03, -.32924300E+03, 0.10056200E+03, 0.72709300E+03, 0.63569000E+02, -.21146000E+03, 0.12580000E+04, 0.30457000E+03, 0.18399500E+03, -.33411300E+03, 0.59416400E+02, 0.81538200E+03, -.44171500E+03, -.35265100E+03, 0.59274900E+03, 0.11700300E+04, -.17982200E+03, -.77819400E+03, 0.82521200E+03, 0.52817700E+03, -.75073600E+03, -.11162000E+04, -.59482100E+03, -.18703500E+04, -.56990500E+03, -.75273500E+03, 0.18493100E+04, 0.13938400E+03, 0.17566600E+04, -.96480700E+03, -.19860000E+00, -.39872700E+00, -.49805800E+00, 0.12420600E+00, -.63338900E+00, 0.79328600E+00, 0.17992200E+01, 0.15066900E+00, -.14672400E+00, -.24524200E+00, -.69818900E+00, 0.16349800E-01, -.42818500E+00, 0.10605600E+01, 0.21265800E+01, 0.18356600E+00, -.23682300E+04, 0.13254500E+04, 0.34815200E+03, 0.17764100E+03, 0.21500500E+03, -.11363800E+04, -.23392800E+03, 0.38065800E+02, 0.14777400E+04, 0.77948200E+02, -.23201000E+03, -.31229300E+03, -.16951200E+03, 0.45631700E+03, -.51326700E+03, -.36029900E+03, 0.78393600E+01, -.45582100E+01, -.43872600E+01, -.22396600E+00, -.20342200E+01, -.39552300E+00, 0.12681300E+02, 0.11810300E+01, 0.28420700E+04, -.49943000E+03, -.99466900E+03, -.35971400E+03, -.75779200E+03, 0.97680400E+03, -.91564700E+02, -.11070300E+03, 0.10591800E+00, -.19198500E+00, 0.92097800E+00, 0.53752000E+00, -.69723700E+00, -.19657500E+01, -.34317100E+01, 0.81082400E-02, 0.31271500E+01, -.19317900E+01, -.17362500E+01, 0.34648500E+00, -.10114500E+01, -.14303700E+01, 0.82449700E+01, 0.99001700E+00, -.83684800E+00, 0.35388700E+00, -.70702500E+02, -.34003200E+02, 0.41835100E+00, -.39102100E+01, -.85600700E+01, -.52813600E+00, 0.13800800E+02, 0.32221400E+00, -.65950200E+03, -.92467000E+02, -.20003700E+03, 0.33442300E+03, 0.84605200E+02, 0.20368700E+03, -.32249900E+03, -.47885600E+02, 0.16924100E+00, 0.12100900E+00, -.12854900E+03, -.16210500E+03, 0.24584200E+01, -.14009000E+03, -.37226200E+00, 0.74558600E+00 }, { 0.51907500E+00, 0.12707700E+00, 0.14725400E+00, 0.65055600E-01, 0.16298900E+00, -.58921900E+00, -.14038600E+01, -.63592300E+00, 0.22979000E-03, -.67188100E-01, -.17248900E-01, -.49247100E+00, -.31257100E+00, -.77414100E+00, 0.76287800E+00, 0.47103900E-01, 0.88401300E+00, -.30892500E+00, 0.43400100E+00, -.15271400E+00, 0.43305400E-01, 0.11419800E+00, 0.70670500E+00, -.26723800E+00, 0.40230800E-01, -.89186900E-01, 0.50818000E+00, 0.21418500E+00, 0.96355800E+00, 0.82922400E-01, 0.22826400E+01, -.78120300E-01, -.42031700E+00, -.54568600E-01, -.27333000E+01, 0.93752800E-01, 0.52481700E-01, 0.69742500E-01, -.15628900E+00, 0.90638900E-02, 0.17621300E+00, 0.17783000E+00, -.52692500E+00, -.35839400E-01, -.17802600E+00, 0.28965600E+00, -.11318400E+00, 0.37261900E+00, 0.12909300E-01, -.33329100E-01, -.16265900E+00, -.47058200E-01, 0.36738000E-01, 0.40603200E-01, 0.13789900E+01, -.63798500E-01, 0.18189200E-01, -.34851900E+01, -.10982000E+01, -.55315500E-01, 0.13061100E+01, -.48850800E+00, -.16291100E+01, -.17132400E+00, 0.17802600E+00, -.67711500E-01, -.11897800E+00, -.36371900E-01, -.30178600E-01, 0.75828400E-01, -.23508800E+00, -.48608100E-01, -.27682300E+02, 0.17567600E+03, 0.20001200E+01, 0.36892600E+02, -.10356600E+02, -.26460500E+02, -.40129200E+02, 0.33375300E+02, 0.23698500E+02, -.15011600E+03, 0.71414300E+00, 0.15037000E+02, 0.17377500E+02, -.85842200E+01, -.21575700E+02, 0.23000800E+02, 0.25881200E+02, -.45391000E+02, -.65017200E+02, -.89984200E+02, 0.24508900E+02, -.16584000E+01, 0.39941200E+02, -.10104200E+03, 0.69326600E+02, 0.47261900E+02, -.61721100E+02, -.46930700E+02, 0.49942400E+02, 0.40161000E+02, -.33123200E+02, -.40989900E+02, -.14812800E+03, 0.16309900E+02, 0.18740200E+02, 0.23211200E+02, 0.13373000E+01, -.57256200E+02, -.94295600E+01, 0.14470000E+02, 0.15328800E+03, -.14366000E+03, -.31400300E+02, -.15965800E+02, 0.44830300E+02, 0.67591600E+02, 0.22355300E+02, 0.11254500E+02, 0.51829300E+02, -.99311500E+02, -.83287000E+02, -.72850700E+02, 0.73792500E+02, 0.27729100E+02, 0.13181000E+02, -.63730900E+02, 0.11805400E+03, -.22243000E+03, -.79645400E+02, -.92437400E+02, 0.18361900E+02, 0.85713600E+02, 0.62100000E+02, -.76499200E+02, 0.26156200E+00, -.40149300E-01, -.15468100E+00, -.60767900E-01, -.40716300E-01, 0.11208200E+00, -.13198100E+00, -.78187100E-01, 0.22076200E+00, -.32029200E-01, -.14129700E+00, -.49250500E-01, -.40276900E-01, 0.97481100E-01, -.11796500E+00, -.66519000E-01, 0.38139300E+02, 0.85916500E+02, 0.43311300E+00, 0.13608400E+02, -.27113200E+02, 0.63404500E+01, -.36430400E+02, 0.19999300E+02, 0.10597800E+03, 0.81250300E+01, -.13613900E+02, -.18764200E+02, -.13352700E+02, 0.37943600E+02, -.10807600E+02, -.15552600E+02, -.11932100E+01, 0.10910600E+01, 0.30338200E+00, -.46010400E-02, 0.15474900E-01, -.38072100E+00, -.35916600E+00, -.12398600E+00, -.63360300E+02, 0.33146600E+03, 0.56356500E+02, 0.31728500E+02, -.78447700E+02, -.60378600E+02, -.63345100E+02, -.60108100E+01, 0.60549800E-02, 0.10686600E+00, 0.83606900E-01, -.24555900E-02, -.65903800E-02, -.13915400E-01, 0.22330900E+00, 0.83443100E-03, -.70578100E+00, 0.66125200E+00, 0.27819500E+00, 0.51985900E-01, -.71316500E-02, -.25112700E+00, -.42643600E+00, -.31765500E-02, 0.10994400E+01, 0.28291100E-02, 0.70606100E+01, -.10494900E+02, -.69581800E-02, -.63022100E+00, -.80210100E+00, 0.21775700E-01, 0.51225900E+00, 0.45064000E-02, 0.10071600E+02, -.40920400E+01, 0.40178700E+01, -.11539700E+02, -.64016700E+01, 0.56715200E+02, -.10958900E+02, 0.17481200E+02, 0.26271800E-01, 0.22267300E-01, -.29693000E+01, 0.32881200E+01, -.22430000E-01, 0.96795000E+01, 0.10005200E-02, -.28736800E-01 }, { -.55624200E+00, -.19407200E+00, 0.66457900E+00, 0.36106700E+00, 0.42364700E+00, 0.17163500E+01, 0.10914900E+01, -.61607300E+00, 0.25255100E+00, -.28538900E+00, -.93429400E-01, -.25012900E+00, -.60364800E+00, 0.24454400E+01, -.10945200E+00, -.19419900E+01, -.51614300E+00, -.15855900E+01, -.63489100E+00, 0.30052700E+00, 0.75241700E+00, -.13608500E+00, -.55796100E+00, 0.49596800E+00, -.11258500E+00, 0.12395000E+00, -.14385600E+00, 0.28898700E-01, 0.12303900E+01, 0.23181300E+00, 0.18532000E+01, -.27420900E+00, -.24523000E+00, -.27102900E+00, -.43543200E+01, 0.10331700E+00, 0.19793000E+00, 0.39373700E+00, -.24458100E+00, -.21714300E-01, 0.20352200E+00, 0.17650400E+00, -.13012100E+01, 0.49496000E+00, -.10235200E+00, -.11705200E+00, 0.13715500E+00, 0.95071700E-01, -.58160600E-01, 0.94030900E-01, -.16820100E+00, 0.74519100E-01, 0.49376700E+00, 0.17076500E-01, 0.56917000E+01, 0.26152000E+00, 0.14548500E-01, 0.63071000E+00, 0.10270700E+02, 0.62665000E+01, -.15321700E+02, 0.14372300E+01, 0.82835600E+01, 0.55771200E+01, -.11654600E+00, 0.36470400E+00, -.81163600E-01, -.23978400E-01, 0.20434400E+00, 0.10774700E+00, -.67552500E+00, -.16447500E-01, -.26273200E+03, 0.15478400E+03, 0.16407800E+03, 0.13404800E+03, -.86540600E+02, -.19505100E+03, -.24075800E+03, 0.15264500E+03, 0.11665100E+03, 0.13386100E+03, 0.28800800E+02, -.29724700E+02, -.10795700E+03, 0.96695800E+02, 0.42581100E+02, -.16191300E+02, 0.70989100E+02, -.18122700E+02, 0.11777900E+03, 0.18763600E+03, -.22930700E+03, -.27881600E+02, -.11480400E+03, 0.18628400E+03, -.31691900E+03, 0.10460800E+03, 0.29022400E+03, 0.23972400E+03, -.26549800E+03, -.14661900E+03, -.18136000E+02, 0.24341600E+03, -.54849400E+03, 0.31507800E+03, 0.35498800E+02, 0.64320800E+02, 0.13651400E+03, -.13889200E+03, 0.13875100E+03, 0.67586400E+02, 0.16012900E+03, 0.48012000E+02, 0.30912000E+02, -.79354400E+02, -.86009800E+02, 0.17227300E+03, 0.16829700E+03, -.72520400E+02, -.31952900E+03, 0.19863900E+03, 0.32152000E+03, 0.28533700E+03, -.40268900E+03, -.10344200E+03, 0.76182700E+02, 0.26918200E+03, 0.19282800E+03, -.11162900E+03, 0.12879500E+03, 0.16783300E+03, -.20057700E+03, 0.15226800E+02, -.11733500E+03, 0.17696000E+03, 0.52302900E-01, 0.27622800E+00, -.83822600E-01, -.58261800E-01, 0.18111700E+00, 0.30304300E+00, -.16831100E+00, -.70013600E-01, 0.48816900E-01, 0.28996100E+00, -.12545800E+00, -.70978500E-01, 0.22148500E+00, 0.24836600E+00, -.24874100E+00, -.75315400E-01, 0.22328800E+03, -.17908600E+03, 0.59308500E+02, 0.58385400E+02, -.11801700E+03, 0.12713400E+02, -.21317800E+03, 0.68597100E+02, -.27881700E+03, 0.41592600E+02, 0.49058400E+02, 0.52033900E+02, 0.28269600E+02, -.86317200E+02, 0.38251500E+02, 0.41526100E+02, 0.16213900E+01, -.11181000E+01, -.14174800E+01, -.80932800E+00, 0.92461500E+00, 0.35486500E+00, -.25346700E+01, -.86134700E+00, -.64461700E+03, 0.21877900E+02, -.50187400E+02, 0.67786600E+02, 0.27978300E+03, -.29364000E+03, -.22729900E+02, 0.42719300E+02, 0.50550500E-01, -.38411700E+00, 0.87921400E-01, 0.15641900E-01, -.16138800E+00, 0.12132900E-01, 0.91869400E+00, -.17342600E-01, 0.10531000E+01, -.98828200E+00, -.78603300E+00, -.46863900E+00, 0.40264300E+00, 0.97975400E-01, -.21335800E+01, -.50870900E+00, 0.24126800E+00, 0.10224600E+00, -.97040600E+01, -.24026400E+01, 0.18087200E-01, 0.47883900E+00, 0.22416000E+01, 0.39480500E-01, -.13425000E+01, 0.50547100E-01, -.41807700E+02, 0.32446000E+02, 0.29556900E+02, 0.70974000E+02, 0.45162900E+01, -.54856700E+02, 0.62508100E+02, -.36586400E+02, 0.62754000E-01, 0.10921700E+00, -.28244700E+02, 0.17656400E+02, -.33823600E+00, 0.35959400E+02, -.59688400E-01, -.12431900E+00 }, { 0.32559800E+00, 0.27648100E+00, -.61939300E+00, -.44885900E+00, -.12223100E+00, 0.12395200E+01, -.19359300E+01, -.85082200E+00, -.10064200E+00, 0.71737400E-01, -.10204900E+00, -.23229600E+00, -.43339100E-01, -.12483800E+01, 0.63802300E+00, 0.98542900E+00, 0.79338000E+00, -.75591800E+00, -.38903800E+00, -.23725600E+00, 0.29989700E+00, 0.23011700E+00, 0.54504400E+00, -.57372000E+00, -.19842000E-01, -.24368100E+00, 0.82902000E-02, 0.31192600E-01, -.11699000E+01, -.17147200E+00, -.42915700E+01, 0.26405300E+00, 0.42984300E+00, 0.93213000E-01, -.19710500E+01, 0.74544900E-01, -.61555300E-01, -.65143400E-01, -.66805300E+00, -.51156300E-01, -.18972200E+00, 0.28465600E+00, -.10860300E+01, 0.39375500E+00, -.55969600E-01, 0.96662800E+00, -.87019100E-01, -.68844900E+00, -.76641200E-01, 0.14218500E+00, -.57015000E-01, 0.43504200E-01, 0.57990800E+00, -.58677700E-01, 0.22928700E+01, 0.45525000E+00, 0.56391900E-01, -.36815400E+00, 0.62417800E+00, 0.40773100E+01, -.12956300E+01, -.86989100E-01, 0.50104400E+01, 0.54152100E+01, 0.34998100E-01, 0.17657200E+00, -.12030500E-01, -.91620200E-01, 0.17904900E-01, -.15202600E+00, -.38392400E+00, -.58303700E-01, -.17779200E+03, 0.22381700E+03, -.69435000E+02, 0.72070900E+01, 0.10660400E+03, -.10403300E+03, -.38109100E+02, 0.56234300E+01, 0.25406500E+03, -.10181600E+03, 0.57045600E+02, 0.79322100E+02, -.11177300E+03, 0.39047100E+02, -.40182500E+02, 0.10072900E+03, -.94440400E+01, -.14565400E+02, 0.12695400E+03, 0.95545200E+02, -.17764300E+03, -.67644900E+02, -.10853600E+03, 0.11898900E+03, 0.17866400E+03, 0.53272000E+02, -.11600400E+03, -.69111300E+02, 0.10203200E+03, 0.13257400E+03, 0.17825700E+03, -.42442300E+02, -.41866200E+03, 0.11438300E+03, 0.82018800E+02, 0.75418700E+02, 0.50455200E+02, -.16648000E+03, 0.16688300E+02, 0.76940400E+02, 0.22511100E+03, 0.25748700E+02, -.21544200E+02, 0.42468700E+02, -.12850700E+03, 0.43988700E+02, 0.80759700E+02, 0.71691100E+02, -.11446700E+03, 0.44510600E+02, 0.73424200E+02, 0.12356000E+03, -.89346700E+02, -.59969500E+02, 0.84243400E+02, 0.15313500E+03, 0.23012300E+03, -.22278600E+03, 0.82660600E+02, 0.59405400E+02, -.23709400E+03, 0.14606000E+03, -.11242900E+03, 0.12389000E+03, 0.12977400E+00, 0.15256000E+00, -.35666700E-01, -.14778100E+00, -.58397600E-02, -.11853200E+00, -.38454500E+00, -.15110800E+00, 0.11680700E+00, 0.16628900E+00, -.39238500E-01, -.15173900E+00, 0.14422100E-01, -.13614300E+00, -.41404200E+00, -.14505500E+00, 0.16496300E+03, 0.29599400E+02, -.71561900E+02, -.39001600E+02, -.11763300E+02, 0.56221800E+02, -.58205400E+02, -.40709000E+02, -.12440700E+03, 0.37598700E+02, 0.16120800E+02, 0.20835800E+02, 0.21146500E+02, -.32530300E+02, 0.96142200E+02, 0.26206900E+02, -.47733000E+00, -.48984100E-01, 0.22414200E+00, -.27737500E+00, 0.92898400E-01, -.22529600E+00, -.13906400E+01, -.65751300E+00, -.10082700E+04, 0.41857700E+03, 0.21363300E+03, 0.18399600E+03, 0.30791200E+02, -.37484400E+03, 0.38897300E+02, 0.12575500E+03, 0.45972100E-01, -.15987800E+00, 0.11208500E-01, 0.43089400E-01, -.64147300E-01, 0.19244600E+00, 0.34021600E+00, -.29539400E-01, -.10598300E+00, -.20435800E+00, 0.65990200E-01, -.14979300E+00, 0.49591200E-01, 0.45532800E-01, -.63921700E+00, -.38629700E+00, 0.53962900E+00, 0.63654600E-01, -.18600400E+02, 0.16222900E+02, 0.36441000E-01, -.21058500E+00, 0.72235300E+00, -.24505800E-01, -.36079500E+00, 0.44706000E-01, 0.71814900E+02, 0.50523100E+02, 0.13000300E+02, -.53750300E+02, 0.20015900E+02, -.59150000E+01, 0.29201200E+02, -.13770800E+02, 0.38793900E-01, 0.57700300E-01, 0.23353000E+00, 0.12940800E+02, 0.79745900E-02, 0.33907300E+02, -.48917400E-01, 0.22487900E-01 }, { -.45708400E+00, -.82464800E-01, -.38242200E+00, 0.93463000E+00, 0.13040200E+01, 0.18330900E+00, -.19919800E+01, -.40693200E+00, -.24723100E+00, 0.31286600E+00, 0.60888400E-01, 0.12477500E+00, 0.47054200E+00, -.16471500E+01, 0.21612200E+00, 0.19123800E+01, 0.42045700E+00, 0.68555700E+00, 0.17093400E+00, -.58799700E+00, 0.63978800E+00, -.12489500E+00, -.67110400E+00, -.70709400E-01, -.13542100E-01, 0.20869500E-01, -.50779900E+00, -.86562800E-01, -.12709900E+01, 0.41512900E-02, -.49437100E+00, 0.15570700E+00, 0.21406800E+00, 0.17203500E+00, -.23876300E+00, -.11899700E+00, -.18407700E+00, -.34909400E-01, 0.56210600E-01, 0.10771300E-01, -.26130800E+00, -.14687700E+00, -.80100600E+00, 0.51221000E+00, 0.15144700E+00, 0.33122900E+00, 0.87228200E-01, -.85299900E+00, -.24121300E-01, 0.25046400E-01, -.27338200E+00, -.35066300E-01, 0.56859600E+00, 0.32586700E-01, 0.15149700E+01, 0.69917500E-01, 0.69570700E-01, 0.88026000E-01, 0.46982500E+00, -.22539200E+00, 0.22147800E+01, -.16884200E+00, 0.59577200E+00, -.31728700E+00, 0.14086600E+00, -.74659300E-01, -.89564100E-01, 0.20547000E-01, -.23458000E-01, -.94933800E-01, 0.10134200E+00, 0.73558100E-02, -.43961200E+02, 0.10315600E+03, -.98980400E+02, -.71679000E+02, 0.15534500E+03, -.63002400E+02, -.11220400E+03, -.95476200E+02, 0.12783000E+03, -.14303800E+03, 0.23438800E+02, 0.28888300E+02, -.37258100E+02, 0.94486100E+01, -.21871000E+01, 0.44349300E+02, 0.21035700E+03, 0.91127100E+02, 0.24151400E-01, -.63698500E+02, -.44157000E+02, 0.43977400E+02, 0.11611500E+03, -.59381700E+02, -.17053200E+03, 0.17966000E+03, 0.38161500E+02, 0.60418500E+02, -.26593600E+02, -.53071000E+02, 0.15707800E+02, 0.60704900E+02, -.44589900E+03, 0.15777400E+03, 0.33589100E+02, 0.84531300E+02, 0.79655800E+02, -.20272700E+03, 0.38636800E+02, 0.81867900E+02, 0.41754200E+03, -.22501800E+03, -.11288100E+03, -.10477300E+03, 0.43822700E+02, 0.17960400E+03, 0.11141700E+03, -.74627000E+02, 0.12622500E+03, 0.15964800E+02, -.13342600E+02, -.62148900E+02, 0.50863100E+02, 0.43444600E+02, 0.12060000E+02, -.48597100E+02, 0.42757300E+03, -.27446800E+03, -.92739300E+02, -.10755500E+03, -.35428400E+02, 0.21133700E+03, 0.20005200E+03, -.56212000E+02, 0.21188100E+00, -.97291300E-01, -.81914100E-01, 0.55124400E-01, -.11520100E+00, -.99773800E-01, 0.56028100E-01, 0.17572000E-01, 0.18491600E+00, -.81223200E-01, -.82138900E-01, 0.41710500E-01, -.87059500E-01, -.10000500E+00, 0.69714300E-01, 0.10101100E-01, -.37355000E+02, 0.82043200E+02, -.85561600E+01, -.15044700E+02, 0.12152300E+02, -.17668100E+02, -.90730500E+02, -.14772900E+02, -.31045800E+02, 0.24614700E+02, 0.99870700E+01, 0.10557500E+02, -.25386900E+01, -.80781200E+01, 0.42800000E+02, 0.13962800E+02, -.10485800E+01, 0.73792500E+00, 0.57275500E+00, 0.20412600E+00, -.43640800E+00, -.15575600E+00, -.56871400E+00, -.47547900E-02, -.49362500E+03, 0.36301300E+03, 0.73838300E+02, 0.10143500E+03, -.13958300E+02, -.20929700E+03, -.24451500E+01, 0.37098600E+02, 0.20268100E-01, 0.82832900E-01, 0.82818100E-01, 0.53847900E-02, -.82266000E-01, 0.10983700E+00, -.13934600E+00, -.77227900E-02, -.56337500E+00, 0.46125600E+00, 0.38733800E+00, 0.79081000E-01, -.24383300E+00, 0.32245800E-01, -.44117300E+00, -.21078000E-01, 0.92751400E+00, -.10727800E-01, -.41437100E+01, 0.22398300E+01, 0.19439500E-02, -.12852600E+01, -.10736400E+01, -.45499300E-02, 0.89661600E+00, -.14335800E-02, -.21387100E+02, 0.22120500E+02, 0.43064900E+02, -.19671300E+02, 0.24125300E+01, 0.37756500E+02, -.94369300E+01, -.59714600E+02, 0.52169400E-02, -.13610900E-01, -.19441600E+02, 0.94915200E+01, 0.64975300E-01, 0.22419800E+02, 0.42007300E-02, 0.61188900E-02 }, { 0.28521400E+01, 0.34781200E+01, -.20994400E+01, 0.14514600E+00, -.89313800E+00, -.15949400E+01, 0.44183300E+01, 0.40042700E+01, -.20287000E+01, -.32234300E+01, 0.10925900E+01, 0.58714400E+00, 0.17816400E+00, -.10026200E+01, 0.27491200E+01, 0.41131400E+01, 0.47030200E+01, 0.35772800E+01, 0.11830400E+01, -.67828200E+00, -.18436600E+01, 0.68781200E+00, 0.18438800E+01, -.21042400E+01, 0.20513500E+00, -.86439700E+00, 0.28654600E+01, 0.99179700E+00, -.57148100E+00, -.54036800E+00, 0.61019200E+00, 0.20366000E+00, 0.92746000E+00, -.22210900E+00, -.15022600E+01, -.74790600E+00, 0.30377800E+00, -.12376000E+01, 0.14489200E+01, 0.60624300E+00, -.94949400E+00, -.35925200E+01, 0.28075000E+01, -.10677300E+00, 0.89197700E+00, 0.32772200E+01, -.85787500E+00, -.17354300E+01, -.26058800E-01, -.23948000E+00, 0.16823700E+00, 0.72238600E+00, -.30211000E+00, -.31561900E+00, -.27956600E+01, 0.61337200E+00, -.18430400E+00, -.61287700E+00, 0.98258900E+00, 0.17475500E+01, 0.13238000E+01, 0.19686200E+02, 0.20200800E+02, -.46297400E+01, -.66785900E+00, -.17513700E+01, 0.13237900E+00, 0.86681200E+00, -.54815800E+00, 0.21869100E+00, 0.26158500E+01, 0.73771300E+00, 0.10031600E+04, -.10960500E+04, -.49383600E+03, -.75910700E+03, 0.47422100E+03, 0.82028000E+03, 0.41677600E+03, -.81641100E+03, -.83439300E+02, -.18342200E+03, -.47966300E+02, -.12949000E+03, 0.13333300E+03, 0.32291800E+03, 0.30823300E+03, -.13944100E+03, 0.11434800E+04, -.37785200E+03, -.18299500E+03, -.17679800E+03, -.16469800E+03, 0.60224800E+03, 0.80817900E+03, -.17646600E+03, 0.41696200E+03, -.34009300E+03, -.21645400E+03, -.29656700E+03, 0.13487900E+03, 0.29128000E+03, 0.23524500E+03, -.33719400E+03, -.29357400E+03, 0.82095800E+03, 0.11078500E+03, 0.86952200E+02, -.47760300E+02, 0.31946100E+02, -.10520600E+03, 0.80034900E+02, -.95318400E+03, -.58632400E+03, -.22748500E+03, -.17260100E+03, 0.86915900E+03, 0.41953300E+03, 0.56679700E+03, -.16895200E+03, 0.22834900E+03, 0.32421800E+03, -.20120800E+03, -.24755700E+03, 0.14677000E+03, 0.50017700E+03, 0.45414700E+03, -.30604000E+03, 0.20118400E+04, -.17729200E+03, -.14465500E+03, 0.71161700E+02, -.47941700E+03, 0.64286900E+03, 0.54511500E+03, 0.27827900E+02, -.14142200E+01, -.18950900E+01, 0.12631700E+00, 0.13218900E+01, -.62121800E+00, 0.25744000E+00, 0.19450200E+01, 0.13760200E+01, -.12225600E+01, -.19423000E+01, 0.16194800E+00, 0.12234900E+01, -.64873900E+00, 0.17069400E+00, 0.19148900E+01, 0.12067400E+01, 0.24693500E+03, -.19118300E+03, -.15497000E+03, -.18359500E+03, 0.24477300E+03, 0.48673600E+03, 0.12631400E+03, -.15088900E+03, -.76144000E+03, 0.56082700E+03, 0.11095300E+03, 0.15931200E+03, 0.61296500E+02, -.20473800E+03, -.40796100E+02, 0.14581500E+03, -.57182900E+01, 0.40239200E+01, 0.40641500E+00, -.20929500E+00, 0.24873400E+00, -.40743400E+01, 0.34031900E+01, 0.56452700E+00, 0.10362000E+04, -.54099800E+02, -.89424300E+02, -.26263000E+03, -.20858500E+03, -.14576900E+03, -.16486800E+03, -.24499600E+03, -.84396000E-01, 0.15107100E+01, -.50409000E-01, -.30172900E+00, 0.40223900E+00, -.23891000E+00, -.25394400E+01, 0.54932700E-01, -.22679900E+01, 0.31015900E+01, 0.39433900E+00, -.41685500E+00, 0.22293100E+00, -.26427500E+01, 0.19546000E+01, 0.10423600E+00, -.63215400E+01, -.16140300E+01, 0.78354200E+01, -.10191900E+03, -.13640700E+01, -.51158800E+01, -.59665800E+01, 0.12221000E+01, 0.35814400E+01, -.14161100E+01, -.77060600E+02, -.44889700E+02, 0.21373100E+03, -.40090500E+02, 0.31006300E+02, 0.15778300E+03, -.18988500E+02, -.33481400E+03, -.11238100E+01, -.13479100E+01, 0.55019400E+02, 0.84835900E+02, -.82986000E+00, 0.32310000E+02, 0.14829400E+01, -.10634700E+01 }, { -.12544300E+01, -.42343700E+00, 0.10500000E+01, 0.51736100E+00, 0.37479100E+00, 0.27580200E+01, 0.25127400E+01, -.77181500E+00, 0.33637400E+00, -.48979700E+00, -.36207700E-01, 0.12122700E+00, -.78758800E+00, 0.41823100E+01, -.59298900E+00, -.29801500E+01, -.16364600E+01, -.12371100E+01, -.21697100E+00, 0.66710000E+00, -.11057300E+00, -.10498800E+00, 0.19556400E-01, 0.49932300E+00, 0.11981400E+00, 0.36476200E+00, 0.60827600E+00, 0.17077900E+00, 0.14022300E+01, -.55996400E+00, 0.41404200E+01, -.11977900E+00, -.82384900E+00, 0.16471400E-01, -.30373200E+01, 0.83358300E-01, -.36049000E+00, -.67192600E+00, 0.13957300E+01, -.17144000E+00, -.60267900E+00, -.18290800E+01, -.18556400E+01, 0.88597300E+00, 0.11770400E+01, -.24086500E+01, 0.45309600E+00, -.31100200E+01, -.55558800E+00, 0.29744000E-01, 0.21896000E+00, -.51693400E-01, 0.26421200E+00, -.45958200E+00, 0.32779200E+01, -.26324500E+00, -.85164600E-01, -.16098200E+01, -.92471100E+00, 0.36429200E+00, -.13893400E+01, -.19848800E+00, 0.12991800E+02, -.14317100E+01, -.20746900E+01, -.13391900E+00, -.26104300E+00, 0.15558500E+00, 0.25346400E+00, -.81353200E+00, -.95865700E+00, 0.70793200E-01, 0.98758500E+03, -.26189900E+03, -.23774000E+03, -.24621100E+03, 0.42283500E+02, 0.41473600E+03, 0.37650500E+03, -.20436300E+03, 0.25989200E+03, -.45590900E+03, 0.75273100E+01, 0.18848300E+02, -.72251900E+02, -.28647300E+02, -.72522400E+02, -.96534200E+01, 0.21518400E+03, -.10621700E+02, 0.81167100E+02, -.16413400E+02, -.24232900E+03, -.59158700E+02, -.14198800E+03, -.40062300E+02, -.35370800E+02, 0.21090500E+03, 0.34571800E+02, -.50410600E+00, -.11075500E+03, 0.14077300E+02, 0.25229400E+03, -.18950500E+02, 0.57658200E+02, 0.10884900E+03, -.55387700E+02, -.29521000E+02, 0.42949800E+02, -.51138700E+02, 0.22507100E+02, -.43781200E+02, -.39583300E+03, -.51487800E+03, -.19213300E+03, -.14716300E+03, 0.42016800E+03, -.13788500E+03, 0.21679900E+03, -.15495500E+03, 0.10503300E+03, 0.22057000E+02, -.90947900E+02, -.16718900E+03, 0.30768500E+02, 0.60037500E+02, 0.21352500E+03, -.19950300E+03, -.37624600E+03, 0.16873500E+03, -.12400700E+03, -.17369600E+03, 0.30964800E+02, -.25571100E+03, -.16357600E+03, -.24532700E+03, -.24749100E+01, -.71975700E-01, -.50393200E+00, 0.10623700E+00, 0.33064300E+00, -.96933700E+00, -.41292700E+00, 0.42351800E-01, -.24598800E+01, -.74871700E-01, -.39661600E+00, 0.15594200E+00, 0.29309500E+00, -.94765200E+00, -.44676100E+00, 0.83291000E-01, 0.93949600E+03, -.19509600E+03, -.19340100E+03, -.27471700E+03, -.79040000E+02, 0.32002500E+03, 0.17593400E+01, -.23236300E+03, -.52305500E+02, 0.11942700E+03, 0.40505800E+02, 0.29919400E+02, -.14283500E+01, -.13201900E+02, 0.93709900E+02, 0.38102100E+02, 0.24948900E+00, 0.13230900E+01, 0.13000200E+01, 0.85767800E+00, -.13603900E+01, 0.43216600E+00, -.48642300E+01, 0.10659100E+01, 0.47572900E+03, 0.36422700E+03, 0.98746500E+02, 0.91107100E+02, -.99959500E+02, 0.22442000E+03, -.10981000E+03, 0.15547000E+03, 0.18284400E+01, 0.15810700E+00, 0.10284400E+00, -.11175600E+00, -.27095700E+00, 0.64800100E+00, 0.97701600E+00, 0.54783300E-02, 0.17928000E+01, 0.81154400E+00, 0.10881300E+01, 0.52637600E+00, -.10683800E+01, 0.87351800E+00, -.38873000E+01, 0.71941000E+00, -.10100200E+02, -.60287100E+00, 0.22317200E+02, -.82745300E+02, -.63348800E+00, -.81562600E+01, -.31549300E+01, 0.69052600E+00, 0.24018400E+01, -.57820400E+00, 0.14983300E+03, -.54983700E+02, 0.38231900E+02, -.55863400E+02, -.37266300E+02, -.33549900E+02, -.95744700E+01, 0.15066400E+03, -.52563500E+00, -.47487300E+00, -.13808500E+01, 0.10671300E+03, -.77681900E+00, -.78286100E+02, 0.61160100E+00, -.84034700E+00 }, { -.30897600E+00, -.12759600E+00, 0.51203500E+00, 0.23666000E+00, 0.17935500E+00, 0.11217300E+01, 0.81170400E+00, -.52432700E+00, 0.66510000E-01, -.14324800E+00, 0.11150800E-01, 0.73542900E-01, -.29802500E+00, 0.13685900E+01, -.96230800E-01, -.72508200E+00, -.54995500E+00, -.14866900E+00, 0.55357200E-01, 0.11178200E+00, 0.39217400E-01, -.65789800E-01, -.47694900E-01, 0.12785700E+00, -.19808900E-01, 0.44588100E-01, -.14504100E+00, -.41619300E-01, -.64993300E-01, 0.36664200E-01, -.26315600E+00, 0.37240200E-01, -.78133800E-01, -.48490500E-01, -.12999300E+01, 0.79343500E-01, -.21697800E-01, 0.77483600E-01, -.25769500E+00, -.42895900E-01, -.16942900E-01, 0.12176000E+00, 0.11696600E+00, 0.10567400E+00, 0.10289900E-01, -.77917800E-01, 0.10072500E+00, -.34413100E+00, -.17390600E-01, 0.25549700E-01, -.61379800E-01, 0.80049600E+00, 0.41391300E+00, 0.32959500E-01, 0.21265600E+01, 0.14445400E+00, 0.68446100E-01, 0.16555100E+00, 0.29668200E+00, 0.20491900E+00, -.12603500E+00, 0.19920200E-01, 0.21702400E+00, 0.13031600E+01, 0.46099900E+00, 0.90486700E-01, 0.55673600E-01, 0.26747900E+00, -.47621000E-01, 0.11194100E+00, -.76710800E-01, -.21518500E-01, -.22065100E+03, 0.10979400E+03, -.35233300E+01, -.23284800E+01, 0.80066700E+02, -.10714600E+03, -.83987900E+02, -.89665800E+01, -.10035200E+02, 0.80543000E+02, -.36698400E+01, 0.11884400E+02, -.11608800E+01, 0.39849600E+01, 0.24445200E+02, 0.26482100E+02, -.24000800E+02, 0.24100800E+02, -.79311900E+01, 0.36118200E+02, 0.10149600E+02, -.78590200E+01, 0.25181300E+02, 0.44045900E+02, -.30387700E+02, 0.50784000E+02, -.10620900E+02, 0.26197700E+01, 0.41650200E+02, 0.70469500E+01, -.23246800E+02, 0.15983800E+02, -.23383900E+03, 0.31785500E+02, 0.31157700E+02, 0.41295600E+02, 0.26134200E+02, -.80664300E+02, 0.24655900E+02, 0.40927400E+02, 0.25046300E+03, 0.72129700E+02, 0.17806300E+02, 0.48898700E+00, -.11810100E+03, 0.73867300E+02, -.75683800E+01, 0.16669300E+02, -.43605200E+02, 0.36729600E+02, 0.26045400E+02, 0.57925300E+02, -.14509900E+02, -.25733600E+02, 0.10624300E+02, 0.82860800E+02, 0.92265600E+02, -.15347600E+03, 0.45705700E+02, 0.86270200E+02, -.66237600E+02, 0.81648200E+02, 0.48917400E+02, 0.12026100E+03, 0.57048100E+00, 0.53841400E-01, 0.14282800E+00, 0.16334200E+00, -.11012000E+00, 0.13725800E+00, -.12092200E+00, -.20691900E-01, 0.56614000E+00, 0.64204700E-01, 0.10655800E+00, 0.14277800E+00, -.85150300E-01, 0.13543600E+00, -.11650700E+00, -.33263800E-01, -.16266400E+03, 0.43543100E+02, 0.17767800E+02, 0.31212900E+02, 0.34130300E+02, -.59420600E+02, -.24462800E+02, 0.23456800E+02, 0.18769900E+02, -.19532800E+02, -.62250400E+01, -.75808100E+01, -.14586500E+01, 0.22251800E+01, -.80974500E+01, -.79036100E+01, -.24566800E+00, -.41697200E+00, -.67176600E-01, 0.65372500E+00, 0.12469100E+00, -.16665300E+00, 0.28841600E-01, -.28234000E+00, -.42275900E+03, 0.17182200E+02, 0.38548200E+02, 0.36565600E+02, 0.44557600E+02, -.17543500E+03, -.25494100E+02, -.11054300E+02, -.37656500E+00, -.97194100E-01, 0.11305000E-01, -.28256300E+00, 0.38971100E-02, -.81660100E-01, 0.55217400E-01, -.91619000E-02, -.43426800E+00, -.29658600E+00, -.13581400E+00, 0.54908800E+00, 0.13318500E+00, -.14778000E+00, 0.14549000E+00, -.20956400E+00, 0.23418600E+01, 0.50177000E-01, -.56311800E+01, 0.24159200E+02, 0.42180900E-01, 0.13861600E+01, 0.68393100E+00, -.45894400E-01, -.55648500E+00, 0.39562600E-01, -.11477300E+02, 0.27771200E+02, 0.48843300E+01, -.35703900E+01, 0.66746600E+01, 0.62839200E+01, 0.90822600E+01, -.54880700E+02, 0.61106300E-01, 0.47944300E-01, -.24320900E+01, -.26023500E+02, 0.29059000E-02, 0.33229700E+02, -.44833700E-01, 0.83412100E-01 }, { -.81383100E+00, -.28520600E+00, 0.10776000E+01, -.22797200E-01, 0.63566700E+00, 0.23535500E+01, 0.13079500E+01, -.10436600E+01, 0.37262300E+00, -.10102400E+01, 0.83755900E-02, 0.35575000E+00, -.11977700E+01, 0.61622100E+01, -.85885300E+00, -.35498800E+01, -.10749600E+01, -.29603300E+01, -.14728600E+01, 0.17155100E+01, 0.80892900E-01, -.40685600E-01, -.14247500E+00, 0.52951600E-01, 0.15143900E-01, -.32358600E-01, -.93917500E-01, -.60440800E-01, 0.75671800E-02, 0.41423900E-01, -.42754600E+00, 0.90887300E-01, 0.31202000E-01, -.38797200E-01, -.11593900E+01, 0.57804200E-01, -.10972000E+00, -.18267800E+00, 0.29559200E+00, -.24317100E-01, 0.13539200E+00, -.14178600E-01, 0.16511500E+01, -.22020300E+00, 0.27190200E+00, -.13613800E+01, 0.14453300E+00, 0.67049200E+00, 0.49623900E-01, -.15943200E-01, 0.27905900E+00, 0.23491700E-01, -.49246800E+00, -.74407700E-02, 0.13105900E+00, -.16370200E+00, -.15068600E+00, 0.23362500E+00, -.41500600E+00, -.18221300E+00, 0.13236600E+01, 0.13553100E-01, -.62934200E+00, -.30184400E+00, -.14867600E+01, 0.34933300E+00, -.78358400E-01, -.82880900E-02, 0.31849500E+00, -.17695600E+00, -.77651200E+00, -.97628500E-01, 0.51736900E+03, -.41826100E+03, 0.49367700E+02, 0.19625300E+02, -.22189000E+03, 0.33714000E+03, 0.42341700E+03, 0.10510400E+03, -.64097000E+02, 0.68938100E+02, -.23685700E+02, -.25869700E+02, 0.13778000E+02, -.18631300E+01, -.69983500E+02, -.84168500E+02, -.53762300E+03, -.26081600E+02, 0.10293500E+03, 0.13161000E+03, 0.12416600E+03, -.11069600E+03, -.37978800E+03, 0.10232800E+03, 0.22931800E+03, -.23967600E+03, 0.12718100E+02, -.57104300E+02, -.55436800E+02, 0.75022300E+02, 0.10397300E+03, -.65603100E+02, 0.88069900E+03, -.32488500E+03, -.77192300E+02, -.15141700E+03, -.15490000E+03, 0.38383800E+03, -.76834100E+02, -.14128900E+03, -.82128400E+03, 0.35377100E+03, 0.84913600E+02, 0.12668200E+03, -.25375300E+02, -.35333200E+03, -.12797300E+03, 0.23494100E+02, -.95402100E+02, -.72991900E+01, -.15602800E+02, -.10332200E+02, -.37734800E+01, 0.20004300E+02, 0.54603600E+00, -.57447800E+02, -.11445500E+04, 0.72707900E+03, 0.11528500E+03, 0.64515900E+02, 0.17894800E+03, -.54974400E+03, -.48902100E+03, -.97897300E+02, -.19115200E+01, 0.49080800E+00, -.34916300E+00, -.24764300E+00, 0.57965700E+00, -.27376100E+00, -.27363400E+00, -.26008400E+00, -.18392000E+01, 0.45126700E+00, -.24377300E+00, -.16121000E+00, 0.49787300E+00, -.25955700E+00, -.33252600E+00, -.17832000E+00, 0.50384400E+03, -.26131800E+03, -.96777500E+02, -.12503500E+03, -.34690600E+02, 0.18782300E+03, 0.20314900E+03, -.10241000E+03, 0.20282400E+03, -.36049000E+02, -.32167400E+02, -.40039000E+02, -.10895400E+02, 0.71916900E+02, -.50932900E+02, -.39713300E+02, 0.20488800E+01, -.10894600E+01, -.30806700E+00, 0.26833500E+00, 0.20604200E+00, 0.12656500E+00, -.14294000E+01, 0.65481500E+00, 0.12563900E+04, -.58265900E+03, -.71186000E+02, -.10670200E+03, -.44293000E+02, 0.53531900E+03, -.17374100E+02, 0.99517300E+02, 0.97079100E+00, -.29621500E+00, -.12518000E+00, -.12712700E+00, -.76666800E-01, 0.33757500E-01, 0.92528500E+00, 0.13406500E-01, 0.20374500E+01, -.86007000E+00, 0.49574600E-02, 0.44642900E+00, -.16033700E+00, 0.11282500E+00, -.13354400E+01, 0.58574300E+00, -.79770200E+01, 0.65421400E-01, 0.22551900E+02, -.52747200E+02, -.85947100E-03, -.28535300E+01, -.11225300E+00, 0.47044900E-01, -.42696500E-01, 0.33090700E-01, 0.13978500E+03, -.87796400E+02, -.12512600E+03, 0.16507800E+02, -.19396500E+02, -.16732100E+03, -.12371600E+02, 0.22498400E+03, -.51574100E-01, 0.59838100E-01, 0.41175900E+02, 0.34681800E+02, 0.45653700E-01, -.10935900E+03, -.34095600E-01, -.12432200E+00 }, { 0.40674000E+00, 0.53715000E+00, -.32147600E+00, 0.23345200E-01, -.10331500E+00, -.31223800E+00, -.14929900E+00, 0.43430100E+00, -.65804000E-01, -.23631500E+00, 0.65842000E-01, 0.23867500E+00, 0.38020500E-01, -.34186500E-01, 0.10935200E+00, 0.74391700E+00, 0.68126300E+00, 0.22741800E+00, 0.16453000E-01, -.16749600E+00, -.14131200E+00, 0.12364100E+00, 0.27093300E+00, -.26153500E+00, 0.46215600E-01, -.10529200E+00, 0.28304400E+00, 0.10389200E+00, -.14738300E+00, -.74416700E-01, -.35674700E+00, 0.30412300E-01, 0.10402100E+00, 0.92854300E-01, 0.10412800E+01, -.25926100E-01, 0.29844200E-04, 0.22504300E-01, 0.25332700E+00, 0.33781600E-01, 0.34948200E-01, -.19044600E+00, -.18634000E+00, 0.83333100E-01, 0.82008000E-01, 0.39011500E-01, -.44226700E-01, 0.12635700E+00, 0.23230300E-03, -.14152500E-01, 0.46215300E-01, 0.50598000E-01, -.76154800E-01, -.40816200E-01, -.37637600E+00, 0.42838500E-01, -.32929300E-01, -.87723000E-01, 0.35525000E-01, 0.11076800E+00, 0.10009700E+00, 0.58407800E-01, -.31039600E-01, -.94995200E-01, 0.16418800E-01, 0.28166600E+01, 0.73721200E-02, 0.18018200E-01, -.11479000E-02, -.66582400E-02, 0.32818800E-01, -.38609400E-02, 0.16148300E+02, 0.43332100E+01, 0.55577500E+01, 0.21707700E+01, -.25835000E+01, -.26995100E+00, -.12540100E+02, -.45612400E+00, 0.71936100E+00, -.21856800E+00, -.49619300E-01, 0.40762600E+01, -.47880800E+01, -.82280500E+01, -.52431300E+01, 0.24589200E+01, 0.11279600E+02, -.33004400E+02, -.75439100E+01, 0.81532800E-01, -.26349700E+01, 0.50449700E+01, 0.13579700E+02, 0.29139700E+01, -.11319100E+02, 0.16221600E+02, 0.54759100E+01, 0.60353000E+01, -.92992900E+00, -.66650800E+01, -.11614000E+02, 0.35080600E+01, -.25610100E+02, -.79627400E+00, 0.28699500E+01, 0.63656200E+01, 0.20588200E+01, -.16311900E+02, -.31551200E+01, 0.60939600E+01, -.14633300E+00, 0.36766000E+01, 0.82962700E+01, 0.18747100E+01, -.10089700E+02, -.14777200E+02, -.18338900E+02, -.11008300E+01, 0.34456100E+01, -.13404900E+02, -.13562800E+01, 0.40742700E+01, -.36311500E+01, -.32095600E+01, 0.19345700E+01, 0.37116200E+01, -.15582000E+02, -.27103800E+01, -.10296900E+02, -.73117100E+01, 0.27787900E+01, 0.17975100E+01, 0.23095800E+02, -.52267000E+01, 0.66480200E-02, 0.20966900E-03, 0.19249400E-01, 0.52635500E-02, -.60695800E-02, -.12101700E-01, 0.50365000E-02, -.72783700E-02, 0.52572000E-02, 0.12281300E-02, 0.14540400E-01, 0.45114100E-02, -.35599200E-02, -.88853900E-02, 0.11944300E-01, -.62356800E-02, 0.17500100E+02, -.93020300E+01, -.24444800E+01, -.58667800E+01, -.88104500E+00, 0.24129500E+01, -.98840300E+00, -.82565300E+01, 0.97842900E+01, -.53951600E+01, -.51497200E+00, -.18890700E+01, -.13632500E+01, 0.31906500E+01, 0.14704500E+01, -.22532600E+01, 0.16814900E+00, -.12188400E+00, -.90289000E-02, 0.74798800E-01, -.76850800E-02, 0.79479300E-01, 0.62858200E-01, 0.26624500E-01, -.60837600E+01, -.15592000E+01, -.72442000E+00, -.29472600E+00, 0.12572300E+02, 0.73465700E+01, 0.38056800E+01, 0.26616100E+01, 0.14863800E-02, -.64502300E-02, 0.38942000E-02, -.21105400E-01, -.21089800E-02, -.46198200E-04, -.50521900E-01, -.41470600E-03, 0.76540100E-01, -.59921400E-01, -.15952100E-01, 0.62697400E-01, 0.46546100E-02, 0.50668300E-01, 0.63955900E-01, 0.12612400E-01, 0.33131300E-01, 0.15139500E-01, 0.16881900E+01, 0.23217700E+01, 0.17823600E-01, 0.18020700E+00, 0.65441900E-01, -.20436700E-01, -.89257000E-01, 0.15683800E-01, -.36612900E+01, 0.13190600E+01, 0.20911600E+01, 0.20809000E+01, -.15852800E+01, -.32102100E+01, 0.25294600E+01, -.32073700E+01, 0.10897700E-01, 0.95177200E-02, -.58649000E+00, -.21366300E+01, -.68478800E-02, -.14327400E+01, -.16392000E-01, 0.23263500E-01 }, { 0.16547500E+00, 0.68201000E-01, -.29945800E+00, 0.30330200E-01, -.65039600E-01, -.56947200E+00, -.48643800E+00, 0.25788700E+00, -.85198200E-01, 0.17315100E+00, -.35716500E-02, -.10115200E+00, 0.20132600E+00, -.11305800E+01, 0.17714900E+00, 0.67937100E+00, 0.32669700E+00, 0.26597700E+00, 0.38648800E-01, -.14835300E+00, 0.64449700E-01, 0.10547400E-02, -.10410900E+00, -.52864800E-01, -.33306900E-02, -.13357900E-01, 0.66137200E-01, 0.26082100E-01, -.82076200E-01, -.12598300E-02, -.28840300E-01, -.37245600E-01, 0.70627000E-01, 0.19076800E-01, 0.19979900E+00, -.71461200E-01, -.21948700E-02, -.13789800E-01, 0.56766000E-01, 0.59845600E-02, -.31026800E-02, -.70290100E-01, -.57431900E-01, -.12813000E-01, 0.30835300E-01, 0.10394200E+00, -.22716600E-01, -.12279300E+00, -.16277700E-02, 0.18486700E-02, 0.33472000E-02, -.27325000E-02, 0.15381600E-01, -.29799600E-02, -.45771900E+00, 0.25025400E-02, 0.14535400E-02, -.37903900E-01, 0.24249600E-01, -.28020200E-01, -.35982600E-01, 0.12855500E-01, -.13840000E-01, -.16602100E+00, -.40092100E-01, 0.14608300E-01, 0.52983700E+00, 0.31747800E-01, 0.13990900E-01, -.13993500E-01, 0.63770400E-02, -.15000400E-01, -.43163200E+02, 0.27836500E+02, -.58460800E+01, -.35894700E+01, 0.21649800E+02, -.23376100E+02, -.15539200E+02, -.10581100E+02, 0.19911600E+02, 0.37892500E+00, 0.11555100E+01, 0.60112700E+01, -.80447500E+01, 0.32044500E+01, -.13937500E+01, 0.75544400E+01, -.35282800E+01, -.31178300E+01, 0.55764300E+01, 0.83123300E+01, -.45176800E+01, -.22903700E+01, 0.35063800E+01, 0.10942000E+02, -.22387000E+02, 0.24558200E+02, 0.42271500E+01, 0.88419500E+01, -.26993000E+01, -.53547000E+01, -.27337000E+00, 0.69306000E+01, -.90416400E+02, 0.18308200E+02, 0.14333700E+02, 0.21171600E+02, 0.70313600E+01, -.36265900E+02, 0.24613700E+01, 0.21264400E+02, 0.40463500E+02, 0.73595600E+01, 0.19317300E+01, 0.46449200E+00, -.21029100E+02, 0.11187300E+02, 0.62315800E+01, 0.17455200E+01, 0.96262400E+00, -.16659200E+01, 0.69924200E+01, 0.93305300E+01, -.10112600E+02, -.16918600E+01, 0.13439100E-01, 0.10237400E+02, 0.35528800E+02, -.31188100E+02, -.43781100E+01, -.33496900E+01, -.49342500E+01, 0.29842700E+02, 0.24761600E+02, 0.78509400E+01, 0.61686500E-02, 0.41833400E-01, 0.78452400E-02, -.91828300E-03, 0.99088800E-02, -.14105400E-01, -.61675400E-02, -.30365300E-01, 0.53687300E-02, 0.43239400E-01, 0.56938300E-02, 0.33169700E-03, 0.12717600E-01, -.14505400E-01, -.58849600E-02, -.26502500E-01, -.28736100E+02, 0.13198500E+02, -.77523000E+00, -.50709800E+00, 0.92220400E+01, -.93404900E+01, -.22284500E+01, -.40257500E+01, 0.13634600E+02, -.83776300E+01, -.24524600E+01, -.30789200E+01, -.19454200E+01, 0.52334200E+01, 0.39306700E+01, -.32220900E+01, 0.95301000E-02, -.85853000E-01, 0.35341500E-01, 0.15329500E+00, -.18570800E-01, -.13768500E-01, -.51785300E-01, 0.55485200E-02, -.10519300E+03, 0.29737600E+02, 0.17744400E+02, 0.20629100E+02, 0.44755300E+01, -.43157400E+02, -.63561100E+01, 0.13034700E+02, 0.33398600E-02, -.36079200E-01, 0.16583100E-02, -.45462200E-01, -.16245800E-01, 0.13264600E-01, -.14255200E-01, -.21563900E-02, 0.14588000E-01, -.75855000E-01, 0.10927400E-01, 0.13124300E+00, -.15999400E-01, 0.86531700E-02, -.67645500E-02, 0.48882900E-02, 0.25163900E-01, 0.48128000E-01, 0.33238700E+00, 0.26001300E+01, 0.47525200E-01, 0.13361500E+00, 0.12126900E+00, -.49081300E-01, -.85925900E-01, 0.45465400E-01, -.37045900E+01, 0.35702400E+01, 0.12418700E+01, -.85459300E+00, 0.53267900E+00, -.34205500E+01, 0.25923600E+01, -.11011300E+02, 0.32729300E-01, 0.36131300E-01, -.53088100E+00, -.17281100E+01, 0.71326100E-01, 0.34273700E+01, -.47529100E-01, 0.54267500E-01 }, { 0.21513800E+00, 0.88983700E-01, -.35788800E+00, -.16668300E+00, -.12586200E+00, -.78349700E+00, -.56805900E+00, 0.36732700E+00, -.45801200E-01, 0.98720300E-01, -.80878500E-02, -.55680200E-01, 0.20413900E+00, -.95219600E+00, 0.73776700E-01, 0.50123000E+00, 0.38611700E+00, 0.97603100E-01, -.35211300E-01, -.78908700E-01, -.25981300E-01, 0.45667100E-01, 0.34679700E-01, -.87816800E-01, 0.13762300E-01, -.31310900E-01, 0.10217000E+00, 0.30174500E-01, 0.56898600E-01, -.25001800E-01, 0.20886600E+00, -.27761000E-01, 0.50199500E-01, 0.33415800E-01, 0.87836500E+00, -.55215400E-01, 0.15477200E-01, -.57263000E-01, 0.18075700E+00, 0.29757100E-01, 0.13163600E-01, -.86134600E-01, -.65043000E-01, -.74624000E-01, -.65911400E-02, 0.48367000E-01, -.69081600E-01, 0.24258000E+00, 0.12226000E-01, -.18590200E-01, 0.41941500E-01, 0.65997300E-02, -.11389700E+00, -.71689000E-02, -.76928500E+00, -.54122500E-01, -.22682500E-01, 0.61737600E-01, -.89843700E-01, -.11941800E+00, 0.22215400E-01, 0.53488100E-02, -.32756300E-01, -.11202900E+00, 0.17441200E-01, 0.75387800E-02, -.70785100E-03, 0.45204000E+00, 0.90295200E-02, -.80366600E-02, 0.92176800E-01, -.78922000E-02, -.34151700E+00, 0.78764600E+01, -.60356800E+01, -.53569200E+01, 0.27894400E+01, -.71995300E+00, -.34941800E+01, -.80459700E+01, 0.13295300E+02, 0.37002400E+01, 0.40957600E+01, 0.18535000E+01, -.64891200E+01, 0.34604100E+01, -.81432800E+00, 0.21753800E+01, 0.80252700E+01, 0.38728700E+01, 0.99910000E+01, 0.37359000E+01, -.38248800E+01, 0.49310400E+01, -.78595800E+00, 0.18345000E+01, 0.33359600E+01, -.20818900E+01, -.57222000E+00, 0.13546100E+01, -.38296400E+01, -.13040000E+01, 0.61902800E+01, 0.73375300E+00, -.78251100E+01, -.81766200E+01, 0.42603500E+01, 0.49254300E+01, 0.22924600E+01, -.72007600E+01, -.24686200E+01, 0.61842400E+01, 0.31224400E+02, 0.65172700E+01, -.84909200E+01, -.67384700E+01, -.46100000E+01, 0.91708900E+01, 0.30960800E+01, -.59240500E+01, 0.22332700E+01, 0.47773800E+01, 0.74048900E+01, 0.47961800E+01, -.56397000E+01, -.18370200E+01, -.10942700E+02, 0.39866400E+01, 0.22027700E+02, -.10289300E+02, -.13312800E+01, -.49482500E+01, 0.25577800E+01, 0.91124000E+01, 0.11659900E+02, -.31566900E+01, -.16134700E-02, 0.24482400E-01, -.67823400E-02, 0.24250600E-02, 0.13397000E-01, -.13608100E-01, 0.58319900E-01, -.16073500E-01, -.17302500E-03, 0.24085700E-01, -.44903200E-02, 0.37528900E-02, 0.12410100E-01, -.11340900E-01, 0.58441000E-01, -.13807100E-01, -.12076800E+02, 0.42994100E+01, -.12606400E+01, -.36555200E+00, 0.18213000E+01, -.71235000E+01, -.82538100E+00, -.21436200E+01, -.16216500E+02, 0.15018500E+01, 0.17760800E+01, 0.32447500E+01, 0.12485700E+01, -.65084000E+01, 0.24388500E+01, 0.26184400E+01, 0.27295900E-01, -.43592800E-01, 0.23600400E-01, 0.96712200E-01, -.21697200E-01, 0.18631900E-01, 0.11709600E+00, 0.14845800E-01, -.33176300E+02, -.15305500E+00, 0.29188600E+01, 0.50118000E+01, 0.56302800E+01, -.52601200E+01, 0.14758300E+02, 0.39117700E+01, -.20814400E-02, -.18608100E-01, -.62338300E-02, -.30192700E-01, -.46005700E-02, 0.27791900E-02, -.95852400E-01, -.80145800E-03, 0.14420300E-01, -.39010000E-01, 0.10281300E-01, 0.80918800E-01, -.15400000E-01, 0.19579200E-01, 0.11134400E+00, 0.10198000E-01, -.22353100E-02, 0.54345400E-01, -.16648300E+01, 0.11234100E+01, 0.59465700E-01, 0.50797300E-01, 0.99073300E-01, -.64971900E-01, -.89678000E-01, 0.54464200E-01, -.30075800E+01, 0.14936800E+01, -.52704000E-01, -.42580700E+00, 0.20305800E+01, -.28568600E+01, 0.56151100E+00, -.28997200E+01, 0.36760600E-01, 0.38140600E-01, -.12778400E+01, 0.17765900E+00, 0.10273600E+00, 0.38853700E-01, -.56597100E-01, 0.72749000E-01 }, { 0.16299500E+00, 0.38729000E-01, 0.42851200E-01, -.60550900E-01, -.14711300E+00, -.18178200E+00, -.70703200E-01, -.51762200E-01, 0.17610400E-01, -.34612600E-01, -.10327300E-01, -.48305200E-01, -.87044500E-01, 0.12429300E+00, -.43518300E-02, -.22074600E+00, 0.10790600E-01, -.72326800E-01, 0.19551500E-01, 0.66073200E-01, -.88459700E-01, 0.27551500E-01, 0.12380600E+00, -.79245800E-01, 0.13440100E-01, -.33318200E-01, 0.69870900E-01, 0.29061000E-01, -.54550500E-01, -.19102200E-01, -.24926300E+00, 0.31860700E-01, 0.17297100E-01, 0.14095000E-01, -.50496700E-01, 0.91099200E-02, -.24498700E-02, -.82546200E-02, -.53412200E-01, 0.33270600E-02, -.18976100E-01, 0.15100100E-01, -.42349900E-01, 0.12459700E-01, -.15563900E-01, 0.10015400E+00, -.12951900E-01, -.10230500E+00, -.27329400E-02, 0.46648500E-02, -.19158900E-01, -.32176600E-02, 0.40208800E-01, 0.38032400E-02, -.35012900E-01, 0.17328900E-01, 0.52425200E-02, 0.56536600E-01, 0.27736400E-01, 0.50261100E-01, 0.52800500E-01, 0.35068100E-02, -.18207800E-01, 0.34475000E-01, 0.38804400E-01, -.28734900E-02, -.64701000E-02, -.30152700E-01, 0.25060000E+00, -.13176400E-02, 0.46510500E-01, 0.93440400E-03, 0.26198500E+01, 0.11292100E+01, 0.34360800E+01, 0.28195500E+01, -.25954200E+01, -.68645100E+00, -.85985400E+01, 0.41089600E+01, 0.60786300E+01, -.74042600E+01, 0.35552000E+01, 0.17644100E+01, -.40748700E+01, -.93234400E+00, -.27296400E+01, 0.15472000E+01, 0.17020100E+02, -.65131100E+01, -.49029900E+01, -.43898200E+01, -.32456400E+01, 0.48576600E+01, 0.73118700E+01, -.29902800E+01, 0.26105100E+01, 0.66571200E-01, -.20567100E+01, -.18549000E+01, 0.44466100E+01, -.90232800E+00, -.31798700E+01, -.12573900E+01, 0.17427900E+02, -.40600100E+01, -.45706400E+01, -.48982400E+01, 0.20605700E+01, 0.51378300E+01, 0.73538700E+00, -.42478600E+01, -.64331700E+01, -.62342400E+01, 0.12735500E+01, -.75325400E+00, 0.36295500E+01, -.40445200E+01, -.57545600E+01, -.18851000E+01, 0.36314900E+01, -.49607600E+01, -.23260600E+01, -.22624200E+01, 0.19998300E+01, -.54782200E+00, 0.97123900E+00, -.18526300E+01, 0.89465600E+01, -.55102100E+01, -.72817500E+01, -.62992300E+01, -.15977400E+00, 0.23749400E+01, 0.79257300E+01, -.75742200E+01, 0.59170900E-02, -.85518900E-02, -.11897400E-02, -.80077100E-02, -.25751800E-02, -.13638500E-04, 0.25792000E-01, 0.11773500E-02, 0.36713600E-02, -.80254000E-02, -.25773100E-02, -.79084300E-02, -.14108800E-02, -.14974800E-03, 0.27587600E-01, 0.10509000E-02, 0.17565400E+01, 0.14432000E+01, 0.49278700E+00, 0.72189900E+00, -.22687900E+01, -.63968100E+00, -.34453600E+01, 0.94483300E+00, -.93424500E+01, 0.42986200E+01, 0.11151100E+01, 0.17620500E+01, 0.13584700E+01, -.30907600E+01, 0.20441200E+01, 0.17404700E+01, 0.40003600E-01, 0.15192000E-01, -.37505600E-02, -.35456300E-01, -.92237700E-02, 0.30456500E-01, 0.10281500E+00, -.23712900E-02, 0.54973900E+01, 0.40576900E+01, -.38652100E+01, -.17905000E+01, 0.26633200E+01, 0.65878200E+01, 0.88220300E+01, 0.31999000E+00, 0.69432500E-02, 0.66790300E-02, 0.57076000E-02, 0.13331600E-01, -.29162900E-02, 0.32833000E-02, -.51411400E-01, -.78829400E-04, 0.17254800E-01, 0.16483500E-01, -.48721800E-03, -.28226900E-01, -.37573800E-02, 0.17461600E-01, 0.82091800E-01, -.14793200E-02, 0.29297700E-01, 0.98876400E-02, -.12055200E+01, 0.55161400E+00, 0.12958200E-01, 0.31022400E-01, 0.10832300E-02, -.15333200E-01, -.23860400E-02, 0.11077200E-01, -.19828700E+01, 0.80953000E+00, 0.25100800E+01, -.17313300E+00, 0.84435500E+00, 0.14261400E+01, 0.11571500E+00, -.68360900E+00, 0.70746800E-02, 0.59463900E-02, -.83639800E+00, 0.15063200E+00, 0.97578700E-02, -.91626100E+00, -.11347300E-01, 0.17269900E-01 }, { -.45555200E+00, -.15582900E+00, 0.45204600E+00, 0.23717800E+00, 0.15121700E+00, 0.11569500E+00, -.15418600E+01, -.50767200E+00, 0.84288500E-01, -.15543600E+00, 0.33767800E-01, 0.47640000E+00, 0.61640300E-01, 0.11139400E+01, -.44134400E+00, -.20776900E+00, -.25346100E+00, -.15792700E+00, -.16078200E+00, 0.13801100E-01, 0.29285700E-02, 0.36557000E-01, 0.22631900E+00, 0.49033400E-01, 0.28962100E-01, 0.10207000E-01, -.20949200E+00, -.83764500E-01, -.12740300E+00, -.55758000E-01, -.63988300E+00, 0.11960600E+00, -.69543900E-01, 0.96755100E-01, 0.98379000E+00, 0.17898800E+00, -.42789800E-01, 0.22305400E+00, 0.13116700E+00, 0.32360900E-02, 0.10399500E+00, -.98204500E-02, 0.21888100E-01, 0.91894400E-01, 0.41793400E-01, -.34874500E+00, 0.57010500E-01, 0.59636500E+00, -.81084400E-03, -.98086500E-02, 0.24087000E-01, 0.41931300E-01, -.49438000E-01, -.37662300E-01, 0.42675500E+00, 0.44869100E-01, -.16443700E-01, -.10440900E+00, -.24396300E-01, 0.87689000E-01, -.31440800E-02, -.11412300E-01, 0.11521800E+00, 0.40079300E+00, -.47951300E-01, -.30262400E-01, 0.25004700E-01, -.15522900E+00, -.14503300E+00, 0.12508000E+01, 0.53881100E-01, 0.33281600E-01, 0.14020800E+03, -.76252000E+02, 0.13035500E+02, 0.17770000E+01, -.52517300E+02, 0.63486500E+02, 0.26942900E+02, 0.13186300E+02, -.42176100E+02, 0.26826500E+01, -.13010100E+01, -.91014000E+01, 0.14168600E+02, -.13000300E+02, -.12930200E+01, -.12670400E+02, 0.12267900E+02, -.41775200E+01, -.79494600E+01, -.15124000E+02, 0.27445300E+01, 0.72726700E+01, 0.98402100E+00, -.18207600E+02, 0.43888400E+02, -.55785500E+02, -.64298400E+01, -.16667200E+02, 0.30643200E+01, 0.79687500E+01, -.18263000E+01, -.14737500E+02, 0.12575600E+03, -.83245600E+01, -.18518500E+02, -.28829800E+02, -.14106800E+02, 0.50407500E+02, -.10740900E+02, -.29905100E+02, -.10021700E+03, -.60397800E+01, 0.42345600E+01, 0.72347000E+01, 0.35370700E+02, -.37682200E+02, -.28022200E+02, 0.43139100E+01, 0.93524500E+00, 0.31334600E+01, -.99129300E+01, -.14470900E+02, 0.11066800E+02, 0.14601500E+01, 0.23850900E+01, -.16330800E+02, -.95696000E+02, 0.84563800E+02, 0.13301600E+02, 0.82989100E+01, 0.59595100E+01, -.64924100E+02, -.47046600E+02, -.99256500E+01, -.81642000E-02, -.88436800E-01, 0.60525200E-02, 0.23547600E-02, -.28736900E-01, 0.20397100E-01, 0.34458100E-01, 0.65319600E-01, -.72253100E-02, -.90939100E-01, 0.87807700E-02, -.17325300E-02, -.33687300E-01, 0.23123000E-01, 0.35236000E-01, 0.56468900E-01, 0.85667200E+02, -.41574200E+02, 0.12350400E+01, -.48024100E+01, -.23438600E+02, 0.30309900E+02, 0.84324800E+00, 0.16012900E+01, -.19850700E+02, 0.33290300E+01, 0.33586900E+01, 0.49573400E+01, 0.27996500E+01, -.43071900E+01, 0.34762600E+01, 0.61817300E+01, 0.50501900E-01, 0.12745700E+00, -.90878300E-01, -.31545300E+00, 0.52416800E-01, 0.54998700E-01, 0.30060300E+00, -.19763500E-02, 0.17089300E+03, -.52649000E+02, -.24187100E+02, -.25683600E+02, -.10630900E+02, 0.75494000E+02, 0.15036200E+02, -.10710900E+02, -.70159800E-02, 0.71028800E-01, -.15718500E-01, 0.99882400E-01, 0.40327200E-01, -.26488000E-01, -.48647000E-01, 0.35875100E-02, 0.77019000E-02, 0.12915400E+00, -.51521400E-01, -.28118600E+00, 0.52071600E-01, 0.38974900E-02, 0.20196000E+00, -.13706100E-01, -.31195900E-01, -.88202800E-01, 0.22210400E+01, -.39143200E+01, -.82265100E-01, -.11262000E+00, -.20817900E+00, 0.80403100E-01, 0.15524400E+00, -.81531800E-01, 0.24798000E+01, -.55142000E+01, 0.47926500E-01, 0.32788800E+01, -.28777700E+01, 0.67015600E+01, -.33393000E+01, 0.18356100E+02, -.60731100E-01, -.69223100E-01, 0.50028600E+00, 0.52193400E+01, -.19081200E-01, -.80322100E+01, 0.84867600E-01, -.85002900E-01 }, { 0.10637400E-01, -.25762900E-01, 0.11210500E+00, 0.12061900E+00, 0.51363100E-01, -.38215000E+00, 0.13476700E+00, -.31322600E-01, 0.46570400E-01, -.76767800E-02, 0.24252600E-03, 0.34288600E-01, 0.65677700E-01, -.84238800E-01, -.72606900E-01, 0.18470400E-01, 0.58675500E-01, -.15111000E-01, -.78702600E-02, -.43186600E-02, 0.23873800E-01, -.41112900E-02, -.33574200E-02, -.95327900E-02, 0.19323000E-02, -.36299500E-02, -.76100900E-02, -.90555900E-02, -.40295700E-01, -.14152200E-01, -.21361300E+00, 0.17257200E-01, 0.38038900E-01, 0.13538300E-01, 0.52179400E+00, -.56705700E-03, 0.64467700E-04, 0.80922500E-03, 0.67242300E-02, 0.91624700E-03, -.99523200E-03, 0.46490700E-03, -.27791000E-01, 0.58517400E-02, -.53581500E-03, 0.24607800E-02, -.30882000E-02, 0.86409500E-02, -.10448000E-04, 0.72965400E-03, 0.41115300E-02, 0.17328400E-02, -.10467200E-03, -.18075700E-02, -.30764600E+00, 0.11657700E-02, -.16292500E-02, 0.37464100E-02, 0.34493700E-02, 0.31029800E-03, 0.68123200E-02, -.80077900E-04, -.11957900E-01, -.13744800E-01, 0.13803600E-01, -.88688100E-03, -.18982100E-02, 0.10211400E-01, -.17483500E-02, -.29761900E-02, 0.28774700E+00, 0.13454100E-02, 0.34531900E+01, 0.11031000E+01, -.22831700E+01, -.22774000E+01, 0.22519300E+01, -.58565500E-01, -.30588200E+01, -.25946700E+01, 0.20762700E+01, -.28368300E+01, 0.98257200E-01, 0.36344800E+00, -.50051200E+00, -.41953800E+00, 0.57774400E+00, 0.64175600E+00, 0.74261300E+01, 0.23931900E+01, 0.27693900E+00, -.68751500E+00, -.34575700E+01, 0.81460700E+00, 0.31597700E+01, -.52526300E+00, -.22682800E+01, 0.34379100E+01, -.29333400E+00, 0.11669900E+00, 0.21812600E+00, -.65667300E+00, 0.22959100E+00, 0.12627900E+00, -.83827900E+01, 0.43036600E+01, 0.50168100E+00, 0.12293100E+01, 0.20071100E+01, -.41643500E+01, 0.11270500E+01, 0.11117300E+01, 0.57267200E+01, -.67014400E+01, -.26601400E+01, -.24823900E+01, 0.25376000E+01, 0.21231000E+01, 0.13747400E+01, -.16848900E+01, 0.50388000E+00, 0.26452300E+01, -.32540400E-01, -.44758700E+00, 0.91831400E-01, -.44297400E+00, 0.13441400E+01, -.13808300E+00, 0.54838900E+01, -.46127700E+01, -.10918000E+01, -.69679300E+00, -.18020500E+01, 0.23584200E+01, 0.43559800E+01, 0.19594200E+00, 0.72629700E-03, -.38118600E-02, -.17487500E-03, 0.49554400E-02, -.26026100E-02, -.41087200E-02, 0.30910300E-01, 0.26200100E-02, 0.41221700E-03, -.34354800E-02, -.36657200E-03, 0.43718400E-02, -.20164500E-02, -.39478900E-02, 0.30993400E-01, 0.21513600E-02, 0.24810800E+01, -.11849200E+00, -.33779700E+00, -.70789600E+00, -.67811200E+00, 0.18538400E+00, -.29439800E+01, -.61934900E+00, -.26105100E+01, 0.55094300E+00, 0.74111700E+00, 0.68516000E+00, 0.14372500E+00, -.85669300E+00, 0.15145700E+01, 0.78500100E+00, -.15602800E-01, 0.17537300E-01, 0.14482900E-01, 0.13498100E-01, -.13752500E-01, 0.18226800E-02, 0.11357900E+00, 0.28116500E-02, -.97370600E+01, 0.60988400E+01, 0.22534700E+01, 0.22520000E+01, -.33497200E+00, -.36378700E+01, -.52656100E+00, 0.93301100E+00, 0.28760100E-02, 0.27488100E-02, 0.17508100E-02, -.25092300E-02, -.20968200E-02, 0.37562900E-02, -.59271500E-01, -.12706300E-03, -.57563100E-02, 0.11600800E-01, 0.86917500E-02, 0.73594400E-02, -.77132300E-02, 0.51139400E-02, 0.10141500E+00, 0.21488200E-03, 0.50876100E-02, 0.10427500E-01, -.20996100E+00, 0.16688200E-01, 0.14156500E-01, 0.81213000E-02, 0.21954200E-01, -.17605700E-01, -.21590700E-01, 0.11658200E-01, -.88644500E+00, 0.49409000E+00, 0.18886700E+01, -.52742900E+00, 0.71191600E-01, 0.12360300E+01, 0.63847000E-01, -.17404300E+01, 0.68716700E-02, 0.57787300E-02, -.59484500E+00, 0.45594900E+00, 0.21216900E-01, 0.35590500E+00, -.12148700E-01, 0.22279400E-01 }, { 0.18205200E+00, 0.76613500E-01, -.33457400E+00, -.14409200E+00, -.12870800E+00, -.76922700E+00, -.58504500E+00, 0.22887800E+00, -.19081300E-01, 0.46852200E-01, -.63214800E-02, -.10934600E+00, 0.56401000E-01, -.53564100E+00, 0.11112900E+00, 0.22867600E+00, 0.21353100E+00, 0.83182900E-01, 0.38531400E-01, -.36886900E-01, -.53437800E-02, 0.32518000E-02, -.52449300E-01, -.50229300E-01, -.12684600E-02, -.13594000E-01, 0.87987600E-01, 0.30434700E-01, -.34526300E-03, 0.24137200E-02, 0.13131500E+00, -.45620400E+00, 0.13790000E-01, -.19158400E-01, 0.55209700E-01, -.14162500E+00, 0.18826600E-01, -.33753000E+00, 0.37560100E+00, -.12008700E-01, -.24175500E-01, -.15871700E+00, 0.17784500E+00, -.11617300E+00, 0.53392000E-01, -.20744400E+00, -.43017600E-01, 0.81032200E-01, 0.32117100E-01, -.14972400E-01, -.62066500E-01, -.34606200E+00, -.17222900E+00, 0.81099400E-02, -.11419400E+01, -.68186700E+00, -.49321000E-01, -.32947900E-01, -.17947600E+00, -.10572700E+00, 0.23540200E+00, -.44025200E-02, -.18683800E+00, -.57045300E+00, 0.15883700E+00, 0.15015300E-01, -.15854300E+00, 0.85528800E-02, 0.25382300E+00, 0.21893900E-01, 0.34609800E+00, -.15993500E+00, -.10568100E+03, 0.74969300E+02, -.15202600E+02, -.16699400E+02, 0.42106500E+02, -.38607800E+02, -.39436900E+01, -.27629100E+02, 0.10722900E+03, -.21863200E+02, 0.12812200E+01, 0.15008100E+02, -.27348900E+02, 0.26251500E+02, -.21648800E+02, 0.21219400E+02, 0.50460100E+00, 0.83759300E+01, -.80166900E+01, 0.87095100E+01, 0.20137600E+01, 0.65955300E+01, 0.86313900E+01, 0.87425300E+00, -.17836700E+02, 0.41494000E+02, -.45470400E+01, 0.14009600E+01, 0.58549500E+01, -.62501600E+01, -.35345300E+01, -.55826200E-02, -.50588200E+02, -.17763400E+02, 0.52521300E+01, 0.11297600E+02, 0.76771700E+01, -.22864700E+02, 0.81256800E+01, 0.10591600E+02, 0.10656100E+03, 0.10104100E+01, -.10159700E+01, -.10570600E+02, -.87859500E+01, 0.41196200E+02, 0.88253600E+01, 0.40447000E+01, 0.78080800E+01, 0.25729700E+02, -.70467700E+01, 0.23332100E+01, 0.14901300E+01, 0.31718400E+01, -.52283900E+01, 0.37971600E+01, 0.19427500E+02, -.40715200E+02, -.19711700E+02, -.12602600E+02, 0.22434900E+02, 0.28531100E+02, 0.46485700E+02, 0.13821100E+01, -.66816700E-01, 0.62525100E-01, -.91686000E-01, -.11015100E+00, 0.82578900E-01, 0.11820400E-01, 0.88305800E-01, -.20969300E+00, -.44602200E-01, 0.60595400E-01, -.92302400E-01, -.10394400E+00, 0.78946200E-01, 0.19039600E-01, 0.90222400E-01, -.20104100E+00, -.88467100E+02, 0.35024800E+02, -.11455600E+02, -.13607500E+02, 0.38465700E+02, -.22571800E+02, 0.28581400E+02, -.18235300E+02, -.25689300E+02, 0.11389500E+02, 0.43306600E+01, 0.37240900E+01, 0.34187000E+01, -.12457700E+02, -.72522000E+01, 0.12165700E+01, -.21287600E+00, -.19863900E+00, 0.11375800E+00, 0.56855200E+00, -.11409800E+00, -.12020300E+00, -.75384200E-01, 0.97701600E-01, -.17060600E+03, 0.11679100E+02, 0.16330400E+02, 0.15489100E+02, 0.11566400E+02, -.64828300E+02, -.47992400E+01, -.90860700E+01, -.51388800E-01, -.50221800E-01, 0.76542300E-01, -.54930500E-01, -.51498200E-01, -.43015200E-01, -.79023700E-01, 0.11134600E+00, -.11402900E+00, -.14524700E+00, 0.13056500E+00, 0.56572600E+00, -.11370500E+00, -.82301000E-01, -.84792200E-01, 0.17337800E+00, -.31410100E+00, 0.27791200E+00, -.20155700E+01, -.42250200E+01, 0.28872500E+00, -.44706100E-01, 0.45752000E+00, -.29480700E+00, -.45684900E+00, 0.27560800E+00, -.26239800E+01, -.40282500E+00, 0.27960800E+01, -.42149600E+01, 0.14208200E+01, 0.10804500E+02, 0.10088600E+01, -.13818400E+02, 0.19488300E+00, 0.20138400E+00, 0.32055200E+01, 0.28595000E+01, 0.36147700E+00, 0.75647300E+01, -.28416200E+00, 0.30910400E+00 }, { -.81524300E+00, -.25318900E+00, 0.14604700E+01, 0.16359900E-01, -.23864400E+00, 0.17140100E+01, 0.38630900E+01, -.20712300E+00, 0.62501100E+00, -.10589500E+01, 0.74658600E-02, 0.90475000E+00, -.12607400E+01, 0.81264200E+01, -.19891900E+01, -.47208300E+01, -.25419800E+01, -.16293300E+01, 0.11797000E+01, 0.50873700E+00, -.82675500E+00, -.38866800E-01, 0.89828200E+00, 0.65845000E+00, 0.27164200E-01, 0.47625100E+00, 0.39341800E+00, -.14768400E+00, 0.38541400E+01, 0.25951500E+00, 0.72871400E+01, -.30382900E+00, -.54750500E+00, -.68719100E+00, 0.61189900E+01, -.60853200E-01, 0.31083800E+00, -.70508400E+00, 0.49857300E+00, 0.84965200E-01, -.36923600E-01, 0.20263100E+00, -.47090600E+01, 0.10521300E+01, -.20204700E+00, -.12295300E+01, 0.17805200E+00, 0.76187600E+00, 0.23304700E-01, 0.47560300E-01, 0.26725700E+00, -.31418400E-01, -.31095300E+00, 0.38588900E-02, -.18230300E+01, -.16490000E+00, -.70045700E-01, -.50993100E+00, -.28579700E+00, -.20582100E+00, -.11994100E+01, -.10480200E+00, -.45244800E-01, -.17664400E+01, -.40579100E+00, 0.13396400E+00, -.15034100E+00, 0.10239000E+01, 0.65610300E+00, 0.73787700E-01, 0.59830400E-01, 0.51844700E+00, -.11665800E+04, 0.21443100E+03, 0.81480200E+02, 0.84341500E+02, 0.18594800E+03, -.49797800E+03, -.30611000E+03, 0.23204800E+02, -.51544900E+02, 0.17353100E+03, -.82772400E+02, -.40416300E+02, 0.69407200E+02, 0.97785900E+02, 0.12144400E+03, -.26222100E+02, -.13295300E+03, 0.67720500E+02, 0.20503900E+02, 0.78158100E+02, 0.75294500E+02, 0.61006200E+02, 0.60188000E+02, 0.74091800E+02, -.24803900E+01, -.16375700E+02, -.24791100E+02, -.36864800E+02, 0.27550900E+02, 0.97230200E+01, -.34273600E+02, -.41162400E+02, -.35095900E+03, 0.73589500E+02, 0.84328900E+02, 0.95118200E+02, 0.18411600E+02, -.79668400E+02, 0.24873500E+02, 0.10316800E+03, 0.36444000E+03, 0.14630200E+03, -.95954100E+02, -.70984800E+02, -.74393300E+02, 0.25165300E+03, 0.21055600E+03, -.51165700E+02, -.51921000E+02, 0.14292100E+03, -.52727100E+01, 0.20331400E+02, 0.26799000E+02, 0.46127100E+02, 0.29565900E+02, 0.17813200E+02, 0.61876900E+03, -.36385700E+03, -.53511600E+02, -.43632900E+01, 0.12015800E+02, 0.42308000E+03, 0.31261200E+03, 0.57220500E+02, -.14675500E+00, 0.38773800E+00, -.10281300E+00, 0.21779800E+00, 0.19199200E+00, 0.75967100E-01, 0.19090400E+00, -.54987800E-01, -.90311900E-01, 0.37822800E+00, -.70329500E-01, 0.22845200E+00, 0.17368800E+00, 0.61195100E-01, 0.13348600E+00, -.32540800E-01, -.67318200E+03, 0.14314400E+03, 0.10619000E+03, 0.11860000E+03, 0.86953800E+02, -.23839300E+03, -.13436100E+03, 0.91546000E+02, 0.75827100E+02, 0.36955100E+02, -.22359600E+00, -.10759100E+02, -.24972300E+02, 0.92779800E+01, -.73068000E+02, -.16340000E+02, -.10805000E+01, -.38196500E+00, 0.20524200E+00, 0.12304800E+01, 0.56883400E-01, -.95739800E+00, -.83057300E+00, 0.70634800E-03, -.35401600E+03, -.14947500E+02, 0.18963100E+03, 0.10781300E+03, -.11723800E+03, -.28822600E+03, -.12724100E+03, 0.49801400E+02, -.17529100E+00, -.29993000E+00, -.38129200E-01, -.50620100E+00, -.68815500E-01, -.80919400E-01, 0.18706700E+00, -.61179000E-01, -.48440000E+00, -.54976200E+00, 0.16877900E+00, 0.10609000E+01, -.11038400E+00, -.60065100E+00, -.78260600E+00, 0.11874100E-01, -.71934100E+00, 0.23029300E+00, -.24672700E+02, -.10106100E+02, 0.19981800E+00, 0.50167500E-01, 0.74918200E+00, -.19190500E+00, -.66806400E+00, 0.20045200E+00, -.10341600E+03, -.86476200E+01, -.46481200E+01, 0.86615100E+00, 0.34419900E+02, -.42667100E+02, -.71560100E+00, -.14233400E+03, 0.14528400E+00, 0.18700800E+00, -.25562300E+02, -.13955400E+02, 0.10685500E+00, 0.27470200E+02, -.21282500E+00, 0.22524500E+00 }, { -.13141000E+01, -.44126400E+00, 0.10984300E+01, 0.54237800E+00, 0.39244800E+00, 0.28901000E+01, 0.26233900E+01, -.80586700E+00, 0.35453800E+00, -.51148900E+00, -.38463500E-01, 0.12597500E+00, -.83261900E+00, 0.44070800E+01, -.61020400E+00, -.31291300E+01, -.17208700E+01, -.13027800E+01, -.19414300E+00, 0.69141200E+00, -.12764400E+00, -.11124200E+00, 0.62918600E-01, 0.48297700E+00, -.36929000E-01, 0.15250000E+00, -.48071500E+00, -.16105000E+00, 0.87209700E+00, 0.97327700E-01, 0.18214900E+01, -.10469400E-01, -.57581800E+00, -.13018500E+00, -.27188500E+01, 0.39040000E+00, 0.51864900E-02, 0.17841200E+00, 0.17119500E+00, -.87846600E-01, 0.24076000E+00, 0.16026000E+00, 0.76630100E+00, 0.39633900E-01, 0.81768800E-01, -.13468000E+01, 0.25063300E+00, 0.11738900E+01, 0.25558000E-01, -.35994900E-01, 0.75735500E-01, 0.42391600E-01, -.30476400E+00, -.20364900E-01, 0.35561800E+01, -.96501100E-01, -.59364200E-01, 0.11207300E+00, -.18531900E+00, -.11616300E+00, 0.27775800E+00, -.62056300E-01, 0.54513900E-01, 0.72103600E+00, -.12898500E+01, 0.11526300E+00, -.19748200E+00, -.30721800E+00, 0.15867000E+01, -.16550200E+00, -.50559200E+01, 0.41982700E+00, -.94371500E+00, -.65507800E+03, 0.17454200E+03, 0.11822300E+03, -.27891200E+03, 0.19584300E+03, 0.46170700E+03, 0.22478300E+03, -.31197000E+03, 0.29172700E+03, -.12729600E+03, -.11320300E+03, 0.14471000E+03, 0.47762600E+02, 0.22382400E+02, -.19883500E+03, -.95640700E+03, 0.55389200E+02, 0.16179800E+03, 0.23098000E+03, 0.28873800E+03, -.12452800E+03, -.52374600E+03, 0.17259400E+03, 0.43163300E+03, -.52198300E+03, -.72102400E+01, -.15152100E+03, -.68998000E+02, 0.15259100E+03, 0.12897800E+03, -.16349600E+03, 0.13769400E+04, -.46426000E+03, -.82403700E+02, -.21933300E+03, -.26564700E+03, 0.64429900E+03, -.11823800E+03, -.20163700E+03, -.11006700E+04, 0.61857000E+03, 0.15006100E+02, 0.12005500E+03, -.70123200E+01, -.36855600E+03, -.19578500E+02, -.25635500E+02, -.21723800E+03, 0.13884500E+03, -.47129300E+02, -.32974000E+02, 0.56944500E+02, 0.73800400E+02, 0.23929200E+02, -.11277200E+03, -.13842100E+04, 0.98520500E+03, 0.16372900E+03, 0.11915900E+03, 0.30223000E+03, -.60806400E+03, -.58727100E+03, -.12645100E+03, -.29926400E+01, 0.87441000E+00, -.59513700E+00, -.63150600E-01, 0.95037000E+00, -.30939100E+00, -.22965200E+00, -.18994500E+00, -.28338300E+01, 0.79850900E+00, -.39163500E+00, 0.66028400E-01, 0.79534800E+00, -.30040300E+00, -.37485400E+00, -.70327000E-01, 0.33151400E+03, -.36647600E+03, -.40367800E+02, -.77077200E+02, -.28308400E+02, 0.11840500E+03, 0.17919400E+03, -.48758400E+02, 0.36680100E+03, -.85091500E+01, -.43349300E+02, -.65881200E+02, -.38479700E+02, 0.10992300E+03, -.16568500E+03, -.68716800E+02, 0.19863600E+01, -.14609700E+01, -.43152300E+00, 0.78719600E+00, 0.49941700E+00, -.57411900E+00, -.25853100E+01, 0.10043600E+01, 0.21867300E+04, -.10634600E+04, -.17718600E+02, -.17338100E+03, -.20404700E+03, 0.78608700E+03, -.13462400E+03, 0.12418200E+03, 0.12639600E+01, -.52836000E+00, -.29492700E+00, -.48394900E+00, -.54320500E-01, -.57468200E-01, 0.16498600E+01, -.71828000E-01, 0.25004600E+01, -.13658400E+01, 0.66130000E-01, 0.93313300E+00, -.20118800E+00, -.37105800E+00, -.25927700E+01, 0.83309400E+00, -.12579600E+02, -.47364100E-01, 0.17707100E+02, -.97722400E+02, -.17280300E+00, -.48324200E+01, -.18919400E+00, 0.25593200E+00, -.99719000E-01, -.10763800E+00, 0.13478900E+03, -.15912800E+03, -.19883000E+03, 0.36795900E+02, -.68938900E+01, -.28334600E+03, -.32737600E+02, 0.26608300E+03, -.18844400E+00, -.44637200E-02, 0.38342300E+02, 0.42575900E+02, -.25557600E+00, -.15834100E+03, 0.10833100E+00, -.36594900E+00 }, { -.10658900E+01, -.29463600E+00, -.30151600E+00, 0.29186300E+00, 0.98176400E+00, 0.10480200E+01, 0.26966000E+00, 0.41753700E+00, -.12792700E+00, 0.71835200E-01, 0.10336600E+00, 0.41379800E+00, 0.59509600E+00, -.78944000E+00, -.40603100E-01, 0.16513200E+01, 0.16141500E+00, 0.32434300E+00, -.24766000E+00, -.64828200E+00, 0.72586400E+00, -.13939300E+00, -.78878800E+00, 0.74263400E+00, -.12171900E+00, 0.31831100E+00, -.79464500E-01, -.20813400E+00, 0.10386900E+01, 0.20500600E+00, 0.25357700E+01, -.24140700E+00, 0.31371000E+00, -.27111500E+00, 0.86152200E+01, -.46622900E+00, 0.10265000E+00, -.67013800E-01, 0.54683500E+00, 0.21447600E+00, 0.62386200E-01, 0.64689400E+00, -.29805900E+01, 0.57303100E-02, -.54988300E+00, 0.16228100E+00, -.24562500E+00, 0.13323600E+01, 0.35618700E-01, -.20465300E-01, 0.30422400E+00, -.48400900E-01, -.41709400E+00, -.39384200E-01, -.38871800E+01, -.21487000E+00, -.31508600E-01, -.62491100E+00, -.55455600E+00, -.54678700E+00, -.20143900E+00, -.58588300E-01, 0.10856000E+00, -.58666600E-01, -.14719300E+00, 0.66628200E-01, 0.10493600E+00, -.73192200E-01, 0.12215200E+00, -.15324700E-01, 0.24273800E+00, 0.48225400E+00, -.17389100E+00, 0.13794400E+00, -.15816200E+03, -.12725000E+03, 0.12325300E+03, -.55929300E+01, 0.89211300E+02, -.15215900E+03, 0.49945600E+02, 0.88814700E+02, -.84521400E+01, -.21587800E+02, 0.33306900E+01, 0.49496100E+02, 0.78231100E+02, 0.75557900E+01, -.47951300E+02, 0.10782300E+03, 0.16147900E+03, 0.93666100E+02, -.89554200E+02, -.53649900E+02, -.66677000E+01, 0.77264600E+02, 0.96299600E+02, -.21832800E+02, -.65884400E+02, -.33034000E+02, 0.13407500E+01, 0.87371500E+02, 0.11511300E+03, -.17428300E+02, -.55714500E+03, 0.12944000E+03, 0.12500800E+03, 0.13717100E+03, 0.56048700E+01, -.21305300E+03, -.24947500E+02, 0.12838900E+03, 0.43744800E+03, -.67732500E+01, -.86313600E+02, -.56652400E+02, -.54879400E+02, 0.17204600E+03, 0.11039800E+03, -.68497800E+00, -.17465100E+02, 0.98579400E+02, 0.81890300E+02, 0.63088400E+02, -.56471600E+02, -.25736300E+02, -.80013800E+01, 0.83679200E+02, 0.44906000E+02, -.13108600E+03, 0.24396900E+03, 0.19798000E+03, -.16427500E+03, 0.63420600E+02, 0.20575300E+02, 0.25051900E+03, 0.35764300E+00, 0.14505000E+00, 0.89916500E-01, 0.12751800E-01, -.36386600E-01, 0.37228900E-01, 0.51420800E-01, -.26914000E-01, 0.36281300E+00, 0.14788000E+00, 0.98822700E-01, 0.50889100E-02, -.38464400E-01, 0.24839500E-01, 0.32096500E-01, -.26271800E-01, -.17549600E+03, 0.31901600E+02, -.11594900E+02, 0.23474300E+01, 0.81728100E+02, -.30603600E+02, 0.22897100E+02, -.37618300E+01, -.10901100E+03, -.24867000E+02, 0.95338200E+01, 0.22024200E+02, 0.81709100E+01, -.37654700E+02, 0.10960900E+02, 0.22001600E+02, -.11057400E+01, 0.30634800E+00, 0.13696400E+00, 0.68468100E-01, 0.12455700E+00, -.34852800E+00, 0.16354700E+00, -.20204200E+00, -.72662900E+03, 0.78824100E+02, 0.57270800E+02, 0.78429800E+02, 0.56761000E+02, -.33763200E+03, -.13453600E+03, -.17494800E+02, -.23924600E+00, -.10441300E+00, -.12872500E+00, -.73314000E-02, 0.45869200E-01, 0.46441900E-01, -.19481000E+00, -.60629000E-01, -.66787300E+00, 0.16118600E-01, -.45953400E-01, -.56736500E-01, 0.10706800E+00, -.15339300E+00, 0.37293400E+00, -.18518900E+00, 0.14715700E+01, 0.15706500E+00, 0.10689000E+02, 0.10738800E+02, 0.16213800E+00, 0.10323500E+01, 0.32438700E+00, -.17655800E+00, -.28281600E+00, 0.14878400E+00, 0.11796600E+02, 0.26876000E+02, 0.17462900E+02, -.21777700E+02, -.11721200E+01, 0.23033800E+02, 0.64361500E+01, -.79356500E+02, 0.11687500E+00, 0.12065500E+00, 0.61652000E+01, -.27947100E+01, 0.17135000E+00, 0.53467500E+02, -.15724900E+00, 0.20660000E+00 }, { -.21618800E+01, -.94250100E-01, 0.20683200E+01, 0.14526400E+01, 0.11199800E+01, -.66946500E+00, -.76160700E+01, -.14451400E+01, 0.99707200E-01, -.31274000E-01, 0.32659300E+00, 0.36919500E+01, 0.19178800E+01, 0.42322500E+01, -.25964000E+01, 0.22483700E+01, 0.11067100E+00, -.47353200E+00, -.99614400E-01, -.11783100E+01, 0.43378800E+00, 0.75134100E+00, 0.26699000E+01, -.79300500E+00, 0.28877800E+00, 0.20999200E-01, 0.71308800E-02, -.42635700E-01, 0.53007200E+00, 0.48170800E-01, -.52586800E+00, 0.60845100E+00, -.69694800E+00, 0.59145100E+00, 0.63895400E+01, 0.10373700E+01, -.42140600E+00, 0.15365500E+01, 0.14469000E+01, -.18601200E+00, 0.11390000E+01, 0.10692500E+01, -.64766200E+01, 0.13872700E+01, -.11958900E+00, -.20760500E+01, 0.82203300E-01, 0.52882400E+01, -.13973300E-01, 0.10783000E+00, 0.17841900E+00, 0.36494200E+00, 0.34638400E-01, -.14589100E+00, 0.55318100E+01, 0.50322000E+00, -.29279900E+00, 0.13259100E+01, 0.27266600E+00, 0.40814300E+00, 0.26825400E+00, -.40413500E+00, 0.75069700E-01, 0.23121800E+01, 0.74944700E+00, -.23533700E+00, -.81211100E-01, -.66112000E+00, -.78892000E+00, 0.23697500E+00, 0.64194300E+01, -.18565100E+01, -.10428900E+01, -.20466100E+00, -.67064200E-01, -.11454500E+03, -.87106300E+02, 0.67464700E+02, -.13915700E+03, -.10271200E+03, -.15993000E+03, 0.10438400E+03, -.15648300E+03, -.15015700E+03, 0.20482200E+03, 0.16603800E+03, 0.18724200E+03, -.14345800E+03, 0.11168200E+03, 0.23072100E+03, 0.29196100E+02, -.35387900E+02, 0.10851600E+03, 0.42254800E+03, -.12341200E+03, -.11762200E+03, 0.32660600E+03, -.24539000E+03, -.12833600E+03, -.18805700E+03, 0.42952300E+02, -.10727500E+03, 0.31840700E+02, -.17081800E+03, 0.62418600E+03, -.69395900E+02, -.12565500E+03, -.17379700E+03, 0.40365300E+02, 0.44116500E+03, 0.35158100E+02, -.15420500E+03, -.30666800E+03, 0.36654800E+03, -.16218000E+03, -.51317200E+02, 0.29016500E+03, 0.15990800E+03, 0.13687200E+03, -.24905200E+02, -.73218000E+01, 0.34863900E+03, -.10521400E+03, -.12894400E+03, 0.17364900E+03, 0.14906300E+03, -.23762800E+02, -.15076800E+03, 0.75913500E+02, -.55746100E+02, 0.29451700E+02, 0.96362200E+02, 0.18417000E+03, -.10729400E+03, -.65197500E+02, 0.47627600E+02, -.96401500E+00, 0.11386700E-01, -.50328500E+00, 0.26833700E+00, 0.34630100E+00, 0.24018700E+00, 0.13041900E+01, 0.10224600E+00, -.79643000E+00, -.24564000E-01, -.39909700E+00, 0.25494600E+00, 0.26320500E+00, 0.30164800E+00, 0.11967900E+01, 0.72214200E-01, 0.36081000E+02, -.91787600E+02, 0.84948100E+02, 0.33642000E+02, -.10818700E+03, -.35773800E+02, -.15976700E+03, 0.57403400E+02, -.32418400E+03, 0.16052400E+03, 0.73676600E+02, 0.79602900E+02, 0.27358700E+02, -.82310800E+02, 0.22607700E+01, 0.78838500E+02, -.10487200E+01, -.42535400E+00, 0.18155900E+00, 0.32924100E+00, -.57161500E+00, -.12672000E+01, 0.22361100E+01, -.44883100E-01, 0.28185900E+03, -.18907800E+03, 0.22145200E+03, 0.88067600E+02, -.36403600E+03, 0.80697300E+02, -.37985200E+02, 0.81857000E+02, -.26499700E-01, -.30471500E-01, 0.33719100E-01, -.12302000E+00, -.45084800E-01, -.56443000E+00, -.11094500E+01, 0.13753300E+00, -.25698800E+00, -.32729600E+00, 0.49946900E+00, 0.39141500E+00, -.61266600E+00, -.10761800E+01, 0.12800800E+01, 0.13736400E+00, -.40658700E+01, 0.27932300E+00, -.37963500E+02, -.89902700E+02, 0.33723500E+00, -.32712000E+01, 0.32487700E+00, -.39364300E+00, -.69252500E+00, 0.28882800E+00, -.97277100E+02, -.74309800E+02, -.67255800E+02, -.37889700E+02, 0.38864700E+02, 0.46144400E+01, -.43588300E+02, -.23144900E+02, 0.13562500E+00, 0.15318600E+00, -.32978800E+02, 0.91821100E+02, 0.95919400E+00, -.23358300E+02, -.30665200E+00, 0.49954800E+00 }, { 0.65432400E+00, 0.22325000E+00, -.64810100E+00, -.34146900E+00, -.21840900E+00, -.16837400E+00, 0.22209100E+01, 0.73571000E+00, -.12157600E+00, 0.22422500E+00, -.48114400E-01, -.68506800E+00, -.86893300E-01, -.16067900E+01, 0.63585300E+00, 0.30040100E+00, 0.36397800E+00, 0.23415200E+00, 0.23316500E+00, -.19794200E-01, -.61668400E-02, -.52183400E-01, -.32269500E+00, -.72243700E-01, -.41467700E-01, -.13934100E-01, 0.30438200E+00, 0.12161700E+00, 0.18518400E+00, 0.82052800E-01, 0.93486400E+00, -.17263100E+00, 0.97367400E-01, -.13932000E+00, -.14261500E+01, -.25737700E+00, 0.61731000E-01, -.31614900E+00, -.19388000E+00, -.46717000E-02, -.14891500E+00, 0.15922500E-01, -.51416700E-01, -.12834300E+00, -.61924500E-01, 0.50695200E+00, -.82282700E-01, -.86225400E+00, 0.70846300E-03, 0.14185300E-01, -.36312900E-01, -.60179500E-01, 0.74282400E-01, 0.96491800E+00, -.15970500E+01, -.15631000E+00, 0.11592600E+00, 0.47906700E-01, 0.61048400E-01, -.23892000E+00, -.42877400E+00, -.25497000E-01, -.72547200E-01, -.12178000E+01, -.28021700E+00, 0.98688300E-01, -.46466500E-01, 0.53209700E+00, 0.39707200E+00, 0.67548300E+00, -.74635700E+00, 0.85163800E+00, 0.40034400E+00, -.90336300E-01, 0.56493600E+00, -.65356000E-01, 0.56305400E+02, 0.48141200E+02, 0.88069800E+02, 0.14397800E+02, 0.17590100E+02, -.52446800E+02, 0.20876000E+02, 0.23084100E+02, -.26098800E+02, 0.65789300E+01, -.37053000E+02, 0.37360800E+01, -.77507500E+02, -.13475400E+03, -.57578600E+02, -.11422600E+02, 0.84310100E+02, 0.73308800E+01, -.54417400E+02, 0.90605200E+01, -.11905000E+03, 0.10766500E+03, 0.58287000E+02, 0.54785100E+02, -.18224900E+02, -.35442800E+02, -.13251700E+02, 0.43914100E+02, 0.10212900E+03, -.67328800E+02, -.25149900E+02, -.20917200E+02, -.54019600E+01, 0.52546800E+02, 0.10612300E+02, -.13872600E+02, -.20563500E+03, 0.10361500E+03, 0.68444200E+02, 0.50700800E+02, -.65486900E+02, -.70716600E+02, -.57633300E+01, -.55929300E+01, -.22448300E+01, -.12708600E+03, -.17553900E+02, -.40531200E+01, 0.17959800E+01, 0.38255700E+02, 0.12229900E+02, -.14039500E+02, 0.50831500E+02, 0.76836800E+01, -.11672000E+03, -.85651500E+02, 0.52565500E+02, 0.15382200E+02, -.43062000E+02, -.10985100E+03, -.44840100E+00, 0.14959900E+00, -.32699600E-01, 0.26718600E-03, 0.92411100E-01, 0.40626800E+00, -.19267100E+00, -.58885700E-01, -.45337500E+00, 0.14612700E+00, -.31124500E-01, 0.28836300E-01, 0.96633300E-01, 0.39463300E+00, -.18671700E+00, -.28332100E-01, 0.92779500E+02, 0.26093800E+02, -.48849900E+02, -.30666300E+02, 0.20055200E+02, 0.47227200E+02, 0.70922400E+02, -.30909200E+02, 0.18263700E+03, -.11806500E+01, -.35495700E+02, -.42136600E+02, -.14556000E+02, 0.65219000E+02, -.27719400E+02, -.43927700E+02, 0.63746000E+00, -.47291100E+00, 0.26700400E-01, 0.34432500E+00, -.10690600E-01, 0.19960600E+01, -.92383200E+00, 0.16986400E+00, 0.29701400E+03, 0.11707000E+01, -.33798100E+02, -.33896100E+02, 0.11765100E+02, 0.11412800E+03, 0.15978600E+02, 0.31439500E+02, 0.30902900E+00, -.98948700E-01, 0.34533400E-01, -.21581900E+00, -.78432100E-01, -.85745700E+00, 0.35114000E+00, -.44302300E-01, 0.59134000E+00, -.32449600E+00, 0.55165600E-01, 0.38071000E+00, -.83479400E-01, 0.17882700E+01, -.80807600E+00, 0.13339700E+00, -.18780900E+01, -.89188300E-01, 0.26111000E+01, 0.26527100E+00, -.15408600E+00, -.30566800E+00, -.12860100E+00, 0.20565500E+00, 0.24170500E+00, -.12147300E+00, 0.49086000E+02, -.13108700E+02, -.42698900E+02, 0.51494600E+01, -.22440700E+01, -.67012500E+02, 0.15027600E-01, 0.48658400E+02, -.78984000E-01, -.43144300E-01, 0.18698000E+02, -.13794800E+02, -.51680700E+00, -.26482900E+02, 0.12032100E+00, -.30445300E+00 }, { -.12487000E+01, -.55307000E+00, 0.23254600E+01, 0.92494200E+00, 0.89700000E+00, 0.53260800E+01, 0.38765200E+01, -.17489800E+01, 0.14538600E+00, -.45839500E+00, 0.73821100E-01, 0.10925200E+01, -.45170300E+00, 0.43274500E+01, -.12379400E+01, -.14614400E+01, -.16749500E+01, -.85150200E+00, -.23493400E+00, 0.62817000E-01, 0.12345000E+00, -.70689300E-04, 0.49964000E+00, 0.39211700E+00, -.91436300E-02, 0.22874800E-01, -.49931900E+00, -.21027100E+00, 0.29428900E+00, -.44851400E-01, -.99069400E+00, 0.26727900E+00, -.19207100E+00, 0.12158700E-01, -.30974600E+01, 0.32934200E+00, -.52288600E+00, -.87404200E+00, 0.69486000E+00, -.25835900E+00, -.13834200E+00, -.13071300E+01, 0.38133300E+01, 0.20951900E-01, 0.13148900E+01, -.29304600E+01, 0.87859300E+00, -.13900200E+01, -.32612800E-02, 0.12202300E-02, -.22332800E+00, -.16181800E+00, 0.39950900E+00, 0.15024200E+00, -.54565100E+01, -.82474600E-01, 0.13976500E+00, 0.51684900E+00, -.20768400E+00, -.15833800E+00, -.35845400E+00, -.77861300E-01, 0.12149600E+00, -.36468600E+00, -.32147600E+00, 0.50794900E-01, -.53831100E-01, 0.15690100E+00, 0.36967900E+00, 0.41173200E-01, 0.17551900E+01, 0.40894700E+00, 0.86633700E-01, -.39071400E+00, -.26502600E-01, -.10562800E+00, -.16305200E+01, 0.19449200E+03, 0.40769200E+03, 0.59308100E+02, -.64806400E+02, 0.73380800E+02, -.21646400E+02, -.33726400E+02, 0.29426800E+02, 0.10688600E+03, -.19712300E+01, -.88890900E+02, -.53215000E+03, -.55473600E+02, 0.66962400E+02, 0.12087500E+03, 0.21269700E+03, 0.13120400E+02, -.50184400E+03, 0.10165000E+03, 0.66720400E+02, -.66276000E+01, 0.55117500E+02, 0.13850100E+02, -.55576400E+02, -.20913800E+02, 0.13386000E+03, 0.32706400E+01, 0.76214500E+03, -.38433700E+03, -.99033500E+02, -.14284400E+03, -.74673500E+02, 0.43541000E+03, -.22642000E+01, -.10635600E+03, -.76122600E+03, 0.58727500E+03, 0.11734900E+03, 0.15874700E+03, -.13159500E+03, -.17186700E+03, 0.27393000E+02, 0.20305500E+02, -.91280200E+02, -.89070600E+02, -.99387200E+01, 0.61346200E+01, 0.14604600E+01, 0.97269800E+02, -.35969600E+02, -.42756700E+02, -.27660000E+03, 0.21707900E+03, -.33965100E+02, -.15647600E+02, 0.15591200E+03, -.21227400E+03, -.47844500E+03, -.13580400E+03, -.19490800E+01, 0.68605700E+00, -.34973000E+00, -.72128100E-02, 0.61418100E+00, 0.61723500E+00, -.10637900E+00, -.20210000E+00, -.18748700E+01, 0.65058500E+00, -.25224800E+00, 0.88679800E-01, 0.55601500E+00, 0.60882200E+00, -.17724000E+00, -.10301300E+00, 0.22360900E+03, 0.13912500E+02, -.11061400E+03, -.67203700E+02, 0.25799600E+02, 0.14961400E+03, 0.26692100E+03, -.57431200E+02, 0.25252700E+03, 0.16895100E+02, -.54302800E+02, -.56799600E+02, -.16512900E+02, 0.99580600E+02, -.75991800E+02, -.61512100E+02, 0.17984000E+01, -.16215500E+01, -.23396700E+00, 0.70923700E+00, 0.14604500E+00, 0.27321900E+01, -.14137100E+01, 0.27269200E+00, 0.93003000E+03, -.36901100E+03, -.20597800E+01, -.41167600E+02, -.90181100E+02, 0.34146800E+03, 0.42856100E+02, 0.16490800E+03, 0.10133600E+01, -.46558700E+00, -.91008300E-01, -.60875400E+00, -.20941600E+00, -.15121600E+01, 0.66087700E+00, -.14046900E+00, 0.20371300E+01, -.13089700E+01, 0.80229000E-01, 0.92477500E+00, -.31219700E+00, 0.25608000E+01, -.12921300E+01, 0.31017700E+00, -.81476000E+01, 0.27231200E-01, -.10594900E+02, -.48666300E+02, -.10763200E+00, -.29334400E+01, 0.34240400E-01, 0.19182600E+00, 0.51018600E-01, -.53110200E-01, 0.17195800E+03, -.81302000E+02, -.18985600E+03, -.65973000E+01, 0.18744900E+02, -.21784600E+03, -.12568700E+02, 0.20415400E+03, -.85059000E-01, 0.56445500E-01, 0.67705500E+02, 0.19633800E+02, -.51252500E+00, -.92611500E+02, 0.40533700E-01, -.33490600E+00 }, { -.48753900E+00, -.64058400E+00, 0.82361200E-01, 0.60376400E+00, 0.53640400E+00, -.28702200E+01, -.31274000E+01, -.69233600E+00, -.46579400E-02, 0.47462400E+00, 0.10274100E+00, 0.31033400E+00, 0.68185500E+00, -.24760200E+01, 0.53342000E+00, 0.24804700E+01, 0.44136400E+00, 0.34948100E+00, -.83165400E-01, -.73972900E+00, 0.98383000E+00, -.20694800E+00, -.12955400E+01, 0.73711200E+00, -.97003300E-01, 0.18549900E+00, -.74716100E+00, -.27083900E+00, -.79274100E+00, 0.35745700E-01, -.22682200E+01, -.61247000E-01, 0.27007500E+00, -.39260900E-01, -.62501400E+00, -.11450500E+00, -.66782300E-01, 0.83424100E-01, -.46182000E+00, -.10638600E+00, -.12995900E+00, -.10716900E+00, 0.81523800E+00, 0.74250500E-01, 0.18406900E+00, 0.61175400E+00, 0.14867200E+00, -.15671100E+01, -.65454200E-01, 0.90345800E-01, -.20330000E+00, -.65679600E-01, 0.68650900E+00, 0.48153500E-01, -.95599300E+00, 0.25895400E+00, 0.14772500E+00, -.46409100E+00, 0.38936800E+00, 0.59631600E+00, -.52798200E+00, 0.48853300E-01, 0.11424100E+00, -.56131000E+00, -.41602400E+00, 0.62701300E-01, -.10979400E-01, 0.30957800E+00, 0.26122500E+00, -.53719900E-02, -.13156900E+01, 0.32557300E+00, 0.25887300E+00, -.18011300E+00, 0.15446600E+00, 0.37568300E-01, 0.40814100E+00, 0.64893500E-01, 0.78901500E+02, -.63593600E+00, -.42312400E+02, 0.23890800E+02, -.29504200E+02, -.72324100E+01, 0.31137400E+02, -.16948500E+02, 0.16326400E+02, -.44533500E+01, -.21433600E+03, 0.92298400E+02, 0.40560600E+02, 0.77360400E+02, -.12187700E+02, -.10181600E+03, -.11238700E+03, 0.77096700E+02, -.54539700E+02, 0.46853400E+02, 0.18272300E+02, 0.13096600E+02, -.16623800E+02, -.49698000E+01, 0.95657300E+01, 0.11051800E+02, -.15795700E+03, 0.33477900E+02, 0.20273500E+02, 0.21538500E+02, -.16188500E+02, -.35851400E+02, 0.18803100E+02, 0.12888000E+02, -.12550400E+03, 0.19189100E+02, 0.50857800E+02, 0.50357100E+02, -.30465400E+02, -.70579900E+02, -.20783600E+00, 0.57012800E+02, -.56925600E+02, 0.46819700E+02, 0.44902000E+01, 0.24023200E+02, -.17037200E+02, -.19574200E+02, 0.51884400E+02, 0.28936900E+02, -.38146400E+03, 0.10293900E+03, 0.10867900E+03, 0.13370100E+03, -.28235700E+02, -.15030800E+03, -.14019300E+03, 0.14712400E+03, -.15869600E+00, 0.61867800E-01, 0.29136300E-01, 0.13717900E-02, 0.28055300E-01, -.28736100E+00, -.34466300E+00, -.10791100E-01, -.16304500E+00, 0.66940800E-01, 0.29187800E-01, -.14197900E-02, 0.30400700E-01, -.29157600E+00, -.36400400E+00, -.83857100E-02, 0.76426100E+02, -.52652000E+02, -.11086900E+02, -.25415200E+02, 0.51394200E+01, 0.29166200E+02, 0.39119100E+02, -.24249700E+02, 0.14067200E+03, -.70801300E+02, -.16748900E+02, -.26775600E+02, -.12781900E+02, 0.51383700E+02, -.28687600E+01, -.22651300E+02, 0.20721600E+00, -.13845000E+00, -.60465400E-01, -.84817300E-01, 0.23279400E-01, -.10944200E+01, -.48231400E+00, -.88992100E-01, -.11126600E+03, -.26953700E+02, 0.44124900E+02, 0.39673100E+02, -.21468800E+02, -.79699600E+02, -.18367800E+03, 0.23189100E+02, 0.16369500E+00, -.62212600E-01, -.15149700E-01, 0.21985900E-01, -.36947300E-01, 0.51889100E+00, 0.44171700E+00, -.12666300E-01, 0.28215100E+00, -.12421100E+00, -.47305100E-01, -.78517500E-01, -.16870400E-01, -.89054500E+00, -.22073500E+00, -.57019900E-01, -.64703500E+00, -.12032600E+00, 0.14089800E+02, -.61777900E+01, -.13133300E+00, -.44993500E+00, -.79296800E-01, 0.13315800E+00, 0.11942200E+00, -.12144300E+00, 0.35245600E+02, -.32403600E+01, -.14290200E+02, -.24476800E+01, -.14028000E+02, -.53729800E+01, 0.45389500E+01, 0.15817800E+02, -.98610700E-01, -.87609200E-01, 0.10356400E+02, 0.36814500E+01, 0.99353100E-01, 0.78227300E+01, 0.12647600E+00, -.10926100E+00 }, { -.23753900E+00, -.97712800E-01, 0.42871000E+00, -.44830700E-01, 0.93021100E-01, 0.81614900E+00, 0.69467100E+00, -.36948000E+00, 0.12254800E+00, -.24962700E+00, 0.49577400E-02, 0.14269300E+00, -.29146300E+00, 0.16253800E+01, -.24990100E+00, -.97757800E+00, -.46654000E+00, -.38806400E+00, -.55016600E-01, 0.21460100E+00, -.92765400E-01, -.14931600E-02, 0.15049100E+00, 0.76381300E-01, 0.49266600E-02, 0.18992600E-01, -.92409600E-01, -.37311100E-01, 0.12021600E+00, 0.23881200E-02, 0.47461400E-01, 0.52969200E-01, -.10198600E+00, -.27882300E-01, -.29167300E+00, 0.10235100E+00, 0.28350900E-02, 0.19090000E-01, -.80432400E-01, -.85539600E-02, 0.57859200E-02, 0.10004000E+00, 0.85259200E-01, 0.17448900E-01, -.42315900E-01, -.15540000E+00, 0.33002200E-01, 0.18164500E+00, 0.25847100E-02, -.28358000E-02, 0.83854900E+00, 0.49147100E-02, -.86067200E-01, 0.11261500E-01, 0.14769200E+01, -.21616800E-01, -.78891600E-02, 0.68867700E-01, -.24676700E+00, 0.20434300E+00, -.31229000E+00, -.39526300E-01, 0.11817200E+00, 0.43015700E+00, -.15812800E-01, -.24575900E-01, 0.62128900E+00, -.20924100E+00, -.45136900E-01, 0.65480300E-01, -.44756400E+00, -.22321800E+00, -.78794200E-01, 0.41354600E-01, -.78928600E-01, -.12063100E-01, -.23433900E+00, 0.11030700E+00, -.19981700E+00, 0.13279300E+02, -.33605900E+02, 0.12675800E+02, -.11600700E+02, -.21293000E+02, 0.23461600E+02, 0.68890900E+01, 0.21208100E+02, -.15730700E+02, 0.60285400E+01, 0.47131900E+02, -.15347600E+02, -.13242000E+02, 0.14862000E+02, -.27257600E+00, -.59725100E+00, -.24744500E+02, -.42346200E+02, 0.17426200E+02, 0.33302900E+02, 0.23086500E+02, -.22037900E+02, -.19634500E+02, -.16562600E+02, 0.31877000E+02, 0.55658100E+02, -.19379900E+01, -.24164900E+02, -.25102700E+02, 0.63498700E+01, 0.31807600E+02, 0.20690300E+02, -.27410700E+02, 0.91618000E+02, -.40219000E+02, -.20015800E+02, -.34156700E+02, 0.31038200E+02, 0.59483500E+02, 0.25514500E+02, -.22289600E+02, 0.70916300E+00, 0.37765900E+02, -.65247000E+01, -.19313000E+02, 0.26556200E+02, 0.97532800E+01, 0.87880000E+01, -.14377400E+02, -.16879200E+02, -.17857000E+02, 0.27778500E+02, 0.35663300E+02, -.59663900E+01, -.34441500E+02, -.32201900E+02, 0.24473800E+02, 0.16162900E+00, -.96621200E-01, 0.16476300E+00, 0.66639800E-02, -.42216100E-01, 0.80942600E-01, -.21981500E-01, 0.37031100E-01, 0.16755100E+00, -.96024800E-01, 0.16080800E+00, -.53366200E-02, -.38661300E-01, 0.79577500E-01, -.24877900E-01, 0.22397700E-01, 0.20187900E+02, -.13513600E+02, 0.13374800E+02, 0.96855600E+01, -.99063300E+01, 0.30906400E+01, -.15332300E+02, 0.18899800E+02, -.31237900E+02, 0.18825900E+02, 0.91100000E+01, 0.74115200E+01, 0.33911400E+01, -.14333000E+02, -.18906500E+02, 0.72112200E+01, -.30016400E+00, 0.16642400E+00, 0.79054000E+00, -.30183200E+00, 0.26203700E-01, -.16949800E+00, -.23638800E+00, -.12180800E+00, 0.57768400E+02, -.27049200E+02, -.38712400E+02, -.33561200E+02, 0.12446800E+02, 0.40990800E+01, -.30396200E+02, -.47644700E+02, -.13716300E+00, 0.66485000E-01, -.35021000E+00, 0.10900400E+00, 0.85774100E-02, -.25034000E-01, 0.15591400E+00, 0.28621100E-01, -.26791700E+00, 0.13904600E+00, 0.76892900E+00, -.24629800E+00, 0.17020300E-01, -.19549700E+00, -.30999000E+00, -.58071500E-01, 0.66146400E+00, -.43605700E-01, -.49981000E+00, -.54705100E+01, -.36087700E-01, 0.90833800E+00, 0.17716900E+00, 0.31766400E-01, -.26047000E+00, -.36690400E-01, 0.55560500E+01, -.22578200E+01, 0.79069300E+00, 0.42506500E+01, -.22336600E+01, 0.18812400E+02, -.63305000E+01, 0.52088100E+01, -.15323100E-01, -.31291500E-01, -.38377100E+00, 0.73543400E+00, -.32597000E-01, 0.97000100E+01, 0.39894800E-01, -.11529300E-01 }, { 0.19041100E+00, 0.79502200E-01, -.35026200E+00, -.15189100E+00, -.13556000E+00, -.80691500E+00, -.61015200E+00, 0.24153700E+00, -.20001200E-01, 0.49868100E-01, -.66473100E-02, -.11552700E+00, 0.59212400E-01, -.56467600E+00, 0.11800200E+00, 0.23691500E+00, 0.22351700E+00, 0.86235400E-01, 0.35562800E-01, -.37584200E-01, -.12643800E-02, 0.35384300E-02, -.51641700E-01, -.54886800E-01, -.25611300E-02, -.16369700E-01, 0.96300000E-01, 0.34401000E-01, 0.12718600E-01, 0.10027400E-02, 0.11627600E+00, -.34559800E-01, 0.50152800E-01, -.62117000E-02, 0.14505900E+00, -.59591100E-01, 0.13848600E-01, -.55341400E-01, 0.40109500E-01, 0.38387800E-02, -.14069200E-01, -.37028000E-01, -.53827600E-01, -.19902700E-01, 0.61850800E-02, 0.84344900E-01, -.26431600E-01, -.96278000E-01, 0.21621300E-02, -.83009000E-03, 0.96870500E-02, -.27761600E-02, -.15757200E-01, 0.18006100E-02, -.33953800E+00, -.15251000E-01, -.57276200E-02, 0.33055100E-01, 0.45533900E-02, -.37603000E-01, 0.19900500E-01, 0.98460000E-02, -.48531300E-01, -.15495900E+00, 0.24719800E-01, 0.99390400E-02, -.45995500E-02, 0.64633500E-01, 0.43037600E-01, -.89448100E-02, 0.75477700E-01, -.80854800E+00, 0.10274400E+00, -.90456000E-01, 0.58136500E-01, 0.51100900E-01, 0.44990800E-01, 0.76939200E-01, 0.33271300E+00, -.75698400E-01, 0.98538000E+02, -.30744500E+02, 0.17007400E+02, 0.20944200E+02, -.42037600E+02, 0.39716400E+01, -.44555000E+02, 0.20137800E+02, 0.41587000E+02, -.30358400E+02, -.19191300E+02, -.14656300E+02, 0.21877900E+01, 0.46062600E+00, 0.41814000E+02, -.19714400E+02, 0.18769300E+01, 0.13728000E+01, 0.12164800E+01, 0.28915100E+01, 0.32741900E+00, 0.77115800E+01, -.10603400E+02, 0.82970900E+00, 0.69240400E+02, -.42285100E+02, -.57582700E+01, -.62608900E+01, -.51115000E+01, -.34852000E+01, -.92456500E+01, -.67058200E+01, 0.90505000E+02, -.35980700E+02, -.93278900E+01, -.21970800E+02, 0.26586300E+01, 0.10546900E+02, -.23466000E+02, -.17370700E+02, 0.19675500E+02, -.52619100E+01, -.52785700E+01, -.46470700E+01, 0.92395300E+00, -.50552400E+01, -.19256800E+02, -.71273600E+01, -.80011600E+01, 0.27551400E+02, -.43074100E+02, -.56217600E+02, 0.37594600E+02, 0.89438000E+01, 0.56610300E+02, -.63186300E+02, -.42846800E-01, 0.20990400E-01, -.64893500E-01, -.12788300E+00, 0.60930300E-01, -.15993000E-01, 0.99158100E-01, -.18024300E+00, -.29258900E-01, 0.17374700E-01, -.65110800E-01, -.11877800E+00, 0.55792200E-01, -.78419300E-02, 0.11204100E+00, -.17138900E+00, -.31449900E+02, 0.75201600E+01, -.12794300E+02, -.15984600E+02, 0.21494400E+02, -.11645900E+02, 0.20177900E+02, -.17906300E+02, -.43767900E+02, 0.19309800E+02, 0.65620300E+01, 0.72149300E+01, 0.54585800E+01, -.22427800E+02, -.73611600E+01, 0.41917700E+01, -.18882600E-01, -.93193000E-01, 0.14619600E+00, 0.44076600E+00, -.71235000E-01, 0.84816900E-01, -.66305100E-01, 0.18640300E+00, 0.26357500E+02, -.29337400E+02, -.30570500E+02, -.26001500E+02, 0.37958500E+02, 0.37799500E+02, 0.58941400E+02, -.25780500E+02, -.47674900E-01, -.67584700E-02, 0.32634000E-01, -.89451900E-02, -.19690200E-01, -.15072400E-01, -.90000000E-01, 0.10434800E+00, -.55405300E-01, -.45852600E-01, 0.15385900E+00, 0.43950300E+00, -.57422200E-01, 0.40853900E-01, -.12617800E+00, 0.21157800E+00, -.20481800E+00, 0.24870700E+00, -.70467000E+00, -.20030700E+00, 0.26400800E+00, 0.15121200E+00, 0.37040900E+00, -.26984900E+00, -.40280300E+00, 0.25158000E+00, -.37892400E+01, -.17847100E+01, 0.96730200E+01, 0.37760600E+01, -.10999900E+01, 0.65040700E+01, 0.11052000E+00, 0.39346600E+01, 0.17877700E+00, 0.17994600E+00, -.21757900E+00, -.67806700E+00, 0.28676300E+00, -.44034900E+01, -.25762800E+00, 0.27405400E+00 }, { -.18060000E+01, -.29253500E+01, 0.21693000E+01, -.16020700E+00, 0.14070300E+01, 0.16450200E+01, 0.23629200E+01, -.15150500E+01, -.22430500E+00, 0.21410000E+01, -.27501700E+00, -.21494300E+00, 0.24411100E+01, -.58089900E+01, -.18795000E+01, 0.89056700E+00, -.28570000E+01, -.97618700E-01, -.36877800E+00, -.30669800E+00, 0.21949600E+01, -.79760100E+00, -.94985900E+00, -.13305900E+01, -.55015200E+00, 0.32543700E+00, -.14456500E+01, -.69588000E+00, -.24195800E+00, 0.16866700E+00, 0.12595200E+01, 0.10973300E+00, 0.11114000E+00, -.44607400E+00, 0.30823200E+01, 0.27211500E+00, 0.36534500E-01, -.39572900E+00, 0.88998100E+00, -.38645800E+00, -.22479300E+00, 0.95327900E+00, -.21612100E+01, -.88304200E+00, -.17368400E+00, -.14584300E+01, -.16217900E+00, 0.10765500E-02, 0.22189100E+00, -.42442300E-02, 0.59517900E+00, -.27441700E+00, -.11047400E+01, 0.24362600E+00, -.50112300E+01, -.10964900E+01, -.35154300E+00, 0.11933000E+01, -.22753200E+01, -.11991600E+01, 0.14698300E+01, -.36455900E+00, -.11427400E+01, -.24292200E+01, 0.14702100E+01, 0.23767300E+00, -.26869500E+00, 0.12992800E+01, 0.12254000E+01, 0.30422600E+00, 0.27805600E+01, 0.36685200E+00, -.14177800E-01, -.11757600E+00, 0.19856500E+00, 0.30545400E+00, 0.71343000E+00, 0.86812100E-01, -.19844300E+01, 0.28383900E+01, -.36389400E+01, 0.30197600E+03, -.10550300E+03, 0.92815500E+01, 0.22772200E+02, -.50336300E+02, -.61509000E+02, -.22402000E+02, -.46443900E+03, 0.29162800E+03, 0.10156700E+03, 0.17521000E+03, 0.12655900E+03, -.11138700E+03, -.13936000E+03, 0.14298800E+03, 0.12506600E+03, -.11568100E+03, -.72345900E+02, -.51097600E+02, 0.22257300E+02, 0.50452600E+02, -.13756000E+02, -.73530200E+02, -.15389700E+03, -.93304000E+02, 0.13183700E+03, 0.11744100E+03, -.57911600E+02, -.84199900E+02, -.27354100E+02, 0.14654200E+03, 0.31978800E+03, 0.57667200E+03, -.45791600E+02, -.94351100E+01, -.27806100E+03, -.44836900E+02, -.14889700E+03, -.58233600E+02, -.21838100E+03, 0.33247300E+03, 0.58523200E+02, 0.15172700E+03, -.84138000E+02, -.13486900E+03, -.14010400E+03, 0.11545000E+03, -.80112600E+03, 0.45043800E+03, 0.31232100E+02, -.11396400E+02, 0.24003800E+03, -.21913300E+03, -.10644000E+02, -.36271200E+02, -.93960600E+00, 0.10795200E+01, -.76202600E+00, -.16919100E+00, 0.65266400E+00, -.11063700E+01, 0.34394900E+00, -.78005000E+00, -.80780300E+00, 0.10675900E+01, -.70827300E+00, -.12493300E+00, 0.61127100E+00, -.10246500E+01, 0.29075900E+00, -.69209400E+00, -.10039200E+03, -.14682500E+03, -.14605700E+02, -.53491200E+02, 0.85257500E+02, -.88832900E+02, 0.37572800E+02, -.67337600E+02, 0.10027600E+03, -.14084300E+03, 0.43666700E+01, -.11086300E+02, -.31150900E+02, 0.36858900E+01, -.45285000E+02, -.21231200E+02, 0.10410400E+01, -.29514000E+01, -.15577000E+01, 0.35847300E+01, -.62708000E+00, -.36010300E+01, -.55216700E+00, 0.12552500E+01, 0.80582100E+02, -.69414900E+03, 0.19752100E+03, 0.11103800E+03, -.60011100E+02, 0.15534500E+03, 0.67092700E+02, 0.17004200E+03, 0.35331600E-01, -.91682500E+00, 0.10180400E+01, -.68415100E+00, -.30609200E+00, 0.14149500E+01, 0.92012200E-01, 0.24260400E+00, 0.79729900E+00, -.23331500E+01, -.14950800E+01, 0.31291400E+01, -.65275200E+00, -.30827300E+01, -.46286900E+00, 0.10356100E+01, -.39968700E+01, 0.13076600E+01, 0.74985500E+01, -.13868800E+02, 0.13042200E+01, -.24359900E+01, 0.17274300E+01, -.13259800E+01, -.15446600E+01, 0.12533800E+01, -.21698500E+01, -.54181600E+02, -.47753000E+02, 0.89275400E+00, 0.68009700E+01, -.16201400E+03, 0.13253800E+02, 0.34908500E+02, 0.82274400E+00, 0.94750500E+00, -.67971300E+01, 0.49178200E+01, 0.18852700E+01, -.63742600E+02, -.13039600E+01, 0.14274800E+01 }, { -.58335500E+00, -.77177500E+00, 0.46063300E+00, -.31045900E-01, 0.15148900E+00, 0.44826300E+00, 0.19362700E+00, -.63544600E+00, 0.94608200E-01, 0.34335800E+00, -.95831200E-01, -.33498300E+00, -.46288300E-01, 0.46232300E-01, -.17392000E+00, -.10654500E+01, -.98174000E+00, -.32996400E+00, -.31103600E-01, 0.23907200E+00, 0.20564800E+00, -.17761400E+00, -.39286900E+00, 0.37359300E+00, -.66930300E-01, 0.15473900E+00, -.40462900E+00, -.14968100E+00, 0.20318200E+00, 0.10809900E+00, 0.51895800E+00, -.47569400E-01, -.14521600E+00, -.13511500E+00, -.14314500E+01, 0.35690500E-01, 0.25467400E-02, -.27383200E-01, -.35491600E+00, -.49780700E-01, -.49230200E-01, 0.28101700E+00, 0.22507500E+00, -.11468100E+00, -.12285600E+00, -.49462400E-01, 0.60994200E-01, -.15895000E+00, -.66087200E-04, 0.87616000E+00, -.15786800E+00, -.16117900E+00, 0.25193000E+00, 0.13486500E+00, 0.88534700E+00, -.15619400E+00, 0.10593200E+00, 0.11056900E+01, -.47670500E-01, -.51532700E+00, -.16655600E+00, -.12987400E+00, 0.20926100E+00, 0.83129100E+00, 0.99729000E-01, 0.71892300E+00, 0.19325900E+00, -.53535400E+00, 0.67922800E-01, -.26647500E-01, 0.10581000E+01, -.29758200E+00, 0.11495800E+00, 0.12284400E+00, 0.27031700E+00, -.35393200E-01, -.32439200E+00, 0.11378600E+00, -.53355000E+00, -.59804200E+00, -.82228800E-01, 0.24575300E+00, 0.43672000E+02, -.45976400E+01, -.89954200E+01, 0.75546300E+01, 0.17390100E+02, 0.13281800E+02, 0.13970600E+03, 0.89386900E+02, -.89305600E+01, -.26760600E+02, -.57755700E+02, -.45706500E+01, -.25136200E+01, -.24423100E+01, -.15018600E+03, 0.57154600E+02, 0.57935500E+02, 0.62266700E+02, -.20592800E+02, -.72345100E+02, 0.17266400E+01, 0.69565600E+02, 0.22785500E+03, 0.35054800E+02, -.89818300E+02, -.92065600E+02, 0.31227000E+02, 0.95971800E+02, 0.56739700E+02, -.96881100E+02, -.19087800E+03, -.13063400E+03, 0.60765200E+02, 0.41640100E+02, 0.75516600E+02, -.30052900E+02, 0.26491400E+02, 0.59750400E+02, 0.41708700E+02, -.15029200E+02, 0.26007300E+02, -.11926100E+02, 0.29028300E+01, 0.80151800E+01, 0.97784700E+01, 0.36887700E+01, 0.18161000E+03, 0.37875200E+02, 0.41219900E+02, 0.73175700E+02, -.86020100E+02, -.34058300E+02, -.12456100E+03, 0.96513000E+02, 0.44738800E+00, 0.67642000E+00, 0.44993800E+00, -.10076100E+00, -.23136600E+00, 0.20401300E+00, -.89182600E-01, 0.25725100E+00, 0.44251900E+00, 0.67641800E+00, 0.39557800E+00, -.14319800E+00, -.21099300E+00, 0.19495000E+00, -.85403300E-01, 0.19666100E+00, -.34657600E+01, 0.50752200E+02, 0.21499700E+02, 0.36898400E+02, -.36275000E+02, 0.14174300E+01, -.40175900E+01, 0.40896800E+02, -.11023800E+03, 0.18907700E+02, 0.71276300E+01, 0.15414600E+02, 0.24920700E+02, -.29015100E+02, 0.35583400E+02, 0.18889300E+02, 0.78108200E-01, 0.50337200E+01, 0.77627000E+00, -.17927900E+01, -.22203900E-01, 0.82966800E+00, 0.55701800E+00, -.43517500E+00, -.12208500E+03, 0.49491200E+02, -.10388400E+03, -.49443200E+02, 0.33231200E+02, -.50275600E+02, 0.21304200E+02, -.81362000E+02, -.27359300E+00, -.18029700E+01, -.44065400E+00, 0.62315500E+00, 0.88731000E-01, -.22875100E+00, -.80649700E-01, 0.31136700E-01, -.20907800E+00, 0.45362100E+01, 0.69624100E+00, -.15823800E+01, 0.11099600E+00, 0.60954900E+00, 0.57454400E+00, -.35743500E+00, 0.18598500E+01, 0.93025600E-01, -.13211700E+02, 0.17288000E+02, -.15886000E-01, 0.28486900E+01, -.62217300E+00, 0.91716100E-01, 0.72950800E+00, -.47802200E-01, -.34344000E+01, 0.30096900E+02, 0.20954900E+02, -.22305500E+01, 0.17998400E+01, 0.60841200E+02, -.31716800E+01, -.14409500E+02, -.67858100E-01, -.31510900E-02, 0.20813400E+01, -.42000700E+01, 0.87452800E-02, 0.29559200E+02, -.40563000E-01, -.11966600E+00 }, { 0.15538900E+01, 0.31425100E+01, -.10620400E+01, 0.20405600E+00, -.16945400E+00, 0.59244300E+01, 0.69863400E+01, 0.11153800E+01, 0.22586000E+01, 0.29314400E+01, -.11673900E+01, -.70592100E-01, -.81828800E+00, 0.51967500E+01, -.10251700E+01, -.36996700E+01, -.44447400E+01, 0.10640800E+01, 0.26024100E+01, 0.26470200E+00, -.95496300E+00, -.76445200E+00, -.56060700E+00, 0.24617200E+00, 0.30835700E+00, -.25103100E+00, -.21271200E+01, -.85710800E+00, -.22363000E+01, -.35875700E+00, -.10039200E+02, 0.93483400E+00, 0.13551600E+01, -.28961700E+00, -.12186700E+01, 0.90510300E-01, 0.35287200E-02, -.35075200E+00, -.17950500E+01, 0.35096400E+00, -.72477400E+00, -.84133800E-01, 0.32802900E+01, -.51051400E+00, 0.24372000E+00, 0.10722800E+01, -.33767300E+00, -.19872700E+01, -.28857400E-01, 0.24177700E+00, 0.63988600E-01, -.40908500E-01, 0.66478200E+00, -.69718100E-01, -.34325800E+01, 0.28746400E+00, -.73062100E-01, -.52087400E+00, 0.35321600E+00, 0.19839500E+01, 0.95409000E+00, 0.31813500E+00, -.13003900E+01, -.36169300E+01, 0.97583000E+00, 0.30208100E+00, -.53048000E+00, 0.16632100E+01, 0.14533900E+01, -.20927900E+00, 0.47115400E+00, 0.14501400E+01, 0.16937300E+00, -.55696800E+00, 0.26425100E+00, -.11601100E+00, 0.11759200E+01, -.71989700E-01, -.16522300E+01, -.89309400E+00, -.44642400E+01, 0.64924900E+00, -.27079000E+01, -.82848700E+02, 0.48726000E+02, 0.12123800E+02, 0.91492000E+02, -.49438100E+02, 0.24752700E+03, 0.29539000E+03, -.74349300E+02, -.60919900E+02, -.45484900E+02, -.11098500E+03, -.11625800E+03, -.60845500E+02, -.78028900E+03, 0.43142300E+03, 0.39462400E+03, 0.34213000E+03, -.27080100E+03, -.30841500E+03, -.11790700E+03, 0.33156400E+03, 0.73812200E+03, -.44079400E+02, -.27165300E+03, -.25178000E+03, 0.46730400E+02, 0.22467700E+03, 0.18507400E+03, -.28157300E+03, 0.34859300E+03, -.61831600E+03, -.14033800E+03, -.22812200E+03, 0.29554300E+03, 0.17289500E+03, 0.16577000E+03, -.17195900E+03, 0.10013300E+03, 0.11735800E+03, -.10722100E+02, -.12028500E+03, 0.13049200E+03, 0.30964000E+02, 0.10205500E+03, -.10254400E+03, -.23670300E+03, 0.30035000E+03, 0.45040500E+02, 0.17578800E+03, 0.49755900E+02, -.45336400E+03, -.29525700E+03, 0.18893600E+03, 0.27552800E-02, 0.22912000E+01, 0.10958300E+01, -.36830100E+00, -.98450300E-01, -.27387300E+00, -.21370000E+00, 0.28630000E+00, 0.89900600E-01, 0.22674900E+01, 0.10518800E+01, -.43649500E+00, -.11315400E+00, -.24018700E+00, -.24394800E+00, 0.18006700E+00, 0.39604000E+03, -.95702500E+02, 0.36164700E+02, 0.43883300E+01, -.15423300E+03, -.95519800E+01, -.11034400E+03, 0.14955200E+02, -.10289700E+03, 0.82406200E+02, 0.40318100E+02, 0.17161100E+02, 0.30409600E+02, -.69129700E+02, -.42083500E+02, 0.19051600E+02, 0.22705600E-01, 0.13188000E+02, 0.56657700E+01, -.30341600E+01, -.92070100E+00, 0.38902500E+00, -.16546600E+01, -.67456400E-01, 0.25690200E+03, -.11344000E+03, -.26494100E+03, -.20501300E+03, 0.12009400E+03, 0.12779200E+03, -.20965700E+03, -.26629100E+03, -.29924200E+00, -.51545700E+01, -.20952200E+01, 0.14491500E+01, 0.23877200E-01, 0.17384300E+00, 0.69252200E+00, 0.26773600E+00, -.17459400E+00, 0.11812900E+02, 0.51775800E+01, -.27401500E+01, -.52539700E+00, 0.27215100E+00, -.14920900E+01, -.13764300E-01, 0.85829500E-02, 0.79886700E+00, -.78330200E+01, -.16456500E+02, 0.51652800E+00, 0.60037100E+01, -.19032500E-02, -.31905200E+00, -.79368100E-02, 0.41726600E+00, 0.24184500E+02, 0.67319100E+01, 0.28767200E+02, 0.27643500E+02, -.34527300E+02, 0.94107300E+02, -.29088400E+02, 0.48427100E+02, 0.14865000E+00, 0.38739400E+00, -.19064800E+02, 0.94039500E+01, 0.10363000E+01, 0.41051500E+02, -.66413700E+00, 0.31531600E+00 }, { -.96643700E+00, -.30985600E+00, 0.17139600E+01, 0.60445900E+00, -.11076000E+00, 0.22042900E+01, 0.43630700E+01, 0.27172700E+00, 0.47466000E+00, -.65745400E+00, 0.40910000E-02, 0.29690200E+00, -.93343300E+00, 0.55723100E+01, -.81919400E+00, -.35766000E+01, -.19777300E+01, -.94866100E-01, 0.14784200E+01, 0.65813700E+00, -.11425600E+01, -.41237800E-01, 0.11146600E+01, -.67799200E-01, 0.10197500E+00, 0.43366200E+00, 0.13385700E+00, -.59413000E-01, 0.25701100E+01, -.16816800E-01, 0.58263300E+01, -.43839000E+00, -.10777200E+01, -.75550500E-01, 0.33040400E+01, 0.22047000E+00, 0.27491800E+00, -.24371300E-01, 0.65075600E+00, -.99495100E-01, 0.31977300E+00, 0.86360400E-02, -.29838300E+01, 0.74572700E+00, -.40111100E-01, -.32486000E+00, -.10540600E+00, 0.23278200E+01, 0.20229100E-01, 0.32530800E-01, 0.29041800E+00, 0.20129900E+00, -.37894400E+00, -.23835100E+00, 0.27568200E+01, 0.14858400E+00, -.24843700E+00, -.15085300E+00, -.14346600E-01, 0.31694800E+00, 0.12416700E+00, -.13074000E+00, -.19917800E+00, -.21748300E+00, 0.31978500E+00, -.55652500E-01, -.20108600E+00, 0.30351600E+00, -.60286300E-01, 0.62209800E-01, 0.16823800E+01, -.46859200E+00, 0.58734000E+00, 0.19060000E+00, -.33223000E+00, -.36516900E+00, -.30148200E+00, 0.15973800E+00, -.14831000E+01, 0.30828100E+01, 0.72924700E+00, -.33241700E+00, -.13451300E+01, -.14745700E+00, 0.46791300E+02, -.21630000E+02, 0.31568600E+02, 0.26061200E+02, 0.98264100E+02, 0.36431500E+03, 0.39145000E+02, 0.22087200E+02, -.15754200E+03, -.13098100E+02, -.55912800E+02, 0.63153900E+02, -.12793900E+03, 0.30564500E+02, -.62489100E+02, -.21624200E+02, 0.81666200E+02, -.12224100E+03, 0.31003100E+02, -.15605800E+02, 0.18223400E+03, 0.17779300E+03, -.10064300E+03, -.11707100E+03, 0.61235900E+02, 0.11968700E+03, 0.11668600E+03, -.12718400E+03, -.60396200E+03, -.97042000E+02, 0.11799900E+03, 0.15371100E+03, 0.16493800E+03, -.20784800E+03, -.29044500E+02, 0.19833000E+03, -.52522500E+02, 0.19175600E+03, 0.40607800E+01, 0.12292600E+02, -.17079100E+01, -.53239800E+02, 0.55602300E+02, 0.33822800E+02, -.20286600E+03, 0.34945600E+03, 0.11578500E+03, 0.18886800E+03, -.11731600E+03, -.26948400E+03, -.29074100E+03, 0.24684300E+03, 0.37050500E-01, 0.14730800E+01, -.54325300E-01, -.90863400E-01, -.16888100E+00, -.55870200E+00, 0.28993000E+00, 0.28389300E+00, 0.74256200E-01, 0.14741300E+01, -.10902600E+00, -.15943300E+00, -.16330600E+00, -.53204800E+00, 0.24958500E+00, 0.19678800E+00, 0.51200400E+02, -.21134200E+02, 0.27436300E+02, 0.22927300E+02, -.64782600E+02, -.69516100E+01, -.19258800E+02, 0.36168800E+02, -.17089600E+03, -.68523000E+02, 0.26513700E+02, 0.32651700E+02, 0.29458200E+02, -.30796300E+02, 0.13426100E+03, 0.45323400E+02, 0.26110000E+00, 0.82476000E+01, -.11139700E+01, -.16307800E+01, -.77859700E+00, -.12433900E+01, 0.29671900E+01, -.30384700E+00, -.34518100E+03, 0.24821100E+02, 0.62411700E+02, 0.66117500E+02, -.15282100E+03, -.93738800E+02, -.99181000E+02, -.31464500E+01, -.98014200E-01, -.33918400E+01, 0.62465100E+00, 0.79255900E+00, 0.21200800E-01, 0.81999000E+00, -.93685700E+00, 0.13334300E+00, 0.96544900E-01, 0.74317100E+01, -.10864600E+01, -.15463600E+01, -.36427600E+00, -.11015600E+01, 0.29592300E+01, -.27780300E+00, 0.19639000E+00, 0.51511800E+00, -.21610100E+02, 0.14157800E+01, 0.37100400E+00, -.34904400E+00, -.14528100E+01, -.28787700E+00, 0.17748000E+01, 0.27483300E+00, -.60510200E+00, 0.27283300E+02, 0.52410700E+02, -.50906500E+02, 0.25886700E+01, 0.10493900E+03, -.54062400E+00, -.26882400E+02, 0.51554100E-01, 0.20684200E+00, -.57737700E+01, 0.42695500E+02, 0.11918100E+01, 0.26053800E+02, -.44518300E+00, 0.32876600E+00 }, { 0.12226300E+01, 0.27140200E+00, 0.73006500E-01, 0.12565300E-02, -.35262400E+00, -.22364600E+01, -.23503700E+01, -.48233000E+00, -.41438200E+00, -.76508400E+00, 0.11329900E+00, 0.42254500E+00, -.33874400E+00, 0.81181800E+00, -.11163900E+01, -.16039800E+01, -.18676500E-01, 0.14834800E+01, 0.37400300E+00, 0.28142900E+00, -.44233900E+00, 0.19113600E+00, 0.19711800E+01, -.22781500E+01, -.13130500E+00, -.34470300E+00, 0.26365700E+01, 0.92757300E+00, 0.89170800E+00, 0.24464500E+00, 0.24241600E+01, -.15265100E+00, -.61986700E-01, -.87746500E-01, 0.28414200E+00, -.31314800E-01, 0.87333200E-01, 0.47129600E+00, -.19426600E+00, -.66841200E-01, 0.34274700E+00, 0.63342000E+00, -.40519700E+01, 0.70802000E+00, -.23087900E+00, -.76390100E+00, 0.74605400E-01, -.43668100E+00, -.17783300E-01, 0.31232500E-01, 0.68804800E-01, -.28271400E-01, -.10705700E+00, -.27310800E-01, 0.20518800E+01, 0.44922800E-01, 0.11087600E-01, -.42057400E+00, 0.20480200E+00, -.30481400E+00, -.11474800E+00, -.13619600E+00, 0.19762600E+00, 0.32240600E+00, -.16487400E+00, -.66630700E-01, 0.21204300E+00, -.15157500E+00, -.41266800E+00, 0.15493400E-01, 0.30721600E+00, -.38811100E+00, -.12917500E+00, 0.23675800E+00, -.18557900E+00, -.78903700E-01, 0.50391800E+00, -.41215200E+00, -.80592600E+00, -.20494600E+00, -.15399200E+00, 0.16373700E+00, -.42986400E+00, 0.11877800E+00, -.14057800E+00, 0.27624200E+02, 0.14608500E+02, 0.13949200E+02, 0.96470700E+02, -.11699400E+03, 0.27047800E+02, 0.34542300E+01, -.10503800E+03, 0.45428000E+02, 0.46358700E+02, 0.35530700E+02, 0.10982600E+03, -.45405100E+02, -.70642600E+02, -.53894800E+02, 0.73729500E+02, 0.28547300E+02, 0.45851100E+02, -.37679600E+02, -.24046100E+03, 0.20401500E+03, 0.17223800E+02, 0.23149300E+02, 0.20458400E+02, -.29936700E+02, -.13461100E+02, 0.17368300E+02, -.51180600E+03, 0.32154300E+02, 0.15438200E+03, 0.16726000E+03, 0.23438800E+02, -.12045000E+03, -.98783600E+00, 0.18260100E+03, 0.40802400E+02, -.71873100E+02, 0.77427500E+01, 0.48812800E+01, -.33003200E+02, 0.28000900E+02, 0.66189100E+02, 0.20210000E+02, 0.29489800E+03, -.33245200E+02, 0.10965300E+03, 0.81051000E+02, -.20011000E+03, 0.12302800E+03, -.81769900E+02, 0.11579600E+03, 0.29721000E+00, -.21519900E-01, 0.31843600E+00, -.81658300E-02, -.20936800E+00, 0.20359300E+00, -.14597200E-02, 0.22044200E+00, 0.29970800E+00, -.22132000E-01, 0.27122700E+00, -.43860200E-01, -.19525300E+00, 0.18169700E+00, 0.53304900E-02, 0.17277400E+00, -.53310300E+02, 0.75776700E+02, 0.20409000E+02, 0.28592400E+02, 0.13873100E+01, 0.72530900E+02, 0.21725600E+02, 0.32612900E+02, -.70657000E+02, -.40687100E+01, 0.17416100E+01, 0.92536100E+01, 0.18926600E+02, 0.15296400E+02, 0.82611500E+02, 0.17300100E+02, -.12218900E+00, 0.18667500E+01, -.41752600E+00, -.12827900E+01, 0.44843000E+00, 0.79841100E-02, 0.13837000E+01, -.60943200E+00, -.41094600E+03, 0.21250200E+03, 0.43202800E+02, 0.72723300E+02, -.45445500E+02, -.22345500E+03, 0.16508600E+02, 0.39381400E+02, -.22972000E+00, -.46933300E+00, -.13746700E+00, 0.32807100E+00, 0.13436500E+00, -.87947800E-01, -.40956400E+00, -.37209800E-02, -.18268100E+00, 0.17674000E+01, -.31552200E+00, -.10540100E+01, 0.38159000E+00, -.82064800E-01, 0.13149400E+01, -.45923400E+00, 0.11748000E+01, -.16460700E+00, -.20109400E+01, 0.65007000E+01, -.17308500E+00, 0.19574500E+01, -.35641400E+00, 0.17444200E+00, 0.30935900E+00, -.19361300E+00, -.15485400E+01, 0.23467700E+02, 0.21625200E+02, -.18205500E+02, 0.73396300E+01, 0.56664200E+02, 0.10076200E+02, -.46639200E+02, -.15124400E+00, -.16148100E+00, 0.18976200E+02, 0.15721100E+02, -.51186300E-01, 0.26861100E+02, 0.16858800E+00, -.14926200E+00 }, { -.23964600E+01, -.65846400E+00, 0.38986900E+00, 0.79892500E+00, -.29298200E-01, 0.30653100E+01, 0.51507700E+01, -.32757700E+00, 0.57900900E+00, -.52512300E+00, -.10919900E+00, 0.12665400E+01, -.33104500E+00, 0.73805900E+01, -.34608500E+01, -.53360000E+01, -.45278300E+01, -.11292100E+01, -.16792600E+01, 0.17685100E+01, -.81853900E+00, -.38212900E+00, -.13848700E+01, 0.18620000E+00, -.24205600E+00, 0.38491800E+00, -.21020800E+01, -.83968300E+00, -.30537900E+01, -.21643400E+00, -.48575800E+01, 0.46378600E+00, 0.63148700E+00, -.27097000E+00, 0.38430900E+01, 0.66791600E+00, 0.13780100E+00, 0.52899000E+00, 0.94794000E+00, -.24853000E+00, -.43164600E+00, 0.22018800E+00, 0.13058700E+01, -.52728500E+00, -.58732700E-01, -.19673500E+00, -.60032800E-02, 0.78254100E+00, 0.98425600E-01, 0.70770100E-01, 0.46460800E+00, 0.86715900E-01, -.88004000E+00, -.74233500E-01, 0.30007100E+01, -.44329200E+00, -.41834700E+00, 0.29250400E+01, 0.17961400E+00, -.11824800E+01, 0.83972700E+00, -.35682800E+00, -.12070800E+01, -.17916300E+01, 0.14398100E+01, 0.29449000E-01, -.20913000E+00, 0.11853100E+01, -.12191500E-01, -.37256700E-02, 0.71583700E+01, -.41436100E+00, -.29798900E+00, 0.25190900E+00, 0.18504400E+00, 0.26628200E+00, 0.30550400E+00, -.58179700E+00, -.18476700E+01, 0.24861600E+01, 0.24274000E+00, 0.49272900E+00, 0.11641100E+01, -.37219700E+00, -.19052600E-01, -.12991800E+01, 0.99352200E+02, -.24065100E+02, 0.19836100E+03, 0.32246700E+03, 0.12295500E+03, 0.10585300E+03, -.18654400E+03, -.75576300E+02, -.10604000E+03, 0.12830100E+03, -.25861900E+03, 0.85239900E+02, 0.68363600E+02, 0.93487700E+02, -.57438800E+02, -.12517300E+03, 0.53617300E+02, 0.63170000E+02, 0.14734200E+03, 0.31707400E+02, -.13119100E+03, -.13421900E+03, 0.13317000E+03, 0.87883100E+02, 0.14204900E+03, -.13096000E+03, -.24220300E+03, -.39026500E+03, -.94545500E+02, -.50142100E+02, 0.14765800E+03, -.49893100E+01, 0.36538500E+02, -.74015200E+02, 0.61534000E+02, 0.10267300E+03, 0.30282000E+02, 0.11102500E+02, 0.23682900E+01, -.15685400E+01, 0.50526600E+02, -.25583300E+01, 0.11827200E+03, 0.70771600E+02, 0.74046500E+02, 0.16453400E+03, -.17596000E+03, -.87229500E+02, -.15187200E+03, 0.14619800E+03, -.60725300E+00, 0.25665900E+00, 0.96172400E-01, 0.43012200E+00, -.11354300E+00, -.22963700E-01, 0.47113700E+00, 0.39674900E+00, -.64254900E+00, 0.26082100E+00, 0.12066400E+00, 0.42139500E+00, -.11067000E+00, -.63436800E-01, 0.41659000E+00, 0.38493700E+00, -.11509600E+03, 0.78678600E+02, 0.47255300E+02, 0.65577700E+02, -.56088500E+02, 0.15505000E+02, -.69699400E+01, 0.60417500E+02, -.62471800E+02, -.30310300E+02, 0.40778200E+01, 0.12514800E+02, 0.16233600E+02, -.78459900E+01, 0.74362200E+02, 0.18970400E+02, 0.40048500E+00, 0.29158400E+01, 0.17616700E+00, 0.54723700E-01, -.15627000E+00, 0.98632400E+00, 0.23296800E+01, -.10248500E+00, -.61836400E+02, 0.30889100E+02, 0.19299000E+02, -.26597000E+00, 0.26447700E+02, -.86040500E+02, -.81703600E+02, 0.64117100E+02, 0.67984400E+00, -.57384800E+00, -.11821700E+00, -.36558800E+00, 0.28146800E-01, 0.15688400E-01, -.10034800E+01, -.20874600E+00, 0.83746700E+00, 0.21363600E+01, 0.57409700E-02, -.73761900E-01, -.84796600E-01, 0.10372100E+01, 0.22482000E+01, -.26126700E+00, -.24010700E+01, -.22837600E+00, -.36926100E+02, -.13173600E+01, -.22070500E+00, -.22435400E+01, -.46537000E+00, 0.18713000E+00, 0.52479600E+00, -.25242400E+00, -.52158200E+01, 0.17121200E+02, 0.52570900E+02, -.21113300E+02, 0.16375500E+02, 0.79895900E+01, 0.10571600E+02, -.37558000E+02, -.24891600E+00, -.22118600E+00, 0.29940100E+01, 0.25568400E+02, 0.11042000E+00, -.46913600E+01, 0.22781000E+00, -.12429900E+00 }, { -.88738300E+00, -.35769300E+00, 0.16516800E+01, -.21984000E+00, -.22632000E+00, 0.29522400E+01, 0.45783400E+01, -.47356200E+00, 0.56652000E+00, -.92360600E+00, 0.20656800E-01, 0.88585400E+00, -.14210100E+01, 0.75563200E+01, -.15267600E+01, -.41282300E+01, -.24829400E+01, -.18666900E+01, 0.25565000E+00, 0.83432000E+00, -.89710000E+00, -.16802700E-01, 0.10082300E+01, 0.56789200E+00, -.41896700E-01, 0.30390500E+00, 0.26451700E+00, -.24821700E-01, 0.22085800E+01, 0.25593800E+00, 0.56626100E+01, -.21474900E+00, -.86794400E+00, -.48027800E+00, -.11566100E+01, 0.38913700E+00, 0.13834000E+00, 0.84071400E-01, 0.55253900E+00, -.52036900E-01, 0.22462500E+00, -.15033800E+00, -.81567000E-01, 0.17372400E+00, 0.86870200E-01, -.12651000E+01, 0.26498700E+00, 0.13999500E+01, 0.27870500E-01, -.53733100E-01, 0.97977700E-01, 0.12953900E-01, -.43641700E+00, 0.23335200E-01, 0.24889500E+01, -.22308300E+00, -.18880900E-01, 0.14773900E+00, -.89204200E-01, -.44662600E+00, -.15906500E+00, -.82031800E-01, 0.20889800E+00, 0.43455000E+00, -.15605300E+00, -.48497500E-01, 0.11830400E+00, -.13499900E+00, -.31105900E+00, 0.54641200E-01, -.25187300E+00, -.21277500E+00, -.69395100E-01, 0.27257800E+00, -.23969600E+00, 0.67166200E-01, -.24574800E+00, 0.28093200E-01, 0.47845100E+00, -.25545100E+01, -.54068700E+00, 0.28974400E-01, 0.57681100E+00, 0.21935800E+00, -.34103600E+00, -.68015200E+00, -.52184400E-03, 0.28890100E+02, 0.24831500E+03, -.99178400E+02, -.51990400E+02, -.92897600E+02, -.60023900E+02, 0.75206700E+02, 0.27459000E+03, -.88754600E+02, 0.17177000E+03, -.11639500E+03, -.96602400E+02, -.80490100E+02, 0.10049900E+03, 0.64225500E+02, -.29661400E+02, -.55281300E+02, -.21997100E+03, 0.15157800E+03, 0.43624500E+02, 0.32397300E+02, 0.13124700E+02, -.88112100E+02, -.31847900E+02, 0.17693600E+02, 0.62068400E+02, -.11757000E+03, 0.21667800E+02, 0.16755300E+02, 0.94789900E+02, 0.74807000E+02, 0.17377700E+02, 0.81352400E+02, 0.28245600E+02, -.22009600E+02, -.11985900E+02, -.93453400E+01, 0.26323100E+02, -.18969300E+02, -.20134700E+02, 0.20694400E+02, 0.45498200E+03, -.18091900E+03, 0.54965700E+02, 0.10862300E+02, -.17196800E+03, 0.19830600E+03, 0.13550100E+03, 0.34683800E+02, 0.12791600E+01, -.95101200E+00, 0.29824400E+00, 0.43954000E-01, -.40810900E+00, 0.48149500E+00, 0.36279200E+00, 0.11968400E+00, 0.12617800E+01, -.94336400E+00, 0.23759200E+00, -.99859000E-02, -.38106900E+00, 0.46810000E+00, 0.41917700E+00, 0.53326900E-01, -.27114600E+03, 0.10553700E+03, 0.49825100E+02, 0.67843900E+02, 0.54820100E+02, -.13644700E+02, 0.26726800E+02, 0.82106200E+02, -.22598200E+03, 0.41752400E+02, 0.30988400E+02, 0.40655800E+02, 0.23985400E+02, -.75841100E+02, -.85216100E-01, 0.38174800E+02, -.13641600E+01, -.65359800E+00, -.25210500E+00, -.60959200E+00, 0.48338200E+00, -.66437800E-01, 0.19938300E+01, -.53352100E+00, -.17428600E+03, 0.99568800E+02, -.78010800E+02, -.90415100E+02, 0.41005700E+02, -.10052900E+03, 0.79225200E+02, -.19105900E+03, -.87739500E+00, 0.11196700E+01, -.94363000E-01, 0.22504800E+00, 0.22968100E+00, -.24772700E+00, -.81905800E+00, 0.11989300E+00, -.15248200E+01, -.53835700E+00, -.19893700E+00, -.48499200E+00, 0.53245600E+00, -.33459500E+00, 0.15159600E+01, -.33275300E+00, 0.52443100E+01, -.15232300E+00, -.75903600E+01, 0.21642700E+02, -.26173500E-01, 0.28542100E+01, 0.25740400E+00, -.51455200E-01, -.57506800E+00, -.51028800E-01, -.33117100E+02, 0.33170900E+02, 0.68826700E+02, -.41038200E+00, 0.10805000E+02, 0.12872200E+03, -.32429100E+00, -.78314700E+02, 0.35900900E-01, -.10699900E+00, 0.10225700E+02, -.16955100E+02, -.18070500E+00, 0.56612400E+02, 0.88613200E-01, 0.12427600E+00 }, { 0.19939500E+01, 0.38587400E+00, -.24695400E+01, -.15179300E+01, -.58590100E-01, -.15252000E+01, -.44217700E+01, 0.69933400E+00, -.86423100E+00, 0.10878600E+01, 0.76594100E-01, -.36610900E+00, 0.16811400E+01, -.11739700E+02, 0.10287100E+01, 0.89881400E+01, 0.45301400E+01, 0.21133400E+01, -.29817200E+01, -.17253800E+01, 0.27196300E+01, 0.30886000E+00, -.21261700E+01, -.42219000E+00, -.72364700E-01, -.77222200E+00, 0.11569700E+01, 0.63731900E+00, -.40900400E+01, 0.12888600E-01, -.82694000E+01, 0.28696800E+00, 0.18981700E+01, 0.35149500E+00, -.27847500E+01, -.88633100E+00, -.35791600E+00, -.24129600E+00, -.10207400E+01, 0.14315300E+00, -.63095600E+00, 0.24585000E+00, 0.26612400E+01, -.12516800E+01, -.33436600E+00, 0.28150600E+01, -.11227200E+00, -.46362800E+01, -.51813500E-01, 0.80666500E-01, -.80024800E+00, -.59364900E+00, 0.12773600E+01, 0.58893500E+00, -.81451900E+01, -.41106000E+00, 0.55617700E+00, 0.10990700E+01, 0.19595200E+00, -.12213800E+01, -.21054100E+01, 0.18335600E+00, 0.13297900E+00, -.51554900E-02, -.64911800E+00, 0.28826600E+00, -.55280400E-01, -.69010600E+00, 0.92228000E+00, -.35910300E+00, -.10446100E+01, 0.20279000E+01, -.78737300E+00, -.55773500E+00, 0.12935300E+01, 0.10642200E+00, 0.18677500E+01, -.39670300E+00, -.15310500E+01, -.87886600E+00, -.70811800E+00, 0.34551500E+00, -.18256100E+00, -.59519300E-01, -.92200200E-02, -.31669200E+00, 0.65118200E+00, 0.52779000E+00, -.63118500E+03, 0.15327000E+03, 0.15868000E+03, 0.17866300E+03, 0.69220800E+02, -.15807200E+03, -.54170400E+03, 0.16691900E+03, -.46418800E+03, 0.30738100E+03, 0.30181900E+03, 0.23828600E+03, -.28413500E+03, -.18954600E+03, 0.66702500E+02, 0.22841400E+03, -.29210100E+03, -.89654200E+02, -.11432500E+02, 0.54918600E+02, -.76044900E+01, -.78773500E+02, 0.61771500E+02, 0.53957900E+02, -.60755100E+01, 0.28798000E+03, 0.13145900E+02, 0.54312700E+01, -.18820800E+03, -.97081700E+02, 0.13055900E+03, -.43836900E+02, -.30048000E+02, -.59832100E+02, 0.82692500E+02, 0.47899100E+01, -.80570100E+02, 0.54482200E+02, 0.71908600E+02, 0.16532200E+01, -.10574900E+04, 0.20234300E+03, 0.12534200E+03, 0.11832300E+03, 0.21314500E+03, -.47200800E+03, -.35450400E+03, 0.14893000E+03, -.14236300E+01, 0.15250300E+01, 0.19247700E+00, -.54662500E+00, 0.59618700E+00, -.13498800E+01, -.15873100E+01, -.31707100E+00, -.14488800E+01, 0.15308800E+01, 0.25635200E+00, -.47422000E+00, 0.58105000E+00, -.13316100E+01, -.16843200E+01, -.22028500E+00, 0.70711500E+03, -.24416700E+03, -.60351400E+02, -.15428100E+03, -.14808200E+03, 0.54781800E+02, -.11697400E+03, -.16069100E+03, 0.63856700E+03, -.20052400E+03, -.87741600E+02, -.11783400E+03, -.70061200E+02, 0.22588300E+03, 0.34081900E+02, -.10122400E+03, 0.26288300E+01, -.10317600E-01, 0.23799300E+01, -.11734000E+01, -.66427800E+00, -.34953800E+01, -.67797500E+01, 0.20332700E+00, -.38069800E+03, 0.19923500E+03, 0.18194400E+03, 0.31126800E+03, -.11310200E+03, -.11188000E+03, -.35128700E+03, 0.34513500E+03, 0.12941000E+01, -.17194900E+01, -.95974000E+00, 0.50451800E+00, -.40047100E+00, 0.17767700E+01, 0.29064200E+01, -.18520600E+00, 0.24698000E+01, 0.59169900E-01, 0.21247900E+01, -.10897200E+01, -.73346100E+00, -.26082600E+01, -.51989400E+01, 0.14866500E+00, -.57402900E+01, 0.21160400E+00, 0.33383000E+02, -.23107200E+02, -.14065400E-02, -.12940900E+00, 0.18874200E+00, 0.13199700E+00, 0.19202600E+00, 0.61050300E-01, 0.87105400E+02, -.19711300E+02, -.14008300E+03, 0.18437200E+02, -.35572900E+02, -.18953900E+03, -.20215100E+01, 0.14536500E+03, -.36422700E-01, 0.18251900E+00, -.26070300E+02, 0.23281200E+02, 0.27663400E+00, -.40553500E+02, -.10206000E+00, -.19545500E+00 }, { -.23445900E+00, -.55555100E-01, -.59914100E-01, 0.89929300E-01, 0.21329600E+00, 0.26562500E+00, 0.98740000E-01, 0.67119400E-01, -.25702300E-01, 0.50292300E-01, 0.15103900E-01, 0.76287500E-01, 0.12988200E+00, -.17699800E+00, -.34410900E-02, 0.32135100E+00, -.18345900E-01, 0.10621700E+00, -.33123900E-01, -.94001900E-01, 0.12799300E+00, -.39306300E-01, -.17823700E+00, 0.11078500E+00, -.19411700E-01, 0.47473400E-01, -.10201400E+00, -.43034900E-01, 0.69607000E-01, 0.26014600E-01, 0.32835500E+00, -.43506400E-01, -.19633100E-01, -.19929800E-01, 0.10686500E+00, -.12631700E-01, 0.34618800E-02, 0.13993300E-01, 0.77175800E-01, -.48886700E-02, 0.26164500E-01, -.18373400E-01, 0.39139900E-01, -.17404900E-01, 0.20399500E-01, -.13579100E+00, 0.16829300E-01, 0.14688900E+00, 0.39094700E-02, -.56129000E-02, 0.27823400E-01, 0.41233500E-02, 0.70587000E+00, -.56391900E-02, 0.69024400E-01, -.62270400E-01, -.19655800E-01, -.88596300E-01, -.91726000E-01, -.19357500E+00, -.32290400E+00, -.14775800E-01, 0.63883500E-01, -.17312900E+00, -.15540900E+00, 0.19788600E-01, -.22419200E-02, 0.12653400E+00, 0.75044600E+00, 0.11129300E-02, -.51596400E+00, 0.59710100E-01, 0.35806400E-01, -.88487700E-02, 0.13345400E+00, 0.21388600E-02, -.55817200E-02, 0.25359500E-01, -.15458600E-01, -.20924200E+00, -.27841200E+00, 0.17147100E-01, -.91122800E-01, -.24384800E-01, 0.70188300E-01, 0.17877900E-01, -.67902300E-01, -.79001800E-01, -.36585400E-01, 0.35562100E+02, -.69110100E+01, -.61076800E+01, 0.14151300E+02, -.14555000E+02, -.10796900E+02, -.12281500E+02, -.10227000E+03, 0.45636600E+02, 0.61488000E+02, 0.52743600E+02, -.50025700E+02, -.35635800E+02, -.11673400E+02, 0.49170100E+02, 0.12211600E+02, -.22919400E+01, -.20039100E+02, -.12623800E+02, 0.10821100E+02, -.14859800E+01, 0.19150700E+02, -.15966100E+02, 0.85502400E+02, -.64051900E+02, -.23366900E+02, -.31677900E+02, 0.14091500E+02, 0.43953900E+02, 0.28502800E+02, -.27736900E+02, 0.26232700E+02, 0.60674300E+01, 0.18008000E+01, -.15746500E+02, 0.12973700E+02, 0.16156700E+02, -.13999300E+01, -.16745000E+02, 0.83644700E+01, 0.48461000E+01, -.69761700E+01, -.15406500E+01, 0.14505000E+02, -.13775200E+02, -.16992300E+02, -.45544800E+01, 0.36073100E-01, -.41698000E-02, 0.12465000E+00, 0.59904700E-03, 0.72094600E-01, 0.26566000E-01, -.98205400E-01, 0.53396300E-02, 0.38393300E-01, -.46593500E-02, 0.12358500E+00, -.42118000E-02, 0.74340300E-01, 0.26137300E-01, -.98833400E-01, -.10013100E-02, 0.23584900E+02, -.24765600E+01, 0.48037800E+01, -.11846500E+01, -.11482400E+02, 0.39015100E+01, -.89811800E+01, 0.87672200E-01, 0.30477700E+02, -.70245900E+00, -.18753800E+01, -.61100800E+01, -.25829400E+01, 0.67924600E+01, -.96436500E+01, -.59770500E+01, -.89329500E-01, 0.27238200E+00, 0.64537800E+00, -.74383400E-01, 0.42864100E+00, 0.60986600E-02, -.57900100E+00, -.15063300E-01, 0.31975400E+02, 0.83302800E+01, -.24909000E+02, -.18456700E+02, 0.18258800E+02, 0.10891800E+01, -.10100400E+02, -.21723900E+02, -.35044700E-01, -.48337400E-01, -.26492200E+00, 0.36060900E-01, -.17811900E+00, -.29843800E-01, 0.23502200E+00, 0.23742100E-01, -.70373700E-01, 0.23882400E+00, 0.59421600E+00, -.57176300E-01, 0.37725600E+00, 0.84548500E-02, -.53053100E+00, 0.45807700E-02, 0.14109300E+00, -.15325700E-01, 0.38029600E+00, -.67471300E+00, -.23824400E-01, 0.64975100E+00, 0.30294700E+00, 0.33673500E-01, -.34235000E+00, -.21172700E-01, 0.11031500E+01, 0.61280500E+00, -.20083100E+01, 0.86127700E+01, -.40008200E+01, 0.32527900E+01, -.31864400E+01, 0.77389600E+01, -.12448000E-01, -.11670900E-01, -.13951400E+01, -.24776200E+01, -.12631700E-01, 0.34644000E+01, 0.20029800E-01, -.35892700E-01 }, { -.49875300E+00, -.15622000E+00, 0.63924900E+00, 0.32306500E+00, 0.43959500E+00, 0.18396900E+01, 0.12224600E+01, -.27335300E+00, 0.18162100E+00, -.13354100E+00, -.96296000E-01, -.51443700E-01, -.15213900E+00, 0.13101500E+01, -.31027400E+00, -.10496300E+01, -.93389100E-01, -.14003000E+01, -.82474700E+00, 0.19009500E+00, 0.61768600E+00, -.46499900E-01, -.46208400E+00, 0.14159400E+00, -.60144000E-01, 0.17119000E-01, -.24517100E+00, -.26833200E-01, 0.74345100E+00, 0.10662500E+00, 0.16931000E+01, -.16022900E+00, -.10505700E+00, -.14789000E+00, -.19845600E+01, 0.13561100E+00, 0.16850100E+00, 0.33345200E+00, 0.43578800E+00, 0.15075300E-02, 0.22618900E+00, -.10092000E+00, -.71364300E+00, 0.18203100E+00, 0.60143900E-01, -.78477900E+00, 0.68653300E-01, 0.57117800E+00, 0.12392000E-01, -.17322200E-01, 0.71178300E-01, 0.10430500E+00, -.19459500E+00, -.33814900E-01, 0.34321300E+01, -.29962000E-01, -.10342000E+00, 0.38623800E+00, 0.25743800E+00, -.27830900E+00, 0.49003700E+00, 0.70439000E-02, -.12496600E+00, -.30217400E+00, 0.14662000E+00, -.62679300E-02, -.10913400E-02, 0.20229400E+00, -.58610300E-03, 0.39781400E-01, -.61196200E-01, -.46646600E-01, -.12252600E+00, 0.15137600E+00, -.10931700E+00, -.28669900E-01, 0.11228500E-01, -.89687300E-01, -.10683400E+00, 0.40831000E-01, -.61562200E+00, 0.15991200E+00, 0.45842000E+00, -.10484200E+00, 0.18105600E-01, 0.38997100E-01, 0.56861700E-02, -.19918800E+00, -.15930300E+00, -.27045600E+01, -.49346700E+02, -.40444600E+02, 0.82267100E+02, -.20937700E+02, -.20244600E+02, -.77957900E+02, -.32054600E+03, 0.15978100E+03, 0.22690800E+03, 0.18998000E+03, -.19003900E+03, -.11019800E+03, -.57377900E+02, 0.18093600E+03, 0.35027700E+02, -.79731300E+02, -.54627100E+02, -.25161100E+02, 0.18833800E+02, -.35559600E+02, 0.35845000E+02, -.36654800E+02, 0.51616100E+03, -.21360500E+03, -.10780600E+03, -.15714000E+03, 0.29222200E+02, 0.20280000E+03, 0.10628400E+03, -.14278600E+03, 0.88324400E+02, -.28470400E+02, 0.21921500E+01, -.51806200E+02, 0.47852300E+02, 0.52727400E+02, -.22088100E+02, -.56092800E+02, -.11066400E+02, -.63906900E+02, -.36733100E+02, -.30100900E+02, 0.93755000E+02, -.44059100E+02, 0.10026300E+02, -.50962100E+02, 0.25706200E+00, -.21982200E+00, 0.41078100E+00, -.21949500E-01, 0.23234200E+00, 0.11282000E+00, -.31399900E+00, -.91091400E-01, 0.25996800E+00, -.22300000E+00, 0.41615100E+00, -.30234700E-01, 0.23458800E+00, 0.12055300E+00, -.29844800E+00, -.10002700E+00, 0.12019600E+03, -.36707600E+02, 0.10365500E+02, -.19129300E+02, -.38609100E+02, -.60713000E+01, -.40542800E+02, -.17265300E+02, 0.11390000E+03, 0.11282600E+02, -.28877700E+01, -.19530200E+02, -.18718100E+02, 0.11413100E+02, -.66764200E+02, -.21065100E+02, -.13992400E+00, -.45132900E+00, 0.25425500E+01, -.48688200E-02, 0.11784000E+01, -.92819900E-02, -.25490600E+01, -.38054700E-01, 0.17503000E+03, 0.29485000E+02, -.11434000E+03, -.93083700E+02, 0.90293900E+02, 0.55162400E+02, -.30433900E+02, -.10237900E+03, -.18979600E+00, 0.31629000E+00, -.10441300E+01, 0.28333400E-01, -.48672800E+00, -.13202500E+00, 0.87012300E+00, 0.95160800E-01, -.27427500E+00, -.32727800E+00, 0.23933900E+01, 0.65840500E-01, 0.10179800E+01, -.49204200E-01, -.23908400E+01, 0.75501500E-01, 0.10593000E+01, -.10513000E-03, 0.65689000E+01, -.52445800E+01, 0.49376100E-02, 0.24379400E+01, 0.13419700E+01, 0.74941700E-02, -.16085800E+01, 0.19409600E-01, 0.77992100E+01, 0.10530100E+01, -.20225900E+02, 0.38655700E+02, -.16060900E+02, 0.10139400E+01, -.10128200E+02, 0.38287200E+02, 0.49616300E-01, 0.23311700E-01, -.98592000E+01, -.14497100E+02, -.39487300E-01, 0.11957900E+02, -.14105900E-02, -.40745200E-02 }, { 0.25111700E+01, 0.35012600E+01, -.18277300E+01, 0.67632700E+00, -.10146500E+01, -.23434400E+01, 0.12675000E+01, 0.15207000E+01, -.18439200E+01, 0.25235800E+00, 0.58450700E+00, 0.55143900E+00, 0.96859100E+00, -.39431400E+01, 0.22422700E+01, 0.61088400E+01, 0.41125900E+01, 0.47715800E+01, 0.11480400E+01, -.99423800E+00, -.15235900E+01, 0.85881800E+00, -.10107500E+01, 0.44258100E+00, 0.28996400E+00, 0.16799000E+00, 0.14553700E+01, 0.57134200E+00, -.50272300E+01, 0.11515100E+01, -.29381300E+01, 0.79974800E+00, 0.97806800E+00, -.42523300E+00, -.62123000E+01, -.74836500E+00, -.42954300E+00, 0.31436900E+01, -.40748200E+01, 0.58827400E+00, -.36603700E+00, 0.22049000E+01, -.38787600E+01, 0.54296200E+00, -.86616700E+00, 0.17448700E+01, 0.16006200E+00, -.55135600E+01, -.10229300E+00, 0.21817900E+00, -.48171700E+00, -.24775800E+00, 0.11266800E+01, 0.17328300E+00, 0.30949300E+01, 0.25296800E+00, 0.30048300E+00, -.59690700E+00, 0.10552800E+01, -.40719200E-01, 0.50102900E+00, -.70962700E-01, -.23305100E+00, 0.56901600E+00, 0.39031200E+00, -.22646700E-01, -.83343000E-01, -.66485400E+00, -.22932900E+00, -.18481400E+00, -.58122400E+00, 0.25061500E+00, -.36724300E-02, -.13239300E+00, -.62438900E+00, -.53280500E+00, 0.29542100E+00, -.76181800E+00, -.18552800E-02, -.40960800E+00, -.24275700E+00, -.28909700E+00, -.25969500E+01, 0.34925300E+00, 0.75234000E+00, 0.26356700E+01, -.77623400E-01, -.23818900E+01, -.80140000E+00, -.39168900E+01, 0.14565900E+01, -.12347900E+03, 0.21984800E+03, 0.40219700E+02, -.87654400E+02, -.11798600E+03, 0.16065100E+02, -.85694900E+02, 0.85479500E+02, 0.29120300E+02, -.92789300E+02, 0.42265800E+02, -.29857500E+02, 0.26523900E+02, -.22996900E+03, 0.23100100E+03, 0.78711300E+02, 0.60827500E+02, 0.87271800E+01, -.60642300E+02, 0.17418700E+02, 0.68596400E+02, 0.61304200E+03, 0.39973400E+03, -.18879800E+03, -.11511100E+03, -.14581800E+03, 0.25719600E+03, 0.10480500E+03, -.16536400E+03, -.12879900E+02, -.11888600E+03, 0.44875100E+02, -.39438100E+02, 0.50860900E+02, 0.63187200E+01, -.11997000E+03, -.40307700E+02, 0.30554600E+03, -.31535600E+03, -.10567800E+03, -.22999100E+03, 0.20902600E+03, 0.21572700E+03, 0.53105200E+02, -.23122000E+03, -.48165700E-01, 0.81524900E-01, 0.10076600E+00, -.50040200E+00, 0.30191900E+00, 0.55597200E+00, -.53307000E-01, -.43945100E+00, -.74880100E-01, 0.75059200E-01, 0.17468600E+00, -.42055100E+00, 0.29329900E+00, 0.52438700E+00, -.10703200E+00, -.35516900E+00, -.32371500E+02, 0.91863300E+02, 0.49239400E+02, 0.55158700E+02, -.17841000E+02, -.79539000E+02, -.95619600E+02, 0.86814200E+02, 0.24131500E+03, -.39490100E+02, -.35865200E+02, -.49381200E+02, -.50058400E+02, 0.61093900E+02, -.12561400E+03, -.57523100E+02, -.66826400E+00, -.33393700E+01, 0.22550400E+01, -.36351200E+00, 0.17466900E+00, -.14633800E+00, -.38616800E+01, 0.33394000E+00, 0.32383600E+03, 0.37361900E+02, 0.37637900E+02, 0.96416800E+01, -.10449200E+03, 0.12934500E+03, 0.29138600E+02, 0.10284800E+02, 0.82394900E-01, 0.89991000E+00, -.95104600E+00, 0.20580600E+00, -.14560900E+00, -.55542200E+00, 0.13483400E+01, -.23110100E-01, -.31852200E+00, -.34688900E+01, 0.20332000E+01, -.23593500E+00, -.84658900E-01, -.48122100E-01, -.38016700E+01, 0.39517000E+00, -.22266200E+00, 0.46213500E+00, 0.16523400E+02, 0.33793200E+00, 0.44128600E+00, 0.30645200E+01, 0.12476400E+01, -.41671300E+00, -.13476300E+01, 0.49329000E+00, -.26731400E+02, -.13659300E+02, -.87153100E+02, 0.49235400E+02, -.79444800E+01, -.11581500E+03, -.30455700E+02, 0.47112100E+02, 0.43721000E+00, 0.46293400E+00, -.18642200E+02, -.42677000E+02, -.57142200E+00, -.14666400E+02, -.44965200E+00, 0.32632600E+00 }, { -.26394300E+01, -.71782600E+00, 0.22977800E+01, 0.12249000E+01, 0.10372200E+01, 0.12817600E+01, -.10175700E+02, -.31935700E+01, 0.31337400E+01, 0.88048700E+00, -.98465900E+00, 0.25393600E+01, 0.12946000E+00, 0.94965700E+01, -.53940900E+01, -.58417200E+01, -.47559900E+01, -.25073600E+01, -.62422200E+00, 0.11087700E+01, -.39599400E+00, -.30732900E+00, 0.92671700E+00, 0.90431300E+00, 0.58413500E+00, 0.14774900E+00, -.24220500E+01, -.80353000E+00, -.10516000E+00, -.33029000E+00, -.18148400E+01, 0.21983700E-01, -.81529800E+00, 0.97597800E+00, 0.79638200E+01, 0.12056900E+01, -.93278200E-01, 0.17743200E+01, 0.10953000E+01, -.14182300E+00, 0.14561800E+01, 0.96879200E+00, 0.30565900E+01, -.11952300E+01, -.43940300E+00, -.32878200E+01, 0.54416600E-01, 0.62812400E+01, 0.16593300E+00, -.27544400E+00, 0.19958500E+00, -.23785100E+00, -.15010400E+01, -.11968300E+00, 0.13269600E+01, -.73046800E+00, -.14892700E+00, 0.96944600E+00, -.19020000E+01, -.16151200E+01, 0.85577900E+00, -.42033300E+00, 0.50701700E+00, 0.18191200E+01, -.58555800E-01, -.16859100E+00, 0.44914300E+00, -.10590800E+01, -.89215400E+00, 0.79689400E-01, 0.28213600E+00, -.71543500E+00, -.22340300E+00, 0.54945800E+00, -.68338600E+00, 0.38469200E+00, 0.10665200E+01, -.11687000E+01, 0.14597100E+01, -.21186500E+01, 0.18579900E+01, 0.39863900E+00, 0.28579100E+01, 0.25031800E+00, -.12382900E+01, 0.18559400E+01, 0.26748400E+00, -.55662300E+00, -.19697000E+00, -.13893500E+02, 0.22709500E+01, 0.23588300E+00, 0.66808100E+02, 0.54375700E+01, 0.14339700E+03, -.39820500E+02, -.40838500E+02, -.10460400E+03, 0.41497400E+02, 0.17082500E+02, -.51370800E+02, 0.13361500E+02, 0.82877300E+01, 0.12984300E+02, -.50861900E+03, 0.11570700E+03, 0.11958600E+03, 0.13609100E+03, -.72084000E+01, -.20825400E+03, -.50028200E+02, 0.12292800E+03, 0.25562400E+03, -.40411500E+02, -.94576200E+02, -.10178600E+03, 0.31986700E+02, 0.12676200E+03, 0.66485900E+01, -.67014800E+02, 0.90217500E+02, 0.82858100E+02, -.28625600E+02, -.50545200E+02, 0.49091400E+02, 0.64401100E+02, 0.33248500E+02, -.52158700E+02, 0.10540300E+03, -.37673500E+02, -.21117500E+02, -.17730700E+02, -.35095600E+02, 0.10320600E+03, 0.12424300E+03, -.28663500E+02, 0.86976000E-01, -.13523900E+01, -.20317500E+00, 0.23085400E+00, 0.65916300E+00, 0.28206700E-01, -.24290400E+00, 0.48778500E-01, 0.76987100E-01, -.13513400E+01, -.15071400E+00, 0.23971400E+00, 0.64810000E+00, 0.19795200E-01, -.23898300E+00, 0.63294600E-01, -.11294100E+03, -.16966000E+01, -.88622200E+01, -.32189200E+01, 0.59549000E+02, 0.20594900E+02, 0.20173800E+02, 0.59425400E+01, 0.28710100E+02, -.26704200E+01, -.25800300E+01, -.30544000E+01, -.11988400E+02, 0.17186000E+02, -.15474100E+02, -.59384200E+01, -.15372600E+01, -.48979100E+01, -.43987600E+00, 0.90118900E+00, 0.37130100E+01, -.34222500E+00, -.10248800E+01, 0.13549600E+00, -.79067500E+02, 0.17073900E+02, 0.51132200E+02, 0.35672800E+02, 0.44930000E+02, -.98422500E+02, -.47109000E+02, 0.59289700E+01, -.72907100E-01, 0.26405600E+01, 0.77826700E-01, -.37745500E+00, -.13076200E+01, -.37346900E-01, 0.50537300E+00, -.79915000E-01, -.78644900E+00, -.46476900E+01, -.43790600E+00, 0.68112900E+00, 0.31686300E+01, -.14380000E+00, -.10060900E+01, 0.46585300E-01, 0.31067900E+00, -.65477700E+00, 0.19536100E+02, -.56453000E+01, -.53537100E+00, -.18764300E+01, 0.12371300E+01, 0.47900300E+00, -.13982200E+01, -.47265600E+00, -.13965700E+02, -.60686700E+01, 0.18369500E+02, 0.17885000E+02, -.97990300E+01, 0.13367200E+02, -.66677900E+01, -.34837400E+02, -.27738500E+00, -.39727900E+00, 0.51303000E+01, -.21367700E+01, -.37153000E+00, 0.49028800E+01, 0.60360300E+00, -.50832600E+00 }, { -.10666600E+01, -.32988200E+00, 0.17681900E+01, 0.68498700E+00, -.17558900E+00, 0.21586800E+01, 0.45273400E+01, -.28302900E+00, 0.58506900E+00, -.89128000E+00, -.58482600E-03, -.11268900E+00, -.16218800E+01, 0.74452200E+01, -.34218500E+00, -.49119400E+01, -.27123800E+01, -.47179100E+00, 0.21735600E+01, 0.77530100E+00, -.11239800E+01, -.26157000E+00, 0.54880800E+00, 0.60291800E+00, 0.79578000E-01, 0.59825300E+00, -.32329000E+00, -.20724000E+00, 0.23748200E+01, 0.18838100E+00, 0.53581100E+01, -.25119300E+00, -.13311200E+01, -.20123200E+00, -.77991100E+00, 0.40110900E+00, 0.18996200E+00, 0.51820600E+00, -.63789400E+00, -.57190600E-01, 0.30652000E+00, 0.54823400E+00, -.23824300E+01, 0.81497700E+00, -.18916300E+00, -.23276600E+00, 0.63670700E-01, 0.15427400E+01, -.26022900E-01, 0.13024900E+00, 0.50316200E-01, 0.11564100E+00, 0.22948100E+00, -.15207600E+00, 0.54658900E+01, 0.29493100E+00, -.14975500E+00, 0.48314000E+00, 0.53202500E+00, 0.68105200E+00, 0.45445600E+00, -.11432400E+00, -.25604100E+00, -.73523300E+00, 0.24959000E+00, 0.31947600E-01, -.14229400E+00, 0.39891100E+00, 0.25910800E+00, 0.94370200E-01, 0.10138500E+01, 0.12650900E+00, 0.68706100E+00, 0.18082600E+00, -.56110900E+00, -.40144900E+00, -.41832600E+00, 0.24815900E+00, -.80629300E+00, -.53865300E+00, -.84375800E+00, -.47026100E-01, -.10372000E+01, 0.43043600E+00, 0.45462000E+00, 0.39460700E+00, -.92088000E-01, 0.33035600E+00, -.96911600E-02, 0.18364000E+01, 0.44948500E+00, -.42307800E-01, 0.19728500E+00, 0.83950400E+02, 0.47837800E+02, 0.15349300E+02, 0.47660600E+03, -.23980200E+03, -.27434100E+03, -.23438900E+03, 0.22069700E+03, 0.14732700E+03, 0.13565000E+02, -.21701700E+03, 0.11754600E+03, -.72223700E+02, 0.39384900E+02, -.67564800E+01, -.10302900E+02, 0.94709200E+02, -.33276300E+02, 0.13486100E+02, -.11065400E+03, 0.30205200E+03, 0.60533100E+02, 0.88781300E+02, -.86608600E+02, -.85513900E+02, -.17713500E+03, 0.73109700E+02, -.13923900E+03, 0.36805400E+02, -.92013000E+01, 0.71518900E+02, -.28757900E+02, -.87504500E+02, -.59052700E+02, 0.77377800E+02, -.46053500E+02, -.13143800E+03, 0.11335100E+02, -.90037700E+01, -.88607900E+01, 0.63383400E+02, 0.12010200E+03, -.90695700E+01, 0.17571600E+00, -.46361100E+00, -.56109600E+00, -.22569500E-02, -.36310300E+00, 0.25528900E+00, 0.67946000E+00, -.13691700E+00, 0.13587900E+00, -.45069700E+00, -.55270600E+00, 0.25977400E-01, -.35557700E+00, 0.25035300E+00, 0.68147700E+00, -.99392600E-01, -.24099300E+03, 0.32750000E+02, 0.25756800E+01, 0.39669900E+02, 0.67858100E+02, -.63143300E+02, 0.52855900E+02, 0.40040300E+02, -.19681600E+03, 0.25146000E+02, 0.17124000E+02, 0.38390800E+02, 0.14880400E+02, -.64170700E+02, -.82983500E+01, 0.32355500E+02, 0.18549000E+00, -.35076300E+01, -.25577200E+01, 0.64687200E+00, -.19241400E+01, 0.34030600E+00, 0.30941600E+01, 0.21898700E-01, 0.77676600E+01, -.15981400E+03, 0.36723400E+02, -.80016500E+00, -.22564000E+02, 0.59999600E+02, 0.68284200E+02, 0.87921100E+01, 0.53496400E-01, 0.12692300E+01, 0.10667100E+01, -.30330200E+00, 0.76448100E+00, -.22122800E+00, -.11918600E+01, -.79884700E-01, 0.14034700E-01, -.32168800E+01, -.23049600E+01, 0.60192000E+00, -.17237200E+01, 0.16588400E+00, 0.25653500E+01, 0.26926700E-01, 0.80357200E+00, 0.11194200E+00, -.97836700E+01, 0.73426100E+01, 0.21988200E+00, -.21945200E+01, -.85952500E+00, -.31489100E+00, 0.93395500E+00, 0.21447000E+00, -.23138300E+02, -.28060200E+01, 0.54878400E+01, -.29806600E+02, 0.19836500E+02, 0.18440800E+01, 0.71232200E+01, -.36666600E+02, 0.19538500E+00, 0.13054400E+00, 0.46038800E+01, -.60319300E+01, 0.56543500E-01, -.73675800E+01, -.16612800E+00, 0.35514900E+00 }, { -.22159200E-01, 0.74361400E-01, -.35689600E+00, -.34500300E+00, -.14559500E+00, 0.12565600E+01, -.45319400E+00, 0.81658600E-01, -.13026900E+00, 0.94037900E-01, -.12263700E-01, -.79111100E-01, -.14085200E+00, 0.13703600E+00, 0.18308500E+00, 0.50827300E-02, -.15738600E+00, -.65904000E-02, -.90986200E-01, 0.10593000E+00, -.73170700E-01, 0.15364700E-01, 0.22114500E-01, -.33907100E-01, -.98542500E-02, -.10348600E-01, -.12746700E-02, 0.39903300E-02, 0.12738600E+00, 0.39215300E-01, 0.38329300E+00, -.33723400E-01, -.29518600E-01, -.53767300E-01, -.14091400E+01, 0.25171000E-02, 0.13268200E-03, 0.54811400E-01, -.86822100E-02, -.54497100E-02, 0.23458600E-01, 0.67363000E-01, -.57605200E+00, -.26516700E-01, -.37478700E-01, 0.61327100E-01, -.96080400E-02, 0.57029600E-02, 0.89300700E-03, 0.53858100E-02, -.95712000E-02, -.23787400E-01, 0.12966500E-01, 0.62866000E-02, 0.20554100E+00, -.19667100E-01, 0.79435300E-02, 0.91442500E-01, -.12396900E-01, -.94835000E-01, -.56013000E-01, -.28253300E-01, 0.44522000E-01, 0.50743800E-01, -.56961900E-01, 0.92650500E-02, 0.17310900E-01, -.62311000E-01, 0.35914200E-01, 0.21929900E-02, 0.32456700E-01, 0.70341500E-01, 0.55983900E-02, 0.23722700E-01, -.81070100E-01, -.26659200E-01, -.14935400E+00, 0.30224900E-01, -.69402600E-01, -.21628900E+00, -.82517700E-02, 0.35724200E-01, 0.19120700E+00, 0.11298200E-01, -.23554000E-01, 0.11635400E+00, 0.13359000E-01, -.37125400E-01, 0.31525600E-01, -.35788000E+00, 0.13222500E+00, 0.43368300E-01, 0.25788400E-01, 0.36842200E-01, 0.25117900E+02, -.14282300E+01, 0.22329400E+02, -.15356900E+02, -.18085300E+02, -.12481000E+02, 0.13972800E+02, 0.97568300E+01, -.62250800E+01, -.12100900E+02, -.12452600E+02, -.11118600E+02, 0.99052600E+01, 0.66294100E+01, -.30725100E+01, -.80962300E+01, -.70131000E+01, 0.64766200E+01, 0.34646800E+02, -.10966600E+02, -.47152900E+01, -.36124400E+01, -.36749500E+01, 0.88816700E+01, -.11149900E+02, 0.11514400E+00, -.65627000E+01, 0.88822400E+01, -.10800300E+01, 0.59072800E+01, 0.13106500E+00, -.57733000E+01, -.80845000E+01, 0.66817900E+01, 0.24904000E+00, -.93620800E+00, 0.27051900E+01, 0.54770500E+01, -.76269400E+01, 0.73002500E+01, 0.23090500E+02, 0.44974400E+01, 0.86425900E-01, -.16306900E+00, -.35863000E-01, 0.39545100E-01, -.24224100E-01, 0.47837100E-01, 0.51981600E-01, 0.13847700E-02, 0.82542200E-01, -.16173600E+00, -.35791800E-01, 0.38259800E-01, -.23449600E-01, 0.46809300E-01, 0.56949400E-01, 0.10952800E-02, -.39715700E+02, 0.37028100E+01, 0.10634400E+01, 0.48672200E+01, 0.11940700E+02, -.66687900E+01, 0.87370700E+01, 0.35901500E+01, -.16242400E+02, 0.21586700E+00, 0.10877300E+01, 0.28511200E+01, 0.22267800E+01, -.61949700E+01, -.16117700E+01, 0.19799400E+01, -.14974600E+00, -.52960900E+00, -.17939500E+00, 0.18569100E+00, 0.21494600E-01, 0.14543500E+00, 0.34367400E+00, 0.28682200E-02, -.73779700E+01, -.90906300E+01, -.27186600E+01, -.97300100E+01, 0.10563300E+02, -.48350900E+01, 0.62304600E+00, -.12912700E+02, -.50018900E-01, 0.29560800E+00, 0.79807400E-01, -.74256500E-01, 0.19151300E-01, -.65166600E-01, -.12229200E+00, -.23784800E-02, -.13115700E+00, -.48497500E+00, -.17389500E+00, 0.15906500E+00, 0.22815200E-01, 0.11906500E+00, 0.28256700E+00, -.16736800E-02, 0.35763000E+00, -.47008600E-01, -.62239200E+00, 0.17399500E+01, -.25140300E-01, -.20278800E+00, 0.43404700E-01, 0.10049100E-01, -.51406200E-01, -.23671400E-01, -.36540000E+01, 0.45841700E+00, 0.57238500E+01, -.93155800E+00, 0.14450100E+01, 0.69521900E+01, 0.58086600E+00, -.82427700E+01, -.64024300E-02, -.26928200E-01, 0.99807400E+00, -.17321400E+01, -.16814700E-01, 0.24477000E+01, 0.36295700E-01, -.30119200E-02 }, { -.54483900E+00, -.22443500E+00, 0.96289600E+00, -.95107500E-01, 0.24524500E+00, 0.18269500E+01, 0.15036000E+01, -.81526200E+00, 0.29918500E+00, -.53867800E+00, -.20766100E-02, 0.32481400E+00, -.68430900E+00, 0.37914400E+01, -.60873600E+00, -.23048700E+01, -.11345200E+01, -.91233800E+00, -.84056700E-01, 0.47839200E+00, -.25357900E+00, -.44471600E-02, 0.36405300E+00, 0.19727200E+00, 0.44998500E-02, 0.72796800E-01, -.18336200E+00, -.51401700E-01, 0.39310900E+00, 0.21324600E-01, 0.81810700E+00, 0.42042100E-01, -.32350000E+00, -.22639000E-01, -.17320700E+00, 0.20025600E+00, 0.32379900E-01, 0.64685400E-01, -.11614000E+00, 0.35461600E-02, 0.27628500E-01, 0.25014500E+00, 0.39074500E+00, -.10202900E+00, -.20040100E+00, -.17856300E+00, 0.15370300E-01, 0.61664100E+00, 0.16597800E-01, -.27960100E-01, -.47942300E-01, -.19787700E-01, -.11244700E+00, 0.42317000E-01, 0.12743800E+01, -.10033700E+00, 0.98797100E-02, 0.54837100E+00, -.60585700E-01, -.20542500E+00, 0.33914300E+00, -.74137300E-01, 0.64055000E-01, 0.75528400E+00, 0.17683900E+00, -.62761300E-01, 0.55426100E-01, -.36875900E+00, -.28588600E+00, 0.30781500E-01, 0.76063600E+00, -.32317600E+00, -.14819900E+00, 0.11786100E+00, -.62794100E-01, -.21720900E-01, -.66924300E+00, 0.24006800E+00, -.33767700E+00, -.57709500E+00, -.41226000E-01, -.13053200E+00, -.20692500E-01, -.36094700E-01, 0.18787500E+00, -.59231000E+00, 0.12029200E-01, 0.48431200E+00, 0.31396600E-01, -.15658500E+01, 0.67748400E+00, -.17760400E+00, 0.73563200E-01, -.26093200E+00, -.82379300E+00, 0.31707900E+02, 0.21228800E+03, -.10628500E+03, -.13810300E+03, -.11645500E+03, 0.12031400E+03, 0.91940700E+02, 0.37022700E+01, -.11043000E+03, 0.56904400E+02, 0.51648900E+02, 0.17081300E+02, -.13644800E+02, -.10281800E+02, 0.61984200E+02, -.42902900E+01, -.39740100E+01, -.22630500E+03, 0.18420800E+03, 0.67891100E+02, 0.96288200E+02, -.59511900E+02, -.89569900E+02, -.80312000E+02, 0.74205700E+02, -.64357600E+02, -.16455100E+02, -.60344700E+01, 0.28700000E+02, -.10842000E+02, -.33301200E+02, -.22185500E+01, 0.32898900E+02, 0.38330500E+02, -.19383500E+02, 0.14947300E+02, 0.79482400E+01, -.27000900E+02, 0.59218600E+02, -.84328000E+01, 0.19384900E+02, -.30205300E-01, 0.86264400E-01, -.48513600E-01, -.12215200E+00, -.16582800E+00, 0.22184500E+00, 0.14438900E+00, -.38013700E-01, -.38179400E-01, 0.88657900E-01, -.57197100E-01, -.10935900E+00, -.16104700E+00, 0.20435700E+00, 0.12913700E+00, -.26288300E-01, -.12112800E+03, 0.57316700E+02, 0.92112900E+01, 0.34251800E+02, 0.30107700E+02, -.15225200E+02, 0.23375800E+02, 0.35423200E+02, -.21350400E+02, 0.42380400E+01, -.80044700E+01, -.93411900E+00, 0.83312600E+01, 0.32563800E+01, -.21615100E+01, -.26238400E+01, -.53254100E-01, -.28295700E+00, -.59057700E+00, -.24326900E+00, -.76373600E+00, 0.38023500E+00, 0.98452900E+00, 0.15920400E-01, -.20271400E+02, -.57926200E+02, 0.33148000E+02, 0.14380400E+02, -.42023500E+02, -.13037000E+02, 0.11827000E+02, 0.24615600E+02, 0.28629400E-01, -.66313100E-02, 0.22418900E+00, 0.97083200E-01, 0.34977000E+00, -.23928100E+00, -.22707200E+00, -.18860900E-01, 0.44168200E-02, -.33999200E+00, -.56944600E+00, -.18210300E+00, -.72142300E+00, 0.30715000E+00, 0.82135500E+00, 0.10025400E-01, -.14996300E+00, 0.84550500E-01, -.20796300E+01, 0.71115800E+01, 0.79693400E-01, 0.51100300E+00, -.24377400E+00, -.84645600E-01, 0.37592400E+00, 0.79038000E-01, -.11734400E+02, -.68199700E+00, -.15714600E+01, -.13979300E+02, 0.70564800E+01, -.82202400E+01, 0.26247400E+01, -.20691200E+02, 0.63654100E-01, 0.72558900E-01, 0.75464600E+01, -.88647300E+01, -.12186800E+00, -.29691600E+01, -.82974600E-01, 0.74171600E-01 }, { 0.60848700E+00, 0.21361600E+00, 0.46050800E-01, -.23523700E+00, -.45757200E+00, -.92526000E+00, -.53132900E+00, -.49259500E-02, 0.23640100E-01, -.26672000E+00, -.12710400E-01, -.25465200E+00, -.39326000E+00, 0.57854400E+00, 0.74524000E-01, -.10215000E+01, -.30009100E-01, -.37714900E-01, 0.20650500E+00, 0.10295100E+00, -.41112800E+00, 0.10716100E+00, 0.47473000E+00, -.76253000E-01, 0.20711900E-01, -.66793200E-01, 0.49626400E+00, 0.21412700E+00, 0.18555100E+00, -.47268400E-02, 0.69354300E+00, -.19145800E-01, -.11487400E+00, -.77294300E-01, -.89648900E+00, -.27612400E-01, 0.84494900E-01, -.16138800E+00, -.12893800E+00, 0.51273200E-01, -.14827600E+00, -.16448000E+00, 0.98831700E+00, -.40056600E-01, -.49655500E-01, 0.54159300E+00, -.53270400E-01, -.60788400E+00, -.11721100E-01, -.16260900E-01, -.92428300E-01, 0.27769700E-01, 0.43474200E-01, 0.45046700E-01, 0.98839100E+00, 0.40163300E-01, 0.29526600E-01, 0.64840600E+00, 0.32432900E+00, 0.15560000E+00, 0.16403500E+00, 0.10883600E+00, -.52488300E-01, 0.11626200E+00, 0.10595500E+00, -.70338600E-02, 0.58655500E-01, -.10855600E+00, -.12705600E+00, -.57197200E-02, 0.22457000E+00, 0.21967600E-01, -.53381000E-01, 0.36238500E-02, -.92376300E-01, 0.11956800E-01, -.21594300E+00, 0.49702100E-01, 0.28151300E+00, -.41274800E+00, 0.22426600E+00, 0.19915300E-01, 0.45765600E+00, -.59331500E-01, -.16299800E+00, -.41049100E+00, 0.19351500E+00, 0.34931700E+00, 0.27769700E-01, -.18019100E+01, 0.29909900E+00, -.44088300E-01, 0.59126000E-01, 0.88221900E-01, -.13726000E+01, 0.17139200E+00, -.11710800E+03, 0.73123000E+02, 0.56446300E+02, 0.52116000E+02, -.45913600E+02, -.47271600E+02, -.15183200E+02, 0.47149800E+02, 0.75338100E+01, -.31266000E+01, -.16543200E+02, -.98807300E+01, 0.59935800E+01, -.52614400E+01, 0.11438100E+02, -.15852400E+02, 0.27135500E+02, -.53039900E+02, -.14680800E+02, -.19549100E+02, 0.19662000E+02, 0.93318700E+01, 0.18874600E+02, -.16254800E+02, 0.30645500E+02, -.57588000E+01, -.17531300E+01, -.18086900E+02, 0.14307200E+02, 0.22278500E+02, 0.12097800E+02, -.17668700E+02, -.68638800E+02, 0.64348700E+02, 0.61059100E+01, 0.17532100E+02, 0.62431100E+01, -.50067000E+02, -.17055400E+02, 0.17207400E+02, -.54569500E-01, 0.16522000E+00, 0.13807500E+00, -.14361700E-01, 0.94383000E-01, 0.50293700E-03, -.15467200E+00, 0.30428400E-01, -.41861100E-01, 0.16294000E+00, 0.13234000E+00, -.21551300E-01, 0.93012000E-01, 0.63728000E-02, -.15277100E+00, 0.21481900E-01, 0.66986600E+02, -.29958600E+02, -.43796800E+01, -.13709600E+02, -.13887000E+02, 0.75252100E+01, -.80932700E+01, -.14756000E+02, 0.43981900E+02, -.82448000E+01, -.35127700E+01, -.99807400E+01, -.12348700E+01, 0.14871300E+02, -.58707800E-01, -.95426200E+01, 0.68684300E-01, 0.87514900E+00, 0.57957800E+00, -.16533000E+00, 0.46609700E+00, 0.25583800E+00, -.59411900E+00, 0.43044900E-01, 0.37573100E+02, 0.17110100E+01, -.23356900E+02, -.21311900E+02, 0.20377300E+02, 0.11222500E+02, -.36324700E+02, -.24074500E+02, -.18073600E-01, -.39773000E+00, -.21871700E+00, 0.10054400E+00, -.21324100E+00, -.89874500E-01, 0.25273700E+00, 0.23551100E-01, 0.36182900E-01, 0.84311800E+00, 0.50368200E+00, -.16002200E+00, 0.44321100E+00, 0.23521200E+00, -.48960800E+00, 0.23532000E-01, -.24113800E+00, -.31326000E-02, 0.38684300E+01, 0.25864100E+00, -.40002100E-01, 0.77247600E+00, 0.16781900E+00, 0.70503200E-01, -.15606800E+00, -.38981100E-01, 0.39796100E+01, 0.32157200E-01, -.41003100E+00, 0.52412600E+01, -.78183600E+01, -.48671600E+00, -.28393900E+01, 0.42331700E+01, -.39496000E-01, -.16335900E-01, -.17406100E+01, -.12857800E+01, 0.28902000E-01, 0.24713500E+01, 0.21689300E-01, -.92836200E-01 }, { -.28029100E+01, -.34751000E+01, 0.22073100E+01, 0.74321000E-03, 0.72125300E+00, 0.25209100E+01, 0.14197000E+01, -.29107100E+01, 0.86380100E+00, 0.20170500E+01, -.58220800E+00, -.66343300E+00, -.46946600E+00, 0.26876100E+01, -.22874200E+01, -.54406500E+01, -.56459900E+01, -.28048500E+01, 0.19888300E+00, 0.48067800E+00, 0.13418200E+01, -.80975400E+00, -.13615800E+01, 0.19226700E+01, -.29670400E+00, 0.73110100E+00, -.14514000E+01, -.40362100E+00, 0.37773100E+01, 0.58910300E+00, 0.77423300E+01, -.65214600E+00, -.15216200E+01, 0.52284300E+00, 0.46103100E+01, 0.32381900E+00, -.97205400E-01, 0.16561500E+01, 0.32690400E+00, -.63833100E-01, 0.17013200E+01, 0.27653700E+01, -.59551600E+01, 0.96195600E+00, -.74410600E+00, -.51731400E+01, 0.87109800E+00, 0.44911000E+01, 0.11786100E+00, -.88231400E-02, 0.67773300E-01, -.49432300E+00, -.42810200E+00, 0.66712200E-01, 0.37351700E+01, -.83242000E+00, 0.10107900E-01, 0.28593800E-01, -.21059300E+01, -.22634200E+01, -.26087500E+01, -.66919500E+00, 0.97742500E+00, 0.11183800E+01, -.11932700E+01, 0.19577600E+00, -.30712200E+00, -.98625600E+00, 0.12263200E+01, 0.50228000E-01, -.38465700E+01, 0.15633400E+01, -.58389900E-01, 0.38997800E+00, 0.15652600E+01, -.13488100E+00, 0.75194400E+00, -.26346300E+00, -.18385500E+01, 0.37206200E+01, 0.37771200E+00, -.13420900E+00, -.61159300E+00, -.18684700E+00, 0.39070600E+00, 0.14697600E+01, -.27225800E+00, -.74808800E+00, 0.42247200E+00, 0.96590600E+00, 0.25637600E+01, -.39278800E+00, -.94365000E-01, -.36017400E-01, 0.30506700E+01, 0.30207900E+01, -.23895100E+01, -.14290200E+03, -.79200800E+01, -.34358100E+02, 0.24569500E+02, 0.29858600E+02, 0.80889800E+02, -.35683000E+02, -.56819300E+03, 0.21571000E+03, 0.20123000E+03, 0.22375900E+03, -.57513100E+02, -.25221900E+03, -.91195100E+02, 0.22808000E+03, 0.79355100E+02, 0.66897900E+02, -.30975200E+02, -.15066800E+02, -.63974600E+02, 0.66992100E+01, 0.88519600E+02, -.16985100E+02, -.58474800E+02, 0.51279300E+02, 0.34613700E+02, 0.42516400E+02, -.57833200E+02, -.56820300E+02, 0.26427500E+02, 0.36329800E+02, 0.13885400E+03, 0.29618900E+02, -.85845400E+02, -.89211000E+02, 0.18992900E+02, 0.59633800E+02, -.57159900E+01, -.68568500E+02, -.43389500E+00, 0.85702700E+00, -.13476300E+01, 0.93082400E-01, 0.38983200E+00, -.89091800E+00, 0.11664200E+00, 0.93437800E-01, -.45267200E+00, 0.84743300E+00, -.12797800E+01, 0.12442100E+00, 0.35646200E+00, -.88777400E+00, 0.83486100E-01, 0.13280600E+00, 0.27525300E+02, 0.30754400E+00, -.26562600E+02, -.84644700E+01, -.22940900E+02, -.17067500E+02, -.55072900E+02, -.76881800E+01, 0.15000500E+02, -.79946400E+02, -.41774100E+01, -.29439100E+00, -.10565300E+02, 0.15511900E+02, 0.82773600E+02, 0.51745000E+01, 0.24473600E+00, 0.23038000E+01, -.52459200E+01, 0.33878800E+00, 0.54417200E+00, -.14574600E+01, 0.41660700E+00, 0.19157000E+00, -.36141300E+03, 0.20418200E+03, 0.21736200E+03, 0.21576700E+03, -.14617300E+03, -.89435200E+02, 0.66811800E+02, 0.21197800E+03, 0.41868800E+00, -.11566500E+01, 0.22079400E+01, -.19782000E+00, -.38376900E+00, 0.10710700E+01, -.36582200E+00, -.22520300E+00, 0.48618500E+00, 0.17474900E+01, -.47616600E+01, 0.67657500E-01, 0.50897300E+00, -.95149300E+00, 0.75694600E+00, -.47931400E-01, -.17131700E+01, 0.13127600E+00, 0.34086600E+01, 0.47581400E+00, 0.21792400E-01, -.88496200E+01, -.27765100E+01, 0.63791600E-01, 0.33776700E+01, 0.29278300E-01, 0.46600200E+00, -.56253400E+01, 0.38944700E+00, -.47999500E+01, 0.16637900E+02, -.55088000E+02, 0.52779900E+01, 0.46477400E+01, -.65320500E-01, 0.65753000E-01, -.18294400E+02, 0.23744800E+02, 0.53080900E+00, -.25000200E+02, -.75919100E-01, -.19704600E+00 }, { -.10272400E+01, -.12235600E+01, 0.70950000E+00, 0.22023300E+00, 0.77068900E+00, 0.10833400E+01, 0.12481100E+00, -.22688800E+01, 0.25477500E-01, 0.28583400E+00, -.22537400E+00, -.78915300E+00, 0.12828000E+00, 0.17882500E-01, -.12195400E+01, -.29513800E+01, -.14704800E+01, -.30629200E+01, -.20087100E+01, 0.88907900E+00, 0.15962600E+01, -.13981000E+00, -.10215200E+01, 0.18195400E+01, -.31038600E+00, 0.20073800E+00, -.52436300E+00, -.17521400E+00, 0.20058600E+01, 0.50902900E+00, 0.20898000E+01, -.33077300E+00, -.15279800E+00, -.55306000E+00, -.59770600E+00, -.61542900E-01, 0.32029600E+00, 0.41747700E+00, -.13393300E+01, 0.63939900E-01, 0.21145400E+00, 0.70866300E+00, -.12062200E+01, 0.19727600E+00, -.11581600E+00, -.47465600E+00, 0.39062700E-01, -.10476500E+01, -.26266900E-01, 0.51065800E-01, -.22717100E+00, -.13469300E+00, 0.47248800E+00, 0.12945800E+00, -.81621600E+00, 0.89569800E-01, 0.13736800E+00, 0.16301400E+00, 0.67115000E-01, -.26471400E+00, 0.84542000E+00, -.96029200E-01, 0.31849800E-01, 0.14069100E+01, 0.41141900E+00, -.71632100E-01, 0.65722500E-02, -.10357600E+01, -.13235100E-01, -.57592200E-01, 0.15417000E+01, -.18581700E+00, -.26991300E+00, 0.10930200E+00, -.41810200E+00, 0.17416200E+00, -.28118300E+00, -.24039900E+00, -.49555100E+00, -.17223500E+01, 0.11868100E+01, -.58439100E-01, 0.55010900E+00, 0.16879000E+00, -.43399400E+00, 0.94592000E+00, 0.59380000E-01, -.15835800E+00, 0.38797500E+00, -.29130900E+01, 0.11469100E+01, -.69946900E-01, -.65376300E-01, 0.60007700E-01, 0.51587300E+01, 0.11803900E+01, -.82692800E-01, 0.50319900E-01, 0.38304700E+02, 0.14523600E+02, -.35247800E+02, 0.67837700E+01, 0.23103300E+02, 0.13172900E+02, -.21400400E+03, 0.90891700E+02, 0.67969700E+02, 0.84355400E+02, -.26191800E+02, -.81754900E+02, -.28168300E+02, 0.90631900E+02, -.38112700E+02, 0.62853800E+02, 0.23691200E+02, 0.33192900E+02, -.17303800E+02, -.18626900E+02, 0.11561500E+02, 0.33998300E+02, -.79612200E+01, 0.26787500E+02, 0.21318300E+02, 0.11502500E+02, -.21167300E+02, -.13140600E+01, 0.44676000E+02, 0.74599900E+01, 0.11843300E+03, -.12963900E+02, -.43109000E+02, -.33139800E+02, -.38405500E+01, 0.42049500E+02, 0.28399100E+01, -.27453800E+02, -.61163300E-02, 0.31921200E-01, -.17225300E+00, 0.61775200E-01, 0.32810900E+00, -.23587200E+00, 0.14680000E-01, 0.97596500E-01, -.42306600E-02, 0.33842000E-01, -.16612900E+00, 0.53726200E-01, 0.33184600E+00, -.22032300E+00, 0.14066500E-01, 0.90029400E-01, 0.88484000E+02, -.21598700E+02, -.30979200E+02, -.30723900E+02, 0.85680900E+00, 0.29522500E+02, -.34912700E+00, -.29502100E+02, -.11090400E+03, 0.82129000E+02, 0.27363900E+02, 0.23527300E+02, 0.28145100E+01, -.36578500E+02, 0.14718500E+02, 0.22506300E+02, 0.15006900E+00, 0.17901200E+00, -.64993800E+00, -.25088400E+00, 0.13611500E+01, -.36221200E+00, 0.17937800E+00, -.13516100E+00, -.53951000E+02, 0.55905400E+02, 0.29504600E+02, 0.11454600E+02, -.86718400E+01, 0.11983800E+02, 0.38271300E+02, 0.13237600E+02, 0.94184100E-02, -.14874900E+00, 0.23906600E+00, 0.16519500E-01, -.61733300E+00, 0.23469900E+00, -.10372100E+00, -.45446600E-01, 0.11050900E+00, 0.23169100E+00, -.52638000E+00, -.23797800E+00, 0.11750400E+01, -.28896300E+00, 0.21643000E+00, -.13921500E+00, -.18571600E-02, -.32385800E-01, 0.76690900E+01, -.51182300E+01, -.45152500E-01, -.11007700E+01, -.15999500E+00, 0.56527000E-01, 0.45519200E-01, -.48633600E-01, 0.36011200E+01, 0.27678500E+01, 0.32153800E+00, 0.77331500E+01, 0.21666400E+01, -.64040900E+01, 0.38396900E+01, 0.27312500E+01, -.60876200E-01, -.42536300E-01, 0.55039200E+00, 0.77896700E+01, -.28277300E-01, -.94430400E+00, 0.42553200E-01, -.63820100E-01 }, { -.27335900E+00, -.11395600E+00, 0.50101600E+00, 0.21531000E+00, 0.19326100E+00, 0.11555900E+01, 0.87271700E+00, -.34348900E+00, 0.29307900E-01, -.73119700E-01, 0.91201000E-02, 0.15934400E+00, -.89804200E-01, 0.81117000E+00, -.15940700E+00, -.34455100E+00, -.31597900E+00, -.13221500E+00, -.46060900E-01, 0.52175400E-01, 0.36269500E-02, -.52811700E-02, 0.76027200E-01, 0.79820500E-01, 0.36765900E-02, 0.22900600E-01, -.13725900E+00, -.47951300E-01, -.29933400E-02, -.95525100E-03, -.13291300E+00, 0.47175900E-01, -.77729600E-01, 0.85542900E-02, -.24560300E+00, 0.85804300E-01, -.19509600E-01, 0.74237700E-01, -.54787700E-01, -.57151200E-02, 0.22016500E-01, 0.50348400E-01, 0.10510800E+00, 0.26289800E-01, -.71449900E-02, -.13195300E+00, 0.39647000E-01, 0.14183900E+00, -.28116700E-02, -.75286400E-04, -.14573400E-01, 0.41405400E-02, 0.19746100E-01, -.21697400E-02, 0.51148200E+00, 0.42795600E+00, -.13769000E-01, -.23810200E+00, -.13017900E+00, 0.51075100E-01, 0.10613500E+00, -.42365600E-01, 0.20054600E-02, -.82490400E-01, 0.31272300E-03, -.23431700E-01, -.95266700E-01, -.63971900E-01, 0.15055000E-02, 0.44863100E-01, -.36758300E+00, -.16768800E+00, -.78843300E-02, 0.12223400E-01, -.25236900E-01, 0.64960700E-01, 0.32057200E-01, 0.25776100E-01, 0.19900000E+00, -.36735400E-01, 0.70985900E+00, -.43584900E-01, -.57466600E-01, -.10330000E-01, 0.12858600E+00, 0.94259600E-01, -.53727700E-01, 0.19223400E-01, 0.36310900E-02, 0.44929400E-01, 0.31748800E+00, -.61567800E-01, 0.23626100E-01, -.70579100E-01, 0.47340700E+00, 0.31652200E+00, -.56294300E+00, -.47543000E-01, 0.31600500E-02, -.52105500E+01, 0.20754400E+01, 0.72597400E+01, 0.31791900E+01, -.56996100E+01, -.39831400E+02, 0.18417700E+02, 0.13753700E+02, 0.15817300E+02, -.62113400E+01, -.16652500E+02, -.68384600E+01, 0.15209900E+02, 0.46846100E+02, 0.70645800E+01, -.21555100E+02, -.17951500E+02, -.26854300E+01, 0.15169500E+02, 0.46310000E+01, -.18748600E+02, 0.13970100E+01, 0.35784000E+01, -.25112200E+01, -.50282600E+01, 0.40319000E+01, -.97768800E-01, 0.11160000E+02, -.42780000E+01, -.31284700E+02, 0.12060900E+02, -.24151500E+01, -.26631700E+01, 0.26428600E+01, -.71670000E+01, 0.30431300E+01, -.17653600E+01, -.82559000E-01, 0.10115500E+00, -.11781200E+00, 0.16413500E-01, 0.20554300E-01, -.27938900E-01, -.85323000E-01, 0.52296800E-01, -.81680100E-01, 0.10097000E+00, -.11092900E+00, 0.22207900E-01, 0.17172900E-01, -.28392300E-01, -.89492300E-01, 0.58895800E-01, 0.23719000E+02, -.12732300E+02, -.64147500E+01, -.59010800E+01, -.99617600E+00, 0.51828700E+01, -.53664000E+01, -.48865200E+01, 0.11846300E+02, -.61346900E+01, -.18576200E+01, -.21866700E+01, -.21406000E+01, 0.44956500E+01, 0.11581200E+01, -.18239500E+01, -.76134300E-01, 0.18945400E+00, -.37392700E+00, 0.14321700E+00, -.14921200E-02, -.58423800E-02, -.36181900E+00, 0.30507900E+00, -.24729300E+01, -.38094600E+01, 0.14275800E+02, 0.13596200E+02, -.63764400E+01, -.86485800E+00, -.11660300E+02, 0.14167300E+02, 0.51191500E-01, -.11796900E+00, 0.18594300E+00, -.48085700E-01, -.94122400E-02, -.13213300E-03, 0.16334100E+00, -.12360600E+00, 0.12594600E-01, 0.12206800E+00, -.35333600E+00, 0.95516800E-01, -.13958800E-02, 0.45224300E-01, -.29604700E+00, 0.23886600E+00, -.34672000E+00, -.83508700E-01, 0.30660000E+01, -.94056500E+00, -.12030000E+00, -.94635300E+00, -.49862700E+00, 0.15122200E+00, 0.55635600E+00, -.10110300E+00, 0.21848100E+01, -.20622600E+01, 0.67242800E+00, 0.24206200E+00, -.17302500E+01, -.81388100E+01, -.14778300E+01, 0.80140000E+00, -.69321300E-01, -.50736200E-01, -.11868300E+01, 0.89691800E+00, -.27416500E+00, -.33572000E+01, 0.10176700E+00, -.19832700E+00 }, { 0.12699800E+01, 0.26878900E+00, 0.53634500E-01, -.12235500E+01, -.23710400E+01, -.37941400E+01, -.17723700E+01, 0.10718600E+01, 0.54014800E+00, -.74413000E+00, -.16360900E+00, -.18812500E+00, -.94021500E+00, 0.28355400E+01, -.11808000E+01, -.39313100E+01, -.77305500E+00, -.19298500E-01, 0.46955700E-01, 0.13911600E+01, -.17754900E+01, 0.17158900E+00, 0.13739400E+01, -.13305800E+01, 0.11581400E+00, -.29161400E+00, 0.13528200E+01, 0.42244200E+00, -.67587500E+00, -.28113900E+00, -.59954400E+00, 0.17119300E+00, 0.18640300E+00, 0.39507600E+00, 0.48323800E+01, -.97374000E-02, -.22778800E-01, -.10343600E+00, 0.60818100E+00, -.47946000E-01, -.81731200E-01, -.35961600E+00, -.29346000E+01, 0.64953900E+00, 0.19486000E+00, -.88890900E+00, 0.48713700E-01, -.50239200E+00, 0.24991600E-01, -.55604900E-01, 0.44489300E+00, 0.11934400E+00, -.79922200E+00, -.16470500E+00, -.23716400E+01, -.29146500E-01, -.18405400E+00, -.90395000E+00, -.26185100E+00, -.39914500E+00, 0.73256100E+00, -.44682700E-01, -.24225600E+00, 0.54082900E+00, 0.57266800E+00, -.15051700E+00, 0.12291900E+00, -.28895300E+00, -.54287400E+00, -.61123200E-01, 0.18690900E+01, -.74900000E+00, -.15507000E+00, 0.12872300E+00, -.98496200E+00, -.17899600E-01, -.10791000E+01, -.97848900E-01, -.22261000E-01, 0.10555700E+01, 0.16895800E+01, 0.25545800E-01, 0.15066000E+01, -.53771900E+00, -.42794500E+00, -.44410500E+00, 0.35649100E+00, -.97358600E-01, 0.25912200E-01, -.59204300E+01, 0.57412100E+00, -.17289900E+00, 0.12685900E+00, -.36599700E+00, -.10368300E+01, 0.52785800E+00, 0.19857100E+01, -.25654700E+00, 0.84368600E+00, 0.89978000E+00, 0.12711700E+02, -.73455200E+00, -.20351300E+02, 0.56204400E+01, 0.11094000E+03, -.68028000E+02, -.18089900E+02, -.27449700E+02, 0.85045800E+01, 0.28258200E+02, 0.84604700E+01, -.28765800E+02, 0.51794500E+02, -.65041700E+02, -.26880300E+01, -.26151000E+02, -.24977900E+01, 0.10928400E+02, 0.10926000E+02, -.27680700E+02, -.37133700E+02, 0.14422700E+02, 0.38561200E+01, 0.11471800E+02, 0.12271400E+02, -.23014800E+02, -.25880000E+02, 0.17158100E+02, -.78192600E+02, -.34188600E+02, 0.20375000E+02, 0.47076200E+00, 0.12949900E+02, -.32569400E+02, 0.23721700E+02, -.24887200E+01, 0.11819100E+00, 0.21653800E+00, 0.40048400E-01, -.40063000E-01, -.17906200E+00, 0.16853900E+00, 0.24465700E+00, -.82986300E-01, 0.11372400E+00, 0.21385600E+00, 0.38050400E-01, -.44704100E-01, -.18223500E+00, 0.16602900E+00, 0.25631900E+00, -.84907000E-01, -.56848200E+02, 0.17908100E+02, 0.22649900E+02, 0.18939700E+02, -.16355900E+02, -.35280300E+02, -.21727800E+02, 0.17959200E+02, 0.26638700E+02, -.39847300E+02, -.66435900E+01, -.63935400E+01, 0.28502200E+01, 0.23005100E+01, -.16419200E+02, -.71444800E+01, 0.13969900E+00, 0.12849900E+01, 0.13136400E+00, -.74257400E-01, -.82628900E+00, 0.83746000E+00, 0.10627900E+01, -.16646600E+00, -.39084900E+02, -.24896300E+02, -.37129200E+02, -.25042300E+02, 0.58894000E+02, -.41824900E+01, 0.86228200E+01, -.29854900E+02, -.56018300E-01, -.46051000E+00, -.80008400E-01, 0.78953800E-01, 0.36690000E+00, -.29724800E+00, -.50212700E+00, 0.12077800E+00, -.18962600E-01, 0.11664700E+01, 0.13474300E+00, -.71784000E-01, -.71935500E+00, 0.71160900E+00, 0.93149600E+00, -.14400200E+00, 0.50662000E+00, 0.26938900E+00, -.10153500E+02, 0.55211200E+01, 0.27626300E+00, 0.75721600E+00, 0.12520800E+00, -.28897200E+00, -.12842600E+00, 0.24248900E+00, -.14012200E+01, 0.17544600E+01, -.10431400E+01, 0.21254200E+01, 0.57853600E+01, 0.21724800E+01, -.24515000E+01, 0.35619800E+01, 0.16218100E+00, 0.17199600E+00, -.63939600E+01, -.77456100E+01, 0.47044600E+00, 0.45259400E+01, -.27530900E+00, 0.31455600E+00 }, { 0.72127400E+00, 0.27561100E+00, -.11196600E+01, -.56619300E+00, -.57177800E+00, -.25969600E+01, -.15480700E+01, 0.12524900E+01, -.20949600E+00, 0.26861900E+00, 0.20811600E-01, -.18685500E+00, 0.71533100E+00, -.34147000E+01, 0.43966000E+00, 0.19424900E+01, 0.13591200E+01, 0.52400000E+00, -.89484400E-01, -.10170200E+00, -.25097100E+00, 0.17505400E+00, 0.22107500E+00, -.41890800E+00, 0.10419400E+00, -.21698700E+00, 0.23041600E+00, -.44990800E-02, -.46642000E+00, -.16397000E+00, -.16703400E+01, 0.20117000E+00, 0.42967600E+00, 0.18516700E+00, 0.30502200E+01, -.16887900E+00, -.95453800E-01, -.27371800E+00, 0.17500100E+00, 0.12236900E+00, -.71148800E-01, -.36433400E+00, 0.37365400E+00, -.55090800E+00, 0.12580600E+00, 0.25855500E+00, -.27798300E+00, 0.29124700E+00, 0.49829500E-01, -.34383600E-01, 0.15830000E+00, -.48789800E-01, -.26334300E+00, 0.13083200E-01, -.65325200E+01, -.21642500E+00, -.63921700E-01, 0.15732700E+00, -.57300700E+00, -.44213500E+00, 0.54991100E+00, 0.49868100E-02, -.32883800E+00, -.54805600E+00, 0.36239500E+00, 0.71334600E-01, -.84191000E-01, 0.93791900E-01, 0.43896600E+00, -.42813400E-01, 0.24106600E+01, 0.45838900E+00, 0.46625700E-01, -.10064000E+00, -.79296600E-01, 0.13977800E+00, -.19699600E+00, -.41566100E-01, 0.83933800E-01, -.13589100E+00, 0.75009300E+00, 0.16104600E+00, 0.14088900E+01, -.17655300E+00, -.30071600E+00, 0.84784900E-01, 0.16206600E+00, -.41310800E+00, 0.10833200E+00, -.38601900E+01, 0.64891800E+00, 0.10311100E+00, 0.33788300E-01, -.84218800E-01, 0.21718700E+01, -.14077800E+00, -.59018300E-01, 0.22048000E-01, 0.33403700E+00, 0.78004200E+00, 0.24029500E+00, -.83761700E+01, -.44085700E+01, 0.49704900E+00, -.40971400E+02, 0.22597200E+02, -.44036800E+01, -.27633500E+01, 0.19708800E+02, -.16317100E+01, 0.11248800E+02, -.40989900E+01, -.66870400E+01, 0.59507900E+01, 0.73352200E+01, 0.46720100E+01, -.73937800E+01, 0.86729400E+01, -.25395400E+01, 0.53003000E+01, 0.10801000E+02, 0.26223800E+01, -.97646900E+01, -.11514000E+02, 0.42025600E+01, 0.55103700E+01, 0.22892200E+01, -.11428400E+02, 0.79539100E+02, -.28096200E+02, -.10590400E+02, -.14397500E+02, -.90571600E+01, 0.36066500E+02, 0.51238500E+01, -.12539000E+02, -.45536700E-01, -.23731500E+00, 0.17251800E+00, 0.26021200E-01, 0.61017100E-01, 0.15045200E-01, 0.16310500E+00, -.21230100E-01, -.43452900E-01, -.23718700E+00, 0.17449800E+00, 0.28103500E-01, 0.61966100E-01, 0.14226600E-01, 0.15955000E+00, -.20242900E-01, -.27641200E+02, 0.99834700E+01, 0.90905700E+01, 0.96057100E+01, -.11960700E+01, 0.28249800E+01, 0.13818700E+01, 0.11136000E+02, 0.31233000E+01, -.56926300E+01, 0.12732900E+01, -.21927200E+00, -.13258900E+01, 0.28707400E+01, 0.16870000E+01, -.41960700E+00, 0.18536300E-01, -.10250100E+01, 0.73210400E+00, 0.40346100E-01, 0.30763000E+00, -.11431500E+00, 0.51609700E+00, -.16895600E+00, 0.18340400E+02, 0.12568300E+02, 0.64161900E+01, 0.65179100E+01, -.69285300E+01, -.21654000E+01, 0.10294400E+02, 0.49045600E+01, 0.26322100E-01, 0.45945100E+00, -.34419500E+00, -.48378500E-01, -.12119700E+00, 0.13993300E-01, -.24910800E+00, 0.49589500E-01, 0.48563400E-01, -.92339800E+00, 0.65991300E+00, 0.48133800E-01, 0.24806600E+00, -.11203200E+00, 0.41984100E+00, -.13482200E+00, -.19005600E+00, 0.27569700E-01, -.24134300E+01, -.22951000E+00, 0.88569600E-01, 0.12438900E+01, 0.85761500E+00, -.14059100E+00, -.93138700E+00, 0.72603000E-01, -.34770200E+01, -.62509100E+00, 0.60969600E+00, -.26770200E-01, 0.11677800E+01, 0.79564000E+00, 0.54509400E-01, -.31240200E+01, 0.50649800E-01, 0.19918900E-01, 0.20927700E+01, 0.36987000E+00, 0.28556300E+00, -.67864100E+00, -.55629600E-01, 0.20753500E+00 }, { -.14598500E+01, -.20261600E+01, 0.19555600E+01, -.25541100E+00, -.34135400E-01, 0.16879900E+01, 0.57375300E+01, -.16833200E+01, -.10862700E+00, -.64129200E+00, 0.16500300E+00, -.89768100E+00, -.13229900E+01, 0.31966600E+01, -.28544700E+00, -.43519500E+01, -.38242000E+01, -.13108100E+01, -.20254100E+00, 0.15109200E+01, -.37798800E+00, -.57717200E+00, -.97790500E+00, 0.10210600E+01, -.12991400E+00, -.84108400E-01, -.17691600E+01, -.41157400E+00, -.33908800E+00, 0.30223400E+00, -.88755600E+00, 0.68270600E-01, -.40721900E+00, 0.14394400E+00, -.80756300E+01, 0.33650700E+00, -.18613400E+00, 0.52066500E+00, -.14542800E+01, -.15327600E+00, 0.63966800E+00, 0.14967900E+01, 0.54600900E+01, -.13641700E+01, -.12922200E+00, -.32366500E+01, 0.51971300E+00, 0.13019500E+01, 0.13636000E+00, -.26480900E+00, -.14139700E+00, -.31656400E+00, -.73848100E+00, 0.17477900E+00, 0.21812200E+01, -.80035700E+00, 0.70940100E-01, -.14170900E+01, -.21149000E+01, -.95974900E+00, 0.23241100E+01, -.13587700E+00, 0.21410300E+00, 0.28347500E+01, 0.70851400E+00, -.23696000E+00, 0.82748400E-01, -.17531900E+01, -.65027700E+00, 0.11985200E+00, -.61338800E+01, -.72926700E+00, -.44475100E+00, 0.39791800E+00, -.60700500E+00, -.21451200E+00, -.31617800E-01, 0.27805600E-01, 0.79865500E+00, -.70932000E+00, -.62153900E+00, -.37928600E+00, -.12898800E+01, 0.56182700E+00, -.21114300E+00, 0.55290700E+00, -.70346200E+00, 0.52586900E+00, -.15722100E+00, -.15438500E+01, 0.11207400E+01, -.29509800E+00, -.43528700E-01, 0.55365500E+00, -.25286000E+01, 0.16476400E+01, 0.15604100E+01, -.72747500E-01, -.31351600E+00, -.35523700E+00, 0.41214000E+00, -.80147000E-01, 0.68454400E+02, -.75756200E+01, -.17342400E+03, 0.63581200E+02, 0.72647600E+02, 0.96258900E+02, -.46236000E+02, -.85095800E+02, -.55034900E+02, 0.10011300E+03, -.13309800E+03, 0.21270700E+01, 0.27802500E+02, 0.56606400E+02, -.21190700E+02, -.41561800E+02, 0.46382300E+02, 0.64706900E+02, 0.22004100E+02, -.35269600E+02, 0.25074600E+02, 0.37722900E+02, -.48076400E+02, -.12429600E+02, 0.12668300E+02, 0.29734600E+02, 0.28522400E+03, -.17115500E+02, -.94065000E+02, -.51044300E+02, -.14458400E+02, 0.97658300E+02, -.28674500E+02, -.41584500E+02, 0.22900600E-01, 0.55073300E-01, -.69146300E+00, 0.13760800E+00, 0.44071200E+00, -.57650300E+00, -.23383000E+00, 0.20343500E+00, 0.72811400E-02, 0.56750600E-01, -.68535000E+00, 0.13517400E+00, 0.44400100E+00, -.56771600E+00, -.22621600E+00, 0.19937300E+00, 0.15428200E+02, 0.45742800E+02, -.47624500E+02, -.28299400E+02, 0.25219600E+02, 0.42514000E+02, 0.55856600E+02, -.34050700E+02, -.13182000E+03, 0.60410900E+02, 0.23143200E+02, 0.31801700E+02, 0.62426000E+01, -.36096800E+02, 0.58822700E+02, 0.34086400E+02, 0.17443800E+00, 0.58918300E+00, -.31698800E+01, -.57484800E-01, 0.19558800E+01, -.11764200E+01, -.33352900E+00, -.87785000E-01, -.19438400E+03, 0.18274300E+03, 0.10529800E+03, 0.80135600E+02, -.83224900E+02, -.36984600E+02, 0.99695600E+02, 0.82741100E+02, 0.72890300E-01, -.18670800E+00, 0.13415600E+01, -.14920800E+00, -.87607100E+00, 0.81147600E+00, 0.97917200E-01, -.19507900E+00, 0.15059700E+00, 0.52325300E+00, -.28416000E+01, -.94187700E-01, 0.17536500E+01, -.97735400E+00, -.73901200E-01, -.13206700E+00, 0.15390900E+00, -.27993300E+00, -.24835300E+01, -.24693400E+01, -.33741900E+00, -.51709300E+01, -.14377900E+01, 0.39761900E+00, 0.14548700E+01, -.30908700E+00, 0.51225000E+01, 0.52143300E+01, -.23333400E+01, -.10052400E+02, 0.12617000E+02, -.72837700E+01, 0.11137700E+02, 0.13011600E+01, -.25268700E+00, -.21525800E+00, 0.89958000E+01, 0.19755200E+02, -.56950100E+00, -.57061700E+01, 0.31213300E+00, -.48822100E+00 }, { 0.26680900E+01, 0.10264100E+01, -.33501800E+01, -.18754200E+01, -.62430500E+00, -.25039700E+01, 0.38466100E+01, 0.19477400E+01, -.69737900E+00, 0.12682800E+01, -.79031800E-01, -.12443900E+01, 0.12997400E+01, -.94721400E+01, 0.11848100E+01, 0.58565000E+01, 0.36855000E+01, 0.34691800E+00, -.12522300E+01, -.34413400E+00, 0.68373400E+00, 0.15549500E+00, -.19872000E+01, -.74610000E+00, 0.73434000E-01, -.44504500E+00, 0.32491000E+00, 0.22147600E-01, -.37961200E+01, -.10266200E+00, -.66891800E+01, 0.25524500E+00, 0.23117300E+01, 0.83611500E-01, 0.68021200E+01, -.13785100E+01, -.38521800E+00, -.20616000E+01, 0.61787200E+00, 0.10290300E+00, -.11762900E+01, -.25017200E+00, -.59867100E+00, -.71815000E+00, 0.28385900E+00, 0.88791400E+00, -.45987000E+00, -.30936100E+01, 0.10839000E+00, 0.28872100E-01, 0.45754900E+00, -.29363900E+00, -.42422500E+00, 0.23186700E+00, -.14062600E+02, -.55437300E+00, -.17632600E+00, -.14595700E+00, -.14462300E+01, -.98066500E+00, 0.26582700E+01, -.22221200E-01, -.19673200E+01, -.39191400E+01, 0.20075600E+01, 0.21363200E+00, -.22346200E+00, 0.15995500E+01, 0.11038300E+01, -.26552400E-01, 0.12476100E+01, 0.10395000E+01, 0.10449500E+01, -.93297100E+00, 0.53201800E-01, -.16501300E+00, -.16696300E+01, 0.85435100E+00, 0.28096300E+00, 0.29997300E+01, 0.18992400E+01, -.14320100E+00, -.23615200E-01, -.64009500E+00, 0.15830200E+00, 0.28676100E+00, 0.14108300E+00, -.16331300E+01, -.20149600E-01, -.11050700E+01, -.36234100E+00, -.27076400E-01, 0.37381200E+00, 0.33393600E+00, -.63973500E+01, 0.50153300E-01, 0.32854800E+01, -.23686600E+00, -.45681800E+00, -.22611600E+01, 0.16634200E+01, 0.26430500E+01, 0.52804000E+00, -.87054900E+01, -.37841100E+02, 0.86756300E+01, 0.51587600E+02, 0.43876900E+02, -.49961200E+02, -.94354400E+01, -.23850700E+02, 0.54842500E+02, 0.63218200E+02, 0.11496600E+03, -.95342300E+01, 0.19905100E+02, -.25855700E+01, 0.78244700E+01, -.21535900E+02, 0.16533400E+02, -.53987000E+02, 0.42588500E+02, 0.45241300E+02, 0.46431100E+02, -.40265200E+02, -.12723700E+02, -.38444000E+00, 0.31741700E+02, -.86754800E+02, 0.13363900E+03, -.35419400E+01, 0.45517100E+02, 0.16357600E+02, -.53402000E+02, -.14721400E+02, 0.46344800E+02, 0.19777800E+00, 0.27953400E+00, -.54096900E+00, 0.27539700E+00, -.32735500E+00, 0.73294300E-02, -.54082200E+00, 0.35187000E+00, 0.20003400E+00, 0.28663900E+00, -.55403800E+00, 0.26108600E+00, -.31460100E+00, 0.19533500E-01, -.53571500E+00, 0.33880500E+00, 0.16659200E+03, -.90066100E+02, -.66677500E+02, -.45709800E+02, 0.25627100E+02, 0.27136700E+02, 0.22315100E+02, -.50933200E+02, -.19264500E+03, 0.12716300E+03, 0.37880000E+02, 0.36226400E+02, 0.14027800E+02, -.68651200E+02, -.73628400E+01, 0.29745400E+02, -.28302000E+00, 0.10013400E+01, -.24425900E+01, 0.80778000E+00, -.10760200E+01, 0.11685600E+00, -.16275500E+01, 0.10525600E+01, 0.16344100E+03, -.85801700E+02, -.46021600E+02, -.86395300E+02, -.71436800E+01, 0.10189900E+03, -.33276300E+02, -.74848300E+02, -.17909500E+00, -.62003300E+00, 0.11166100E+01, -.40525900E+00, 0.46049900E+00, -.71165700E-01, 0.93438800E+00, -.52394700E+00, -.30337600E+00, 0.98061700E+00, -.21642000E+01, 0.71582600E+00, -.87364700E+00, 0.35565400E-01, -.14510100E+01, 0.90471400E+00, 0.79384100E+00, -.62633600E+00, 0.15435900E+02, -.56645000E+00, -.80892800E+00, -.49319100E+01, -.33594800E+01, 0.96538500E+00, 0.34311400E+01, -.70861300E+00, 0.29289800E+01, 0.46257300E+01, 0.26609800E+00, 0.15549300E+01, -.52726600E+01, 0.30036700E+01, 0.10429400E+01, -.40946000E+01, -.45341000E+00, -.41095700E+00, 0.10633700E+01, -.28776300E+01, -.24306800E+01, 0.47292900E+01, 0.71239400E+00, -.11769500E+01 }, { -.72266600E+01, -.10766400E+01, 0.52293000E+01, 0.41254600E+01, 0.12207100E+01, 0.36669400E+01, 0.90427100E+01, -.31226800E+01, 0.15952200E+01, -.35987800E+01, 0.13817300E+00, 0.11587700E+01, -.38952800E+01, 0.26632300E+02, -.36587300E+01, -.20228400E+02, -.83113600E+01, -.66310500E+01, -.49770600E-01, 0.47241500E+01, -.31210800E+01, -.29032500E+00, 0.12291700E+00, 0.50954500E+01, -.17028100E+00, 0.18579400E+01, -.23324500E-01, -.64484100E-01, 0.79144700E+01, 0.20758100E+01, 0.29668300E+02, -.56381400E+00, -.43790800E+01, -.20196300E+01, -.12011500E+02, 0.14438000E+01, 0.73277400E+00, 0.48329500E+01, 0.84106300E+00, 0.67753200E+00, 0.20236800E+01, 0.24383100E+01, -.52698100E+01, 0.82143200E+00, -.17103300E+01, -.31468500E+01, 0.23508400E+00, 0.82772900E+01, 0.22243600E+00, -.24846800E+00, 0.17549100E+00, 0.40686500E+00, -.20815300E+01, -.15287600E+00, 0.29098500E+02, -.90555600E+00, -.61145000E+00, 0.74721200E+01, 0.63941800E+00, -.29416200E+01, 0.21351400E+01, -.41786500E+00, -.50860500E+00, 0.33252400E+01, 0.20077700E+01, -.28199400E+00, 0.70954400E-01, -.17087900E+01, -.15808900E+01, -.72444200E-01, 0.44931700E+01, -.15729800E+01, -.12980100E+01, 0.11257300E+01, -.60994200E+00, -.78876500E+00, -.33980700E+01, 0.41488700E+00, -.50250100E+01, -.58446000E+01, -.17339100E+01, -.72586900E+00, -.25866700E+01, 0.96631600E+00, 0.13178600E+01, -.13510400E+01, -.29369000E+00, 0.12218100E+01, -.13677700E+00, 0.99118600E+01, -.15792900E+01, 0.78549500E+00, 0.63469100E+00, -.83045100E+00, -.30316800E+01, 0.85794500E+00, -.49372200E+01, -.28023000E+00, -.18077900E+01, -.45138600E+01, -.82680300E+00, -.70780000E+00, -.40651500E+00, 0.90959700E-02, -.78296700E+03, 0.15716800E+03, 0.23642800E+03, 0.24964600E+03, -.14395900E+01, -.30017500E+03, -.40944600E+02, 0.26886700E+03, 0.38233600E+03, 0.12043700E+03, 0.28295300E+02, 0.43233900E+02, -.16121800E+03, 0.68789200E+02, -.11689700E+02, 0.45023400E+02, -.18342000E+03, 0.16194500E+03, 0.10948500E+03, 0.13293300E+03, -.97302200E+02, -.81891900E+02, 0.14117900E+02, 0.13174500E+03, 0.22718100E+03, 0.72002100E+02, -.49288100E+02, 0.12962800E+02, -.17624300E+02, 0.27783200E+02, -.12436800E+02, 0.37630100E+02, 0.47260500E+00, 0.65836900E-01, -.12235000E+01, 0.66151800E+00, 0.19563100E-01, -.30503500E+00, 0.29840200E+00, 0.40834400E+00, 0.46223400E+00, 0.77003200E-01, -.12184400E+01, 0.62970400E+00, 0.34981500E-01, -.27044600E+00, 0.30539400E+00, 0.38869700E+00, 0.17724500E+03, -.13017600E+03, -.67174100E+02, -.29159000E+02, -.21257200E+02, 0.32532900E+01, -.30577300E+02, -.43776600E+02, -.20735800E+03, 0.80638500E+02, 0.47708200E+02, 0.40855400E+02, 0.18358700E+02, -.55062000E+02, 0.93910300E+02, 0.45137300E+02, 0.33763900E-01, -.24425800E+00, -.53691300E+01, 0.17761600E+01, 0.18351100E+00, 0.53448600E+00, 0.22134200E+01, 0.55923200E+00, -.54460200E+03, 0.24515200E+03, 0.94196700E+02, 0.39864700E+02, 0.51621500E+02, -.10769300E+03, 0.75732600E+01, 0.29445900E+02, -.25973700E+00, -.23064400E+00, 0.22725500E+01, -.93861900E+00, -.18041400E+00, 0.76866200E-01, -.91175400E+00, -.50853800E+00, -.23803100E+00, -.26923100E-01, -.47401300E+01, 0.14526400E+01, 0.25003600E+00, 0.50422600E+00, 0.21818400E+01, 0.38201400E+00, 0.20170100E+01, -.39863700E+00, 0.24236400E+01, 0.10419200E+02, -.47545500E+00, -.90254000E+01, -.35984800E+01, 0.53758600E+00, 0.39758500E+01, -.43635100E+00, -.20567400E+01, 0.16981200E+02, -.52825100E+01, 0.18033900E+01, 0.21227300E+02, -.68027400E+01, 0.10020300E+02, -.12672400E+02, -.30354900E+00, -.28837300E+00, -.13488700E+02, 0.14063000E+02, 0.53053300E+00, 0.16591700E+02, 0.43878800E+00, -.65519400E+00 }, { 0.95867300E+00, 0.17998200E+00, -.13906100E+01, -.11108300E+01, -.10212800E+01, -.33829900E+01, -.50477200E+01, 0.51766600E+00, -.11949700E+00, 0.42870400E+00, -.16063500E+00, -.40214700E+00, 0.10131400E+01, -.42483700E+01, 0.15882900E+00, 0.89269400E+00, 0.74395200E+00, 0.37519200E+00, -.10985300E+00, -.95801800E-01, -.14243800E+00, 0.34457200E-01, 0.26324500E+00, -.72144600E+00, 0.18467000E-01, -.33755400E+00, -.43962100E+00, -.14889400E+00, -.50357200E+00, -.61670900E+00, -.45900000E+01, 0.18996000E+00, 0.75416200E+00, 0.35521400E+00, 0.63950300E+01, -.22427000E+00, -.34257600E-02, -.12689300E+01, 0.64456700E+00, 0.70378300E-02, -.50334800E+00, -.49100200E+00, -.89264300E+00, 0.33141000E+00, 0.19782300E+00, 0.28081100E+00, -.39823300E-01, -.99570900E+00, -.43652200E-01, -.46113800E-02, 0.18528500E+00, 0.10052200E+00, 0.15424900E-01, -.10655600E+00, -.52003600E+01, 0.25073100E+00, 0.58236500E-01, -.25473100E+01, -.82360000E-01, 0.97109300E+00, -.51756900E+00, 0.21779400E+00, 0.22111300E+00, -.49731200E+00, -.52247100E+00, -.64981600E-02, 0.54075100E-01, 0.47741200E+00, -.62963900E-01, -.77823500E-02, -.20249200E+01, -.17012800E+00, -.55739600E-01, -.10754900E-01, 0.32762600E+00, 0.18157300E+00, 0.12875900E+01, -.25378600E+00, 0.74848100E+00, 0.12224900E+01, -.32021700E+00, 0.15237200E+00, 0.25141800E+00, -.13822900E+00, -.22715500E+00, -.81385700E+00, -.26529100E-01, 0.52782000E+00, 0.38640700E-01, -.12033900E+01, -.72842300E+00, -.31273000E+00, -.10507500E+00, -.68740300E+00, -.14650500E+01, -.43336200E+00, -.54838500E+00, -.90092500E-01, -.11766800E+00, 0.49584000E+00, 0.10795800E+00, -.97474800E+00, -.11619600E+00, 0.42861000E-02, 0.72026100E-01, 0.75408700E+02, -.22500900E+02, -.14799300E+02, 0.12169700E+02, 0.16106000E+02, 0.67549900E+01, -.18903500E+02, -.59667800E+02, 0.24769400E+02, 0.20479800E+02, 0.27090500E+02, -.27001000E+02, -.17606500E+02, -.31507600E+02, 0.30367400E+02, 0.65927000E+02, -.36839200E+02, -.20481500E+02, -.29318700E+02, 0.61930700E+01, 0.20477000E+02, 0.53489400E+01, -.31622400E+02, 0.11264400E+03, -.57160500E+02, -.55722200E+01, -.21483000E+02, -.15880100E+02, 0.61437500E+02, -.94452700E+01, -.21140700E+02, -.61550800E-01, -.21181700E+00, 0.25781400E+00, -.86098600E-01, 0.24486600E+00, 0.60419200E-01, 0.94479700E-01, -.70473300E-01, -.61375600E-01, -.21170600E+00, 0.25582900E+00, -.79568600E-01, 0.24796500E+00, 0.52672500E-01, 0.86918700E-01, -.67317100E-01, -.67001300E+02, 0.43922200E+02, 0.21023600E+02, 0.19269900E+02, 0.52388700E+01, 0.49978200E+01, 0.68218300E+01, 0.23743400E+02, 0.21390400E+02, -.23539600E+02, -.75326200E+01, -.59273300E+01, -.20467900E+01, 0.10686100E+02, 0.71382400E+01, -.60789600E+01, 0.60583300E-01, -.93720200E+00, 0.10766700E+01, -.37470800E+00, 0.11556500E+01, -.25653700E+00, 0.20283300E+00, -.36906000E+00, 0.11650900E+01, 0.44031100E+02, 0.20449100E+02, 0.31561700E+02, -.35904000E+02, -.12894900E+02, 0.39232500E+02, 0.30198900E+02, 0.40916000E-01, 0.42887800E+00, -.48503900E+00, 0.11045100E+00, -.46113000E+00, 0.18529700E-01, -.92272700E-01, 0.11265800E+00, 0.87043800E-01, -.87672700E+00, 0.96300900E+00, -.28542600E+00, 0.96292200E+00, -.23450800E+00, 0.12337600E+00, -.28048700E+00, -.26514900E+00, 0.10375700E+00, 0.30391900E+01, 0.15278300E+00, 0.16019200E+00, 0.24685200E+01, 0.14037700E+01, -.20712500E+00, -.14359100E+01, 0.14085900E+00, -.56271300E+01, -.43870500E+00, 0.16975500E+01, 0.14598800E+01, -.50955000E+01, 0.16703200E+01, 0.17892800E+01, -.41245200E+01, 0.93155400E-01, 0.73883500E-01, 0.54257200E+01, 0.17206100E+01, 0.37800700E+00, -.32444300E+01, -.12782800E+00, 0.27297300E+00 }, { 0.13235300E+01, 0.60935700E+00, -.21912700E+01, -.90011300E+00, -.96574100E+00, -.52181800E+01, -.16347300E+01, 0.31907100E+01, -.28716800E+00, 0.67481500E+00, -.80559800E-01, -.91174100E+00, 0.10856500E+01, -.56980200E+01, 0.90246100E+00, 0.15759300E+01, 0.20103400E+01, 0.13649200E+01, 0.55895600E+00, 0.15403700E+00, -.10995900E+01, 0.13001800E+00, 0.29458800E+00, -.74886500E+00, 0.71097000E-01, 0.17335800E+00, 0.10137800E+01, 0.24482700E+00, 0.16783400E+01, 0.39291700E-01, 0.69548700E+01, -.58017000E+00, -.27172200E+00, -.95668700E-01, 0.64442200E+01, -.46849500E+00, 0.52947100E+00, 0.27853200E+00, 0.11045000E+01, 0.41032400E+00, 0.14369700E+00, -.19188800E+00, -.48483400E+01, -.30964000E-01, -.78336900E+00, 0.20291700E+01, -.10365100E+01, 0.33604800E+01, 0.84955600E-01, -.10489900E+00, 0.50346500E+00, 0.26211300E+00, -.10694000E+01, -.24533800E+00, 0.58207700E+00, -.19824800E+00, -.36914400E+00, 0.10005300E+01, -.17485200E+00, -.67093300E+00, 0.26732200E+00, 0.28542900E-01, -.32435400E+00, -.12893700E+01, 0.19749600E+00, 0.69395900E-01, 0.23672200E-01, 0.70659900E+00, 0.17626900E+00, 0.32073800E-01, 0.22230100E+01, 0.27695700E+00, 0.14826700E+00, 0.87693700E-01, 0.38104700E+00, 0.10848800E+00, -.23166800E+00, 0.75975100E-01, -.29357900E+00, -.72123400E+00, 0.34422300E+00, 0.88732100E-01, 0.10890500E+01, -.22990900E+00, -.84429000E-01, -.63736600E+00, 0.10972200E+00, 0.13767800E+00, -.70130300E-01, -.10097800E+00, -.36327700E-01, -.52586500E-01, 0.18260900E+00, -.29062800E+00, -.10669200E+01, -.57571400E-01, -.74694800E+00, -.16863500E+00, -.14196000E+00, 0.23457600E+01, -.29327100E+00, 0.82048400E+00, -.39251600E+00, 0.85565300E-01, 0.98967100E-01, 0.63419600E-01, 0.42015800E+02, 0.39853900E+02, -.48165300E+02, -.19528800E+02, -.39544000E+02, 0.43181900E+02, -.72456500E+02, -.32007900E+02, 0.24266800E+02, 0.21719300E+02, -.10040800E+02, -.33298300E+02, 0.45373300E+02, 0.20514400E+02, -.37402900E+02, -.53995500E+01, 0.21920900E+02, 0.32844300E+02, -.22854300E+02, -.31679000E+02, -.75107300E+01, 0.29209000E+02, 0.41744200E+02, -.51115000E+02, -.19663500E+02, -.15462000E+02, 0.16564000E+02, 0.14656700E+02, 0.18026500E+02, -.16616700E+02, 0.86895000E-01, 0.20721900E+00, -.57582700E-01, -.60198400E-01, 0.16238600E-01, -.33082200E+00, 0.15801000E+00, -.12104300E+00, 0.78649400E-01, 0.20510100E+00, -.58652100E-01, -.62821100E-01, 0.14638300E-01, -.33360200E+00, 0.16144300E+00, -.12172300E+00, -.11066200E+03, 0.52034900E+02, 0.26120700E+02, 0.35890200E+02, -.17160000E+01, -.57362500E+02, -.14210200E+02, 0.30126800E+02, -.20417000E+02, -.45216100E+01, 0.20201700E+01, 0.16714000E+01, 0.34738700E+01, -.12741300E+02, 0.49212600E+01, 0.13985300E+01, 0.36579800E+00, 0.10461500E+01, -.38185000E+00, -.38902200E+00, -.16458200E+00, -.93356500E+00, 0.69304600E+00, -.71449700E+00, -.58609400E+02, 0.52981500E+02, 0.29714600E+02, 0.14018300E+02, -.29493000E+02, 0.73699700E+00, 0.29477700E+02, 0.14768700E+02, -.71190800E-02, -.42125500E+00, 0.11472800E+00, 0.12116400E+00, 0.39891700E-01, 0.60274900E+00, -.35590200E+00, 0.24491200E+00, 0.15018400E+00, 0.94437500E+00, -.32570000E+00, -.32475100E+00, -.14660800E+00, -.86628700E+00, 0.67250500E+00, -.61898300E+00, 0.39996500E+00, 0.32545200E+00, -.43454700E+01, 0.41077600E+01, 0.36596400E+00, 0.10952200E+00, 0.34534500E+00, -.40658800E+00, -.23390800E+00, 0.31542500E+00, -.58501800E+01, 0.26831200E+01, -.20265300E+01, 0.28153800E+01, 0.10867800E+02, -.54520000E+01, 0.49600300E+01, -.76090800E-02, 0.18455700E+00, 0.19617300E+00, -.63110800E+01, -.11445400E+01, 0.97048000E+00, 0.72865200E+00, -.34615300E+00, 0.49625300E+00 }, { 0.11062200E+01, 0.37071500E+00, -.18519400E+01, -.12088400E+01, -.12517900E+01, -.48352600E+01, -.21472700E+01, 0.27222300E+01, -.16306400E+01, -.33824400E+00, 0.66399600E+00, -.66365400E+00, 0.61828000E+00, -.73045300E+01, 0.35257200E+01, 0.61022200E+01, 0.45702700E+01, 0.75562300E+00, -.22607800E+00, -.95770900E+00, -.53389700E+00, 0.81150600E+00, 0.17879600E+00, 0.31610700E+00, -.53722900E-01, -.54148400E-01, -.23412200E+00, -.14131400E+00, 0.12332700E+00, 0.68416800E-01, -.10049200E+01, 0.45960000E+00, 0.15370600E+00, 0.16807900E-01, 0.22926300E+00, -.11211500E+00, -.14554200E+00, 0.77570100E-01, -.82196300E+00, 0.35147400E+00, -.15685200E+00, -.41371200E+00, 0.70055600E+00, 0.40001500E-01, 0.17039700E+00, 0.37835100E+00, -.10869900E-01, -.74676200E+00, -.37601900E-01, 0.19231200E-01, -.19031000E+00, 0.43716200E-02, 0.51538000E+00, 0.11404500E+00, -.44698800E+01, 0.10760500E+00, 0.13542000E+00, -.67370900E-02, 0.34769500E+00, 0.99924300E-02, 0.14696400E+00, 0.13832100E+00, 0.15124300E+00, 0.82066000E+00, -.68559600E-01, 0.29781700E-01, -.51559600E-01, -.62691100E+00, 0.17039900E+00, -.10095400E-01, 0.21659200E+01, 0.39530500E+00, -.59455300E-01, -.90263000E-01, -.76004500E-01, -.22831500E-01, -.10683800E+01, 0.50034700E+00, -.36932800E+00, -.56459300E+00, 0.63302300E+00, -.14702700E+00, 0.94536100E+00, -.24737900E+00, 0.62737900E-02, -.98145400E+00, 0.11280600E+00, 0.59341300E+00, 0.34728500E+00, -.83863100E-01, -.66799100E-01, -.91312300E-01, -.33618900E+00, 0.19778800E+00, 0.26279000E+01, -.28937500E+00, 0.37258500E+00, 0.52105600E-01, 0.84517800E+00, 0.13164000E+01, 0.14991700E+00, -.68018300E+00, -.20941300E+00, -.10845500E+00, -.38758800E-01, 0.50040700E+00, -.91475700E-01, -.13135200E+02, -.13066400E+01, 0.13608100E+02, -.43280900E+01, -.12935000E+02, -.98765800E+01, -.15121800E+02, 0.21286900E+01, -.17248500E+01, 0.66405000E+00, 0.20274200E+02, 0.18266200E+02, -.46961800E+01, 0.12774200E+02, -.38949400E+01, -.85573000E+01, -.12744000E+02, 0.21819500E+01, 0.26203100E+02, 0.23414600E+02, -.14558400E+02, 0.80805600E+02, 0.33928400E+00, 0.10684600E+02, 0.12586100E+02, -.33658200E+02, 0.54088000E+02, -.12522600E+02, 0.14597600E+02, -.81034200E-01, -.16883500E+00, 0.20664100E+00, -.38532600E-01, -.85694100E-02, 0.47945700E-01, 0.22196800E-02, -.36576700E-01, -.77661600E-01, -.16948000E+00, 0.20629200E+00, -.35971200E-01, -.63471500E-02, 0.34892100E-01, -.64638200E-02, -.35644000E-01, -.42093000E+02, 0.30658400E+02, 0.10257200E+02, 0.17786100E+02, 0.56281200E+01, 0.40757500E+01, 0.38171800E+01, 0.17392800E+02, 0.66518500E+02, -.17599500E+02, -.95710300E+01, -.13902100E+02, -.30220000E+01, 0.28253700E+02, -.41551200E+01, -.12091200E+02, -.17359000E+00, -.60945800E+00, 0.69289500E+00, -.14850500E+00, 0.21247000E+00, -.35566100E+00, -.11770400E+00, -.14273100E+00, -.82944900E+01, 0.90000100E+01, 0.22259600E+02, 0.21310500E+02, -.21369900E+02, -.43901900E+02, -.27648500E+02, 0.25901000E+02, 0.31356000E-01, 0.32618500E+00, -.37501100E+00, 0.45749600E-01, -.16032800E-01, 0.60831900E-01, 0.68507500E-01, 0.53867500E-01, -.19167000E-01, -.59883900E+00, 0.63409700E+00, -.87690800E-01, 0.14674700E+00, -.32349600E+00, -.13450300E+00, -.86629500E-01, -.37107100E+00, -.12517600E-01, -.23713900E+00, -.14096600E+01, 0.24181700E-01, 0.10938900E+01, 0.63727200E+00, -.54047200E-01, -.67058400E+00, 0.19094500E-01, -.93300700E+00, -.11937100E+01, -.44181100E+00, 0.73494300E+00, 0.18691400E+01, -.13772000E+01, -.62311700E+00, -.79965300E+01, 0.17138400E-01, -.44508400E-02, 0.46669000E+01, -.16289400E+01, 0.35108300E+00, -.28845100E+00, -.49591000E-02, 0.95371000E-01 }, { -.53109800E+00, -.15349200E+00, -.10518600E+00, 0.25022100E+00, 0.48569400E+00, 0.68250100E+00, 0.28433900E+00, 0.70050700E-01, -.51225600E-01, 0.18089600E+00, 0.23264600E-01, 0.20904500E+00, 0.32976700E+00, -.49076800E+00, -.65528300E-01, 0.84469200E+00, 0.68645500E-02, 0.10860200E+00, -.14424000E+00, -.14708600E+00, 0.33912100E+00, -.80948400E-01, -.37200200E+00, 0.13040500E+00, -.35676400E-01, 0.77109500E-01, -.29594700E+00, -.13266400E+00, 0.24042800E-01, 0.27767600E-01, 0.95230100E-01, -.36951300E-01, 0.36996400E-01, 0.80637900E-02, 0.68462200E+00, -.83488400E-02, -.33748600E-01, 0.77065400E-01, 0.14860700E+00, -.18856700E-01, 0.80953500E-01, 0.80210800E-01, -.63015300E+00, 0.55593700E-02, 0.16108000E-01, -.26627200E+00, 0.16564700E-01, 0.45829700E+00, 0.89954100E-02, 0.95819100E-02, 0.57131200E-01, -.22760000E-01, -.36441300E-01, -.22960900E-01, -.60623100E+00, -.51877300E-01, -.18191200E-01, -.22789000E+00, -.15471400E+00, -.22622700E+00, -.88402000E-03, -.69880400E-01, 0.23823500E-01, -.13293800E+00, -.64900900E-01, 0.18457400E-01, 0.26280700E-02, 0.75659300E-01, 0.94798100E-01, -.79933800E-03, 0.30362100E-01, 0.58673800E-01, 0.22997600E-01, 0.22732200E-02, 0.53450700E-01, 0.79246500E-03, -.92540500E-01, 0.33229200E-01, -.25350200E-01, -.11299700E+00, -.14244000E+00, 0.26154300E-01, -.68159000E-02, 0.31622700E-01, 0.57506200E-02, 0.16038100E+00, -.64157900E-01, -.11789100E+00, -.13153800E-01, 0.30834600E+00, 0.15667600E-01, 0.18254100E-01, -.36670800E-01, -.97477100E-01, 0.92225700E+00, -.38562500E-02, -.44692500E+00, 0.43304400E-01, -.74858200E-01, -.10292300E+00, -.26365900E+00, -.50424900E-01, -.86934700E-01, -.87525600E-02, 0.80972300E-02, -.24631900E-01, 0.54781200E-01, -.41454600E-02, 0.48340900E+01, 0.47851100E+00, 0.38095100E+01, -.50690000E+00, 0.76267200E+01, 0.14015800E+01, 0.66537400E-01, -.16766800E+01, -.47263400E+01, 0.36157300E+01, -.42201800E+00, -.67523400E+00, -.12395100E+02, 0.45674800E+01, 0.49906400E+01, 0.75718300E+01, -.72189100E+01, -.64581900E+01, -.20790100E+01, 0.75556400E+01, 0.74395900E+01, -.89029200E+01, -.56672500E+01, -.69379100E+01, 0.31284700E+01, 0.26271700E+01, 0.34135500E+01, -.64802100E+01, 0.12283000E-01, -.12992300E-01, -.14033600E-01, 0.10321500E-01, 0.22391300E-01, 0.54517600E-01, 0.43480000E-01, 0.23987400E-02, 0.10243300E-01, -.12706100E-01, -.13776300E-01, 0.10859200E-01, 0.22641700E-01, 0.54378000E-01, 0.44505200E-01, 0.32143300E-02, -.44303500E+01, 0.25463100E+01, -.82657500E+00, 0.12119100E+00, -.25617900E+00, -.43112800E+00, 0.72910300E+00, 0.84887000E+00, -.95496500E+01, -.75463700E+00, 0.16200300E+01, 0.21534300E+01, 0.28810500E+00, -.33637800E+01, -.22628200E+00, 0.15042900E+01, 0.16820700E-02, -.63889800E-01, -.60973200E-01, 0.50333800E-01, 0.89474100E-01, 0.28987900E+00, 0.20938400E+00, 0.16060600E-01, -.10845600E+02, 0.48744000E+01, -.22426900E+01, -.27244700E+01, 0.10664700E+02, 0.43329200E+00, 0.74700400E+01, -.44945700E+01, 0.13116700E-02, 0.31561900E-01, 0.26604000E-01, -.19682400E-01, -.40813500E-01, -.11322200E+00, -.93237800E-01, -.73000800E-02, -.24690800E-02, -.60661600E-01, -.58566200E-01, 0.33821100E-01, 0.76123100E-01, 0.25961100E+00, 0.18850200E+00, 0.59472800E-02, 0.55792300E-01, 0.88986400E-02, -.12355000E+01, 0.73337000E+00, 0.10126900E-01, 0.43135300E-01, 0.10522200E+00, -.11277200E-01, -.11930500E+00, 0.92695400E-02, -.63482900E+00, 0.28691100E+00, -.11567100E+00, 0.45093000E+00, 0.32717100E+00, -.28730800E+00, 0.99398900E+00, 0.81464200E+00, 0.75806200E-02, 0.71024400E-02, -.19377000E-01, -.57211400E+00, -.50648600E-01, 0.54238900E+00, -.91390900E-02, 0.64857800E-02 }, { -.71402400E+00, -.29294200E+00, 0.11503300E+01, 0.52534400E+00, 0.43634900E+00, 0.25117600E+01, 0.17931500E+01, -.11357700E+01, 0.18133800E+00, -.30715200E+00, 0.61469900E-02, 0.13822300E+00, -.71696700E+00, 0.32209400E+01, -.25193700E+00, -.18060000E+01, -.13167100E+01, -.38713700E+00, 0.21051500E+00, 0.13967900E+00, 0.11634800E+00, -.15756500E+00, -.11217600E+00, 0.38040600E+00, -.66791200E-01, 0.15657400E+00, -.30621400E+00, -.50904500E-01, 0.23420400E+00, 0.13146400E+00, 0.63882900E+00, -.49242900E-01, -.34124900E+00, -.13855400E+00, -.32013500E+01, 0.18238800E+00, 0.11082100E-01, 0.19956300E+00, -.45340900E+00, -.10614000E+00, 0.19015500E-01, 0.29737100E+00, 0.20423000E+00, 0.36448300E+00, -.23391200E-01, -.35332700E+00, 0.28082600E+00, -.57694600E+00, -.43226700E-01, 0.37311800E-01, -.16713900E+00, 0.60080900E-02, 0.31955600E+00, 0.21559400E-01, 0.43020100E+01, 0.17933000E+00, 0.84907600E-01, -.20046300E+00, 0.38719300E+00, 0.57377300E+00, -.22883700E+00, 0.47990400E-02, 0.20039700E+00, -.62459000E-01, -.33380800E+00, -.25941500E-01, 0.77215100E-01, 0.20889300E+00, -.19961900E+00, 0.66884500E-01, -.24132500E+01, -.23375600E+00, -.30088800E-01, 0.11539300E+00, -.29196700E-03, 0.44623200E-01, 0.60646700E+00, -.13105200E+00, 0.63623700E+00, 0.44131500E+00, -.47655000E+00, 0.57949600E-01, -.51567000E-01, -.25153200E-01, -.86199100E-01, -.39871300E+00, 0.41317100E-02, 0.55967700E+00, -.60294200E-01, -.37784800E+00, 0.19406600E+00, -.16707500E+00, -.33725500E-01, -.18190800E+00, -.27343300E+01, 0.56375100E+00, 0.10884300E+00, 0.64573600E-02, -.39521500E+00, 0.37313200E+00, -.13866900E+00, 0.42985800E-01, 0.56536000E-01, -.14737700E+00, 0.17744200E-01, -.92736700E-01, 0.14975500E+00, -.53170900E+00, -.10552900E+01, 0.95171000E+01, -.11220200E+01, -.39512000E+00, 0.76988800E+01, 0.10670400E+02, 0.14829000E+02, 0.13965000E+02, -.20466300E+02, 0.81342900E+00, -.41307500E+02, 0.17602700E+02, 0.19867400E+01, 0.74692100E+01, 0.63515100E+01, 0.54691500E+01, -.14545000E+02, 0.80320300E+01, 0.17211300E+02, 0.52227400E+01, 0.12415200E+01, 0.31233200E+02, 0.47607000E+01, 0.10530100E+02, -.10218000E+02, 0.66472100E+01, -.58813700E+01, 0.12854300E+02, 0.34368800E-01, -.81973100E-01, -.59782700E-01, 0.83247100E-01, 0.74461200E-01, 0.98033500E-01, -.42935500E-01, 0.37500900E-01, 0.32977300E-01, -.80598600E-01, -.62288600E-01, 0.82215900E-01, 0.76859900E-01, 0.99584500E-01, -.40847000E-01, 0.34600000E-01, 0.13773300E+01, 0.34196200E+01, -.13856200E+02, -.71266400E+01, 0.12763800E+02, 0.14754700E+02, 0.18861100E+02, -.85763900E+01, -.26835600E+02, 0.18167100E+02, 0.50047300E+01, 0.41829900E+01, 0.28819800E+01, -.31425300E+01, 0.67920300E+01, 0.38436800E+01, -.13733100E+00, -.21734100E+00, -.39848100E+00, 0.28267100E+00, 0.54198300E+00, 0.40909400E+00, 0.22576500E+00, 0.33909500E-01, -.32971500E+02, 0.51276500E+01, -.15826700E+01, -.27843800E+01, 0.16777800E+02, -.12871400E+02, 0.32452900E+01, -.83031300E+00, -.25321800E-01, 0.12314100E+00, 0.14688800E+00, -.13520100E+00, -.18805600E+00, -.20317700E+00, -.13079900E-02, -.32322700E-01, -.82126800E-01, -.19022600E+00, -.35197500E+00, 0.23359400E+00, 0.46752300E+00, 0.36764000E+00, 0.19609100E+00, 0.18127200E-01, 0.13118100E+00, -.10237300E+00, 0.47292200E+01, 0.21676500E+00, -.11022900E+00, -.49472100E+00, 0.40126700E-01, 0.11852400E+00, -.11205600E+00, -.10057600E+00, 0.21830600E+00, 0.11130500E+01, 0.77531300E+00, 0.58555000E+00, -.46056300E+01, 0.90116100E+01, 0.13116500E+01, -.44163100E+01, -.65379100E-01, -.69445100E-01, 0.51890300E+01, 0.32184100E+00, -.28760100E+00, 0.15969800E+01, 0.10724900E+00, -.13796400E+00 }, { 0.11844500E+01, 0.34129400E+00, 0.23857500E+00, -.35204000E+00, -.10179600E+01, -.41665800E+00, 0.19711600E+01, -.19899800E+00, 0.19072200E-01, 0.28566300E+00, -.18572600E+00, -.79201100E+00, -.84344500E+00, 0.16901200E+01, 0.43718700E+00, -.32316900E+01, -.10776800E+01, -.53757700E+00, 0.12731300E+01, 0.55896600E+00, -.11890200E+01, 0.20901000E+00, 0.14223400E+01, -.65719200E+00, 0.15022700E+00, -.34939400E+00, 0.31599300E+00, 0.26705100E+00, -.33253200E+00, -.25790000E+00, -.16321500E+01, 0.19201600E+00, -.34955600E+00, 0.26795800E+00, -.63154100E+01, 0.25489500E+00, -.88278300E-01, -.48352400E+00, -.35966500E+00, -.73351800E-01, -.20418400E+00, -.76045300E+00, 0.27765400E+01, 0.89008100E-01, 0.55546000E+00, -.66820700E+00, 0.18298300E+00, -.13986000E+01, -.17677600E-01, -.17599800E-01, -.69161800E-01, 0.63073700E-01, 0.89170700E-01, -.15496300E-01, 0.20858100E+01, 0.17629000E+00, 0.47127100E-01, -.84773600E+00, -.69912600E-01, 0.95147500E+00, 0.18022400E+00, 0.12629200E+00, 0.82622700E-01, 0.40877700E+00, 0.59673300E-01, -.70213300E-01, -.12083400E+00, -.12482100E+00, -.67777100E-01, 0.53674400E-01, -.22865800E+01, -.40037600E+00, 0.10988600E+00, 0.49785500E-03, -.46829600E+00, -.40397500E-01, -.14778000E+00, 0.70487200E-01, 0.52247400E+00, 0.11038300E+01, 0.13892600E+00, -.13758400E+00, -.17783500E+00, 0.24378800E-01, 0.76103500E-01, 0.26877700E+00, -.21116500E+00, -.47123500E+00, -.28613300E+00, -.27561500E+01, 0.46422500E+00, 0.48080600E-01, 0.28820900E-01, -.49640900E+00, 0.28831500E+00, 0.32374600E+00, -.71680500E+00, -.79928900E-01, -.17661900E+00, 0.50754300E+00, -.32997900E-01, -.73549100E+00, 0.27946700E-01, 0.10010000E+00, 0.66041500E-01, -.11328000E+00, -.45310800E+00, -.12488800E+00, 0.23667600E+00, -.39482600E+00, -.10535000E+02, -.18604900E+01, -.40610300E+02, -.50117100E+01, 0.20714400E+02, 0.17833200E+02, -.19420500E+02, -.14466400E+02, 0.19500100E+02, 0.21973700E+02, 0.24471300E+02, -.29472500E+02, -.77522900E+01, -.11013700E+02, 0.19698300E+01, 0.43507800E+01, 0.46750700E+00, -.12886700E+02, 0.10560800E+03, -.60094600E+02, -.24374600E+02, -.22396100E+02, -.34033500E+01, 0.65744600E+02, 0.12366600E+02, -.22120700E+02, -.39112900E-01, -.86942800E-01, 0.60759500E-01, -.86988300E-01, 0.27301600E+00, -.22841500E+00, 0.16162900E+00, -.16767600E+00, -.44318700E-01, -.87851800E-01, 0.63332900E-01, -.79829300E-01, 0.27199000E+00, -.23370700E+00, 0.15473900E+00, -.16137000E+00, -.14750000E+03, 0.73058700E+02, 0.28606100E+02, 0.38710500E+02, 0.11380600E+02, -.36047500E+02, -.94123100E+01, 0.36029500E+02, 0.47679400E+02, -.27492000E+02, -.71480700E+01, -.10563600E+02, -.49269100E+01, 0.14945300E+02, 0.89298400E+01, -.10479400E+02, 0.18922900E+00, -.55918900E+00, 0.23527500E+00, -.33742700E+00, 0.98544000E+00, -.89978700E+00, 0.32929900E+00, -.77483500E+00, -.43000200E+02, 0.80559000E+02, 0.37203100E+02, 0.35938000E+02, -.39631200E+02, -.30449800E+02, 0.27866800E+02, 0.33983500E+02, 0.62997200E-01, 0.23123900E+00, -.13543500E+00, 0.10423300E+00, -.44867600E+00, 0.45608200E+00, -.24269000E+00, 0.28191000E+00, 0.15426300E+00, -.53994600E+00, 0.21313900E+00, -.27507600E+00, 0.82620800E+00, -.79043700E+00, 0.31875900E+00, -.65954600E+00, -.14417900E+00, 0.28564700E+00, -.38587300E+01, 0.26931600E+01, 0.36358300E+00, 0.12576900E+01, 0.13847800E+01, -.42921500E+00, -.13764000E+01, 0.31930000E+00, -.79811100E+01, -.32469900E+00, -.60358400E+00, 0.21785500E+01, 0.37129400E+01, -.25398700E+01, 0.21088100E+01, -.57570600E+01, 0.19516600E+00, 0.18477800E+00, -.63975400E+00, -.56725100E+00, 0.93715800E+00, -.10851000E+01, -.32143300E+00, 0.53029700E+00 }, { 0.10879300E+01, 0.48476000E+00, -.20188000E+01, -.11809900E+01, -.14484500E+01, -.45478200E+01, -.23293000E+01, 0.17516100E+01, -.12503800E+01, -.45062900E+00, 0.48652400E+00, -.12101400E+01, -.15161500E+00, -.47258400E+01, 0.30751300E+01, 0.37583500E+01, 0.37493000E+01, -.18373600E+00, -.54117100E+00, -.56432000E+00, 0.19957000E-01, 0.77353400E+00, -.31805200E+00, -.25832700E+00, -.12985700E+00, -.67966400E-01, 0.16395600E+00, 0.17239900E+00, 0.12351600E+00, 0.88612600E-01, -.40075700E+00, -.21534000E+00, -.55878500E-01, -.24052200E+00, -.66304100E+01, 0.10064500E-01, 0.37861700E-01, -.26587600E+00, -.32853400E+00, -.21385900E+00, -.11686800E+00, -.83141900E-01, 0.75707600E+00, 0.24786300E+00, 0.30833500E+00, -.17697600E+00, 0.25745400E+00, -.16999300E+01, -.53933800E-01, 0.74967500E-01, -.16038300E+00, 0.14524200E-01, 0.50562500E+00, 0.27476300E-01, 0.37847000E+01, 0.28245000E+00, 0.57396300E-01, 0.11149800E-01, 0.51639900E+00, 0.88260000E+00, 0.26766200E+00, 0.12539100E+00, -.20841400E+00, -.69009100E+00, 0.12037400E+00, 0.30159200E-01, -.35188100E-01, 0.35216600E+00, 0.19784500E+00, 0.16349100E-01, -.26715100E+01, 0.18276300E+00, 0.13842500E+00, -.93524600E-01, 0.63843300E-01, 0.86376500E-01, 0.67513500E+00, -.75429900E-01, 0.15069600E+01, 0.37165100E+00, -.89273200E-01, 0.17721800E-01, 0.14123500E+00, -.47642400E-01, -.16464000E+00, -.16688200E+00, 0.28787600E-01, 0.28515800E-01, -.14006400E+00, -.18809200E+01, 0.52095900E+00, -.17475900E-01, 0.76012000E-01, -.13256000E+00, -.18372300E+01, 0.62390700E+00, 0.64570900E+00, 0.86125300E-02, -.36600900E+00, -.69438500E+00, 0.11862000E+00, 0.63205700E+00, 0.23219300E+00, 0.37432100E-01, -.50250700E-01, -.47326900E+00, 0.10288400E+00, -.59035900E+00, 0.13778100E+00, 0.64387600E-01, 0.50294000E+00, 0.54282300E+01, 0.51834200E+02, 0.12220300E+02, -.12659400E+02, -.69507700E+01, -.30568900E+00, 0.10074300E+02, -.14442400E+02, -.11325400E+02, -.20235900E+01, 0.14862200E+02, 0.31105600E+01, 0.16145300E+01, -.48091900E+00, 0.23332500E+01, 0.64129700E+01, 0.18243500E+00, -.39001000E+02, 0.42253300E+02, 0.14716900E+02, 0.17151100E+02, -.26537100E+01, -.29663600E+02, -.10323400E+02, 0.17567400E+02, 0.14783500E-01, 0.12447900E+00, -.73047800E-01, 0.62011800E-01, -.49797200E-01, 0.19736700E-01, -.95692500E-01, 0.13267200E+00, 0.21589500E-01, 0.12520400E+00, -.75572700E-01, 0.55288400E-01, -.48382000E-01, 0.26682000E-01, -.94084800E-01, 0.12595200E+00, 0.79712700E+02, -.42770200E+02, -.12882800E+02, -.17457500E+02, -.88471600E+01, 0.14651800E+02, -.51478200E+01, -.17131100E+02, -.36641300E+02, 0.18154400E+02, 0.77832000E+01, 0.71867900E+01, 0.40854000E+01, -.11554000E+02, 0.66242800E+01, 0.80377000E+01, -.56057000E-01, 0.57174100E+00, -.27888400E+00, 0.11822100E+00, -.11888200E+00, 0.15425100E+00, -.24781000E+00, 0.46225300E+00, -.63452700E+00, -.31192100E+02, -.91437300E+01, -.10682200E+02, 0.13297500E+02, 0.98001600E+01, -.10273300E+02, -.34311100E+01, -.45235700E-01, -.29265900E+00, 0.14578600E+00, -.50270800E-01, 0.49921600E-01, -.91482600E-01, 0.15039600E+00, -.19338200E+00, -.61213400E-01, 0.55768600E+00, -.24024100E+00, 0.95345400E-01, -.79836000E-01, 0.13307700E+00, -.22548900E+00, 0.39376400E+00, 0.49090500E-01, -.14971400E+00, 0.48720900E+01, -.11169200E+01, -.20620900E+00, -.94179400E+00, -.81302700E+00, 0.25311500E+00, 0.80476300E+00, -.18221400E+00, 0.32157900E+01, 0.10233700E+01, 0.51066900E+00, -.13363300E+01, -.30809300E+01, -.11578300E+01, -.85241000E+00, 0.68550500E+00, -.12156300E+00, -.10300900E+00, -.14452800E+01, 0.29241400E+01, -.39710200E+00, -.67083400E+00, 0.17739600E+00, -.31216600E+00 }, { 0.10816200E+01, 0.40519000E+00, -.10450800E+01, -.73495300E+00, -.66702700E+00, -.52985900E-01, 0.52863700E+01, 0.17837400E+01, -.26534200E+00, 0.36181100E+00, 0.51799000E-01, -.10857200E+01, -.40250600E+00, -.25159500E+01, 0.13508700E+01, 0.84491700E+00, -.42652900E+00, 0.28192600E+01, 0.16725200E+01, 0.14168500E+00, -.14365000E+01, -.29231500E+00, -.47762000E+00, -.65449200E+00, -.12209100E+00, -.22175800E-01, -.81393900E-01, -.11833000E+00, -.85069100E+00, 0.16866500E+00, 0.23537900E+00, -.27811200E-01, 0.32598000E+00, -.36127900E+00, -.23727000E+01, -.29730800E+00, -.12240700E-02, -.57997300E+00, -.83426300E+00, -.15279200E+00, -.29899300E+00, 0.42667700E+00, 0.19310900E+01, -.84488000E+00, -.41836400E-01, 0.10217800E+00, -.50644300E-01, -.18539800E+01, 0.90989900E-01, -.10979400E+00, 0.68654500E-01, -.29899600E+00, -.51649300E+00, 0.14206300E+00, -.37691300E+01, -.59556000E+00, 0.47067100E-01, -.60660400E+00, -.13056500E+01, -.34140800E+00, 0.41475500E+00, 0.27085700E-01, -.29972100E+00, -.10262600E+01, 0.25784600E+00, 0.63444400E-01, 0.12120900E-02, 0.37367800E+00, 0.29330700E+00, 0.66160200E-02, -.33699600E+01, 0.36025700E+00, 0.53217700E+00, -.10105200E+00, -.11343800E-01, -.27146400E+00, 0.22674300E+00, 0.37425500E-01, 0.29175200E+00, 0.17274900E+01, -.31066800E+00, -.35000100E-02, -.99124400E+00, 0.15875100E+00, -.22419900E+00, 0.33698100E+00, -.26803800E+00, -.21463500E+00, -.22026000E+00, 0.26885000E+01, -.13791500E+01, 0.66579200E-01, -.19949000E-01, 0.18777400E+00, -.34634200E+01, -.14079400E+00, 0.15198000E+01, 0.94264800E-01, -.44647600E+00, -.17104700E+01, 0.20937400E+00, -.14181000E-01, 0.45301200E+00, -.16008700E+00, -.29912000E-01, -.22269700E+00, 0.73631200E-01, 0.25888500E+00, -.58114400E+00, 0.42106900E+00, -.60136200E+00, -.29861800E+00, 0.60121400E+02, -.21187100E+02, -.14524300E+02, -.12954700E+02, -.21429700E+01, 0.24610700E+02, 0.21885900E+02, -.11429100E+02, 0.94428000E+01, -.10004100E+02, -.23759900E+01, -.68567200E+01, 0.59619700E+01, 0.40841900E+01, -.60272700E+01, -.87850400E+01, -.67229200E+01, -.33472800E+01, -.74556600E+01, -.23434500E+00, 0.76320400E+01, 0.10136400E+01, 0.52283200E-01, -.21969200E+01, 0.19392200E-01, 0.88289400E-02, -.67392600E-02, 0.38706000E-01, 0.46229700E-01, -.83000700E-01, -.80001900E-01, 0.74951700E-01, 0.19441700E-01, 0.96957100E-02, -.92160700E-02, 0.37124600E-01, 0.47173300E-01, -.79880300E-01, -.81246100E-01, 0.72502700E-01, -.75948400E+01, 0.23952800E+01, 0.74551700E+00, 0.19451500E+01, 0.64848100E+00, -.28056400E+01, -.91483300E+01, 0.14451000E+01, 0.13919300E+01, 0.12676600E+02, 0.23843700E+01, -.12258600E+01, 0.18077700E+01, 0.31762800E+01, 0.57648600E+01, -.42385000E+00, -.74863300E-02, -.28880700E-01, 0.81980300E-01, 0.12496600E+00, 0.16845000E+00, -.26860200E+00, -.43344300E+00, 0.26871300E+00, -.11154400E+02, 0.38184600E+02, 0.69743000E+01, 0.57196700E+01, -.83054900E+01, -.61807700E+01, 0.19731500E+00, 0.67719600E+01, -.14886000E-01, -.26055900E-01, 0.36685700E-02, -.62971900E-01, -.89164900E-01, 0.12130900E+00, 0.16701700E+00, -.12448600E+00, -.15196400E-01, -.12489300E-01, 0.71842000E-01, 0.11107700E+00, 0.15188900E+00, -.22493600E+00, -.36750700E+00, 0.23763300E+00, 0.80816200E-01, -.93185300E-01, -.68634900E+00, -.45852300E+00, -.11387200E+00, -.13247300E+00, -.88284100E-01, 0.13253400E+00, 0.34631500E-01, -.98640200E-01, -.19605800E+01, 0.80552300E+00, -.38727500E+00, -.27171200E-01, 0.63191600E+00, -.26257700E+01, -.80178300E+00, -.97131800E+00, -.63601400E-01, -.59130800E-01, -.16332600E+01, 0.11426300E+01, -.58216700E+00, -.31098700E+00, 0.10422800E+00, -.15232000E+00 }, { 0.98804600E+00, 0.60896400E+00, -.30372100E+00, -.22292600E-01, 0.30412100E+00, 0.66699800E+00, 0.53434800E+01, 0.18858100E+01, -.24953900E+00, 0.31842000E+00, 0.69323700E-01, -.24576400E+00, 0.31683400E+00, -.31993200E+01, 0.10758200E+01, 0.27106400E+01, 0.16747600E+01, 0.11907700E+01, 0.50214600E+00, -.60791800E+00, -.65966300E-01, 0.12200400E+00, 0.30239800E-01, -.34974400E+00, 0.51880400E-01, -.24106400E-02, 0.74053500E+00, 0.26298700E+00, 0.45285300E-01, 0.16391600E+00, 0.22453600E+01, -.26771300E+00, 0.17546000E-02, -.16068200E+00, -.17139100E+01, -.34119700E+00, 0.13466700E+00, -.49873000E-01, -.45357500E+00, 0.48686100E-01, -.15948000E+00, -.39113800E-01, -.81966400E+00, -.26239800E+00, -.38341600E+00, 0.18624000E+01, -.40178700E+00, -.69404400E+00, -.87334000E-02, -.41527000E-01, -.21278200E+00, -.63444000E-01, 0.12977200E+00, 0.63917500E-01, -.22741800E+00, -.35843000E-01, 0.86434100E-01, 0.12057100E+01, 0.29485900E+00, -.44099500E+00, -.93140700E+00, -.26797700E-01, 0.22165200E+00, -.51163300E+00, -.55420700E+00, 0.23781800E-01, 0.72093400E-01, 0.29582500E+00, 0.88441400E-01, -.40504800E-01, 0.26704600E+00, 0.17474000E+00, 0.39424700E+00, -.14870400E+00, 0.20081000E+00, -.59863800E-01, -.10384000E+01, 0.36985300E+00, 0.39599400E+00, -.82143700E+00, 0.12161100E+01, -.23896500E+00, -.94573100E-01, 0.18081800E-01, -.17572100E+00, 0.22765300E+00, 0.11694700E-01, -.17990600E+00, 0.33870300E-01, 0.22431700E+01, -.59626800E+00, -.29722800E-01, 0.97662100E-01, -.15403000E-01, -.74687200E+00, 0.27241700E+00, 0.34654600E+00, 0.24624100E-01, -.22284500E+00, -.14588000E+01, 0.23249200E-01, 0.72954700E+00, 0.32911800E-01, 0.23832800E+00, -.30390200E-01, -.11791300E+00, 0.11195100E+00, -.57229400E-01, 0.11339000E+01, 0.24826300E+00, -.29866900E+00, -.63789500E-01, -.12670800E+00, 0.38370800E+02, 0.62795500E+01, 0.11392500E+02, -.47902700E+01, -.61029300E+00, 0.53186600E+01, 0.14820000E+02, -.14560000E+01, -.46945700E+01, 0.10320400E+01, 0.35335600E+00, 0.59248200E+01, -.68442600E+01, -.44751800E+01, 0.66489300E+00, 0.19034600E+02, 0.11675600E+02, -.15437700E+02, -.62232200E+01, 0.63626900E+01, 0.73489700E+01, -.32170500E+01, -.50319600E+01, 0.31202300E-01, 0.87866000E-01, -.12646400E+00, -.50590900E-02, 0.20473900E-01, -.13122500E+00, -.15033700E-01, 0.47402200E-02, 0.31111400E-01, 0.88218400E-01, -.12533100E+00, -.54384300E-02, 0.20301500E-01, -.12718400E+00, -.17958900E-01, 0.42068200E-02, -.21172100E+02, 0.57369900E+01, 0.18669700E+01, 0.50615700E+01, 0.71025400E+00, -.32722500E+01, -.42242200E+01, 0.51973200E+01, 0.21774100E+02, -.15760100E+02, -.35796900E+01, -.41212800E+01, -.12955700E+01, 0.97233100E+01, 0.69637100E+01, -.23444400E+01, -.25885200E-01, 0.22169000E+00, -.39098400E+00, 0.26424300E-01, -.91842000E-01, -.43817900E+00, -.19301900E+00, 0.46747900E-01, -.40801200E+02, 0.51453400E+02, 0.17116400E+02, 0.13987400E+02, -.19279800E+02, -.16733400E+02, 0.33782700E+01, 0.90194100E+01, -.20648100E-01, -.14968100E+00, 0.20772000E+00, -.31233900E-02, -.11006400E-01, 0.19903800E+00, 0.56315300E-01, -.21305600E-01, -.36418700E-01, 0.19814300E+00, -.34370200E+00, 0.23030600E-01, -.72792300E-01, -.36216600E+00, -.14880300E+00, 0.45971600E-01, 0.13575600E+00, 0.26046500E-01, -.14677700E+01, -.38468000E+00, 0.11825600E-01, -.63453600E+00, -.41913800E+00, 0.45380500E-03, 0.51106500E+00, 0.14186700E-01, -.19712100E+01, 0.13380400E+00, -.80994600E-01, -.26206800E+00, 0.13595100E+01, 0.21169500E+01, -.65304700E+00, -.99324900E+00, 0.63020700E-02, 0.17545400E-01, -.14067800E+01, 0.21041300E+01, -.47761800E-01, 0.88986300E+00, -.19256200E-01, -.10355700E-01 }, { -.13721100E+01, -.17447200E+01, 0.10571400E+01, -.22351800E-01, 0.43249300E+00, 0.11177700E+01, 0.41055700E+00, -.16221300E+01, 0.18542200E+00, 0.64025700E+00, -.18701300E+00, -.54363500E+00, -.14620300E+00, 0.65726700E+00, -.75979500E+00, -.25379200E+01, -.24600100E+01, -.95683500E+00, -.13052500E+00, 0.43728200E+00, 0.54847000E+00, -.40425900E+00, -.86174700E+00, 0.97109700E+00, -.19976400E+00, 0.40891900E+00, -.72225500E+00, -.34574300E+00, 0.72742300E+00, 0.33070500E+00, 0.18260000E+01, -.97977400E-01, -.22926500E+00, -.54316100E+00, -.22359100E+01, 0.71183300E-01, 0.70390900E-01, -.52414600E-01, -.79135500E+00, -.11852200E+00, -.14513600E+00, 0.87177200E+00, -.10443500E+01, 0.78571800E-01, -.32758600E+00, -.26275200E+00, 0.19748400E+00, -.36000900E+00, -.28963700E-02, 0.78148900E-01, -.46085300E-01, -.14743400E+00, 0.17501400E+00, 0.95737600E-01, 0.18360000E+01, -.12803900E+00, 0.60595600E-01, -.63429800E+00, -.12895400E+00, -.22640400E+00, -.48646100E+00, -.21309600E+00, -.91011000E-01, -.65476400E+00, -.13524600E+00, 0.31306400E-01, -.27671000E+00, 0.41628100E+00, 0.23720700E+00, 0.47248900E-01, -.19052700E+01, 0.39341200E+00, 0.10537800E+00, -.15816000E+00, 0.16280700E+00, -.20210100E+00, -.10224000E+01, 0.52182900E+00, -.42449600E+00, 0.11013800E+01, -.47125000E+00, -.42484100E+00, -.19384500E+01, -.11590400E-01, 0.66370600E+00, -.15173200E+00, -.14914000E+00, -.94244400E-01, -.10977400E-01, 0.21593700E+01, 0.42352600E+00, -.77030500E-01, -.38463600E-01, -.49947100E+00, 0.16452600E+01, 0.15062900E+01, -.59487100E+00, -.95336000E-01, 0.31334600E-01, 0.14996300E+01, -.50183200E+00, 0.70920100E+00, -.59372500E-01, -.48744000E-01, -.13524600E+00, -.63934800E+00, 0.26048100E+00, -.22191100E-01, 0.19005100E+01, -.11325500E+01, 0.11010100E+00, -.10253400E+00, -.38016500E+00, -.51507900E+00, 0.26425800E+02, 0.30135900E+02, -.22992400E+02, -.14825200E+02, -.20025900E+02, 0.37606000E+02, 0.26655300E+01, -.15448700E+02, 0.17955500E+02, 0.13488700E+02, -.22469800E+02, 0.68668500E+01, 0.21268300E+01, 0.10893500E+02, 0.27715100E+02, 0.39784000E+02, -.10873600E+02, 0.76319100E+01, 0.27384100E+00, 0.20210000E+01, -.12850600E+02, 0.86489100E+01, 0.98753300E-01, 0.10072100E+01, -.48551900E+00, 0.12107400E+00, -.78406800E-02, -.19405300E-01, -.84556600E-01, 0.45295200E-01, 0.99145800E-01, 0.10056800E+01, -.49250900E+00, 0.11675400E+00, -.66359600E-02, -.12160800E-01, -.84293600E-01, 0.38009900E-01, 0.33395000E+02, 0.74874100E+01, -.17450400E+02, -.36835000E+01, -.70870700E+01, -.30965400E+00, -.12064700E+02, -.67846500E+01, -.46675200E+01, 0.20452000E+02, 0.20132900E+01, -.96594700E+00, 0.25684600E+01, 0.41435400E+01, 0.17577800E+02, 0.11429200E+01, -.79760900E-01, 0.44171300E+01, -.20400500E+01, 0.45728000E+00, -.11061500E+00, 0.12604800E+00, -.20780200E+00, 0.47889300E-01, -.80490800E+02, 0.10508400E+03, 0.81275600E+01, 0.97653700E+01, -.61778300E+01, -.22705300E+02, -.28791100E+01, 0.79522800E+01, -.74076800E-01, -.19490400E+01, 0.93220600E+00, -.20927300E+00, 0.15943200E-01, -.43472800E-01, 0.12244200E+00, -.42052200E-01, -.10665400E+00, 0.38827600E+01, -.17747600E+01, 0.39729200E+00, -.82061200E-01, 0.11744800E+00, -.15715300E+00, 0.47992700E-01, 0.40976600E+00, 0.24496100E+00, 0.55969900E+01, -.81161700E+00, 0.81229600E-01, -.26634400E+01, -.23431700E+01, 0.41813500E-01, 0.23150700E+01, 0.78906800E-01, -.20418900E+01, 0.25353500E+01, -.90605100E-01, 0.95811300E+00, -.58205300E+01, 0.12340100E+02, 0.19746200E+00, -.28114800E+01, 0.22195700E-01, 0.13928400E+00, -.34614100E+01, 0.39269900E+01, 0.23182000E-01, 0.34814800E+01, -.16717500E+00, -.14082100E+00 }, { -.13986700E+01, -.52463300E+00, 0.21224600E+01, 0.66086900E+00, 0.74353800E+00, 0.41925700E+01, 0.43929900E+01, -.39688200E+00, 0.36117600E+00, -.10090400E+01, 0.17355100E+00, 0.39435900E+00, -.14945800E+01, 0.58885000E+01, 0.64181100E+00, -.20429800E+01, -.18658300E+01, -.54368600E+00, 0.16774300E+01, -.17741600E+00, 0.41957300E+00, -.28487000E+00, 0.14178300E+01, -.73477700E+00, -.12973000E+00, -.29622100E+00, -.14859000E+00, -.15254500E-02, 0.15983600E+01, -.25484500E+00, -.38434000E+00, 0.75316600E+00, -.12499300E+01, 0.51960200E-01, -.85262700E+01, 0.10846900E+01, -.13314200E+00, 0.23492400E+00, -.99448600E+00, -.71121400E-01, 0.12385600E+00, 0.45080900E+00, 0.27123200E+00, 0.18657000E+00, 0.42495500E-02, -.73224200E-01, 0.21637500E+00, -.14697500E+01, -.36345400E-01, 0.95778000E-01, -.34441400E+00, -.14483100E+00, 0.66684800E+00, 0.12958800E+00, 0.21155900E+01, 0.11012100E+00, 0.11474100E+00, 0.98300700E+00, 0.44105900E+00, 0.44897300E+00, 0.10755800E+00, 0.24980300E-01, -.23630800E+00, -.48342300E+00, 0.17830400E+00, 0.71674000E-01, -.94411200E-01, 0.98076500E-01, 0.29188600E+00, -.23332800E-01, -.30824700E+00, 0.41537600E+00, 0.37756200E-02, -.12875700E+00, -.26774000E-01, 0.14642200E+00, 0.82365300E+00, -.29659300E+00, 0.56162400E+00, 0.15189600E+00, 0.14068000E+00, 0.16614600E+00, 0.29004400E+00, 0.16121300E-01, -.32516500E+00, 0.32498100E+00, 0.13088900E+00, -.22366100E+00, -.64425100E-01, 0.29237500E+01, -.70857900E+00, 0.22324700E+00, -.42965300E+00, 0.44436200E+00, 0.21595300E+01, -.97636800E+00, 0.19167900E+00, 0.11657600E+00, 0.15034100E+00, 0.17874500E+01, -.90583600E+00, 0.17994900E+00, -.15692100E+00, -.12384500E+00, -.59941100E-01, -.54745800E+00, 0.18687600E+00, -.22258200E+00, -.49927000E+00, -.99058600E-01, 0.87285500E+00, 0.21130900E+00, -.90988600E+00, -.10518600E+01, -.70983300E+00, 0.33167800E+02, -.39999200E+01, -.11550300E+02, -.26358500E+02, 0.39350300E+02, 0.49620400E+01, -.25707700E+02, 0.12911700E+02, 0.15240000E+02, -.48368100E+01, -.27468000E+01, -.16506000E+01, 0.17714100E+02, -.67116800E+02, 0.39352300E+02, 0.33827500E+01, 0.26746300E+02, 0.11889700E+02, -.48594300E+02, -.15599300E+02, 0.25618600E+02, 0.21606400E+00, 0.80488600E+00, -.27932200E+00, 0.67152000E-01, -.53624800E-02, 0.23062500E-01, -.24528700E+00, 0.13080900E+00, 0.21329400E+00, 0.80438900E+00, -.28777700E+00, 0.57942500E-01, -.60694000E-02, 0.35950100E-01, -.23992300E+00, 0.11968100E+00, 0.62654900E+02, -.25933000E+01, -.17800600E+02, -.12104900E+02, -.12435600E+02, 0.16745600E+02, -.19059100E+02, -.11441500E+02, 0.18816100E+02, 0.64923700E+01, -.33088800E+01, -.49597300E+01, 0.38409200E+01, 0.20151500E+02, 0.22023200E+02, -.48667800E+00, -.16410100E+00, 0.36972000E+01, -.96657800E+00, 0.20953900E+00, -.10019900E+00, 0.29554800E+00, -.60528400E+00, 0.42416100E+00, -.15421500E+03, 0.14114500E+03, 0.12506700E+02, -.10410000E+01, 0.16063900E+02, -.46678000E+02, -.19462300E+02, -.55943800E+01, -.14051300E+00, -.15974600E+01, 0.53625400E+00, -.89115600E-01, 0.74011400E-02, -.15470000E+00, 0.35050000E+00, -.20243500E+00, -.22806300E+00, 0.32698500E+01, -.87803000E+00, 0.17154900E+00, -.44900500E-01, 0.30166500E+00, -.48813000E+00, 0.37494800E+00, 0.90231200E+00, 0.58488000E-01, 0.68085400E+01, 0.43821900E+00, -.10801900E+00, -.14556500E+01, -.18042600E+01, 0.23731400E+00, 0.16730100E+01, -.86810000E-01, -.96219200E-01, 0.47481100E+01, -.79289700E+00, -.45235800E+00, -.69225800E+01, 0.18874300E+02, 0.55267300E+00, -.73921300E+00, -.69799600E-01, 0.27224100E-01, -.32536000E+01, 0.34751000E+01, -.94865000E+00, 0.81080300E+01, 0.21950200E-01, -.35564200E+00 }, { 0.18875000E+01, 0.63209800E+00, -.15768500E+01, -.78587400E+00, -.57080900E+00, -.41583900E+01, -.37332200E+01, 0.11838000E+01, -.50882000E+00, 0.73550800E+00, 0.55283600E-01, -.19571800E+00, 0.11895700E+01, -.63473100E+01, 0.89384200E+00, 0.44890000E+01, 0.24766900E+01, 0.18827500E+01, 0.28528200E+00, -.99206900E+00, 0.18060300E+00, 0.15912700E+00, -.91549500E-01, -.68865200E+00, 0.53392500E-01, -.21769100E+00, 0.69449200E+00, 0.23423100E+00, -.12337600E+01, -.13769300E+00, -.25609200E+01, 0.10565400E-01, 0.81705200E+00, 0.18610800E+00, 0.38366700E+01, -.56210100E+00, -.68937500E-02, -.25772100E+00, -.24974100E+00, 0.12608600E+00, -.34524600E+00, -.23452700E+00, -.10904100E+01, -.55182000E-01, -.11719700E+00, 0.19341000E+01, -.35822200E+00, -.16965400E+01, 0.38529600E+00, 0.13156500E+00, -.60393900E-01, -.14048200E+00, 0.10722100E+01, -.24457800E+00, -.86170000E+01, 0.12326000E+00, 0.10404600E+00, -.11447700E+01, -.11197700E+00, 0.61064900E+00, -.23218200E+01, 0.10506600E+00, 0.48111700E+00, -.21602000E+01, -.15975300E+01, 0.36921900E+00, -.33804700E+00, 0.79316300E+00, 0.25471600E+01, -.33147200E+00, -.55443400E+00, 0.20406900E+01, 0.44141500E-01, -.70520000E-01, 0.27832900E+00, -.23327500E+00, -.27293300E+00, 0.10700800E+00, -.32952400E+00, 0.76184800E+00, 0.81993000E+00, 0.25970100E+00, -.57121300E+00, -.69025100E-02, -.31249300E+00, 0.17274100E+01, 0.32274600E+00, -.13532500E+01, 0.23664300E+00, 0.21200300E+01, -.75189300E+00, 0.17342800E+00, 0.36736400E+00, 0.10196600E+01, -.37199100E+01, -.50470200E+00, 0.28353300E+01, -.12991000E+00, -.87797100E-01, -.58141900E+00, 0.83442500E+00, 0.20171400E+01, 0.26990200E+00, 0.33499600E+00, -.87710900E-01, -.44307100E+00, 0.90358400E+00, -.67084000E+00, -.22680100E+00, -.94351500E+00, -.10475800E+00, 0.79483900E+00, 0.12938700E+01, 0.11316500E+01, -.40507100E+00, 0.24393300E+00, -.25667800E+02, -.79395400E+00, -.27292500E+02, -.16321000E+01, -.62214800E+01, 0.85183600E+00, -.86002400E+00, 0.73153600E+01, -.37357300E+02, 0.71195500E+01, 0.30319800E+01, 0.10754000E+02, 0.21962900E+03, -.33299700E+02, -.27629000E+02, -.29617800E+02, -.40030500E+02, 0.10346500E+03, 0.22829100E+01, -.21809700E+02, 0.84970900E+00, -.38220300E+00, -.10251700E+00, 0.12315300E+00, -.16851500E-01, 0.66449600E+00, 0.41845000E+00, -.10463200E+00, 0.84327800E+00, -.38325200E+00, -.89473900E-01, 0.13352500E+00, -.12722700E-01, 0.65094200E+00, 0.41815100E+00, -.94963000E-01, 0.28675400E+02, 0.17485100E+02, -.17785300E+02, -.85600300E+01, 0.42917400E+01, 0.31188600E+02, 0.28062700E+02, -.78541700E+01, 0.15160700E+02, -.14158200E+02, -.70282600E+01, 0.59502800E+00, -.84796900E+01, -.40348100E+00, -.41136100E+01, -.55456100E+00, 0.34323900E+01, -.14189200E+01, -.31821300E+00, 0.58658800E+00, 0.17362800E+00, 0.22215100E+01, 0.16475500E+01, -.37925500E+00, 0.26276600E+02, -.40199800E+02, 0.33044600E+02, 0.35287100E+02, -.17009400E+02, -.37551700E+01, 0.30355100E+02, 0.36524800E+02, -.16068200E+01, 0.77637900E+00, 0.10902900E+00, -.30674100E+00, 0.10046400E-01, -.10860900E+01, -.73584400E+00, 0.11928900E+00, 0.31465000E+01, -.13627100E+01, -.27311200E+00, 0.54534700E+00, 0.86950600E-01, 0.19440500E+01, 0.13734000E+01, -.28723700E+00, 0.26417100E+01, 0.13533700E+00, -.36189400E+01, -.41409200E+01, 0.20522000E+00, 0.46773900E+00, 0.84823000E+00, -.25516100E+00, -.97196600E+00, 0.17886500E+00, 0.21372300E+01, -.46823700E+01, -.12560400E+01, -.11916300E+00, 0.42164000E+01, -.72937600E+01, 0.33433800E+01, -.18351100E+01, 0.17655600E+00, 0.11632900E+00, 0.91360000E+01, 0.40552600E+01, 0.83531100E+00, -.78556700E+01, -.16655200E+00, 0.24411600E+00 }, { 0.96558600E+00, 0.40722700E+00, -.17027600E+01, 0.99408300E-01, -.89657100E+00, -.30319500E+01, -.19201100E+01, 0.16063900E+01, -.15215100E+01, 0.55633200E+00, 0.45081800E+00, -.26439600E-01, 0.10944100E+01, -.71010500E+01, 0.16726000E+01, 0.68250900E+01, 0.36934500E+01, 0.16085600E+00, -.62365600E+00, -.18443600E+01, 0.87454400E+00, 0.61712500E+00, -.10480700E+01, 0.79244600E+00, -.14751700E+00, 0.14976000E+00, 0.92941800E+00, 0.22281800E+00, 0.12184200E+01, 0.36742400E+00, 0.30930000E+01, -.44120100E+00, -.29781800E+00, -.27015600E+00, -.16151100E+01, 0.31422700E-01, 0.18052300E+00, 0.13411500E+01, 0.16127800E+00, -.50209500E-01, 0.92549200E+00, 0.11967100E+00, 0.15788900E+01, -.69135300E+00, -.94647000E-01, 0.35383200E+00, -.83109200E-01, -.41127300E+00, 0.37596100E-01, -.70609500E-03, -.90211900E-02, -.19686200E+00, -.21092800E+00, 0.52342600E-01, -.93885200E+00, -.26666600E+00, 0.26244900E-01, 0.79926000E+00, -.36940300E+00, -.25698700E+00, -.41783000E+00, -.95066400E-01, -.26841600E+00, -.85566700E+00, 0.93560400E-01, 0.59876400E-01, -.45257500E-01, 0.36389200E+00, 0.16124700E+00, -.10924700E+00, 0.16480800E-01, 0.35289200E+00, 0.94686400E-01, -.63237300E-02, -.63938300E-01, -.20708800E-01, 0.77038700E+00, -.51319300E+00, 0.33833500E+00, 0.55621200E+00, 0.60101000E+00, 0.11975200E+00, 0.49743200E+00, -.70921400E-01, -.71546100E-02, 0.39837700E+00, 0.19986800E+00, -.77756900E+00, -.19540100E+00, -.29358100E+01, -.20988800E-01, 0.47099200E+00, 0.25588000E+00, -.20248600E-01, -.10502700E+00, -.88447900E+00, 0.28203600E+00, -.28077000E-01, -.14278500E+00, -.96415000E+00, 0.55294300E-01, -.25553100E+00, -.13839100E-01, -.17598900E+00, 0.15580600E+00, -.18374800E+00, 0.41064000E+00, 0.65037700E+00, 0.11297400E+01, -.80011000E+00, 0.29878300E+00, 0.14671800E-01, 0.31800800E+00, 0.96704300E+00, -.60845400E+00, 0.29168100E+00, -.22920300E+00, -.19001500E+02, -.72877500E+02, 0.48857100E+00, 0.33903500E+02, -.25229000E+01, -.91267700E+01, -.16366300E+02, -.10589400E+02, 0.34531600E+02, 0.12327900E+02, -.16686200E+02, -.45092600E+02, 0.51180000E+02, 0.17416800E+02, 0.16187000E+02, -.16090600E+02, -.22535700E+02, -.72840600E+01, 0.16552100E+02, 0.14997100E+00, 0.16518800E+00, -.13882700E+00, 0.24590600E+00, -.13416200E+00, 0.42783200E+00, -.17544400E+00, 0.15310700E+00, 0.15316300E+00, 0.16520600E+00, -.13627000E+00, 0.24882200E+00, -.13444900E+00, 0.43177600E+00, -.17003700E+00, 0.15314600E+00, 0.16217800E+03, -.50707900E+02, -.48040600E+02, -.49419000E+02, 0.46984100E+01, 0.48144700E+02, 0.25285500E+02, -.50672600E+02, -.76393200E+02, 0.73042800E+02, 0.11722700E+02, 0.15306500E+02, 0.31530700E+01, -.30176100E+02, -.11318800E+02, 0.11944400E+02, 0.60080600E+00, 0.89548800E+00, -.66220900E+00, 0.92853300E+00, -.17558000E+00, 0.16562400E+01, -.30665800E+00, 0.51252900E+00, 0.13085400E+03, -.10553700E+03, -.39682000E+02, -.32664000E+02, 0.27846100E+02, 0.63137900E+02, 0.15183400E+01, -.24459600E+02, -.37040700E+00, -.32841000E+00, 0.28092400E+00, -.42766000E+00, 0.17167400E+00, -.82051200E+00, 0.25330500E+00, -.23317000E+00, 0.63633000E+00, 0.76230900E+00, -.59169600E+00, 0.78783700E+00, -.15039400E+00, 0.14513000E+01, -.31829000E+00, 0.42416300E+00, 0.39422300E+00, -.27431800E+00, 0.12438100E+02, -.36282000E+01, -.36834000E+00, -.16666300E+01, -.11687800E+01, 0.44559000E+00, 0.89567100E+00, -.32622800E+00, 0.10455900E+02, -.17529700E+01, 0.18837000E+01, -.23408000E+01, -.12616600E+02, 0.59390900E+01, -.22611600E+01, 0.32812100E+01, -.19790700E+00, -.17673400E+00, 0.61403600E+01, -.27680400E+00, -.11443200E+01, -.42471600E+01, 0.31977400E+00, -.56319600E+00 }, { -.15589800E+01, -.55386100E+00, 0.14602800E+01, 0.85643700E+00, 0.67903100E+00, 0.16223000E+00, -.67283000E+01, -.20130600E+01, 0.37289200E+00, -.30750700E+00, 0.54624100E-01, 0.19908400E+01, 0.35040300E+00, 0.39617900E+01, -.20897600E+01, -.37851400E+00, -.79206800E+00, -.87046600E+00, -.75020000E+00, -.15345800E+00, 0.23514000E+00, 0.19254900E+00, 0.80662900E+00, 0.19226400E+00, 0.98093300E-01, 0.11825600E+00, -.56322800E+00, -.18546700E+00, -.17973700E+00, -.18307000E+00, -.10042700E+01, 0.21096400E+00, -.48210400E+00, 0.51077700E+00, 0.51646600E+01, 0.68291000E+00, -.10621700E+00, 0.12074600E+01, 0.92943000E+00, -.98808600E-02, 0.63772700E+00, 0.33218600E+00, -.18494800E+01, 0.63144700E+00, -.73554500E-01, -.11929900E+01, 0.20215600E+00, 0.32738500E+01, -.52457200E-02, -.60594700E-02, 0.73722600E-01, 0.12471700E+00, -.17974200E+00, -.17802300E+00, 0.35928600E+01, 0.13121800E+00, -.69997000E-01, -.25290200E+00, -.24812000E-01, 0.88641200E-01, -.87219700E+00, -.14487900E+00, 0.55602600E+00, 0.13145100E+01, -.49735400E+00, -.83085600E-01, 0.48609800E-01, -.45753600E+00, -.45731000E+00, 0.23966300E-01, 0.14517600E+00, -.51930300E+00, -.33811200E+00, 0.14998400E+00, 0.21453200E-01, 0.48782200E-01, -.66842900E-01, -.12294700E+00, 0.34007500E+00, -.14241000E+00, -.24841100E+00, -.79875500E-01, -.11068500E+00, 0.11223100E+00, 0.11863300E+00, -.94763400E-02, -.15899400E+00, -.20102400E+00, -.26318900E+00, 0.24895300E+00, -.37264100E+00, 0.20919000E+00, 0.11018600E-01, -.18856400E+00, -.45186300E+00, -.78457300E+00, -.12158500E+01, -.68139200E-01, -.44572900E+00, -.32372400E+00, -.33913600E+00, -.42437200E-02, 0.36761700E-03, -.26495200E+00, 0.97399400E-01, -.39341200E+00, -.33364600E+00, -.15383600E+00, -.10660900E+01, 0.11108500E+01, 0.69845200E-01, 0.30427800E+00, -.20037000E+00, 0.27755300E+00, -.78593200E+00, 0.15642300E+00, 0.12046300E+00, 0.18042600E-01, 0.43189800E+02, 0.36584900E+01, 0.33545700E+01, -.30713000E+02, 0.74175300E+01, 0.19914200E+01, -.21028500E+01, -.46673100E+01, -.20605700E+02, -.29750100E+01, 0.14296800E+02, -.32279500E+02, -.21621800E+02, -.19139300E+02, 0.18752200E+02, 0.15123200E+02, 0.75151300E+01, -.22180300E+02, -.10528900E+00, 0.81214100E+00, -.23738800E+00, -.97759000E-01, 0.26166400E-01, -.57070700E-01, -.74509500E-02, -.61524200E-01, -.10956400E+00, 0.81080900E+00, -.24125400E+00, -.94231500E-01, 0.24461800E-01, -.58488800E-01, -.12681400E-01, -.56862800E-01, -.72790100E+02, 0.53088600E+02, 0.16327100E+02, 0.25960400E+02, -.63358400E+01, -.30166600E+02, -.27007400E+02, 0.25499200E+02, 0.19202100E+02, 0.11311400E+02, -.61640900E+01, -.69215400E+01, 0.63399900E+00, 0.51385700E+01, 0.18926700E+01, -.77155200E+01, -.36892300E+00, 0.31093100E+01, -.94992000E+00, -.28131100E+00, -.20421000E+00, -.13023700E+00, -.42204200E+00, -.16189000E+00, -.12992100E+02, 0.79401800E+02, 0.39207600E+01, 0.79889300E+01, -.22369500E+02, -.26950400E+01, 0.12027400E+02, 0.39603800E+01, 0.22469900E+00, -.14580300E+01, 0.45495500E+00, 0.13142500E+00, 0.27158700E-01, 0.10268400E+00, 0.10087900E+00, 0.67489700E-01, -.34579800E+00, 0.26961700E+01, -.83886000E+00, -.24104500E+00, -.18392100E+00, -.11951900E+00, -.34930100E+00, -.13868800E+00, -.31354100E+00, 0.35300000E+00, -.35941600E+01, 0.22647700E+01, 0.24893100E+00, -.60702600E+00, -.12310400E+01, -.17464200E+00, 0.12973500E+01, 0.23398800E+00, -.65012900E+01, 0.53372500E+00, -.68752600E+00, 0.19480400E+01, 0.34246000E+01, -.41664100E+01, -.26704700E+00, 0.36365200E+00, 0.12807900E+00, 0.22426500E+00, -.62910000E+01, -.23248500E+01, 0.31695900E+00, 0.96574400E+00, -.30405600E+00, 0.12338100E+00 }, { -.28711900E+01, -.89070000E+00, 0.26622200E+01, 0.13192700E+01, 0.12005000E+01, 0.11932100E+01, -.95581800E+01, -.28297500E+01, 0.27189600E+01, 0.60535600E+00, -.74622900E+00, 0.29772600E+01, 0.19979300E+00, 0.10393600E+02, -.47605000E+01, -.64563000E+01, -.57793900E+01, -.21247800E+01, 0.71450700E+00, 0.90955700E+00, -.61067300E+00, -.28440800E+00, 0.25886100E+01, 0.22777800E+00, 0.53707500E+00, -.82768000E-01, -.14841600E+01, -.44296100E+00, 0.15429200E+01, -.27304100E+00, 0.65984600E+00, 0.56619700E+00, -.14393500E+01, 0.10534400E+01, 0.54707100E+01, 0.12487700E+01, -.20838200E+00, 0.16273600E+01, 0.36797200E+00, 0.32996200E+00, 0.12328400E+01, 0.54870900E+00, 0.17254500E+01, -.97809900E+00, -.68427300E+00, -.16408500E+01, -.31287900E+00, 0.69685000E+01, 0.13095700E+00, -.29292200E+00, -.29553600E+00, -.93111900E-01, -.58962600E+00, 0.80595600E-01, -.82966400E+00, -.53186900E+00, -.17219600E-01, 0.28673000E+01, -.12429700E+01, -.14485300E+01, 0.66147900E+00, -.22153200E+00, 0.76966300E+00, 0.36163700E+01, -.38084100E-01, -.15905200E+00, 0.81343200E-01, -.20614800E+01, -.40623200E+00, 0.10375800E+00, 0.39804300E+01, -.47946500E+00, -.47417400E+00, 0.23522700E+00, -.34044800E+00, 0.57045900E+00, -.11894000E+01, 0.23907100E+00, 0.57804800E+00, -.18494700E+01, 0.30843600E+01, -.23729200E+00, 0.33314600E+01, -.25315900E+00, -.69168100E+00, -.81139700E+00, 0.33192600E+00, 0.94959400E+00, 0.60064800E+00, -.10102900E+02, 0.18972200E+01, -.99479600E-01, 0.20692500E+00, -.11600000E+00, 0.61481900E+01, 0.11392500E+01, 0.61321900E+00, 0.47547200E+00, 0.16008400E+01, -.12253400E+00, -.83651500E-01, -.32504700E+00, -.39459600E+00, -.78231100E-01, -.40427300E+00, 0.44521900E+00, 0.53436600E+00, 0.89373200E+00, 0.31937300E+01, 0.97846900E+00, 0.26462800E+00, 0.62128400E+00, 0.10705200E+01, 0.20259700E+00, -.43277800E+00, 0.39785000E-01, -.62650500E+00, 0.90507200E+00, 0.57459600E+00, -.96773600E+01, -.29570700E+02, 0.51540100E+02, 0.50891900E+01, 0.14687700E+02, 0.17403900E+00, -.97134700E+01, 0.14758900E+02, 0.24125100E+02, 0.12810400E+03, 0.49700400E+02, 0.18058900E+02, 0.19421600E+02, -.41184200E+02, 0.16414800E+02, -.32606400E+02, 0.26509300E+02, 0.45845500E+00, -.38546400E+00, -.14879500E+00, 0.64602800E-01, -.24975700E+00, 0.63269200E-01, 0.19249800E+00, -.24219000E-01, 0.46983300E+00, -.38799800E+00, -.13766800E+00, 0.55880600E-01, -.24922400E+00, 0.57050100E-01, 0.18906200E+00, -.31638000E-01, 0.70218400E+02, -.53594100E+02, 0.57202700E+01, 0.12071900E+01, -.26556800E+02, 0.11272000E+02, -.84670800E+01, 0.29406200E+01, 0.11827300E+03, -.10570100E+03, -.20615000E+02, -.16837400E+02, -.13032200E+02, 0.40770200E+02, -.12748700E+01, -.11185500E+02, 0.16475900E+01, -.11579300E+01, -.49961500E+00, 0.17194200E+00, -.98660300E+00, -.75374400E-01, 0.75697600E+00, -.80135500E-01, -.84232100E+02, -.39825600E+02, 0.43857000E+02, 0.43136500E+02, -.24963900E+02, -.49505000E+02, -.43877200E+02, 0.42675400E+02, -.88280500E+00, 0.63037900E+00, 0.17548000E+00, -.82073600E-01, 0.45570800E+00, -.15429700E-01, -.31033800E+00, 0.44727000E-01, 0.14498700E+01, -.10013300E+01, -.37377600E+00, 0.20292700E+00, -.87593800E+00, -.97544400E-01, 0.61829800E+00, -.10385000E-01, 0.14531500E+01, -.59785300E-01, -.48088900E+01, -.64669100E+01, 0.50048300E-02, -.12397500E+01, -.67641200E+00, -.48302600E-01, 0.10384300E+01, -.36964900E-02, 0.56692700E+01, -.20565500E+01, -.20152600E+01, -.24501400E+01, 0.58773800E+01, -.49034100E+01, -.14246300E+01, -.39181600E-01, 0.27588600E-01, -.34188100E-01, -.20022500E+01, 0.79809200E+01, 0.18933100E+01, -.22048400E+01, 0.26410900E-01, 0.68403300E-01 }, { 0.14949500E+01, 0.53483500E+00, -.14784000E+01, -.82446600E+00, -.54869500E+00, -.29403700E+00, 0.54514300E+01, 0.17333600E+01, -.30469400E+00, 0.42681000E+00, -.86163300E-01, -.16765400E+01, -.22460800E+00, -.37793900E+01, 0.16476600E+01, 0.65124000E+00, 0.87819200E+00, 0.68466500E+00, 0.47778100E+00, 0.72725900E-01, -.57341100E-01, -.14792900E+00, -.84792600E+00, -.18134700E+00, -.92829300E-01, -.70465700E-01, 0.60656200E+00, 0.22154000E+00, 0.11547600E+00, 0.16965000E+00, 0.11868100E+01, -.28882100E+00, 0.39720600E+00, -.37848200E+00, -.36917000E+01, -.62275400E+00, 0.11216600E+00, -.86628900E+00, -.59667600E+00, -.80987100E-02, -.45769400E+00, -.97066100E-01, 0.56935700E+00, -.40799300E+00, -.49314600E-01, 0.11989900E+01, -.19299600E+00, -.24770300E+01, 0.78438500E-03, 0.26925300E-01, -.53817900E-01, -.11684900E+00, 0.16598500E+00, 0.13168700E+00, -.22771400E+01, -.10966000E+00, 0.48273000E-01, 0.17978400E+00, 0.75821600E-01, -.16411200E+00, 0.44323500E+00, 0.16264000E+00, -.59771300E+00, -.11412600E+01, 0.52378000E+00, 0.10059300E+00, -.12653700E+00, 0.29435200E+00, 0.51254700E+00, -.12411500E+00, -.99046000E+00, 0.71719300E+00, 0.33595300E+00, -.34533600E+00, -.14253600E+00, -.30246300E+00, -.82890700E+00, 0.28802500E+00, 0.19435800E+00, 0.15167000E+01, 0.64948300E+00, -.14776200E+00, -.64703000E+00, -.12976100E+00, 0.20453400E-02, -.71571200E-01, 0.46047700E-01, -.43591300E+00, -.17357200E-01, 0.53293100E+00, -.92969000E+00, 0.22166600E+00, -.18651500E-01, 0.31596900E+00, -.29251200E+01, -.35375100E+00, 0.27889400E+01, 0.10319200E+00, -.84769600E-01, -.26376600E+01, 0.55877400E+00, 0.10920600E+01, 0.36987000E+00, 0.87095700E-01, -.13596200E+00, -.53159700E+00, 0.65615200E-01, -.28865100E+00, -.11002300E+01, -.21533200E+00, 0.48769000E+00, 0.64026800E+00, 0.79980000E+00, 0.44945900E+00, -.29366400E+00, 0.15924900E+00, 0.21661000E+00, 0.62823600E+00, 0.54202400E+00, 0.12937100E+00, -.37810600E+02, 0.24979800E+02, 0.15041900E+02, 0.22192100E+02, -.86010300E+01, -.20470300E+02, 0.15149300E+02, 0.24399800E+02, -.18119900E+02, 0.57738800E+01, 0.17308800E+02, 0.14311700E+02, -.39339600E+01, -.19200800E+02, -.11904800E+02, 0.14677600E+02, -.26572700E+00, -.29831400E+00, 0.17780100E+00, 0.27545600E-01, -.43807200E-01, 0.15820500E+00, -.73322300E-01, 0.84623000E-01, -.26807800E+00, -.29668700E+00, 0.17455200E+00, 0.23890300E-01, -.43276100E-01, 0.15387000E+00, -.73848400E-01, 0.81508300E-01, -.33973200E+02, 0.27784400E+01, 0.13389000E+02, 0.15005000E+02, -.28885400E+01, -.13899800E+02, -.54104900E+01, 0.14614800E+02, 0.87793800E+01, -.20101000E+02, -.33156100E+01, -.30416200E+01, 0.18813500E+01, 0.48018100E+01, 0.26435600E+01, -.17141700E+01, -.13343800E+01, -.12088900E+01, 0.58386400E+00, 0.73390300E-01, -.63267600E-01, 0.72180900E+00, -.65757000E-01, 0.32629400E+00, -.76247400E+02, -.12010200E+01, 0.12847300E+01, -.32541200E+01, 0.22646000E+02, -.19120900E+02, -.97361700E+01, -.41900800E+01, 0.56332000E+00, 0.54148500E+00, -.29048200E+00, -.24023700E-01, 0.53267300E-01, -.27507100E+00, 0.88258400E-01, -.14012500E+00, -.11886100E+01, -.10452200E+01, 0.50031400E+00, 0.50744500E-01, -.43525700E-01, 0.61527200E+00, -.39735400E-01, 0.27175600E+00, -.79625500E+00, -.26400700E+00, -.23058700E+01, 0.33392600E+01, -.25330900E+00, 0.50644900E+00, 0.47734300E+00, 0.24618800E+00, -.26584300E+00, -.22474700E+00, 0.65202300E-01, 0.30613700E+01, -.34848300E-01, 0.35818700E+00, 0.23268400E+01, 0.12937200E+01, 0.22541900E+01, -.46378700E-01, -.14057900E+00, -.16711700E+00, -.12017000E+01, -.20557600E+01, -.42074000E+00, 0.32321900E+01, 0.25846400E+00, -.25855300E+00 }, { 0.10388600E+01, 0.31052700E+00, -.16131800E+01, -.16230200E+01, -.10327700E+01, -.20097900E+01, -.19136900E+01, 0.18597300E+01, -.39086800E-02, 0.51047600E+00, -.23625900E+00, -.12037100E+01, 0.43438900E+00, -.60764300E+01, 0.11810300E+01, 0.20876700E+01, 0.22298400E+01, -.12688600E+00, -.41464800E+00, -.23560900E+00, 0.19340500E+00, 0.66173600E-01, 0.18116100E+00, -.95269700E+00, 0.32475500E-01, -.39482600E+00, -.15571600E+00, -.15453200E-01, 0.39809300E-01, -.47686400E+00, -.20372000E+01, -.14694200E+00, 0.30456600E+00, 0.30396300E+00, 0.12218800E+01, -.90023800E-01, -.66758200E-01, -.15715200E+01, 0.13148000E+01, -.23751400E+00, -.21717300E+00, -.11853600E+01, 0.19410400E+01, -.11468200E+00, 0.70190300E+00, -.12914400E+01, 0.15555900E+00, -.18127200E+00, 0.10861000E-01, -.17331000E+00, 0.25672600E+00, 0.99886200E-01, -.55286400E+00, -.65986900E-01, -.36510700E+01, -.12192800E-01, 0.59533800E-01, -.33141100E+01, -.93201000E+00, 0.61323000E+00, -.57617100E+00, 0.20043400E+00, 0.61952700E+00, 0.37448300E+00, -.77010600E+00, -.12141100E+00, 0.15546100E+00, 0.19738000E+00, -.44797100E+00, 0.12568300E+00, -.57571900E+01, -.80709300E+00, 0.20089500E-02, -.14798200E-02, 0.46918900E+00, 0.34080900E+00, 0.96033200E+00, -.18097100E-01, 0.22538200E+01, 0.22460900E+01, 0.67551300E+00, -.18098800E+00, 0.16680800E+00, -.20766100E+00, -.43065400E+00, -.64037900E+00, -.39699500E+00, 0.20524900E+00, -.29839400E+00, -.12122400E+01, -.12572400E+01, -.29876500E+00, -.23181500E+00, -.10044900E+01, -.28946800E+01, -.28708500E+00, 0.26783200E+00, 0.36139100E-01, -.43440400E+00, -.18973400E+01, -.81712800E-01, -.13760500E+01, 0.13903400E+00, 0.13319100E+00, 0.16108600E-01, 0.40494300E+00, -.54856300E+00, -.10474400E+00, -.51819000E+00, 0.83959000E+00, 0.39962800E+00, -.38755700E-02, 0.18452100E+00, -.33915100E+00, -.33757700E+00, 0.96660800E-01, 0.48531600E-02, -.76626600E-01, 0.40304800E+00, 0.32574500E+00, 0.78928200E-01, -.20054300E+02, 0.10287100E+01, 0.26443800E+01, 0.54334500E+01, -.62916000E+01, -.33134300E+01, 0.39860500E+01, -.74581900E+02, -.21013600E+02, 0.14212000E+01, 0.97107900E+01, 0.14134700E+02, -.28305600E+02, 0.14405600E+02, 0.48597700E+01, -.53739100E-02, 0.10878500E+00, 0.35150300E-01, -.55639900E-02, 0.46036400E-01, -.13226100E+00, -.11448900E+00, 0.23264500E-01, -.14698200E-01, 0.11044200E+00, 0.32690300E-01, -.21846200E-02, 0.46278100E-01, -.13331100E+00, -.11330300E+00, 0.26800600E-01, -.12320900E+02, 0.20112900E+01, 0.48974700E+01, 0.67715200E+01, -.17499100E+01, -.12200700E+02, -.83763600E+01, 0.61227400E+01, -.22678400E+02, 0.62750800E+01, 0.20421900E+01, 0.26481200E+01, 0.21760800E+01, -.94336400E+01, -.47850200E+01, 0.10462600E+01, -.15850500E+00, 0.33787200E+00, 0.11993800E+00, -.17105800E-01, 0.16625400E+00, -.55262300E+00, -.44089700E+00, 0.77356900E-01, 0.32276600E+02, 0.53827500E+00, -.18202700E+02, -.23877800E+02, 0.13819900E+02, 0.19772200E+02, -.97737000E-01, -.23487700E+02, 0.12203200E+00, -.16144800E+00, -.46731800E-01, -.16630900E-01, -.78826700E-01, 0.26992800E+00, 0.20560400E+00, -.63129200E-01, -.19477100E+00, 0.27357400E+00, 0.93955400E-01, -.15613700E-01, 0.14629300E+00, -.49369000E+00, -.38005900E+00, 0.63083700E-01, 0.54885800E-01, -.57607800E-02, 0.32239300E+01, 0.31809900E+01, -.23868500E-01, 0.39205400E+00, 0.44614300E-02, 0.36605900E-01, -.51554700E-01, -.17556000E-01, -.28707800E+00, 0.13903100E+01, 0.30454400E+00, 0.11310100E+01, -.35240800E+01, 0.15625400E+01, 0.59262800E+00, 0.80704100E+00, -.13990400E-01, -.13979400E-03, -.20410700E+01, -.41931500E+01, -.49780000E+00, 0.25436900E+01, 0.15309800E-01, -.34563000E-01 }, { -.26656500E+01, -.52330400E+00, 0.23127800E+01, 0.19878500E+01, 0.71261100E+00, 0.38546800E+00, 0.92298700E+00, -.18038100E+01, 0.24101200E+00, -.11693300E+01, 0.19261200E+00, 0.14422200E+01, -.46689900E+00, 0.98106900E+01, -.21753300E+01, -.66134600E+01, -.30667200E+01, -.19652900E+01, 0.14425400E+00, 0.14362800E+01, -.12878500E+01, 0.48094400E-01, 0.10220100E+01, 0.90494100E+00, -.72513200E-01, 0.54624700E+00, 0.52612900E+00, 0.80428400E-01, 0.26339900E+01, 0.67470100E+00, 0.95856000E+01, -.79712500E-01, -.14714200E+01, -.57493100E+00, -.13024600E+01, 0.69856400E+00, 0.23190600E+00, 0.23194900E+01, 0.72721900E+00, 0.34639600E+00, 0.95006700E+00, 0.42273400E+00, -.41823900E+01, 0.90701300E+00, -.39321500E+00, -.21241600E+01, -.30365600E-02, 0.40710100E+01, 0.87272100E-01, -.12813300E+00, 0.33171000E+00, 0.29548300E+00, -.10729100E+01, -.29910900E+00, 0.10715200E+02, -.65127800E-01, -.39993900E+00, 0.25753000E+01, 0.13083000E+00, -.44384300E+00, 0.22557500E+01, -.19859800E+00, -.33489400E+00, 0.47834000E+00, 0.10029600E+01, -.19340100E+00, 0.26700400E+00, -.20667400E-01, -.88553800E+00, 0.12723000E+00, 0.23188300E+01, -.13202300E+01, -.13152800E+00, 0.31564100E+00, -.10107600E+01, 0.91702200E-01, -.23992700E+01, 0.81520100E-01, 0.21609500E+01, -.14277500E+01, 0.95466100E+00, -.22530200E-01, 0.19906700E+01, -.15476900E+00, -.66532600E+00, 0.79970900E+00, -.20173100E+00, -.16199000E+01, -.11640200E+01, -.37198300E+01, 0.53789400E+00, 0.64280400E+00, 0.36099000E+00, -.85510700E+00, -.11817300E+01, -.60411300E-01, -.16015400E+01, -.37574700E+00, -.10168000E+01, 0.18247300E+01, -.26740200E+00, -.44853300E+00, -.10441100E+00, 0.20491700E+00, 0.28039600E+00, -.56985100E+00, 0.29494800E+00, -.73235100E-01, 0.25278800E+01, -.44453800E+00, 0.89783200E+00, 0.37256000E+00, -.67587000E+00, 0.26078400E+00, 0.49951200E+00, -.92071700E-01, -.11828500E-01, -.56086700E-02, -.10243300E+00, -.87161000E-01, -.14222700E+00, -.12773300E+01, -.18023700E+02, -.15086300E+02, 0.23681400E+02, -.13878700E+01, 0.12033100E+01, -.17787400E+02, -.80687400E+02, 0.15234000E+01, -.12549100E+02, -.67474100E+01, 0.24526100E+02, -.73944400E+01, 0.15643600E+02, -.12445400E+02, -.15810500E+00, -.39086300E+00, 0.45842700E+00, -.10544300E+00, 0.22202300E+00, -.16172100E+00, 0.25544200E+00, -.32980600E-01, -.15318100E+00, -.39113200E+00, 0.46041400E+00, -.10382800E+00, 0.21959600E+00, -.15242600E+00, 0.25464900E+00, -.32499200E-01, -.12633000E+02, -.36545700E+01, 0.31441900E+01, -.81777000E+01, 0.31373800E+01, 0.62742300E+01, 0.16202900E+01, -.86938500E+01, -.35143900E+02, 0.27130600E+02, 0.11569100E+02, 0.53400800E+01, 0.36511600E+01, -.12522100E+02, 0.45024800E+01, 0.44553100E+01, -.23998500E+00, -.18275600E+01, 0.20803600E+01, -.42591000E+00, 0.77191200E+00, -.34632900E+00, 0.93119000E+00, -.13837000E+00, 0.93799500E+02, -.51738800E+01, 0.21864100E+01, -.16532800E+02, -.86879100E+01, 0.34727400E+02, 0.23641400E+02, -.11912200E+02, 0.19515000E+00, 0.74781000E+00, -.88407400E+00, 0.20196400E+00, -.38370700E+00, 0.18278400E+00, -.46960300E+00, 0.83833000E-01, -.20158900E+00, -.15701900E+01, 0.18045700E+01, -.38819600E+00, 0.67507000E+00, -.27289600E+00, 0.83383900E+00, -.14480900E+00, -.56112500E+00, 0.11249600E+00, -.22732400E+01, 0.74782300E+00, 0.22607500E+00, 0.34848400E+01, 0.21659500E+01, -.32326000E+00, -.23243800E+01, 0.19001500E+00, -.18012000E+01, -.16659800E+01, 0.76411900E+00, -.51148500E+00, 0.20707400E+01, -.24296000E+01, 0.38168900E+00, -.89456900E-01, 0.11743100E+00, 0.71024500E-01, 0.22029800E+01, -.37749700E+00, -.11390300E+00, -.28625300E+01, -.16360800E+00, 0.45281600E+00 }, { -.11811800E+01, -.50582500E+00, 0.21323100E+01, -.12723500E+00, -.91433600E-01, 0.37315400E+01, 0.38577400E+01, -.75974700E+00, 0.64509600E+00, -.10767800E+01, -.30481100E-02, 0.83394600E+00, -.17624800E+01, 0.88285600E+01, -.15636300E+01, -.54661700E+01, -.31910700E+01, -.15677200E+01, 0.46843400E+00, 0.62129500E+00, -.58658600E+00, -.10212900E+00, 0.11975400E+01, 0.88347700E+00, -.14576000E+00, 0.32930300E+00, 0.63439200E+00, 0.16326400E+00, 0.42218300E+01, 0.32685800E+00, 0.74357500E+01, -.52905600E+00, -.13742500E+01, -.45856700E+00, -.25116500E+01, 0.49902800E+00, 0.36980000E+00, 0.29106400E+00, 0.22789900E+00, -.61286600E-01, 0.51506600E+00, 0.47296200E+00, -.23215100E+01, 0.22936800E+00, -.35862200E+00, -.18541500E+01, 0.36311800E+00, 0.18793400E+01, 0.34820300E-01, -.21571000E-01, 0.79590600E-01, -.77196700E-01, -.51507600E+00, 0.11650400E+00, 0.25960900E+01, -.32847300E+00, 0.16993900E-01, 0.11840300E+01, -.25381300E+00, -.60704200E+00, -.17274600E+01, -.25585300E+00, 0.36205500E+00, 0.43733800E+00, -.36116200E+00, -.30037900E-01, 0.13521100E-01, -.65969900E-01, -.11816800E+00, 0.65021400E-01, 0.97849500E+00, -.10568600E+00, -.13206400E+00, 0.60767100E-01, 0.41331100E+00, -.71687300E-01, -.17820600E+01, 0.74696700E+00, -.49518200E+00, -.12274900E+01, -.62329800E+00, -.23153200E+00, -.91540800E+00, 0.17194300E+00, 0.50234800E-01, -.81522200E+00, 0.35293900E-01, 0.86006400E+00, -.92625800E-01, 0.61215200E+00, 0.43094000E+00, -.23395900E+00, 0.21189300E+00, -.41712100E+00, -.46820900E+01, 0.19284900E+01, 0.67972500E+00, -.13722800E+00, -.30786800E+00, -.18755700E+00, -.17638400E+00, 0.16009700E-01, 0.32478900E-01, 0.22027200E+00, 0.54853400E-01, -.64784200E+00, -.32015300E-01, -.52676900E+00, 0.60999900E+00, -.73584200E+00, 0.67702900E+00, -.14295700E+00, 0.73762700E-01, -.23812700E+00, 0.44064500E+00, -.22138300E-01, 0.43377400E+00, -.62948100E-01, -.13700200E+00, 0.22787200E+00, 0.24602400E+00, 0.44259500E+00, -.43992500E+00, -.87346300E+01, 0.16739000E+02, -.77549300E+01, -.84405300E+01, -.12341000E+02, -.12204300E+03, 0.19438000E+02, -.22674000E+01, -.81775600E+01, 0.32982400E+02, -.31833300E+02, 0.10589700E+02, -.11262500E+02, -.48245600E+00, -.15101400E+00, 0.18177400E+00, -.12080700E+00, 0.12768500E+00, -.31856300E+00, 0.15071100E+00, -.22708500E-01, -.47746400E+00, -.15098800E+00, 0.17912900E+00, -.12094600E+00, 0.12467100E+00, -.30594000E+00, 0.15419300E+00, -.22702200E-01, -.38044600E+02, 0.86328600E+01, 0.25835000E+01, -.89387400E+01, 0.77868700E+01, -.20326500E+00, 0.89935500E+01, -.82858400E+01, -.90836200E+01, 0.13036900E+02, 0.56908300E+01, 0.16229800E+00, 0.22719200E+01, 0.22060400E+01, 0.12697500E+02, 0.94531200E+00, -.15719100E+01, -.86459800E+00, 0.86131800E+00, -.37852100E+00, 0.27449900E+00, -.86401600E+00, 0.68080800E+00, 0.30705800E-01, 0.82705200E+01, 0.27522000E+02, 0.52718800E+01, 0.40426600E+01, -.10393600E+02, 0.39797000E+01, 0.11675400E+02, 0.65804100E+01, 0.80891300E+00, 0.28106000E+00, -.33669400E+00, 0.22509000E+00, -.19091900E+00, 0.42637200E+00, -.33454100E+00, 0.45775800E-01, -.14016700E+01, -.68500000E+00, 0.73810800E+00, -.36446300E+00, 0.25915500E+00, -.70546200E+00, 0.63737900E+00, -.10870300E-01, -.15765100E+01, 0.73294800E-01, -.14926200E+01, -.38774300E+00, 0.13585400E+00, 0.10865500E+01, 0.96538800E+00, -.19226600E+00, -.11247100E+01, 0.11513000E+00, -.39076300E+01, -.55115100E+00, 0.96419900E+00, 0.49800400E+00, 0.10042800E+01, -.45474200E+00, -.16817000E+01, 0.11871600E+00, 0.46150900E-01, 0.34960000E-01, 0.55848600E+00, 0.24705600E+01, -.23959400E+00, -.23115700E+01, -.10285100E+00, 0.28198300E+00 }, { 0.54802400E+00, 0.21153200E+00, -.93839000E+00, 0.91204500E-01, -.35661900E+00, -.18582800E+01, -.12711400E+01, 0.90033400E+00, -.32763900E+00, 0.52670000E+00, 0.23344600E-01, -.27840400E+00, 0.70235800E+00, -.38798300E+01, 0.61960900E+00, 0.24589000E+01, 0.11321600E+01, 0.95310000E+00, 0.19395500E+00, -.62054200E+00, 0.29457300E+00, 0.55001600E-02, -.33081300E+00, -.13928300E+00, 0.59158800E-03, -.96525000E-01, 0.19736600E+00, 0.34432200E-01, -.15946100E+00, 0.60226700E-02, -.84483200E+00, -.23619100E-03, 0.35026300E+00, -.30225900E-01, -.20565400E+00, -.17140000E+00, -.50919600E-01, -.67135400E-01, 0.46593200E-01, -.14771100E-01, 0.26251000E-01, -.25096900E+00, -.77713800E+00, 0.34310700E+00, 0.33817400E+00, -.44417100E+00, 0.13713000E+00, -.83696600E+00, -.24252000E-01, 0.33569000E-01, 0.83028200E-01, 0.25110900E-01, 0.13535700E+00, -.61733600E-01, -.12021900E+01, 0.14463900E+00, 0.50222000E-02, -.12700200E+01, 0.24666700E-01, 0.29573800E+00, -.51173100E-01, 0.11832500E+00, 0.33432200E-01, -.49779600E+00, -.19043800E+00, 0.61800200E-01, -.25003900E-02, 0.16083700E+00, 0.27784900E+00, -.20026400E-01, -.17801000E+01, 0.37185400E+00, 0.19459900E+00, -.14724200E+00, 0.52007000E-01, -.62438600E-01, 0.26260500E+00, -.24257900E-01, 0.44801500E+00, 0.27159600E+00, -.53055300E+00, 0.81623100E-01, -.58276500E+00, 0.14344700E+00, -.86628200E-01, 0.66363600E+00, -.18724100E+00, -.41044700E+00, -.13359300E+00, -.62640600E+00, 0.12176000E+00, 0.34663400E-01, -.99413200E-01, -.40272500E-01, -.30295300E+00, -.71229100E-01, 0.25673300E+00, 0.11081500E+00, -.23912400E+00, -.18047600E+00, -.19217700E-01, 0.24488000E+00, 0.14373300E+00, -.54247100E-02, -.61051500E-01, -.19204700E+00, -.10055800E+00, 0.12935600E+00, 0.92112200E+00, 0.23911800E+00, -.10632300E+00, 0.16941700E+00, -.46867500E-01, 0.51108500E+00, 0.10855300E+00, 0.55250000E-01, 0.11145300E+00, 0.18463000E+00, 0.18614500E+00, 0.66145200E-01, -.22549200E-02, -.30330400E+00, 0.23925400E+00, -.31456900E+00, 0.13847900E+02, -.77786800E+01, -.44346500E+01, 0.23983300E+00, -.64979400E+02, -.44870000E+02, 0.10072400E+02, 0.48255200E+01, 0.13143100E+02, -.25600600E+02, 0.99668200E+01, 0.12300600E+01, -.23859600E+00, -.30301200E+00, 0.24007400E+00, -.12111100E+00, 0.65565900E-01, -.18724400E+00, -.35300600E-01, -.43917000E-01, -.24423400E+00, -.30103000E+00, 0.23581900E+00, -.12081000E+00, 0.66842900E-01, -.18923900E+00, -.33196600E-01, -.41886300E-01, -.55798900E+02, 0.87443500E+01, 0.16278700E+02, 0.12711700E+02, 0.53993400E+01, -.19248500E+02, 0.18861900E+01, 0.12845200E+02, -.18942900E+02, -.38343400E+00, 0.24095900E+01, 0.13371100E+01, 0.33910100E+01, -.56680800E+01, 0.27143000E+01, 0.46530900E+00, -.96492600E+00, -.14053300E+01, 0.88223900E+00, -.51232900E+00, 0.27847600E+00, -.76457100E+00, -.60188800E-01, -.19652900E+00, -.11252300E+02, 0.39181800E+01, -.11035100E+02, -.14401200E+02, 0.12900600E+02, -.18452300E-01, 0.88839600E+00, -.14793100E+02, 0.52055000E+00, 0.59265300E+00, -.40680600E+00, 0.21837400E+00, -.13105700E+00, 0.37823900E+00, 0.35864800E-01, 0.71430200E-01, -.92247800E+00, -.12201400E+01, 0.75580400E+00, -.44913600E+00, 0.25561100E+00, -.68527400E+00, -.37989200E-01, -.18029900E+00, -.70493100E+00, -.37495100E-01, -.84557100E+00, 0.49059900E+01, 0.27902400E-01, 0.14397800E+01, 0.94718100E+00, -.81016600E-01, -.92644700E+00, 0.22059500E-01, -.27176300E+01, 0.21627100E+01, 0.38897900E+00, 0.10853600E+01, 0.52477900E+00, 0.19853800E+01, 0.56882400E+00, -.70050200E-01, 0.79446200E-02, -.23570100E-01, -.63375000E+00, -.38600900E+01, 0.18000600E-01, 0.33835400E+01, 0.62536500E-02, 0.15193100E+00 }, { 0.18501600E+01, 0.60199400E+00, -.25591300E+01, -.77857100E+00, -.18635100E+00, -.68399600E+00, 0.29163500E+01, 0.11439400E+01, -.70510700E+00, 0.10792100E+01, -.10730200E+00, -.20752000E+01, 0.43541100E+00, -.90090700E+01, 0.18522500E+01, 0.43070600E+01, 0.28182400E+01, 0.15906200E+01, -.12289100E+01, -.71264200E+00, 0.15031200E+01, -.23777900E+00, -.31207200E+01, 0.34555500E+00, -.19048100E+00, -.33295800E+00, -.16175100E+00, 0.77091000E-01, -.20676000E+01, 0.61032000E-01, -.50209200E+01, -.16609100E+00, 0.14218100E+01, -.28685800E+00, -.55116700E+01, -.70187400E+00, 0.21424700E+00, 0.28048200E-01, -.13398200E+01, 0.19175300E+00, -.47567700E+00, -.34386500E+00, 0.35897200E+01, -.10188100E+01, 0.26699200E-01, 0.14894100E+01, -.19595600E+00, -.41442000E+01, -.10188200E-01, 0.41491100E-01, -.27253600E+00, -.28483400E+00, 0.55708300E+00, 0.11871000E+00, -.29747200E+01, -.17007200E+00, 0.18504900E+00, -.86742500E+00, -.55157400E-01, -.27949100E-01, 0.39046800E+00, 0.20444400E+00, -.50156000E+00, -.22171600E+01, 0.37118300E-01, 0.18973900E+00, -.25793600E+00, 0.76278900E+00, 0.10775200E+01, -.22339800E+00, -.39662500E+01, 0.13698000E+01, 0.61362700E+00, -.27609800E+00, -.72710300E-01, -.58454000E+00, -.26815300E+00, -.56660900E-01, 0.63172700E-01, 0.12928800E+01, -.65989000E+00, -.27352000E-01, -.11337300E+01, 0.24221900E-01, 0.12744400E+00, 0.12763800E+01, -.21950900E+00, -.17477600E+01, -.42368200E+00, -.25477200E+01, 0.80498100E+00, 0.23812000E+00, 0.37120700E+00, -.42042300E+00, -.38111900E+01, 0.76172800E+00, -.35494000E+00, -.41372100E+00, -.60015700E+00, 0.97132800E+00, 0.32326700E+00, -.96779300E+00, 0.28066000E+00, 0.22668100E+00, 0.16156800E+00, -.96558200E+00, -.73223000E+00, -.74960100E+00, 0.19506100E+01, -.17621100E+01, 0.19746200E+01, 0.32141000E+00, -.61303700E+00, -.73842400E+00, 0.91623500E+00, 0.16343200E+00, 0.44864200E+00, -.51550200E-01, -.54570100E-02, 0.10070300E+00, 0.37349200E+00, -.50298900E+00, 0.54290900E+00, 0.62704700E-01, -.38498200E+00, -.18121800E+02, -.18574100E+02, -.30060700E+01, -.87101700E+02, -.96375300E+01, 0.84170500E+01, 0.10891400E+01, 0.22062800E+02, -.40230400E+02, 0.40456900E+01, -.14433500E+01, -.35501100E+00, -.63550100E+00, 0.34506300E+00, -.17102300E-01, -.13797900E-01, -.43272100E+00, 0.74540900E-01, 0.19273600E-02, -.35853800E+00, -.63338400E+00, 0.34062700E+00, -.18451100E-01, -.11894200E-01, -.42932900E+00, 0.79826800E-01, 0.12715300E-02, -.57638100E+02, -.29873100E+01, 0.17966000E+02, 0.56612700E+01, 0.61665200E+01, -.14282600E+02, 0.16136600E+02, 0.58471500E+01, -.26187900E+02, -.26925400E+01, 0.61518400E+01, 0.40973600E+01, 0.29557100E+01, -.42510900E+01, 0.17253900E+02, 0.44636700E+01, -.12715200E+01, -.27545000E+01, 0.14322800E+01, -.12193200E+00, -.12359500E+00, -.16627400E+01, 0.49133700E+00, -.44736100E-01, -.14927300E+02, 0.10004800E+02, 0.15759700E+01, 0.86985200E+01, -.12760200E+02, -.15596300E+01, 0.84731900E+01, 0.81755300E+01, 0.71452800E+00, 0.11792900E+01, -.63147200E+00, 0.41958000E-01, 0.17404500E-01, 0.78967900E+00, -.20512800E+00, 0.59956500E-02, -.12363200E+01, -.23533200E+01, 0.12569700E+01, -.10853800E+00, -.79722900E-01, -.14666600E+01, 0.44772100E+00, -.43521500E-01, -.10778800E+01, -.15967300E+00, -.21386800E+01, 0.17874100E+01, -.23275400E-01, 0.12857000E+01, 0.14911200E+01, -.89425200E-01, -.15567200E+01, -.34032100E-01, -.51517400E+01, 0.19195400E+01, 0.87013400E+00, 0.75794600E+00, 0.19029600E+01, 0.14017700E+01, 0.16676600E+01, 0.18329800E+00, -.30258500E-01, -.10819000E+00, 0.48290000E+00, 0.30774800E+01, -.41871700E+00, -.26414200E+00, 0.93922800E-01, 0.24623100E+00 }, { -.97466400E+00, -.31679900E+00, 0.12389800E+01, 0.64848200E+00, 0.88564300E+00, 0.34128600E+01, 0.20238100E+01, -.60485300E+00, 0.83225900E-01, -.52319400E+00, -.20441800E-01, -.63750700E-01, -.54176200E+00, 0.26811900E+01, -.15764400E+00, -.15642800E+01, 0.42800900E-01, -.22518200E+01, -.13134100E+01, 0.13291900E+00, 0.13530100E+01, -.14135300E+00, -.10750200E+01, 0.24757300E+00, -.95933200E-01, -.68544100E-01, -.65377800E+00, -.99351900E-01, 0.11814800E+01, 0.19702900E+00, 0.20881500E+01, -.18999800E+00, -.12204500E+00, -.25061700E+00, -.54943000E+01, 0.31080600E+00, 0.16155400E+00, 0.42814300E+00, 0.10441900E+01, 0.11056200E-01, 0.55141300E+00, -.35032600E+00, 0.15688400E+01, -.16991700E-01, 0.47524200E+00, -.28525000E+01, 0.32886400E+00, 0.15344600E+01, 0.60745100E-01, -.62480000E-01, 0.29783400E+00, 0.18379600E+00, -.72536700E+00, -.55044800E-01, 0.63497000E+01, -.22033800E+00, -.24642400E+00, 0.39823400E+00, 0.83813800E-01, -.40449300E+00, 0.19687900E+01, 0.92641000E-01, -.68374600E+00, -.97890300E+00, 0.91363900E+00, -.56498800E-02, 0.91347400E-02, 0.48512300E+00, -.67715400E-02, 0.39417500E-01, -.17084200E+01, 0.21582300E-01, -.23484800E+00, 0.32484900E+00, -.13547900E+00, -.14036500E+00, 0.45208600E+00, -.18509900E+00, 0.20516000E+00, -.12521600E+01, -.20359900E+01, 0.24830400E+00, 0.26021600E+00, 0.12260600E+00, 0.25172900E-01, -.98635800E-01, -.19573300E+00, -.25220400E-01, -.41181100E+00, -.40678000E+01, 0.14389900E+01, 0.99215900E-01, 0.53917700E-01, 0.96938800E-01, -.12843700E+01, -.36920000E+00, 0.50242800E-03, -.64654100E-01, -.29802400E+00, -.10710800E+01, -.13040100E+00, -.48734900E+00, 0.52068800E-01, -.53313200E-01, 0.95997900E-01, 0.20690100E-01, -.60388700E-01, -.36055600E-01, -.42305300E+00, -.13408200E+00, 0.60565000E+00, -.28330400E+00, 0.68687300E+00, 0.27539800E+00, -.33147600E+00, 0.39088400E-03, -.11484100E+00, 0.39625000E+00, -.14280900E+00, 0.17590400E+00, 0.53458100E+00, 0.61327300E+00, -.29149200E+00, 0.22858900E+00, -.96321600E+00, -.15842000E+00, -.12132900E+02, -.58744500E+01, -.54240000E+02, -.24724200E+02, -.29673200E-02, -.83596800E+01, 0.15570900E+02, -.14522800E+02, 0.98239000E+01, -.93006400E+01, -.12679500E+00, 0.90023100E-01, 0.13559000E+00, -.11649700E+00, 0.19157600E-01, -.20724000E+00, 0.13817500E+00, -.46988400E-01, -.12584100E+00, 0.89855300E-01, 0.13196800E+00, -.11840400E+00, 0.19044500E-01, -.20141200E+00, 0.14170800E+00, -.47368700E-01, -.14694300E+02, 0.83239100E+01, 0.36933900E+01, -.35225000E+01, 0.97302700E+00, -.45399000E+01, 0.62344900E+01, -.58044300E+00, -.14907300E+02, 0.17662300E+02, 0.80134300E+01, 0.81478300E+00, 0.66382900E+00, -.18845000E+01, 0.86559800E+01, -.19345700E+01, -.32894100E+00, 0.30836000E+00, 0.54276800E+00, -.50288500E+00, -.28969900E-01, -.66812000E+00, 0.62757000E+00, -.19430200E+00, 0.27229400E+01, 0.20193900E+02, -.49955300E+01, -.57551100E+01, 0.24651400E+01, -.38578800E+00, 0.33304400E+01, -.57349300E+01, 0.22832500E+00, -.17960500E+00, -.23609400E+00, 0.23617700E+00, -.16797900E-01, 0.32037800E+00, -.29337300E+00, 0.10003900E+00, -.33965500E+00, 0.31047900E+00, 0.46939400E+00, -.45437400E+00, -.13520300E-01, -.57256600E+00, 0.56967900E+00, -.18875600E+00, -.39886300E+00, 0.19353600E+00, -.79188200E-02, 0.16027300E+01, 0.22643400E+00, 0.10119500E+01, 0.37308700E+00, -.26090100E+00, -.43540600E+00, 0.19503100E+00, -.39304900E+01, 0.52703300E+00, 0.56557200E+00, 0.14545500E+01, -.26672800E+00, 0.10999100E+01, 0.10253900E+01, -.13080600E+00, 0.10857600E+00, 0.11458300E+00, -.29080900E+00, -.91572500E+00, 0.41436000E+00, 0.92274700E+00, -.20915700E+00, 0.33016400E+00 }, { 0.50216300E+01, 0.68549500E+00, -.59047500E+01, -.36216900E+01, -.12381400E-01, -.59943400E+01, -.13964000E+02, 0.24640400E+01, -.27437800E+01, 0.26237700E+01, 0.50469100E+00, -.28195500E+00, 0.51811000E+01, -.30500300E+02, 0.33150800E+01, 0.24147400E+02, 0.11638800E+02, 0.67623700E+01, -.55780400E+01, -.50155300E+01, 0.58436700E+01, 0.69102100E+00, -.29838500E+01, -.29253500E+01, -.32222300E+00, -.17863200E+01, 0.37763500E+01, 0.17583900E+01, -.84299400E+01, -.25162200E+00, -.15114800E+02, 0.39076900E+00, 0.43247300E+01, 0.95481700E+00, 0.11763700E+01, -.24420200E+01, -.60793400E+00, -.12664400E+01, -.12778400E+01, 0.42909600E+00, -.16883800E+01, -.36316900E+00, 0.25424200E+01, -.23049700E+01, -.78691700E+00, 0.77281600E+01, -.91194000E+00, -.10298600E+02, -.97810800E-01, 0.10081300E+00, -.15056000E+01, -.10752200E+01, 0.23532400E+01, 0.98208700E+00, -.21096600E+02, -.69507200E+00, 0.95697300E+00, 0.45985300E+01, 0.10508600E+01, -.28669400E+01, -.38217100E+01, 0.17514800E+00, 0.31290700E+00, -.19567900E+01, -.18244600E+01, 0.55951400E+00, 0.28146600E+00, -.40966600E-01, 0.17226400E+01, -.57649600E+00, 0.57505700E+01, 0.37613900E+01, -.21324200E+01, -.10740500E+01, 0.23812400E+01, 0.12922900E+01, 0.37534100E+01, -.17342700E+01, 0.13339600E+01, -.18129500E+01, 0.10789200E+01, 0.19485200E+01, 0.64946500E+01, -.10931400E+01, -.25018400E+01, 0.23011800E+01, 0.18829700E+01, -.23420800E+01, 0.70306800E+00, -.52106100E+01, 0.24860500E+01, 0.47847200E+00, -.38541200E+00, 0.78827200E+00, 0.90712300E+01, -.15479100E+01, -.21018900E+00, -.10166400E+00, -.67075500E-01, 0.10932500E+02, -.10269900E+01, 0.43060000E+01, 0.26455500E+00, 0.26060500E-01, -.76283500E+00, -.22239600E+01, 0.26645100E+01, -.19219000E+00, 0.51720800E+01, -.34240700E+01, -.29074600E+00, 0.72469600E+00, -.17527200E+00, 0.23594200E+01, 0.29401900E+00, 0.30538800E+00, 0.40859800E+00, 0.23681300E+01, 0.12408200E+01, 0.80697900E+00, -.10562400E+00, -.23288200E+01, 0.11164000E+01, -.38073900E+00, 0.26271100E+01, 0.19439000E-01, -.36405000E+01, -.19902800E+02, -.31421700E+03, 0.11539400E+02, 0.99517700E+01, -.16363000E+02, 0.85187700E+02, -.10167500E+03, 0.41159300E+02, -.22696100E+02, -.10596600E+01, -.76941000E-01, 0.88350500E+00, -.59611800E+00, 0.92985900E+00, -.13629800E+01, 0.64760000E+00, -.39791800E+00, -.10443000E+01, -.77866200E-01, 0.86038800E+00, -.61043600E+00, 0.92476700E+00, -.13170000E+01, 0.66086800E+00, -.41261500E+00, -.10187600E+03, 0.43698400E+02, 0.15711200E+02, -.22517000E+02, 0.28416500E+02, -.34500100E+02, 0.17162800E+02, -.15947800E+02, -.54073600E+01, 0.54345500E+02, 0.31927100E+02, -.87197500E+01, 0.78448400E+00, 0.22939500E+02, 0.52462100E+02, -.17272200E+02, -.31907100E+01, -.78661800E+00, 0.34618300E+01, -.25721900E+01, 0.32874600E+01, -.39264500E+01, 0.32411700E+01, -.17206900E+01, -.10225000E+03, 0.13680400E+03, -.40016800E+01, -.18676800E+02, 0.37324400E+02, -.33008500E+02, -.27099200E+01, -.13694000E+02, 0.18803700E+01, 0.16766800E-01, -.15103400E+01, 0.12597000E+01, -.16340800E+01, 0.19599200E+01, -.14942500E+01, 0.90183300E+00, -.31001600E+01, -.36205300E+00, 0.29803200E+01, -.23851700E+01, 0.29527200E+01, -.33219500E+01, 0.30479000E+01, -.16550600E+01, -.33467300E+01, 0.10554700E+01, 0.20234900E+01, 0.10905600E+02, 0.13340800E+01, 0.70863100E+01, 0.58657200E+01, -.15902200E+01, -.63285200E+01, 0.11434400E+01, -.18431200E+02, 0.47162900E+01, 0.36274700E+01, 0.78939900E+01, -.30964600E+01, 0.55477900E+01, 0.91325800E+01, -.49412200E+01, 0.61211500E+00, 0.60851500E+00, 0.10662800E+00, -.66838600E+01, 0.22980200E+01, 0.79028900E+01, -.11831700E+01, 0.20529600E+01 }, { -.24685800E+00, 0.28645400E+00, -.91623200E+00, 0.61896700E-01, 0.11775000E+00, 0.49820400E-01, -.27071700E+01, -.18219500E+00, -.10840200E+00, 0.11850200E-01, 0.63585900E-01, 0.56272600E+00, 0.43916300E+00, -.41198100E+00, -.18568400E+00, 0.11521100E+01, 0.58164200E+00, 0.18856800E+00, -.12201000E+00, -.47715500E+00, 0.35968200E+00, 0.12464200E+00, 0.25494300E+00, -.18749800E+00, 0.61945200E-01, -.76280200E-01, -.70320700E-02, 0.26264400E-01, -.94760600E-01, -.11925100E+00, -.70287300E+00, 0.11366500E+00, 0.22570300E-02, 0.18009800E+00, 0.89342900E+00, 0.14062200E+00, -.37608600E-01, 0.21070200E+00, 0.38671700E+00, 0.24590700E-01, 0.11348800E+00, -.81858100E-01, -.75066900E+00, 0.18826200E+00, 0.63845600E-02, -.95432900E-01, -.81746700E-02, 0.62912900E+00, -.86699700E-02, 0.15426400E-01, -.27451900E-03, 0.74373000E-01, 0.47524700E-01, -.54630100E-01, 0.79004600E+00, 0.91947200E-01, -.44238200E-01, 0.25435900E+00, 0.22820600E+00, 0.46257800E-01, -.10842300E+00, -.18786400E-01, 0.22244500E-01, -.13968600E-01, -.52583200E-01, -.64533700E-02, -.31046900E-01, 0.99805100E-01, -.22692700E-01, -.16633200E-02, 0.10023400E+01, -.10998800E+00, -.12617400E+00, 0.20261700E-01, 0.48217800E-01, 0.79266900E-01, 0.19209900E+00, -.10532800E+00, -.14878000E+00, 0.65806100E-01, -.21533900E+00, 0.79053700E-01, 0.12474200E+00, -.32057600E-01, 0.57745100E-01, -.72555400E-02, 0.82245500E-01, -.79186900E-01, -.17666400E-01, -.67929900E+00, 0.31025500E+00, -.53817400E-02, 0.21332400E-02, -.86945500E-01, 0.41768700E+00, -.72376600E-01, -.54089700E+00, -.20963500E-01, -.45479400E-01, 0.43704700E+00, -.63536600E-01, -.10221800E+00, -.62445700E-01, 0.16541600E-01, -.39302100E-02, 0.35165800E-02, -.65973000E-01, -.50704700E-01, 0.29053600E+00, -.22878500E+00, 0.21156300E+00, 0.86790500E-01, -.11860400E+00, 0.24240400E+00, 0.11796800E+00, -.35324900E-01, 0.61611600E-01, 0.17674100E+00, 0.95806100E-02, 0.98844000E-01, 0.12380800E+00, -.10072700E-01, 0.39965100E-01, -.24603600E-01, 0.95866600E-01, 0.10276000E+00, 0.21337500E-01, 0.27673300E-01, -.14062300E+02, -.17415600E+00, 0.24395500E+00, -.21909500E+00, 0.32836700E+01, -.37237300E+01, 0.10401800E+01, -.49519600E+00, -.10328100E-01, 0.37779900E-01, -.67276200E-02, -.31725100E-01, 0.31775600E-01, 0.22574900E-02, 0.52952000E-02, -.18890400E-01, -.99612600E-02, 0.37764100E-01, -.70808900E-02, -.31655600E-01, 0.31517600E-01, 0.28767500E-02, 0.53362700E-02, -.18463700E-01, -.26817300E+01, 0.26453600E+01, -.20896800E-01, -.26770600E+00, 0.96261200E+00, -.11653500E+01, -.12258600E+01, -.97078400E-01, 0.11266600E+00, 0.11113500E+01, 0.31880400E+00, 0.31138400E+00, -.43271900E+00, 0.72655900E-01, -.14330100E+01, 0.12422800E+00, -.21089600E-01, 0.12507900E+00, -.77373900E-02, -.98674500E-01, 0.10011800E+00, 0.23690400E-01, -.55098500E-02, -.39542100E-01, 0.24739100E+01, -.13930400E+01, -.10574100E+01, -.13859800E+01, 0.11526100E+01, 0.10804300E+01, -.47481600E+00, -.14817800E+01, 0.12308000E-01, -.67197900E-01, 0.11607800E-01, 0.53809900E-01, -.50617100E-01, -.11259700E-01, -.41178300E-02, 0.26910400E-01, -.15810000E-01, 0.11296600E+00, -.76939700E-02, -.87180200E-01, 0.85109100E-01, 0.23384900E-01, -.56750600E-02, -.35394000E-01, -.36506500E-01, 0.42816000E-01, 0.22045400E+00, -.34121100E+00, 0.39694700E-01, 0.14557400E+00, 0.59757700E-01, -.37147900E-01, -.77690300E-01, 0.36599200E-01, -.13962900E+00, -.26877800E+00, -.10586500E+00, 0.20457400E+00, -.25808800E+00, -.19802100E+00, 0.13864600E+00, 0.39277100E+00, 0.21872400E-01, 0.27711800E-01, -.14708500E+00, 0.38419500E-01, 0.56381400E-01, 0.35089100E-01, -.41193400E-01, 0.34521500E-01 }, { -.10551500E+01, -.41907200E+00, 0.19275500E+01, 0.29547400E+00, -.88639100E-01, 0.37752800E+01, 0.56627200E+01, 0.36221600E-01, 0.41255800E+00, -.58063700E+00, 0.13770200E-01, 0.38377700E+00, -.11032500E+01, 0.51134200E+01, -.58973200E+00, -.30827400E+01, -.19624500E+01, -.61008000E+00, 0.35721500E+00, 0.84748100E+00, -.11382200E+01, -.37861300E-02, 0.10454200E+01, 0.35610300E+00, -.25195900E-04, 0.36475300E+00, 0.12921400E+00, -.28446900E-01, 0.12669400E+01, 0.13268900E+00, 0.45268600E+01, -.26005600E+00, -.92422500E+00, -.15076700E+00, -.42171500E+00, 0.22949100E+00, 0.67849100E-02, 0.49757600E-01, 0.36670800E+00, -.82832400E-01, 0.12723300E+00, -.17398500E+00, 0.45472200E+00, -.41998000E-01, 0.17202200E-01, -.27565300E+00, 0.72811500E-01, 0.14818500E+01, 0.14821500E-01, -.54889500E-01, 0.23182700E-01, 0.30774400E-01, -.21323300E+00, -.41395400E-01, 0.16311900E+01, -.60716900E-01, -.18789300E-01, 0.27218800E+00, -.12433000E+00, -.40091600E+00, -.15790800E+00, -.10504900E+00, 0.38766700E+00, 0.13779400E+01, -.16790100E+00, -.88644400E-01, 0.12614100E+00, -.67512300E+00, -.42133000E+00, 0.33600200E-01, 0.65201900E+00, -.42146200E+00, -.14485200E+00, 0.14976300E+00, -.59619000E-01, -.58484100E-01, -.82629000E+00, 0.35166400E+00, -.28700100E+00, 0.79513200E-01, 0.79479900E+00, -.17171900E+00, 0.31466900E+00, -.80889300E-01, 0.11613300E+00, -.61865700E+00, 0.59030800E-01, 0.70094600E+00, 0.17598100E+00, -.36424200E+00, -.24895900E+00, -.86884500E-01, 0.13250900E+00, -.12873500E+00, -.24921100E+00, 0.27155900E+00, 0.34211900E+00, 0.76246200E-02, -.11202000E+00, -.66387500E+00, 0.37186600E+00, -.13001300E+00, 0.88451100E-01, -.13745000E+00, 0.74790200E-01, 0.31866600E+00, 0.16145300E+00, 0.73829800E-01, -.14184400E+01, 0.97749800E+00, -.71689700E+00, 0.13488100E+00, 0.54547500E-02, 0.52165900E+00, -.75949700E+00, -.46166500E-01, -.38943200E-01, -.90210600E-01, 0.56189000E+00, -.12849900E+00, -.51570100E-01, -.34556800E-02, -.19916800E-01, 0.11730400E+00, -.86224600E+00, -.31517300E+00, -.51483900E+00, 0.16508500E+00, -.92550100E-01, -.52065200E+02, 0.83519500E-01, 0.14783300E+01, 0.30722900E+00, -.46176800E+01, 0.87038100E+01, -.81878800E+00, -.34648400E-01, -.21855400E+00, 0.39798100E-01, 0.36205000E-01, -.12017200E+00, -.92395100E-01, -.11839900E+00, 0.35619300E-01, -.41310300E-01, -.21653000E+00, 0.40577800E-01, 0.39777100E-01, -.11676500E+00, -.98462000E-01, -.11852100E+00, 0.39628700E-01, 0.66277600E+01, -.18142000E+02, 0.19359200E+01, 0.22229700E+01, 0.27618900E+00, -.63466300E+01, 0.21941200E+01, 0.17998800E+01, -.31407300E+02, 0.79863900E+01, 0.55965900E+01, 0.63168500E+01, -.29379500E+00, -.14957500E+02, -.46401200E+01, 0.60581000E+01, -.16327600E+00, -.92532400E+00, 0.17787000E+00, 0.97522700E-01, -.45902700E+00, -.60649200E+00, -.56394100E+00, 0.72386400E-01, 0.51615700E+02, -.19523800E+02, -.70152700E+01, -.93528100E+01, -.65688600E+01, 0.20689000E+02, -.44919400E+01, -.81505300E+01, 0.11618400E+00, 0.44347900E+00, -.87529500E-01, -.87750700E-01, 0.20212500E+00, 0.26269000E+00, 0.25222300E+00, -.81662400E-01, -.16160500E+00, -.85651900E+00, 0.16626300E+00, 0.10603000E+00, -.40474900E+00, -.55808500E+00, -.52122100E+00, 0.81366800E-01, -.86526000E-01, -.19098300E+00, 0.15988100E+01, 0.51286600E-01, -.17114200E+00, -.31434400E+00, -.42075300E+00, 0.15759900E+00, 0.41213100E+00, -.15152500E+00, 0.77842300E+00, 0.37873500E+00, 0.22630900E+00, 0.50802300E-01, -.17688400E+01, -.25212200E+00, -.38972900E-01, 0.13857100E+01, -.88753900E-01, -.11624400E+00, -.12608000E+01, -.39992200E+00, -.43967900E+00, -.90200500E-01, 0.18047000E+00, -.14409200E+00 }, { -.78335100E+00, -.33753700E+00, 0.37137200E+00, 0.52683900E+00, 0.87104500E+00, 0.19857800E+01, 0.73294000E+00, -.10977600E+01, -.23184500E+00, 0.35558600E+00, 0.54642900E-01, 0.39780300E+00, 0.71007000E+00, -.16923600E+01, 0.58486200E-01, 0.19783400E+01, 0.10363000E+01, -.95684700E+00, -.70459500E+00, -.83084100E+00, 0.17387300E+01, -.21879800E-01, -.86111100E-01, 0.20297100E+00, -.25195100E-01, 0.28159100E-01, -.26374600E+00, -.11066800E+00, 0.15746900E+00, -.26129700E-01, -.38288300E+00, -.54283900E-01, 0.72288700E-01, -.56590400E-01, 0.28418300E+00, -.77924000E-02, 0.14892300E-01, -.13602000E+00, 0.13329500E+00, 0.29629800E-02, 0.61476600E-01, -.11003800E+00, 0.13430700E+01, -.10738500E+00, 0.95426100E-01, -.29087500E+00, 0.56386500E-01, 0.39649300E+00, 0.39061100E-02, -.16951200E-01, 0.21153700E-01, 0.90882200E-02, -.32038500E-01, -.36391100E-01, 0.28174900E+00, 0.17134600E-01, 0.35161900E-02, -.55707500E+00, -.21797200E+00, 0.32219800E+00, -.60019600E-01, 0.58222000E-01, 0.12849800E+00, -.63451300E-01, -.18986600E+00, 0.23235300E-01, 0.16753000E-01, 0.44826500E-01, 0.64283700E-01, 0.35094200E-01, -.16128000E+01, 0.75191700E-01, 0.14032100E+00, 0.30684200E-01, 0.47152500E-02, -.92525600E-01, 0.28344100E+00, -.54595100E-01, 0.86607000E-01, 0.15515600E-01, -.63960900E+00, 0.61805300E-01, -.51569900E+00, 0.19863200E+00, 0.67031300E-01, 0.70691200E+00, -.21780700E+00, -.22971700E+00, -.11478400E+00, 0.21139900E+01, -.92933400E-01, 0.21929800E-01, 0.10213600E+00, 0.32809000E+00, -.70459400E+00, -.29554900E+00, -.62579200E+00, -.54863500E-01, -.62222100E+00, 0.81888900E+00, -.12889300E+00, 0.18363200E+00, 0.18951300E+00, 0.88875500E-01, 0.58019700E-01, -.19300700E+00, -.20324400E+00, -.16552700E+00, 0.57179600E-01, -.47865900E+00, 0.14649000E+00, -.14430400E+00, -.23193500E+00, -.36320300E+00, 0.38171400E-01, 0.16383000E-01, -.59801100E-01, -.17986600E-02, -.28767500E-01, -.13346200E+00, 0.26384100E+00, 0.75209000E-01, 0.52053300E-01, -.44199000E-01, -.25754000E+00, 0.99007000E-01, -.59424300E-01, -.11791200E-01, 0.18374200E+00, 0.80466300E-02, -.48473200E+01, -.53355800E+01, 0.36879600E+01, 0.23957000E+01, 0.21004500E+01, -.46815500E+01, 0.11782100E+00, 0.15079100E-01, 0.21377500E-01, -.90878900E-01, 0.79054800E-01, -.63403300E-01, 0.16492300E+00, -.11983300E+00, 0.11993500E+00, 0.13965000E-01, 0.22653600E-01, -.91082300E-01, 0.78226600E-01, -.58450700E-01, 0.16516500E+00, -.12016100E+00, -.53083500E+00, -.20059400E+00, -.61150400E+00, -.43008500E+01, 0.19578300E+01, 0.37888500E+01, 0.35447700E+01, -.29267700E+01, 0.22294300E+02, -.51486500E+01, -.86080700E+00, -.32665200E+01, -.69344600E+01, 0.96831200E+01, 0.62588200E+01, -.32170000E+01, 0.60041600E+00, 0.21070700E-01, 0.18624500E+00, -.33921600E+00, 0.17088600E+00, -.12337900E+00, 0.60513900E+00, -.45069800E+00, -.73769700E+01, 0.96166600E+01, 0.90184500E+01, 0.72061500E+01, -.72203700E+01, -.80692600E+01, -.38814300E+01, 0.79314000E+01, -.23938800E+00, -.30207100E-01, -.60790900E-01, 0.16921800E+00, -.11440800E+00, 0.56570800E-01, -.30388300E+00, 0.22075000E+00, 0.51500100E+00, 0.38001900E-01, 0.15821000E+00, -.30724300E+00, 0.14975100E+00, -.83483400E-01, 0.53971200E+00, -.40185900E+00, 0.37015700E+00, 0.24861400E+00, -.78386600E+00, -.55202300E+00, 0.29105900E+00, 0.80177800E+00, 0.54551700E+00, -.32766200E+00, -.57234900E+00, 0.25404900E+00, -.13100100E+01, -.95123900E+00, -.13127500E-01, 0.24750300E+00, 0.84976800E+00, 0.59050600E-01, 0.62072200E+00, -.33672800E+00, 0.16082000E+00, 0.15685200E+00, 0.10915100E+01, 0.11115100E+01, 0.79191700E+00, -.37100800E+00, -.26873800E+00, 0.37886800E+00 }, { 0.41317400E+01, 0.54584500E+01, -.43355200E+01, -.90492200E-01, -.22637000E+01, -.67050300E+01, -.75893300E+01, 0.49843700E+01, -.10038600E+01, -.43425500E+01, 0.11042800E+01, 0.33228600E+01, -.12301900E+00, 0.62654700E+00, 0.25332200E+01, 0.10120700E+02, 0.11220100E+02, 0.14291900E+01, 0.20892800E-01, -.23208800E+01, -.23297200E+01, 0.23638200E+01, 0.55706700E+01, -.24607400E+01, 0.97721000E+00, -.87551100E+00, 0.61106400E+01, 0.24032800E+01, 0.21609600E+00, -.65863200E+00, 0.23110700E+01, -.25088200E+00, -.69529300E+00, 0.18050200E+01, 0.80542900E+01, -.30182500E+00, -.18667000E+00, 0.18590800E+01, 0.26746100E+01, 0.69652700E+00, 0.99900700E+00, -.16530800E+01, -.63601100E+01, 0.13322100E+01, -.65159800E+00, 0.56204200E+01, -.11977300E+01, 0.35739900E+01, -.17800800E+00, 0.12713800E+00, -.50669100E+00, 0.38276500E+00, 0.10247800E+01, -.33799300E+00, 0.29355900E+01, 0.12630100E+01, 0.30776600E-01, 0.46949100E+01, 0.29306700E+01, 0.17695800E+00, -.27228400E+01, 0.59479800E-01, 0.58065500E+00, 0.22739200E+01, -.61309900E+00, -.11345800E+00, 0.30697500E+00, -.15223800E+01, -.84679800E+00, -.51457600E+00, 0.10818100E+02, -.19116900E+00, -.41253900E+00, -.23935100E+00, 0.71602400E+00, 0.60761100E+00, 0.67013500E+00, -.11813900E+01, -.86817200E+00, -.44739800E+01, 0.68509300E+01, -.58659800E+00, 0.17658500E+00, 0.56672300E+00, -.86809700E+00, 0.24063100E+01, 0.82633400E+00, -.68412100E+00, 0.93499700E+00, 0.76358500E+01, -.41743600E+01, 0.70690200E+00, 0.73007800E+00, 0.39315900E+00, 0.73504600E+00, -.28998500E+01, -.27826300E+01, -.69547800E+00, -.16130500E+01, 0.82892600E+00, -.21174700E+00, 0.26057800E+01, 0.29186800E+00, 0.39553000E+00, 0.57203400E+00, 0.31834000E-01, 0.87084100E+00, 0.21845900E+00, 0.32182400E+01, 0.25204500E+00, -.10506800E+01, -.32682600E+00, -.27895900E+01, 0.43961400E+01, -.26373000E+01, 0.11954700E+01, -.48189300E+00, 0.81706700E+00, 0.20373400E+01, -.22029800E+00, -.76168100E+00, 0.43585100E-01, 0.76082900E+00, -.37002000E+00, -.19772200E+01, 0.81991500E-01, -.12822300E+01, 0.42858700E+00, -.96509900E+01, 0.21248800E+01, 0.11807000E+00, -.22096300E+02, 0.75008000E+01, 0.17779100E+02, -.41801900E-01, -.20557300E+02, 0.44772200E-01, 0.94434300E-01, 0.10723400E+00, -.37359200E+00, 0.56515100E+00, 0.32131700E+00, 0.45933300E+00, -.30563100E+00, 0.50644300E-01, 0.91681200E-01, 0.10367900E+00, -.37734800E+00, 0.56276600E+00, 0.32755000E+00, 0.46155300E+00, -.30821600E+00, -.14982700E+02, 0.41480000E+02, 0.25382400E+01, -.40220400E+01, -.94792100E+00, 0.89596300E+01, -.10478900E+02, 0.21583200E+00, 0.63913300E+02, -.31561600E+02, -.47393000E+01, -.97833700E+01, 0.33900100E+01, 0.38357300E+02, 0.20735700E+02, -.50127200E+01, 0.27564600E+00, 0.39836300E+00, 0.41651900E+00, -.13284100E+01, 0.22237500E+01, 0.17337300E+01, 0.21450400E+01, -.99902600E+00, -.29512700E+03, 0.18199200E+03, 0.56295600E+02, 0.68020400E+02, 0.27710000E+02, -.11118500E+03, 0.67965100E+01, 0.64154600E+02, -.11009300E+00, -.20364900E+00, -.17567500E+00, 0.68326200E+00, -.10125500E+01, -.73191900E+00, -.96539400E+00, 0.52582900E+00, 0.25071100E+00, 0.40053800E+00, 0.32661700E+00, -.11997400E+01, 0.19380400E+01, 0.15743800E+01, 0.19517700E+01, -.89527300E+00, 0.13788700E+00, 0.68370000E+00, -.44595000E+01, 0.14945400E+01, 0.74511900E+00, 0.30058100E+01, 0.30473500E+01, -.79747400E+00, -.31305700E+01, 0.66028800E+00, -.43943300E+01, 0.33684800E+00, -.69113100E+00, 0.14257400E+01, 0.47169200E+01, 0.22987000E+01, 0.28252800E+01, -.17937100E+01, 0.40948800E+00, 0.43460200E+00, 0.28066100E+01, 0.38746800E+01, 0.23821400E+01, 0.12734600E+01, -.70891800E+00, 0.84337700E+00 }, { 0.24082600E-01, -.64947800E-01, 0.27388000E+00, 0.28888900E+00, 0.12037500E+00, -.95416200E+00, 0.33550200E+00, -.59864100E-01, 0.11786500E+00, -.15401800E-01, -.17396300E-02, 0.68598900E-01, 0.15111200E+00, -.20004200E+00, -.16212000E+00, 0.18704500E-01, 0.13699900E+00, -.33351900E-01, 0.49271700E-02, -.13316900E-01, 0.55243900E-01, -.12487300E-01, -.39504500E-02, -.22015100E-01, 0.59059300E-02, -.80087400E-02, -.17834800E-01, -.18955400E-01, -.67420000E-01, -.33349500E-01, -.44270300E+00, 0.35596900E-01, 0.76217200E-01, 0.33249100E-01, 0.11920500E+01, -.90218400E-03, 0.14671700E-02, -.66546300E-02, 0.20375600E-01, 0.27775600E-02, -.87091900E-03, -.10387100E-01, -.26909600E-02, 0.10448300E-01, 0.22954300E-02, -.96807700E-02, -.51403800E-02, 0.24079500E-01, 0.18547600E-03, -.12279400E-02, 0.72942900E-02, 0.58960900E-02, -.33717200E-02, -.36133400E-02, -.68713400E+00, 0.26177700E-02, -.27877500E-02, -.52169200E-03, 0.50790900E-02, 0.92522200E-02, 0.22919900E-01, 0.38819800E-02, -.21927500E-01, -.20510100E-01, 0.27666600E-01, -.40376100E-02, -.23484800E-02, 0.21299800E-01, -.11708200E-01, -.50137500E-02, 0.38599600E+00, -.26298100E-01, -.58732000E-02, -.42892600E-02, 0.22757500E-01, 0.10106800E-01, 0.50589600E-01, -.19201900E-01, 0.12184600E-01, 0.43055900E-01, 0.29006200E-01, -.85202600E-02, -.42628500E-01, -.22271300E-02, -.23368900E-03, -.23034300E-01, 0.20048100E-02, 0.92125800E-02, -.26559700E-02, 0.18861500E+00, -.77590600E-01, -.69701200E-02, -.11098700E-01, -.62416500E-02, -.17695700E+00, -.25741100E-01, -.23577700E-01, -.52314800E-02, 0.15757000E-01, 0.60292600E-01, 0.11189400E-01, 0.11175700E-01, -.31554500E-02, 0.36906100E-02, -.47687000E-02, -.34025300E-02, 0.17156700E-01, 0.17198000E-01, 0.69427100E-01, -.53841600E-01, -.54681700E-02, 0.22808400E-02, -.13204700E-01, 0.14087200E-01, 0.35993200E-01, 0.31865900E-02, 0.43477200E-02, 0.24738100E-01, -.32844700E-02, 0.13898400E-01, 0.18548800E-01, -.35955100E-01, 0.26989900E-01, 0.83753100E-02, 0.17516300E-01, 0.13024500E-01, 0.38743300E-01, -.15650300E-01, 0.17920600E+00, -.62751600E-02, -.24753000E-01, -.97037900E-02, 0.24253100E+00, 0.88131200E-01, 0.43395400E+00, -.58514800E-01, 0.52112300E-04, -.20898500E-01, 0.10499500E-01, -.48971600E-02, 0.27513900E-01, -.15691700E-01, 0.40813500E-01, -.86964500E-02, 0.22022200E-03, -.20939600E-01, 0.10292700E-01, -.51226400E-02, 0.27566900E-01, -.15117000E-01, 0.40946100E-01, -.90406400E-02, -.79276300E+00, 0.56965000E+00, -.11939500E+00, -.21362700E+00, 0.64252500E+00, 0.92397600E-01, 0.24326100E+00, -.19094500E+00, 0.17878800E+01, -.40062500E+00, 0.10147900E+00, -.40418200E+00, -.12531400E+00, 0.10037500E+01, 0.82906400E+00, -.41336500E+00, 0.28262300E-02, -.87544600E-01, 0.37636900E-01, -.26172700E-01, 0.11175900E+00, -.44948500E-01, 0.41233600E+00, -.43298300E-01, -.41234900E+01, 0.24948400E+01, 0.92242000E+00, 0.64577300E+00, 0.47762400E+00, -.17027200E+01, 0.43375400E+00, 0.68875400E+00, 0.34425100E-02, 0.36615800E-01, -.18267400E-01, 0.11016800E-01, -.51284700E-01, 0.23439500E-01, -.80618200E-01, 0.18877200E-01, -.35327800E-02, -.72485200E-01, 0.32715700E-01, -.23833100E-01, 0.98171100E-01, -.39100600E-01, 0.15995700E+00, -.38673200E-01, 0.45422900E-02, 0.28209000E-01, -.10685100E+00, 0.25141900E+00, 0.38320700E-01, 0.15079700E+00, 0.18116400E+00, -.46983200E-01, -.18544600E+00, 0.32824900E-01, -.26020200E+00, 0.11157200E+00, 0.46971700E-01, 0.15581700E+00, 0.11186800E+00, 0.19813000E+00, 0.15836300E+00, -.25440500E+00, 0.19909000E-01, 0.17324900E-01, 0.24585100E+00, -.16103800E+00, 0.73668800E-01, 0.13718000E+00, -.32752100E-01, 0.58936700E-01 }, { 0.55819500E+00, 0.70556500E+00, -.36177300E+00, -.69947200E+00, -.63068700E+00, 0.22559300E+01, 0.12156900E+01, 0.28350000E+00, -.17335400E+00, -.60120400E+00, 0.30899900E-01, -.43839900E+00, -.89974500E+00, 0.26631200E+01, 0.15396800E-01, -.17559900E+01, -.28023700E+00, 0.15553300E+00, 0.10899400E+00, 0.49534500E+00, -.55832200E+00, 0.14158600E+00, 0.81218400E+00, -.86296800E+00, 0.11467300E-01, -.26235900E+00, 0.88260300E+00, 0.38662800E+00, 0.34376100E-01, 0.30923900E-01, 0.95457800E-01, 0.53412800E-01, -.60496500E-02, -.68162300E-01, -.34651600E+01, 0.24969400E-01, 0.26704300E-01, -.33208500E-01, -.13954100E+00, 0.39146100E-01, -.77531800E-01, -.94715000E-01, -.60908500E+00, 0.26207200E+00, 0.65227100E-01, -.22301200E+00, 0.30242000E-01, -.56629100E+00, -.87676300E-02, 0.25706100E-02, -.42522900E-01, 0.39683600E-01, 0.34755500E-01, -.55453500E-02, 0.22884600E+01, 0.81221700E-01, -.11665300E-01, 0.97837900E-01, 0.17413500E+00, 0.32183400E+00, 0.18880400E+00, 0.77369900E-01, -.12747900E+00, -.47057900E-01, 0.20096900E+00, -.18640100E-01, -.39583100E-01, 0.27947000E-01, -.61184800E-01, -.92959000E-02, -.92806800E+00, -.10169100E+00, 0.12786600E-01, -.49268100E-01, -.27188100E-01, 0.66858800E-02, 0.18478700E+00, -.95775300E-01, 0.25873500E+00, 0.56586500E+00, 0.85022000E-01, -.51777600E-01, -.31246200E+00, 0.32004300E-02, -.16038000E-01, 0.51032900E-01, -.11703100E-01, -.20984200E+00, -.14112800E+00, -.38485100E+00, -.37912800E-01, 0.17037600E-01, 0.45391400E-01, -.76728200E-01, -.17618600E+01, 0.13595600E+00, 0.39423000E+00, -.12837300E-01, -.25947600E+00, -.27938000E+00, 0.35821600E-01, 0.14808700E+00, 0.10480800E+00, 0.50585300E-01, -.11601800E-01, -.22939700E+00, -.34423600E-01, -.27960700E+00, -.29155400E+00, 0.11814800E+00, 0.40224200E+00, 0.21369000E+00, 0.42570400E-01, 0.20745100E+00, -.13310100E+00, 0.13508500E-01, 0.80682800E-01, 0.77595000E-01, 0.44270200E-01, 0.11507600E+00, 0.95018700E-01, 0.35460000E+00, -.77182200E-01, 0.84583200E-01, -.24557900E+00, -.25502900E-01, 0.22023000E+00, 0.30702300E-01, 0.39853900E+00, 0.65355400E-01, -.44342800E+00, 0.12743900E+00, 0.36397600E+01, -.61700100E+01, -.36431100E+01, -.65672500E-02, -.21503800E-01, 0.59368500E-01, -.18329700E-01, 0.21064400E-01, -.16829000E+00, 0.43723300E-01, -.19009900E+00, 0.36377900E-01, -.21623600E-01, 0.59419900E-01, -.17644000E-01, 0.22144400E-01, -.16832500E+00, 0.42138900E-01, -.19027900E+00, 0.37394300E-01, 0.18868400E+02, -.13792500E+02, -.17731900E+01, -.32166600E+01, -.25876900E+01, 0.24017600E+01, 0.40757500E+01, -.35001100E+01, -.18254800E+02, 0.93613700E+01, 0.83543800E+00, 0.38764300E+01, -.64754700E+00, -.91408600E+01, -.44413100E+01, 0.40341300E+01, -.72431100E-01, 0.25022500E+00, -.35643900E-01, 0.96446200E-01, -.69784800E+00, 0.70859200E-01, -.16952400E+01, 0.16667600E+00, 0.50171300E+02, -.29794200E+02, -.12744100E+02, -.11630800E+02, -.33975400E+01, 0.21948300E+02, -.35390500E+01, -.10763600E+02, 0.17681700E-01, -.10311300E+00, 0.30394400E-01, -.42115200E-01, 0.30933400E+00, -.57823400E-01, 0.38053700E+00, -.70126600E-01, -.44655900E-01, 0.20798000E+00, -.30622300E-01, 0.87998400E-01, -.60628800E+00, 0.59691400E-01, -.76434700E+00, 0.14746500E+00, -.89699000E-01, -.14347700E+00, 0.15186500E+01, -.10452500E+01, -.18040700E+00, -.62577500E+00, -.90670100E+00, 0.21200300E+00, 0.90753600E+00, -.15632800E+00, 0.21004600E+01, -.56327500E+00, -.22941300E+00, -.11031000E+01, -.14106900E+01, -.10719000E+01, -.86235200E+00, 0.25089900E+01, -.95266100E-01, -.89778000E-01, -.50414900E+00, 0.28600300E+00, -.44352000E+00, -.61447200E+00, 0.15923800E+00, -.25432500E+00 }, { -.11274700E+01, -.45148600E+00, 0.19701100E+01, 0.32008700E+00, -.15235700E+00, 0.37600000E+01, 0.58533200E+01, -.48592400E+00, 0.52583900E+00, -.81514900E+00, 0.13493900E-01, -.36739200E-01, -.18309300E+01, 0.68646000E+01, -.16749800E+00, -.43149500E+01, -.26121000E+01, -.88029900E+00, 0.84292000E+00, 0.10076200E+01, -.10477100E+01, -.20981100E+00, 0.52535600E+00, 0.73603600E+00, -.49180500E-01, 0.45195800E+00, -.16745600E+00, -.12829700E+00, 0.10322500E+01, 0.29218400E+00, 0.37876500E+01, -.18505000E+00, -.94489800E+00, -.30658600E+00, -.36564900E+01, 0.26176200E+00, -.65458100E-01, 0.15342200E+00, -.51730800E+00, -.13861800E+00, 0.84810100E-01, 0.29827500E+00, 0.92189300E+00, 0.11761800E+00, 0.51363800E-01, -.62845900E+00, 0.32046600E+00, 0.50974500E+00, -.18922400E-01, 0.26721800E-01, -.51068500E-01, -.39375000E-01, 0.10468900E+00, 0.11378600E-01, 0.35123200E+01, 0.36942400E-01, 0.39556300E-01, 0.14143900E+00, 0.18771400E+00, 0.11824000E-01, 0.22533700E+00, -.65547200E-01, 0.13521600E+00, 0.52475500E+00, -.39376600E-01, -.29014100E-01, 0.15601800E+00, -.34774900E+00, -.23602900E+00, 0.43205400E-01, -.10808600E+01, -.27785200E-01, -.15315000E-01, 0.17076400E+00, -.21769800E+00, -.12954400E+00, -.34263900E+00, 0.18247500E+00, 0.51123100E+00, -.12988400E+01, -.66883200E-01, 0.26116500E-01, 0.40747800E+00, 0.17737300E+00, -.15033000E+00, -.17513800E+00, 0.45709000E-01, 0.64356900E+00, 0.34612700E-01, 0.10229600E+00, 0.20725200E+00, -.41633600E-01, 0.14260900E+00, 0.48232900E+00, -.28497300E+00, 0.67273300E-01, 0.61913800E+00, 0.82272100E-02, -.19933200E+00, -.65812700E+00, 0.22366700E+00, -.25130700E+00, 0.12771900E+00, 0.16254100E+00, 0.42538100E-01, 0.21458600E+00, -.77510400E-01, -.14166800E+00, -.55881000E+00, 0.61597700E+00, 0.89754500E-01, -.45538400E-01, 0.17773600E+00, -.26072600E+00, -.83153900E+00, 0.69428500E-02, -.90045700E-01, -.13836100E+00, 0.28125800E+00, -.12169000E+00, 0.49466600E-01, 0.62721900E-01, 0.33878400E-01, 0.11973700E+00, -.55652600E+00, -.36041400E+00, -.68486300E+00, 0.12647300E+00, -.89617300E+00, 0.48824800E+00, 0.65503100E+00, 0.17083400E+00, -.90117600E+01, 0.16520000E+01, 0.10011900E+02, -.20950300E+00, -.27302800E-01, 0.62096800E-01, -.18588700E-01, 0.29141700E-01, 0.28384100E+00, -.30027300E+00, 0.53843600E+00, -.21016400E-01, -.25859200E-01, 0.60938300E-01, -.19140400E-01, 0.26415200E-01, 0.28299400E+00, -.29463500E+00, 0.53898600E+00, -.24612200E-01, -.75448100E+01, 0.13117100E+02, 0.14135800E+01, 0.39093200E+01, -.44970900E+01, -.48244900E+01, -.10554800E+02, 0.45309500E+01, 0.35512500E+02, -.16839500E+02, -.10851200E+01, -.87376400E+01, 0.25568000E+01, 0.18540600E+02, 0.10970400E+02, -.88413700E+01, -.12670900E+00, 0.36449900E+00, -.16518600E+00, 0.12884500E-01, 0.11403500E+01, -.99690300E+00, 0.59107500E+01, -.20963600E+00, -.89325600E+02, 0.59996400E+02, 0.22873100E+02, 0.21205800E+02, 0.51483300E+01, -.37276500E+02, 0.50051000E+01, 0.19573500E+02, 0.10809700E+00, -.14929000E+00, 0.30693500E-01, -.29969700E-01, -.51806800E+00, 0.50306600E+00, -.10661900E+01, 0.67626000E-01, -.18616100E+00, 0.34327800E+00, -.12905800E+00, 0.54355100E-02, 0.99821400E+00, -.87659600E+00, 0.21549000E+01, -.18481300E+00, -.24242600E-01, 0.37212800E+00, -.13710700E+01, 0.21959000E+01, 0.44766100E+00, 0.67777100E+00, 0.12892400E+01, -.52027900E+00, -.13185800E+01, 0.38378200E+00, -.35700400E+01, 0.15274400E+01, 0.13006400E+01, 0.22602600E+01, 0.10884900E+01, 0.37833900E+01, 0.99770600E+00, -.41337600E+01, 0.22126400E+00, 0.22426900E+00, -.47349100E+00, -.63579600E+00, 0.89219100E+00, 0.12919400E+01, -.40434200E+00, 0.65071000E+00 }, { 0.86141300E+00, 0.28513900E+00, -.15565800E+01, -.14733000E+01, -.10538400E+01, -.21224900E+01, -.19926300E+01, 0.11619700E+01, 0.90948100E-01, 0.19083700E+00, -.22253600E+00, -.14330400E+01, -.25239000E+00, -.37965500E+01, 0.13445500E+01, 0.55255400E+00, 0.12490000E+01, -.29464200E+00, 0.23652700E+00, -.55264400E-01, 0.12138000E+00, -.17987700E+00, -.31212500E+00, -.38004500E+00, -.14277200E-01, -.17742800E+00, -.28268300E+00, -.59249900E-01, -.35790200E+00, -.28852500E+00, -.20199000E+01, 0.26249000E-01, 0.40888800E-01, 0.16454500E+00, -.16283700E+01, 0.22840700E-01, -.11174400E+00, -.94454700E+00, 0.14284000E+00, -.19853100E+00, -.34818100E+00, -.71596900E+00, 0.19845400E+01, -.35624800E-01, 0.47869800E+00, -.57227900E+00, 0.24159000E+00, -.17432900E+01, -.30402400E-01, -.65693700E-01, 0.36970900E-02, -.59534700E-03, 0.66272300E-01, 0.16815600E-01, -.19688400E+01, 0.10632800E+00, 0.14060500E+00, -.23192800E+01, -.37682300E+00, 0.68121100E+00, -.53862500E+00, 0.16753100E+00, 0.55960100E+00, 0.15275400E+00, -.78643700E+00, -.33918100E-01, 0.15367600E+00, 0.11089900E+00, -.11640300E+00, 0.10646300E+00, -.48858900E+01, -.23873200E+00, 0.96709700E-01, -.12530900E+00, 0.19114000E+00, 0.31014400E+00, 0.51952900E+00, 0.13801200E+00, 0.23949200E+01, -.59963800E+00, -.29516600E+00, 0.17345500E-01, 0.38990900E+00, 0.21306900E+00, -.82014400E+00, -.39711900E+00, -.37190300E+00, 0.43523100E+00, -.17464500E+00, 0.10106600E+01, -.11678700E+01, -.26248500E+00, -.19783900E+00, -.23760900E+00, -.84038900E+00, -.23900000E+00, 0.50159500E+00, 0.15346700E+00, 0.70651600E-01, -.18732300E+01, -.14138300E+00, -.10243800E+01, 0.57272200E-03, -.19216300E-01, -.78920400E-01, 0.19855700E+00, -.60920700E+00, -.22450300E-01, -.88908300E+00, 0.96084300E+00, 0.14424800E+00, 0.12236800E-01, 0.25103700E+00, -.50310100E+00, -.22199800E+00, 0.76984700E-01, 0.37550500E-01, -.32209300E+00, 0.14660000E+00, 0.11569400E+00, -.22804900E-02, 0.76783500E+00, -.22582600E+00, 0.55205400E-01, 0.20580100E+00, 0.26572700E-01, 0.12854400E+00, -.93269900E-01, 0.18038700E+00, -.10402700E+00, -.19954300E+00, -.48045400E-01, 0.25300800E+01, -.52041300E+00, -.11048500E+00, 0.30351300E+01, 0.50613200E-01, 0.18018000E+00, -.46442200E-01, -.36342900E-02, -.76161000E-01, 0.17718700E-01, -.94286300E-01, 0.27939500E-02, 0.51408800E-01, 0.17992800E+00, -.45941100E-01, -.35985600E-02, -.76584200E-01, 0.17968300E-01, -.94640500E-01, 0.33793300E-02, 0.51210200E+01, -.21518700E+01, -.14619800E+00, -.18880200E+00, -.20982900E+01, -.62219900E+00, -.10042300E+01, 0.55660100E+00, -.13790000E+01, 0.35040200E+00, 0.16496100E+00, 0.72372200E+00, -.21655200E+01, -.29780100E+01, -.39982700E+01, 0.44867800E+00, 0.20615700E+00, 0.74034900E+00, -.13695800E+00, 0.11619300E-01, -.36624800E+00, 0.28588900E-01, -.11182400E+01, 0.51012500E-01, 0.17966600E+02, -.15483400E+02, -.74128300E+00, -.12967900E+01, -.47785100E+01, 0.55754500E+01, -.44335100E+01, -.21281800E+01, -.10787000E+00, -.33449700E+00, 0.74856700E-01, 0.34591800E-02, 0.15496500E+00, -.31131200E-01, 0.19899200E+00, -.14972800E-01, 0.19206900E+00, 0.64542700E+00, -.11595900E+00, 0.12413300E-01, -.32258700E+00, 0.30060900E-01, -.42349500E+00, 0.48128700E-01, 0.15029400E+00, 0.87388500E-02, 0.78979200E+00, -.13366900E+01, -.27907300E-01, -.29077900E+00, -.66714600E+00, 0.57073500E-01, 0.68522500E+00, -.21262600E-01, 0.39741700E+00, -.59696400E+00, -.33488600E+00, -.15353000E+00, -.79303700E+00, -.54821400E+00, -.50442800E+00, 0.15454900E+00, -.12381600E-01, 0.63658500E-02, -.87761900E+00, 0.43363900E+00, 0.11525700E-01, -.24959800E+00, 0.79323900E-02, -.87474800E-01 }, { -.73894200E+00, -.24779300E+00, 0.61685600E+00, 0.30111700E+00, 0.21611800E+00, 0.16218800E+01, 0.14855200E+01, -.43889400E+00, 0.20082900E+00, -.28759200E+00, -.22086800E-01, 0.65295800E-01, -.47209900E+00, 0.24769400E+01, -.33535300E+00, -.17635600E+01, -.96294600E+00, -.73198500E+00, -.10484400E+00, 0.38908000E+00, -.74295100E-01, -.61864800E-01, 0.38732200E-01, 0.27378000E+00, -.20084700E-01, 0.86914100E-01, -.26587400E+00, -.88238400E-01, 0.50776000E+00, 0.55791500E-01, 0.10693500E+01, -.10213100E-01, -.33172300E+00, -.72833100E-01, -.15560900E+01, 0.21941200E+00, 0.35844700E-02, 0.10046400E+00, 0.99712600E-01, -.49604900E-01, 0.13817400E+00, 0.87337300E-01, 0.42742800E+00, 0.24690000E-01, 0.46132100E-01, -.76007900E+00, 0.14161700E+00, 0.66775700E+00, 0.14178000E-01, -.20884500E-01, 0.41612600E-01, 0.24678400E-01, -.17080900E+00, -.11929900E-01, 0.20296600E+01, -.52963200E-01, -.32846200E-01, 0.57910700E-01, -.10361300E+00, -.64814900E-01, 0.15064200E+00, -.34563700E-01, 0.37119200E-01, 0.41740800E+00, 0.10215700E+00, -.39355800E-01, 0.14973700E-01, -.16747400E+00, -.17802200E+00, 0.25199600E-01, -.45952800E+00, -.24747500E+00, -.10485900E+00, 0.10852500E+00, -.32478200E-01, 0.15170900E-01, -.10100700E-01, -.20678100E-01, -.44863000E-01, -.17322500E-01, -.10657900E+00, -.36066500E-01, -.85119600E-02, 0.10838300E-01, 0.48768200E-01, -.17811200E+00, -.46715500E-01, 0.14889200E+00, -.25577200E-01, 0.22617500E+00, -.11072200E-02, -.19538200E-01, -.18464500E-01, -.62409400E-01, 0.74263900E-01, 0.55808800E-01, -.21459400E+00, 0.14192700E-01, -.33605200E-01, -.14153300E+00, -.11488100E+00, -.24543800E+00, -.31144200E-01, -.42384700E-01, 0.13116100E-01, -.13225900E-02, -.32610200E-01, 0.46879700E-02, 0.50670300E-01, 0.12582700E+00, 0.74730800E-01, -.94185300E-03, 0.25369100E-01, -.24596500E-01, -.52217700E-01, -.36773800E-02, -.44359100E-01, 0.28941000E-01, -.25402400E-03, 0.32455200E-01, -.28079900E-02, 0.10580500E+00, -.12721200E-01, 0.11441200E-01, -.39400300E-01, -.37791200E-01, 0.85129300E-01, -.30335500E-02, -.73361000E-01, -.53652700E-01, 0.14404700E-01, 0.36104000E-02, -.11628700E+00, 0.15054500E+00, 0.33887200E-01, 0.11547900E-01, 0.22144000E+01, -.21673300E-01, -.82153800E-02, -.33558200E-02, -.55641900E-02, 0.14557400E-01, -.13888800E-01, 0.13545500E-02, 0.92791900E-02, -.21532000E-01, -.83682900E-02, -.33485100E-02, -.53617400E-02, 0.14071200E-01, -.13696900E-01, 0.13775400E-02, -.22880200E+01, 0.80847500E+00, 0.13707600E+00, 0.57522700E+00, 0.51782000E+00, -.69598300E+00, 0.25262500E+00, 0.42647800E+00, -.26334200E+01, 0.49362600E+00, 0.44565200E+00, 0.61121100E+00, 0.43553000E+00, -.97225500E+00, -.61548000E+00, 0.66480300E+00, 0.25915600E-01, -.83657100E-01, -.43209500E-01, -.16866800E-01, -.10702000E-01, 0.56674300E-01, -.21486100E-02, 0.12926100E-02, -.14961400E+00, -.38988300E-01, -.78997300E+00, -.71532600E+00, 0.92694700E+00, 0.47397900E+00, 0.19265100E+00, -.80058200E+00, -.14468500E-01, 0.39896200E-01, 0.17575200E-01, 0.63380600E-02, 0.75074800E-02, -.22724500E-01, 0.23806200E-01, -.22404600E-02, 0.23690800E-01, -.74183500E-01, -.37676400E-01, -.14132600E-01, -.99428500E-02, 0.47200300E-01, -.40989100E-01, 0.15647200E-02, 0.31864000E-01, -.18636200E-01, -.94694500E-01, 0.48828600E-01, -.19249000E-01, -.85066600E-01, -.25091500E-01, 0.20696600E-01, 0.27684700E-01, -.16740800E-01, 0.21713700E-01, 0.36411400E-01, -.40381900E-01, -.28744500E-01, 0.95324400E-01, -.59995000E-02, -.46518100E-01, 0.30703900E-01, -.94602900E-02, -.11357700E-01, -.14036700E-01, -.76635000E-01, -.54755600E-01, 0.78676000E-01, 0.18844300E-01, -.26448600E-01 }, { 0.22854600E+00, 0.30209700E+00, -.17973100E+00, 0.15720700E-01, -.55604100E-01, -.17203700E+00, -.87983500E-01, 0.23837600E+00, -.36944400E-01, -.13211600E+00, 0.36644400E-01, 0.13774000E+00, 0.24186200E-01, -.17397800E-01, 0.54231200E-01, 0.41820000E+00, 0.38153300E+00, 0.12685600E+00, 0.54154500E-02, -.94186600E-01, -.78675200E-01, 0.69544700E-01, 0.15072900E+00, -.14823900E+00, 0.25600300E-01, -.57730800E-01, 0.16004300E+00, 0.58253100E-01, -.87322100E-01, -.41517300E-01, -.19868000E+00, 0.15541000E-01, 0.60410900E-01, 0.51369000E-01, 0.61266300E+00, -.15234400E-01, 0.12113300E-02, 0.14227500E-01, 0.14671000E+00, 0.18588300E-01, 0.19525600E-01, -.10514400E+00, -.11781600E+00, 0.48021700E-01, 0.44126600E-01, 0.25972400E-01, -.26198100E-01, 0.79724300E-01, 0.29276700E-03, -.75968400E-02, 0.27637700E-01, 0.28907800E-01, -.45341700E-01, -.23515900E-01, -.19620600E+00, 0.23665200E-01, -.19831000E-01, -.41816300E-01, 0.20967400E-01, 0.60921400E-01, 0.53938100E-01, 0.32059100E-01, -.20180500E-01, -.60753000E-01, 0.11301200E-01, 0.11901900E-02, 0.74878300E-02, 0.26222300E-01, -.31033400E-02, -.27655500E-02, 0.70249400E-01, 0.12172700E-01, -.82421800E-02, -.43059000E-02, -.31356100E-01, 0.97189700E-02, 0.52955700E-01, -.33576400E-01, 0.69054800E-01, -.66431000E-01, -.26946300E-01, 0.28862600E-01, 0.61500800E-01, 0.95797000E-02, -.55724600E-01, 0.20452500E-01, 0.16360800E-01, -.21462400E-02, -.68167000E-02, -.35162500E+00, 0.21680200E-01, 0.60093800E-02, 0.41267500E-02, 0.26878500E-01, -.12547600E+00, -.68920200E-01, 0.12406500E+00, 0.18236600E-03, 0.64094900E-03, -.43381700E-01, 0.24440900E-01, 0.28604100E-01, 0.11203200E-01, 0.11284500E-02, -.25412800E-02, 0.99500500E-02, -.11175500E-01, 0.97465700E-02, 0.12628400E-01, 0.14922500E-01, -.26281300E-01, 0.53137000E-02, 0.15007700E-01, 0.33462700E-01, 0.21157400E-01, -.48158100E-02, 0.53263300E-02, 0.20793600E-02, -.11068600E-01, -.34164500E-03, -.12988100E-01, -.36692700E-01, 0.15397200E-01, -.23887600E-01, 0.88453300E-01, 0.34580800E-02, 0.17019900E-01, -.68799200E-02, -.37966300E-01, -.18335900E-01, 0.26939700E-01, -.10999800E-02, -.28000100E+00, -.59922100E-01, 0.18222200E-01, -.57416300E-02, -.28352600E-02, 0.28301800E+01, 0.10537900E-02, 0.20097600E-02, -.27462300E-02, 0.95241000E-02, -.11279700E-01, 0.31663300E-02, -.61879100E-02, 0.17460900E-01, 0.10220700E-02, 0.21146500E-02, -.28109100E-02, 0.94188000E-02, -.11330900E-01, 0.33139100E-02, 0.61067900E+00, -.30670700E+00, -.18754200E+00, -.52954000E-01, 0.11497000E+00, 0.21098600E+00, 0.12774300E+00, -.84584000E-01, -.11136200E+01, 0.62134100E+00, -.35031100E-01, 0.23983700E+00, -.58497500E-01, -.69033300E+00, -.59881000E+00, 0.17449300E+00, -.22999200E-01, 0.66805700E-01, 0.62631300E-02, 0.11766100E-01, -.10392800E-01, 0.32677500E-01, -.10851200E+00, 0.16969500E-01, 0.43588500E+01, -.24648200E+01, -.11116700E+01, -.12358800E+01, 0.70783000E-01, 0.18710900E+01, 0.84122300E-01, -.11810600E+01, 0.90460800E-02, -.31218700E-01, -.13889100E-02, -.45603500E-02, 0.52060700E-02, -.16353500E-01, 0.23795400E-01, -.67707500E-02, -.18177300E-01, 0.57811900E-01, 0.49475200E-02, 0.10432800E-01, -.91751600E-02, 0.28425300E-01, -.50056000E-01, 0.14683300E-01, -.21983100E-01, -.38400600E-02, 0.85982400E-01, -.34536200E-01, -.84933900E-02, 0.12371400E-02, -.25191700E-01, 0.12146200E-01, 0.13067200E-01, -.70219400E-02, 0.12766600E+00, -.36357200E-01, -.56272400E-02, -.27282300E-01, -.76205200E-01, -.97203200E-01, -.22659300E-01, 0.10571500E+00, -.45347500E-02, -.22584700E-02, 0.55650200E-01, -.86726900E-01, -.62031500E-01, -.26700100E-01, 0.60488200E-02, -.16170000E-01 }, { 0.92945600E-01, 0.38128800E-01, -.16897500E+00, 0.16257600E-01, -.36937400E-01, -.32165000E+00, -.27389900E+00, 0.14645100E+00, -.47827800E-01, 0.97286700E-01, -.20521600E-02, -.58038300E-01, 0.11201900E+00, -.63518500E+00, 0.10169200E+00, 0.38128400E+00, 0.18413400E+00, 0.14661800E+00, 0.22435700E-01, -.82774600E-01, 0.36329100E-01, 0.43113500E-03, -.58130300E-01, -.28789800E-01, -.17527400E-02, -.76776400E-02, 0.38446100E-01, 0.14687800E-01, -.43655000E-01, -.84827000E-04, -.12187000E-01, -.21051400E-01, 0.39038400E-01, 0.10450400E-01, 0.10641300E+00, -.39972900E-01, -.15446400E-02, -.66320700E-02, 0.31752500E-01, 0.33428100E-02, -.15692200E-03, -.38642300E-01, -.39152500E-01, -.57634700E-02, 0.18514900E-01, 0.52510000E-01, -.11980900E-01, -.65088100E-01, -.87939700E-03, 0.10193400E-02, 0.34026800E-02, -.14294700E-02, 0.67399400E-02, -.21268200E-02, -.25777900E+00, 0.14233400E-02, 0.56417800E-03, -.29736300E-01, 0.11213400E-01, -.15497900E-01, -.19422200E-01, 0.73497900E-02, -.75441300E-02, -.91952900E-01, -.22259300E-01, 0.81680800E-02, 0.30168100E-02, 0.37909800E-01, 0.29368000E-01, -.60306000E-02, -.17775300E-01, 0.49752600E-01, 0.15957500E-01, -.11741400E-01, 0.89912300E-02, -.25530100E-02, 0.37176500E-01, -.11810900E-01, 0.36925300E-01, -.49596000E-01, -.41995600E-02, 0.12751100E-01, 0.15487000E-01, 0.46837000E-02, -.17753600E-01, 0.47132900E-01, -.62763000E-03, -.32281600E-01, -.17921500E-02, 0.55331200E-01, -.32386900E-01, 0.15570300E-01, -.43263500E-02, 0.21949600E-01, 0.88510000E-01, -.71100000E-01, 0.18929800E-01, 0.20026800E-02, 0.17853500E-02, -.27321100E-01, -.83325500E-02, 0.93214300E-02, -.17199600E-02, -.82323800E-03, -.17715300E-02, -.28257200E-02, 0.94844400E-02, 0.91306500E-02, 0.60455200E-01, -.14821500E-01, -.50866300E-02, -.18146400E-02, 0.14789300E-01, 0.12402900E-01, -.30137200E-02, 0.47870700E-02, -.14479100E-02, 0.16780000E-01, 0.60100400E-02, 0.51762500E-02, 0.40690500E-02, -.14375700E-01, 0.12678900E-01, -.10288600E-01, 0.24302200E-01, -.32374500E-03, -.32543800E-02, -.78499600E-04, -.36769900E-01, -.79603000E-02, 0.10630300E-01, -.71340500E-03, -.23102500E+00, -.31384000E-02, 0.22071300E-01, 0.26472400E-02, -.83805400E-03, -.91584400E-03, 0.53241100E+00, 0.31983600E-03, -.12231500E-02, 0.44783100E-03, -.48537400E-02, 0.37409900E-03, -.18636700E-02, -.25634300E-02, 0.48654400E-02, 0.33355800E-03, -.12157500E-02, 0.42177100E-03, -.48437600E-02, 0.38552500E-03, 0.55755000E-01, -.14517400E+00, 0.29064000E-01, -.35901500E-01, 0.13035700E+00, 0.12592500E-01, 0.10463500E+00, -.54625200E-01, -.62776300E+00, 0.27318800E+00, 0.77601100E-01, 0.14061000E+00, -.85136700E-02, -.28821000E+00, -.14339500E+00, 0.11943400E+00, -.69594800E-02, -.12433900E-01, 0.20414200E-01, 0.12386700E-02, -.36937900E-02, 0.27429500E-03, -.44977900E-01, 0.12492100E-02, 0.10870300E+01, -.73193400E+00, -.42374200E+00, -.45568900E+00, 0.18207300E+00, 0.50556000E+00, 0.61987200E-02, -.43232700E+00, 0.32013900E-02, 0.50788300E-02, -.87109700E-02, -.52002200E-03, 0.18809100E-02, -.48950100E-03, 0.92091500E-02, -.51471200E-03, -.60140600E-02, -.10775200E-01, 0.17492100E-01, 0.97859800E-03, -.30568600E-02, 0.21953500E-03, -.18211200E-01, 0.91591900E-03, -.61686300E-02, -.34556200E-02, 0.41154100E-01, 0.24811700E-01, -.34503400E-02, 0.19243800E-01, 0.10821100E-01, 0.34625900E-02, -.90114300E-02, -.30571300E-02, 0.34969300E-01, 0.97225900E-02, -.12152900E-01, -.11198900E-01, -.35913700E-01, -.23696600E-01, 0.87037800E-02, 0.31760900E-01, -.18376300E-02, -.21528700E-02, 0.31534100E-01, -.47733000E-01, -.48549500E-02, 0.21509000E-01, 0.34401000E-02, -.33924800E-02 }, { 0.12075800E+00, 0.49679200E-01, -.20211700E+00, -.95546400E-01, -.71809800E-01, -.44322100E+00, -.31896800E+00, 0.20974700E+00, -.25421600E-01, 0.55012200E-01, -.47095500E-02, -.35776700E-01, 0.11174400E+00, -.53644500E+00, 0.48268900E-01, 0.27903000E+00, 0.21897200E+00, 0.51427200E-01, -.16235400E-01, -.44793800E-01, -.14022100E-01, 0.25409900E-01, 0.20642400E-01, -.47722100E-01, 0.78401400E-02, -.18054900E-01, 0.57687600E-01, 0.17603800E-01, 0.40833300E-01, -.13586400E-01, 0.13390000E+00, -.16275600E-01, 0.24843200E-01, 0.18705600E-01, 0.46772500E+00, -.30854500E-01, 0.84525800E-02, -.34570400E-01, 0.10046400E+00, 0.16652800E-01, 0.84698500E-02, -.48909100E-01, -.24498700E-01, -.42818900E-01, -.28375800E-02, 0.21544200E-01, -.37624600E-01, 0.13595000E+00, 0.69041000E-02, -.11024200E-01, 0.22775400E-01, 0.36569100E-02, -.64165700E-01, -.36854400E-02, -.42486200E+00, -.30813500E-01, -.12093000E-01, 0.30072700E-01, -.51827400E-01, -.66623500E-01, 0.14185200E-01, 0.36397300E-02, -.16138800E-01, -.56863500E-01, 0.82740000E-02, 0.37777800E-02, 0.73933900E-04, 0.24916600E-01, 0.17722600E-01, -.32152700E-02, 0.15126300E+00, 0.25646300E-01, -.30223100E-02, -.24649100E-02, 0.99899400E-02, 0.70515300E-03, -.33885600E-01, 0.11410800E-01, -.26655100E-01, -.62999300E-01, -.34118300E-03, 0.70005600E-02, 0.42102100E-01, -.94685600E-03, -.14706700E-01, -.14299600E-01, 0.29752300E-02, 0.60891300E-03, 0.46177100E-02, -.73067600E-01, -.89934900E-02, 0.49044800E-02, 0.64109000E-02, 0.30467600E-02, 0.82654900E-02, -.29779800E-01, 0.32477500E-01, 0.79637500E-03, 0.57194100E-02, -.78630200E-01, 0.57304400E-02, 0.87750200E-02, -.24358800E-02, 0.41586700E-02, 0.16411600E-02, 0.89799000E-02, 0.65740100E-02, 0.12444800E-01, 0.47309700E-01, -.38957100E-01, 0.36400400E-04, -.54325900E-02, 0.29162200E-01, 0.16231600E-01, 0.43574400E-02, -.40764700E-03, 0.73215200E-03, 0.17517000E-01, -.88606600E-02, 0.28986800E-02, 0.17863600E-01, -.55250100E-02, -.73278600E-03, -.18748800E-04, 0.71541700E-02, -.13041800E-03, 0.14440600E-01, -.48078100E-02, 0.71179300E-01, -.14886600E-01, 0.28096100E-01, -.69084500E-02, -.16014300E+00, -.47971200E-02, 0.21151600E-01, -.11955600E-01, -.20419700E-02, -.10121800E-02, 0.56924400E-02, 0.43244900E+00, -.24843500E-02, -.15082700E-02, -.50769800E-02, 0.20495500E-02, -.45278000E-02, -.28071800E-02, 0.29824800E-02, 0.29522200E-02, -.24637300E-02, -.15199000E-02, -.50405700E-02, 0.20405900E-02, 0.14957600E+00, -.26825400E+00, -.47680400E-01, -.10316100E+00, 0.93341500E-01, 0.97624600E-01, 0.18668700E+00, -.13432200E+00, -.79507300E+00, 0.24039000E+00, 0.64809100E-01, 0.15023000E+00, 0.94277500E-01, -.33847200E+00, -.67136700E-01, 0.14452000E+00, -.18137700E-01, -.11829800E-01, 0.11297900E-01, 0.11427700E-01, -.78430000E-02, -.74017400E-02, -.68462100E-01, 0.73545100E-02, 0.62521500E+00, -.23982600E+00, -.21560300E+00, -.23158200E+00, 0.10890500E+00, 0.33803000E+00, 0.11810600E+00, -.23412400E+00, 0.82467300E-02, 0.52382900E-02, -.50969800E-02, -.52130500E-02, 0.38426300E-02, 0.29906300E-02, 0.90515400E-02, -.33628200E-02, -.15776600E-01, -.10268600E-01, 0.96263000E-02, 0.98362500E-02, -.65081600E-02, -.64194600E-02, -.17566400E-01, 0.62126400E-02, -.14517700E-01, -.62194200E-02, 0.11648900E-01, 0.17675300E-01, -.64242600E-02, -.19738400E-02, -.17629800E-02, 0.65949200E-02, 0.27532000E-02, -.57338200E-02, 0.31803500E-01, 0.20560400E-01, 0.14637000E-02, -.16478300E-01, -.58456400E-02, -.18778900E-01, -.48185600E-02, 0.12176100E-01, -.36922400E-02, -.40308100E-02, 0.21022900E-01, -.14404800E-01, 0.69412100E-03, 0.62361900E-02, 0.62944800E-02, -.65819100E-02 }, { 0.91685000E-01, 0.21899400E-01, 0.25049000E-01, -.32233400E-01, -.81269400E-01, -.99369800E-01, -.41013900E-01, -.34046200E-01, 0.94626000E-02, -.19294600E-01, -.56421300E-02, -.23729400E-01, -.46461400E-01, 0.70399300E-01, -.79253100E-02, -.12197300E+00, 0.44219200E-02, -.39166200E-01, 0.78353300E-02, 0.37454700E-01, -.48986800E-01, 0.15536600E-01, 0.68625600E-01, -.46600800E-01, 0.71977800E-02, -.18701700E-01, 0.38281000E-01, 0.15570900E-01, -.37366800E-01, -.11536400E-01, -.15657900E+00, 0.19172500E-01, 0.12984800E-01, 0.76575600E-02, -.74005400E-02, 0.52235400E-02, -.10743100E-02, -.38612500E-02, -.29770700E-01, 0.17995500E-02, -.12080100E-01, 0.10371700E-01, -.34919400E-01, 0.72836900E-02, -.10234900E-01, 0.62786600E-01, -.86109500E-02, -.58791400E-01, -.15178900E-02, 0.32391100E-02, -.10470600E-01, -.19669700E-02, 0.23409500E-01, 0.19245200E-02, -.27764100E-01, 0.97861900E-02, 0.23543900E-02, 0.38475600E-01, 0.17053900E-01, 0.27105800E-01, 0.28927500E-01, 0.11537400E-02, -.12995200E-01, 0.13075600E-01, 0.24046500E-01, -.11334700E-02, -.46921600E-02, -.13718300E-01, 0.24022800E-02, -.10116600E-02, 0.11277300E+00, -.96803600E-03, -.46744500E-03, -.20618100E-02, -.14267500E-01, 0.85739200E-04, 0.13058600E-02, -.44479100E-02, -.23732700E-01, 0.55628500E-01, 0.45483000E-01, -.85213400E-03, 0.13795500E-01, -.52431600E-02, -.28820600E-02, -.54732900E-02, 0.14759100E-01, 0.33275000E-02, 0.96183300E-02, -.13601200E+00, 0.17412100E-01, -.38161800E-02, 0.60865700E-02, 0.12642800E-03, -.31688000E-01, 0.26082500E-01, 0.19951600E-01, -.42516400E-02, 0.44413500E-02, 0.48208600E-01, 0.30614000E-01, 0.34729100E-01, 0.11068300E-01, 0.40072400E-02, -.90924300E-03, 0.38645200E-02, 0.30086100E-02, -.31297200E-02, -.55946000E-01, -.62975100E-02, -.10546000E-01, 0.10819300E-01, -.41071200E-02, 0.92995800E-02, 0.69535600E-02, -.18575300E-02, 0.19708500E-02, 0.79396200E-03, 0.63683600E-02, -.46163700E-03, 0.29440200E-03, -.14245700E-01, 0.33003600E-02, -.64441400E-02, 0.25510300E-02, 0.11511400E-01, -.19267800E-01, 0.27543200E-02, 0.33320200E-01, 0.16337000E-01, 0.79906800E-03, -.19212900E-02, -.50758900E-01, -.66611000E-01, -.14238700E-01, 0.16416200E-02, 0.19747400E-03, 0.17894000E-02, -.14325700E-02, -.28666100E-02, 0.25561000E+00, -.90397300E-03, 0.49402100E-02, -.15442500E-02, 0.52052500E-03, 0.49859100E-02, -.72653700E-03, -.12391700E-02, 0.50138900E-02, -.80552300E-03, 0.49065400E-02, -.15504700E-02, 0.63588200E+00, -.10533900E+00, -.12313100E+00, -.15390700E+00, -.64844100E-01, 0.22238500E+00, -.65352600E-01, -.12177800E+00, 0.17522700E+00, 0.14010400E+00, -.54940300E-01, -.59018200E-01, -.53628100E-01, 0.35992900E-01, 0.41465600E-01, -.67185200E-01, 0.38983700E-02, 0.19603100E-01, -.17920800E-02, -.46948000E-02, 0.18843900E-01, -.33675600E-02, 0.23306300E-01, -.54877800E-02, 0.67546200E+00, -.46075600E+00, -.51677200E-01, -.10838500E+00, -.76471800E-01, 0.20475000E+00, 0.71113900E-01, -.74219300E-01, -.14189200E-02, -.93059600E-02, 0.11063400E-02, 0.22867500E-02, -.88339400E-02, 0.10004900E-02, -.84855700E-02, 0.27831900E-02, 0.31998700E-02, 0.17400700E-01, -.15657300E-02, -.41363200E-02, 0.16384400E-01, -.26780000E-02, 0.14965700E-01, -.48244200E-02, 0.12555800E-02, 0.68774300E-02, 0.30619000E-01, 0.14905800E-01, 0.70016100E-02, 0.17240300E-01, 0.98791600E-02, -.72083700E-02, -.10920300E-01, 0.62065400E-02, 0.31986200E-02, -.14946900E-01, 0.19806400E-02, 0.11814000E-01, -.24454400E-01, -.53069400E-02, 0.20678900E-01, 0.72051700E-02, 0.37044700E-02, 0.43254800E-02, 0.27476800E-01, -.28933400E-01, 0.96354400E-02, -.61560800E-02, -.68860700E-02, 0.79212800E-02 }, { -.25605300E+00, -.87368900E-01, 0.25435900E+00, 0.13305200E+00, 0.84341200E-01, 0.66140800E-01, -.86174000E+00, -.28258200E+00, 0.47803500E-01, -.87299400E-01, 0.18877200E-01, 0.26732400E+00, 0.34194600E-01, 0.62642600E+00, -.24786400E+00, -.11786800E+00, -.14208700E+00, -.87195500E-01, -.90272500E-01, 0.84266800E-02, 0.26721900E-03, 0.20660000E-01, 0.12740000E+00, 0.27611600E-01, 0.16341100E-01, 0.65004000E-02, -.11568400E+00, -.46370300E-01, -.69465900E-01, -.30255800E-01, -.34697600E+00, 0.65739200E-01, -.40668900E-01, 0.54048400E-01, 0.54890500E+00, 0.10030700E+00, -.23589000E-01, 0.12750500E+00, 0.73542400E-01, 0.18717900E-02, 0.59117900E-01, -.62075400E-02, 0.67492900E-02, 0.52967500E-01, 0.23118300E-01, -.19507300E+00, 0.32007200E-01, 0.33583900E+00, -.57124900E-03, -.56547000E-02, 0.13269000E-01, 0.23681600E-01, -.27734800E-01, -.21003000E-01, 0.24941700E+00, 0.25626900E-01, -.90287900E-02, -.58505800E-01, -.12552000E-01, 0.49159100E-01, -.30924700E-02, -.61651700E-02, 0.65938700E-01, 0.22609100E+00, -.28533600E-01, -.17123300E-01, 0.15078100E-01, -.87650600E-01, -.82931200E-01, 0.11053300E-01, 0.95534600E-01, -.11430900E+00, -.54705600E-01, 0.32902000E-01, -.28247400E-01, 0.30508100E-01, 0.22239800E-01, -.34791800E-01, 0.24218000E-01, -.86324000E-01, -.19465500E-01, 0.72264000E-02, 0.73329500E-01, 0.57264500E-02, -.31204900E-02, 0.14704400E-01, -.98966700E-02, 0.81895100E-02, -.84325000E-02, -.10874700E+00, 0.50621900E-01, -.24840400E-02, -.57932600E-02, -.19477000E-01, 0.27878100E+00, -.35273600E-01, -.20427400E+00, -.53305900E-02, 0.16406100E-01, 0.18935300E+00, -.37147800E-01, -.73571400E-01, -.24056500E-01, -.17239200E-01, 0.83025900E-02, 0.31363900E-01, -.26332500E-01, 0.28849300E-01, -.16792000E-01, 0.57815300E-01, -.36738000E-01, -.30562800E-01, -.64119300E-01, -.37785100E-01, -.10803100E-01, -.66847500E-02, -.15766700E-01, -.39738800E-01, 0.49893900E-02, -.17252300E-01, -.49628400E-01, -.70533800E-02, 0.58478800E-02, -.38312200E-02, -.53648300E-03, -.36538100E-02, -.11116000E-01, -.47357900E-02, -.53817200E-02, 0.11002500E-01, 0.10583900E-01, 0.74854300E-02, 0.18403200E+00, 0.19630100E-01, -.52485900E-02, 0.35163300E-02, 0.19955500E-02, 0.91191800E-03, -.73372500E-03, -.23658400E-02, -.56133400E-02, 0.12380900E+01, 0.72395900E-03, -.97362400E-03, 0.43963300E-02, 0.25803100E-02, -.43481900E-03, -.10608600E-02, -.13923000E-02, 0.10950900E-01, 0.77182200E-03, -.10085900E-02, -.19989100E+00, 0.22448800E+00, 0.10428400E-01, 0.80815100E-01, -.90873900E-01, 0.33196700E-01, 0.38415800E-01, 0.11189800E+00, 0.71366000E+00, -.36363600E+00, -.76621000E-01, -.17124600E+00, -.24278300E-01, 0.31487300E+00, 0.13684000E+00, -.21018400E+00, 0.15596300E-01, 0.13386100E-01, -.29848200E-02, -.44593100E-02, -.44602600E-02, 0.47478700E-01, 0.44168700E-03, -.38683400E-02, -.64946800E+00, 0.45925300E+00, 0.69446600E-01, 0.84706400E-01, 0.55466300E-01, -.20058000E+00, -.11307700E+00, 0.31250900E-01, -.78755200E-02, -.54243000E-02, 0.11323200E-02, 0.21134700E-02, 0.25087600E-02, -.20726300E-01, -.20871500E-02, 0.19249300E-02, 0.13898700E-01, 0.11819700E-01, -.27038500E-02, -.39401800E-02, -.40388000E-02, 0.41324000E-01, 0.54662000E-02, -.34106900E-02, 0.14058100E-01, 0.15211300E-02, -.35384000E-01, 0.67149200E-02, 0.67667100E-03, 0.78018600E-02, -.48357900E-02, 0.10028900E-04, 0.84626500E-02, 0.66556900E-03, -.24459900E-01, -.61990700E-02, 0.55747900E-02, 0.90435100E-02, 0.28213500E-01, 0.16390900E-01, -.69614600E-02, -.18832000E-01, 0.77443200E-03, 0.10838600E-02, 0.13970600E-01, -.10636000E-02, 0.13681500E-02, 0.76133900E-02, -.11314500E-02, -.16275500E-02 }, { 0.61611700E-02, -.14276600E-01, 0.63799000E-01, 0.69525000E-01, 0.30306600E-01, -.21271100E+00, 0.74517700E-01, -.21266100E-01, 0.25992900E-01, -.39004100E-02, 0.26673100E-03, 0.22272700E-01, 0.39110900E-01, -.47120400E-01, -.45684800E-01, 0.11991700E-01, 0.31278900E-01, -.58220900E-02, -.73878400E-02, -.18986200E-02, 0.13528100E-01, -.23859600E-02, -.34342100E-02, -.63616400E-02, 0.85003700E-03, -.15965300E-02, -.42078600E-02, -.53915700E-02, -.28864900E-01, -.77088100E-02, -.12854400E+00, 0.10424900E-01, 0.23772500E-01, 0.72339100E-02, 0.30810700E+00, -.56869200E-03, 0.31672700E-03, 0.28497200E-02, 0.24783100E-02, 0.51376200E-03, -.13781200E-02, 0.27767200E-02, -.27390400E-01, 0.37452500E-02, -.21789200E-02, 0.71820400E-02, -.27918500E-02, 0.30020000E-02, -.18022400E-04, 0.90767900E-03, 0.23295300E-02, 0.73549000E-03, 0.65560500E-03, -.88680600E-03, -.17525200E+00, 0.48809900E-03, -.12264300E-02, 0.88795500E-02, 0.38518500E-02, -.19896000E-02, 0.32652800E-02, -.75168800E-03, -.87560900E-02, -.11879500E-01, 0.94930500E-02, -.13420800E-03, -.15117500E-02, 0.76538100E-02, 0.22696100E-03, -.19113200E-02, 0.12571000E+00, -.24804900E-02, -.73562800E-03, -.19338700E-02, 0.50498500E-02, 0.20110500E-02, 0.87827700E-02, -.53354500E-02, -.40045200E-02, 0.16232700E-01, 0.98504500E-02, -.73737300E-03, -.57703400E-02, -.22860600E-02, 0.97649600E-03, -.66575100E-02, 0.50991600E-02, -.10161300E-02, 0.24413700E-03, 0.13822200E-01, -.13240400E-01, 0.21471100E-03, -.20911700E-02, -.31720200E-02, -.30475000E-01, -.53380700E-02, -.27065200E-02, -.15272500E-02, 0.59261900E-02, 0.13688600E-01, 0.50817000E-02, -.23706000E-03, -.15243200E-02, 0.97819600E-04, -.61853700E-03, 0.30671200E-03, 0.28040900E-02, 0.62410700E-02, 0.12675800E-01, -.13639700E-01, -.12181300E-02, 0.16184000E-02, 0.31627700E-03, 0.11720700E-01, 0.11977000E-01, -.14937600E-02, 0.33644200E-02, 0.42608100E-02, -.55614700E-02, 0.16192200E-02, 0.51040000E-02, -.11537500E-01, 0.64334000E-02, 0.11091300E-02, 0.50537500E-02, 0.31377300E-02, 0.12858000E-01, -.40104100E-02, 0.64878700E-01, -.32961900E-03, -.11070800E-01, -.25887100E-02, 0.22352400E+00, -.25450500E-02, -.14955400E-02, -.20871500E-02, -.40483900E-03, 0.58420100E-03, 0.38324400E-03, -.28705800E-03, 0.12264400E-02, -.17080200E-03, 0.23385200E+00, -.46793900E-03, -.86595700E-03, 0.16276800E-02, 0.20835500E-03, -.11017700E-03, 0.29551100E-03, -.19111900E-03, 0.13925200E-02, -.45365700E-03, 0.25287900E-01, 0.29433400E-01, -.15560200E-01, -.13618100E-01, 0.14730700E-01, 0.24835800E-01, 0.37259700E-01, -.12861500E-01, -.52264100E-01, 0.52186400E-01, 0.66082900E-02, 0.95424800E-02, -.18591700E-01, -.42354800E-01, -.11358200E-01, -.47580400E-03, -.21591600E-02, 0.57165500E-02, 0.10560400E-02, 0.19356300E-03, 0.32277100E-03, -.10715100E-02, -.46122800E-01, -.11915600E-02, 0.29413500E+00, -.16666500E+00, -.37903600E-01, -.66525100E-01, -.19018900E-01, 0.11231800E+00, 0.40006400E-01, -.61933000E-01, 0.12638400E-02, -.28631000E-02, -.38490400E-03, 0.80741400E-04, -.37004200E-03, 0.27746400E-03, -.22527600E-02, 0.72231200E-03, -.18734100E-02, 0.50413600E-02, 0.87019000E-03, 0.15171000E-03, 0.30596700E-03, -.86657200E-03, 0.35196800E-02, -.10724600E-02, -.30493800E-02, 0.17816500E-02, -.11844200E-02, 0.38901900E-02, 0.18309200E-02, 0.46817000E-02, 0.16637100E-02, -.19317500E-02, -.20533400E-02, 0.16210700E-02, 0.17586000E-02, -.50824900E-02, 0.48048800E-02, 0.26540200E-02, 0.15007700E-02, -.83784500E-03, 0.23541100E-02, 0.70067400E-03, 0.96445800E-03, 0.11221800E-02, 0.12658300E-01, -.10167400E-01, 0.26262100E-02, -.10637800E-02, -.18048400E-02, 0.22442000E-02 }, { 0.10689500E+00, 0.44347200E-01, -.19786600E+00, -.87286600E-01, -.77282500E-01, -.45636400E+00, -.34253800E+00, 0.13902300E+00, -.10912000E-01, 0.27580900E-01, -.38893000E-02, -.69495200E-01, 0.30188900E-01, -.31861100E+00, 0.73408400E-01, 0.13063300E+00, 0.12749400E+00, 0.45227600E-01, 0.23830700E-01, -.21652700E-01, -.67694900E-04, 0.16591000E-02, -.27939800E-01, -.29589000E-01, -.13323900E-02, -.98752900E-02, 0.54320200E-01, 0.19960100E-01, 0.15175100E-01, 0.90017000E-03, 0.79892900E-01, -.19715500E-01, 0.24961800E-01, -.34837000E-02, 0.54653000E-01, -.33222600E-01, 0.74084400E-02, -.33614100E-01, 0.21205500E-01, 0.22234800E-02, -.70425500E-02, -.21652100E-01, -.15948700E-01, -.12478300E-01, 0.46102900E-02, 0.41449300E-01, -.13688300E-01, -.55904800E-01, 0.12856900E-02, -.10544200E-02, 0.46960300E-02, -.17420000E-02, -.92167800E-02, 0.14118100E-02, -.18642100E+00, -.91930900E-02, -.25653100E-02, 0.14283400E-01, 0.88375100E-03, -.20545700E-01, 0.13484200E-01, 0.62349300E-02, -.25550900E-01, -.82445700E-01, 0.12752200E-01, 0.52232700E-02, -.21734500E-02, 0.33771500E-01, 0.22989500E-01, -.48878000E-02, 0.25166800E-01, 0.35147300E-01, 0.12461400E-01, -.83868400E-02, 0.79166400E-02, -.62476900E-02, 0.11413800E-01, 0.19452700E-03, 0.52959300E-02, 0.30041400E-02, 0.29271100E-02, 0.29979400E-02, -.73546800E-02, 0.36022500E-03, -.96198700E-02, -.17673800E-02, 0.44087700E-02, -.31300000E-02, 0.87533000E-03, 0.15605000E-01, -.28838500E-01, 0.49087400E-02, -.18059000E-03, 0.10778100E-01, -.78861600E-01, -.20613300E-01, 0.67235700E-01, 0.21161000E-02, -.26083500E-02, -.73231800E-01, 0.87644800E-02, 0.15280700E-01, 0.55473200E-02, 0.32697700E-02, -.26447800E-02, -.64742600E-02, 0.96101000E-02, 0.27954900E-03, 0.34200500E-01, -.22959500E-01, 0.78884300E-02, 0.86209100E-02, 0.27752000E-01, 0.23071800E-01, 0.74377600E-02, 0.22070600E-02, 0.33474400E-02, 0.22353600E-01, -.27429300E-02, 0.94884900E-02, 0.18052400E-01, -.72461000E-02, 0.62871700E-02, -.36693300E-02, 0.17629200E-01, 0.18078800E-02, 0.13419300E-01, -.17544700E-02, 0.21111800E-01, -.10472800E-01, 0.24136600E-02, -.43932800E-02, -.64935900E-01, -.11689600E-01, 0.12938900E-01, -.24678900E-02, -.10649700E-02, -.31714000E-04, 0.30914000E-02, 0.13636700E-02, -.21142600E-02, -.10159200E-02, -.15580400E-01, 0.14029000E+00, -.23484600E-02, -.31530600E-04, 0.16222200E-02, 0.60942000E-03, -.52738800E-03, -.12790100E-02, -.36290700E-02, 0.75988700E-03, 0.11931800E+00, -.14469000E+00, -.24914500E-01, -.39202400E-01, 0.10554100E+00, 0.21979700E-01, 0.73553200E-01, -.64828500E-01, -.75142400E+00, 0.33683700E+00, 0.70121800E-01, 0.16565000E+00, 0.18603200E-01, -.35513800E+00, -.18271600E+00, 0.16004500E+00, -.85291200E-02, -.20265100E-02, 0.70332600E-02, 0.27454900E-02, -.15427200E-02, -.74912800E-02, -.59354200E-01, 0.31894200E-02, 0.12395800E+01, -.74570400E+00, -.36119100E+00, -.40211700E+00, 0.98561700E-01, 0.54255900E+00, 0.74188600E-01, -.37432600E+00, 0.39078800E-02, 0.48779900E-03, -.28288300E-02, -.12005200E-02, 0.76309800E-03, 0.28574700E-02, 0.73503900E-02, -.14015700E-02, -.72322700E-02, -.18628600E-02, 0.59691200E-02, 0.24145400E-02, -.12614000E-02, -.65897600E-02, -.15341200E-01, 0.27249500E-02, -.78446800E-02, -.25061200E-02, 0.31777900E-01, 0.83781000E-02, -.28467400E-02, 0.20509100E-02, 0.74311800E-03, 0.31420400E-02, -.24507800E-02, -.24717300E-02, 0.37955900E-01, 0.10780500E-02, -.71992100E-02, -.11496100E-01, -.25651200E-01, -.26914200E-01, 0.93962100E-03, 0.31927300E-01, -.16084300E-02, -.15771100E-02, 0.18112300E-01, -.33406000E-01, 0.93312900E-02, 0.56702500E-02, 0.26626200E-02, -.33149300E-02 }, { -.73776300E+00, -.24792800E+00, 0.61682800E+00, 0.30115200E+00, 0.21638800E+00, 0.16197000E+01, 0.14849100E+01, -.43978900E+00, 0.20000800E+00, -.28699700E+00, -.21852200E-01, 0.65280200E-01, -.47066500E+00, 0.24705800E+01, -.33523800E+00, -.17595500E+01, -.96236700E+00, -.72949200E+00, -.10523700E+00, 0.38832300E+00, -.73528500E-01, -.62072300E-01, 0.37547500E-01, 0.27334300E+00, -.20231100E-01, 0.86535600E-01, -.26649500E+00, -.88553400E-01, 0.50345400E+00, 0.55587800E-01, 0.10585200E+01, -.91494400E-02, -.32973600E+00, -.72951700E-01, -.15528700E+01, 0.21893900E+00, 0.33445400E-02, 0.99996800E-01, 0.97452700E-01, -.49464700E-01, 0.13695800E+00, 0.87736800E-01, 0.42870000E+00, 0.24128700E-01, 0.45962200E-01, -.75747900E+00, 0.14139200E+00, 0.66195000E+00, 0.14122700E-01, -.20751300E-01, 0.41277400E-01, 0.24404300E-01, -.16978400E+00, -.11688500E-01, 0.20195000E+01, -.52889600E-01, -.32576500E-01, 0.57303300E-01, -.10334800E+00, -.64413600E-01, 0.15133700E+00, -.34443600E-01, 0.36536600E-01, 0.41597900E+00, 0.10256000E+00, -.39244300E-01, 0.14762300E-01, -.16691900E+00, -.17744500E+00, 0.25069700E-01, -.45735000E+00, -.24683300E+00, -.10471300E+00, 0.10807500E+00, -.32464600E-01, 0.15168400E-01, -.10144300E-01, -.20818200E-01, -.44876600E-01, -.16030800E-01, -.10639100E+00, -.35963200E-01, -.88634000E-02, 0.10672700E-01, 0.48722200E-01, -.17755000E+00, -.46465600E-01, 0.14773000E+00, -.25697800E-01, 0.22374200E+00, -.52510600E-03, -.19451500E-01, -.18496500E-01, -.62550300E-01, 0.73243700E-01, 0.56169500E-01, -.21390700E+00, 0.14027600E-01, -.33583300E-01, -.13953500E+00, -.11433400E+00, -.24426200E+00, -.30929200E-01, -.42224900E-01, 0.13094600E-01, -.15437900E-02, -.32496700E-01, 0.45621300E-02, 0.50080300E-01, 0.12557100E+00, 0.74827100E-01, -.61873300E-03, 0.24966900E-01, -.24276700E-01, -.51976000E-01, -.36016700E-02, -.43885100E-01, 0.28787900E-01, -.13935900E-03, 0.32398900E-01, -.27774500E-02, 0.10535800E+00, -.12748700E-01, 0.11466100E-01, -.39263500E-01, -.37399500E-01, 0.84759400E-01, -.28919700E-02, -.71163400E-01, -.53176900E-01, 0.13098200E-01, 0.37669800E-02, -.11545500E+00, 0.15036000E+00, 0.33698000E-01, 0.11942500E-01, 0.43705000E-02, -.75777500E-02, -.15271700E-01, -.77429300E-02, -.21750300E-01, 0.11721400E-01, -.58708100E-01, 0.90549900E-02, 0.22139000E+01, -.21062000E-01, -.81986400E-02, -.33454400E-02, -.52119300E-02, 0.13908400E-01, -.13424300E-01, 0.12864500E-02, -.22299600E+01, 0.78399700E+00, 0.12420500E+00, 0.55492600E+00, 0.52178000E+00, -.67149000E+00, 0.26345800E+00, 0.40800000E+00, -.26398100E+01, 0.51148100E+00, 0.44440500E+00, 0.61256500E+00, 0.42525800E+00, -.98103500E+00, -.61560600E+00, 0.66377900E+00, 0.25634600E-01, -.81939500E-01, -.42329900E-01, -.16751900E-01, -.10321800E-01, 0.55965100E-01, -.45928600E-02, 0.10479500E-02, -.29594900E-01, -.11313700E+00, -.80803800E+00, -.74082800E+00, 0.91765400E+00, 0.51584100E+00, 0.19819500E+00, -.82243800E+00, -.14291300E-01, 0.39028700E-01, 0.17247200E-01, 0.63337600E-02, 0.72707600E-02, -.22494200E-01, 0.23380900E-01, -.20684100E-02, 0.23441000E-01, -.72634200E-01, -.36928400E-01, -.14049000E-01, -.95923100E-02, 0.46626600E-01, -.40392400E-01, 0.13304200E-02, 0.31258900E-01, -.18180700E-01, -.92062900E-01, 0.48844800E-01, -.18786200E-01, -.83028200E-01, -.24325400E-01, 0.20211200E-01, 0.26817500E-01, -.16334600E-01, 0.24122300E-01, 0.34717600E-01, -.39986300E-01, -.28998900E-01, 0.93026800E-01, -.79178500E-02, -.45500500E-01, 0.32162900E-01, -.92238200E-02, -.11076600E-01, -.92561000E-02, -.78449700E-01, -.54395700E-01, 0.77806200E-01, 0.18386800E-01, -.25865700E-01 }, { 0.22845000E+00, 0.30154100E+00, -.18027800E+00, 0.15022900E-01, -.55968900E-01, -.17344200E+00, -.90006700E-01, 0.23861900E+00, -.36886300E-01, -.13146500E+00, 0.36496500E-01, 0.13718000E+00, 0.24356400E-01, -.18952300E-01, 0.54491500E-01, 0.41807500E+00, 0.38129400E+00, 0.12667000E+00, 0.56793100E-02, -.94201100E-01, -.78525200E-01, 0.69440400E-01, 0.15043500E+00, -.14793100E+00, 0.25620700E-01, -.57611200E-01, 0.15986800E+00, 0.58225100E-01, -.86590500E-01, -.41373500E-01, -.19687900E+00, 0.15265600E-01, 0.60139600E-01, 0.51362000E-01, 0.61107700E+00, -.15305300E-01, 0.12253500E-02, 0.14267100E-01, 0.14659300E+00, 0.18522900E-01, 0.19723700E-01, -.10482300E+00, -.11845700E+00, 0.48030000E-01, 0.44019300E-01, 0.25579200E-01, -.26131300E-01, 0.80214900E-01, 0.29282600E-03, -.76002200E-02, 0.27619500E-01, 0.28858300E-01, -.45317000E-01, -.23500800E-01, -.19508500E+00, 0.23620900E-01, -.19787300E-01, -.42442000E-01, 0.20710100E-01, 0.60738900E-01, 0.53589300E-01, 0.31973100E-01, -.19884300E-01, -.60282100E-01, 0.10999000E-01, 0.11727400E-02, 0.75117200E-02, 0.25987700E-01, -.30877000E-02, -.27335700E-02, 0.68568700E-01, 0.12111000E-01, -.82087300E-02, -.42310900E-02, -.31286700E-01, 0.96502900E-02, 0.53001900E-01, -.33472600E-01, 0.68998100E-01, -.66642900E-01, -.27224500E-01, 0.28756700E-01, 0.61063000E-01, 0.96927000E-02, -.55603200E-01, 0.20652400E-01, 0.16110600E-01, -.20249200E-02, -.67776000E-02, -.35099900E+00, 0.21695900E-01, 0.59546700E-02, 0.41020100E-02, 0.26724900E-01, -.12486100E+00, -.68610400E-01, 0.12342900E+00, 0.20103900E-03, 0.62878600E-03, -.44040200E-01, 0.24390300E-01, 0.28391400E-01, 0.11226500E-01, 0.11363000E-02, -.25193400E-02, 0.10045000E-01, -.11296500E-01, 0.96797500E-02, 0.12657100E-01, 0.15022800E-01, -.26345800E-01, 0.52364700E-02, 0.15221800E-01, 0.33390100E-01, 0.21225000E-01, -.49250000E-02, 0.53241200E-02, 0.19913400E-02, -.11050400E-01, -.25575600E-03, -.13062600E-01, -.36514000E-01, 0.15327600E-01, -.23833500E-01, 0.88437400E-01, 0.34326700E-02, 0.16912900E-01, -.68412300E-02, -.38016200E-01, -.18372800E-01, 0.27037900E-01, -.11287800E-02, -.28584100E+00, -.60327000E-01, 0.18270500E-01, -.57296400E-02, -.28424600E-02, 0.61360400E-02, 0.20340200E-02, 0.46072200E-02, -.10404200E-01, 0.76288200E-02, -.47190400E-01, 0.22082300E-01, -.27819200E-02, 0.28300200E+01, 0.97354700E-03, 0.20496100E-02, -.26494500E-02, 0.93169200E-02, -.10978400E-01, 0.32313400E-02, 0.60251200E+00, -.29720600E+00, -.18717300E+00, -.51913600E-01, 0.11480900E+00, 0.20985400E+00, 0.12678600E+00, -.82877100E-01, -.10986700E+01, 0.61741900E+00, -.34831300E-01, 0.23612500E+00, -.58656100E-01, -.68217800E+00, -.59130700E+00, 0.17134300E+00, -.22772400E-01, 0.66205700E-01, 0.60188600E-02, 0.11481000E-01, -.97814800E-02, 0.32363000E-01, -.10676500E+00, 0.16611600E-01, 0.43152900E+01, -.24428700E+01, -.11002600E+01, -.12244800E+01, 0.70882200E-01, 0.18522600E+01, 0.87897500E-01, -.11697500E+01, 0.89741600E-02, -.30956700E-01, -.12978500E-02, -.44351100E-02, 0.49159700E-02, -.16188900E-01, 0.23115500E-01, -.66134000E-02, -.18009200E-01, 0.57302100E-01, 0.47378000E-02, 0.10178500E-01, -.86427700E-02, 0.28152400E-01, -.48714700E-01, 0.14368400E-01, -.21781000E-01, -.36059000E-02, 0.84764600E-01, -.32986100E-01, -.81855800E-02, 0.16159200E-02, -.24466600E-01, 0.11777000E-01, 0.12417500E-01, -.67559300E-02, 0.12562900E+00, -.35946600E-01, -.51356800E-02, -.26313300E-01, -.75003600E-01, -.95443700E-01, -.21880800E-01, 0.10406800E+00, -.43705300E-02, -.21124100E-02, 0.56172900E-01, -.87232700E-01, -.61651200E-01, -.26164900E-01, 0.57809200E-02, -.15727000E-01 }, { 0.92923100E-01, 0.38237300E-01, -.16882500E+00, 0.16390500E-01, -.36680900E-01, -.32106400E+00, -.27439000E+00, 0.14572200E+00, -.47785700E-01, 0.97009900E-01, -.20588500E-02, -.58023900E-01, 0.11197900E+00, -.63449200E+00, 0.10159000E+00, 0.38072500E+00, 0.18426200E+00, 0.14678500E+00, 0.22152700E-01, -.82601000E-01, 0.36193600E-01, 0.48426700E-03, -.58146700E-01, -.29130600E-01, -.17792200E-02, -.76421100E-02, 0.38312100E-01, 0.14674600E-01, -.44525200E-01, -.24698000E-03, -.13309300E-01, -.21043500E-01, 0.39296800E-01, 0.10459500E-01, 0.10796400E+00, -.40120500E-01, -.14885300E-02, -.72746900E-02, 0.31895700E-01, 0.33509100E-02, -.63541600E-03, -.39082700E-01, -.35766500E-01, -.64876300E-02, 0.18371700E-01, 0.53868100E-01, -.12229700E-01, -.65835200E-01, -.85325500E-03, 0.10023000E-02, 0.32422500E-02, -.14763300E-02, 0.67808800E-02, -.19958900E-02, -.25912200E+00, 0.12549600E-02, 0.56067300E-03, -.27291100E-01, 0.11563500E-01, -.15635700E-01, -.19083200E-01, 0.73786400E-02, -.80066800E-02, -.92797600E-01, -.21834100E-01, 0.82180800E-02, 0.29534900E-02, 0.38371100E-01, 0.29445700E-01, -.60344600E-02, -.13986700E-01, 0.49900100E-01, 0.15993500E-01, -.11722500E-01, 0.90188500E-02, -.25231400E-02, 0.37286100E-01, -.11890600E-01, 0.35951200E-01, -.48515200E-01, -.35543800E-02, 0.12958300E-01, 0.16404900E-01, 0.43972600E-02, -.17590800E-01, 0.46642800E-01, -.11198400E-03, -.32108300E-01, -.15752400E-02, 0.56260700E-01, -.32424600E-01, 0.15592600E-01, -.42247800E-02, 0.22615600E-01, 0.89520600E-01, -.71676800E-01, 0.19661700E-01, 0.21564300E-02, 0.20066200E-02, -.27261400E-01, -.83358800E-02, 0.94163300E-02, -.18344700E-02, -.85876400E-03, -.18900700E-02, -.27226300E-02, 0.97313600E-02, 0.94022700E-02, 0.60422700E-01, -.15498400E-01, -.51730400E-02, -.19207000E-02, 0.14571500E-01, 0.12145400E-01, -.31714100E-02, 0.48952600E-02, -.18688200E-02, 0.17030600E-01, 0.57513700E-02, 0.48983400E-02, 0.44281200E-02, -.14529300E-01, 0.12768700E-01, -.10353800E-01, 0.23521100E-01, -.45414000E-03, -.29081400E-02, -.28612800E-03, -.36979600E-01, -.80556700E-02, 0.11116600E-01, -.74518600E-03, -.21500600E+00, -.20651000E-02, 0.22030000E-01, 0.23062700E-02, -.81630700E-03, -.88762200E-03, 0.90234700E-02, 0.82780100E-03, -.53364800E-02, 0.31217300E-03, -.21880600E-01, 0.28958400E-02, -.81649400E-03, -.85310600E-03, 0.53222700E+00, 0.35982100E-03, -.13292900E-02, 0.37215400E-03, -.50887000E-02, 0.42255500E-03, 0.50254900E-01, -.14255100E+00, 0.33987200E-01, -.30956300E-01, 0.12280500E+00, 0.54866700E-02, 0.95698100E-01, -.49920900E-01, -.61991400E+00, 0.26812800E+00, 0.74919100E-01, 0.13872600E+00, -.68845300E-02, -.28534800E+00, -.14473900E+00, 0.11753100E+00, -.66695000E-02, -.11743000E-01, 0.19859600E-01, 0.13779300E-02, -.42044400E-02, -.23030300E-04, -.49694800E-01, 0.14430800E-02, 0.10826200E+01, -.72175800E+00, -.41433800E+00, -.44559100E+00, 0.17308100E+00, 0.50040500E+00, 0.96667200E-03, -.42282800E+00, 0.30644000E-02, 0.47960500E-02, -.84701500E-02, -.58765000E-03, 0.21128600E-02, -.36827900E-03, 0.97044700E-02, -.60842400E-03, -.57330800E-02, -.10209800E-01, 0.17023600E-01, 0.11145200E-02, -.35131200E-02, -.40466100E-04, -.19210700E-01, 0.11000600E-02, -.60103900E-02, -.35738400E-02, 0.40820900E-01, 0.22463000E-01, -.36258900E-02, 0.17868200E-01, 0.95453600E-02, 0.36888000E-02, -.78136000E-02, -.32052200E-02, 0.35326000E-01, 0.85706300E-02, -.12543200E-01, -.11867000E-01, -.35801300E-01, -.25142000E-01, 0.78589700E-02, 0.32427200E-01, -.19288300E-02, -.22243100E-02, 0.27856900E-01, -.45250300E-01, -.49475600E-02, 0.20008900E-01, 0.35843400E-02, -.36821700E-02 }, { 0.12073600E+00, 0.49827400E-01, -.20191800E+00, -.95011800E-01, -.71359000E-01, -.44222100E+00, -.31982900E+00, 0.20850400E+00, -.25440200E-01, 0.54914900E-01, -.47075200E-02, -.34925100E-01, 0.11208300E+00, -.53521700E+00, 0.46968900E-01, 0.27902700E+00, 0.21871200E+00, 0.51446700E-01, -.16997100E-01, -.44768000E-01, -.13894300E-01, 0.25429500E-01, 0.20359500E-01, -.48099900E-01, 0.77679900E-02, -.17926100E-01, 0.57878900E-01, 0.17618500E-01, 0.39713700E-01, -.13619800E-01, 0.13289800E+00, -.16420000E-01, 0.25316400E-01, 0.18613500E-01, 0.47175800E+00, -.30935000E-01, 0.86451700E-02, -.34300900E-01, 0.10120000E+00, 0.16646400E-01, 0.83602000E-02, -.48970700E-01, -.25501600E-01, -.42731700E-01, -.30350900E-02, 0.22377900E-01, -.37853300E-01, 0.13675900E+00, 0.69254700E-02, -.10971300E-01, 0.22973200E-01, 0.37310100E-02, -.64487400E-01, -.37547000E-02, -.42296600E+00, -.30851700E-01, -.12290600E-01, 0.31636600E-01, -.51519300E-01, -.66693400E-01, 0.13958900E-01, 0.35896000E-02, -.16701200E-01, -.58244600E-01, 0.87188400E-02, 0.38553100E-02, 0.76705400E-05, 0.25678300E-01, 0.17832100E-01, -.32266000E-02, 0.15368300E+00, 0.25845300E-01, -.27827200E-02, -.25247800E-02, 0.10198600E-01, 0.63339700E-03, -.33714200E-01, 0.11327300E-01, -.27608000E-01, -.61936400E-01, -.41862700E-03, 0.71308600E-02, 0.41780600E-01, -.10858100E-02, -.14398600E-01, -.14744600E-01, 0.33866800E-02, 0.77454100E-03, 0.46942200E-02, -.70686400E-01, -.93354500E-02, 0.48720900E-02, 0.65074700E-02, 0.35071500E-02, 0.62324400E-02, -.29960300E-01, 0.33529100E-01, 0.82018500E-03, 0.57366400E-02, -.78818700E-01, 0.56851100E-02, 0.87528200E-02, -.25324700E-02, 0.42392800E-02, 0.15800100E-02, 0.89545400E-02, 0.67998100E-02, 0.12527400E-01, 0.47340700E-01, -.39427400E-01, 0.15638800E-04, -.56806500E-02, 0.29000500E-01, 0.16039600E-01, 0.46299400E-02, -.48336300E-03, 0.65363500E-03, 0.17315900E-01, -.95816300E-02, 0.25325400E-02, 0.17848900E-01, -.56186400E-02, -.74762900E-03, 0.17485400E-03, 0.68668400E-02, -.39196700E-03, 0.15080200E-01, -.50562100E-02, 0.70577600E-01, -.15191600E-01, 0.27869700E-01, -.68942000E-02, -.14230000E+00, -.29781100E-02, 0.20859200E-01, -.12270300E-01, -.20602700E-02, -.94440200E-03, 0.54850600E-02, 0.68698800E-02, -.10047900E-01, -.12363300E-02, -.22113000E-01, 0.14602600E-01, -.20387400E-02, -.90144300E-03, 0.52849300E-02, 0.43242000E+00, -.24926000E-02, -.14833500E-02, -.50647500E-02, 0.20363200E-02, 0.13038500E+00, -.25067900E+00, -.41636800E-01, -.93024600E-01, 0.84618200E-01, 0.86766600E-01, 0.17459100E+00, -.12376200E+00, -.75732000E+00, 0.22073100E+00, 0.60115500E-01, 0.14264800E+00, 0.93699200E-01, -.32306400E+00, -.66034800E-01, 0.13714900E+00, -.17951000E-01, -.10675000E-01, 0.10524600E-01, 0.11389400E-01, -.80572400E-02, -.72680400E-02, -.70360900E-01, 0.74253800E-02, 0.57601900E+00, -.20484000E+00, -.19604500E+00, -.21048900E+00, 0.99888900E-01, 0.31474900E+00, 0.11162900E+00, -.21491800E+00, 0.81635900E-02, 0.47384600E-02, -.47640000E-02, -.51918500E-02, 0.39332500E-02, 0.29416800E-02, 0.91264500E-02, -.33966600E-02, -.15590400E-01, -.92985100E-02, 0.89663500E-02, 0.98161900E-02, -.67117800E-02, -.63045700E-02, -.17726700E-01, 0.62902100E-02, -.14414200E-01, -.61406100E-02, 0.99412700E-02, 0.15537500E-01, -.63976000E-02, -.30624400E-02, -.27324200E-02, 0.66102100E-02, 0.37692000E-02, -.57019800E-02, 0.30550400E-01, 0.19485300E-01, 0.17463500E-02, -.16085000E-01, -.45763800E-02, -.18506200E-01, -.54795900E-02, 0.11528500E-01, -.36730200E-02, -.39761700E-02, 0.17473200E-01, -.12036100E-01, 0.77345400E-03, 0.50943900E-02, 0.62401300E-02, -.66494400E-02 }, { 0.91388600E-01, 0.21806200E-01, 0.24946100E-01, -.32535600E-01, -.81566000E-01, -.99339600E-01, -.40285000E-01, -.33113000E-01, 0.95792000E-02, -.19258500E-01, -.56609300E-02, -.24019200E-01, -.46668500E-01, 0.70563900E-01, -.72594100E-02, -.12218900E+00, 0.44757900E-02, -.39354100E-01, 0.82566300E-02, 0.37469200E-01, -.49069100E-01, 0.15522500E-01, 0.68723000E-01, -.46111200E-01, 0.73258900E-02, -.18751600E-01, 0.38212700E-01, 0.15609700E-01, -.36097200E-01, -.11449400E-01, -.15490000E+00, 0.19025000E-01, 0.12491700E-01, 0.78133400E-02, -.10827600E-01, 0.52729500E-02, -.12168900E-02, -.38550100E-02, -.29795800E-01, 0.18052200E-02, -.11702600E-01, 0.10030800E-01, -.33405500E-01, 0.72469800E-02, -.98634900E-02, 0.61224500E-01, -.82942800E-02, -.58417900E-01, -.15310000E-02, 0.31551400E-02, -.10538200E-01, -.19671100E-02, 0.23489700E-01, 0.19420600E-02, -.28025600E-01, 0.98376400E-02, 0.24911800E-02, 0.36398900E-01, 0.16561400E-01, 0.27265700E-01, 0.29002700E-01, 0.12610000E-02, -.12295700E-01, 0.14757700E-01, 0.23498900E-01, -.12130200E-02, -.45537800E-02, -.14660100E-01, 0.21728200E-02, -.93062600E-03, 0.10868900E+00, -.11936200E-02, -.55579700E-03, -.19632600E-02, -.14455000E-01, 0.39736900E-04, 0.14521100E-02, -.43571100E-02, -.22941300E-01, 0.54916400E-01, 0.45259100E-01, -.10216100E-02, 0.13547600E-01, -.50091500E-02, -.29588500E-02, -.48185800E-02, 0.14196100E-01, 0.33522400E-02, 0.95811500E-02, -.13689400E+00, 0.17439900E-01, -.38198600E-02, 0.60869600E-02, 0.46017200E-04, -.31128000E-01, 0.25987600E-01, 0.19264700E-01, -.42628000E-02, 0.43743300E-02, 0.47927800E-01, 0.30677000E-01, 0.34095400E-01, 0.11197500E-01, 0.40057200E-02, -.84331200E-03, 0.41192200E-02, 0.26585000E-02, -.28805500E-02, -.56056700E-01, -.61239700E-02, -.10669000E-01, 0.10591300E-01, -.40689000E-02, 0.89561400E-02, 0.69314500E-02, -.18683300E-02, 0.18948700E-02, 0.79903900E-03, 0.66834500E-02, -.33336300E-03, 0.24004600E-03, -.14075400E-01, 0.33846200E-02, -.65192700E-02, 0.27324700E-02, 0.11594000E-01, -.19587000E-01, 0.27758200E-02, 0.33061600E-01, 0.16435400E-01, 0.10057500E-02, -.19135100E-02, -.54935800E-01, -.67205700E-01, -.14060600E-01, 0.16178100E-02, 0.22820000E-03, 0.17469600E-02, -.13425300E-02, -.29009400E-02, 0.19741800E-01, -.68917100E-03, 0.20604000E-01, -.10849500E-01, 0.25835100E-03, 0.16756800E-02, -.12262000E-02, -.28311100E-02, 0.25545800E+00, -.78239200E-03, 0.47197000E-02, -.15208200E-02, 0.62745200E+00, -.11060800E+00, -.12031000E+00, -.15229100E+00, -.62345000E-01, 0.21864500E+00, -.62296800E-01, -.12117200E+00, 0.16011200E+00, 0.14377600E+00, -.52789700E-01, -.56130400E-01, -.51646700E-01, 0.30698700E-01, 0.40883500E-01, -.64017700E-01, 0.39856200E-02, 0.18479600E-01, -.14857800E-02, -.46556800E-02, 0.18480300E-01, -.33149000E-02, 0.22837600E-01, -.54337500E-02, 0.67749200E+00, -.46169800E+00, -.58112500E-01, -.11329300E+00, -.71487500E-01, 0.20783500E+00, 0.69799400E-01, -.79106300E-01, -.14693200E-02, -.87877700E-02, 0.96356500E-03, 0.22556300E-02, -.86504900E-02, 0.98067000E-03, -.81654800E-02, 0.27441300E-02, 0.32704500E-02, 0.16419400E-01, -.13049400E-02, -.41025300E-02, 0.16072200E-01, -.26412900E-02, 0.14397900E-01, -.47782600E-02, 0.14258500E-02, 0.66395700E-02, 0.30766300E-01, 0.15704400E-01, 0.67794100E-02, 0.17171800E-01, 0.99125500E-02, -.69930700E-02, -.10944600E-01, 0.60075700E-02, 0.33408200E-02, -.14118300E-01, 0.16417300E-02, 0.11416700E-01, -.24516200E-01, -.53720000E-02, 0.20529400E-01, 0.74459500E-02, 0.35891800E-02, 0.41760500E-02, 0.27178900E-01, -.29319100E-01, 0.94876600E-02, -.54685300E-02, -.66568900E-02, 0.76954400E-02 }, { -.25572800E+00, -.87484000E-01, 0.25426300E+00, 0.13284200E+00, 0.84251700E-01, 0.65595900E-01, -.86048400E+00, -.28210200E+00, 0.47495900E-01, -.87081600E-01, 0.18954000E-01, 0.26696400E+00, 0.34514500E-01, 0.62456200E+00, -.24722500E+00, -.11717200E+00, -.14221800E+00, -.86639700E-01, -.89610100E-01, 0.81422100E-02, 0.44442900E-03, 0.20630000E-01, 0.12774600E+00, 0.27276800E-01, 0.16307000E-01, 0.63290700E-02, -.11570600E+00, -.46357600E-01, -.69424800E-01, -.30332700E-01, -.34811200E+00, 0.66060500E-01, -.40515400E-01, 0.54028400E-01, 0.54760700E+00, 0.10022200E+00, -.23689300E-01, 0.12698900E+00, 0.72631100E-01, 0.18312800E-02, 0.58823400E-01, -.56404600E-02, 0.54781000E-02, 0.53003200E-01, 0.22901400E-01, -.19405900E+00, 0.31901000E-01, 0.33417100E+00, -.60384800E-03, -.55697600E-02, 0.13038300E-01, 0.23603200E-01, -.27105000E-01, -.20930700E-01, 0.24715400E+00, 0.25729900E-01, -.88908400E-02, -.58668300E-01, -.12380400E-01, 0.49206500E-01, -.33863400E-02, -.62494900E-02, 0.66099500E-01, 0.22677100E+00, -.28623600E-01, -.17121700E-01, 0.14872700E-01, -.88026700E-01, -.82621600E-01, 0.10961500E-01, 0.97521000E-01, -.11425600E+00, -.55058700E-01, 0.32921200E-01, -.27998200E-01, 0.30584200E-01, 0.22394400E-01, -.34846500E-01, 0.23055900E-01, -.86609600E-01, -.19891600E-01, 0.71662600E-02, 0.72553400E-01, 0.59691600E-02, -.29635800E-02, 0.14981700E-01, -.99608500E-02, 0.81421500E-02, -.81717800E-02, -.10793600E+00, 0.50878300E-01, -.24737800E-02, -.60504800E-02, -.19726200E-01, 0.28359700E+00, -.34713500E-01, -.20558500E+00, -.51716200E-02, 0.16666600E-01, 0.18871100E+00, -.37202500E-01, -.73244000E-01, -.23950300E-01, -.17475500E-01, 0.82852300E-02, 0.31406700E-01, -.26444300E-01, 0.28710700E-01, -.16925500E-01, 0.57708400E-01, -.36981400E-01, -.30091600E-01, -.63602400E-01, -.36806300E-01, -.10975400E-01, -.67915200E-02, -.15670900E-01, -.39493800E-01, 0.53053400E-02, -.17058100E-01, -.49465800E-01, -.69252700E-02, 0.55273200E-02, -.38940600E-02, -.78772800E-03, -.35473800E-02, -.11547400E-01, -.45142300E-02, -.24734300E-02, 0.11544800E-01, 0.10405200E-01, 0.74746500E-02, 0.17148800E+00, 0.17843300E-01, -.54052900E-02, 0.39556500E-02, 0.19758400E-02, 0.84915900E-03, -.40883600E-03, -.23504500E-02, -.51300900E-02, 0.87644400E-02, 0.45543300E-02, -.71832700E-02, 0.19449100E-02, 0.85243100E-03, -.44448100E-03, -.24009700E-02, -.49246400E-02, 0.12378200E+01, 0.11271500E-02, -.10499900E-02, -.18425800E+00, 0.21347900E+00, 0.43972600E-02, 0.69747200E-01, -.83556900E-01, 0.46334000E-01, 0.52487000E-01, 0.10129600E+00, 0.69018400E+00, -.34851900E+00, -.72439600E-01, -.16758100E+00, -.25236900E-01, 0.30649800E+00, 0.14551200E+00, -.20689500E+00, 0.15256800E-01, 0.12655800E-01, -.21597100E-02, -.44361900E-02, -.38442700E-02, 0.46570300E-01, 0.40269700E-02, -.41159400E-02, -.62634300E+00, 0.43814300E+00, 0.60709200E-01, 0.72612100E-01, 0.61136700E-01, -.19170000E+00, -.10278800E+00, 0.20837000E-01, -.76730100E-02, -.51464500E-02, 0.77356200E-03, 0.21098000E-02, 0.22047400E-02, -.20323400E-01, -.27851400E-02, 0.20504700E-02, 0.13552500E-01, 0.11242900E-01, -.19984200E-02, -.39474900E-02, -.34767600E-02, 0.40552700E-01, 0.68079400E-02, -.36549200E-02, 0.13700600E-01, 0.17289600E-02, -.34732400E-01, 0.98159700E-02, 0.98206900E-03, 0.94591500E-02, -.33380300E-02, -.38333300E-03, 0.68869700E-02, 0.92089300E-03, -.25002000E-01, -.50390300E-02, 0.61872400E-02, 0.92999500E-02, 0.28035800E-01, 0.17418000E-01, -.57271400E-02, -.20090700E-01, 0.92121300E-03, 0.12035400E-02, 0.18543200E-01, -.30917200E-02, 0.18740100E-02, 0.89075000E-02, -.13839600E-02, -.10922800E-02 }, { 0.59469400E-02, -.14387600E-01, 0.63729900E-01, 0.69190800E-01, 0.30034200E-01, -.21260500E+00, 0.75362900E-01, -.20161100E-01, 0.25774200E-01, -.42712700E-02, 0.43229700E-03, 0.21896700E-01, 0.38637200E-01, -.46743900E-01, -.44683500E-01, 0.11932900E-01, 0.31532300E-01, -.57617300E-02, -.71125300E-02, -.18581400E-02, 0.13446400E-01, -.23267800E-02, -.31704200E-02, -.61500700E-02, 0.84696500E-03, -.17515700E-02, -.41566700E-02, -.53188500E-02, -.27469300E-01, -.77056000E-02, -.12681500E+00, 0.10365400E-01, 0.23334000E-01, 0.72333700E-02, 0.30353100E+00, -.44317100E-03, 0.26960400E-03, 0.26355600E-02, 0.25468000E-02, 0.51392500E-03, -.11598100E-02, 0.22008800E-02, -.26139200E-01, 0.38315000E-02, -.17259500E-02, 0.59584400E-02, -.25096400E-02, 0.29495600E-02, -.34384700E-04, 0.81104700E-03, 0.22537200E-02, 0.80745100E-03, 0.68375000E-03, -.90471800E-03, -.17498400E+00, 0.59838500E-03, -.11294400E-02, 0.73392100E-02, 0.36706800E-02, -.16633500E-02, 0.35209200E-02, -.58922300E-03, -.82201400E-02, -.10567000E-01, 0.90859300E-02, -.23351600E-03, -.13946600E-02, 0.69930900E-02, -.98260900E-04, -.18623800E-02, 0.12257500E+00, -.28225600E-02, -.89330800E-03, -.18597000E-02, 0.48653700E-02, 0.20175000E-02, 0.86414500E-02, -.52172400E-02, -.31178100E-02, 0.15567200E-01, 0.97725100E-02, -.89387400E-03, -.59225700E-02, -.21278300E-02, 0.79615700E-03, -.63015800E-02, 0.46931500E-02, -.95475600E-03, 0.13305200E-03, 0.12597200E-01, -.13072100E-01, 0.14280400E-03, -.20697900E-02, -.33202900E-02, -.31194800E-01, -.52021400E-02, -.28481200E-02, -.16064900E-02, 0.56486700E-02, 0.14014600E-01, 0.52052100E-02, -.10606900E-03, -.12773200E-02, 0.10414500E-03, -.58677900E-03, 0.21841000E-03, 0.25942200E-02, 0.62108500E-02, 0.12725900E-01, -.13682200E-01, -.12864100E-02, 0.16251400E-02, 0.12905000E-03, 0.11735800E-01, 0.11926600E-01, -.13911400E-02, 0.34624600E-02, 0.44862200E-02, -.49981900E-02, 0.18233700E-02, 0.52363300E-02, -.11461400E-01, 0.64606300E-02, 0.10323700E-02, 0.53836800E-02, 0.33273200E-02, 0.12366600E-01, -.38713500E-02, 0.65655500E-01, -.20427700E-03, -.11017800E-01, -.26175600E-02, 0.21800000E+00, -.33790400E-02, -.13501200E-02, -.19682500E-02, -.35651300E-03, 0.51830600E-03, 0.49772500E-03, -.31786400E-03, 0.12319500E-02, -.16833800E-03, 0.60235300E-02, -.35155200E-02, -.34460600E-03, 0.50380400E-03, 0.50433200E-03, -.28834300E-03, 0.11541800E-02, -.15290800E-03, 0.23382100E+00, -.47802100E-03, 0.37617500E-01, 0.16482400E-01, -.19074000E-01, -.20006500E-01, 0.17771400E-01, 0.31238000E-01, 0.43760600E-01, -.19204300E-01, -.66979400E-01, 0.59391600E-01, 0.90099500E-02, 0.12373500E-01, -.18435200E-01, -.47148300E-01, -.81031800E-02, 0.28494800E-02, -.17758300E-02, 0.49026100E-02, 0.12784800E-02, 0.80839100E-04, 0.35842300E-03, -.10558500E-02, -.45789500E-01, -.13536700E-02, 0.30946200E+00, -.17474200E+00, -.43463800E-01, -.71828500E-01, -.17996700E-01, 0.11843000E+00, 0.39492400E-01, -.66452600E-01, 0.10850000E-02, -.24880300E-02, -.48196300E-03, 0.12202800E-03, -.38162200E-03, 0.26750500E-03, -.22449600E-02, 0.78875900E-03, -.15549600E-02, 0.43490500E-02, 0.10594000E-02, 0.50108700E-04, 0.34411300E-03, -.85459500E-03, 0.35242800E-02, -.12169000E-02, -.26820700E-02, 0.17306000E-02, -.45301600E-03, 0.46160100E-02, 0.18133300E-02, 0.49972400E-02, 0.20238500E-02, -.19375500E-02, -.24243900E-02, 0.16009500E-02, 0.20120000E-02, -.47211600E-02, 0.44577200E-02, 0.23282800E-02, 0.97959100E-03, -.85191600E-03, 0.25636500E-02, 0.83353400E-03, 0.95835100E-03, 0.10887800E-02, 0.13972100E-01, -.10204200E-01, 0.25704600E-02, -.63614500E-03, -.17699500E-02, 0.22669400E-02 }, { 0.10690100E+00, 0.44505400E-01, -.19766800E+00, -.86764500E-01, -.76826000E-01, -.45531200E+00, -.34327600E+00, 0.13790800E+00, -.10982300E-01, 0.27503200E-01, -.38866000E-02, -.68619700E-01, 0.30676000E-01, -.31783200E+00, 0.72062400E-01, 0.13091200E+00, 0.12748000E+00, 0.45166300E-01, 0.22976000E-01, -.21672600E-01, 0.81985800E-05, 0.17394000E-02, -.28190900E-01, -.29931900E-01, -.13849300E-02, -.97019300E-02, 0.54394300E-01, 0.19919500E-01, 0.14211500E-01, 0.86522900E-03, 0.79307000E-01, -.19982800E-01, 0.25425300E-01, -.35616200E-02, 0.59688000E-01, -.33302500E-01, 0.76236300E-02, -.33383200E-01, 0.22230400E-01, 0.21673300E-02, -.70583400E-02, -.21700100E-01, -.17157300E-01, -.12390800E-01, 0.44414600E-02, 0.41928700E-01, -.13889200E-01, -.54334700E-01, 0.13195500E-02, -.10254500E-02, 0.49769900E-02, -.16450000E-02, -.97151000E-02, 0.13115600E-02, -.18436200E+00, -.92714000E-02, -.28054600E-02, 0.15603600E-01, 0.10209700E-02, -.20639500E-01, 0.13346000E-01, 0.61702000E-02, -.26079600E-01, -.83945400E-01, 0.13137000E-01, 0.52926600E-02, -.22035100E-02, 0.34653900E-01, 0.23079700E-01, -.48534900E-02, 0.27114200E-01, 0.35255300E-01, 0.12695300E-01, -.83707500E-02, 0.80685300E-02, -.63132000E-02, 0.11677200E-01, 0.10096100E-03, 0.44521200E-02, 0.42475700E-02, 0.25433100E-02, 0.32103700E-02, -.74750100E-02, 0.17220300E-03, -.93639300E-02, -.23688600E-02, 0.48337900E-02, -.27567300E-02, 0.95803700E-03, 0.16422800E-01, -.28780400E-01, 0.47717600E-02, -.35721400E-04, 0.11127400E-01, -.81653600E-01, -.20460800E-01, 0.68463200E-01, 0.21339100E-02, -.25879200E-02, -.73812200E-01, 0.88346000E-02, 0.15332000E-01, 0.54783200E-02, 0.34048100E-02, -.27204300E-02, -.64332800E-02, 0.97382300E-02, 0.17832400E-03, 0.34270900E-01, -.23277100E-01, 0.78474500E-02, 0.83724300E-02, 0.27724700E-01, 0.22637100E-01, 0.79377400E-02, 0.20522400E-02, 0.33161300E-02, 0.21941900E-01, -.36540800E-02, 0.90943900E-02, 0.17959100E-01, -.75276300E-02, 0.62547800E-02, -.35169700E-02, 0.17661100E-01, 0.15812000E-02, 0.14112700E-01, -.20138700E-02, 0.20178000E-01, -.11072400E-01, 0.26042700E-02, -.44784400E-02, -.54930900E-01, -.10395800E-01, 0.12878000E-01, -.30097100E-02, -.10979300E-02, 0.45050700E-04, 0.28338900E-02, 0.14142700E-02, -.24503600E-02, -.98800200E-03, -.16354900E-01, 0.55419200E-02, -.10889900E-02, 0.57947000E-04, 0.27645400E-02, 0.14485700E-02, -.23812800E-02, -.99314700E-03, -.16134000E-01, 0.14035900E+00, 0.10892800E+00, -.13393000E+00, -.21261100E-01, -.31466600E-01, 0.99334700E-01, 0.13308400E-01, 0.63563400E-01, -.57306400E-01, -.73197900E+00, 0.32518800E+00, 0.66697900E-01, 0.16225800E+00, 0.18975800E-01, -.34862200E+00, -.18752200E+00, 0.15696300E+00, -.86883200E-02, -.11009700E-02, 0.63803900E-02, 0.28680400E-02, -.18746300E-02, -.73305500E-02, -.61726100E-01, 0.34306800E-02, 0.12170100E+01, -.72474800E+00, -.34949700E+00, -.38895400E+00, 0.91748500E-01, 0.53285300E+00, 0.70147700E-01, -.36229400E+00, 0.39744600E-02, 0.81941200E-04, -.25448000E-02, -.12513300E-02, 0.91206500E-03, 0.27847300E-02, 0.76151100E-02, -.15127600E-02, -.73372700E-02, -.10991600E-02, 0.54102900E-02, 0.25360500E-02, -.15661400E-02, -.64540200E-02, -.15881700E-01, 0.29507100E-02, -.80137900E-02, -.25479500E-02, 0.31093100E-01, 0.62378700E-02, -.29528900E-02, 0.84905300E-03, -.29718100E-03, 0.33011100E-02, -.13577900E-02, -.25556200E-02, 0.38171400E-01, 0.12320200E-03, -.71260100E-02, -.11473400E-01, -.25274200E-01, -.27458800E-01, 0.13269500E-03, 0.32344100E-01, -.16615600E-02, -.15976300E-02, 0.15024200E-01, -.31834400E-01, 0.92997900E-02, 0.42853200E-02, 0.27344300E-02, -.35422000E-02 }, { 0.71000700E+01, 0.26459100E+01, -.82858700E+01, -.49049100E+01, -.19090700E+01, -.16959600E+02, -.13205000E+02, 0.50554500E+01, -.23344700E+01, 0.33895200E+01, 0.34609800E+00, 0.56121600E+00, 0.71921600E+01, -.29742300E+02, 0.25237700E+01, 0.23408600E+02, 0.12579000E+02, 0.53605400E+01, -.19870900E+01, -.28045800E+01, 0.83608200E+00, 0.11194400E+01, -.13629900E+01, -.39446700E+01, 0.60623100E+00, -.13160200E+01, 0.61420200E+00, -.25292800E+00, -.12707800E+02, -.14398200E+01, -.25559000E+02, 0.17764500E+01, 0.65112700E+01, 0.16375100E+01, 0.38152600E+02, -.32418400E+01, -.10932600E+01, -.33743300E+01, -.21047400E+00, 0.80731800E+00, -.31229100E+01, -.84512300E+00, -.73364600E+01, -.10841700E+01, -.20317900E+00, 0.89856300E+01, -.23996800E+01, -.63104000E+01, 0.59239900E-01, 0.19121200E+00, 0.36047900E+00, -.58177000E+00, 0.10660300E+01, 0.30270200E-02, -.45654500E+02, -.19373400E+00, 0.12685900E-01, -.28321000E+01, -.23542700E+01, -.13898800E+01, 0.20654800E+01, -.18042900E+00, -.17878500E+01, -.60344200E+01, 0.79637400E+00, 0.56253300E+00, -.75317600E+00, 0.20697500E+01, 0.34409500E+01, -.29422600E+00, 0.11175000E+02, 0.36208100E+01, 0.17082100E+01, -.17854800E+01, 0.78643900E+00, -.43055200E+00, -.37627900E+01, 0.16646900E+01, -.21603700E+01, 0.40460800E+01, 0.44232500E+01, -.17628700E+00, 0.44694000E+00, -.93250100E+00, 0.62366200E+00, 0.29845100E+01, 0.47454700E+00, -.43537900E+01, 0.62735900E+00, -.10299400E+02, 0.30240100E+01, 0.19408300E-01, 0.55989600E+00, -.54310900E+00, 0.57160700E+01, 0.24168900E+01, 0.11939500E+00, -.31475100E+00, 0.96983400E+00, 0.31309300E+01, 0.35363900E+01, 0.62152000E+01, 0.79429100E+00, 0.18194100E+01, -.15920600E+00, 0.95781200E+00, -.66468100E-01, -.70612100E-01, 0.16124800E+00, -.25499600E+01, -.11535300E+01, -.21223000E+00, 0.43067500E+00, 0.32496100E+00, 0.52908400E+00, -.34613300E+00, 0.89403600E+00, -.78154700E+00, 0.65692100E+00, -.42995200E+00, -.24020300E+00, -.26733500E+01, -.10898400E+01, -.54754100E+00, 0.10024700E+01, 0.18308000E+01, -.55180800E+01, 0.10074500E+01, 0.66126700E+01, 0.15557600E+01, 0.14957200E+01, -.64553400E+00, -.61179100E+02, -.69596900E+01, 0.19833000E+00, -.13490900E+01, 0.10832200E+00, 0.18797900E+00, 0.63721300E+00, -.18730100E+00, 0.16451900E+01, 0.48261100E-01, 0.58894500E+01, -.15481000E+01, 0.11667500E+00, 0.17940900E+00, 0.63380900E+00, -.19861400E+00, 0.16120000E+01, 0.65824600E-01, 0.58415500E+01, -.16030200E+01, 0.21325800E+03, -.72347500E+02, -.37363400E+02, -.53888200E+02, -.20828900E+02, 0.66047200E+02, 0.10976300E+02, -.46401000E+02, -.36266300E+02, 0.42507300E+02, 0.13236000E+02, 0.68315700E+01, -.43950600E+01, -.14313700E+02, 0.16395700E+02, 0.49715000E+01, 0.11475900E+01, 0.23478100E+01, 0.15051100E+01, -.46124300E+00, 0.14857600E+01, 0.45319600E+00, 0.12842600E+02, -.99506800E+00, 0.33488900E+02, 0.68421900E+00, -.80699300E+01, -.16315000E+02, 0.17660900E+02, 0.21564900E+02, 0.15247200E+02, -.13715200E+02, -.48084300E+00, -.10467500E+01, -.63205800E+00, 0.22305500E+00, -.74889400E+00, -.29746800E+00, -.25627400E+01, 0.48853700E+00, 0.91080500E+00, 0.21748000E+01, 0.13032200E+01, -.43208200E+00, 0.13311900E+01, 0.44102000E+00, 0.49146500E+01, -.88523700E+00, 0.81069600E+00, 0.11974100E+01, 0.79981400E+01, 0.35125700E+01, 0.13383700E+01, 0.51826600E+01, 0.25019800E+01, -.14888500E+01, -.28397800E+01, 0.11553900E+01, 0.28619300E+01, 0.61499300E+00, 0.63143200E+00, 0.12428900E+01, -.69956300E+01, 0.32148700E+01, 0.18796400E+01, 0.81407700E+00, 0.71057600E+00, 0.73898400E+00, 0.95670000E+01, -.30760600E+01, 0.27775800E+01, 0.16007400E+01, -.12581900E+01, 0.17620200E+01 }, { -.62516100E+01, -.19322700E+00, 0.51011300E+01, 0.37717300E+01, 0.33563800E+01, 0.16306400E+02, 0.29784000E+02, -.11418700E+01, 0.12542800E+01, -.21900200E+01, 0.15604600E+00, 0.96311300E+00, -.35514600E+01, 0.20134600E+02, -.23362600E+01, -.11436000E+02, -.58372000E+01, -.50819400E+01, -.17037300E+01, 0.27478700E+01, -.54498400E+00, -.40876500E+00, -.20848500E+01, 0.39081900E+01, -.20229200E+00, 0.12365600E+01, -.21653900E+01, -.90293300E+00, 0.35151800E+01, 0.16013300E+01, 0.12990500E+02, -.51422500E+00, -.18841300E+01, -.16462900E+01, -.12913400E+02, 0.10530300E+01, 0.50123400E-01, 0.20072000E+01, 0.29516800E+00, -.40206600E+00, 0.19662300E+01, 0.19401000E+01, 0.80896900E+01, -.10957300E+01, 0.20416100E+00, -.78064500E+01, 0.11907700E+01, 0.72363800E+01, 0.22691200E+00, -.34262900E+00, 0.77353100E+00, 0.31222900E+00, -.26122700E+01, -.19703000E+00, 0.20021800E+02, -.91369900E+00, -.51936400E+00, -.46861100E+00, -.17018000E+01, -.22505200E+01, 0.32536300E+01, -.43751100E+00, -.22285600E-01, 0.48088100E+01, 0.19875200E+01, -.55899500E+00, 0.21975900E+00, -.21603500E+01, -.22359200E+01, 0.16934600E+00, -.45193200E+01, -.30399200E+01, -.12081800E+01, 0.56627600E+00, -.12669300E+01, -.23503300E+00, -.32810000E+01, 0.64651400E+00, 0.41646800E+00, -.19987300E+00, -.29379300E+00, -.89474600E+00, -.13488300E+01, 0.12013600E+00, 0.56995300E+00, -.82511800E+00, -.82416200E+00, -.38663100E+00, -.14027300E+01, -.84637600E+01, 0.58101700E+00, 0.49478600E+00, 0.15213700E+01, -.23724600E+01, -.17987700E+02, 0.25754900E+01, -.18205500E+00, -.94868400E+00, -.26163500E+01, -.39814900E+01, 0.46620600E+00, -.21711000E+01, 0.39973000E+00, -.52097200E-01, 0.90960700E+00, -.24114000E+01, -.72476000E+00, -.21356000E+01, -.39750900E+01, 0.21432800E+01, 0.33193800E+01, 0.18039700E+00, 0.27332300E+01, 0.68041300E+00, -.10587900E+01, -.30575100E+00, 0.20493500E+01, 0.12150500E+00, 0.13347600E+01, 0.11091900E+01, 0.10416100E+01, 0.22363300E+01, -.20374600E+00, 0.75600400E+00, -.11957800E+01, 0.42515500E+00, 0.77192200E+00, 0.78318500E+00, 0.68144100E+01, -.46629300E-01, -.58412300E+01, 0.92275900E+00, -.46184700E+02, 0.67796000E+01, 0.42899000E+01, 0.39315300E+00, 0.64445000E-01, -.33049700E+00, 0.53585400E+00, -.61592600E+00, 0.32631500E-01, 0.11440700E+00, 0.13728000E+01, -.28902700E+01, 0.61317300E-01, -.32900600E+00, 0.55197500E+00, -.59087700E+00, 0.40075200E-01, 0.12093100E+00, 0.13223100E+01, -.28271000E+01, 0.54371100E+00, -.65901500E+02, -.21024900E+02, -.32187100E+02, 0.54534300E+02, 0.28632300E+02, 0.56831500E+02, -.35568500E+02, -.44081700E+02, 0.15507200E+02, 0.59001600E+01, 0.19204200E+02, -.31223600E+02, -.32765600E+02, -.24748200E+02, 0.19896200E+02, 0.40531100E+00, -.56186500E+01, 0.65392600E+00, -.68156100E+00, -.11111900E+01, 0.33169100E+00, -.47716900E+01, -.10081000E+01, 0.31829700E+03, -.19971400E+03, -.57824200E+02, -.65653900E+02, -.37912500E+02, 0.11805500E+03, -.99469100E+01, -.55280900E+02, -.85094100E-01, 0.23655600E+01, -.20605000E+00, 0.33523000E+00, 0.40165700E+00, -.19048800E+00, 0.94434600E+00, 0.48442400E+00, 0.41619400E+00, -.49192600E+01, 0.52568300E+00, -.60626300E+00, -.96027600E+00, 0.32226700E+00, -.21642600E+01, -.90996200E+00, -.12061500E+00, -.41965600E+00, -.22156500E+01, -.12297300E+01, -.27291300E+00, 0.19155600E+00, 0.87436800E+00, 0.18231600E+00, -.60659900E+00, -.23751700E+00, 0.65531000E+01, -.43062900E+01, -.12986500E+01, -.33344800E+01, 0.23442700E+01, -.72446800E+01, 0.65402700E+00, 0.52327400E+01, -.10823000E+00, -.24399700E+00, 0.10171700E+02, -.38844700E+01, -.10432000E+01, -.28266000E+01, 0.34229900E+00, -.17735300E+00 }, { 0.10291000E+01, 0.46557600E+00, -.18603000E+01, 0.38724400E+00, -.51925500E+00, -.38340300E+01, -.18152900E+01, 0.22668700E+01, -.57255700E+00, 0.11992400E+01, -.38027600E-01, -.77418800E+00, 0.12327600E+01, -.68612100E+01, 0.98822400E+00, 0.33198500E+01, 0.16525700E+01, 0.22703300E+01, 0.74441500E+00, -.65703300E+00, -.13721900E+00, -.10267700E+00, -.71359000E+00, -.27600500E+00, -.67719600E-01, 0.21306200E+00, 0.93211700E+00, 0.24400300E+00, 0.10359000E+01, 0.25948600E+00, 0.51870000E+01, -.65187900E+00, 0.18546500E+00, -.36375700E+00, 0.23816000E+01, -.83886800E+00, 0.42387700E+00, 0.10393500E+00, -.38023700E+00, 0.37123500E+00, -.24752400E+00, -.12081900E+00, -.32042300E+01, -.20889400E+00, -.73713000E+00, 0.32727400E+01, -.77985300E+00, -.53510400E+00, -.11266100E-01, 0.25048000E-01, -.13796900E+00, -.12651100E+00, 0.33273600E+00, 0.30418500E-01, -.25410100E+01, -.12273400E+00, 0.10518300E+00, 0.51020100E-01, 0.26350200E+00, -.76453700E+00, -.16544500E+01, 0.57396600E-01, 0.31925000E+00, -.15912300E+01, -.11106400E+01, 0.23968600E+00, -.83213300E-01, 0.63573900E+00, 0.98082300E+00, -.11256600E+00, -.63709700E+00, 0.14347000E+01, 0.62959700E+00, -.13293200E+00, 0.83224800E+00, -.83667800E-01, 0.46124200E+00, -.72705300E-01, -.50954400E+00, -.45714800E-01, 0.50234800E+00, 0.67389400E-02, 0.44118700E+00, -.25687900E+00, 0.15857100E+00, 0.19157200E-02, 0.47342800E-01, -.32973200E+00, 0.18286800E+00, -.82718800E+00, 0.14111700E+00, 0.84630500E-01, 0.19332400E+00, -.46935100E+00, 0.69253100E+00, 0.42224200E+00, -.62627600E+00, -.63086800E-01, 0.20323500E-01, 0.15508900E+01, 0.12064100E+00, 0.58473800E+00, -.13836200E+00, -.15331800E+00, 0.73617000E-01, 0.19595400E+00, 0.71064400E+00, -.19491400E+00, -.14377400E+01, -.28797000E+00, -.21578600E+00, 0.17930900E+00, 0.13602000E+00, -.22752500E+00, -.28687500E+00, 0.71048900E-02, 0.68090900E-01, -.18768700E+00, 0.29634500E+00, -.26388900E+00, 0.30061400E+00, -.34356900E+00, -.20296600E+00, 0.18783100E-01, -.11091200E+01, -.57392900E-01, -.42830400E+00, 0.12890100E+00, 0.14571500E+01, 0.54742100E+00, -.12197600E+00, -.17923200E+00, 0.19358000E+00, -.12274100E+00, -.32542300E+00, -.46370600E+00, 0.12166000E-01, -.49647200E-01, 0.15273400E+00, 0.35825600E-01, 0.21453000E+00, -.18401600E+00, 0.66822600E+00, -.12587900E+00, 0.12624400E-01, -.49825200E-01, 0.15400100E+00, 0.32168100E-01, 0.20857900E+00, -.17976300E+00, 0.66040600E+00, -.13988700E+00, 0.18087800E-01, 0.40002500E-01, 0.87638300E+01, 0.17071200E+01, -.87136400E+01, -.25718400E+01, -.64173800E+01, 0.31725500E+01, 0.25717700E+02, -.12399700E+02, -.29003100E+01, -.65274900E+01, 0.14950400E+01, 0.14409600E+02, 0.13474900E+02, -.50130900E+01, 0.78104300E-01, -.31390400E+00, 0.29142000E+00, 0.31618000E-01, 0.19379700E+00, -.83295500E+00, 0.14641900E+01, -.86053500E-01, -.87774500E+02, 0.54244900E+02, 0.25792500E+02, 0.28084100E+02, -.41942900E+01, -.37962100E+02, -.29955300E+00, 0.27556500E+02, -.11183300E-01, 0.16625700E+00, -.14947200E+00, -.27244100E-01, -.93468700E-01, 0.39233700E+00, -.31859600E+00, 0.22917200E-01, 0.31802500E-01, -.26679400E+00, 0.26484500E+00, 0.20623900E-01, 0.17408400E+00, -.71551500E+00, 0.69006100E+00, -.75718500E-01, 0.11050800E+00, 0.74855500E-01, -.75569100E+00, 0.55960100E+00, 0.12685800E+00, 0.25037500E+00, 0.49745500E+00, -.17286900E+00, -.54032700E+00, 0.10354300E+00, -.22161300E+01, 0.10503000E+01, 0.30054400E+00, 0.40802400E+00, 0.67441000E+00, 0.16669400E+01, 0.55549500E+00, -.19229600E+01, 0.59401200E-01, 0.41297100E-01, -.14294400E+01, 0.22294000E+01, 0.54889700E+00, -.66595800E-01, -.98703000E-01, 0.25013300E+00 }, { 0.63476400E+00, 0.23482600E+00, -.10961900E+01, -.51165300E+00, -.59738300E+00, -.27129300E+01, -.17622500E+01, 0.80943400E+00, -.11321800E+00, 0.10176000E+00, 0.27446500E-01, -.36966700E+00, 0.19217600E+00, -.20148600E+01, 0.58085800E+00, 0.99645600E+00, 0.78210400E+00, 0.47776200E+00, 0.12757500E+00, 0.47432100E-01, -.13691600E+00, 0.34769000E-01, -.12848600E-01, -.33334600E+00, 0.38505100E-01, -.18251000E+00, 0.28559100E+00, 0.45487200E-01, -.48309200E+00, -.74820900E-01, -.19548000E+01, 0.16319600E+00, 0.40656000E+00, 0.59041300E-01, 0.35675700E+00, -.18384400E+00, -.94277900E-01, -.26322900E+00, -.32941300E+00, 0.43418500E-01, -.14410800E+00, -.18085000E+00, 0.35891300E+00, -.33032000E+00, 0.14094300E+00, 0.44202400E+00, -.13190200E+00, -.11108800E+01, 0.94447100E-02, 0.43021300E-01, 0.11233700E-01, -.12161400E+00, 0.13438200E+00, 0.59567700E-01, -.50560900E+01, -.83602500E-01, 0.22372800E-01, 0.75895300E-01, -.19664000E+00, -.23670700E+00, 0.24399700E+00, -.65749800E-02, -.35112900E+00, -.55243400E+00, 0.34905100E+00, 0.75422200E-01, -.11447900E+00, 0.50421000E-01, 0.40536700E+00, -.84988600E-01, 0.18802100E+01, 0.51270400E+00, 0.12958100E+00, -.17513800E+00, 0.49215200E-03, 0.66066000E-01, 0.19885200E+00, -.17247700E+00, -.17375900E+00, 0.46449800E+00, 0.92695400E+00, 0.56907300E-01, 0.55985400E+00, -.11936600E+00, -.12537100E+00, 0.44611300E+00, 0.13356400E+00, -.64393900E+00, 0.90010500E-01, -.89907900E+00, -.10078500E+00, 0.16868800E+00, -.78954400E-01, 0.71240500E-01, 0.24540000E+01, -.59985000E+00, -.18699900E+00, 0.17314100E-01, 0.27504200E+00, 0.12355300E+01, 0.13395300E+00, 0.54345500E+00, -.10320100E-01, -.12980000E-01, -.33134100E-02, 0.10794900E-01, 0.13500400E+00, 0.28364600E+00, -.29908900E+00, -.12919900E+00, -.15954000E+00, 0.11567700E+00, -.37012900E+00, 0.16639800E+00, -.16805600E+00, 0.64339500E-01, -.66392100E-01, 0.16763200E-01, 0.18344900E+00, -.77969600E-01, -.82923200E-01, 0.11028200E+00, 0.12653200E+00, -.14091900E+00, -.21762200E+00, -.26841000E-01, -.10217400E+00, -.33446500E-02, 0.50890500E-01, 0.42838400E+00, -.52760800E+00, 0.13744600E+00, 0.63747300E+01, 0.87934500E-01, -.52867100E+00, 0.41099800E+00, 0.44453900E-02, -.14961100E-01, 0.11610500E+00, -.54769000E-02, 0.42334400E+00, -.12044100E+00, 0.88420900E+00, -.26839100E+00, 0.49064100E-02, -.16038600E-01, 0.11650800E+00, -.74524300E-02, 0.41143500E+00, -.11684000E+00, 0.86942200E+00, -.26981000E+00, -.73308500E-01, -.10276900E+00, -.12119300E+00, -.49165500E+01, 0.21110400E+01, 0.49020000E+01, 0.35534500E+01, -.34029400E+01, 0.29785600E+02, -.10833300E+02, -.16892700E+01, -.57291300E+01, -.52060600E+01, 0.13555000E+02, 0.95344800E+01, -.57851500E+01, 0.20607800E+00, -.63604500E+00, 0.46767800E+00, -.13496100E+00, 0.39242100E+00, -.50491300E+00, 0.22903700E+01, -.36270900E+00, -.23623700E+02, 0.10573800E+02, 0.11450000E+02, 0.10302000E+02, -.71060700E+01, -.15002800E+02, -.20994200E+01, 0.10416400E+02, -.46043000E-01, 0.26411400E+00, -.20963800E+00, 0.61133800E-01, -.20308200E+00, 0.24171900E+00, -.53150700E+00, 0.16411000E+00, 0.14370700E+00, -.52992000E+00, 0.40765400E+00, -.12927300E+00, 0.34951300E+00, -.42540000E+00, 0.10305900E+01, -.32563800E+00, 0.11713000E+00, 0.20968500E+00, -.15096200E+01, 0.10194800E+01, 0.29027800E+00, 0.10631700E+01, 0.11135600E+01, -.36040100E+00, -.11754800E+01, 0.24761900E+00, -.18893500E+01, 0.18945800E+00, 0.33321000E+00, 0.66651400E+00, 0.14520300E+01, 0.97037600E+00, 0.10399200E+01, -.15719800E+01, 0.15320500E+00, 0.12914200E+00, 0.15866400E+01, 0.27914300E-01, 0.65639300E+00, 0.22121500E+00, -.24708000E+00, 0.46176500E+00 }, { 0.29738800E+01, 0.11152200E+01, -.29863900E+01, -.12517000E+01, -.10062600E+01, -.69415400E+00, 0.10459900E+02, 0.34351200E+01, -.54724000E+00, 0.13709100E+01, -.29606700E+00, -.38104500E+01, -.37891200E+00, -.84075500E+01, 0.38539400E+01, 0.12072000E+01, 0.18067900E+01, 0.15873100E+01, 0.11022400E+01, 0.39330400E+00, -.22563800E+00, -.40857200E+00, -.19507200E+01, -.53861000E+00, -.15280700E+00, -.10917700E+00, 0.41691300E+00, 0.42478500E+00, -.77462800E+00, 0.15798200E+00, 0.19089900E+01, -.68970400E+00, -.10029800E+00, -.35709200E+00, -.14409300E+02, -.49033800E+00, 0.35315400E+00, -.73875900E+00, -.20251800E+00, -.28060100E+00, -.40252800E+00, -.14528800E+00, 0.19610000E+01, -.56243600E+00, 0.47010500E-02, 0.19056300E+01, -.46330200E+00, -.19669700E+01, 0.66117600E-02, 0.41667400E-01, 0.30732000E+00, 0.31804600E+00, -.51079700E+00, -.59201500E-01, 0.10137000E+02, 0.19897800E+00, -.37525000E+00, 0.14433400E+01, 0.10099700E+01, 0.59576200E+00, 0.30411500E+01, 0.12024000E+00, -.15582500E+01, -.19375600E+01, 0.20365500E+01, -.13148800E+00, 0.14891400E+00, 0.12671900E+01, -.77235000E+00, 0.13051800E+00, -.52108600E+00, -.13481500E+01, 0.77715300E-01, 0.25235400E-01, -.12653000E+01, 0.28306300E+00, 0.10846000E+01, -.54011100E+00, 0.15587800E+01, -.33825300E+00, -.25570800E+00, 0.41830300E+00, 0.72447000E+00, 0.30005600E-02, -.63360900E+00, 0.19483800E+00, 0.14978400E+00, -.73893700E-02, -.40144900E+00, 0.71164200E+01, -.17296100E+01, 0.35090100E-01, -.28662700E+00, 0.10567800E+01, -.52568400E+00, -.20065000E+01, 0.87455000E+00, -.16800600E+00, -.48988900E+00, 0.97692300E+00, -.10127400E+01, 0.74707200E+00, -.11422000E+00, 0.25154600E+00, -.20824000E+00, -.70413500E+00, 0.71673500E+00, -.19150700E+00, 0.39124600E+01, -.18807000E+00, 0.26252800E+00, 0.92382000E-01, 0.34920300E-01, 0.71465000E-01, 0.36242200E+00, 0.19046100E+00, -.36599800E+00, 0.13325000E+01, 0.43832200E+00, 0.99543100E+00, -.25090900E+00, 0.48914000E+00, 0.86332700E+00, -.44080600E+00, 0.19540400E+01, 0.76362200E+00, -.70201000E+00, 0.12463800E+00, -.87471100E+01, -.76154600E+00, 0.23674800E+01, 0.40037400E+00, -.19724600E+02, -.21429200E+01, 0.11450400E+01, 0.12181600E+01, -.64046200E-01, 0.40989300E-01, -.25339200E+00, -.17667600E+00, -.85411400E+00, 0.46328500E+00, -.30893900E+01, 0.82575200E+00, -.66256000E-01, 0.43572800E-01, -.26159900E+00, -.16958300E+00, -.82978400E+00, 0.45030600E+00, -.30528800E+01, 0.85168600E+00, 0.18994100E-01, -.54683700E-01, -.13567600E+01, -.57626500E-01, 0.12674800E+02, -.37881500E+01, 0.51590000E+01, -.17567500E+01, -.76941600E+02, 0.39054200E+02, 0.84228000E+01, 0.15934100E+02, 0.67959200E+01, -.35926200E+02, -.31742800E+02, 0.14340400E+02, -.56064000E+00, -.52145100E+00, -.19523900E+00, -.17301400E+00, -.41449500E+00, 0.67480400E+00, -.22868500E+01, 0.46115300E+00, 0.13728000E+03, -.10575300E+03, -.58807300E+02, -.59169600E+02, 0.27053400E+02, 0.65806500E+02, 0.45925000E+00, -.58212200E+02, 0.19491600E+00, 0.21104500E+00, 0.10224900E+00, 0.86301400E-01, 0.23817100E+00, -.35114600E+00, 0.10781500E+01, -.19494800E+00, -.44180500E+00, -.47531600E+00, -.17804800E+00, -.13492700E+00, -.37218800E+00, 0.55648300E+00, -.21268200E+01, 0.41052200E+00, -.40616300E+00, -.44913400E+00, 0.47556800E+01, 0.37025600E+00, -.53877800E+00, -.82833700E+00, -.10414100E+01, 0.62605800E+00, 0.10055500E+01, -.46081500E+00, 0.45629600E+01, -.30484000E+00, -.17665100E+01, -.91811500E+00, -.43708100E+01, -.30047400E+01, -.90137200E+00, 0.46850500E+01, -.27981100E+00, -.27395200E+00, 0.81249200E+00, -.62920100E+01, -.21238200E+01, 0.19553300E+01, 0.48989700E+00, -.77837000E+00 }, { -.29648400E+01, -.11580400E+01, 0.26909800E+01, 0.11692600E+01, 0.12418300E+01, 0.26797600E+01, -.81749800E+01, -.39446100E+01, 0.64240000E+00, -.14758700E+01, 0.19992600E+00, 0.33551800E+01, -.69790600E-01, 0.80733800E+01, -.36197100E+01, -.13007500E+01, -.19307200E+01, -.24304900E+01, -.16077300E+01, -.25437400E+00, 0.91214600E+00, 0.54074900E+00, 0.16599700E+01, 0.19012900E+00, 0.88038100E-01, -.52638400E-01, 0.31655500E-01, -.39638000E-01, -.28066300E+00, 0.21502400E+00, -.15137800E+01, 0.77661300E+00, -.64135200E+00, 0.40609800E+00, 0.18768500E+01, 0.11730600E+01, -.49907500E+00, 0.19825700E+01, -.70926400E+00, -.14250700E+00, 0.96450700E+00, 0.14484600E+01, -.14792000E+01, 0.42368100E+00, -.28414000E+00, -.28931000E+01, 0.79357700E+00, 0.20684000E+01, 0.14441500E-01, -.63907600E-01, -.55686600E+00, -.38622600E+00, 0.32959400E+00, 0.20373500E+00, 0.83073800E+00, -.35533500E+00, 0.28178200E+00, 0.17707100E+01, -.33884800E+00, -.11290700E+01, -.62752400E+00, -.28311300E+00, 0.81552700E+00, 0.25775700E+01, -.56339200E+00, -.82064800E-01, 0.26254900E+00, -.15392500E+01, -.39351600E+00, -.98659700E-01, 0.10371800E+01, -.21339600E+00, -.47885600E+00, 0.27187000E+00, -.37399200E+00, 0.25909600E-01, -.55717000E+00, -.29146900E+00, 0.15107600E+00, -.20943600E+01, 0.26751100E+00, 0.12671400E+00, 0.90941100E+00, 0.17577700E+00, -.65097300E+00, 0.14532500E+00, 0.46557800E+00, 0.74169100E+00, 0.37630500E+00, -.63972200E+01, 0.14979900E+01, -.28054200E-01, 0.24558100E+00, -.18353600E+00, 0.99015200E-01, 0.14309800E+01, 0.63340600E+00, 0.20780800E+00, 0.22983300E+00, -.27036900E+01, 0.15026500E+00, -.20170000E+01, 0.24736200E-01, 0.27130100E-01, -.14221000E+00, 0.12101900E+00, -.48910000E+00, -.16279900E+00, 0.23369700E+01, 0.13045900E+01, 0.65619300E+00, 0.57276900E+00, 0.43586200E+00, 0.89302600E+00, 0.67819500E-01, -.15971900E+00, 0.14875700E+00, 0.19929500E+00, -.12608700E+00, 0.42296600E+00, 0.31602900E+00, -.70185100E+00, 0.68069100E+00, 0.42942100E-01, 0.12193200E+00, 0.13244900E+00, 0.65516600E+00, -.10375200E+00, 0.43358500E+01, -.54847300E+00, 0.91009200E+00, -.14440200E+00, -.74830700E+01, 0.30121500E+01, 0.13300500E+01, -.60388000E+00, -.79687900E-01, -.83125000E-03, -.15172200E+00, 0.68626900E-01, 0.25327900E+00, 0.17057400E+00, -.40432900E+00, 0.41083200E+00, -.79649500E-01, -.14790400E-02, -.15278300E+00, 0.69960700E-01, 0.25163700E+00, 0.16952900E+00, -.40303800E+00, 0.41876900E+00, 0.11755000E+00, -.39660700E-01, -.90050200E+00, 0.34124600E+00, 0.30743700E+00, 0.15280000E+02, -.29406500E+01, -.65241100E+00, 0.17482600E+02, -.26405000E+02, -.31997000E+01, -.23309000E+01, 0.36039200E+01, 0.87228600E+01, 0.42274800E+01, 0.26366300E+00, -.74421400E+00, -.42459600E+00, -.36201500E+00, 0.31031200E+00, 0.30178700E+00, 0.24626900E-01, -.16065100E+01, 0.24290600E+00, -.93607100E+02, 0.75452300E+02, 0.32100500E+02, 0.32309400E+02, -.46455500E+01, -.34795300E+02, 0.62016900E+01, 0.29686100E+02, 0.31781400E+00, 0.22735400E+00, 0.13462600E+00, -.14929800E+00, -.12275600E+00, 0.27305100E-01, 0.76050300E-01, -.12775100E+00, -.63165200E+00, -.39681800E+00, -.31065200E+00, 0.26835400E+00, 0.25846800E+00, 0.29890400E-01, -.99532000E-01, 0.21190900E+00, -.48147800E+00, -.17424200E+00, -.27271700E+01, -.11617100E+01, -.18194200E+00, -.11935100E+01, -.88595500E-01, 0.19160100E+00, 0.17688900E+00, -.16008000E+00, -.22293100E+00, 0.83981800E+00, 0.54607000E+00, -.56106200E-01, 0.23595600E+01, 0.52821800E+00, 0.13460700E+00, -.14544000E+01, -.10750200E+00, -.11280900E+00, 0.48873900E+00, 0.34130500E+01, 0.50067900E+00, -.88256000E+00, 0.17840600E+00, -.21296600E+00 }, { -.15589600E+01, -.65498000E+00, 0.25641000E+01, 0.71781800E+00, 0.61645500E-01, 0.47581200E+01, 0.46944700E+01, -.83994200E+00, 0.55823400E+00, -.84777600E+00, -.26817500E-01, -.39901700E+00, -.21695400E+01, 0.74291700E+01, 0.26850800E+00, -.55246400E+01, -.32976600E+01, -.12823100E+00, 0.14234100E+01, 0.40455400E+00, -.44273600E+00, -.36281400E+00, 0.58110200E+00, 0.12157700E+01, -.20829900E+00, 0.53901700E+00, -.20463200E-02, 0.32999900E-01, 0.35266800E+01, 0.44900500E+00, 0.58006500E+01, -.56046600E+00, -.16679800E+01, -.53477400E+00, -.95920300E+01, 0.61755700E+00, 0.28054400E+00, 0.83619600E+00, -.12550400E+01, -.26648000E+00, 0.56355900E+00, 0.95711200E+00, -.15275600E+01, 0.91017200E+00, -.25677900E+00, -.12079300E+01, 0.70237500E+00, -.18814000E+00, -.12114900E+00, 0.14517800E+00, -.21781900E+00, 0.28352700E-01, 0.57922100E+00, 0.65077900E-02, 0.10372400E+02, 0.47526000E+00, 0.18528200E+00, -.30594300E+00, 0.11083000E+01, 0.12601100E+01, -.22084900E+01, -.31275900E-02, 0.77709500E+00, 0.70224800E+00, -.10379600E+01, -.35701700E-01, 0.20118000E+00, -.13629800E+00, -.37520400E+00, 0.60092000E-01, -.39861700E+01, -.28894400E+00, -.24117700E+00, 0.30573900E+00, 0.32314800E-01, 0.28301700E+00, 0.17742800E+01, -.68014000E+00, 0.19106400E+01, -.77919600E+00, -.93337900E+00, 0.31338800E+00, 0.48141200E+00, 0.26907400E+00, -.72706300E+00, 0.17146300E-01, 0.25332500E-01, 0.66214300E+00, -.27270800E+00, 0.19248200E+01, -.48030300E+00, 0.89283200E-02, -.24795000E+00, 0.20471400E+00, -.11237600E+01, -.67041700E+00, -.29675900E+00, 0.52383600E-01, -.71305200E+00, 0.10014000E+01, -.11038400E+01, -.74464200E+00, -.89394200E-02, -.33227500E+00, 0.11401100E-01, -.64922000E+00, 0.82906400E-01, -.74846800E+00, 0.13868300E+00, 0.12651900E+01, 0.61976200E+00, 0.44589600E+00, -.53714200E+00, -.21571200E+00, -.58530700E+00, 0.34819400E+00, -.84918400E-02, -.15625200E-01, 0.28443900E+00, 0.19889400E+00, -.16973300E-01, 0.89183900E+00, 0.46593400E+00, -.56515900E+00, 0.73209500E+00, -.62526400E+00, 0.88486300E+00, 0.72078100E-01, -.46852200E+01, -.96645600E+00, 0.17516300E+01, 0.10267300E+00, -.32914000E+01, 0.12644300E+01, -.18596300E+00, -.26679100E+00, -.15660900E+00, -.75876900E-01, -.29910400E+00, 0.27697000E+00, 0.15073400E+00, -.52470700E-01, -.10208500E+00, 0.11722100E+01, -.15653900E+00, -.75917300E-01, -.30127300E+00, 0.28157000E+00, 0.15112500E+00, -.53909600E-01, -.10608300E+00, 0.11949300E+01, -.11340700E+00, -.75645700E-01, -.82444600E+00, 0.54105900E-01, -.15960000E+00, -.11981500E+00, -.73679200E+01, -.16948200E+01, 0.70977300E+01, -.10323000E+02, -.32453300E+01, -.60637200E+00, 0.85042200E+01, 0.53679700E+01, -.20698100E+01, 0.42530400E+01, -.15214200E+01, -.14345500E+01, -.32837800E+00, 0.50729300E+00, 0.43900600E+00, -.83130500E+00, 0.40404900E+01, 0.59767700E+00, -.77411400E+02, 0.42649700E+02, 0.33963800E+02, 0.38516400E+02, -.15876700E+02, -.28292300E+02, 0.10219400E+02, 0.39064400E+02, 0.66442300E+00, 0.67984900E+00, 0.11806300E+00, -.24940100E+00, -.18191100E+00, 0.40087000E+00, -.23504000E+00, -.29863100E+00, -.13209700E+01, -.12942600E+01, -.26011100E+00, 0.46465000E+00, 0.37081700E+00, -.74796600E+00, 0.54367200E+00, 0.54776500E+00, -.10113900E+01, -.25820400E+00, -.12344900E+01, -.28350800E+01, -.22332200E+00, -.12180500E+01, 0.26823100E+00, 0.19769600E+00, -.36656500E+00, -.19788900E+00, 0.23078600E+00, 0.86293400E+00, 0.36466800E+00, 0.75000700E-01, 0.95541500E+00, 0.32547400E+00, -.21615000E+00, -.66481300E+00, -.13420100E+00, -.16366700E+00, -.10365500E+01, 0.42139700E+01, -.11896000E+01, -.31835600E+01, 0.24315600E+00, -.17122700E+00 }, { 0.95189300E+00, 0.32486800E+00, -.18187700E+01, -.11200000E+01, -.13057000E+01, -.49638400E+01, -.25135200E+01, 0.19410200E+01, -.13734100E+01, -.65401200E+00, 0.67003200E+00, -.10098500E+01, -.49650700E+00, -.43879300E+01, 0.38785800E+01, 0.40993800E+01, 0.33667300E+01, 0.56371600E+00, 0.48584600E-01, -.63112300E+00, -.18855200E+00, 0.57433200E+00, -.81930900E-01, -.15447300E-01, -.20452300E+00, -.17818500E+00, -.32229000E-01, 0.51877200E-01, 0.33461400E+00, 0.97218400E-01, -.19820000E+01, 0.29268700E+00, 0.14721700E+00, -.22320900E+00, -.67418900E+01, -.95891300E-01, -.84338400E-01, -.30008300E+00, -.12541700E+01, 0.17089000E+00, -.34767800E+00, -.56188800E+00, 0.13442100E+01, 0.30880800E+00, 0.41418600E+00, 0.68610000E+00, 0.15372600E+00, -.27610300E+01, -.10554100E+00, 0.13112800E+00, -.44022300E+00, -.10031700E-01, 0.12166600E+01, 0.15436800E+00, -.89950800E+00, 0.45055600E+00, 0.22832100E+00, 0.41541300E+00, 0.10809000E+01, 0.10064600E+01, 0.26388600E-01, 0.24723100E+00, -.88180600E-01, 0.17959700E-01, 0.45951800E-01, 0.70342600E-01, -.13653000E+00, -.18932700E+00, 0.37432200E+00, -.49773100E-01, 0.46484900E+00, 0.58897300E+00, 0.10038200E+00, -.29755000E+00, 0.22770000E+00, 0.15381600E+00, -.15835000E+00, 0.31466100E+00, 0.10018700E+01, 0.51140700E-01, 0.94491300E+00, -.17870600E+00, 0.71174600E+00, -.18331100E+00, -.19460000E+00, -.98966800E+00, 0.14198800E+00, 0.39663600E+00, 0.19182500E+00, 0.82704200E+00, -.54392700E+00, -.32408200E-01, -.24233100E+00, 0.13910300E+00, 0.47227600E+00, -.21883000E+00, 0.64986400E+00, 0.21360400E-01, 0.14975500E+00, 0.12694600E+01, 0.13941300E+00, 0.68053700E-01, 0.84446100E-01, -.14103300E+00, -.45849800E-01, -.74679000E-02, 0.22836700E+00, 0.46113200E+00, 0.27997400E-01, -.23485600E+00, 0.56296400E+00, 0.49479700E+00, 0.27708000E+00, 0.97334600E+00, -.31060100E+00, 0.88686800E-01, -.57933800E-01, 0.59801100E+00, 0.93468200E-01, 0.17798000E+00, 0.46574500E+00, 0.27444000E+00, -.80768800E-01, 0.60974600E-02, -.55192100E+00, -.29743200E-01, 0.41261300E+00, 0.62998300E-01, 0.12053400E+01, 0.35250000E+00, -.63929700E+00, 0.12398800E+00, 0.48396100E+01, 0.27271300E+00, -.17602900E-01, 0.61949000E-01, 0.31251900E-01, 0.22277600E-02, 0.75087900E-01, -.97216400E-01, -.15069400E+00, 0.16029000E-01, -.13368900E+00, -.38190400E+00, 0.31066800E-01, 0.26020200E-02, 0.75309900E-01, -.96791700E-01, -.14434300E+00, 0.15021200E-01, -.12991100E+00, -.38267700E+00, 0.49979300E-01, 0.65600300E-01, 0.17189000E+00, 0.26425600E-02, -.15579600E-01, 0.25804200E-01, -.31755500E+00, -.13063100E+01, -.24508100E+02, 0.87674100E+01, 0.12253500E+01, 0.46890900E+01, 0.52230000E+01, -.89924000E+01, -.96385500E+00, 0.61637500E+01, -.23052900E+00, -.97045800E-01, -.89230800E-01, 0.41957200E-01, -.65970300E-01, -.14468300E+00, -.33650300E+00, 0.10747500E+00, 0.76715700E+01, -.84090300E+01, -.11472900E+01, 0.43611100E+00, -.95664300E+00, 0.39142900E+01, 0.30096900E+01, 0.11737000E+01, 0.91990900E-01, 0.59594500E-01, 0.39273200E-01, -.21796600E-01, 0.37627100E-01, 0.54794500E-01, 0.13353800E+00, -.51891400E-01, -.18976900E+00, -.96130800E-01, -.74420900E-01, 0.48141800E-01, -.59526800E-01, -.13942000E+00, -.26247300E+00, 0.10475300E+00, -.17239100E+00, -.79157800E-01, -.19369200E+00, -.84481700E+00, -.87934100E-01, -.34246700E+00, -.21390000E+00, 0.97130400E-01, 0.12601800E+00, -.75993800E-01, 0.47063000E+00, -.14808600E+00, -.18218700E+00, -.54667500E+00, 0.57246600E-01, -.50435000E+00, -.33728600E+00, 0.38759400E+00, -.48184400E-01, -.49477800E-01, -.19359100E+00, 0.17041600E+01, -.36081900E+00, -.63157200E+00, 0.83011900E-01, -.11069800E+00 }, { 0.11501700E+01, 0.53514800E+00, -.21381800E+01, -.81820700E+00, -.10212700E+01, -.52751100E+01, -.17781600E+01, 0.23941400E+01, -.11221100E+00, 0.35099200E+00, -.73963200E-01, -.12183000E+01, 0.15827800E+00, -.30721800E+01, 0.97319400E+00, -.29651300E+00, 0.85918200E+00, 0.13256500E+01, 0.86147200E+00, 0.49464000E+00, -.90538000E+00, -.10551000E+00, -.12089900E+00, -.75867800E+00, -.61720700E-01, 0.27026700E+00, 0.13088800E+01, 0.39044500E+00, 0.16626900E+01, 0.24986100E+00, 0.73556600E+01, -.76213100E+00, -.23513200E+00, -.43946200E+00, 0.18721100E+01, -.60893200E+00, 0.60606300E+00, 0.16170100E+00, 0.26389200E+00, 0.13936700E+00, -.24897200E-01, 0.38222200E+00, -.63297700E+01, 0.54988800E+00, -.85401900E+00, 0.25404700E+01, -.77961900E+00, 0.10076600E+01, 0.16391800E-01, 0.42760600E-02, 0.31511100E+00, 0.23380900E+00, -.49440100E+00, -.20349100E+00, 0.42542100E+01, 0.75512300E-01, -.26400900E+00, 0.54508100E+00, 0.47286200E+00, -.31728000E+00, 0.16138300E-01, 0.16751600E-01, -.36293400E+00, -.11096400E+01, 0.27896800E+00, 0.21503100E-01, -.37139400E-01, 0.65331400E+00, 0.19477400E-01, -.11678000E-01, 0.52659000E+00, -.10215600E-01, 0.41957500E+00, -.68660600E-02, 0.34146600E+00, -.50666500E-01, -.51168100E-02, 0.96635100E-02, -.11823400E+00, 0.16612300E+01, 0.12954900E+01, -.27644200E+00, -.17773800E+00, -.41736400E+00, 0.37234400E+00, -.56182800E+00, 0.88777700E-01, -.13092300E+00, -.13433400E+00, 0.45198100E+00, -.52650000E+00, -.19691600E-02, 0.88159500E-01, -.75808000E+00, -.24483400E+01, 0.52413300E+00, -.16055600E+00, -.13932100E+00, -.22710600E+00, 0.16068700E+01, -.99776700E-01, 0.94387000E+00, -.24262400E+00, 0.10287700E+00, 0.19484100E-01, -.23119300E+00, 0.83460400E+00, -.18450500E+00, 0.43656000E+00, 0.22744800E+00, 0.79237300E-01, 0.16134600E+00, 0.34928200E+00, 0.29118600E+00, 0.16417900E+00, -.60758000E-01, 0.13349400E+00, 0.64366100E-01, 0.19506500E+00, 0.20848900E+00, 0.51430000E-01, -.14580400E+00, -.28678300E-01, 0.68512900E-01, 0.18867800E+00, 0.23034200E+00, -.18191900E+00, 0.95718700E-01, -.46542000E-01, 0.75581600E-01, -.84987800E+00, 0.25642900E-01, -.45598800E+01, -.61165300E+00, 0.13942400E+00, 0.28705900E+00, 0.57232900E-01, 0.14281200E-01, 0.32873100E-01, -.14363000E+00, 0.66822200E-01, 0.22190800E-01, 0.26842700E+00, -.55233700E+00, 0.57097500E-01, 0.13944200E-01, 0.36207200E-01, -.14145500E+00, 0.64612800E-01, 0.22520300E-01, 0.25967700E+00, -.54774600E+00, 0.79422700E-01, 0.69734700E-01, 0.92291400E-01, -.49203800E-01, 0.13621900E+00, -.15047600E-01, -.66824800E-01, -.97810200E+00, -.22756200E+02, 0.10569900E+02, 0.16183800E+01, 0.46585300E+01, 0.24632700E+01, -.86645200E+01, 0.30058300E+00, 0.60067600E+01, 0.19318600E+00, 0.19637100E+00, -.12926600E+00, -.66320700E-01, -.10857900E-01, -.20249700E+00, -.14481200E+00, -.79312500E-01, 0.16256400E+02, -.13394500E+02, -.62602000E+00, 0.21075800E+00, -.40715400E+01, 0.53162300E+01, 0.25002200E+01, 0.15827300E+01, -.92382200E-01, -.77514800E-01, 0.64168200E-01, 0.29324900E-01, -.94383600E-04, 0.79611900E-01, 0.26059300E-01, 0.34385900E-01, 0.17592600E+00, 0.16514700E+00, -.10883700E+00, -.48740800E-01, -.12479700E-01, -.18653500E+00, -.81346800E-01, -.59977900E-01, 0.13108100E+00, 0.43575400E-01, 0.10801800E+00, -.94843000E+00, 0.41911900E-01, -.18924700E+00, -.10249800E+00, -.39798100E-01, -.25164200E-02, 0.38022300E-01, 0.24716700E+00, -.53842700E+00, -.22001600E+00, -.47557900E+00, -.23659400E+00, -.45662800E+00, -.19286200E+00, 0.34625400E+00, 0.24565900E-01, 0.28335900E-01, 0.36921500E-01, 0.18505800E+01, 0.49114900E-01, -.75021700E+00, -.42952900E-01, 0.40430400E-01 }, { -.13073900E+01, -.51202000E+00, 0.20913000E+01, 0.60024700E+00, 0.77183200E+00, 0.43249900E+01, 0.44720300E+01, 0.18616200E+00, 0.26427000E+00, -.85095100E+00, 0.16434200E+00, 0.74526400E+00, -.78565600E+00, 0.40923900E+01, 0.26732200E+00, -.91484900E+00, -.11155000E+01, -.49827100E+00, 0.11049700E+01, -.25830600E+00, 0.24727400E+00, -.74503300E-01, 0.17658900E+01, -.96855300E+00, -.48454400E-01, -.33915600E+00, -.10076000E+00, -.21619900E-02, 0.13982600E+01, -.40387300E+00, -.18280500E+00, 0.73146600E+00, -.11961900E+01, 0.23902900E+00, -.50306600E+01, 0.10758000E+01, -.79085600E-01, 0.17642100E+00, -.28080500E+00, 0.98577500E-02, 0.12032600E+00, 0.88643500E-01, -.13526600E+00, -.17758700E-01, -.13390500E+00, 0.22673300E+00, -.89195500E-01, -.10641500E+00, 0.52148400E-02, 0.21958900E-02, -.21568900E+00, -.71747900E-01, 0.17483500E+00, 0.58357600E-01, 0.90222000E+00, -.10276200E-01, 0.37434800E-01, 0.14972600E+01, 0.10573800E+00, 0.94501800E-01, -.40781100E+00, -.73338300E-01, 0.14849100E-01, -.10343800E+00, -.59752600E-01, 0.85246200E-02, -.44500300E-01, 0.12833600E+00, 0.17230400E-01, -.58291900E-02, 0.13872900E+01, -.99560600E-01, -.38442300E-01, -.74674200E-01, 0.14671800E+00, 0.30748100E+00, 0.13861800E+00, -.12802200E+00, 0.25940000E+00, -.47726300E+00, 0.74550600E+00, 0.44642600E-01, 0.44357100E+00, 0.67537300E-01, -.39031000E+00, 0.67255500E-01, 0.82648700E-01, -.76018900E-01, 0.22456400E-01, 0.46069900E+01, -.13017900E+01, 0.77746500E-01, -.31526100E+00, 0.22708200E+00, 0.26461800E+01, -.97117500E+00, -.51102000E+00, 0.10648300E+00, 0.68934000E-01, 0.11935300E+01, -.97843900E+00, -.15023500E+00, -.29116000E+00, -.60986900E-01, 0.10206200E-01, -.72542100E-02, 0.28720300E+00, 0.70798400E-01, 0.55437600E+00, -.27770000E+00, 0.54333500E+00, -.36047300E+00, -.91188400E+00, 0.51816000E-01, -.66758700E+00, 0.85117800E+00, -.10313100E+00, 0.22352500E+00, -.12220400E+00, -.32026500E+00, 0.41529900E+00, -.48662500E+00, 0.17233100E-01, -.13416000E+00, 0.66140900E-01, -.91836900E-01, 0.43156200E+00, -.18316900E+00, 0.28155300E+01, -.45703600E+00, -.90932600E-01, -.20778600E+00, 0.76494200E+01, 0.13993500E+01, 0.71129400E+00, 0.48118100E-01, 0.67239900E-01, -.49151200E-01, 0.14781900E-01, -.83246800E-01, -.48648800E+00, 0.30437600E-01, -.12340900E+01, -.23553200E+00, 0.65636100E-01, -.46699400E-01, 0.19105800E-01, -.83020200E-01, -.46928400E+00, 0.28137100E-01, -.12121600E+01, -.23836800E+00, 0.12469400E+00, 0.16791100E+00, 0.64304400E+00, -.28994200E+00, -.19129400E+00, -.17490200E+00, 0.83525200E-01, 0.27128400E+00, 0.35946200E+00, -.16101100E+02, 0.16939200E+01, 0.17083300E+01, 0.11042600E+01, -.55944400E-01, -.61469100E+01, 0.89123100E+00, 0.31416000E+00, 0.86441000E-01, -.24467900E+00, -.24677800E-01, -.53705700E+00, 0.66959800E+00, -.63801000E+01, 0.21354400E+00, -.90866100E+01, 0.15685300E+02, -.50738900E+01, -.35495900E+01, 0.83433600E+01, -.12629300E+01, -.13802000E+02, -.68103400E+01, -.17079200E+00, -.30075300E-01, 0.11534800E+00, 0.21308000E-01, 0.26757600E+00, -.31138100E+00, 0.92974400E+00, -.88693100E-01, 0.30645400E+00, 0.63737000E-01, -.21766800E+00, -.16910200E-01, -.47328900E+00, 0.58751900E+00, -.18038000E+01, 0.19040400E+00, 0.23767000E+00, -.30950500E+00, 0.79158400E+00, -.16692900E+01, -.38977700E+00, -.10829800E+01, -.99439400E+00, 0.46612300E+00, 0.10336400E+01, -.33453400E+00, 0.15189400E+01, -.52011400E+00, -.10194300E+01, -.77345300E+00, -.74799900E+00, -.20041700E+01, -.73120300E+00, 0.12951300E+01, -.19932900E+00, -.19010900E+00, -.16581000E+01, 0.10313400E+01, -.26376400E+00, 0.72893300E+00, 0.34571800E+00, -.59154900E+00 }, { -.14553500E+01, -.59516800E+00, 0.25245200E+01, 0.63770500E+00, 0.14561900E+00, 0.48636000E+01, 0.47481100E+01, -.63946000E-01, 0.39475500E+00, -.54801700E+00, -.22910200E-01, 0.23310200E+00, -.10972100E+01, 0.49467500E+01, -.36416800E+00, -.36721600E+01, -.22692600E+01, 0.98089800E-01, 0.69719300E+00, 0.20966300E+00, -.66219500E+00, -.78945000E-01, 0.12251400E+01, 0.75306200E+00, -.95383900E-01, 0.40292200E+00, 0.27428300E+00, 0.63821200E-01, 0.33801500E+01, 0.17460000E+00, 0.61090500E+01, -.46283600E+00, -.14652400E+01, -.20329700E+00, -.23182900E+01, 0.50964900E+00, 0.27193600E+00, 0.63898600E+00, 0.88614100E-01, -.13865500E+00, 0.61177500E+00, 0.44496400E+00, -.24045700E+01, 0.68845300E+00, -.25248700E+00, -.13217900E+01, 0.40282000E+00, 0.12243900E+01, -.43295900E-01, -.32352500E-02, 0.12923300E+00, 0.13780900E+00, -.28876500E+00, -.10481300E+00, 0.55098000E+01, 0.21655500E+00, 0.34645300E-01, -.81419300E+00, 0.19672900E+00, 0.51598100E+00, -.21318900E+01, -.54609900E-01, 0.96933200E+00, 0.18505100E+01, -.96033300E+00, -.12000500E+00, 0.21671900E+00, -.68885200E+00, -.67192700E+00, 0.64496300E-01, -.18333300E+01, -.74361900E+00, -.43404000E+00, 0.31859400E+00, -.12220500E+00, 0.32993100E+00, 0.70245000E+00, -.41053200E+00, 0.11837500E+01, -.10224600E+01, -.22764400E+00, 0.13668000E+00, 0.77149300E+00, 0.14682900E+00, -.50706600E+00, 0.11462800E+00, -.79170100E-01, 0.33939100E+00, -.21093900E+00, 0.11530500E+01, -.51047700E+00, 0.11981100E+00, -.42420300E+00, -.11028300E+00, 0.35102000E+01, -.97401300E+00, -.75758400E+00, 0.92976100E-01, 0.10752400E+00, 0.12953500E+01, -.11031700E+01, -.86823500E+00, -.17289100E+00, -.48099300E+00, -.34722700E-01, -.60906600E+00, -.38765400E+00, -.23113900E+00, -.57298300E+00, 0.10190300E+01, -.10739900E+00, 0.23531000E-01, -.89727700E+00, -.66373100E+00, -.37572500E+00, 0.25687700E+00, 0.13423600E-01, -.45700400E+00, 0.45673300E+00, 0.10871500E-01, -.25942900E+00, 0.67835200E+00, 0.21985300E+00, -.29327000E+00, 0.74683000E+00, -.53069900E+00, 0.37387500E+00, -.15563600E+00, 0.87682100E+00, -.42194400E+00, 0.14257200E+00, 0.18378800E+00, 0.12254600E+02, 0.14859600E+01, -.16305400E+00, 0.28951000E+00, -.64791400E-01, -.11500700E+00, 0.10633300E+00, 0.33102300E+00, -.53774000E+00, -.18081400E+00, -.93675400E+00, 0.84497200E+00, -.65015000E-01, -.11196300E+00, 0.10138100E+00, 0.32812900E+00, -.52187200E+00, -.17872900E+00, -.90619900E+00, 0.83539800E+00, -.19363200E+00, 0.10448100E+00, 0.36102800E+00, 0.33376400E-01, -.44856200E+00, -.18972300E+00, -.10536800E+00, 0.81306900E+00, 0.36331300E+00, -.40324500E-01, 0.31419000E+01, -.13547700E+01, 0.36976300E+01, 0.37489400E+00, -.32766700E+01, -.29537900E+01, -.88410300E+00, -.58559600E+00, 0.20939400E+00, 0.53974500E+00, -.23070200E+00, -.14861400E-01, -.15823300E-01, 0.63796300E+00, -.50368700E+01, 0.10899100E+02, 0.28900900E+01, 0.66164800E+00, -.27895000E+00, 0.21525800E+01, 0.20354200E+01, -.97036300E+00, 0.37611100E+00, 0.26059900E+00, -.11239900E+00, -.25544600E+00, 0.13420700E+00, 0.28439100E-01, 0.28577500E+00, -.30067200E+00, -.77520900E+00, -.51689500E+00, 0.18946700E+00, 0.46732600E+00, -.20062000E+00, -.22801800E-01, -.47717200E+00, 0.55268000E+00, -.57009300E+00, -.34451800E+00, 0.14809100E+01, -.84535400E-01, -.37025300E+00, -.46552000E+00, -.29291500E+00, 0.39216400E+00, 0.33636200E+00, -.32719700E+00, 0.45419100E+00, 0.13107800E+01, 0.27961300E+00, 0.27145800E+00, -.13740300E+01, -.32186100E-01, -.24086600E+00, -.18459400E+00, -.20827000E+00, -.21960200E+00, -.64256700E+00, -.14255600E+01, -.15761900E+01, -.19658600E+00, 0.35700800E+00, -.42271300E+00 }, { -.14093800E+01, -.62101400E+00, 0.23785700E+01, 0.99811000E+00, 0.83396900E+00, 0.51814400E+01, 0.36115500E+01, -.25644000E+01, 0.31160700E+00, -.79490400E+00, 0.85166100E-01, 0.73108000E+00, -.13825700E+01, 0.68701700E+01, -.10264900E+01, -.31906700E+01, -.27109600E+01, -.93556200E+00, 0.15659800E+00, 0.33644100E+00, 0.29123900E+00, -.25858000E+00, -.65920100E-01, 0.59762000E+00, -.11499700E+00, 0.13361300E+00, -.46252100E+00, -.17380700E+00, 0.46753100E-01, 0.14949200E+00, -.13932200E+01, 0.18341100E+00, -.10810900E+00, -.28830000E+00, -.70672600E+01, 0.20236200E+00, -.50831000E+00, -.95471300E+00, -.30709000E+00, -.47997800E+00, -.32503500E+00, -.67959300E+00, 0.27560800E+01, 0.55054900E+00, 0.12692700E+01, -.26617700E+01, 0.11789300E+01, -.37463300E+01, -.75148900E-01, 0.10914300E+00, -.36693500E+00, -.20311000E+00, 0.94348600E+00, 0.18663700E+00, -.25536300E+01, 0.20265300E+00, 0.26504300E+00, -.50895300E+00, 0.30041800E+00, 0.33466100E+00, -.44520200E+00, -.83490700E-01, 0.91456500E-01, -.39130800E+00, -.31466000E+00, 0.73505100E-02, -.83315600E-01, 0.18690500E+00, 0.23571300E+00, 0.17704200E-01, -.86266100E+00, 0.22761300E+00, 0.36877200E+00, -.45870500E+00, -.14416800E+00, -.33518800E+00, -.15929200E+01, 0.10282500E+01, 0.32984900E+00, 0.75308300E+00, 0.27673400E+00, -.32987100E+00, -.14076900E+01, 0.63733000E-01, 0.41638800E+00, 0.49176700E+00, -.18412500E+00, -.34888200E+00, -.12064900E+00, 0.97248900E+00, 0.46968400E-01, -.16517700E-02, -.35276300E-01, -.12310300E+00, -.26933600E+00, 0.69027000E+00, 0.36948800E+00, -.46358900E-02, 0.93375200E-01, -.66394200E+00, 0.18537800E+00, 0.56173800E-01, 0.11860300E+00, 0.10366900E+00, -.92804700E-01, -.29279000E+00, -.32207300E+00, -.61512800E-01, 0.67057300E+00, -.16244800E+00, -.10163700E-02, -.13467900E-01, 0.14354900E+00, 0.13384800E+00, 0.17897500E+00, -.48085400E-01, 0.26981800E+00, -.69536400E-01, 0.42929300E+00, 0.21757200E+00, -.16737100E+00, -.17714700E+00, -.14560300E+00, 0.29613400E+00, 0.27040400E+00, 0.22172700E+00, -.76841400E+00, 0.20234200E+00, -.10033400E+01, 0.31081400E+00, -.18217400E+01, 0.47550700E-01, -.22487300E+00, -.83737200E+00, -.63120500E-01, 0.34819200E+00, 0.10960300E+00, 0.44575100E-01, -.69767200E-02, -.13314900E+00, -.19817900E+00, 0.16848400E-01, 0.14658400E+00, -.75666800E+00, 0.10942500E+00, 0.44719900E-01, -.29811200E-03, -.13090200E+00, -.19615600E+00, 0.16324900E-01, 0.14186200E+00, -.75439500E+00, 0.82819900E-01, 0.12320500E+00, 0.55533500E+00, -.87565100E+00, 0.11357600E+00, 0.89886700E-01, -.33400200E+00, -.45309100E+00, -.42409900E+00, -.30241700E+00, 0.68752700E+00, 0.31171300E+01, -.70530700E+01, 0.19122300E+00, 0.47072500E+01, 0.45488700E+01, 0.13841400E+01, 0.70020200E+00, -.22798000E+00, -.46838500E+00, 0.45665000E-01, -.28310000E+00, 0.12514600E-01, -.72836200E+00, 0.30246700E+02, -.27038800E+02, -.37286500E+00, 0.10783400E+01, -.10627600E+02, 0.19939200E+01, -.88915300E+01, 0.32474100E+01, -.59571800E+00, -.31444800E+00, 0.13541000E+00, 0.22467300E+00, -.69283100E-01, 0.10344700E+00, -.25819800E+00, 0.33975600E+00, 0.12112600E+01, 0.61669500E+00, -.19455100E+00, -.39764600E+00, 0.33647900E-01, -.24465000E+00, 0.37752400E+00, -.62305000E+00, 0.91449700E+00, 0.39228900E+00, -.68352300E+00, -.20544100E+01, 0.42369900E+00, 0.26097100E+00, 0.23866000E+00, -.45020400E+00, -.42103200E+00, 0.37407200E+00, -.64168300E+00, -.23040000E+01, -.62610800E+00, -.50758200E+00, 0.42994600E+00, -.64321300E+00, 0.73284600E-02, 0.37174500E+00, 0.24191800E+00, 0.25132900E+00, 0.61304800E+00, 0.38132900E+01, 0.14100600E+01, -.72207600E+00, -.40781200E+00, 0.49352400E+00 }, { 0.14625200E+01, 0.18383900E+01, -.97546100E+00, 0.79833300E-01, -.60053000E+00, -.12210500E+01, 0.53527200E-01, 0.19200400E+01, -.18494600E+00, -.68911500E+00, 0.19387300E+00, 0.36199400E+00, 0.69706800E-01, -.79186300E+00, 0.11752500E+01, 0.24661400E+01, 0.26287800E+01, 0.10898500E+01, 0.41775100E+00, -.46895200E+00, -.71845800E+00, 0.43356400E+00, 0.10370600E+01, -.99666900E+00, 0.25077400E+00, -.48928000E+00, 0.64710000E+00, 0.36279100E+00, -.64651800E+00, -.38942300E+00, -.20426700E+01, 0.15421100E+00, 0.99273200E-01, 0.64794400E+00, 0.64897500E+00, -.85356000E-02, -.11052900E+00, -.17746300E-01, 0.68286600E+00, 0.15705500E+00, 0.15532800E+00, -.12781700E+01, 0.29618600E+01, -.31158400E+00, 0.51862500E+00, 0.58790700E-01, -.16434600E+00, 0.14022900E+00, 0.96643200E-03, -.11328400E+00, -.40824900E-01, 0.16136000E+00, -.11142900E+00, -.62260100E-01, -.22900600E+01, 0.13381100E+00, -.63430200E-02, -.88315600E+00, -.81428700E-01, 0.60789100E+00, 0.44641700E+00, 0.30011800E+00, 0.17167700E+00, 0.58415500E+00, -.15136200E+00, -.39558100E-01, -.50780600E-01, -.34061400E+00, -.10847200E+00, 0.39175100E-01, -.65364400E+00, -.37481100E-01, -.23230800E+00, -.47347000E-01, -.57546500E+00, 0.88968300E-01, 0.48346100E+00, -.20879100E+00, 0.21644400E+00, -.19429500E+00, -.10846900E+00, 0.10308600E+00, 0.47915100E+00, 0.77114300E-01, -.12377400E+00, 0.55797700E+00, -.15362700E+00, -.33334500E+00, 0.21253200E-01, -.25348900E+01, 0.27008400E+00, 0.13816300E+00, -.59311600E-01, 0.14480100E+00, 0.43505400E+01, -.10365000E+01, -.69371200E+00, -.97423200E-01, 0.56472300E+00, 0.22971200E+01, -.30253000E+00, 0.34553800E+00, -.10185900E+00, -.23880900E+00, -.61833000E-01, 0.13677400E+00, -.27716200E-01, 0.81834800E+00, 0.81224700E-01, -.11642900E+01, -.50831300E+00, -.78218300E+00, -.65313600E+00, -.78308300E+00, 0.61072300E+00, 0.58056500E-01, -.46692400E+00, 0.31294300E+00, 0.39244200E+00, 0.12319300E+00, -.13975100E+00, 0.13953000E+00, 0.20134800E+00, -.22674600E+00, 0.21289300E-01, -.42992400E-01, 0.38464200E+00, -.21116500E+00, 0.22139800E+00, 0.21499600E+00, 0.38358300E+00, 0.95783700E-01, 0.99294200E+01, -.42618200E+00, 0.35096700E+00, -.60334100E-01, 0.22005000E-01, -.13634600E+00, 0.15733200E+00, 0.12537000E+00, -.65736800E+00, 0.15133100E+00, -.26481700E+01, 0.69876100E+00, 0.20222000E-01, -.13178300E+00, 0.15251000E+00, 0.12682000E+00, -.64441100E+00, 0.14674900E+00, -.26146200E+01, 0.69764000E+00, -.31878100E-01, 0.15642000E+00, 0.10643100E+01, -.15980400E+01, -.35550100E-01, 0.11926000E+00, 0.18679600E+00, -.91439000E+00, 0.62866100E+00, -.56374500E+00, -.25692500E+00, -.56880100E+00, -.45711700E+01, -.11661400E+01, -.34126500E+01, -.36534400E+01, 0.11138200E+01, -.10735800E+01, 0.59560500E+00, -.13336100E+00, -.42083700E+00, 0.10671700E+01, -.78473900E+01, -.62072300E-01, 0.98762600E+02, -.67591900E+02, -.36487300E+02, -.37951700E+02, 0.10015300E+02, 0.35652800E+02, -.18852900E+02, -.38823600E+02, -.51720400E+00, 0.39445800E+00, -.21755300E+00, 0.86036900E-01, 0.21199800E+00, -.51994400E+00, 0.10383000E+01, 0.59168700E-01, 0.10015500E+01, -.91730100E+00, 0.48895800E+00, -.12577600E+00, -.36586000E+00, 0.94372100E+00, -.20870400E+01, -.67977600E-01, 0.72568900E+00, -.28953600E+00, 0.11856000E+01, 0.13211100E+01, -.32998700E+00, 0.56018500E+00, 0.44081700E+00, 0.37685200E+00, -.48026300E+00, -.28267600E+00, 0.14170300E+01, -.13111700E+01, -.18188800E+01, -.10130800E+01, -.11548400E+01, -.37048400E+01, -.54103400E-01, 0.25163100E+01, -.14924300E+00, -.16902200E+00, -.76035900E+00, -.31860200E+01, -.12306600E+01, 0.15911100E+01, 0.30695000E+00, -.48065500E+00 }, { 0.84136700E+00, 0.17907200E+00, -.13658400E+01, -.10324800E+01, -.10226900E+01, -.34362500E+01, -.49138500E+01, -.24246700E-01, -.35355700E-01, 0.22968500E+00, -.13712100E+00, -.61204100E+00, 0.38766300E+00, -.25010100E+01, 0.41107900E+00, -.10987000E+00, -.47748400E-01, 0.37988500E+00, 0.40109700E+00, -.60972000E-02, -.52184700E-01, -.21659100E+00, -.97971500E-01, -.45971800E+00, -.61151800E-01, -.31640400E+00, -.45346000E+00, -.17097200E+00, -.75991700E+00, -.61306300E+00, -.55579200E+01, 0.43560300E+00, 0.74120700E+00, 0.26283400E+00, 0.47637500E+01, -.19001500E+00, -.48763400E-01, -.12022600E+01, -.99283600E-01, 0.58545900E-01, -.69630200E+00, -.42776700E+00, 0.36813000E+00, 0.23953600E+00, 0.24787300E+00, 0.66354900E+00, 0.43157500E-01, -.26231200E+01, -.59784400E-01, 0.60599300E-01, 0.74983000E-01, 0.40967200E-01, 0.39188200E+00, -.50544300E-01, -.61373400E+01, 0.29678200E+00, 0.85907300E-01, -.22831500E+01, 0.13875100E+00, 0.11345800E+01, 0.74690500E-01, 0.29502900E+00, -.85975600E-01, -.82628200E+00, -.19361100E+00, 0.73971800E-01, -.44383900E-01, 0.38399600E+00, 0.30784500E+00, -.33913300E-01, -.13941000E+01, 0.42226500E+00, 0.56704100E-01, -.13568700E+00, -.49392300E-01, 0.37403200E-01, 0.10966400E+01, -.20284300E+00, 0.62783600E+00, 0.57553000E+00, -.82672600E+00, 0.29190400E+00, 0.25833800E+00, 0.26590400E-02, -.25739700E+00, -.35383000E+00, 0.58745100E-01, 0.29680500E+00, 0.68769600E-01, -.21584300E+00, -.32947400E+00, -.13272800E+00, -.25793600E+00, 0.17339900E+00, 0.11651000E+01, -.57399100E+00, 0.61356800E+00, 0.79570600E-01, 0.55705100E+00, 0.89324700E+00, 0.30754500E-02, -.78271300E+00, -.13415800E+00, -.16290300E+00, -.11429700E+00, 0.35033900E+00, -.14784500E+00, -.27429200E-01, -.51951200E+00, -.19139500E+00, 0.28110000E+00, 0.20289800E-01, 0.42423400E+00, -.76472400E+00, -.12154200E+00, 0.18747300E+00, -.51086200E-02, -.22036400E-01, -.28515300E+00, -.13808800E+00, 0.11909300E+00, -.29761500E+00, -.19581200E+00, -.17011200E+00, 0.45573500E+00, 0.86610700E-01, 0.62817100E-01, -.88403900E-01, -.14180300E+00, -.26713000E+00, 0.57922000E+00, -.10410200E+00, 0.31888300E+01, -.36182500E+00, 0.10612500E+00, -.25616700E+00, -.14329200E-01, 0.11994000E+00, -.19088800E+00, 0.68185100E-01, -.72504300E+00, 0.77166800E-01, -.94521700E+00, 0.32694600E+00, -.14138600E-01, 0.12059100E+00, -.18813400E+00, 0.70416800E-01, -.70991500E+00, 0.72154600E-01, -.92408500E+00, 0.33448900E+00, 0.10475100E+00, 0.16250400E-01, 0.37939500E+00, -.10956900E+01, -.10918200E+00, -.43835200E-01, -.21325600E-02, 0.85849000E-01, -.20973600E+00, 0.19032500E+00, -.45954600E+00, 0.20073900E+00, 0.56113000E-01, -.36999700E+01, -.96526300E+01, -.84615400E+00, -.89809800E+00, 0.33098200E+00, -.27316700E-01, 0.41643400E+00, -.55748800E+00, -.20876800E+00, -.64192600E+00, 0.45763300E+00, 0.40474200E+02, -.21448600E+02, -.13326800E+00, -.23046700E+01, -.12412200E+02, 0.16013800E+02, 0.41854700E+00, -.26074700E+01, 0.39337100E+00, -.14545600E+00, 0.59440500E-02, -.19084700E+00, 0.25277700E+00, 0.90765100E-01, 0.30463800E+00, -.21091100E+00, -.76477400E+00, 0.26059600E+00, -.12322800E-01, 0.37263800E+00, -.49234600E+00, -.19448500E+00, -.61094900E+00, 0.40640000E+00, -.68003100E+00, -.18951600E+00, 0.64176100E+00, -.17017700E+01, -.23335700E+00, -.63689700E+00, -.86759000E+00, 0.26684400E+00, 0.90252700E+00, -.20181000E+00, 0.94142300E+00, -.21667800E+00, 0.37884700E+00, 0.28806400E-01, -.59493400E+00, -.53236700E+00, -.64078100E+00, 0.74671100E+00, -.13155700E+00, -.11906400E+00, -.89051800E+00, -.66542100E+00, -.99470400E+00, -.13572000E+01, 0.20938400E+00, -.29766800E+00 }, { 0.21859700E+01, 0.80784600E+00, -.20490700E+01, -.14976700E+01, -.13524500E+01, -.37493900E+00, 0.10062600E+02, 0.35377400E+01, -.12541200E+00, 0.91458700E+00, -.10869400E+00, -.21036400E+01, -.50989600E+00, -.54435800E+01, 0.18492800E+01, 0.14323500E+01, -.53736700E+00, 0.46041500E+01, 0.20486000E+01, 0.56570100E+00, -.24835500E+01, -.52904100E+00, -.10928400E+01, -.88712600E+00, -.23818500E+00, 0.10107200E-01, -.13277200E-01, -.21365500E+00, -.21476400E+01, 0.12585900E+00, -.10415200E+01, -.12106100E+00, 0.10237100E+01, -.53470500E+00, 0.93408100E+00, -.83856900E+00, 0.11715900E+00, -.12492000E+01, -.14045100E+01, -.20405000E+00, -.95831100E+00, 0.35089200E+00, 0.13481200E+01, -.12252700E+01, -.14706200E+00, 0.19158200E+01, -.36755000E+00, -.46787700E+01, 0.10510800E+00, -.99241600E-01, 0.12975900E+00, -.50034500E+00, -.54602300E+00, 0.22549300E+00, -.10522800E+02, -.81285900E+00, 0.11162300E+00, -.12548900E+01, -.18205500E+01, -.64839100E+00, -.52494900E+00, -.32868400E-01, -.24558900E+00, -.23739600E+01, -.28762200E+00, 0.18790800E+00, -.22209600E-01, 0.10210200E+01, 0.79431000E+00, 0.54295800E-01, -.29319000E+01, 0.94429500E+00, 0.90272600E+00, -.20816000E+00, -.13688700E+00, -.27132700E+00, 0.20102700E+00, 0.96842300E-02, -.14017400E+00, 0.31710700E+01, 0.21329900E+00, 0.33861700E+00, 0.94642400E-01, -.14703800E+00, -.51968300E+00, 0.56909200E+00, -.29871200E-01, -.56061000E+00, -.54294400E-01, 0.28767000E+01, -.13556700E+01, -.80570800E-01, -.26225900E+00, 0.48470400E+00, -.65290900E+00, -.36747100E+00, 0.20662800E+01, 0.19563500E+00, 0.20349500E+00, 0.27723800E+00, 0.29713700E+00, 0.59744400E+00, 0.34432500E+00, -.34430200E-01, -.92021800E-01, 0.24817700E+00, 0.27182900E+00, 0.52838900E+00, -.14416300E+01, 0.29106600E+00, -.17784500E+01, -.90898000E+00, 0.83885500E+00, -.13086600E+01, 0.51830800E+00, -.63397700E-01, 0.64933300E-01, -.70299000E+00, -.11882200E+00, -.39081200E+00, -.57528300E+00, -.58916400E+00, 0.20760300E+00, -.39642800E+00, 0.14877500E+01, 0.14346500E+00, -.13035700E+01, -.52009000E-01, -.14829200E+01, -.25168600E+00, 0.64441300E+00, -.52117100E-01, -.10674800E+02, -.11012000E+01, 0.43073300E+00, 0.53525900E+00, -.47397800E-02, -.26218600E-01, 0.15301800E+00, -.70461300E-01, 0.14799500E+00, 0.53966900E-01, -.60965300E-01, -.21668700E+00, -.46836600E-02, -.26230400E-01, 0.14939000E+00, -.71429000E-01, 0.14882500E+00, 0.54600000E-01, -.56844300E-01, -.21996800E+00, 0.77899700E-01, 0.27346700E-02, -.31870200E+00, 0.63867500E+00, 0.18311700E+00, -.20613400E-01, -.34862900E+00, 0.73656000E+00, -.17496100E+00, 0.68740300E+00, -.80488100E+00, -.78404200E+00, -.13285200E+00, 0.19033400E+00, 0.98167200E+01, 0.40889500E+00, 0.17418000E-01, -.66588300E+00, 0.18098000E+00, 0.16331900E+00, 0.46504900E+00, -.59437300E+00, 0.38231300E+01, -.10445100E+00, -.21762400E+02, 0.12070300E+02, 0.14120700E+02, 0.14978200E+02, -.96685800E+01, -.13609400E+02, -.31003100E-02, 0.15831400E+02, 0.39409800E-02, 0.29547100E+00, -.78940200E-01, -.83111100E-01, -.21850600E+00, 0.27728600E+00, -.45466000E+00, 0.34820100E-01, -.38041100E-02, -.57229400E+00, 0.16511200E+00, 0.14501900E+00, 0.40456500E+00, -.52340000E+00, 0.90123500E+00, -.86264200E-01, 0.33345200E-01, 0.99276900E-01, 0.95408100E+00, -.56207200E+00, 0.16174400E+00, 0.23936100E+00, 0.99217800E+00, -.21536600E+00, -.12683600E+01, 0.13592200E+00, -.82298400E+00, 0.53052300E-01, 0.25439200E+00, 0.19373600E+00, -.10838600E+01, 0.88733200E+00, 0.44759800E+00, -.89874400E+00, 0.82893200E-01, 0.60381800E-01, 0.84226100E+00, 0.34444800E+01, -.50566200E+00, -.92332900E+00, -.12751700E+00, 0.29474600E+00 }, { -.10949000E+01, -.38899400E+00, 0.12910700E+01, 0.73238800E+00, 0.85867200E+00, 0.32323300E+01, 0.18940700E+01, -.12708000E+01, 0.23674200E+00, -.79494100E+00, -.23570500E-01, -.47633300E+00, -.14244400E+01, 0.49279500E+01, 0.22648500E+00, -.33255300E+01, -.84562100E+00, -.25669200E+01, -.85959000E+00, 0.36076500E+00, 0.15338300E+01, -.33492200E+00, -.13086200E+01, 0.98341600E+00, -.19736900E+00, 0.17383000E+00, -.50013200E+00, -.17469300E-01, 0.21273000E+01, 0.45705400E+00, 0.27302900E+01, -.41154600E+00, -.41742500E+00, -.53052800E+00, -.10126200E+02, 0.25485900E+00, 0.23619600E+00, 0.59655900E+00, -.31665300E+00, -.57391300E-01, 0.51533500E+00, 0.24251400E+00, 0.41398000E+00, 0.57154900E+00, 0.12403300E+00, -.15094500E+01, 0.47808300E+00, 0.55521800E+00, -.70947200E-01, 0.13313700E+00, -.17797700E+00, 0.13030100E+00, 0.57655900E+00, 0.39558300E-01, 0.10870100E+02, 0.32027900E+00, -.15820300E-01, 0.73482400E+00, 0.14515500E+01, 0.71331100E-01, 0.10400000E+01, 0.85043700E-01, -.36441800E+00, -.17101100E-01, 0.63066500E+00, -.18719600E-01, 0.67141900E-02, -.10166600E+00, -.97055400E-01, -.34577800E-01, -.17242200E+01, -.75356900E-02, 0.23635600E-01, 0.44475200E-01, 0.40948500E-01, -.16669700E+00, 0.27705000E+00, 0.19465900E-01, 0.17921800E+00, -.79083300E+00, -.81603600E+00, -.15360100E+00, -.10419800E+01, 0.31248200E+00, 0.13818400E+00, -.89089200E-01, -.27981200E+00, 0.27544800E+00, -.12712900E+00, 0.17282000E+01, -.63999200E+00, 0.10323400E+00, 0.56193400E-01, 0.77556200E-01, -.19302200E+01, -.27818400E+00, 0.79763300E-01, -.61220400E-01, -.33412700E+00, -.13119700E+01, -.46973500E-01, -.58542200E+00, 0.12420200E+00, -.17415300E+00, 0.79779800E-01, -.10302600E+00, -.75915500E-01, 0.86218700E-01, -.47422300E+00, -.10023900E+00, 0.30656300E+00, 0.47734200E-01, 0.36250900E+00, 0.34893400E+00, -.13319400E+00, -.96275600E-02, -.91766200E-02, 0.19642900E+00, -.12156500E+00, 0.54492700E-01, 0.20586200E+00, 0.39980300E+00, -.18704800E+00, 0.31454300E+00, -.89180600E+00, -.13329000E+00, 0.73809700E+00, -.20397900E-01, 0.24658200E+00, 0.25703500E+00, -.68687600E+00, 0.34130700E-01, 0.82965200E+01, 0.53366400E-01, -.42905400E+00, -.20600600E-01, 0.22751700E-02, 0.17611800E-01, -.21423900E-01, 0.25113400E-01, -.15281300E+00, -.32765400E-01, -.67234900E-01, 0.79890400E-01, 0.23060000E-02, 0.17814700E-01, -.21032800E-01, 0.24454600E-01, -.15275500E+00, -.32724700E-01, -.65120600E-01, 0.78021300E-01, -.95022300E-01, -.20273600E-01, 0.14377600E+00, -.51467400E-01, -.53016300E-01, 0.48301300E-01, -.21426800E+00, 0.96304200E-01, -.44717800E+00, -.31931100E+00, 0.28953400E+00, -.99069300E-01, 0.46190400E+00, 0.23895300E-01, 0.81830400E-01, 0.42928000E+01, -.62628100E-01, 0.91538600E+00, -.47122700E+00, -.15249400E+00, 0.49964200E-01, -.44327800E+00, 0.26604900E+01, -.15342800E+00, -.31007800E+02, 0.18357700E+02, 0.14531900E+02, 0.15690400E+02, -.69974700E+01, -.13073000E+02, 0.54776200E+01, 0.17009700E+02, 0.36996700E-01, -.36751300E+00, 0.20144200E+00, 0.65546400E-01, -.48576800E-01, 0.20341500E+00, -.43674000E+00, 0.62486100E-01, -.58349600E-01, 0.78722100E+00, -.39460500E+00, -.12174600E+00, 0.39438300E-01, -.39112900E+00, 0.83006700E+00, -.12047300E+00, -.45058300E-01, 0.22990100E+00, -.11296900E+01, -.17545000E+01, 0.23915200E+00, -.40211100E+00, -.47719200E+00, -.25208400E+00, 0.48961600E+00, 0.20988300E+00, -.47087200E+00, -.33845300E+00, 0.45612500E+00, 0.12975100E+00, 0.10319200E+01, 0.10683800E+01, -.29034700E+00, -.66284600E+00, 0.12209900E+00, 0.14127700E+00, 0.28450200E+00, 0.26132900E+01, 0.11587200E+01, -.10732600E+01, -.23409700E+00, 0.28729300E+00 }, { -.32454600E+01, -.10842700E+01, 0.27303800E+01, 0.13658600E+01, 0.98668500E+00, 0.71734300E+01, 0.64397500E+01, -.20432500E+01, 0.87531000E+00, -.12663100E+01, -.93804000E-01, 0.36229600E+00, -.20350500E+01, 0.10940600E+02, -.15527800E+01, -.76954300E+01, -.42590000E+01, -.32605800E+01, -.47736600E+00, 0.16934800E+01, -.30708500E+00, -.26913500E+00, 0.18748400E+00, 0.11781800E+01, -.90777500E-01, 0.37305600E+00, -.11880700E+01, -.40360100E+00, 0.21467700E+01, 0.23298000E+00, 0.44023100E+01, -.13308200E-01, -.14075900E+01, -.31799900E+00, -.65045600E+01, 0.97220300E+00, 0.10265400E-01, 0.44099100E+00, 0.43473700E+00, -.21594300E+00, 0.59639100E+00, 0.40744800E+00, 0.18113600E+01, 0.99707300E-01, 0.19948500E+00, -.33081600E+01, 0.61152000E+00, 0.29446400E+01, 0.63536500E-01, -.82795800E-01, 0.19009700E+00, 0.99926500E-01, -.74640200E+00, -.49675600E-01, 0.86162700E+01, -.24237300E+00, -.14929400E+00, 0.32408700E+00, -.45597200E+00, -.29555500E+00, 0.65589800E+00, -.16196700E+00, 0.11675100E+00, 0.17188800E+01, 0.48204600E+00, -.16248700E+00, 0.49271700E-01, -.68451100E+00, -.73835700E+00, 0.10578700E+00, -.17101100E+01, -.10334000E+01, -.46242600E+00, 0.47228100E+00, -.12565100E+00, 0.67724900E-01, -.94563800E-02, -.10843200E+00, -.29613800E+00, -.75958500E-01, -.52814000E+00, -.13421900E+00, -.28866800E-01, 0.45449300E-01, 0.22339500E+00, -.80381400E+00, -.17255500E+00, 0.65911800E+00, -.98131900E-01, 0.93737100E+00, 0.57305700E-01, -.86297500E-01, -.86154200E-01, -.24242700E+00, 0.42837100E+00, 0.25957200E+00, -.90408400E+00, 0.70864000E-01, -.10381500E+00, -.57421900E+00, -.50104000E+00, -.10516300E+01, -.14709600E+00, -.18955900E+00, 0.52194700E-01, 0.82448200E-02, -.11915100E+00, 0.26605000E-01, 0.20626700E+00, 0.47824500E+00, 0.34545600E+00, -.63658300E-02, 0.14775600E+00, -.11498100E+00, -.21215600E+00, -.22461200E-01, -.19162900E+00, 0.12275300E+00, -.73649200E-01, 0.12241900E+00, -.17975700E-01, 0.45339900E+00, -.85775700E-01, 0.65019100E-01, -.18595000E+00, -.17865500E+00, 0.40396500E+00, -.17038200E-01, -.38384700E+00, -.25647900E+00, 0.85261900E-01, 0.73758200E-02, -.46542600E+00, 0.66191100E+00, 0.11047500E+00, 0.16881500E-01, 0.12902200E-01, -.25700900E-01, -.77469000E-01, -.29828600E-01, -.76899400E-01, 0.51600200E-01, -.20208800E+00, 0.60444100E-01, 0.11903500E-01, -.25156400E-01, -.77740900E-01, -.29391800E-01, -.72604800E-01, 0.49415000E-01, -.19868300E+00, 0.61602800E-01, -.47485600E-01, -.17838100E-01, -.16486400E+00, -.15345200E-01, 0.30731000E-01, 0.82597500E-02, -.12187700E+00, 0.17915600E+00, 0.28259000E-01, 0.15635600E+00, 0.24734400E+00, 0.15630700E+00, -.27898000E+00, -.17304900E+00, -.90260100E-01, -.18507700E-01, 0.23213700E+01, -.72604200E+00, 0.11025800E+00, -.43835200E-01, 0.99936100E-01, 0.17953900E+00, 0.66129900E+00, -.52975300E-01, 0.38710200E+01, -.50281100E+01, -.23507000E+01, -.24728500E+01, 0.13092900E+01, 0.21271600E+01, -.12797900E-01, -.24606800E+01, -.53424000E-01, 0.31531200E+00, -.50272700E-01, 0.16785800E-01, -.40105700E-01, -.74498700E-01, -.56388000E-01, 0.20569900E-01, 0.99137300E-01, -.63074000E+00, 0.92690700E-01, -.40508400E-01, 0.87007600E-01, 0.15477900E+00, 0.12639600E+00, -.48289000E-01, 0.11552300E+00, -.35887000E-01, -.39309100E+00, 0.85888900E+00, -.12026400E-01, 0.18214500E+00, 0.46427800E+00, -.49644900E-02, -.48517000E+00, -.11822700E-01, -.70513200E-01, 0.16239600E+00, -.15450600E+00, 0.35032300E-01, 0.41447500E+00, -.76540800E-02, 0.13908900E+00, 0.10208900E+00, -.17193400E-02, -.20230200E-01, 0.22037700E+00, -.89319500E+00, -.35523100E+00, 0.20497800E+00, 0.24690000E-01, 0.12190400E-01 }, { 0.10017400E+01, 0.13273900E+01, -.79758500E+00, 0.51227500E-01, -.26098700E+00, -.76926100E+00, -.33555800E+00, 0.10998000E+01, -.15829900E+00, -.58889000E+00, 0.16260900E+00, 0.56180200E+00, 0.67554400E-01, -.72850900E-01, 0.31541900E+00, 0.18127000E+01, 0.16954100E+01, 0.57147100E+00, 0.53530800E-01, -.40105300E+00, -.36213900E+00, 0.30559100E+00, 0.67134800E+00, -.64043400E+00, 0.11626400E+00, -.26541400E+00, 0.69802100E+00, 0.26127100E+00, -.34276200E+00, -.18579300E+00, -.84938700E+00, 0.73808000E-01, 0.24017300E+00, 0.23667800E+00, 0.23939800E+01, -.64361100E-01, -.38234600E-02, 0.42299100E-01, 0.61718000E+00, 0.86914000E-01, 0.84945400E-01, -.49894900E+00, -.30071900E+00, 0.17872500E+00, 0.21217000E+00, 0.90654500E-01, -.10725600E+00, 0.27477800E+00, 0.98240400E-03, -.39300400E-01, 0.10320200E+00, 0.12114000E+00, -.18426400E+00, -.95296900E-01, -.10052600E+01, 0.10069500E+00, -.75535300E-01, -.18557800E+00, 0.86358400E-01, 0.26404300E+00, 0.26541000E+00, 0.14836700E+00, -.71366700E-01, -.20791200E+00, 0.39476400E-01, 0.13603200E-02, 0.39467700E-01, 0.77929000E-01, -.28116900E-01, -.12470400E-01, 0.25669300E+00, 0.47548200E-01, -.41730000E-01, -.20838500E-01, -.15403300E+00, 0.48218900E-01, 0.22125700E+00, -.14622300E+00, 0.36682100E+00, -.32142200E+00, -.38096500E-01, 0.12170400E+00, 0.34109400E+00, 0.36075700E-01, -.26632600E+00, 0.11715600E+00, 0.63145600E-01, -.35001500E-01, -.36404100E-01, -.16036300E+01, 0.82139600E-01, 0.34867600E-01, 0.19478700E-01, 0.12298400E+00, -.48023800E+00, -.35448400E+00, 0.51240200E+00, -.37118700E-02, -.41919900E-02, -.79534600E-01, 0.10494300E+00, 0.13770900E+00, 0.51287500E-01, 0.35196600E-02, -.94994000E-02, 0.38634600E-01, -.39605300E-01, 0.61458300E-01, 0.53453100E-01, 0.57952000E-01, -.11102500E+00, 0.22629100E-01, 0.31529100E-01, 0.14711700E+00, 0.59762600E-01, -.10318400E-02, 0.12171300E-01, 0.47169800E-01, 0.69305100E-02, 0.15662500E-01, -.43714600E-01, -.14791700E+00, 0.86281100E-01, -.11405300E+00, 0.37302800E+00, 0.28130600E-01, 0.41617000E-01, -.23159700E-01, -.16982700E+00, -.54035400E-01, 0.11460900E+00, 0.16717700E-02, -.99346900E+00, -.26759500E+00, 0.83802100E-01, -.27083700E-02, -.80875900E-02, 0.22575300E-01, 0.14014200E-01, 0.16165300E-01, -.46874100E-01, 0.32323800E-01, -.23638500E+00, 0.83301800E-01, -.79012600E-02, 0.22585300E-01, 0.13142700E-01, 0.16430500E-01, -.45804000E-01, 0.31639400E-01, -.23216600E+00, 0.84664000E-01, 0.13245900E-01, 0.10703000E-01, -.53187300E-02, -.13343900E+00, 0.35782000E-01, 0.40537200E-01, -.25209600E-01, -.61320500E-01, -.43918900E-01, -.56942200E-01, -.19612100E+00, -.81088400E-01, 0.17937200E-01, 0.51378000E-01, -.11844600E-01, -.38697300E-01, -.29477300E-01, 0.29602500E+01, 0.63248900E-01, 0.82038400E-01, -.97150800E-02, -.26630900E-01, -.16439400E+00, 0.73920100E-01, 0.52568700E+01, -.24260000E+01, 0.65215600E+00, 0.39287900E+00, -.22357500E+01, 0.14511400E+01, -.56243700E+00, 0.46117400E+00, 0.26983900E-01, -.66983300E-01, -.25204000E-01, -.36920600E-01, 0.59618500E-02, 0.11325500E-01, 0.53358500E-01, -.33612900E-01, -.55644700E-01, 0.12830400E+00, 0.56742200E-01, 0.72987900E-01, -.89714800E-02, -.24893900E-01, -.10710900E+00, 0.65700800E-01, -.53434600E-01, -.17695200E-01, 0.18425100E+00, -.41366200E+00, -.27044000E-01, -.67481300E-02, -.50162600E-02, 0.33958500E-01, -.82643800E-01, -.23374200E-01, 0.61061400E-01, -.50588200E-01, -.37297600E-02, -.44034900E-01, -.18528900E+00, -.24257500E+00, -.29334000E-01, 0.32479000E-01, -.15538900E-01, -.11301600E-01, 0.29481800E-01, 0.41457400E+00, -.31319500E+00, -.29065600E+00, 0.22296400E-01, -.37978700E-01 }, { 0.41066200E+00, 0.16867800E+00, -.74085300E+00, 0.78489900E-01, -.15635400E+00, -.14084200E+01, -.12085700E+01, 0.62899200E+00, -.21232500E+00, 0.43158600E+00, -.86803800E-02, -.24851100E+00, 0.50447900E+00, -.28105600E+01, 0.43219900E+00, 0.16835900E+01, 0.80451800E+00, 0.67605500E+00, 0.89985800E-01, -.36637900E+00, 0.15998300E+00, 0.19003700E-02, -.26486300E+00, -.13359100E+00, -.84158900E-02, -.33276000E-01, 0.15419800E+00, 0.62908900E-01, -.22593800E+00, -.54488100E-02, -.12347200E+00, -.89337100E-01, 0.18135300E+00, 0.49736500E-01, 0.50211500E+00, -.17751100E+00, -.59940900E-02, -.32708800E-01, 0.13556600E+00, 0.13534500E-01, -.11096700E-01, -.16627700E+00, -.15750500E+00, -.26837900E-01, 0.72791500E-01, 0.26729000E+00, -.56438200E-01, -.31275500E+00, -.46512000E-02, 0.55983300E-02, 0.64014800E-02, -.48983100E-02, 0.44559200E-01, -.89324700E-02, -.10867400E+01, 0.11044000E-01, 0.27366900E-02, -.92887500E-01, 0.68038700E-01, -.62362000E-01, -.83822000E-01, 0.31888100E-01, -.36035800E-01, -.40333100E+00, -.94399900E-01, 0.35106300E-01, 0.85945600E-02, 0.17134300E+00, 0.12918300E+00, -.26964000E-01, -.65185100E-02, 0.20929500E+00, 0.65101000E-01, -.54303900E-01, 0.39547100E-01, -.94979100E-02, 0.16495500E+00, -.51383900E-01, 0.13924500E+00, -.16000600E+00, -.16330600E-01, 0.57424000E-01, 0.58561400E-01, 0.16435700E-01, -.71502000E-01, 0.19579700E+00, 0.57944200E-02, -.14054600E+00, -.47046900E-02, 0.26266700E+00, -.14805100E+00, 0.65602200E-01, -.20164300E-01, 0.91944500E-01, 0.38782200E+00, -.30590000E+00, 0.75094400E-01, 0.11147600E-01, 0.64307500E-02, -.12983100E+00, -.33763800E-01, 0.27533900E-01, -.69050000E-02, -.73107500E-02, -.94112500E-02, -.10193500E-01, 0.36289900E-01, 0.35432800E-01, 0.25295900E+00, -.64956800E-01, -.23791000E-01, 0.31788600E-02, 0.57964600E-01, 0.63453600E-01, -.54916400E-02, 0.20427200E-01, -.52581500E-02, 0.72588900E-01, 0.26308000E-01, 0.21080100E-01, 0.25059400E-01, -.70062800E-01, 0.57122200E-01, -.45110600E-01, 0.92542500E-01, 0.84608300E-02, -.15176900E-01, -.11856500E-02, -.10878300E+00, -.17176000E-01, 0.36316400E-01, -.21826700E-02, -.86239600E+00, -.40516200E-01, 0.88620500E-01, 0.15143400E-01, -.26882800E-02, -.29216100E-02, 0.40342600E-01, 0.26871600E-02, -.27181700E-01, 0.16222600E-02, -.98078500E-01, 0.88904400E-02, -.26689300E-02, -.27700400E-02, 0.39704600E-01, 0.26904800E-02, -.26389400E-01, 0.15627500E-02, -.96153400E-01, 0.86774600E-02, 0.14526400E-02, 0.90538700E-02, 0.43208800E-01, -.23236600E-01, 0.40516900E-01, 0.66985400E-02, -.18772200E-01, 0.29128500E-01, -.41182300E-01, -.55994100E-02, 0.27665600E-02, 0.79835700E-02, 0.29081600E-01, -.12824500E-01, 0.36096300E-01, 0.40519100E-02, -.25751700E-01, 0.16159600E-01, 0.58884600E+00, 0.20962100E-01, -.21327500E-02, -.26002700E-01, 0.13513300E-01, 0.95992700E-02, -.12354000E+01, 0.12602300E+01, 0.77057400E+00, 0.57086600E+00, -.28999400E+00, -.25510200E+00, 0.75569900E+00, 0.60648300E+00, 0.26328100E-01, -.19506400E-01, -.27426600E-01, -.99041500E-02, 0.24938200E-03, 0.12320400E-01, -.15268600E-01, -.48792900E-02, -.49567700E-01, 0.39354100E-01, 0.53396200E-01, 0.17985400E-01, -.12343600E-02, -.22440100E-01, 0.30157500E-01, 0.80573100E-02, -.43075700E-01, 0.56045700E-02, -.55038400E-01, 0.39067900E-01, 0.61862200E-02, 0.79340400E-01, 0.26180000E-01, -.75134100E-02, -.90038000E-02, 0.50877200E-02, -.12808700E-01, 0.70339300E-01, 0.58554700E-01, 0.26637300E-01, 0.68978500E-01, 0.56948000E-01, 0.37219300E-01, -.50645800E-01, 0.24011300E-02, 0.31426600E-02, 0.52440100E-01, -.49478700E-01, 0.75548700E-01, -.36723900E-01, -.58233000E-02, 0.12197300E-01 }, { 0.53426800E+00, 0.22023400E+00, -.88462100E+00, -.40252000E+00, -.30280800E+00, -.19315100E+01, -.14134300E+01, 0.88927400E+00, -.11711500E+00, 0.25005600E+00, -.18911800E-01, -.11975600E+00, 0.51963000E+00, -.23625100E+01, 0.15379000E+00, 0.12557700E+01, 0.94322200E+00, 0.26122100E+00, -.10717900E+00, -.18810000E+00, -.66237700E-01, 0.11254300E+00, 0.73164400E-01, -.22149800E+00, 0.33740900E-01, -.77280300E-01, 0.24891100E+00, 0.69443600E-01, 0.85554100E-01, -.64017200E-01, 0.39606300E+00, -.61337300E-01, 0.14712200E+00, 0.83086100E-01, 0.22873600E+01, -.13867500E+00, 0.37027400E-01, -.12918400E+00, 0.44572100E+00, 0.73604600E-01, 0.27878600E-01, -.20498500E+00, -.23044500E+00, -.18267100E+00, -.17607000E-01, 0.13800300E+00, -.17553300E+00, 0.59614900E+00, 0.30358700E-01, -.42646800E-01, 0.11182500E+00, 0.15982700E-01, -.28445100E+00, -.20206000E-01, -.19928500E+01, -.13305700E+00, -.60105800E-01, 0.15646400E+00, -.22354500E+00, -.30387900E+00, 0.56459100E-01, 0.93149000E-02, -.96009500E-01, -.29758200E+00, 0.60036500E-01, 0.20584100E-01, -.47842100E-02, 0.13074000E+00, 0.92229200E-01, -.17961000E-01, 0.83261200E+00, 0.12590400E+00, -.62431900E-02, -.20709800E-01, 0.45669600E-01, 0.73278600E-02, -.15934100E+00, 0.43209400E-01, -.13477300E+00, -.22518900E+00, 0.33020200E-01, 0.37058400E-01, 0.21416700E+00, -.19206600E-01, -.62272300E-01, -.68317700E-01, 0.34842500E-01, -.26995700E-01, 0.21809700E-01, -.43243200E+00, -.29705200E-01, 0.27735700E-01, 0.30043500E-01, -.18008100E-02, 0.64984400E-01, -.13582900E+00, 0.14584900E+00, -.33448300E-02, 0.37412300E-01, -.28617200E+00, 0.38619700E-01, 0.59719300E-01, -.16198400E-01, 0.21889300E-01, 0.91064500E-02, 0.36715400E-01, 0.24869800E-01, 0.55566700E-01, 0.18844000E+00, -.15980500E+00, -.31842600E-02, -.23518400E-01, 0.10530900E+00, 0.76683500E-01, 0.31122800E-01, -.70111200E-02, 0.13064000E-01, 0.51089700E-01, -.48546200E-01, -.14878400E-03, 0.68151400E-01, -.35426700E-01, 0.26526900E-02, -.21831000E-02, 0.35692300E-01, -.23738100E-02, 0.77948700E-01, -.26012900E-01, 0.36003100E+00, -.62494200E-01, 0.91019000E-01, -.25870000E-01, -.51163100E+00, 0.14420100E-01, 0.86498500E-01, -.45312800E-01, -.99233900E-02, -.45114400E-02, 0.26559000E-01, 0.28403300E-01, -.33310200E-01, -.78194000E-02, -.71437400E-01, 0.49524700E-01, -.98039800E-02, -.43623800E-02, 0.25710600E-01, 0.28003200E-01, -.32166500E-01, -.75208900E-02, -.68685900E-01, 0.48281800E-01, 0.23348000E-02, 0.11599200E-01, 0.11085700E-01, 0.77718700E-02, -.52166700E-02, -.63551700E-02, -.24880500E-01, 0.12096200E+00, -.21163500E-01, 0.27334400E-01, -.14554000E-01, -.48500000E-01, -.12685100E-01, -.21061100E-03, 0.14553400E-01, -.15621800E-01, -.20266400E-01, 0.24700100E-02, 0.49182500E-01, 0.47315400E+00, -.31079100E-03, -.48302700E-01, -.81896500E-01, 0.13320200E-01, -.40993900E+00, 0.28617700E+00, 0.38132100E+00, 0.32282500E+00, -.16071500E+00, -.17056700E+00, 0.39600800E+00, 0.28473400E+00, 0.20427100E-01, -.37105200E-02, -.11493300E-01, -.18943900E-01, -.63720700E-03, 0.21187200E-01, -.57313700E-02, -.55313100E-02, -.37352100E-01, 0.46902500E-02, 0.22390900E-01, 0.37443400E-01, 0.46744800E-03, -.41445500E-01, 0.90830600E-02, 0.11032000E-01, -.36119800E-01, -.98460800E-03, -.17008400E-01, 0.27295500E-01, -.49087200E-04, 0.80239700E-02, 0.31705000E-01, -.11734100E-02, -.29038400E-01, -.35516600E-03, -.12015000E-01, 0.42336300E-01, 0.30438600E-01, 0.15227600E-01, 0.25570200E-01, 0.90947700E-02, 0.61383200E-02, -.35424200E-01, -.83812200E-03, -.96075800E-03, 0.16832700E-01, -.27433300E-01, 0.64713500E-01, -.17350100E-01, 0.56532000E-03, 0.50271000E-02 }, { 0.40021700E+00, 0.93907100E-01, 0.10336700E+00, -.16108500E+00, -.37320300E+00, -.45392000E+00, -.15456300E+00, -.10795200E+00, 0.45807300E-01, -.88580800E-01, -.26392900E-01, -.13946500E+00, -.22927300E+00, 0.30808400E+00, 0.13455500E-01, -.56472800E+00, 0.30367100E-01, -.17973000E+00, 0.58845900E-01, 0.16311100E+00, -.22165300E+00, 0.66199000E-01, 0.30001400E+00, -.18609200E+00, 0.33415900E-01, -.80920800E-01, 0.17274100E+00, 0.74386500E-01, -.11509600E+00, -.43743600E-01, -.54347500E+00, 0.72634200E-01, 0.28710900E-01, 0.34319500E-01, -.22474300E+00, 0.21634500E-01, -.56852900E-02, -.25552100E-01, -.13281100E+00, 0.87600800E-02, -.45372300E-01, 0.22706500E-01, -.27494900E-01, 0.29770000E-01, -.30948600E-01, 0.21989700E+00, -.25413400E-01, -.26449400E+00, -.68363300E-02, 0.78776600E-02, -.48630600E-01, -.59907400E-02, 0.92751100E-01, 0.10539100E-01, -.14575600E-01, 0.43139700E-01, 0.15238400E-01, 0.11194400E+00, 0.64948500E-01, 0.13557300E+00, 0.14018000E+00, 0.14529400E-01, -.35012100E-01, 0.10453200E+00, 0.87733200E-01, -.98659600E-02, -.99917900E-02, -.81721600E-01, -.14650300E-01, 0.36030000E-03, 0.27610200E+00, -.24778100E-01, -.25710900E-02, -.28956800E-02, -.73222100E-01, -.29540900E-02, 0.23861900E-02, -.11858900E-01, -.50280000E-01, 0.18588100E+00, 0.18483600E+00, -.11861300E-01, 0.52078200E-01, -.15768600E-01, -.18906100E-01, -.21774900E-01, 0.43209500E-01, 0.32890400E-01, 0.33237100E-01, -.57713100E+00, 0.68482300E-01, -.21295600E-01, 0.28429300E-01, 0.53852300E-02, -.24479600E+00, 0.10978000E+00, 0.10884700E+00, -.19196000E-01, 0.12260200E-01, 0.17345200E+00, 0.12884000E+00, 0.13087900E+00, 0.49075900E-01, 0.19944400E-01, -.20867800E-02, 0.23466300E-01, 0.94039400E-02, -.96620400E-02, -.26627000E+00, -.14221400E-01, -.45195000E-01, 0.27212500E-01, -.15520000E-01, 0.15025300E-01, 0.20982600E-01, -.61779000E-02, 0.22639700E-02, 0.36042400E-02, 0.31778400E-01, 0.30086700E-02, -.10599200E-02, -.37447200E-01, 0.88470700E-02, -.20018600E-01, 0.15476900E-02, 0.44322100E-01, -.79648600E-01, 0.11374200E-01, 0.79034100E-01, 0.63444200E-01, 0.13691300E-02, -.47136200E-02, -.15309000E+00, -.25861000E+00, -.50270300E-01, 0.47708400E-02, 0.24852900E-02, 0.65050600E-02, -.80519800E-02, -.11848100E-01, 0.72364100E-01, 0.72429700E-04, 0.55244300E-01, -.36852500E-01, 0.25643100E-02, 0.62641500E-02, -.75477400E-02, -.11582900E-01, 0.70412700E-01, 0.24135000E-03, 0.52498500E-01, -.35871500E-01, 0.12670500E-01, -.35976500E-02, -.93014700E-02, 0.37276100E-02, 0.59025600E-02, 0.86057400E-02, 0.46022100E-01, -.82606500E-01, 0.48012200E-01, -.46653300E-01, -.59507500E-01, -.44892600E-01, 0.91671200E-01, 0.25169200E-01, 0.33007800E-01, 0.26069300E-01, 0.45745100E-02, 0.55962000E-01, -.11874900E+00, -.54141600E-01, 0.27047400E+00, -.29065300E-01, -.74395700E-01, -.13617300E-01, -.16153300E+01, 0.19683200E+01, 0.57566900E+00, 0.49830900E+00, -.14035500E-01, -.63431000E+00, 0.30460700E+00, 0.50568600E+00, -.12597000E-02, -.68587300E-01, 0.25742600E-01, 0.97530600E-02, -.96422000E-02, 0.13399500E-01, -.39833900E-02, 0.55752600E-02, 0.37651200E-02, 0.14133600E+00, -.52423200E-01, -.19928900E-01, 0.17159600E-01, -.25116300E-01, 0.58058300E-02, -.11591900E-01, 0.29734400E-02, 0.18210400E-01, 0.16571000E-01, -.48101700E-01, 0.14184200E-01, -.51225000E-01, -.11182800E+00, -.11222700E-01, 0.13163500E+00, 0.12752800E-01, -.42192800E-01, -.12691400E-01, 0.47573700E-01, 0.26044000E-01, 0.53667600E-02, 0.63378800E-01, 0.16321500E-01, -.55781800E-01, 0.66214000E-02, 0.10895800E-01, -.30759300E-01, 0.39314200E-01, 0.13395900E+00, 0.16171700E-01, -.16265000E-01, 0.96555900E-02 }, { -.11266100E+01, -.38370500E+00, 0.11212900E+01, 0.59041900E+00, 0.37599100E+00, 0.30742400E+00, -.37722200E+01, -.12589900E+01, 0.21050000E+00, -.38830300E+00, 0.82722300E-01, 0.11771600E+01, 0.14385700E+00, 0.27824400E+01, -.10900300E+01, -.52615500E+00, -.63134100E+00, -.41210600E+00, -.39071200E+00, 0.32316200E-01, 0.90251600E-02, 0.88989100E-01, 0.56421700E+00, 0.12439900E+00, 0.70694900E-01, 0.24057800E-01, -.52241900E+00, -.20912900E+00, -.29620100E+00, -.14329400E+00, -.15750700E+01, 0.29544600E+00, -.17206500E+00, 0.23854400E+00, 0.24569800E+01, 0.44285500E+00, -.10577500E+00, 0.53069400E+00, 0.34239600E+00, 0.79216100E-02, 0.25452200E+00, -.35527300E-01, 0.10382400E+00, 0.21985400E+00, 0.11002100E+00, -.87390900E+00, 0.14138400E+00, 0.14874400E+01, -.10465500E-02, -.24383500E-01, 0.62427400E-01, 0.10381500E+00, -.12729400E+00, -.94695800E-01, 0.10094000E+01, 0.10732700E+00, -.43029200E-01, -.24821000E+00, -.65782300E-01, 0.21612600E+00, -.67256200E-02, -.30375500E-01, 0.28098400E+00, 0.96587300E+00, -.11938800E+00, -.73472300E-01, 0.58871500E-01, -.36841000E+00, -.34983900E+00, 0.47500900E-01, 0.50510300E+00, -.49486400E+00, -.24712400E+00, 0.14962500E+00, -.11976300E+00, 0.13529300E+00, 0.11482500E+00, -.15975500E+00, 0.74490900E-01, -.37403300E+00, -.11992300E+00, 0.42559600E-01, 0.32205500E+00, 0.33220700E-01, -.14135800E-01, 0.79587500E-01, -.43159900E-01, 0.25918600E-01, -.38472500E-01, -.39510600E+00, 0.23394500E+00, -.94723200E-02, -.29409200E-01, -.63994300E-01, 0.13430500E+01, -.17083300E+00, -.93335900E+00, -.19069500E-01, 0.65648200E-01, 0.84561500E+00, -.17753000E+00, -.30598700E+00, -.10051300E+00, -.81481400E-01, 0.33367000E-01, 0.12324500E+00, -.10975700E+00, 0.11721600E+00, -.24153000E-01, 0.22255600E+00, -.14885900E+00, -.11951700E+00, -.27361400E+00, -.15348500E+00, -.60674800E-01, -.24589900E-01, -.77501400E-01, -.14708800E+00, 0.26883900E-01, -.70823900E-01, -.21108400E+00, -.32048300E-01, 0.27742400E-01, -.27718000E-01, 0.51564900E-02, -.19848300E-01, -.53834400E-01, -.16315000E-01, -.85669300E-01, 0.38238000E-01, 0.11528200E+00, 0.28579200E-01, 0.55711900E+00, 0.49076800E-01, -.27439200E-01, 0.15390700E-01, 0.51319300E-02, 0.36800400E-02, -.58984700E-02, -.46192600E-02, -.23334900E-01, 0.37075200E-01, 0.13363900E-01, -.23073300E-02, 0.50135000E-02, 0.36872600E-02, -.62198900E-02, -.48963300E-02, -.22469100E-01, 0.36512500E-01, 0.14642600E-01, -.33095700E-02, -.72102100E-02, -.12438200E-01, -.49679400E-01, 0.28463300E-01, -.24106400E-01, 0.28514100E-01, -.97475100E-01, 0.52144700E-01, -.79070300E-01, 0.15451200E-01, -.76228400E-01, -.42254100E-01, -.15998900E+00, -.19467800E-01, -.11016100E+00, -.60807300E-01, 0.32162100E-01, -.97950400E-01, 0.11135400E+00, 0.77489800E-01, -.10325100E+00, 0.13773200E+01, -.14514200E+00, 0.32503000E-01, 0.98507800E+01, -.83519600E+01, -.14889200E+01, -.12079400E+01, -.19356600E+01, 0.31478500E+01, -.22146700E+01, -.10761700E+01, -.40341700E-01, 0.11249400E+00, -.17716400E-01, -.13224100E-01, 0.15729800E-01, -.68403500E-01, 0.79154600E-01, -.14013400E-01, 0.69378300E-01, -.23117600E+00, 0.44557400E-01, 0.29228700E-01, -.24930400E-01, 0.12747400E+00, -.15277500E+00, 0.30612900E-01, 0.61206900E-01, -.50183300E-01, 0.31319700E+00, -.36981600E+00, -.50953400E-01, -.19739800E-01, 0.10620500E+00, 0.53424400E-01, -.15659500E+00, -.44108600E-01, 0.18289200E+00, -.21487400E+00, -.21783600E+00, -.13871300E+00, -.36408400E+00, -.43999300E+00, -.76994900E-01, 0.27416000E+00, -.23647600E-01, -.29531700E-01, 0.11237300E-01, 0.38630100E+00, -.43259400E+00, -.28544800E+00, 0.50477500E-01, -.63976500E-01 }, { 0.30496200E+01, 0.11887500E+01, -.27759200E+01, -.20375800E+01, -.21472300E+01, -.76887000E+01, -.52594000E+01, 0.38159800E+01, -.11525400E+01, 0.11073600E+01, 0.52507900E+00, 0.36326000E+00, 0.16653700E+01, -.10114600E+02, 0.19307700E+01, 0.95603100E+01, 0.18044100E+01, 0.95018300E+01, 0.36260500E+01, -.16110100E+01, -.32012300E+01, -.27355900E-01, 0.28909600E+00, -.22868400E+01, 0.44874400E-01, -.48616200E+00, -.43800300E+00, -.43351300E+00, -.47046200E+01, -.58070500E+00, -.93533400E+01, 0.88644200E+00, 0.17532000E+01, 0.28019600E+00, 0.86105600E+01, -.39689000E+00, -.40986800E+00, -.10939000E+01, -.50652900E+00, -.21761400E+00, -.70690900E+00, 0.55653000E+00, 0.26665900E+01, -.16976400E+01, -.20975800E-01, 0.14104200E+01, -.41923700E+00, -.28804500E+01, 0.18610300E+00, -.16753100E+00, 0.16024700E+00, -.59261200E+00, -.81814100E+00, 0.54516500E-01, -.17101000E+02, -.10318600E+01, 0.93352700E-02, -.13263800E+01, -.30543600E+01, -.13693100E+00, -.57514500E+00, -.11925500E+00, -.45033100E+00, -.27138300E+01, -.55484100E-02, 0.17507000E+00, -.23516600E+00, 0.14970500E+01, 0.82472400E+00, -.40720100E-01, -.92029900E+00, 0.36246500E+00, 0.96713200E+00, -.41080500E+00, 0.26848700E+00, -.76667200E-01, 0.21054900E+01, -.75694900E+00, -.54477300E+00, 0.62072000E+01, -.68863500E+00, 0.51194200E+00, -.21082800E+01, 0.33922700E+00, -.48520900E+00, 0.17917900E+01, -.38769400E-01, -.14313600E+01, -.31151800E+00, 0.89401200E+01, -.33306300E+01, 0.21214200E-01, -.12168100E+00, 0.32654500E+00, -.34554300E+01, -.11125700E+01, -.33797600E+00, 0.74750700E-01, -.13181000E+01, 0.10213700E+01, 0.23467400E-01, -.76278500E+00, 0.80521100E+00, -.20391500E+00, -.12449800E+00, -.48706200E+00, -.31762300E+00, 0.52226800E+00, 0.12198700E+01, -.15414900E+01, -.58977000E+00, -.24430100E+00, 0.10387200E+01, 0.10189900E+01, 0.16376000E+01, -.28239100E+00, 0.62517500E+00, 0.91716400E+00, -.10322400E+00, 0.41356500E+00, 0.28563200E+00, -.76066900E+00, 0.79007600E+00, -.43174000E+00, 0.19314900E+01, 0.11485200E+01, -.12896900E+01, 0.22775200E+00, 0.52549000E+01, 0.11856600E+00, 0.47854000E+00, 0.12140800E+00, -.25695700E+01, -.11617100E+01, -.52684000E-01, 0.57461000E+00, -.27063200E-01, 0.31834400E-01, 0.12116000E-01, -.33325900E-01, -.25929100E+00, 0.89658000E-01, -.32642200E+00, 0.42880300E-01, -.26967400E-01, 0.32043100E-01, 0.78643700E-02, -.33512900E-01, -.25276900E+00, 0.87562800E-01, -.31628200E+00, 0.43582500E-01, -.43304200E-01, -.55543800E-01, -.36073600E+00, 0.30960500E+00, 0.21543200E+00, 0.11717800E+00, -.81319000E+00, 0.11067600E+01, -.13394100E+01, 0.60145100E-01, -.64411700E+00, 0.41822400E-01, -.14017600E+01, 0.14797000E+01, 0.10269600E+01, -.47191000E+00, 0.64262600E+00, -.41737800E+00, 0.62189500E+00, -.82260000E+00, -.71300400E+00, 0.95421100E+00, -.87709400E+01, -.10155500E+00, 0.36698900E+02, -.30432700E+02, -.31392400E+02, -.29711000E+02, 0.24217900E+02, 0.14721200E+02, -.15103800E+02, -.30257100E+02, -.62090800E+00, 0.30411400E+00, -.71932000E-01, 0.21202500E+00, 0.10174200E+00, -.57500100E+00, 0.98539000E+00, 0.84544800E-01, 0.11806400E+01, -.69195600E+00, 0.19004100E+00, -.35903000E+00, -.12757100E+00, 0.10446600E+01, -.19516800E+01, -.10134500E+00, 0.90264600E+00, -.25279600E+00, 0.97945200E-01, 0.11091400E+01, -.30262600E+00, 0.25955100E+00, 0.24690000E+00, 0.35992600E+00, -.20821800E+00, -.25796500E+00, 0.14137100E+01, -.70839500E+00, -.20781200E+01, -.12660400E+01, -.73247300E-01, -.35796800E+01, -.16212700E+00, 0.19503300E+01, -.13662800E+00, -.14851900E+00, -.70300200E+00, -.25917100E+01, -.96440300E-01, 0.23034800E+01, 0.27515900E+00, -.48564300E+00 }, { -.63371300E+00, -.25805900E+00, 0.11261600E+01, 0.47399900E+00, 0.46628200E+00, 0.26031400E+01, 0.19511200E+01, -.71888300E+00, 0.95365100E-01, -.14658700E+00, 0.10011900E-02, 0.33463100E+00, -.22802500E+00, 0.19261100E+01, -.40533900E+00, -.92042400E+00, -.78151300E+00, -.33135000E+00, -.19782200E-01, 0.26876100E-02, 0.24471200E-01, -.21529100E-01, 0.15213700E+00, 0.26450000E+00, -.95837400E-02, 0.10914600E+00, -.29830900E+00, -.72897900E-01, 0.30258700E+00, 0.41748400E-01, 0.89087700E+00, -.14387400E-01, -.32215100E+00, -.82331300E-02, -.65538000E+00, 0.19203400E+00, 0.10302200E-01, 0.18710900E+00, 0.35115200E-01, -.23118300E-01, 0.94585300E-01, 0.11514100E+00, 0.16620400E+00, 0.18273100E+00, -.45611900E-01, -.50293700E+00, 0.14198400E+00, 0.54346300E+00, -.77232000E-02, -.26282600E-01, -.40726700E-01, 0.49996500E-01, -.37053100E-01, -.15437600E-01, 0.27865400E+01, 0.51379900E-01, 0.18343000E-01, -.16524100E+00, 0.46143900E-01, 0.21154300E+00, -.19701400E+00, -.41838400E-02, 0.28364400E+00, 0.68736800E+00, -.21352100E+00, -.63785800E-01, 0.51590900E-01, -.22374900E+00, -.29210900E+00, 0.53046300E-01, -.10515800E+01, -.37721500E+00, -.12440800E+00, 0.11031100E+00, -.13953300E-01, -.39813200E-02, -.96766900E-01, 0.75653800E-01, 0.81751500E-01, -.52240700E+00, -.53654700E+00, -.66999200E-01, -.37494900E+00, 0.12716500E+00, 0.75893300E-01, -.16580300E+00, -.14190900E+00, 0.28779100E+00, -.88165900E-01, 0.83842800E+00, 0.23960600E-01, -.79936400E-01, -.12406400E-01, -.57961100E-02, -.55218300E+00, 0.17057600E+00, -.12272400E+00, 0.33005200E-01, -.38049600E-01, -.76622300E+00, -.20887200E+00, -.51460300E+00, -.65828800E-01, -.40752900E-01, 0.20288100E-01, 0.54362900E-01, -.17273800E+00, -.11692400E+00, -.44032300E+00, 0.21890800E+00, 0.70113700E-01, -.71403200E-01, -.11554700E+00, -.33852100E+00, -.10185300E+00, -.63829900E-01, -.18634100E-01, -.33007000E+00, -.14969200E+00, -.81320700E-01, -.21752300E+00, 0.36500500E+00, -.27188600E+00, 0.24163400E+00, -.47090100E+00, -.11410800E+00, 0.89029100E-01, 0.28873300E-01, -.11293200E+01, 0.10724600E+00, -.33006800E+00, 0.80301100E-01, 0.29692400E+01, 0.20685300E+00, -.37287400E+00, -.63821100E-01, 0.14192800E-01, 0.37423800E-01, -.10061000E+00, 0.56063400E-01, -.68453400E-01, 0.18511000E-01, 0.23864100E+00, 0.28853100E+00, 0.14319300E-01, 0.37171100E-01, -.99095100E-01, 0.55515400E-01, -.67648700E-01, 0.17681400E-01, 0.24244500E+00, 0.28875100E+00, -.25592600E-01, -.59710700E-01, -.34680400E-01, -.10808700E+00, -.85724800E-01, 0.10945200E+00, -.76364000E-01, -.24378500E+00, -.15259300E+00, -.13641700E+00, -.30563700E+00, 0.13862300E+00, -.27622900E+00, 0.21503700E+00, -.35200600E+00, -.16542800E+00, 0.59642400E-01, -.22250900E+00, 0.19308500E+00, 0.35172700E+00, -.39318400E+00, 0.12090300E+00, -.45353600E-01, 0.25930700E+00, 0.20309200E+02, -.14287800E+02, -.60631500E+01, -.53851000E+01, -.36550500E-01, 0.60912900E+01, -.61847400E+01, -.52388500E+01, -.10717100E+00, 0.24881100E+00, -.23090900E-01, -.55385400E-01, 0.58150500E-01, -.92982600E-01, 0.21097900E+00, -.11684700E+00, 0.18041100E+00, -.50498700E+00, 0.64789700E-01, 0.10716700E+00, -.92988900E-01, 0.17126700E+00, -.39584900E+00, 0.22788000E+00, 0.17999200E+00, -.17246200E+00, 0.64268500E+00, -.78690700E+00, -.18367400E+00, -.15618500E+00, -.25831700E-01, 0.19757100E+00, -.57109700E-01, -.16020900E+00, 0.46767000E+00, -.22572800E+00, -.63067700E+00, -.37334200E+00, -.70515800E+00, -.11643600E+01, -.32003300E+00, 0.64856200E+00, -.92313200E-01, -.10476100E+00, -.13658500E+00, 0.83421200E+00, -.12051500E+01, -.40107200E+00, 0.17805500E+00, -.23241200E+00 }, { 0.42968000E+01, 0.15261900E+01, -.36081500E+01, -.19917300E+01, -.14897300E+01, -.94882200E+01, -.80915800E+01, 0.28817600E+01, -.12598100E+01, 0.13783000E+01, 0.20970300E+00, -.70491900E+00, 0.26966700E+01, -.14809700E+02, 0.25654400E+01, 0.10282200E+02, 0.58641000E+01, 0.48330200E+01, 0.56038600E+00, -.21175400E+01, 0.37143200E+00, 0.33129900E+00, -.47521400E+00, -.15232000E+01, 0.15590400E+00, -.61310900E+00, 0.14051600E+01, 0.44983200E+00, -.36380700E+01, -.41573200E+00, -.84327000E+01, 0.30676900E+00, 0.22076600E+01, 0.33527800E+00, 0.71025500E+01, -.13590700E+01, -.12599700E+00, -.10426500E+01, -.10204400E+01, 0.30222900E+00, -.11385000E+01, -.10068400E+01, 0.36799300E+00, -.45722000E+00, 0.93237900E-02, 0.47902600E+01, -.79771700E+00, -.54586400E+01, -.10808200E+00, 0.10558200E+00, -.31463800E+00, -.88506200E-01, 0.12516600E+01, 0.90386700E-01, -.13436900E+02, 0.48470900E+00, 0.24438100E+00, -.12100500E+01, 0.75480100E+00, 0.84118900E+00, 0.35711800E+00, 0.35789200E+00, -.26532700E+00, -.20532500E+01, -.35562000E+00, 0.17409200E+00, 0.76689400E-02, 0.78961500E+00, 0.72939300E+00, -.84705600E-01, 0.20279800E+01, 0.10871800E+01, 0.63350800E+00, -.70126800E+00, -.14541600E+00, 0.11827400E+00, 0.31189900E+00, 0.14098700E+00, 0.95719100E+00, 0.20126500E+00, 0.10924400E+01, 0.20006700E+00, 0.86545200E+00, -.28701900E+00, -.27123200E+00, 0.72785200E+00, 0.24351500E+00, -.74261800E+00, 0.18470000E+00, -.54109400E+01, 0.82193600E+00, -.32633500E-01, -.73106100E-01, -.24319900E+00, 0.26817700E+01, -.17362400E-01, 0.47612500E+00, -.12145300E+00, 0.53545900E+00, 0.38185700E+01, 0.76052700E+00, 0.16174500E+01, 0.12458500E+00, 0.27990900E+00, -.10078300E+00, 0.56850600E+00, -.20046300E+00, 0.65296600E+00, -.67048800E-01, -.50541700E+00, -.12253300E+01, -.73768200E+00, -.21697000E+01, -.11878400E+01, 0.12012000E+01, -.11572800E+00, -.60541700E+00, -.73940300E+00, -.22483700E+00, -.57327700E+00, -.83707400E-01, -.95423100E+00, 0.47655200E+00, -.24981600E+00, -.41255400E+00, 0.50231800E+00, -.24117400E+00, -.31947900E+00, 0.16096300E+01, 0.13385600E+01, -.18575800E+01, 0.31438700E+00, 0.28412200E+02, -.11895900E+01, -.71560400E+00, 0.55069100E+00, 0.33172600E+00, 0.88469200E-01, 0.19933900E-01, -.24499700E-01, -.71734700E+00, -.17416000E+00, -.11691300E+01, -.67403700E+00, 0.33010800E+00, 0.92045100E-01, 0.36636500E-01, -.24173100E-01, -.70490200E+00, -.17204700E+00, -.11421300E+01, -.68097400E+00, 0.18306900E-01, 0.61293400E-02, 0.75838200E+00, 0.14068600E+01, -.13989300E+00, -.19481700E+00, 0.35204400E+00, -.21599900E+00, -.53719900E-02, -.93160900E+00, -.18851000E+01, -.57664700E+00, 0.12006000E+01, 0.16056500E+01, -.17680700E+00, -.31123100E+00, 0.11961200E+01, 0.12102700E+01, -.26843400E+01, 0.43201200E+00, -.52451600E+01, -.18879600E+00, 0.90869700E+00, 0.17326200E+01, -.10773300E+03, 0.12267600E+03, 0.56891000E+02, 0.56059700E+02, -.28350500E+02, -.42229900E+02, 0.17364300E+02, 0.55548800E+02, -.41860500E+00, -.25395400E+01, 0.87196700E+00, -.13916100E+00, 0.38847700E+00, 0.77351400E+00, -.13980000E+00, -.42720900E-01, 0.91648000E+00, 0.52519500E+01, -.17738900E+01, 0.21216100E+00, -.87682100E+00, -.14333500E+01, 0.23154100E+00, 0.18825200E-01, 0.77114000E+00, 0.48094000E+00, 0.33664800E+01, -.68192700E+01, 0.33241800E+00, -.29733600E+01, -.48685200E+01, -.23051600E+00, 0.53692700E+01, 0.29345500E+00, 0.43118800E+00, -.91408100E+00, 0.21888700E+01, -.41981200E+00, -.31436200E+01, 0.35352600E+01, -.19502900E+01, -.20497200E+01, 0.14714800E+00, 0.28093800E+00, -.20403600E+01, 0.85350400E+01, 0.43265600E+01, -.35738800E+01, -.41115700E+00, 0.20276500E+00 }, { 0.25136600E+01, 0.10053200E+01, -.40653200E+01, -.11210400E+01, -.12417200E+01, -.93463500E+01, -.91915300E+01, 0.19254300E+00, -.61795900E+00, 0.10520200E+01, -.80807900E-02, -.38812200E+00, 0.17875200E+01, -.79145400E+01, 0.52028500E+00, 0.46455800E+01, 0.29588100E+01, 0.65562400E+00, -.64181100E+00, -.72927700E+00, -.39352500E-01, 0.44295600E+00, -.38301900E+00, -.19551200E+00, 0.40505400E-01, -.81701700E-01, 0.72762300E+00, 0.26420500E+00, -.12131500E+01, -.23882700E+00, -.49955100E+01, -.42314200E+00, 0.13688100E+01, 0.10417400E+00, 0.79526100E+01, -.94550000E+00, 0.14215100E+00, -.47869200E+00, 0.33797900E+00, 0.14878100E+00, -.50377300E+00, -.37583300E+00, -.26646200E+01, 0.50227200E+00, -.16908000E+00, 0.32847900E+01, -.40408000E+00, -.82537600E+00, -.14901200E+00, 0.18984200E+00, -.16001400E+00, 0.15562100E+00, 0.12757600E+01, -.10216700E+00, -.37846300E+01, 0.86078000E+00, 0.13150700E+00, -.14526400E+01, 0.10087200E+01, 0.15401900E+01, -.92720900E+00, 0.26842800E+00, 0.17951700E+00, -.16194600E+00, -.43867700E+00, 0.85409400E-01, -.64412900E-01, 0.18625200E-01, 0.43598000E+00, -.67523500E-01, 0.25903600E-01, 0.50916400E+00, 0.31344000E+00, -.67662900E+00, 0.55773400E+00, 0.16761200E+00, 0.55603000E+00, 0.25847900E+00, 0.10823400E+01, 0.60480900E-01, 0.45393200E-01, -.16038600E+00, -.10754300E+01, 0.23480600E+00, 0.48494900E-01, 0.47911000E-01, -.97954300E-01, -.37469800E-01, 0.19267400E+00, 0.24193100E+00, -.89853000E+00, -.82898700E-01, 0.60606300E+00, -.39095900E+00, -.44803200E+01, 0.81123500E+00, 0.21681600E-02, -.19554200E+00, -.30547000E+00, -.11931000E+01, 0.10528100E+01, 0.48276100E+00, 0.31319000E+00, 0.40029200E-01, -.26627200E-01, -.19329500E+00, -.41485800E+00, -.54985300E+00, -.70735800E+00, -.28053600E-01, -.39569500E-01, 0.10302200E+01, 0.46125300E+00, -.20689600E+00, 0.31365900E+00, -.45135400E+00, 0.38697700E+00, -.84228700E+00, -.31317800E-01, -.28382000E+00, -.57563000E+00, -.18226200E-01, -.36650700E+00, 0.47143000E+00, -.87723500E+00, 0.38319100E+00, -.40278600E+00, 0.16269500E-01, -.44100100E+01, 0.10949500E+01, -.94808800E+00, 0.51879000E+00, 0.13973900E+02, -.58591800E+00, -.91528000E+00, 0.34837700E+00, -.67870500E-01, 0.19596300E+00, -.34912900E+00, 0.15387500E+00, -.92784300E+00, -.21238300E-01, -.38328800E+00, 0.46162000E+00, -.66496000E-01, 0.19557100E+00, -.34436100E+00, 0.15739100E+00, -.91998900E+00, -.25461600E-01, -.37942700E+00, 0.47713100E+00, -.23656500E-01, -.56148400E-01, 0.52440600E+00, -.14283400E+01, -.17248100E+00, -.29801300E+00, 0.22042000E+00, -.64413300E+00, -.43793900E+00, -.92298400E+00, -.49610600E+00, 0.32836400E+00, 0.25534800E+00, 0.20280700E+01, -.10448500E-01, 0.45446900E-02, 0.27602800E+00, 0.23998000E+00, -.79486500E+00, -.67327100E+00, -.73120800E+00, 0.20099200E+00, 0.36129800E+00, -.84096600E+00, 0.34818300E+00, -.31928800E+02, -.14389000E+02, -.88533500E+01, 0.12838800E+02, 0.62357500E+00, -.59076600E+01, -.71991900E+01, 0.40864000E-01, 0.59180100E+00, -.89363500E-01, 0.88329200E-01, -.52413800E-01, -.26906500E+00, 0.44739200E-01, 0.25343300E-01, -.11298300E+00, -.12185000E+01, 0.20156300E+00, -.12945700E+00, 0.11975900E+00, 0.49819100E+00, -.76137300E-01, -.27504300E-02, -.11418200E+00, -.11417000E+00, -.13685100E+01, 0.12006100E+01, -.86227600E-01, 0.33899800E+00, 0.73172300E+00, 0.70261900E-01, -.74621200E+00, -.74206000E-01, 0.18212200E-01, -.14151200E+00, -.11678900E+01, 0.38924400E-01, 0.97934500E+00, -.14152900E+01, 0.16381400E+00, 0.82646000E+00, -.35984500E-01, -.65808700E-01, 0.14674700E+00, -.10243500E+01, -.91431300E+00, 0.46258200E+00, 0.10059900E+00, -.84301400E-01 }, { 0.69280900E+01, 0.16574700E+01, -.76521700E+01, -.37327000E+01, -.43205500E+01, -.19065900E+02, -.20672700E+02, 0.33669900E+01, -.13164000E+01, 0.35801400E+01, -.44919400E+00, -.21778700E+01, 0.32683700E+01, -.21557600E+02, -.69526300E+00, 0.91690000E+01, 0.68339100E+01, 0.71340600E+01, -.32535900E+01, -.71041500E+00, -.16196600E+01, 0.56147500E+00, -.50404500E+01, 0.15260300E+01, 0.38265500E+00, 0.16406700E+01, 0.30935200E+01, 0.11445300E+01, -.74514900E+01, 0.13375100E+01, 0.33292100E+01, -.32969500E+01, 0.33779100E+01, -.42618500E+00, 0.13397300E+02, -.39061000E+01, 0.69726000E+00, 0.12016600E+01, 0.41563800E+00, 0.22691700E+00, -.14378500E+01, -.16061300E+01, -.29144100E+01, -.98655700E+00, -.18296600E+01, 0.96431300E+01, -.15962200E+01, -.95797100E+00, -.13759600E+00, 0.17593100E+00, -.68876000E+00, 0.46577100E-01, 0.15429300E+01, 0.35103600E-01, 0.27302300E+01, 0.52679000E+00, 0.19625300E+00, 0.45636800E+01, 0.23516300E+01, -.13417300E+01, -.35120800E+01, -.55203300E+00, 0.11332400E+01, -.10748300E+01, -.23008900E+01, 0.10081900E+00, 0.73629500E-01, 0.10171500E+01, 0.67055300E+00, 0.43482100E-01, 0.79893900E+01, 0.20577500E+00, 0.13537700E+01, 0.24325000E+00, 0.57175100E+00, -.76912100E+00, -.43657900E+01, 0.14142300E+01, -.29866600E+01, -.28152900E+01, 0.11743300E+01, -.64589400E+00, -.19803300E+01, 0.50449800E+00, 0.11029300E+01, 0.14379100E+01, 0.31862600E+00, -.14762900E+00, 0.10098300E+01, 0.41678000E+01, 0.25658500E+01, -.50663500E+00, 0.70358000E+00, 0.85317900E+00, 0.76142100E+01, 0.46389200E+01, -.56636800E+00, 0.57719200E+00, 0.44384000E+00, -.12575300E+02, 0.23199000E+01, 0.29450300E+01, 0.80015000E+00, 0.83535900E+00, -.32432800E+00, 0.94727300E+00, -.15038900E+01, 0.39205500E+00, 0.38909800E+01, 0.15157300E+01, -.51926800E+01, 0.92202700E-01, 0.20067500E+01, 0.44135800E+01, 0.26448100E+01, -.29183900E+01, -.11079800E+01, -.18256600E+01, -.11824700E+01, -.43451600E+00, -.16595500E+01, -.25382200E+00, -.25901900E+00, -.73101400E+00, -.90299000E+00, 0.47985700E+00, -.12812200E+01, -.12072400E+00, -.91994600E+01, 0.21578800E+01, 0.54658600E+01, 0.50540600E+00, -.38689100E+02, -.11017900E+02, -.19051400E+01, -.12520400E+01, -.34855000E+00, 0.27958700E+00, 0.42519600E-01, 0.62208800E+00, -.59211100E+00, 0.15742700E+00, 0.85505700E+00, 0.23025300E+01, -.34006400E+00, 0.27597700E+00, 0.12317300E-01, 0.61602800E+00, -.59926900E+00, 0.15754400E+00, 0.88112800E+00, 0.22920800E+01, -.43895500E+00, -.52436200E+00, -.21323000E+01, 0.38448200E+00, 0.82199200E+00, 0.53397400E+00, -.39529900E+01, 0.51989000E+01, -.46140200E+01, -.25394000E+01, -.37076500E+01, -.23298100E+01, -.31762200E+01, 0.13012400E+01, -.12792300E+01, -.97640800E+00, 0.88900700E-01, -.23689900E+01, 0.26113700E+01, 0.46260100E+01, 0.22995300E+00, -.77634900E+00, 0.14700100E+00, 0.59274200E+01, -.74623300E+00, 0.34015400E-01, 0.81938000E+02, 0.77026400E+02, -.86774900E+02, -.93779200E+01, 0.32282900E+02, 0.81073400E+02, 0.16262100E+00, -.48057400E+00, 0.31682300E+00, -.70756400E+00, -.31154000E-01, 0.15936100E+01, -.34835000E+00, -.27678200E-01, -.12190000E+00, 0.90571600E+00, -.56289200E+00, 0.13818300E+01, -.96400700E-01, -.31360300E+01, 0.48597900E+00, 0.48566900E-01, -.47799600E+00, 0.23832700E+00, 0.64029100E+01, -.10073700E+02, 0.28896700E+00, -.32934700E+01, -.36915200E+00, -.34364100E+00, -.25310100E+00, 0.24632600E+00, 0.16715100E+01, -.29784100E+01, 0.16187400E+01, -.40281800E+00, -.63725300E+01, -.26218700E+01, -.60061900E+00, -.61258700E+00, 0.12872600E+00, 0.13885900E+00, -.71187700E+00, 0.11486400E+02, 0.19522000E+01, -.10955500E+02, -.26231600E+00, 0.51820100E+00 }, { 0.20694200E+01, 0.83885600E+00, -.34547800E+01, 0.33461000E+00, -.70834200E+00, -.68838100E+01, -.68386200E+01, 0.13582900E+01, -.11152900E+01, 0.20649300E+01, -.37779800E-01, -.12701100E+01, 0.28304100E+01, -.14321500E+02, 0.23034200E+01, 0.81122200E+01, 0.44973300E+01, 0.28414600E+01, 0.11162100E-01, -.23454100E+01, 0.81913000E+00, 0.37851600E+00, -.99991500E+00, -.94434600E-03, 0.40113200E-01, 0.14011200E-01, 0.33383400E+00, 0.27026600E+00, -.94367900E+00, -.20186500E+00, -.29222700E+01, -.57183200E+00, 0.10066900E+01, 0.49985900E+00, 0.78587400E+01, -.11215700E+01, 0.14282100E-01, -.15734400E+00, 0.42597000E+00, 0.14945600E+00, -.18329500E+00, -.12025100E+00, -.28337600E+01, 0.60318700E+00, -.33616900E+00, 0.28387300E+01, -.30131100E+00, -.17674400E+01, -.15044000E+00, 0.10828600E+00, -.28703900E+00, 0.11721500E+00, 0.12155700E+01, -.12415400E+00, -.29130000E+01, 0.84962700E+00, 0.23062900E+00, -.16685600E+01, 0.96933200E+00, 0.16130200E+01, -.13462200E+01, 0.27267800E+00, 0.72325200E+00, 0.37472500E+00, -.11599200E+01, 0.24510700E-01, 0.16107000E+00, -.12102200E+00, 0.23934300E-01, -.60932600E-01, -.14813500E+01, 0.13259000E+00, 0.76201700E-01, -.45870200E+00, 0.22869200E+00, 0.46509200E+00, 0.16107500E+01, -.33264600E+00, 0.29434100E+01, -.12574100E+01, 0.47546300E+00, 0.98127800E-01, 0.42164400E+00, 0.40281700E+00, -.72601900E+00, 0.87967000E+00, -.26986100E+00, -.52046200E+00, -.17847300E+00, 0.15979300E+01, -.22385800E+01, 0.45128800E+00, 0.72140700E-01, 0.49226600E-01, 0.11976600E+01, -.22711300E+01, -.54503000E+00, 0.44911400E-01, -.42226000E+00, -.17368200E+01, -.38016500E+00, -.78637500E+00, 0.19354400E-02, -.50259400E+00, 0.74991600E-02, -.20763000E+00, -.17475700E+00, 0.34131700E-01, -.12802600E+00, 0.11858800E+01, 0.54216400E-01, 0.85051800E+00, -.13253800E+00, 0.67898700E+00, -.10032600E+01, 0.26943700E+00, -.11460800E+00, -.11030800E+00, 0.39898200E+00, -.26653200E+00, -.27387900E+00, 0.54825600E-01, 0.23982500E-01, -.25453600E+00, -.25657400E+00, -.32550700E+00, 0.72118000E+00, -.16284700E+00, -.19779100E+01, 0.46334700E+00, -.80079300E+00, 0.32707400E+00, 0.22154000E+02, 0.42613200E+00, -.59844800E+00, 0.75095400E+00, -.50765700E-01, 0.63492900E-01, -.14520300E+00, 0.34126700E+00, -.11778500E+01, -.89056800E-01, -.14571900E+01, 0.99499000E+00, -.50216100E-01, 0.66145700E-01, -.14316900E+00, 0.34149000E+00, -.11526200E+01, -.92338500E-01, -.14168500E+01, 0.99634200E+00, -.49834600E-01, 0.78290600E-01, 0.80649600E+00, -.10915100E+01, -.43140700E+00, -.16905700E+00, 0.52973800E-01, 0.46963500E+00, 0.71336300E-01, -.41988400E+00, 0.21561100E+00, 0.49156600E+00, 0.51733100E-01, 0.16630000E+01, -.26045900E+00, -.23377400E+00, 0.26146900E+00, 0.10483400E+00, -.19490900E+00, -.27287900E+00, -.30401800E+00, 0.23474600E+00, 0.27661400E+00, -.33641100E-01, 0.35593400E+00, 0.66384400E+00, 0.46719100E-01, -.77193900E+01, 0.82079700E+01, 0.17514700E+01, -.94412400E+00, -.97842800E+01, 0.24092100E-01, 0.28342500E+00, -.18029400E+00, 0.27767200E-01, -.91179600E-01, -.15243000E+00, -.13204300E-01, -.65106300E-02, -.86000500E-01, -.55591400E+00, 0.36371500E+00, -.63522800E-01, 0.20581300E+00, 0.30497900E+00, 0.47323000E-01, 0.16903400E-03, -.65867900E-02, -.54812200E-01, -.92260800E+00, 0.12279500E+01, -.38252400E-01, 0.81741200E+00, 0.70895300E+00, 0.26341400E-01, -.71695100E+00, -.34903400E-01, -.28987900E+00, 0.48281700E+00, -.13015300E+00, 0.19039900E+00, 0.10526100E+01, 0.11307500E+00, 0.49589200E+00, -.82865400E-01, -.17514200E-01, -.32770000E-01, 0.38520300E+00, -.12850800E+01, -.50787800E+00, 0.13488300E+01, 0.47568600E-01, -.22166600E-01 }, { 0.25340300E+01, 0.67092200E+00, -.30445800E+01, -.14051700E+01, -.14211000E+01, -.17315500E+01, 0.52906300E+01, 0.17220500E+01, -.33876600E+00, 0.11654700E+01, -.43951000E+00, -.29534100E+01, -.29384300E+00, -.58861400E+01, 0.79926000E+00, -.15638000E+01, 0.62510800E+00, 0.83398600E+00, -.63089300E+00, 0.99473100E+00, -.82915800E+00, -.57833000E-01, -.29942500E+01, 0.13677100E+01, -.34274500E-01, 0.96413800E+00, 0.18142600E+01, 0.77463600E+00, -.44183300E+00, 0.14205400E+01, 0.10694800E+02, -.19549300E+01, 0.38972400E-01, -.10295100E+01, -.90988100E+01, -.15693400E+01, 0.47773700E+00, 0.31635400E+00, -.10668300E+01, -.17829700E+00, -.48943600E+00, 0.53642900E+00, -.19422100E+01, -.52124700E+00, -.11439400E+01, 0.27313000E+01, -.33592700E+00, -.17588400E+01, 0.31225300E-02, 0.11959700E-01, -.45552700E+00, -.23763900E+00, 0.24848300E+00, 0.38583400E+00, 0.87299800E+01, -.34879300E+00, 0.11964300E+00, 0.38770800E+01, 0.84030500E+00, -.15739500E+01, -.60651200E+00, -.27112400E+00, -.26639800E+00, -.97687600E+00, 0.13420600E+00, 0.48387200E-02, 0.10597400E+00, 0.53932500E+00, -.50622400E-01, 0.47613200E-01, -.63547600E+00, -.88808500E-01, 0.96586100E+00, -.12641700E+00, 0.17905500E+00, -.49207300E+00, -.24018200E+01, 0.10015200E+01, -.48008100E+00, 0.56374400E+00, 0.18258400E+01, -.68993800E+00, -.15087200E+01, -.17756800E+00, 0.49244900E+00, -.36905500E+00, 0.20910200E+00, 0.35427500E+00, 0.22651100E+00, 0.43726700E+01, -.24904700E+00, -.29073800E+00, 0.30666400E+00, 0.21599600E+00, -.50911500E+01, 0.24663800E+01, 0.27525000E+01, 0.38036100E+00, -.31633600E+00, -.75461000E+01, 0.73295900E+00, 0.21687400E+01, 0.23685600E+00, 0.64954200E+00, -.35011300E+00, -.55829800E+00, 0.15848300E+00, -.17937100E+00, 0.20367900E+01, 0.20725400E+01, -.12742600E+01, 0.40692300E+00, 0.14979600E+01, 0.26895500E+01, 0.96441800E+00, -.10701200E+01, -.25002900E+00, -.31692600E+00, -.12246000E+01, 0.50271900E+00, -.56714000E+00, 0.16006600E+01, -.42306800E+00, 0.29350900E+00, -.22660500E+00, -.17697400E+00, 0.10111400E+01, -.10064400E-02, -.46745400E+01, -.25507800E+00, 0.48708200E-01, 0.39478900E+00, -.77102800E+00, -.65571600E+00, -.12653900E+01, -.38497300E+00, -.10955100E+00, 0.21211800E+00, -.48767200E+00, 0.86149300E-01, 0.33883400E+00, 0.10083100E+00, 0.84019500E+00, 0.59394100E+00, -.10762600E+00, 0.20805100E+00, -.48327900E+00, 0.93990100E-01, 0.31278200E+00, 0.95766100E-01, 0.79800500E+00, 0.63737300E+00, -.25021600E+00, -.43133900E+00, -.11764700E+01, -.21544500E+00, 0.46465200E+00, 0.77525600E-01, 0.67930500E+00, -.13630900E+01, -.32529700E+00, -.15678100E+01, -.51789900E+00, 0.20145000E+00, 0.14624800E+01, 0.15377200E+01, 0.11089300E+01, 0.53949900E+00, 0.12065800E+00, 0.71787200E+00, -.15212400E+01, -.13496700E+01, 0.80465000E+00, 0.15286200E+00, -.29489900E+00, -.22079800E+01, 0.17985700E+00, -.15250600E+00, -.27006400E+00, 0.16636600E+00, 0.51088900E+01, 0.40713400E+01, 0.81994300E+01, 0.20611800E+01, -.31433100E+00, 0.16413500E+00, 0.15192900E+00, 0.34604500E-01, -.36886700E-01, -.15524400E+00, -.97710300E-01, 0.14655300E-01, 0.66820600E+00, -.36238900E+00, -.30361500E+00, -.55050300E-01, 0.64559600E-01, 0.31085900E+00, 0.15290900E+00, -.97309100E-02, 0.39110000E+00, -.49221000E-02, -.22267100E+01, 0.17710700E+00, 0.18276600E-02, -.70392900E+00, -.28224400E+00, -.26906800E-02, 0.44305000E+00, 0.18387800E-02, 0.96953400E+00, -.61125400E+00, -.88893100E+00, -.65523500E+00, 0.19882800E+01, -.42172000E+01, -.14214200E+00, 0.60459100E+00, 0.77411900E-02, -.96420600E-03, 0.45352500E-01, -.61560400E+00, 0.14232700E+01, -.16208100E+01, 0.21404400E-02, -.21006000E-01 }, { -.45368300E+01, -.16386400E+01, 0.35772300E+01, 0.21075900E+01, 0.18827500E+01, 0.10139300E+02, 0.75204700E+01, -.33306100E+01, 0.15019500E+01, -.10355400E+01, -.34053200E+00, 0.10740300E+01, -.27040600E+01, 0.15818100E+02, -.33495100E+01, -.10629900E+02, -.61789100E+01, -.55220300E+01, -.92048000E+00, 0.22598600E+01, -.17218400E+00, -.35851600E+00, 0.41870100E+00, 0.13613300E+01, -.20706000E+00, 0.79253400E+00, -.13805700E+01, -.40828600E+00, 0.39920300E+01, 0.46828600E+00, 0.10411200E+02, -.62272400E+00, -.25106300E+01, -.14960900E+00, -.45705800E+01, 0.14701300E+01, 0.21857100E+00, 0.17353900E+01, 0.18732700E+01, -.40080200E+00, 0.15830500E+01, 0.16570500E+01, -.47873700E+01, 0.11747400E+01, -.30021600E+00, -.53288800E+01, 0.80777900E+00, 0.76072600E+01, 0.12061600E+00, -.77728500E-01, 0.53836000E+00, 0.16837000E+00, -.16175300E+01, -.25702200E+00, 0.17748200E+02, -.46925100E+00, -.44475200E+00, 0.13138300E+01, -.68704100E+00, -.12092700E+01, 0.66317100E-01, -.65670300E+00, 0.19673400E+00, 0.13257100E+01, 0.37195400E+00, -.24184600E+00, 0.18526900E+00, -.88966900E-01, -.11733200E+01, 0.20166200E+00, -.17375700E+01, -.17690400E+01, -.56903200E+00, 0.72605300E+00, -.87758500E-01, 0.12647700E+00, -.60982900E+00, 0.19481200E+00, -.35179700E+00, -.12900900E+01, -.15423000E+01, -.93130600E-01, 0.41019500E-01, 0.81681900E-02, 0.24005700E+00, -.20167000E+01, -.14424900E+00, 0.17196400E+01, -.24095900E+00, 0.53031200E+00, 0.54992500E+00, -.43628200E+00, -.34201900E-01, -.13519400E+01, -.15675400E+01, 0.18839500E+01, -.23042300E+01, -.16653400E+00, -.29624600E+00, 0.82888500E+00, -.92705000E+00, -.13000300E+01, -.48298600E+00, -.12861300E+00, 0.14238000E+00, 0.72347200E-01, 0.19370800E+00, -.25794100E+00, 0.16998200E+01, 0.23191700E-01, 0.53690400E+00, -.66766800E+00, 0.19675300E+00, -.43221400E-01, 0.11359700E+01, -.41755100E+00, -.21508800E+00, 0.17385500E+00, -.88900400E+00, 0.41705400E+00, -.91246500E-01, -.68658500E-01, -.70109100E-01, 0.30311800E+00, 0.37450700E+00, 0.87012600E-01, 0.10255600E+01, -.12240300E-01, 0.18255400E+01, -.64282400E+00, -.53953000E+00, -.25028700E+00, -.10051000E+02, -.91044800E+00, 0.58851300E+00, -.40146700E+00, 0.13489300E+00, -.26222200E-01, -.20515000E+00, -.17838600E+00, -.27051000E+00, 0.29795000E+00, -.12362600E+01, -.21951100E+00, 0.13124300E+00, -.24239100E-01, -.19681900E+00, -.16950000E+00, -.25908500E+00, 0.29150800E+00, -.12235200E+01, -.19806000E+00, 0.70838400E-01, -.11590600E+00, -.81328200E+00, 0.97377800E+00, 0.42847500E+00, 0.11423200E+00, -.18841700E+00, 0.74947500E+00, -.79319700E+00, 0.60366000E-01, -.16468200E+01, -.96976600E-01, -.26072500E+00, 0.35072600E+00, -.30618800E+00, 0.18294300E+00, 0.25805400E+00, -.69787400E+00, 0.51239600E-01, 0.14043100E+01, -.21105000E+01, 0.62523000E+00, 0.40932100E+00, 0.26441100E+01, 0.65850900E+00, -.76536900E-01, -.22988400E-01, 0.11854900E+00, -.57736500E+00, 0.10494500E+02, 0.10298400E+02, 0.25628300E+01, 0.33868100E+00, 0.16475700E+01, -.30895100E+00, -.11899300E+00, -.19307100E+00, -.38891100E+00, 0.73612000E-01, -.19031200E-01, -.67956300E+00, -.33662800E+01, 0.55776100E+00, 0.17620800E+00, 0.44212500E+00, 0.84262500E+00, -.50415800E-01, -.28505200E-01, -.53668400E+00, -.39669100E+00, -.10759100E+01, 0.51548400E+01, -.30493800E+00, 0.94856000E-01, 0.21344900E+01, 0.24150200E+00, -.22564700E+01, -.27321300E+00, 0.96185700E+00, 0.17163900E+01, -.51039000E+00, -.59596700E-01, 0.11919600E+01, -.24357200E+01, 0.12258300E+01, 0.58421800E+00, -.15530100E+00, -.24219700E+00, 0.48956800E+00, -.64151400E+01, -.15412500E+01, -.81422400E+00, 0.35323700E+00, -.22593300E+00 }, { 0.47326700E+00, 0.19683200E+00, -.86564800E+00, -.36589500E+00, -.32689300E+00, -.19897100E+01, -.15170000E+01, 0.57805400E+00, -.53238400E-01, 0.12969800E+00, -.15443700E-01, -.26858200E+00, 0.16081500E+00, -.14035500E+01, 0.26484500E+00, 0.60107700E+00, 0.54077300E+00, 0.23178100E+00, 0.69747200E-01, -.86091700E-01, -.46284200E-02, 0.82388000E-02, -.13996500E+00, -.13710200E+00, -.66342200E-02, -.39881600E-01, 0.23405500E+00, 0.79781300E-01, -.19135500E-01, 0.10910500E-02, 0.17220400E+00, -.77716900E-01, 0.14564300E+00, -.15107000E-01, 0.46716000E+00, -.14936000E+00, 0.32921500E-01, -.12328100E+00, 0.93315900E-01, 0.10045900E-01, -.38669300E-01, -.79840500E-01, -.20690600E+00, -.46503000E-01, 0.11692200E-01, 0.23043700E+00, -.70175800E-01, -.23735200E+00, 0.52214100E-02, 0.16433900E-02, 0.30800100E-01, -.72426600E-02, -.38761400E-01, 0.24324600E-02, -.91881700E+00, -.36154600E-01, -.17602200E-01, 0.88187500E-01, 0.13302900E-01, -.10189400E+00, 0.49983700E-01, 0.20538500E-01, -.13415800E+00, -.40042200E+00, 0.77416000E-01, 0.26640200E-01, -.14392800E-01, 0.16490600E+00, 0.11440100E+00, -.25183800E-01, 0.27947200E+00, 0.16606700E+00, 0.61632000E-01, -.47026100E-01, 0.35789900E-01, -.23971500E-01, 0.33331400E-01, -.32237900E-02, 0.29406800E-02, 0.62836300E-01, 0.46229200E-01, 0.17566600E-01, -.88325900E-02, -.12534300E-01, -.38289700E-01, -.14864900E-01, 0.40101300E-01, -.39856800E-01, 0.73273700E-02, -.33701200E-01, -.11922600E+00, 0.27236000E-01, 0.19821600E-02, 0.30416400E-01, -.31679100E+00, -.87747900E-01, 0.29818200E+00, 0.27077800E-02, 0.19774200E-02, -.27149900E+00, 0.55215600E-01, 0.88295300E-01, 0.19673700E-01, 0.16592400E-01, -.99196200E-02, -.31790500E-01, 0.35088400E-01, 0.18621000E-02, 0.12914700E+00, -.88666400E-01, 0.26254700E-01, 0.40695400E-01, 0.10389700E+00, 0.10725200E+00, 0.50827900E-01, 0.15465800E-02, 0.26318700E-01, 0.69676800E-01, -.22482100E-01, 0.29618500E-01, 0.67347200E-01, -.44782900E-01, 0.33249400E-01, -.18327000E-01, 0.83640300E-01, 0.96319200E-02, 0.71088600E-01, -.12291100E-01, 0.14915100E+00, -.41423700E-01, -.22638900E-01, -.14342000E-01, -.19035500E+00, -.32236300E-01, 0.50622100E-01, -.38313400E-02, -.58674500E-02, -.17435000E-03, 0.15937700E-01, 0.47430700E-02, -.94817300E-03, -.66122400E-02, -.44235400E-01, 0.78076600E-02, -.57943400E-02, -.15754000E-03, 0.15632900E-01, 0.49649700E-02, -.10507200E-02, -.64944300E-02, -.44011600E-01, 0.87245900E-02, 0.14372200E-02, 0.50594900E-02, 0.63221200E-03, 0.26802300E-02, 0.26354400E-01, -.38929300E-02, 0.38809000E-02, 0.24690000E-01, -.93911100E-02, -.23666100E-02, 0.10715200E-02, -.34870200E-03, 0.37588500E-01, 0.88910700E-02, 0.46946000E-01, 0.18548900E-01, -.23090900E-01, 0.23710800E-01, 0.22942800E-01, 0.24993200E-01, 0.43433300E-01, -.34285400E-01, 0.11379800E-01, 0.55426300E+00, 0.12747100E+00, 0.17076700E+00, -.42675100E-02, 0.18287700E+00, -.13430800E+00, 0.12957900E+00, 0.33202500E+01, 0.48633600E-01, 0.45396300E-01, -.18654200E+00, 0.47333500E-02, 0.37499600E-01, -.43034700E-01, 0.88784300E-01, -.15704500E+00, 0.69286800E-01, -.58030800E-01, 0.36259100E+00, -.14918400E-01, -.62583900E-01, 0.67083800E-01, -.18144500E+00, 0.27781100E+00, -.12267600E+00, -.10555100E+00, 0.12746200E+00, -.60813000E+00, 0.26773300E+00, 0.13505800E+00, 0.16011000E+00, 0.72335100E-01, -.14461300E+00, -.44294200E-01, 0.11821900E+00, -.29633700E+00, -.65299100E-01, 0.34097000E+00, 0.18551400E+00, 0.62351200E+00, 0.26476300E+00, 0.16579400E+00, -.31323700E+00, 0.69093800E-01, 0.78275000E-01, 0.20801900E+00, -.41978200E+00, 0.91741700E+00, 0.17039700E+00, -.13107800E+00, 0.16979500E+00 }, { 0.26962300E+01, 0.10851300E+01, -.41313800E+01, -.12230400E+01, -.11471300E+01, -.91372700E+01, -.90146300E+01, 0.14815200E+01, -.89199000E+00, 0.15003700E+01, -.19181000E-01, 0.53976300E+00, 0.35360600E+01, -.11975000E+02, -.45136300E+00, 0.74490600E+01, 0.46287900E+01, 0.82635300E+00, -.16925100E+01, -.10724500E+01, -.44718900E+00, 0.92356600E+00, 0.44636300E+00, -.61995000E+00, 0.25591400E+00, -.18799200E+00, 0.88289500E+00, 0.24596100E+00, -.15394900E+01, -.54216500E+00, -.39245300E+01, -.25831700E+00, 0.13701600E+01, 0.59192200E+00, 0.17080200E+02, -.86721200E+00, 0.14957500E+00, -.20127400E+00, 0.19840200E+01, 0.40000700E+00, -.32604500E+00, -.10472300E+01, -.31883000E+01, -.14242000E+00, -.35554100E+00, 0.31963500E+01, -.95173100E+00, 0.18574500E+01, -.19997400E-01, -.40716400E-01, 0.21462600E+00, 0.24981700E+00, 0.10124800E-01, -.22812500E+00, -.92119200E+01, 0.35783200E+00, -.76845100E-01, -.73237600E+00, -.17880100E+00, 0.22460400E+00, -.11634800E+01, 0.93456600E-01, 0.53373600E+00, 0.80459200E+00, -.63789600E+00, 0.69833700E-02, 0.30116700E-01, -.31584000E+00, 0.12304200E+00, -.47079000E-01, 0.40511000E+01, 0.36964800E-02, -.19767600E-01, -.58143600E+00, 0.47290200E+00, 0.37761400E+00, -.10772700E+01, 0.63116300E+00, 0.36350400E+00, -.20793000E+01, 0.45895900E+00, -.16754700E+00, 0.10114200E+00, 0.24639800E+00, -.16546600E+00, -.26461100E+00, -.12617500E+00, 0.23158800E-01, 0.28504800E+00, -.14149700E+01, -.83724100E+00, -.75842200E-01, 0.78298600E+00, -.76637400E+00, -.17875900E+01, 0.61189300E+00, -.93808500E+00, -.25642500E+00, 0.10417900E+00, -.12776200E+01, 0.10592100E+01, 0.11695300E+00, 0.16307300E-01, -.77299200E-01, 0.90360100E-01, 0.37843000E+00, -.45765800E+00, 0.27399300E-02, -.54178800E+00, -.29824700E+00, -.71935500E+00, 0.26514200E+00, 0.28954400E+00, 0.66740300E+00, 0.39198600E+00, -.57418700E+00, 0.40833100E+00, -.79343100E+00, 0.50614700E-01, -.58790300E+00, -.30504500E+00, -.68645800E+00, -.50244900E+00, 0.48127900E+00, -.91686800E+00, 0.43816600E+00, -.23831300E+00, -.14290400E+00, 0.12996200E+01, 0.10457100E+01, -.19669600E+01, 0.25381400E+00, 0.18190600E+02, -.19226100E+00, -.32922900E+00, 0.83634900E+00, 0.36307100E-01, 0.81839400E-01, -.32691500E-01, 0.76200000E-01, -.10883700E+01, -.66942600E-01, -.82427000E+00, -.14462800E+00, 0.36524400E-01, 0.83796600E-01, -.27344900E-01, 0.75641200E-01, -.10687800E+01, -.67885000E-01, -.80034900E+00, -.15139300E+00, 0.96029000E-01, 0.17515300E+00, 0.12154300E+01, -.10747500E+01, -.42106200E+00, -.37830300E+00, -.94301800E-01, -.15714600E+00, 0.36538800E+00, -.83861000E-01, -.74929800E-01, 0.11280300E+00, 0.15069400E+00, 0.14581800E+01, -.11918300E+00, -.14548500E+00, 0.23590500E+00, 0.22045000E+00, -.69248100E+00, -.43215600E+00, -.73242200E+00, 0.15235700E+00, 0.26910400E+00, -.65725900E+00, 0.35709300E+00, 0.10231100E+01, -.66109900E-02, -.91206700E-02, 0.90464900E-01, 0.23041600E-02, -.20929800E+00, -.25815200E+01, 0.26679200E-01, -.27828300E-01, -.43804300E-01, -.20665800E-01, -.68885800E-02, 0.37757600E-01, -.95194000E-02, 0.11661900E-01, -.66563600E-01, 0.61712800E-01, 0.84515400E-01, 0.38953200E-01, 0.16954100E-01, -.74985800E-01, 0.22446400E-01, -.25574500E-01, -.17579900E-01, 0.16748500E-01, 0.51598500E+00, 0.19919200E+00, 0.20041700E-01, 0.23248600E+00, 0.19842900E+00, -.23963900E-01, -.20283200E+00, 0.16810300E-01, -.27602200E+00, 0.17133300E+00, 0.25800800E+00, 0.15515100E+00, -.36527200E+00, 0.90065400E+00, 0.28707000E-01, -.23584300E+00, 0.96764700E-02, 0.98566700E-02, 0.65165800E-01, -.34247200E+00, -.12672300E+00, 0.63310300E+00, -.18317700E-01, 0.35344700E-01 }, { 0.13918500E+01, 0.46880900E+00, -.11642800E+01, -.57546900E+00, -.41754000E+00, -.30612200E+01, -.27763700E+01, 0.86130700E+00, -.37402800E+00, 0.54150300E+00, 0.40262900E-01, -.13466100E+00, 0.87967800E+00, -.46636000E+01, 0.64958100E+00, 0.33118700E+01, 0.18269300E+01, 0.13781600E+01, 0.20839200E+00, -.73245300E+00, 0.13292000E+00, 0.11891100E+00, -.62225200E-01, -.51154200E+00, 0.39844300E-01, -.16071000E+00, 0.51293600E+00, 0.17243800E+00, -.91131400E+00, -.10266300E+00, -.18960600E+01, 0.75076400E-02, 0.60419300E+00, 0.13886800E+00, 0.28711000E+01, -.41321800E+00, -.47779200E-02, -.18799600E+00, -.17565300E+00, 0.92782300E-01, -.25192000E+00, -.17145800E+00, -.81853100E+00, -.39926100E-01, -.86734300E-01, 0.14238500E+01, -.26547500E+00, -.12303100E+01, -.27082000E-01, 0.37711700E-01, -.80155500E-01, -.44068800E-01, 0.32160000E+00, 0.20893900E-01, -.37403600E+01, 0.10280300E+00, 0.62596400E-01, -.11803400E+00, 0.19667100E+00, 0.12251600E+00, -.29885200E+00, 0.65549100E-01, -.54149300E-01, -.75731400E+00, -.20817800E+00, 0.72301300E-01, -.25054500E-01, 0.30274500E+00, 0.32865500E+00, -.46181100E-01, 0.81471100E+00, 0.45780000E+00, 0.19646700E+00, -.20181600E+00, 0.61781600E-01, -.28025300E-01, 0.15661500E-01, 0.43224800E-01, 0.96775400E-01, 0.19321100E-01, 0.20934100E+00, 0.63379200E-01, 0.13917400E-01, -.17180500E-01, -.93474600E-01, 0.34060100E+00, 0.80729700E-01, -.27453400E+00, 0.48834900E-01, -.38905000E+00, -.11527400E-01, 0.36278000E-01, 0.34692700E-01, 0.11479300E+00, -.12318600E+00, -.10866700E+00, 0.38641000E+00, -.26461500E-01, 0.57055700E-01, 0.25010700E+00, 0.21264900E+00, 0.45652100E+00, 0.60439200E-01, 0.79045500E-01, -.24135900E-01, 0.19556200E-02, 0.57092900E-01, -.94002100E-02, -.89139500E-01, -.22851500E+00, -.14781000E+00, 0.12130200E-02, -.50799600E-01, 0.48495000E-01, 0.92890900E-01, 0.85038600E-02, 0.80430100E-01, -.50807000E-01, 0.15016000E-01, -.56832200E-01, 0.63729500E-02, -.19598500E+00, 0.27441600E-01, -.25848900E-01, 0.77499700E-01, 0.72477800E-01, -.17172000E+00, 0.73599800E-02, 0.13379100E+00, 0.10465400E+00, -.13619800E-01, -.77970900E-02, 0.12511500E+00, -.30423400E+00, -.60753800E-01, -.20157800E-01, -.76551600E-02, 0.12870300E-01, 0.30917700E-01, 0.14910500E-01, 0.40262200E-01, -.22613000E-01, 0.10565300E+00, -.16267200E-01, -.72010200E-02, 0.12582500E-01, 0.30966800E-01, 0.14709600E-01, 0.38146500E-01, -.21674800E-01, 0.10389300E+00, -.16626500E-01, 0.19506800E-01, 0.25774100E-02, 0.63991600E-01, 0.76793100E-02, -.11483300E-01, -.12354000E-02, 0.49196100E-01, -.69738200E-01, -.32811700E-01, -.65679900E-01, -.11763400E+00, -.63911300E-01, 0.10634100E+00, 0.77514300E-01, 0.33908100E-01, 0.72724800E-02, -.25700100E-01, 0.88452600E-01, -.68549100E-01, 0.35934000E-01, -.13806900E+00, -.54030000E-01, 0.30155600E-01, 0.84977200E-01, 0.38089400E-01, 0.25505500E-01, 0.61620700E-02, 0.15948500E-01, -.20280500E-01, 0.28706300E-03, 0.11232000E+00, -.15428500E-01, 0.22575800E+01, -.39860200E-01, -.44536200E-02, -.37071600E-02, -.14353500E-02, 0.10327500E-01, -.22013000E-02, -.60193700E-02, -.10284700E+00, 0.77466000E-01, 0.95166300E-02, 0.89613800E-02, 0.18820200E-02, -.21625100E-01, 0.22416000E-02, 0.13337800E-01, -.94585700E-01, 0.44017300E-02, 0.24612600E-01, -.45017000E-01, 0.17550600E-02, 0.17541900E-01, -.35020400E-01, -.28977200E-03, 0.40575400E-01, 0.17413400E-02, -.25065700E-01, 0.19229500E-01, 0.57540600E-01, 0.38457200E-01, -.34651900E-01, 0.14053600E-01, 0.28033000E-01, -.40150100E-01, -.56556800E-03, 0.22696300E-02, -.45906400E-02, 0.25516200E-01, 0.21797800E-01, 0.10415100E-01, -.31513000E-02, 0.12567500E-02 }, { -.43153300E+00, -.56873300E+00, 0.34219700E+00, -.22697300E-01, 0.11093100E+00, 0.33558300E+00, 0.16075800E+00, -.46259400E+00, 0.70122800E-01, 0.25004300E+00, -.69932400E-01, -.25115800E+00, -.39994300E-01, 0.40770900E-01, -.11886500E+00, -.78992600E+00, -.72235500E+00, -.24222700E+00, -.19088400E-01, 0.17783700E+00, 0.14962700E+00, -.13083900E+00, -.28722000E+00, 0.27676300E+00, -.49005800E-01, 0.11221400E+00, -.29936300E+00, -.10999200E+00, 0.15550300E+00, 0.78987800E-01, 0.38170200E+00, -.33223400E-01, -.11014900E+00, -.98542000E-01, -.10941400E+01, 0.27448500E-01, 0.51046300E-03, -.22921900E-01, -.26570400E+00, -.35982300E-01, -.36584200E-01, 0.20199600E+00, 0.19382800E+00, -.87788000E-01, -.87440400E-01, -.41043000E-01, 0.46504000E-01, -.12826800E+00, -.15793800E-03, 0.15022900E-01, -.48234400E-01, -.53296300E-01, 0.79206100E-01, 0.42939300E-01, 0.40927500E+00, -.45573900E-01, 0.34277600E-01, 0.96220500E-01, -.37339600E-01, -.11783200E+00, -.10685000E+00, -.62121500E-01, 0.32035900E-01, 0.98441800E-01, -.16683200E-01, -.14077900E-02, -.14670000E-01, -.39680100E-01, 0.69246700E-02, 0.53023100E-02, -.10630900E+00, -.22140800E-01, 0.17932300E-01, 0.85405000E-02, 0.62110500E-01, -.19243600E-01, -.98866600E-01, 0.62759900E-01, -.14303100E+00, 0.13584000E+00, 0.45424600E-01, -.52881600E-01, -.12108900E+00, -.19457600E-01, 0.10916800E+00, -.46874900E-01, -.26204100E-01, 0.91474900E-02, 0.14259600E-01, 0.68863300E+00, -.43916300E-01, -.12321300E-01, -.68490200E-02, -.48000800E-01, 0.21490600E+00, 0.13241700E+00, -.22274700E+00, 0.35475600E-03, -.45472800E-03, 0.65423600E-01, -.47058900E-01, -.55548100E-01, -.22892800E-01, -.14093300E-02, 0.42036600E-02, -.18649300E-01, 0.22127100E-01, -.19927700E-01, -.21379800E-01, -.28690400E-01, 0.48747100E-01, -.11895700E-01, -.25975500E-01, -.64923400E-01, -.34975100E-01, 0.64603400E-02, -.10339600E-01, -.96687800E-02, 0.94662900E-02, -.39312200E-02, 0.22501700E-01, 0.66951900E-01, -.30236100E-01, 0.46915500E-01, -.16707500E+00, -.10314400E-01, -.22482300E-01, 0.99194500E-02, 0.62920500E-01, 0.27820600E-01, -.49552400E-01, 0.13667700E-02, 0.61641400E+00, 0.12840000E+00, -.34665600E-01, 0.54586900E-02, 0.46604400E-02, -.10793300E-01, -.60470300E-02, -.78793600E-02, 0.16489600E-01, -.14181400E-01, 0.83632000E-01, -.37256500E-01, 0.45444300E-02, -.10762400E-01, -.56060100E-02, -.80050900E-02, 0.16189700E-01, -.13935100E-01, 0.82025000E-01, -.37935400E-01, -.61760100E-02, -.36009400E-02, 0.10384400E-01, 0.55739900E-01, -.16313800E-01, -.19655000E-01, 0.19579400E-01, 0.19061900E-01, 0.32993000E-01, 0.23687000E-01, 0.93825000E-01, 0.36813900E-01, 0.47410100E-02, -.22820000E-01, 0.63755400E-02, 0.16365000E-01, 0.15787600E-01, -.12492800E-01, -.58235200E-01, -.85414200E-01, 0.13966100E-01, 0.49552900E-02, -.66365600E-02, -.13904900E+00, -.17653300E-02, 0.11762500E-01, -.11495600E-01, -.95186300E-02, 0.17943600E-01, -.12818000E-01, -.50928000E-01, 0.99088800E-02, -.75194100E-02, 0.28600600E+01, 0.56438500E-02, 0.78102200E-03, 0.24036900E-02, 0.42868700E-02, -.78194200E-03, 0.23614600E-02, 0.32505100E-01, -.93026800E-01, -.12115900E-01, -.30348600E-02, -.46194500E-02, -.81030700E-02, 0.28485100E-02, -.58323800E-02, 0.30897800E-01, -.81780300E-02, 0.74173300E-01, 0.26790400E-01, -.48264100E-02, -.32588700E-01, 0.81493100E-02, 0.26541400E-02, 0.10680000E-01, -.44371900E-02, 0.33979400E-01, -.62823300E-02, -.28674700E-01, -.17812600E-01, -.67316000E-01, -.80204100E-02, -.11233700E-01, 0.34449300E-01, -.19577300E-02, -.48897700E-02, -.29623300E-01, -.26194900E-01, 0.42658600E-01, -.67736400E-03, 0.65467800E-02, -.20792100E-02 }, { -.17540000E+00, -.72619900E-01, 0.31705700E+00, -.32722700E-01, 0.68488300E-01, 0.60237500E+00, 0.51603400E+00, -.27245000E+00, 0.90270200E-01, -.18308800E+00, 0.37682100E-02, 0.10662900E+00, -.21377900E+00, 0.11975000E+01, -.18677300E+00, -.71982400E+00, -.34663100E+00, -.28312300E+00, -.40243300E-01, 0.15714700E+00, -.67838700E-01, -.13453500E-02, 0.11020800E+00, 0.56823100E-01, 0.36170400E-02, 0.13892100E-01, -.70126400E-01, -.27748700E-01, 0.88352200E-01, 0.17025600E-02, 0.30763200E-01, 0.39740000E-01, -.75321400E-01, -.20164300E-01, -.21730600E+00, 0.76215200E-01, 0.21108700E-02, 0.16306900E-01, -.61149800E-01, -.63743800E-02, 0.46502900E-02, 0.76246300E-01, 0.53259200E-01, 0.15436500E-01, -.32230300E-01, -.11477500E+00, 0.24864200E-01, 0.13236300E+00, 0.16823600E-02, -.19350900E-02, -.27883700E-02, 0.30574300E-02, -.16976500E-01, 0.27408500E-02, 0.49045700E+00, -.22587200E-02, -.16190800E-02, 0.32258700E-01, -.27133500E-01, 0.30617400E-01, 0.38419000E-01, -.13545200E-01, 0.15488800E-01, 0.17835100E+00, 0.42118300E-01, -.15647800E-01, -.44193000E-02, -.75562500E-01, -.56754200E-01, 0.11255900E-01, -.62295300E-02, -.93775900E-01, -.29403300E-01, 0.22380500E-01, -.18613200E-01, 0.39434600E-02, -.71089100E-01, 0.22208000E-01, -.58775600E-01, 0.79909500E-01, 0.44501900E-02, -.25648600E-01, -.32912500E-01, -.68778200E-02, 0.31823100E-01, -.84839800E-01, -.33001400E-02, 0.58953400E-01, 0.12330600E-02, -.11484800E+00, 0.60513300E-01, -.28416100E-01, 0.74822300E-02, -.44930600E-01, -.17167200E+00, 0.13375300E+00, -.36002300E-01, -.50878200E-02, -.41963700E-02, 0.52451400E-01, 0.14689300E-01, -.17642000E-01, 0.31341200E-02, 0.21970400E-02, 0.44466400E-02, 0.40848400E-02, -.18949200E-01, -.17888100E-01, -.11048600E+00, 0.33882600E-01, 0.12121500E-01, 0.25549900E-02, -.26096400E-01, -.24652300E-01, 0.50569000E-02, -.94846600E-02, 0.48612500E-02, -.34315300E-01, -.11404400E-01, -.89702700E-02, -.11080200E-01, 0.28506600E-01, -.24020900E-01, 0.19225400E-01, -.37937300E-01, -.15576900E-02, 0.77421500E-02, 0.51658100E-03, 0.65290600E-01, 0.10783000E-01, -.23006800E-01, 0.17310200E-02, 0.33543500E+00, 0.13912600E-01, -.37380000E-01, -.34996700E-02, 0.13052100E-02, 0.12743600E-02, -.16202000E-01, -.18467100E-02, 0.12427500E-01, -.32856500E-03, 0.46167800E-01, -.70260500E-02, 0.13047900E-02, 0.12053100E-02, -.15946500E-01, -.18452500E-02, 0.12064300E-01, -.28408500E-03, 0.45294500E-01, -.69411100E-02, -.33537700E-03, -.35688000E-02, -.21268400E-01, 0.13901300E-01, -.16634300E-01, -.26199200E-02, 0.50293200E-02, -.10029600E-01, 0.17638300E-01, 0.18800700E-02, -.13087000E-02, -.43089900E-02, -.12923100E-01, 0.59438600E-02, -.14370100E-01, -.10703400E-02, 0.10951600E-01, -.74116300E-02, -.43433400E-01, -.15267000E-01, 0.35465200E-02, 0.70867700E-02, 0.23315000E-03, -.10393000E-01, -.54134800E-02, -.26922200E-02, -.58956300E-03, -.10400900E-01, 0.51349500E-02, -.90344200E-02, -.46612400E-01, 0.53212600E-02, -.25073300E-02, 0.20251500E-02, 0.53720200E+00, 0.26227800E-02, -.22327600E-02, -.10573700E-02, -.19391500E-03, 0.29644800E-02, 0.10905200E-01, -.11858800E-01, -.19255000E-01, -.48405500E-02, 0.41582100E-02, 0.19804800E-02, -.14559400E-03, -.55148700E-02, 0.86094600E-02, 0.38851600E-03, 0.12044100E-02, 0.78556200E-02, 0.69246600E-03, -.28728900E-01, -.32420700E-02, -.73498000E-03, -.20630400E-02, 0.67333500E-03, 0.19571500E-02, -.14287400E-01, -.30531300E-02, -.29352400E-02, -.25856100E-02, -.11380400E-01, -.27929500E-02, 0.25498300E-02, 0.51929700E-03, 0.29752600E-03, -.13296800E-01, -.99665600E-02, -.51295400E-03, 0.15319200E-02, -.54821600E-03, 0.61406900E-04 }, { -.22807100E+00, -.94785100E-01, 0.37882400E+00, 0.17534700E+00, 0.13253000E+00, 0.82833200E+00, 0.60316900E+00, -.38745900E+00, 0.48601500E-01, -.10453900E+00, 0.85338000E-02, 0.56318600E-01, -.21785500E+00, 0.10071500E+01, -.74104500E-01, -.53216400E+00, -.40879000E+00, -.10459100E+00, 0.39595500E-01, 0.83514900E-01, 0.27767700E-01, -.48646000E-01, -.36378500E-01, 0.94154000E-01, -.14458400E-01, 0.32625900E-01, -.10915100E+00, -.32014200E-01, -.57074500E-01, 0.26570200E-01, -.21898200E+00, 0.29919600E-01, -.54473500E-01, -.35261000E-01, -.94628400E+00, 0.58753600E-01, -.16951000E-01, 0.59310600E-01, -.19383100E+00, -.31576000E-01, -.13697800E-01, 0.91465400E-01, 0.75942400E-01, 0.78394600E-01, 0.77413000E-02, -.54611700E-01, 0.74092400E-01, -.26034000E+00, -.12980700E-01, 0.19463700E-01, -.45066200E-01, -.72344100E-02, 0.12134900E+00, 0.78837700E-02, 0.81169900E+00, 0.57244400E-01, 0.24631900E-01, -.70074800E-01, 0.94084300E-01, 0.12698300E+00, -.21903600E-01, -.53602300E-02, 0.36042500E-01, 0.12276500E+00, -.19250600E-01, -.82609100E-02, 0.88419300E-03, -.55091600E-01, -.36824100E-01, 0.64490300E-02, -.32730900E+00, -.51986000E-01, 0.33990500E-02, 0.65311900E-02, -.20947400E-01, -.23397700E-02, 0.63282500E-01, -.19799900E-01, 0.56890300E-01, 0.10572200E+00, -.47531200E-02, -.15551100E-01, -.84754400E-01, 0.49298100E-02, 0.26842200E-01, 0.29646500E-01, -.11855200E-01, 0.21751100E-02, -.96517600E-02, 0.14634900E+00, 0.15705800E-01, -.96118300E-02, -.12727900E-01, -.61808700E-02, -.11951200E-01, 0.57425700E-01, -.66077700E-01, -.53454700E-03, -.12894600E-01, 0.13729000E+00, -.12728400E-01, -.20424300E-01, 0.57212600E-02, -.94043000E-02, -.29408600E-02, -.17280300E-01, -.12923700E-01, -.23783100E-01, -.84271200E-01, 0.73914200E-01, 0.16537700E-02, 0.12255000E-01, -.49614600E-01, -.29445700E-01, -.11151400E-01, 0.14915300E-02, -.24968600E-02, -.27476800E-01, 0.20991600E-01, -.16644000E-02, -.31894100E-01, 0.12552400E-01, 0.60955000E-03, 0.16273400E-03, -.13525300E-01, 0.14702500E-02, -.30009000E-01, 0.10592200E-01, -.13407100E+00, 0.28722800E-01, -.50847600E-01, 0.12508600E-01, 0.20483600E+00, -.49536200E-03, -.36532700E-01, 0.24695700E-01, 0.41656600E-02, 0.14670200E-02, -.95746100E-02, -.13170700E-01, 0.18404300E-01, 0.27955600E-02, 0.39642100E-01, -.27562800E-01, 0.41218200E-02, 0.13932200E-02, -.92223600E-02, -.12993100E-01, 0.17790800E-01, 0.27180800E-02, 0.38241400E-01, -.26990400E-01, -.10615400E-02, -.49817600E-02, -.86621500E-02, 0.86324400E-02, 0.29709800E-02, 0.17245800E-02, 0.10220600E-01, -.51081800E-01, 0.10586300E-01, -.10428300E-01, 0.78300700E-02, 0.19744400E-01, 0.54241000E-02, -.82121600E-03, -.41509700E-02, 0.77802500E-02, 0.81427800E-02, -.88554200E-03, -.21863100E-01, -.39288400E-01, -.18248200E-03, 0.14663700E-01, -.34594200E-02, -.24165100E-01, -.44149400E-02, -.58815300E-02, -.21884200E-02, -.81676600E-02, 0.47877600E-03, -.28844300E-03, -.50229800E-01, -.65499000E-02, -.43805900E-02, -.32802000E-02, 0.12112900E-01, 0.43686300E+00, 0.13803700E-03, -.33660200E-02, 0.36108000E-03, 0.34820200E-02, 0.19018400E-01, 0.18950400E-01, -.12177000E-01, -.13684500E-01, -.79649700E-03, 0.59375000E-02, -.15453800E-02, -.59348900E-02, 0.14762500E-01, 0.42688000E-02, 0.29878900E-03, -.36451500E-01, 0.36232900E-02, -.71963300E-02, -.19588300E-01, -.30159100E-02, 0.20474200E-01, 0.33233400E-02, 0.64969200E-02, -.29068000E-01, -.32721000E-02, -.79752900E-02, -.34753600E-02, -.13574400E-01, -.45263100E-02, 0.68575500E-02, 0.21574600E-02, 0.27474900E-02, -.80034200E-02, 0.33193200E-01, 0.11448000E-01, -.54504600E-02, -.39726800E-02, 0.19344200E-02 }, { -.17251400E+00, -.40966200E-01, -.45058400E-01, 0.65075600E-01, 0.15680400E+00, 0.19354400E+00, 0.73668100E-01, 0.52279000E-01, -.18985100E-01, 0.36602200E-01, 0.11035300E-01, 0.52734600E-01, 0.93413200E-01, -.13169500E+00, 0.16297100E-02, 0.23470800E+00, -.12276600E-01, 0.77560200E-01, -.22602000E-01, -.69799000E-01, 0.94053900E-01, -.29227900E-01, -.13193500E+00, 0.82905900E-01, -.14651700E-01, 0.35622300E-01, -.73991700E-01, -.31084900E-01, 0.54325200E-01, 0.19955600E-01, 0.25866100E+00, -.33388200E-01, -.16709900E-01, -.15438000E-01, 0.67163200E-01, -.98177400E-02, 0.30016900E-02, 0.89869200E-02, 0.57118700E-01, -.35404400E-02, 0.19050100E-01, -.15192500E-01, 0.38242800E-01, -.12815400E-01, 0.15516700E-01, -.10159400E+00, 0.12833600E-01, 0.10766200E+00, 0.29068000E-02, -.46259500E-02, 0.20631700E-01, 0.34424500E-02, -.42595500E-01, -.41810000E-02, 0.35049900E-01, -.18344500E-01, -.59834400E-02, -.55097600E-01, -.28035700E-01, -.53935200E-01, -.56680200E-01, -.40825000E-02, 0.17484100E-01, -.41156000E-01, -.39819000E-01, 0.33286500E-02, 0.64160200E-02, 0.34464500E-01, 0.82728300E-03, 0.87003600E-03, -.15911000E+00, 0.58928400E-02, 0.19180100E-02, 0.20051000E-02, 0.29283500E-01, 0.84854900E-03, -.19780900E-02, 0.65713600E-02, 0.33451100E-01, -.86724200E-01, -.80971800E-01, 0.39664000E-02, -.22228000E-01, 0.66733000E-02, 0.68948900E-02, 0.70930400E-02, -.21405700E-01, -.10698600E-01, -.16908500E-01, 0.25152700E+00, -.31178600E-01, 0.78081400E-02, -.11538900E-01, -.17908600E-02, 0.69894200E-01, -.47927700E-01, -.38940100E-01, 0.76673300E-02, -.72335900E-02, -.77708900E-01, -.56476100E-01, -.58918300E-01, -.21563400E-01, -.76071400E-02, 0.11271900E-02, -.94972300E-02, -.35035300E-02, 0.37681700E-02, 0.10691500E+00, 0.96519100E-02, 0.20402400E-01, -.16666200E-01, 0.58221200E-02, -.13150300E-01, -.11060000E-01, 0.32410400E-02, -.21812100E-02, -.15623900E-02, -.12891000E-01, -.16526800E-03, 0.67564000E-03, 0.22241500E-01, -.49171300E-02, 0.11031600E-01, -.44181300E-02, -.20389800E-01, 0.36839900E-01, -.51715600E-02, -.47434900E-01, -.29544500E-01, -.28116500E-02, 0.31967500E-02, 0.11895100E+00, 0.12421100E+00, 0.24280000E-01, -.16583200E-02, -.61806800E-03, -.30924700E-02, 0.24223200E-02, 0.51909500E-02, -.34915300E-01, 0.66516000E-03, -.34213200E-01, 0.18455300E-01, -.66720100E-03, -.29696100E-02, 0.22284100E-02, 0.50782300E-02, -.33952100E-01, 0.55672700E-03, -.32849800E-01, 0.18007200E-01, -.54483900E-02, 0.23636300E-02, 0.70121500E-02, -.75194300E-02, -.37823000E-02, -.39510200E-02, -.16481400E-01, 0.29180400E-01, -.15314700E-01, 0.20104900E-01, 0.26178400E-01, 0.18798000E-01, -.36282500E-01, -.11670800E-01, -.15175600E-01, -.12139100E-01, -.92886000E-03, -.21821700E-01, 0.46693000E-01, 0.20333200E-01, -.36500900E-01, 0.88765400E-02, -.39826800E-02, 0.16285700E-01, -.29363700E-02, 0.49280300E-02, -.22358300E-03, 0.16401100E-03, -.29650600E-02, 0.35162500E-02, -.30449600E-02, 0.95345900E-02, -.20206000E-02, 0.15236800E-02, -.72965500E-02, -.37975700E-02, 0.25621400E+00, -.99033100E-03, -.30095200E-03, 0.26353800E-03, 0.94497400E-02, -.91690100E-02, 0.77826600E-02, 0.35138700E-02, -.11187400E-01, 0.14800000E-02, 0.34979300E-03, -.18002100E-03, 0.65171300E-02, -.78145000E-03, -.10245300E-01, -.10962600E-01, -.28431800E-03, 0.64307000E-02, 0.10176800E-01, -.14995400E-03, -.12913700E-01, -.33312500E-03, 0.14228200E-01, -.55322600E-02, -.48842900E-02, -.12166000E-01, 0.22249100E-02, -.61206400E-02, -.15153500E-01, 0.71051300E-02, 0.35088100E-04, -.44331200E-03, 0.88884700E-03, 0.17974300E-01, 0.66702700E-02, -.60554200E-02, 0.52077400E-03, 0.63700200E-03 }, { 0.48259800E+00, 0.16568200E+00, -.47889600E+00, -.25100000E+00, -.16032300E+00, -.12048200E+00, 0.16371800E+01, 0.53927200E+00, -.88657900E-01, 0.16452400E+00, -.36006300E-01, -.50487000E+00, -.66182400E-01, -.11776100E+01, 0.46736700E+00, 0.21837100E+00, 0.26920400E+00, 0.16701800E+00, 0.16998800E+00, -.13987800E-01, -.41255900E-02, -.38577800E-01, -.23976000E+00, -.51717600E-01, -.30600800E-01, -.10192200E-01, 0.22340400E+00, 0.89280800E-01, 0.13709200E+00, 0.59588100E-01, 0.68836600E+00, -.12822000E+00, 0.72395700E-01, -.10263100E+00, -.10431400E+01, -.18978100E+00, 0.45828500E-01, -.23516200E+00, -.13714100E+00, -.34118600E-02, -.10945100E+00, 0.91978700E-02, -.24574400E-01, -.96816800E-01, -.44297400E-01, 0.36916500E+00, -.60469800E-01, -.62836200E+00, 0.86805000E-03, 0.10223100E-01, -.25319800E-01, -.44208300E-01, 0.51469500E-01, 0.39792000E-01, -.44272000E+00, -.47515800E-01, 0.17229600E-01, 0.11201400E+00, 0.26324900E-01, -.93195300E-01, 0.24715700E-02, 0.12191000E-01, -.12174000E+00, -.42554400E+00, 0.50050800E-01, 0.32022700E-01, -.25886400E-01, 0.16512200E+00, 0.15276900E+00, -.19760300E-01, -.19881800E+00, 0.21441700E+00, 0.10573300E+00, -.62472100E-01, 0.52891900E-01, -.57362100E-01, -.44086300E-01, 0.67303300E-01, -.34847700E-01, 0.16049300E+00, 0.45043200E-01, -.14558900E-01, -.13192300E+00, -.13165300E-01, 0.42336000E-02, -.30713200E-01, 0.19035400E-01, -.12017100E-01, 0.15323200E-01, 0.19374700E+00, -.97597300E-01, 0.37656100E-02, 0.12005800E-01, 0.35695700E-01, -.55755200E+00, 0.66831500E-01, 0.39503300E+00, 0.88528600E-02, -.30553400E-01, -.35011700E+00, 0.71459200E-01, 0.13873800E+00, 0.44395000E-01, 0.34819700E-01, -.15763900E-01, -.56592900E-01, 0.51744600E-01, -.51582000E-01, 0.25195400E-01, -.10612100E+00, 0.65023700E-01, 0.51660800E-01, 0.11782900E+00, 0.65188500E-01, 0.23567500E-01, 0.12534500E-01, 0.30107500E-01, 0.71957300E-01, -.93161600E-02, 0.32081500E-01, 0.91916500E-01, 0.11728800E-01, -.96759800E-02, 0.78833700E-02, 0.53905500E-02, 0.73174500E-02, 0.18331400E-01, 0.80670100E-02, 0.66200500E-02, -.22615800E-01, -.25605100E-01, -.14243700E-01, -.28037600E+00, -.30115700E-01, 0.11874900E-01, -.10376000E-01, -.30240100E-02, -.15538500E-02, 0.32527100E-03, 0.36341700E-02, 0.78479900E-02, -.16080800E-01, -.14482000E-01, 0.11125200E-01, -.29800600E-02, -.15501800E-02, 0.43788700E-03, 0.37542600E-02, 0.75352000E-02, -.15875400E-01, -.14865100E-01, 0.11587200E-01, 0.23590600E-02, 0.47695300E-02, 0.20524100E-01, -.17993600E-01, 0.96113900E-02, -.12121800E-01, 0.43603700E-01, -.20829500E-01, 0.34138000E-01, -.57371200E-02, 0.31479900E-01, 0.18066600E-01, 0.63797700E-01, 0.68123800E-02, 0.41039000E-01, 0.23852800E-01, -.14262200E-01, 0.38774300E-01, -.42649200E-01, -.30067400E-01, 0.48691800E-01, -.48303600E-01, -.65654900E-02, -.45636700E-01, 0.21323400E-01, 0.16936200E-01, -.11476000E-01, 0.24776200E-01, 0.70461500E-02, -.46381100E-02, 0.14380600E+00, -.93612200E-02, 0.61185500E-02, 0.13904800E-01, -.16221800E-01, -.24184300E-01, -.12189900E-01, 0.12431600E+01, 0.93500200E-02, -.97380000E-02, -.27328000E-01, -.79247600E-01, 0.16061000E-01, 0.18000600E-01, 0.78588000E-02, -.29758500E-01, -.15253600E-01, 0.16455400E-01, -.18942600E-01, -.15922400E-01, 0.79207500E-01, 0.73574900E-01, -.14102400E-01, -.13558900E-01, 0.39334900E-01, 0.12870000E-01, -.50161100E-01, -.12629600E-01, 0.16023200E-01, 0.64472600E-01, -.13712900E-01, 0.40608000E-02, -.61796200E-01, -.93548800E-02, 0.16157500E-01, 0.86310800E-02, -.79161200E-02, -.10051800E-01, -.18135600E-01, -.90911900E-01, -.97153500E-01, 0.30130500E-02, 0.15098600E-01, -.11747000E-01 }, { -.11029300E-01, 0.27499800E-01, -.11852200E+00, -.12696300E+00, -.53719900E-01, 0.40586800E+00, -.14389400E+00, 0.30868300E-01, -.49026200E-01, 0.91933900E-02, -.54074900E-03, -.35063600E-01, -.68299200E-01, 0.89141400E-01, 0.73933600E-01, -.19799000E-01, -.63795600E-01, 0.17161800E-01, 0.72463200E-02, 0.48623600E-02, -.25354300E-01, 0.41616100E-02, 0.25078600E-02, 0.97946200E-02, -.21059100E-02, 0.44771200E-02, 0.83332300E-02, 0.94987100E-02, 0.38987500E-01, 0.15303900E-01, 0.22410100E+00, -.18199600E-01, -.39301600E-01, -.14631600E-01, -.54312900E+00, 0.22245500E-03, 0.15930300E-03, 0.46116700E-03, -.79826400E-02, -.97471500E-03, 0.43231400E-03, 0.13351500E-02, 0.22983700E-01, -.60409800E-02, -.93312200E-03, 0.17816800E-02, 0.24531500E-02, -.97153400E-02, 0.11447100E-04, -.45351200E-03, -.42952300E-02, -.19858200E-02, 0.41787900E-03, 0.20000900E-02, 0.32751100E+00, -.13836600E-02, 0.15169200E-02, 0.63649400E-03, -.24831800E-02, -.16247700E-02, -.82064900E-02, -.39218000E-03, 0.11428900E-01, 0.11782600E-01, -.13663500E-01, 0.11947000E-02, 0.17261300E-02, -.94828700E-02, 0.26175200E-02, 0.30102700E-02, -.19401200E+00, 0.81052300E-02, 0.22417500E-02, 0.26191800E-02, -.84856900E-02, -.39870400E-02, -.18720900E-01, 0.91096600E-02, -.25019000E-02, -.20259400E-01, -.15099700E-01, 0.28137500E-02, 0.14453700E-01, 0.13566700E-02, 0.38773000E-03, 0.89555500E-02, -.37457900E-02, -.29179500E-03, 0.70484800E-03, -.46194000E-01, 0.29364100E-01, 0.82613200E-03, 0.42232700E-02, 0.41867200E-02, 0.61207400E-01, 0.12474300E-01, 0.76025200E-02, 0.26523800E-02, -.86451600E-02, -.23465800E-01, -.78234500E-02, -.54457000E-03, 0.11709100E-02, -.13129400E-03, 0.12749000E-02, 0.52052300E-03, -.44676100E-02, -.10207600E-01, -.28626800E-01, 0.26393900E-01, 0.10422300E-02, -.26024600E-02, 0.14581200E-02, -.16049500E-01, -.17932900E-01, 0.36820300E-03, -.44151600E-02, -.10241900E-01, 0.61161700E-02, -.42507400E-02, -.93408700E-02, 0.18159900E-01, -.11033500E-01, -.25223000E-02, -.89748500E-02, -.53714100E-02, -.21141100E-01, 0.68938200E-02, -.10012800E+00, 0.16976000E-02, 0.13462100E-01, 0.49903700E-02, -.39878500E+00, 0.66417400E-02, 0.21156100E-02, 0.17677500E-02, 0.57900300E-03, -.49624400E-03, -.79302800E-03, -.13147300E-04, -.15202100E-02, 0.22245600E-03, -.82352400E-02, 0.27834200E-02, 0.56462500E-03, -.47950400E-03, -.77371100E-03, -.29873400E-04, -.14543800E-02, 0.20240500E-03, -.81107700E-02, 0.26898500E-02, -.17600100E-03, 0.57765700E-03, 0.34249500E-02, -.42944700E-02, -.11878300E-02, -.87546900E-03, 0.61875500E-02, -.11471000E-01, 0.93932900E-02, 0.32040200E-03, 0.35378600E-02, -.36887700E-03, 0.62246300E-02, -.27077000E-02, -.63878500E-04, 0.32823700E-03, 0.10182800E-02, 0.41653300E-02, -.63789900E-02, -.65512300E-02, -.18984700E-02, 0.50056600E-04, -.12662800E-01, -.11872300E-01, -.42247500E-02, -.39359600E-02, -.35286700E-02, -.53040600E-02, 0.92260700E-02, -.60771800E-02, -.30519500E-01, 0.17173800E-02, -.20657300E-02, -.14001600E-02, 0.10596400E-02, 0.16794800E-02, 0.34248200E-02, 0.39124800E-03, 0.24023200E+00, 0.20028800E-02, 0.90194100E-02, 0.75765700E-02, -.80335000E-03, -.12097800E-02, -.14665100E-02, -.14646200E-02, -.15648000E-01, -.36475700E-02, 0.65403300E-02, 0.12884200E-03, 0.26499900E-01, -.82682100E-02, -.33671100E-03, -.61193000E-02, -.31896600E-02, 0.77003900E-03, 0.27089500E-02, -.26024000E-03, 0.11109500E-01, -.77622400E-02, -.56261300E-02, -.84576400E-02, -.23080100E-01, -.11110100E-01, -.53877000E-03, 0.73870700E-02, -.12694000E-03, 0.71978800E-04, -.10186500E-01, -.39822000E-02, 0.23435100E-01, 0.44185100E-02, 0.74116400E-04, -.12168600E-02 }, { -.20185700E+00, -.84743800E-01, 0.37071300E+00, 0.15964900E+00, 0.14279800E+00, 0.85307100E+00, 0.64773200E+00, -.25428300E+00, 0.21331400E-01, -.52727900E-01, 0.70075200E-02, 0.11962800E+00, -.64511500E-01, 0.59697700E+00, -.12062300E+00, -.25229700E+00, -.23683200E+00, -.92369200E-01, -.34993800E-01, 0.39692300E-01, 0.16888200E-02, -.41174200E-02, 0.55132600E-01, 0.59123800E-01, 0.28132700E-02, 0.16604100E-01, -.10280500E+00, -.36431600E-01, -.10599700E-01, -.10585300E-02, -.12234400E+00, 0.37560500E-01, -.54428100E-01, 0.67723800E-02, -.17120500E+00, 0.63480000E-01, -.15323300E-01, 0.57307800E-01, -.45500600E-01, -.38901000E-02, 0.14951000E-01, 0.39299500E-01, 0.65754000E-01, 0.20079400E-01, -.58087100E-02, -.92137000E-01, 0.28771400E-01, 0.97277800E-01, -.23146900E-02, 0.68305200E-03, -.11056700E-01, 0.25722300E-02, 0.17622400E-01, -.15163200E-02, 0.35410700E+00, 0.15969700E-01, 0.67437800E-02, -.38698700E-01, -.57805600E-02, 0.40286400E-01, -.19275100E-01, -.10060700E-01, 0.52385800E-01, 0.16761400E+00, -.26656500E-01, -.10709000E-01, 0.48908700E-02, -.70665700E-01, -.45826800E-01, 0.93835700E-02, -.87959300E-01, -.67953500E-01, -.25802300E-01, 0.17616400E-01, -.16729200E-01, 0.10705900E-01, -.20278300E-01, 0.42930900E-03, -.34806700E-02, -.20792600E-01, -.11088300E-01, -.73450000E-02, 0.96670300E-02, 0.27236900E-02, 0.16790400E-01, 0.77731400E-02, -.14151100E-01, 0.75622000E-02, -.30874200E-02, -.16795100E-01, 0.53532800E-01, -.89513700E-02, -.67964000E-03, -.18455500E-01, 0.15579300E+00, 0.36519500E-01, -.13168700E+00, -.29728100E-02, 0.22549000E-02, 0.13198200E+00, -.20157800E-01, -.32830600E-01, -.95875100E-02, -.73644500E-02, 0.52026900E-02, 0.11451800E-01, -.17144500E-01, -.32665500E-03, -.58319600E-01, 0.42057200E-01, -.10796700E-01, -.14772300E-01, -.47879200E-01, -.42450100E-01, -.19708000E-01, -.21338100E-02, -.81430700E-02, -.34492700E-01, 0.10082700E-01, -.13800800E-01, -.31321800E-01, 0.17418400E-01, -.12251800E-01, 0.67750600E-02, -.34398900E-01, -.32287800E-02, -.27997300E-01, 0.50479000E-02, -.45365100E-01, 0.20248900E-01, -.60706800E-03, 0.80988200E-02, 0.55828400E-01, 0.18722600E-01, -.21508600E-01, 0.64534000E-02, 0.22502300E-02, -.34664200E-03, -.49861900E-02, -.27065900E-02, 0.43950500E-02, 0.22408900E-02, 0.28891400E-01, -.93117400E-02, 0.22300500E-02, -.36539400E-03, -.48793300E-02, -.28034300E-02, 0.43179500E-02, 0.22436300E-02, 0.28578900E-01, -.96912300E-02, -.87839000E-03, -.22990100E-02, -.53965500E-02, 0.11454200E-01, -.10394900E-01, 0.81093000E-03, -.32660200E-02, -.69548900E-02, 0.38133900E-02, 0.14733600E-02, 0.50531600E-03, -.20310300E-02, -.16445000E-01, -.46780200E-02, -.17713900E-01, -.64028500E-02, 0.92714200E-02, -.10200200E-01, -.10461400E-01, -.92813300E-02, -.19120100E-01, 0.15091800E-01, -.47032800E-02, -.80679600E-02, -.10035000E-01, -.63690500E-02, 0.12610000E-03, -.14639200E-01, 0.45560900E-02, -.76543500E-02, -.79640400E-01, 0.43167200E-02, -.39089400E-02, -.26863100E-02, 0.11265800E-01, 0.10177800E-01, 0.34635600E-02, -.29178500E-02, 0.26860300E-02, 0.14465100E+00, 0.16901200E-01, 0.15282400E-01, -.11437900E-01, -.79207600E-02, -.20950900E-02, 0.64142000E-02, -.21838100E-02, -.92271500E-02, 0.12623800E-01, 0.41282300E-02, 0.24134500E-02, -.21222200E-01, 0.38333200E-02, -.10820500E-01, -.13567300E-01, -.35397600E-02, 0.16248900E-01, 0.34310300E-02, 0.44868900E-02, -.25354700E-01, -.24678100E-02, -.79281400E-02, -.51800900E-02, -.92986800E-02, -.61312500E-02, 0.35701500E-02, 0.22204000E-02, 0.25990100E-02, -.66234600E-02, 0.17366300E-01, 0.11180100E-01, 0.32030700E-02, -.40188700E-02, 0.29940800E-02 }, { -.28111300E+01, -.93931400E+00, 0.23597600E+01, 0.11822600E+01, 0.85700800E+00, 0.62121800E+01, 0.55568300E+01, -.17826400E+01, 0.75823300E+00, -.10967100E+01, -.81909000E-01, 0.31227200E+00, -.17632900E+01, 0.94767200E+01, -.13485300E+01, -.66721600E+01, -.36914200E+01, -.28221500E+01, -.42176100E+00, 0.14710400E+01, -.26597600E+00, -.23436400E+00, 0.15213500E+00, 0.10199700E+01, -.78993500E-01, 0.32291100E+00, -.10337400E+01, -.35069500E+00, 0.18393900E+01, 0.20198400E+00, 0.37828500E+01, -.11160400E-01, -.12132000E+01, -.27505000E+00, -.56311800E+01, 0.84068200E+00, 0.90151400E-02, 0.38383800E+00, 0.37675100E+00, -.18753300E+00, 0.51561300E+00, 0.35429900E+00, 0.15861500E+01, 0.84446500E-01, 0.17321800E+00, -.28728500E+01, 0.53072300E+00, 0.25461800E+01, 0.55406800E-01, -.72509600E-01, 0.16742100E+00, 0.87333100E-01, -.65331300E+00, -.43481800E-01, 0.74854100E+01, -.21090400E+00, -.13077800E+00, 0.27925300E+00, -.39732900E+00, -.25536500E+00, 0.58395500E+00, -.13921300E+00, 0.95672500E-01, 0.14867800E+01, 0.42676600E+00, -.14171100E+00, 0.44758800E-01, -.59141300E+00, -.64607400E+00, 0.92006400E-01, -.15002400E+01, -.90262100E+00, -.39833700E+00, 0.40907700E+00, -.11515900E+00, 0.58155500E-01, -.10987700E-01, -.95044500E-01, -.24419000E+00, -.56517600E-01, -.44972300E+00, -.11642400E+00, -.17932200E-01, 0.35912100E-01, 0.19235800E+00, -.69834500E+00, -.14895700E+00, 0.56746100E+00, -.88686200E-01, 0.78987400E+00, 0.47438200E-01, -.74478700E-01, -.72533200E-01, -.21334400E+00, 0.33246200E+00, 0.22121000E+00, -.77548900E+00, 0.59418800E-01, -.92262000E-01, -.49607000E+00, -.43285400E+00, -.91527600E+00, -.12900100E+00, -.16263300E+00, 0.45833100E-01, 0.64669000E-02, -.10373800E+00, 0.23374500E-01, 0.17807200E+00, 0.42430100E+00, 0.30152300E+00, -.72997700E-02, 0.12372600E+00, -.10254000E+00, -.18148500E+00, -.21433700E-01, -.16609100E+00, 0.10265100E+00, -.65258100E-01, 0.10584200E+00, -.17266600E-01, 0.39398800E+00, -.69877500E-01, 0.58818200E-01, -.16372200E+00, -.15581600E+00, 0.35986700E+00, -.17364900E-01, -.32427000E+00, -.22418400E+00, 0.55099200E-01, 0.97889200E-02, -.27385500E+00, 0.60509800E+00, 0.10360800E+00, 0.21263100E-01, 0.11971600E-01, -.22781600E-01, -.67268000E-01, -.27451900E-01, -.70549600E-01, 0.45534200E-01, -.18827600E+00, 0.47173100E-01, 0.11084000E-01, -.22286700E-01, -.67425300E-01, -.27013100E-01, -.66761500E-01, 0.43609400E-01, -.18529900E+00, 0.48361700E-01, -.41655700E-01, -.14054200E-01, -.14148800E+00, -.11363500E-01, 0.27197400E-01, 0.67435400E-02, -.10253600E+00, 0.14579000E+00, 0.32690100E-01, 0.13633400E+00, 0.21857000E+00, 0.13765900E+00, -.23378900E+00, -.14739300E+00, -.74056900E-01, -.15304900E-01, 0.44463500E-01, -.19617900E+00, 0.16681700E+00, -.56690700E-01, 0.29513600E+00, 0.11308500E+00, -.62062500E-01, -.14710300E+00, -.79785600E-01, -.54147900E-01, -.11526400E-01, -.32465000E-01, 0.38587600E-01, 0.39837100E-02, -.23535000E+00, 0.27404100E-01, -.44313200E-01, 0.28187700E-01, 0.11297900E-01, 0.16224400E-01, 0.49868100E-02, -.14887900E-01, 0.96888200E-02, 0.84760100E-01, 0.23944000E+01, -.15857000E+00, -.12075200E-01, -.15725500E-01, -.76669600E-03, 0.38272600E-01, -.71410600E-03, -.26187300E-01, 0.17134700E+00, -.81608900E-02, -.63155900E-01, 0.10974200E+00, -.25084200E-02, -.23913300E-01, 0.84830800E-01, -.82493200E-03, -.97506800E-01, -.26025800E-02, 0.42637800E-01, -.32023000E-01, -.10227300E+00, -.70491800E-01, 0.79011600E-01, -.22241300E-01, -.48065000E-01, 0.68359800E-01, 0.14897300E-02, -.41483600E-02, 0.16967600E-01, -.69218200E-01, -.48127100E-01, -.17588500E-01, 0.54947800E-02, -.26175000E-03 }, { 0.86775300E+00, 0.11497200E+01, -.68905700E+00, 0.43711500E-01, -.22759900E+00, -.66789500E+00, -.28118800E+00, 0.95761900E+00, -.13853500E+00, -.51196200E+00, 0.14210000E+00, 0.48750800E+00, 0.58679400E-01, -.64867000E-01, 0.27645700E+00, 0.15760900E+01, 0.14687100E+01, 0.49489100E+00, 0.50796800E-01, -.35059600E+00, -.31223700E+00, 0.26488000E+00, 0.58568300E+00, -.55437100E+00, 0.10066900E+00, -.23166600E+00, 0.60344400E+00, 0.22538900E+00, -.29180500E+00, -.16142000E+00, -.74667300E+00, 0.67827600E-01, 0.20829000E+00, 0.20436200E+00, 0.20651200E+01, -.53815400E-01, -.45149500E-02, 0.36388200E-01, 0.52921600E+00, 0.75412500E-01, 0.73906200E-01, -.43055900E+00, -.27367700E+00, 0.15965900E+00, 0.18605200E+00, 0.72356400E-01, -.90788700E-01, 0.23039000E+00, 0.39725100E-03, -.33672000E-01, 0.88851600E-01, 0.10526600E+00, -.15547000E+00, -.82923600E-01, -.88452600E+00, 0.89614000E-01, -.64373900E-01, -.18183400E+00, 0.74351500E-01, 0.23439800E+00, 0.22981800E+00, 0.12941000E+00, -.58124700E-01, -.17342900E+00, 0.30407300E-01, 0.10261900E-02, 0.33311800E-01, 0.63888300E-01, -.22478800E-01, -.10888300E-01, 0.20177700E+00, 0.41978100E-01, -.38245900E-01, -.18120900E-01, -.13319500E+00, 0.41745100E-01, 0.19263200E+00, -.12605500E+00, 0.31948700E+00, -.28673400E+00, -.45759000E-01, 0.10467900E+00, 0.28569200E+00, 0.34432800E-01, -.23105700E+00, 0.10404400E+00, 0.51104600E-01, -.29447000E-01, -.31604100E-01, -.14100200E+01, 0.79087600E-01, 0.29157300E-01, 0.15495700E-01, 0.10259000E+00, -.40816000E+00, -.29747300E+00, 0.44060100E+00, -.27720400E-02, -.25503400E-02, -.74108500E-01, 0.93137100E-01, 0.11890400E+00, 0.46273000E-01, 0.21412000E-02, -.80256900E-02, 0.34277600E-01, -.38093800E-01, 0.50702900E-01, 0.42976100E-01, 0.51366400E-01, -.96202100E-01, 0.22694300E-01, 0.31441800E-01, 0.12860700E+00, 0.53281200E-01, -.18258000E-02, 0.13660400E-01, 0.38694100E-01, 0.70670800E-02, 0.14401800E-01, -.38011200E-01, -.12907000E+00, 0.71238300E-01, -.98761900E-01, 0.32626900E+00, 0.25857700E-01, 0.31786800E-01, -.17987700E-01, -.13615200E+00, -.44064300E-01, 0.98111100E-01, 0.43883800E-03, -.99690300E+00, -.24982000E+00, 0.70685600E-01, -.15069900E-02, -.70597400E-02, 0.19674800E-01, 0.13622000E-01, 0.14142500E-01, -.36928600E-01, 0.27827200E-01, -.19107700E+00, 0.70135700E-01, -.68777000E-02, 0.19666900E-01, 0.12812200E-01, 0.14322000E-01, -.36062700E-01, 0.27284500E-01, -.18748100E+00, 0.71131200E-01, 0.12351100E-01, 0.95498600E-02, -.68512400E-02, -.11402800E+00, 0.30740300E-01, 0.36345900E-01, -.27013700E-01, -.47948500E-01, -.42015600E-01, -.49475000E-01, -.17359100E+00, -.72983200E-01, 0.86845800E-02, 0.40775600E-01, -.12511100E-01, -.34759000E-01, -.26317200E-01, 0.39233200E-01, 0.95624100E-01, 0.14722100E+00, -.29088600E-01, -.10719300E-01, 0.13896900E-01, 0.24183600E+00, 0.43428400E-02, -.25268500E-01, 0.20315900E-01, 0.16443400E-01, -.31457800E-01, 0.17721200E-01, 0.78377800E-01, -.19559800E-01, 0.14044200E-01, -.32066100E-01, -.20895200E-01, -.26484300E-02, -.22602700E-01, -.68201100E-02, 0.31176800E-02, -.24402900E-01, -.25038200E-01, 0.29872700E+01, 0.23081200E-01, 0.41461200E-02, 0.11359900E-01, 0.17108200E-01, -.34925500E-02, 0.78631800E-02, -.50736400E-01, 0.15892100E-01, -.13783400E+00, -.44270800E-01, 0.98239100E-02, 0.59437400E-01, -.13037900E-01, -.58999300E-02, -.28197200E-01, 0.89461200E-02, -.71194000E-01, 0.15563300E-01, 0.47605900E-01, 0.37164900E-01, 0.12871900E+00, 0.14938900E-01, 0.24849200E-01, -.64258100E-01, 0.41132600E-02, 0.94864800E-02, 0.58520600E-01, 0.41907800E-01, -.79074000E-01, 0.64534100E-02, -.12934200E-01, 0.49690300E-02 }, { 0.35508300E+00, 0.14585400E+00, -.63999900E+00, 0.68311800E-01, -.13605000E+00, -.12179700E+01, -.10417100E+01, 0.54593500E+00, -.18357400E+00, 0.37346900E+00, -.73358700E-02, -.21311200E+00, 0.43727900E+00, -.24312200E+01, 0.37169900E+00, 0.14588500E+01, 0.69513200E+00, 0.58681100E+00, 0.79495100E-01, -.31944100E+00, 0.13867100E+00, 0.18207100E-02, -.22809100E+00, -.11555800E+00, -.74062400E-02, -.28658300E-01, 0.13339700E+00, 0.54833100E-01, -.19148100E+00, -.46761800E-02, -.98022800E-01, -.77463000E-01, 0.15571400E+00, 0.42891500E-01, 0.43843400E+00, -.15328800E+00, -.46421300E-02, -.28286700E-01, 0.11706300E+00, 0.12252100E-01, -.10274400E-01, -.14546200E+00, -.13083900E+00, -.24225100E-01, 0.61747800E-01, 0.23567100E+00, -.49314100E-01, -.27509800E+00, -.40990100E-02, 0.46348600E-02, 0.30160400E-02, -.47718600E-02, 0.41426800E-01, -.68107600E-02, -.94378600E+00, 0.91104100E-02, 0.33690600E-02, -.74304700E-01, 0.60755100E-01, -.55118800E-01, -.76869100E-01, 0.27521500E-01, -.28810100E-01, -.34982700E+00, -.85950600E-01, 0.30541100E-01, 0.70824600E-02, 0.14944900E+00, 0.11305700E+00, -.22993300E-01, 0.24773000E-03, 0.18231900E+00, 0.56021400E-01, -.46600400E-01, 0.36794400E-01, -.79078900E-02, 0.14517500E+00, -.44454500E-01, 0.11665900E+00, -.13796900E+00, -.16813500E-01, 0.50174300E-01, 0.49529000E-01, 0.14513800E-01, -.61588400E-01, 0.16955800E+00, 0.53745100E-02, -.11992500E+00, -.33773100E-02, 0.22968600E+00, -.12416300E+00, 0.55386900E-01, -.17070200E-01, 0.81068900E-01, 0.33033000E+00, -.26023200E+00, 0.63068600E-01, 0.10228200E-01, 0.53323900E-02, -.11240500E+00, -.28287000E-01, 0.25276600E-01, -.50130300E-02, -.63493100E-02, -.85847100E-02, -.77925400E-02, 0.32194500E-01, 0.30490800E-01, 0.21338200E+00, -.59590400E-01, -.23173000E-01, 0.20949900E-02, 0.50828200E-01, 0.55535900E-01, -.40799600E-02, 0.17458400E-01, -.45994500E-02, 0.64375500E-01, 0.23969600E-01, 0.19057800E-01, 0.22797800E-01, -.59714100E-01, 0.48248000E-01, -.38206800E-01, 0.76757900E-01, 0.86578000E-02, -.16593500E-01, -.36519400E-04, -.93698900E-01, -.12457800E-01, 0.32264300E-01, -.23861600E-02, -.72710600E+00, -.43929400E-01, 0.72756800E-01, 0.11714600E-01, -.22217000E-02, -.23198000E-02, 0.34442600E-01, 0.26051800E-02, -.23251900E-01, 0.10416200E-02, -.84155000E-01, 0.87792800E-02, -.22038100E-02, -.21912700E-02, 0.33909400E-01, 0.25986100E-02, -.22591100E-01, 0.98926000E-03, -.82493800E-01, 0.85635800E-02, 0.11282400E-02, 0.77534100E-02, 0.40079700E-01, -.23337400E-01, 0.34221300E-01, 0.63408500E-02, -.15957700E-01, 0.23371300E-01, -.35026000E-01, -.65840700E-02, 0.46258100E-04, 0.53921400E-02, 0.26680600E-01, -.11008600E-01, 0.30638200E-01, 0.33654100E-02, -.22178300E-01, 0.14905900E-01, 0.88205600E-01, 0.34000200E-01, -.64752800E-02, -.14763400E-01, -.20898800E-02, 0.28155400E-01, 0.11590100E-01, 0.84568400E-02, 0.15640800E-02, 0.24891500E-01, -.10868800E-01, 0.20396300E-01, 0.10931800E+00, -.11301400E-01, 0.41807200E-02, -.51197400E-02, -.34323100E-01, -.12196700E-01, 0.20959300E-01, 0.13114500E-02, 0.74996100E-02, -.46225200E-01, -.72923500E-02, 0.98350900E-02, 0.56291800E+00, 0.92688700E-02, -.10162900E-01, -.29040300E-02, -.25676200E-02, 0.12080500E-01, -.11531800E-01, -.98399400E-03, 0.78026100E-02, -.31605400E-01, -.19184000E-02, 0.53288800E-01, -.56223600E-03, 0.23037600E-02, 0.12387700E-01, -.17863100E-02, 0.23680200E-02, 0.22490400E-01, 0.36513800E-02, 0.18504000E-02, -.27705800E-02, 0.20321700E-01, -.47473200E-03, -.52253900E-03, -.12576300E-02, -.70770500E-03, 0.23112100E-01, 0.32870700E-01, -.23228200E-02, -.82779600E-02, 0.14583500E-02, -.14223500E-02 }, { 0.46199800E+00, 0.19049000E+00, -.76408400E+00, -.34832800E+00, -.26287600E+00, -.16708700E+01, -.12185600E+01, 0.77169800E+00, -.10109100E+00, 0.21614900E+00, -.16141700E-01, -.10216200E+00, 0.45073600E+00, -.20446500E+01, 0.13169100E+00, 0.10886100E+01, 0.81558400E+00, 0.22973800E+00, -.91417900E-01, -.16389600E+00, -.58587900E-01, 0.97758900E-01, 0.64943400E-01, -.19268300E+00, 0.29323000E-01, -.66734000E-01, 0.21466300E+00, 0.59977100E-01, 0.72560200E-01, -.55585700E-01, 0.33990400E+00, -.52350500E-01, 0.12687500E+00, 0.72430300E-01, 0.19852500E+01, -.11953400E+00, 0.31835300E-01, -.11093400E+00, 0.38374800E+00, 0.63996500E-01, 0.23164300E-01, -.17842400E+00, -.19834000E+00, -.15767100E+00, -.15618800E-01, 0.12308400E+00, -.15207800E+00, 0.51038300E+00, 0.26061100E-01, -.36852600E-01, 0.95047900E-01, 0.13509500E-01, -.24328100E+00, -.16945300E-01, -.17299200E+01, -.11450900E+00, -.51224100E-01, 0.13779800E+00, -.19141900E+00, -.26142500E+00, 0.46932200E-01, 0.82517700E-02, -.81807700E-01, -.25927400E+00, 0.49096900E-01, 0.17965300E-01, -.40162200E-02, 0.11432000E+00, 0.80491400E-01, -.15157600E-01, 0.72243500E+00, 0.11019100E+00, -.55981000E-02, -.18022700E-01, 0.40273300E-01, 0.68803400E-02, -.13572200E+00, 0.37353500E-01, -.11539800E+00, -.19556800E+00, 0.27646200E-01, 0.32960400E-01, 0.18800400E+00, -.16913700E-01, -.54893700E-01, -.59595000E-01, 0.31151900E-01, -.21780600E-01, 0.19234800E-01, -.38371300E+00, -.21931400E-01, 0.23162800E-01, 0.25721700E-01, -.53995900E-03, 0.54039000E-01, -.11612700E+00, 0.12765900E+00, -.26244700E-02, 0.33295400E-01, -.24469000E+00, 0.33745700E-01, 0.51158400E-01, -.13994200E-01, 0.19455500E-01, 0.76112900E-02, 0.33807500E-01, 0.22055900E-01, 0.48426300E-01, 0.15761300E+00, -.13878800E+00, -.38799300E-02, -.21618900E-01, 0.90507900E-01, 0.64351600E-01, 0.26915600E-01, -.54738000E-02, 0.11335600E-01, 0.43561500E-01, -.41976200E-01, -.24102000E-03, 0.59091100E-01, -.30555500E-01, 0.14959000E-02, -.20353700E-02, 0.30515600E-01, -.15850700E-02, 0.64713500E-01, -.21969000E-01, 0.30701300E+00, -.53059200E-01, 0.80770700E-01, -.22859100E-01, -.44557900E+00, 0.67142600E-02, 0.72820000E-01, -.41892900E-01, -.85210400E-02, -.35681500E-02, 0.22354700E-01, 0.24855600E-01, -.28652700E-01, -.66859400E-02, -.60841100E-01, 0.43942400E-01, -.84146800E-02, -.34432700E-02, 0.21633800E-01, 0.24508600E-01, -.27663600E-01, -.64354800E-02, -.58457800E-01, 0.42865500E-01, 0.24657800E-02, 0.97623600E-02, 0.10466000E-01, 0.37867300E-02, -.51239500E-02, -.55712700E-02, -.19755500E-01, 0.10323100E+00, -.19041600E-01, 0.22907100E-01, -.15007000E-01, -.42370900E-01, -.92959700E-02, 0.13803800E-02, 0.13147800E-01, -.13978500E-01, -.17188900E-01, 0.33558900E-02, 0.40069000E-01, 0.78944400E-01, -.27703500E-02, -.28043600E-01, 0.78411100E-02, 0.46511800E-01, 0.11978300E-01, 0.16968400E-01, 0.43999800E-02, 0.19200200E-01, -.49840600E-02, 0.66278000E-02, 0.11885600E+00, 0.15778600E-01, 0.79633900E-02, 0.50853100E-02, -.20830000E-01, -.33273400E-01, 0.40571300E-02, 0.44011000E-02, 0.31692800E-02, -.52618800E-01, -.13821300E-01, -.10155500E-01, 0.35912100E-01, 0.45578500E+00, -.88117900E-03, -.86734700E-02, -.44315100E-03, 0.12764700E-01, -.24026500E-01, -.79687100E-02, -.52555900E-02, 0.48793900E-01, -.72081600E-02, 0.81064200E-02, 0.29689000E-01, 0.64617900E-02, -.30650500E-01, -.65405800E-02, -.70016100E-02, 0.45586700E-01, 0.54311400E-02, 0.94863900E-02, 0.81113400E-02, 0.16337700E-01, 0.17002500E-02, -.99495700E-02, -.41857900E-02, -.50976100E-02, 0.11910900E-01, -.40440700E-01, -.27437500E-01, 0.26028200E-02, 0.76244400E-02, -.50101100E-02 }, { 0.34756500E+00, 0.81767900E-01, 0.88567500E-01, -.13928400E+00, -.32276800E+00, -.39615600E+00, -.13625600E+00, -.91421200E-01, 0.39362900E-01, -.76345700E-01, -.22859500E-01, -.12162200E+00, -.19925700E+00, 0.26559300E+00, 0.14106000E-01, -.48766700E+00, 0.27863700E-01, -.15857100E+00, 0.52894700E-01, 0.14054200E+00, -.19196100E+00, 0.57704400E-01, 0.26230900E+00, -.16059300E+00, 0.29021100E-01, -.70040000E-01, 0.15146500E+00, 0.64876300E-01, -.95805700E-01, -.37495200E-01, -.46194500E+00, 0.62434500E-01, 0.23712500E-01, 0.29426300E-01, -.19852700E+00, 0.18597100E-01, -.50408200E-02, -.22823800E-01, -.11506600E+00, 0.75082000E-02, -.38506000E-01, 0.20892500E-01, -.27842300E-01, 0.25960300E-01, -.26973000E-01, 0.19063200E+00, -.22190800E-01, -.22414600E+00, -.59065700E-02, 0.69513000E-02, -.41855700E-01, -.52704100E-02, 0.80082800E-01, 0.90463000E-02, -.12327400E-01, 0.37174600E-01, 0.13202900E-01, 0.97358400E-01, 0.56157800E-01, 0.11656700E+00, 0.11940800E+00, 0.12231200E-01, -.29959900E-01, 0.91435500E-01, 0.75483300E-01, -.84375200E-02, -.87776100E-02, -.71561700E-01, -.12266300E-01, 0.52236900E-04, 0.24181400E+00, -.20234300E-01, -.27247500E-02, -.21920500E-02, -.62552000E-01, -.29797400E-02, 0.26513300E-04, -.94884500E-02, -.45561300E-01, 0.15365400E+00, 0.15817300E+00, -.10888100E-01, 0.42383000E-01, -.12243000E-01, -.16120800E-01, -.19720800E-01, 0.37081100E-01, 0.30408500E-01, 0.29524400E-01, -.49171600E+00, 0.58086400E-01, -.18033800E-01, 0.24278300E-01, 0.54881300E-02, -.20398300E+00, 0.95665200E-01, 0.95626300E-01, -.15984600E-01, 0.11147900E-01, 0.14161700E+00, 0.11082500E+00, 0.11329100E+00, 0.42553400E-01, 0.16738900E-01, -.17844400E-02, 0.20032100E-01, 0.76669000E-02, -.82238900E-02, -.22672000E+00, -.13182100E-01, -.39287700E-01, 0.24659400E-01, -.11190500E-01, 0.14974800E-01, 0.17685800E-01, -.52813200E-02, 0.21721300E-02, 0.26699600E-02, 0.26026000E-01, 0.17980200E-02, -.15068900E-02, -.33615900E-01, 0.62238100E-02, -.17565200E-01, 0.27825400E-02, 0.37692600E-01, -.69217600E-01, 0.99586800E-02, 0.65769700E-01, 0.54191500E-01, 0.33956500E-02, -.48963900E-02, -.17579700E+00, -.22854300E+00, -.43922000E-01, 0.24970900E-02, 0.19077100E-02, 0.58521200E-02, -.66230600E-02, -.98846600E-02, 0.63203800E-01, 0.20798200E-04, 0.51534300E-01, -.31325300E-01, 0.19847800E-02, 0.56370300E-02, -.62123700E-02, -.96701200E-02, 0.61506500E-01, 0.17656600E-03, 0.49157900E-01, -.30521000E-01, 0.11159200E-01, -.33932900E-02, -.93016800E-02, 0.32431800E-02, 0.56111900E-02, 0.76169200E-02, 0.37741400E-01, -.67411600E-01, 0.37044000E-01, -.40317900E-01, -.51822800E-01, -.37586800E-01, 0.75621100E-01, 0.21719000E-01, 0.27644500E-01, 0.22092500E-01, 0.35182100E-02, 0.46190700E-01, -.98118500E-01, -.43479300E-01, 0.65038900E-01, -.16739300E-01, 0.76050900E-02, -.32951900E-01, 0.56869100E-02, -.12254600E-01, -.54899000E-03, -.27210000E-02, 0.85294000E-02, -.10454900E-01, -.41836100E-02, -.18617800E-01, 0.43200500E-02, -.26372200E-02, 0.13879400E-01, 0.75445900E-02, -.44916500E-01, 0.14656800E-02, 0.21025600E-02, -.12261000E-03, -.83462700E-02, 0.49529500E-02, -.26520000E-01, -.15416700E-01, 0.27281700E+00, -.25908800E-02, -.22338200E-03, -.63061700E-03, -.12382000E-01, 0.11496600E-02, 0.19164800E-01, 0.29991700E-01, 0.37802100E-03, -.12250100E-01, -.16654900E-01, 0.31195200E-03, 0.22286400E-01, 0.45994100E-03, -.29368600E-01, 0.14981400E-01, 0.83475200E-02, 0.24843900E-01, -.44075700E-02, 0.15453900E-01, 0.31155600E-01, -.13695100E-01, -.17081200E-03, 0.61447100E-03, -.82716400E-03, -.42510800E-01, -.90720600E-02, 0.15363900E-01, -.73776300E-03, -.10832000E-02 }, { -.97542300E+00, -.33221000E+00, 0.96881000E+00, 0.51073600E+00, 0.32609700E+00, 0.26179400E+00, -.32859600E+01, -.10958500E+01, 0.18221900E+00, -.33583600E+00, 0.71394900E-01, 0.10204800E+01, 0.12578500E+00, 0.24075700E+01, -.94632300E+00, -.45409000E+00, -.54521100E+00, -.35781500E+00, -.34256500E+00, 0.28544600E-01, 0.92564900E-02, 0.77265600E-01, 0.48515600E+00, 0.10848500E+00, 0.61463200E-01, 0.20519900E-01, -.45442400E+00, -.18168700E+00, -.26429500E+00, -.12449900E+00, -.13815200E+01, 0.25664400E+00, -.14665900E+00, 0.20743700E+00, 0.21349900E+01, 0.38368400E+00, -.91848700E-01, 0.46203500E+00, 0.29637900E+00, 0.67905700E-02, 0.22105900E+00, -.28052200E-01, 0.91394500E-01, 0.18935300E+00, 0.94522900E-01, -.75851100E+00, 0.12256000E+00, 0.12911200E+01, -.76071800E-03, -.21117900E-01, 0.54896900E-01, 0.89856500E-01, -.11187300E+00, -.82377000E-01, 0.87802000E+00, 0.92444700E-01, -.37733200E-01, -.21661700E+00, -.58778100E-01, 0.18649500E+00, -.36335600E-02, -.26215000E-01, 0.24144500E+00, 0.83819600E+00, -.10001900E+00, -.63732500E-01, 0.50424800E-01, -.32049900E+00, -.30339000E+00, 0.40347300E-01, 0.43241200E+00, -.42937100E+00, -.21353500E+00, 0.12902600E+00, -.10563700E+00, 0.11610100E+00, 0.97200300E-01, -.13881900E+00, 0.63900800E-01, -.31768800E+00, -.10202700E+00, 0.35695700E-01, 0.27552800E+00, 0.28327200E-01, -.10662200E-01, 0.67753600E-01, -.37328700E-01, 0.19996500E-01, -.33686400E-01, -.34792900E+00, 0.19954900E+00, -.70446400E-02, -.24560300E-01, -.58015900E-01, 0.11546600E+01, -.14883800E+00, -.80642000E+00, -.16681200E-01, 0.56360300E-01, 0.72196600E+00, -.15223400E+00, -.27123000E+00, -.87631900E-01, -.71207100E-01, 0.29689600E-01, 0.10593200E+00, -.98750700E-01, 0.10055800E+00, -.21179800E-01, 0.19609900E+00, -.12433900E+00, -.10129500E+00, -.23762700E+00, -.13229400E+00, -.53017000E-01, -.21481000E-01, -.66363800E-01, -.13050400E+00, 0.20528100E-01, -.62883200E-01, -.18274200E+00, -.26588300E-01, 0.23738700E-01, -.22062500E-01, -.14494600E-02, -.17546000E-01, -.39734400E-01, -.15280100E-01, -.71322000E-01, 0.34537600E-01, 0.93331900E-01, 0.25594700E-01, 0.51855000E+00, 0.50791300E-01, -.24693500E-01, 0.15824000E-01, 0.43833600E-02, 0.33251900E-02, -.49056900E-02, -.43297200E-02, -.19200900E-01, 0.32099000E-01, 0.14853300E-01, -.40253100E-02, 0.42837500E-02, 0.33251500E-02, -.51738200E-02, -.45586700E-02, -.18509200E-01, 0.31619000E-01, 0.15853800E-01, -.48332100E-02, -.66433400E-02, -.11148300E-01, -.44383100E-01, 0.27398800E-01, -.20132000E-01, 0.24831800E-01, -.84732000E-01, 0.44021900E-01, -.69612300E-01, 0.12295400E-01, -.64511300E-01, -.33622700E-01, -.13929100E+00, -.14705200E-01, -.95005300E-01, -.53172300E-01, 0.28006500E-01, -.85018700E-01, 0.97802500E-01, 0.65765500E-01, -.87662900E-01, 0.96231100E-01, 0.13171000E-01, 0.99922300E-01, -.45942800E-01, -.34964700E-01, 0.24217900E-01, -.51165900E-01, -.18211200E-01, 0.66901400E-02, -.30821500E+00, 0.15971600E-01, -.12065300E-01, -.27065500E-01, 0.30618900E-01, 0.48945800E-01, 0.17242400E-01, -.24355400E-01, -.86388800E-01, 0.14229200E+00, 0.22006400E-01, 0.51537100E-01, -.52566200E-01, -.76228300E-01, -.48432500E-01, 0.12798300E+01, 0.33748700E-01, -.32505500E-01, 0.31034300E-01, 0.30613100E-01, -.14276800E+00, -.12172800E+00, 0.27666300E-01, 0.29819400E-01, -.66704100E-01, -.25784300E-01, 0.89125900E-01, 0.24704200E-01, -.31956100E-01, -.11600600E+00, 0.26125900E-01, -.58905800E-02, 0.11132100E+00, 0.15565600E-01, -.24753000E-01, -.20084300E-01, 0.15401300E-01, 0.19288500E-01, 0.40548200E-01, 0.15144800E+00, 0.20774000E+00, -.14602800E-02, -.29284100E-01, 0.24373700E-01 }, { 0.21797200E-01, -.55764500E-01, 0.23602100E+00, 0.24970700E+00, 0.10366100E+00, -.82742000E+00, 0.28963500E+00, -.52309600E-01, 0.10271200E+00, -.13590800E-01, -.20144300E-02, 0.59057000E-01, 0.13083900E+00, -.17503100E+00, -.14004600E+00, 0.18143100E-01, 0.12161500E+00, -.36256500E-01, 0.35693900E-02, -.12019400E-01, 0.49010200E-01, -.10423800E-01, -.20074100E-02, -.18054700E-01, 0.53333900E-02, -.72526000E-02, -.15170800E-01, -.16796400E-01, -.57346300E-01, -.29829000E-01, -.38989400E+00, 0.30957400E-01, 0.66808500E-01, 0.29476000E-01, 0.10482300E+01, -.90084600E-03, 0.72310200E-03, -.77511200E-02, 0.20030600E-01, 0.22625600E-02, -.51739900E-04, -.88044700E-02, -.17385000E-02, 0.86288900E-02, 0.28867400E-02, -.11119500E-01, -.42882900E-02, 0.26493000E-01, 0.26368700E-03, -.90040800E-03, 0.75662800E-02, 0.48456600E-02, -.41082600E-02, -.37026600E-02, -.61156400E+00, 0.19350700E-02, -.26525200E-02, -.52959600E-02, 0.14460600E-02, 0.81122200E-02, 0.16973200E-01, 0.28306500E-02, -.18851900E-01, -.18593600E-01, 0.23310800E-01, -.32621000E-02, -.24767300E-02, 0.18531000E-01, -.86785200E-02, -.47822300E-02, 0.33514500E+00, -.21151900E-01, -.44629600E-02, -.37620600E-02, 0.19506100E-01, 0.83097800E-02, 0.43336900E-01, -.16447300E-01, 0.10326000E-01, 0.34427600E-01, 0.24363000E-01, -.75313700E-02, -.37888600E-01, -.61385900E-03, -.30263000E-03, -.19043500E-01, 0.79793300E-03, 0.71760700E-02, -.21189300E-02, 0.17194100E+00, -.71158800E-01, -.48833300E-02, -.99956200E-02, -.44050500E-02, -.13738900E+00, -.26601900E-01, -.21587600E-01, -.39848600E-02, 0.14572100E-01, 0.44416400E-01, 0.87848100E-02, 0.67953200E-02, -.29096700E-02, 0.18884900E-02, -.39152900E-02, -.31264900E-02, 0.13605800E-01, 0.15706600E-01, 0.65241900E-01, -.48199100E-01, -.31153700E-02, 0.25049000E-02, -.90551000E-02, 0.13565900E-01, 0.28715500E-01, 0.33364700E-02, 0.28799900E-02, 0.21874100E-01, -.48418800E-02, 0.10852200E-01, 0.15517400E-01, -.31243100E-01, 0.22141000E-01, 0.68012600E-02, 0.14991200E-01, 0.93800400E-02, 0.36149100E-01, -.13859700E-01, 0.14504700E+00, -.71467000E-02, -.15671300E-01, -.94093600E-02, 0.83709800E+00, -.37536300E-02, -.14560400E-02, -.33297400E-03, -.53594700E-03, 0.10458600E-03, 0.43207900E-04, 0.75401700E-03, 0.80932900E-03, -.16235700E-03, 0.31791300E-02, 0.26975600E-02, -.53055900E-03, 0.98305700E-04, 0.54607900E-05, 0.74227100E-03, 0.79380200E-03, -.15769700E-03, 0.31776900E-02, 0.26812200E-02, -.30698200E-03, -.69649400E-03, -.20690800E-02, 0.41337400E-03, 0.24342100E-03, 0.14611400E-03, -.18973600E-02, 0.46361200E-02, -.44299600E-02, 0.16470600E-03, -.15968200E-04, 0.16390900E-02, -.58753900E-02, -.23309400E-03, -.26709100E-02, -.10913300E-02, -.50247400E-03, -.40297400E-02, 0.74230100E-02, 0.37142400E-02, 0.34392900E-02, 0.92230100E-03, 0.23734800E-01, 0.13717800E-01, 0.90163000E-02, 0.10820700E-01, 0.52946800E-02, 0.10084200E-01, -.20092300E-01, 0.10742500E-01, 0.59646400E-01, -.31617100E-02, 0.27655400E-02, 0.25509400E-02, -.84312000E-03, -.35150900E-02, -.58062400E-02, -.56975900E-03, -.63554800E-01, -.27869700E-01, -.47820800E-02, -.43010900E-02, -.24212500E-03, 0.37984700E-02, 0.94227000E-02, 0.24781700E-02, 0.26271000E+00, 0.66143500E-02, -.61103100E-02, -.36694100E-03, -.41679200E-01, 0.81977200E-02, 0.45868100E-03, 0.66306600E-02, 0.13733700E-02, -.12202000E-02, -.12218300E-02, 0.30182000E-03, -.19657700E-01, 0.14066400E-01, 0.65710200E-02, 0.12172600E-01, 0.35652300E-01, 0.15062500E-01, -.26551400E-02, -.12887700E-01, 0.14786800E-03, -.24211600E-03, 0.19739700E-01, 0.15202800E-01, -.36636600E-01, -.10748600E-01, 0.13272400E-04, 0.19581700E-02 }, { 0.40904300E+00, 0.17018200E+00, -.74761800E+00, -.31654600E+00, -.28368600E+00, -.17213900E+01, -.13088600E+01, 0.50208500E+00, -.45649800E-01, 0.11181700E+00, -.13150800E-01, -.23067800E+00, 0.14005700E+00, -.12136500E+01, 0.22707700E+00, 0.52107500E+00, 0.46681600E+00, 0.20444500E+00, 0.60976800E-01, -.75248800E-01, -.52739300E-02, 0.74814500E-02, -.11948100E+00, -.11963400E+00, -.56775400E-02, -.34244100E-01, 0.20249900E+00, 0.69198600E-01, -.17872300E-01, 0.82972300E-03, 0.14718600E+00, -.66854900E-01, 0.12565600E+00, -.12657600E-01, 0.41003600E+00, -.12899500E+00, 0.28457000E-01, -.10566600E+00, 0.78972300E-01, 0.88533700E-02, -.34502700E-01, -.70225100E-01, -.18100700E+00, -.39239300E-01, 0.94931900E-02, 0.20443300E+00, -.60994100E-01, -.21175600E+00, 0.42440600E-02, 0.15207200E-02, 0.24759200E-01, -.64662400E-02, -.30224900E-01, 0.25653200E-02, -.79826100E+00, -.30268900E-01, -.14381700E-01, 0.78768800E-01, 0.14134400E-01, -.86836800E-01, 0.39673500E-01, 0.17798500E-01, -.11407600E+00, -.34567000E+00, 0.63741400E-01, 0.23018700E-01, -.12380600E-01, 0.14283900E+00, 0.98995700E-01, -.21503100E-01, 0.24607000E+00, 0.14369400E+00, 0.53269500E-01, -.41141400E-01, 0.31899800E-01, -.20001200E-01, 0.29589400E-01, -.23632500E-02, 0.35533300E-02, 0.55686400E-01, 0.41873200E-01, 0.15233300E-01, -.61961900E-02, -.11340100E-01, -.33672800E-01, -.14088300E-01, 0.35487500E-01, -.33115900E-01, 0.68682900E-02, -.34954400E-01, -.10236700E+00, 0.22817600E-01, 0.13959500E-02, 0.25797100E-01, -.27550900E+00, -.74476300E-01, 0.25847400E+00, 0.25595700E-02, 0.29776900E-02, -.23326900E+00, 0.48649800E-01, 0.75305300E-01, 0.16986000E-01, 0.14384100E-01, -.87584900E-02, -.25160800E-01, 0.30418500E-01, 0.27526000E-02, 0.10508500E+00, -.76631800E-01, 0.20197300E-01, 0.33807200E-01, 0.88699900E-01, 0.92621300E-01, 0.44348800E-01, 0.16008900E-02, 0.22960300E-01, 0.59291300E-01, -.19033500E-01, 0.25132100E-01, 0.58379200E-01, -.39054100E-01, 0.27714600E-01, -.15514400E-01, 0.70925100E-01, 0.90590200E-02, 0.59082900E-01, -.10348900E-01, 0.13229500E+00, -.33360700E-01, -.21626100E-01, -.12810700E-01, -.13822700E+00, -.33935900E-01, 0.41029100E-01, -.45090900E-02, -.48015700E-02, 0.87722800E-04, 0.13655500E-01, 0.40800800E-02, -.97723900E-03, -.57947400E-02, -.37538400E-01, 0.64669700E-02, -.47370400E-02, 0.10098200E-03, 0.13408500E-01, 0.42673500E-02, -.10602200E-02, -.56958500E-02, -.37332700E-01, 0.72340000E-02, 0.16334500E-02, 0.43436300E-02, 0.28035300E-02, 0.81652200E-04, 0.21996200E-01, -.35836800E-02, 0.41119800E-02, 0.20265500E-01, -.78149500E-02, -.27637800E-02, -.43256200E-03, -.86232400E-03, 0.34522000E-01, 0.89680000E-02, 0.41151000E-01, 0.16097800E-01, -.19442100E-01, 0.21822000E-01, 0.17142100E-01, 0.20214600E-01, 0.35596500E-01, -.30032900E-01, 0.99896400E-02, 0.13233700E-01, 0.22620400E-01, 0.18308800E-01, 0.13600100E-03, 0.31803900E-01, -.13200800E-01, 0.20981600E-01, 0.17973800E+00, -.59614600E-02, 0.67090700E-02, 0.40053200E-02, -.18715100E-01, -.20417600E-01, -.71492300E-03, 0.47914900E-02, 0.24830900E-02, -.76896000E-01, -.11752100E-01, -.79666000E-02, 0.32856000E-01, 0.34117400E-01, 0.45777800E-02, -.73510400E-02, 0.14530200E-02, 0.15864400E+00, -.17986900E-01, -.76387100E-02, -.85544000E-02, 0.13487800E-01, -.76218600E-02, 0.13995800E-01, 0.15427900E-01, 0.75481400E-02, -.19450200E-01, -.67499900E-02, -.19416500E-02, 0.36144900E-01, 0.29817800E-02, 0.84443900E-02, 0.10789000E-01, 0.61128700E-02, 0.36503700E-02, -.24741400E-02, -.42898200E-02, -.47713800E-02, 0.80807000E-02, -.48300000E-02, -.26319800E-01, -.15436200E-01, 0.76855200E-02, -.72572400E-02 }, { -.79865800E+01, -.23053200E+01, 0.55017700E+01, 0.25853700E+01, 0.25490200E+01, 0.18864000E+02, 0.15097700E+02, -.39005500E+01, 0.91022000E+01, 0.20842700E+01, -.33850700E+01, -.83761900E+00, -.53477700E+01, 0.34524600E+02, -.96740000E+01, -.31927400E+02, -.19554900E+02, -.13072200E+02, 0.19082600E+01, 0.67448500E+01, -.23779000E+01, -.21913400E+01, 0.16478200E+01, 0.22177400E+01, 0.75004800E+00, 0.97237100E+00, -.65551100E+01, -.19435900E+01, 0.10310500E+02, -.32444400E+00, 0.19407900E+02, -.17367900E+01, -.45571300E+01, 0.26212500E+00, -.48651200E+01, 0.26811200E+01, 0.82509600E+00, -.31658400E+00, 0.47148800E+01, -.13047500E+01, 0.30132400E+01, 0.35757700E+01, -.11092600E+01, -.17475000E+01, -.15461100E+01, -.80146800E+01, -.20656700E+00, 0.14841700E+02, 0.47565900E+00, -.45819000E+00, 0.12254500E+01, -.39049900E-01, -.45698700E+01, -.37243600E+00, 0.23910400E+02, -.18642500E+01, -.10739600E+01, 0.72616600E+01, -.28927400E+01, -.43072000E+01, 0.46759400E+01, -.11699400E+01, -.11962000E+01, 0.20010800E+01, 0.32473100E+01, -.42435100E+00, 0.66515200E+00, -.11545100E+01, -.17835600E+01, 0.12002700E+00, 0.52670700E+01, -.21848200E+01, -.19940200E+01, 0.18352800E+01, -.33743500E+00, 0.11187400E+01, 0.21770700E+01, -.24848800E+01, 0.26157900E+00, -.48078200E+01, 0.17201000E+01, 0.89083400E+00, 0.47254400E+01, 0.52781300E+00, -.25821900E+01, 0.18765900E+01, 0.58689900E+00, 0.30727400E+00, -.25530000E+00, -.16344600E+02, 0.33630200E+01, 0.39695900E+00, 0.17074500E+01, -.98475400E+00, -.87210800E+00, 0.24078400E+01, -.19438700E+01, -.19692100E+00, -.26085100E+01, -.68752000E+00, -.10737600E-01, 0.49260300E+01, 0.11198400E+01, -.23887000E+00, 0.47787600E-01, -.17718200E+01, 0.24534400E+01, -.27583300E+01, 0.26201900E+01, -.86551600E+00, -.10436800E+01, 0.36614300E+01, 0.14196300E+00, 0.20561400E+01, 0.57367100E+00, -.23461800E-01, -.74009100E+00, 0.13966200E+01, 0.12697000E+01, -.15547600E+00, 0.69477800E+00, -.31067300E+01, 0.12736400E+01, -.10055600E+01, 0.68439000E+00, 0.79237300E+00, -.20721000E+01, 0.13791400E+00, 0.27664900E+01, 0.16207700E+01, 0.99222700E+00, -.54038300E+00, -.35874800E+02, -.97179800E+01, 0.94801200E+00, 0.11466600E+01, 0.21126300E+00, -.18114500E+00, 0.67383500E+00, -.58297800E+00, 0.23607200E+00, -.41454800E-01, 0.34283100E+00, -.23779400E+01, 0.21083500E+00, -.17953400E+00, 0.67464500E+00, -.58272500E+00, 0.24173100E+00, -.35623800E-01, 0.33552900E+00, -.23953900E+01, 0.20383500E+00, 0.42862400E+00, 0.28907200E+00, 0.17493500E+01, 0.15492600E+00, 0.33271600E-01, -.56504500E+00, 0.22024500E+01, 0.30106000E+01, 0.48558700E+00, 0.12417400E+01, -.61699200E+00, 0.21837800E+01, -.55510000E+00, 0.18187600E+01, 0.62631000E+00, -.20584000E+00, 0.13426300E+01, -.20052500E+01, -.16294500E+01, 0.15667100E+01, -.39766500E+00, -.88121000E+00, -.24934900E+01, 0.37183700E+00, 0.12239600E+01, -.41185200E+00, 0.78054600E+00, 0.47996700E+00, 0.31967700E+00, 0.70460700E+01, 0.31867800E+00, -.29295100E+00, -.22269200E-01, 0.51795400E+00, -.62492100E+00, 0.14764200E+01, -.82549000E-01, 0.29420900E+01, -.33391500E+01, 0.46405700E+00, 0.12847200E+00, -.97018700E+00, 0.96071100E+00, -.24217700E+01, 0.17612600E+00, -.47822300E+01, 0.56868100E+01, 0.12528100E+01, -.43595700E+00, 0.82271800E+01, -.42830000E+01, -.54116100E+00, -.17645500E+01, -.23069400E+01, 0.63746800E+00, 0.23469400E+01, -.47349500E+00, 0.19542700E+01, 0.39357900E-01, -.81638700E+00, -.97756500E+00, -.46099600E+01, 0.73906600E+00, -.17591000E+01, 0.14069400E+01, -.28421900E+00, -.27423900E+00, -.13305100E+01, 0.39863500E+01, -.36239800E+01, -.14287900E+01, 0.48675500E+00, -.78755900E+00 }, { -.51758900E-01, 0.55110200E-01, 0.19734900E+00, 0.15257500E+00, 0.71920000E-01, 0.44072600E+00, 0.58703200E+00, -.77604500E-01, 0.23294400E-01, -.99825700E-01, 0.13379100E-01, 0.10285800E+00, -.63456500E-01, 0.47564600E+00, -.73513600E-01, -.13894000E+00, -.49260500E-01, -.59742900E-01, -.19320400E-01, 0.25122200E-01, -.34597600E-01, 0.15292400E-01, 0.76802700E-01, -.11192500E-01, 0.79405400E-02, -.71376600E-02, -.34505100E-02, -.98520600E-03, -.15170100E-01, -.11672300E-01, -.10270600E+00, 0.24144800E-01, -.17722900E-01, 0.13919600E-01, 0.53711700E-01, 0.38786600E-01, -.52608100E-02, 0.40337200E-01, 0.29097700E-01, -.15825800E-02, 0.20419900E-01, -.71621500E-02, -.62375300E-02, 0.36209700E-01, 0.16496900E-01, -.76329100E-01, 0.15811500E-01, 0.89659500E-01, -.79068100E-03, -.12737800E-02, 0.65314000E-02, 0.12825300E-01, -.11646500E-01, -.98089400E-02, 0.23227100E+00, 0.15870500E-01, -.65444500E-02, -.17179200E-01, 0.10029600E-01, 0.41456200E-01, 0.27154200E-01, 0.40295500E-02, 0.93442500E-02, 0.70665200E-01, 0.10083300E-01, -.68042200E-02, 0.42674200E-02, -.29077900E-01, -.32337100E-01, 0.37483700E-02, -.47125800E-02, -.42349500E-01, -.19176400E-01, 0.12444700E-01, -.20957800E-01, 0.89922600E-02, 0.20469700E-01, -.18580600E-01, 0.19099200E-01, -.56500300E-02, -.11045600E-01, 0.40634400E-02, 0.19891600E-01, 0.30594600E-02, -.81965700E-02, -.61710500E-02, 0.19991700E-02, 0.12846400E-01, -.47484900E-02, -.11916100E+00, 0.23981500E-01, -.29916200E-02, -.11536700E-02, -.38269500E-02, 0.29866400E-03, -.26754500E-02, -.18768000E-01, -.11583000E-02, 0.23847100E-03, 0.38817100E-01, -.21106500E-02, -.17317700E-01, -.54630300E-03, -.56553300E-02, 0.13274400E-02, 0.60152400E-02, -.12589900E-01, 0.34580000E-02, -.21098300E-01, 0.32108700E-01, -.92665000E-02, -.42179800E-04, -.13522100E-01, -.53896100E-03, 0.20725900E-02, -.39353500E-02, -.27335400E-02, -.10772400E-01, -.72717400E-03, -.23847700E-02, -.16932500E-01, -.41539600E-02, 0.38187700E-02, -.67099800E-02, 0.19852000E-01, -.56002300E-03, 0.41148300E-02, -.14797400E-02, -.20118900E-01, -.55806100E-03, 0.17341900E-02, 0.27050800E-02, -.11225000E-01, -.11592300E-01, -.31253500E-02, 0.26415200E-02, 0.20934200E-03, 0.19923000E-02, -.29596900E-02, -.15415000E-02, 0.64929600E-03, 0.43909200E-02, -.44037600E-02, 0.29658800E-03, 0.20743100E-03, 0.19720900E-02, -.29561200E-02, -.14761600E-02, 0.60598400E-03, 0.43046200E-02, -.44339200E-02, 0.56661000E-03, 0.81988200E-04, -.12792800E-02, -.94407400E-02, -.33166400E-02, 0.14480900E-02, 0.38361100E-02, -.55542300E-02, -.70399900E-02, -.44847500E-02, -.31348300E-02, -.14365100E-01, -.40200000E-02, -.75748100E-02, 0.31995300E-02, -.53685900E-02, -.25267700E-02, 0.12833700E-02, -.36185700E-02, 0.53130200E-02, 0.74377400E-02, 0.21886500E-03, 0.68893300E-02, 0.94757900E-03, 0.17508600E-01, -.29802100E-02, -.48348000E-02, 0.23506600E-02, -.26510600E-02, -.22807000E-02, 0.22916300E-02, -.15758700E-01, -.87282600E-03, -.57484600E-03, -.36620300E-02, 0.34807700E-02, 0.49653900E-02, -.19783500E-02, -.22732600E-02, -.23996800E-02, 0.83454600E-02, 0.10402200E-02, 0.67579600E-02, -.59296600E-02, -.75378300E-02, 0.20763700E-02, 0.38395900E-02, 0.12660900E-02, -.91992700E-02, 0.62489100E-03, 0.36536400E-01, -.23446100E-01, -.88124000E-02, 0.23947800E-02, 0.34911600E-02, -.43562500E-02, -.19977900E-02, 0.23475400E-02, 0.21792000E-02, -.59787300E-02, -.91066200E-02, 0.42666000E-02, 0.14981400E-02, 0.18476400E-01, -.86930400E-03, 0.79362000E-03, -.42448800E-02, 0.12964800E-02, 0.18641500E-02, 0.43664100E-02, 0.10651600E-01, -.15897200E-01, -.68446100E-03, -.26879700E-02, 0.16834400E-02 }, { -.13352800E+02, -.44813400E+01, 0.14402400E+02, 0.72408100E+01, 0.73392000E+01, 0.40212800E+02, 0.38316200E+02, -.88532700E+01, 0.36290000E+01, -.53851200E+01, -.30298700E+00, -.40709600E+00, -.10712300E+02, 0.47679500E+02, -.28771000E+01, -.32271300E+02, -.18358800E+02, -.12306400E+02, 0.99178300E+00, 0.58227100E+01, 0.17995800E+01, -.23279900E+01, -.55046100E+00, 0.41590900E+01, -.57702200E+00, 0.16951200E+00, -.49582000E+01, -.14626000E+01, 0.12040200E+02, 0.15884700E+01, 0.22120200E+02, 0.68899100E+00, -.58642400E+01, -.16582300E+01, -.46840700E+02, 0.38213600E+01, -.31795600E+00, -.51785100E+00, -.68878600E+00, -.51510200E+00, 0.32649000E+01, 0.15243600E+01, 0.27564500E+02, -.30180000E+01, 0.23848200E+01, -.21108400E+02, 0.33525500E+01, 0.91874700E+01, 0.62101700E+00, -.80032400E+00, 0.75325300E+00, -.44417000E+00, -.51557700E+01, 0.78069000E+00, 0.25727800E+02, -.35665800E+01, -.43297000E+00, 0.13957700E+01, -.49018000E+01, -.27364800E+01, 0.90701200E+01, 0.17635800E+00, -.21103400E+01, 0.22405400E+01, 0.46119300E+01, -.24619100E+00, 0.27007900E-01, -.17442000E+01, -.18584000E+01, 0.53618300E+00, -.16862000E+02, -.77868400E+00, -.17387000E+01, 0.31868700E+01, -.10915600E+01, -.17381300E+01, 0.42568800E+01, -.13181700E+01, -.60398600E+01, 0.27398900E+00, -.91622100E+01, 0.38956800E+00, -.14236300E+01, 0.69629100E-01, 0.27624800E+01, -.30508900E+01, -.10206000E+01, 0.44391100E+01, -.45163100E+00, 0.33841600E+00, 0.52044900E+01, -.17230900E+00, -.19827100E+01, 0.30482600E+01, 0.32419400E+01, -.28907300E+01, 0.17749600E+00, 0.12395500E+01, 0.11655800E+00, 0.20516500E+01, -.47370600E+01, -.52980100E+01, -.12092500E+01, -.64097300E+00, -.11044400E-01, 0.15590200E+01, 0.20497700E+01, 0.28319500E+01, -.17337200E+01, -.16303300E+01, 0.18693200E+01, -.35429600E+01, 0.23346200E+01, -.30407400E+01, 0.44329900E+00, 0.17815000E+00, -.17977200E+01, 0.39275300E+01, -.25068000E+01, 0.17324700E+01, 0.21647800E+01, 0.26030500E+01, 0.86884700E+00, 0.86284100E-01, 0.13894600E+01, -.18684400E+01, 0.44722100E+01, -.48731500E+00, 0.62871200E+01, -.50854000E+01, 0.18964700E+01, -.11791200E+01, -.32121700E+01, 0.71403700E+01, 0.26563800E+01, -.22093500E+01, 0.17651100E+00, -.28339200E+00, -.25042300E+00, -.56930600E+00, 0.14388000E+01, 0.50041800E+00, -.32222500E+01, -.35537700E+00, 0.16627200E+00, -.28062000E+00, -.24414500E+00, -.55691700E+00, 0.14301900E+01, 0.48411100E+00, -.32327600E+01, -.30197600E+00, -.28235800E+00, -.17138000E+00, -.17898600E+01, 0.14327000E+01, 0.11342700E+01, 0.11347600E+01, 0.71842000E+00, -.12486100E+01, 0.97763400E+00, 0.20629800E+01, 0.75669500E+00, 0.32568000E+00, 0.12525300E+01, -.38382800E+01, 0.16623000E+01, 0.43861000E+00, -.70517400E+00, 0.42360600E+00, 0.71777500E-01, -.51751400E+00, 0.25060200E+01, -.23804100E+00, -.11104200E+01, -.82405800E+00, -.10467400E+01, -.43912600E+01, -.51160500E+00, -.12280300E+01, 0.33891300E+01, -.14256200E+01, -.30966600E+01, -.80349400E+00, 0.68267800E+00, 0.54221100E+00, -.14848700E+01, -.21129800E+00, -.14245500E+01, 0.13645600E-01, -.92617500E+00, 0.10583600E+01, -.12550100E+01, -.11093000E+01, 0.26326600E+01, 0.11782200E+00, 0.29697000E+01, 0.79932600E-01, 0.21406900E+01, -.30623800E+01, -.16121000E+01, -.24625200E+02, 0.12998900E+02, 0.27037500E+01, -.85897600E+00, -.35207000E+00, 0.23447100E+00, 0.89739900E+00, -.89717700E+00, -.75882400E+00, 0.12298700E+01, 0.32144100E+01, 0.32273500E+00, 0.76046600E+00, -.67558300E+01, 0.96266900E+01, -.46425700E+00, 0.13554500E+01, -.46101500E+00, -.51732800E+00, -.84301500E+00, -.31397100E+01, -.97377900E+01, 0.12909100E+01, 0.84270900E+00, -.99280300E+00 }, { -.23179000E+01, -.77598900E+00, 0.19383800E+01, 0.94120200E+00, 0.67173800E+00, 0.50881700E+01, 0.46912500E+01, -.13521700E+01, 0.63230700E+00, -.90279700E+00, -.69690200E-01, 0.19619800E+00, -.14873000E+01, 0.77682400E+01, -.10377600E+01, -.55374300E+01, -.30116700E+01, -.22930500E+01, -.32027500E+00, 0.12200600E+01, -.23747900E+00, -.19256900E+00, 0.12942600E+00, 0.86171600E+00, -.61672100E-01, 0.27433500E+00, -.82630900E+00, -.27254500E+00, 0.16225100E+01, 0.17635800E+00, 0.34299600E+01, -.38832500E-01, -.10546400E+01, -.22724400E+00, -.49279100E+01, 0.68830500E+00, 0.12224600E-01, 0.31517400E+00, 0.31754900E+00, -.15599700E+00, 0.43793700E+00, 0.26955700E+00, 0.13336100E+01, 0.82541200E-01, 0.14455200E+00, -.23868000E+01, 0.44534900E+00, 0.21058100E+01, 0.43991900E-01, -.66618500E-01, 0.12805400E+00, 0.79123500E-01, -.53325000E+00, -.38366200E-01, 0.64218600E+01, -.16297100E+00, -.10179400E+00, 0.17199500E+00, -.32273800E+00, -.20082400E+00, 0.46208000E+00, -.10774000E+00, 0.12923000E+00, 0.13339200E+01, 0.30792800E+00, -.12500900E+00, 0.49086000E-01, -.53619100E+00, -.56362200E+00, 0.79978900E-01, -.14799700E+01, -.78339800E+00, -.33053200E+00, 0.34216500E+00, -.10171100E+00, 0.48238800E-01, -.34004200E-01, -.61874800E-01, -.13091600E+00, -.61671300E-01, -.32800400E+00, -.11675500E+00, -.29981700E-01, 0.36691700E-01, 0.15176000E+00, -.55306100E+00, -.15239100E+00, 0.46992300E+00, -.80030800E-01, 0.73519300E+00, -.12817000E-01, -.61609800E-01, -.58470400E-01, -.19834200E+00, 0.24990100E+00, 0.17329900E+00, -.68799400E+00, 0.44743700E-01, -.11062800E+00, -.45338000E+00, -.36282800E+00, -.77350200E+00, -.95523100E-01, -.13377100E+00, 0.41378500E-01, -.51256000E-02, -.10603700E+00, 0.13995300E-01, 0.16418600E+00, 0.40130400E+00, 0.22868200E+00, -.21077600E-02, 0.76825600E-01, -.74085900E-01, -.16810100E+00, -.99706200E-02, -.14096200E+00, 0.94479400E-01, 0.12320400E-01, 0.10563300E+00, -.73843600E-02, 0.33292300E+00, -.36971100E-01, 0.31600200E-01, -.11934300E+00, -.11632000E+00, 0.25562600E+00, -.75989100E-02, -.22642200E+00, -.16427900E+00, 0.55438300E-01, 0.10527900E-01, -.45424300E+00, 0.45209000E+00, 0.10882500E+00, 0.37949400E-01, 0.14159000E-01, -.25027300E-01, -.46297800E-01, -.23762500E-01, -.69806700E-01, 0.36436800E-01, -.19103400E+00, 0.30755900E-01, 0.13353500E-01, -.24480400E-01, -.46527700E-01, -.23524300E-01, -.65873900E-01, 0.34883600E-01, -.18751700E+00, 0.30760200E-01, -.32386000E-01, 0.31362000E-03, -.93196000E-01, -.26257800E-01, 0.16533800E-01, 0.18382400E-04, -.84444400E-01, 0.12385500E+00, 0.75444400E-01, 0.10284800E+00, 0.21698000E+00, 0.97270000E-01, -.17136900E+00, -.14838200E+00, -.57040600E-01, -.98167000E-02, 0.46561700E-01, -.14537300E+00, 0.11181700E+00, -.68888900E-01, 0.24191300E+00, 0.84936800E-01, -.50107200E-01, -.16093400E+00, -.68404900E-01, -.47363000E-01, -.92883800E-02, -.33465900E-01, 0.32612200E-01, -.61753900E-02, -.20980300E+00, 0.24290900E-01, -.41213400E-01, 0.23561200E-01, 0.13536500E-01, 0.15576800E-01, 0.44278900E-02, -.12882500E-01, 0.88731100E-02, 0.72440600E-01, 0.72331500E-01, -.39522700E-01, -.22511300E-01, -.31585500E-01, 0.28711600E-03, 0.24040300E-01, -.30439600E-02, -.12282800E+00, 0.14240400E+00, 0.14887100E+01, -.89610100E-01, 0.95451800E+00, -.70703800E-02, 0.19759900E+00, 0.41087900E+00, -.61200400E-02, -.48452500E+00, -.73401800E-02, -.13725500E+00, 0.28932900E+00, 0.47905300E-01, 0.16109500E+00, 0.78183400E-01, 0.74629600E+00, 0.17604800E+00, -.14298700E-01, -.24969200E-02, -.14198300E-01, 0.11863000E+00, -.92820000E+00, -.36524100E+00, 0.31097700E+00, 0.15981000E-01, 0.18326600E-01 }, { -.78838600E-01, 0.16509700E-01, 0.23612800E+00, 0.16756100E+00, 0.90320800E-01, 0.50911200E+00, 0.72724100E+00, -.10334500E+00, 0.26810000E-01, -.77761400E-01, 0.80612300E-02, 0.79249900E-01, -.63338200E-01, 0.45257400E+00, -.75456100E-01, -.18413700E+00, -.95437600E-01, -.72826600E-01, -.18470200E-01, 0.35287900E-01, -.21515900E-01, 0.50247400E-02, 0.51463900E-01, 0.93596500E-02, 0.39560500E-02, 0.10091400E-02, -.23963700E-01, -.85136500E-02, -.19271700E-02, -.53499000E-02, -.67437400E-01, 0.20234400E-01, -.24488200E-01, 0.59578700E-02, -.29973100E-01, 0.38063900E-01, -.49264400E-02, 0.35308300E-01, 0.85205100E-02, -.39660000E-02, 0.16548200E-01, 0.67681100E-02, 0.11158200E-01, 0.27686600E-01, 0.99518300E-02, -.75836900E-01, 0.18415800E-01, 0.73526600E-01, -.75373300E-03, -.24600000E-03, 0.27655900E-02, 0.83220600E-02, -.55386400E-02, -.61459200E-02, 0.24476000E+00, 0.11637800E-01, -.36372400E-02, -.11092600E-01, 0.66057200E-02, 0.31024900E-01, 0.18370700E-01, -.25903700E-03, 0.11105000E-01, 0.72799400E-01, 0.80338300E-02, -.64811100E-02, 0.30458000E-02, -.29892000E-01, -.29858500E-01, 0.38820000E-02, -.16236600E-01, -.41037700E-01, -.16682100E-01, 0.12218300E-01, -.15352100E-01, 0.69837700E-02, 0.12446800E-01, -.12922400E-01, 0.93559100E-02, 0.28096400E-02, -.82370000E-02, 0.74918700E-04, 0.95839000E-02, 0.18012000E-02, -.36707500E-03, -.87616700E-02, -.44335900E-03, 0.12681000E-01, -.38149400E-02, -.62507200E-01, 0.19288900E-01, -.36527300E-02, -.16807000E-02, -.66217500E-02, 0.13019300E-01, 0.63657100E-02, -.32085000E-01, -.95257800E-03, -.11080700E-03, 0.40074800E-01, -.55630000E-02, -.20158600E-01, -.19963000E-02, -.54452900E-02, 0.14860100E-02, 0.39676400E-02, -.10226000E-01, 0.17777400E-02, -.20224500E-01, 0.27852500E-01, -.46940500E-02, -.74036400E-03, -.14159100E-01, -.49629200E-02, -.79469200E-03, -.30164300E-02, -.32745500E-02, -.10161600E-01, 0.14825100E-03, -.21962700E-02, -.14046500E-01, 0.11614800E-02, 0.14027200E-02, -.29583500E-02, 0.72619100E-02, -.13686000E-02, 0.25815600E-02, -.62479400E-03, -.15964000E-01, 0.10932300E-02, -.16302100E-02, 0.26499900E-02, 0.32376900E-01, -.13100100E-02, -.51851700E-02, 0.29599900E-02, 0.51379200E-03, 0.11038800E-02, -.32383600E-02, -.19245500E-02, 0.14482900E-02, 0.31483900E-02, 0.12871100E-02, -.19346100E-02, 0.50369400E-03, 0.10881200E-02, -.32076500E-02, -.18759500E-02, 0.13983000E-02, 0.30831200E-02, 0.11669500E-02, -.17425500E-02, -.38701100E-03, -.14044900E-02, -.81030600E-02, 0.36930000E-03, 0.17817900E-03, 0.22902500E-02, -.39791900E-02, -.51082900E-02, -.19609300E-02, -.12134600E-02, -.68354900E-02, -.10179200E-02, -.73394600E-02, 0.11137200E-02, -.50723000E-02, -.15293200E-02, 0.22957200E-02, -.45152300E-02, 0.15613000E-02, 0.14116600E-02, 0.97376300E-03, 0.67971700E-02, 0.38689700E-03, 0.73266600E-02, -.30506300E-02, -.37735100E-02, 0.14272500E-02, -.32104800E-02, -.10259700E-02, 0.11129500E-02, -.18637700E-01, -.15434900E-03, -.10727800E-02, -.22478400E-02, 0.38880100E-02, 0.46994300E-02, -.11928500E-02, -.18670700E-02, -.26552700E-02, 0.90483900E-02, 0.19121900E-02, 0.42017600E-02, -.67341400E-02, -.73318800E-02, 0.86910300E-03, 0.31240200E-02, 0.23351500E-02, -.11140000E-01, 0.20308000E-02, 0.78319800E-01, -.21004900E-02, 0.65651400E-02, 0.34341700E-01, 0.15337100E-02, -.18473700E-02, -.53811300E-03, 0.17072900E-03, 0.71389600E-03, -.24141600E-02, -.30145300E-02, 0.33538200E-02, 0.21280300E-02, 0.35608800E-02, 0.12807400E-01, 0.42770700E-03, -.75919600E-03, 0.43499800E-03, 0.67718800E-03, 0.14069800E-02, 0.85628400E-03, -.29044800E-01, 0.22114900E-02, -.91450200E-03, 0.25901000E-03 }, { 0.85973700E+01, 0.31673500E+01, -.72495900E+01, -.27455600E+01, -.25627400E+01, -.18666100E+02, -.16301300E+02, 0.54887100E+01, -.23343800E+01, 0.43802700E+01, 0.35099200E-01, -.23487900E+01, 0.56580300E+01, -.31450100E+02, 0.60778600E+01, 0.19790300E+02, 0.11229900E+02, 0.10095200E+02, 0.16026300E+01, -.31353900E+01, 0.57676200E-02, 0.42067200E+00, -.13040700E+01, -.38573300E+01, 0.39311600E+00, -.11092700E+01, 0.10261000E+01, 0.10080000E+01, -.99192100E+01, -.82989900E+00, -.15627300E+02, 0.18525800E+00, 0.14036700E+01, 0.15958900E+01, -.13462600E+02, -.47929000E+00, 0.10753300E+00, 0.26645700E+01, -.26854500E+01, -.40448900E-01, -.38678800E+00, -.99288800E+00, 0.25180500E+01, -.54823200E+00, -.16896900E+00, 0.98518200E+01, -.16696400E+01, -.46719000E+01, -.30620500E+00, 0.16698800E+00, -.55582100E+00, 0.74458700E+00, 0.17777800E+01, -.51208600E+00, 0.12967900E+02, 0.20063000E+01, 0.35998800E-01, -.20162400E+01, 0.37508000E+01, 0.35799100E+01, 0.22997400E+01, 0.70777600E+00, 0.49427800E-01, 0.12025200E+01, 0.22335800E-01, -.35324700E+00, 0.49635300E+00, -.33586900E+00, -.18075200E+01, -.13203400E+00, -.31044800E+01, -.21350800E+01, -.13007700E+00, -.13058800E+00, -.37484600E+01, 0.59885600E-01, 0.25287100E+01, -.11873900E+01, 0.48886400E+01, -.53392100E+01, -.50988000E+00, 0.43426100E+00, 0.12704800E+01, 0.87286400E+00, -.95999400E+00, 0.18683800E+01, -.32050500E+00, -.52581100E+00, -.75800900E+00, -.36965000E+00, -.32541800E+01, 0.14823400E+01, -.68747900E+00, 0.63559500E+00, 0.10730600E+02, -.70808400E+01, -.20239400E+01, -.42070200E+00, 0.33128800E+00, -.13998100E+01, -.16854000E+01, -.35978200E+01, -.40881000E+00, -.10632300E+01, 0.65862100E-01, 0.15223500E+00, -.65354100E+00, 0.10756600E+01, 0.37093900E+01, 0.21238600E+01, -.40288400E+00, -.11004900E-01, 0.12559400E+01, 0.10216800E+01, -.89189900E+00, -.16497400E-01, -.57275100E+00, 0.78984300E+00, 0.10053100E+01, 0.72601500E+00, -.10518700E+01, -.14070900E+01, 0.85203300E+00, -.80467500E+00, 0.27532500E+01, -.58601200E+00, -.43688300E+00, 0.17718600E+00, -.88199200E+00, -.50887600E+00, -.12245000E+01, -.25446700E+00, -.29233000E+02, -.83635800E+00, 0.21416300E+01, 0.25138300E+00, 0.14322300E+00, -.44769400E-01, 0.10270800E+01, -.42862700E+00, 0.42782600E+00, 0.38763900E+00, -.35850400E+00, -.13428200E+01, 0.14116600E+00, -.44358600E-01, 0.10170700E+01, -.41975000E+00, 0.42717600E+00, 0.38044600E+00, -.35648400E+00, -.13290100E+01, 0.14315300E+00, 0.17355500E+00, 0.12231800E+01, -.16818400E+01, 0.12542800E+01, 0.76569800E+00, -.14845600E+01, 0.92981700E-01, -.16190600E+01, -.12655100E+00, 0.13906900E+01, 0.17055600E+01, -.12791300E+00, -.13099200E+01, 0.95834800E+00, 0.58970900E+00, -.63187700E+00, -.65533100E+00, 0.42784300E+01, 0.38766300E+00, 0.30838800E+01, 0.83329600E+00, -.21409700E+00, 0.26724700E+00, -.27051500E+00, -.63519900E+00, 0.11360800E+00, 0.33757700E+00, -.38625700E+00, 0.11174900E+01, 0.21883500E+01, -.55921600E+00, -.99137500E-01, -.26459300E+00, -.93865000E+00, 0.19721100E+00, 0.26118500E+00, -.30986500E+00, -.16460000E+00, -.88131400E+00, 0.17692200E+00, 0.51241700E+00, 0.17392200E+01, -.37841000E+00, -.40796500E+00, 0.57854200E+00, 0.30184300E+00, 0.16077900E+01, 0.39501300E+00, 0.82821600E+01, -.37951100E+00, 0.20597700E+01, -.11426300E+01, 0.47165400E+01, 0.84290900E-01, 0.72802200E-01, 0.24180700E+00, -.30733700E-01, -.12070100E+00, 0.58134800E+00, 0.22019100E+00, 0.32453000E+00, 0.95994800E+00, 0.30255600E+01, 0.98769900E-01, 0.25852000E+00, -.13541400E-01, 0.15289700E-01, 0.15499700E+01, 0.69969300E+00, -.26389500E+01, 0.46633400E-02, 0.12234200E-01, -.96128500E-01 }, { 0.49152800E+01, 0.15288800E+01, -.63724600E+01, -.19577500E+01, -.72898900E+00, -.13199400E+02, -.22158300E+02, 0.24429300E+01, -.25405400E+01, 0.36182100E+01, 0.29724900E+00, 0.34740900E+00, 0.66619600E+01, -.28307000E+02, 0.23759200E+01, 0.21513500E+02, 0.10142800E+02, 0.75081300E+01, -.79186800E+00, -.56663900E+01, 0.41491600E+01, 0.59981100E+00, -.19626200E+01, -.23935900E+01, 0.25660600E-01, -.11139700E+01, 0.11753800E+01, 0.67350000E+00, -.47134100E+01, -.63792700E+00, -.13766300E+02, 0.42763200E+00, 0.30854500E+01, 0.10281100E+01, 0.88171000E+01, -.12180200E+01, 0.14409500E+00, 0.55634700E+00, -.92368000E+00, 0.45153600E+00, -.75922700E+00, -.23707000E+00, -.68535900E+01, -.25923900E-01, -.93092200E+00, 0.72249100E+01, -.14780600E+01, -.60066800E+01, -.13963900E+00, 0.35954300E+00, -.91627000E+00, -.28584100E+00, 0.24335900E+01, 0.23158600E+00, -.12579600E+02, 0.56816500E+00, 0.24902100E+00, 0.32679200E+01, 0.17886000E+01, 0.11890700E+00, -.21102400E+01, -.19719500E+00, -.50690900E+00, -.47819400E+01, -.89523400E+00, 0.38439500E+00, -.55248300E+00, 0.25690000E+01, 0.21159300E+01, -.14145500E+00, 0.10937100E+02, 0.15530800E+01, 0.53257000E+00, -.90722500E+00, 0.66677400E+00, 0.67762700E+00, 0.18428800E+01, -.99066700E+00, -.17668900E+01, 0.19858800E+01, 0.40391300E+00, 0.10146500E+01, 0.88052600E+00, -.32551500E+00, -.49363500E+00, 0.37409500E+01, 0.81663900E+00, -.34646500E+01, 0.16986100E+00, 0.94643400E+00, 0.19112500E+01, 0.21676400E-02, -.18869600E+00, 0.68183100E+00, 0.81483000E+01, -.10001700E+00, -.33611000E+01, -.32184800E+00, 0.95407500E+00, 0.82815800E+01, -.36118700E+00, 0.34260700E+01, -.14638700E-01, 0.61334600E+00, -.45283900E+00, -.97454300E+00, 0.39823100E+00, 0.93673100E-01, 0.38045100E+01, -.54344000E+01, -.16403800E+00, -.93587200E+00, -.86962200E+00, 0.75730400E+00, 0.28369700E+01, -.10051700E+00, 0.65614100E+00, 0.17262900E+01, 0.12920800E+00, 0.11157600E+01, 0.50885300E+00, -.27876200E+00, 0.40603700E+00, -.19758700E-01, 0.21473600E+01, 0.19706200E+01, -.23783000E+01, 0.54221800E+00, 0.26378300E+01, -.86495600E+00, 0.18659900E+00, -.56751300E-01, -.72921200E+01, -.52328600E+01, -.16101700E+01, 0.10151500E+01, 0.45497100E-01, -.21979100E-01, -.29664800E-01, -.22954600E+00, 0.10549400E+01, -.15911300E+00, 0.15047800E+01, -.79077800E+00, 0.45525400E-01, -.24911100E-01, -.24998400E-01, -.22744000E+00, 0.10189900E+01, -.15420600E+00, 0.14551000E+01, -.78415300E+00, -.12608300E+00, -.50160700E-01, 0.48000400E-01, 0.37759400E+00, -.21737900E-01, 0.25849500E+00, -.65462700E-01, -.13216500E+01, 0.29946000E+00, 0.15177900E-02, -.80833400E+00, -.14269200E+01, 0.59909300E+00, -.15315000E+01, 0.63176400E+00, 0.73490600E+00, -.20629400E+00, 0.34452400E+00, -.71064100E+00, -.17393800E-01, -.73531800E+00, -.77777100E+00, -.59679800E+00, -.30092300E+00, -.87590100E+00, -.10337000E+01, 0.88611100E-01, -.12574800E+01, 0.46695100E+00, -.94810100E+00, -.36416100E+01, -.49761800E+00, 0.62979500E-01, -.19495200E+00, 0.30426500E+00, 0.38749400E+00, -.31348500E-01, 0.14066300E+00, -.53296000E+00, 0.16222900E+01, -.93326500E-01, 0.34764900E+00, -.61472300E+00, -.70471800E+00, -.13669200E+00, -.25311300E+00, 0.91596400E+00, -.28996300E+01, -.27220900E+00, 0.36081900E+01, 0.35534900E+00, 0.10852800E+01, 0.11834000E+02, -.11305300E+00, -.16871800E+01, -.37224500E+00, 0.24169300E+01, 0.34899000E+00, 0.11278800E-01, -.14754300E+01, -.16554100E+00, -.39009800E+00, -.84403000E+00, -.24764300E+01, -.52205600E+00, -.34739700E+00, 0.20137600E+00, 0.26453900E+00, -.23568000E+00, -.21778500E+01, 0.49321700E+01, -.20521600E+00, -.41352700E+00, 0.38755100E+00 }, { 0.88494400E-01, 0.65885600E-02, -.25573600E+00, -.17896700E+00, -.10289900E+00, -.53800600E+00, -.82640700E+00, 0.11097800E+00, -.26443500E-01, 0.56994100E-01, -.44944600E-02, -.61100800E-01, 0.54124300E-01, -.39268100E+00, 0.71491500E-01, 0.18661400E+00, 0.11159400E+00, 0.71580600E-01, 0.16684500E-01, -.35890600E-01, 0.10335300E-01, 0.14195400E-02, -.31798400E-01, -.20445800E-01, -.13643800E-02, -.57688500E-02, 0.34720200E-01, 0.12614900E-01, -.33231500E-02, 0.15776100E-02, 0.48330700E-01, -.16608700E-01, 0.25186000E-01, -.14944000E-02, 0.61168300E-01, -.34217500E-01, 0.45134900E-02, -.30062800E-01, 0.39017900E-02, 0.49075800E-02, -.12890500E-01, -.14097700E-01, -.18840600E-01, -.20731100E-01, -.52961500E-02, 0.68131100E-01, -.18217700E-01, -.58302000E-01, 0.73861800E-03, -.43827100E-03, -.32339500E-03, -.50607400E-02, 0.99959700E-03, 0.36213000E-02, -.22384600E+00, -.85698700E-02, 0.15436500E-02, 0.78804300E-02, -.43467500E-02, -.22789900E-01, -.10203400E-01, 0.27384300E-02, -.11792000E-01, -.67548100E-01, -.50054800E-02, 0.56916500E-02, -.21578600E-02, 0.27440100E-01, 0.25768800E-01, -.36203300E-02, 0.19346100E-01, 0.36700900E-01, 0.13739600E-01, -.10902000E-01, 0.10424900E-01, -.53869500E-02, -.74636300E-02, 0.87650900E-02, -.33144100E-02, -.64569900E-02, 0.65178100E-02, 0.20614300E-02, -.24559100E-02, -.10784000E-02, -.42502400E-02, 0.84468300E-02, 0.19716000E-02, -.10999300E-01, 0.29983000E-02, 0.20864300E-01, -.14671600E-01, 0.36764300E-02, 0.19957400E-02, 0.74304600E-02, -.21895400E-01, -.10233400E-01, 0.38752900E-01, 0.75667600E-03, 0.58249100E-04, -.38978100E-01, 0.75008300E-02, 0.20193400E-01, 0.29136000E-02, 0.48945400E-02, -.14230800E-02, -.26040900E-02, 0.79628700E-02, -.85012800E-03, 0.17076900E-01, -.22700600E-01, 0.21299400E-02, 0.14861100E-02, 0.13859900E-01, 0.75353100E-02, 0.22684400E-02, 0.22447000E-02, 0.33484500E-02, 0.93140800E-02, -.46398600E-03, 0.21627200E-02, 0.11558200E-01, -.37158600E-02, 0.39357200E-04, 0.43383800E-03, 0.65483500E-03, 0.17769000E-02, -.13428100E-02, 0.17750600E-03, 0.12532800E-01, -.19634500E-02, 0.31953100E-02, -.23868500E-02, -.60699700E-01, -.51416800E-02, 0.60369800E-02, -.27706100E-02, -.62565600E-03, -.51702200E-03, 0.30889400E-02, 0.19226200E-02, -.16064700E-02, -.21850300E-02, -.46344800E-02, 0.28978200E-02, -.61203900E-03, -.50514400E-03, 0.30465700E-02, 0.18890000E-02, -.15587400E-02, -.21373200E-02, -.44769400E-02, 0.27703300E-02, 0.65453800E-03, 0.14001700E-02, 0.65359700E-02, -.23946700E-02, 0.64821000E-03, -.12566000E-02, 0.29494300E-02, 0.34518800E-02, 0.87464900E-03, -.31281800E-04, 0.20941600E-02, -.87052900E-03, 0.70266000E-02, 0.12741700E-03, 0.47528100E-02, 0.98205700E-03, -.26586300E-02, 0.49397000E-02, 0.15806600E-03, 0.18327600E-02, -.63057900E-03, -.63652100E-02, -.18237600E-03, -.14433300E-02, 0.28629000E-02, 0.28108500E-02, -.85522700E-03, 0.33228700E-02, 0.38241000E-03, -.42234300E-03, 0.19075900E-01, -.29030300E-03, 0.12344800E-02, 0.12870400E-02, -.37470200E-02, -.42136200E-02, 0.49421100E-03, 0.15056300E-02, 0.31733400E-02, -.88648000E-02, -.22012500E-02, -.24513800E-02, 0.65480300E-02, 0.66998800E-02, 0.21629100E-03, -.25029000E-02, -.37446100E-02, 0.11622400E-01, -.25512600E-02, -.70624700E-01, 0.21345800E-02, -.11126600E-01, -.21526100E-01, -.11190700E-03, -.90443600E-03, 0.33870500E-01, 0.12404900E-02, -.35465100E-03, 0.12677900E-02, 0.20973600E-02, -.25091900E-02, -.15900300E-02, -.24480600E-02, -.10843300E-01, -.62617600E-03, -.11485600E-03, -.23796900E-03, -.31147300E-03, -.49365100E-03, -.27071700E-02, 0.31215500E-01, -.19190800E-02, 0.42069600E-03, -.10809000E-03 }, { -.20317900E+00, -.47671200E+00, 0.58329300E+00, 0.34456800E+00, -.23062500E-01, -.18589700E-01, 0.21926300E+00, -.49457900E+00, 0.59066600E-01, 0.28250000E+00, -.86551600E-01, -.18081500E+00, 0.67923300E-01, -.36687600E+00, -.32144400E+00, -.69736000E+00, -.52894200E+00, -.29548700E+00, -.42263500E-01, 0.67538300E-01, 0.65291800E-01, -.43804700E-01, -.17783900E-01, 0.18824400E+00, -.27595300E-01, 0.80744800E-01, -.94526500E-01, -.40648200E-01, 0.20616000E+00, 0.52503300E-01, 0.52208100E+00, -.19702100E-01, -.12706600E+00, -.71827500E-01, -.19615200E+00, 0.82645900E-01, 0.20814000E-01, 0.90330000E-01, -.28135500E-01, -.27696700E-01, 0.40036900E-01, 0.16384300E+00, -.27839000E+00, 0.12949700E+00, -.44390700E-01, -.22913800E+00, 0.77154700E-01, 0.19782800E+00, -.28068500E-02, 0.94354800E-02, 0.49769900E-02, 0.33434500E-02, -.11816600E-01, -.51444000E-02, 0.12642400E+01, 0.57406300E-02, -.36552300E-02, 0.33333000E-01, 0.42704400E-01, 0.38011500E-02, -.11909100E+00, -.30055000E-01, 0.39607000E-01, 0.56581500E-01, -.36512500E-01, -.71352900E-02, 0.86625700E-02, 0.64379800E-02, -.53525000E-01, 0.95813800E-02, -.31635700E+00, -.56910100E-01, -.11201800E-01, 0.26124000E-01, 0.49154600E-01, -.12219200E-01, -.69988800E-01, 0.33295300E-01, 0.33284600E-01, -.24473400E-01, -.14697700E+00, -.24346200E-01, -.16249400E+00, 0.16866300E-01, 0.33998600E-01, -.10342600E+00, -.48860900E-02, 0.98596300E-01, -.30957300E-01, 0.21425400E+00, 0.46224700E-01, -.29859400E-01, 0.26930500E-02, -.51557900E-01, -.57454400E+00, 0.19113300E+00, 0.30907300E-01, 0.34732600E-02, -.83642700E-01, -.12257900E+00, -.56300700E-01, -.72222800E-01, -.98119600E-03, -.36856700E-02, 0.10076800E-02, -.64070400E-01, -.13669900E-01, -.74297500E-01, 0.11249900E+00, 0.93469600E-01, 0.57845600E-01, 0.43207700E-01, 0.28875200E-01, 0.64708800E-01, 0.18173600E-01, -.12220100E-01, 0.47719000E-01, -.23672900E-01, -.21268800E-01, 0.11239000E-01, -.16948400E-01, -.10267600E-01, -.20483700E-01, 0.18595900E-01, 0.75911000E-01, -.84414100E-02, 0.20039500E-01, 0.18111400E-01, -.34126800E-01, -.53979700E-01, -.26993100E-01, -.13684000E-01, -.96391300E+00, 0.43918700E-01, -.31308700E-02, -.32726600E-01, -.25940200E-02, 0.60332800E-02, -.21818100E-01, -.45077100E-02, 0.89464000E-02, 0.67797100E-02, 0.10361500E+00, -.10503700E-01, -.25294100E-02, 0.58470300E-02, -.21693600E-01, -.42966300E-02, 0.87644500E-02, 0.66898700E-02, 0.10239200E+00, -.97298200E-02, 0.55421500E-02, -.57902300E-02, -.68050800E-01, -.98019700E-03, 0.56310000E-02, 0.38658600E-02, -.16704600E-01, 0.22895500E-01, -.43509900E-01, 0.30938800E-01, 0.13000600E-01, 0.54729300E-01, -.83068900E-01, -.66837700E-02, -.17043700E-01, -.23042700E-02, -.76710800E-02, -.46494200E-01, 0.55869300E-01, 0.35244100E-01, 0.29969500E-02, 0.19142900E-01, -.70261500E-02, 0.47758600E-01, -.52624900E-02, 0.52949600E-02, 0.14097900E-02, 0.38891800E-02, -.20334500E-01, 0.20889400E-01, 0.35762300E-01, 0.81604500E-02, -.46890500E-02, 0.10570300E-02, 0.71054500E-02, -.13281200E-02, 0.22271800E-01, -.33492700E-02, 0.13727000E-01, -.13004700E-01, 0.86824600E-02, -.20822400E-02, -.12384900E-01, 0.47606100E-02, -.42018100E-01, 0.60064800E-02, -.29226100E-01, 0.33174400E-01, 0.10074100E-01, 0.53077600E-01, -.94122300E-02, 0.21924000E-01, -.16136400E+00, -.90709500E-03, -.34729500E-01, -.21335200E+00, 0.12417500E+00, 0.72827800E-02, 0.11639100E-01, -.45531500E-01, -.72435000E-02, -.17222200E-01, -.18122600E-01, -.58415100E-01, -.36035300E-01, -.69378700E-02, 0.42198200E-02, 0.59165000E-02, -.19607000E-01, -.72429700E-01, 0.13463600E+00, -.12890500E-01, -.89186700E-02, 0.67399500E-02 }, { -.69386200E-01, 0.15717700E-01, 0.20907500E+00, 0.14711800E+00, 0.78722600E-01, 0.44828400E+00, 0.62741700E+00, -.94886300E-01, 0.23971900E-01, -.70847700E-01, 0.74898600E-02, 0.73230500E-01, -.57173700E-01, 0.41081000E+00, -.69490200E-01, -.16492800E+00, -.85579600E-01, -.64094300E-01, -.17118800E-01, 0.31711400E-01, -.20070600E-01, 0.49064900E-02, 0.47322900E-01, 0.71512900E-02, 0.36883300E-02, 0.74075600E-03, -.20674000E-01, -.74226900E-02, -.53710700E-02, -.50793600E-02, -.68689100E-01, 0.18712500E-01, -.20852700E-01, 0.55832900E-02, -.20997000E-01, 0.34246100E-01, -.44411200E-02, 0.32826900E-01, 0.70415700E-02, -.35946500E-02, 0.14460900E-01, 0.65581900E-02, 0.45831500E-02, 0.26088200E-01, 0.86043800E-02, -.65190100E-01, 0.16286200E-01, 0.64314300E-01, -.80897800E-03, 0.67359400E-04, 0.23671100E-02, 0.75866100E-02, -.39187200E-02, -.56759200E-02, 0.22123600E+00, 0.11269300E-01, -.33127700E-02, -.92149900E-02, 0.73468100E-02, 0.29117800E-01, 0.15958100E-01, -.26649100E-03, 0.96545600E-02, 0.64712100E-01, 0.74228900E-02, -.57561600E-02, 0.26311000E-02, -.26543800E-01, -.26596500E-01, 0.34454200E-02, -.10374000E-01, -.36717900E-01, -.14723500E-01, 0.10680800E-01, -.14027000E-01, 0.63901800E-02, 0.11556800E-01, -.11972700E-01, 0.81451500E-02, 0.47379700E-02, -.63686500E-02, 0.27159000E-03, 0.89128300E-02, 0.13186700E-02, -.33358000E-03, -.76973700E-02, 0.36363400E-03, 0.10961500E-01, -.32406100E-02, -.60273300E-01, 0.17938500E-01, -.32991000E-02, -.14051600E-02, -.61204200E-02, 0.10978400E-01, 0.62387100E-02, -.28225200E-01, -.10334500E-02, 0.15403600E-03, 0.38078500E-01, -.42065400E-02, -.17183500E-01, -.16736900E-02, -.47704100E-02, 0.13007600E-02, 0.36311300E-02, -.94149800E-02, 0.14511700E-02, -.19924700E-01, 0.25671400E-01, -.49712500E-02, -.53742600E-03, -.13446300E-01, -.42149200E-02, -.39178700E-04, -.29828200E-02, -.26297400E-02, -.10098800E-01, -.90067700E-04, -.23995100E-02, -.13165500E-01, 0.27640800E-03, 0.14652100E-02, -.29065000E-02, 0.70924600E-02, -.10360900E-02, 0.20645200E-02, -.61954500E-03, -.13551100E-01, 0.13983700E-02, -.21340800E-02, 0.24633100E-02, 0.32152800E-01, -.21667300E-02, -.52286600E-02, 0.26587000E-02, 0.44355300E-03, 0.10912100E-02, -.29735200E-02, -.18137900E-02, 0.16743000E-02, 0.28211700E-02, 0.18548400E-02, -.21329600E-02, 0.43573600E-03, 0.10746400E-02, -.29411300E-02, -.17639100E-02, 0.16109500E-02, 0.27640300E-02, 0.17175600E-02, -.19351900E-02, -.30757200E-03, -.13549000E-02, -.75397700E-02, 0.76183700E-03, 0.19024400E-03, 0.20177500E-02, -.33984800E-02, -.51500900E-02, -.18682200E-02, -.13581000E-02, -.67065400E-02, -.11334700E-02, -.61175900E-02, 0.15943900E-02, -.42088400E-02, -.11091500E-02, 0.20391300E-02, -.37557200E-02, 0.70375500E-03, 0.11079100E-02, 0.66154200E-03, 0.61180400E-02, 0.47886200E-03, 0.66564600E-02, -.25694600E-02, -.33270500E-02, 0.13189300E-02, -.28312100E-02, -.97052400E-03, 0.12196800E-02, -.16386600E-01, -.16134800E-03, -.92366800E-03, -.21447900E-02, 0.36971300E-02, 0.44070800E-02, -.10976100E-02, -.17213800E-02, -.22483700E-02, 0.80929500E-02, 0.16502900E-02, 0.39924400E-02, -.64018300E-02, -.68321800E-02, 0.72086500E-03, 0.28616400E-02, 0.16755800E-02, -.96379800E-02, 0.16713900E-02, 0.70560600E-01, -.18183400E-02, 0.42262400E-02, 0.20157600E-01, 0.29690600E-03, 0.10487700E-02, -.29112400E-02, -.18828000E-01, 0.33997800E-01, -.18984900E-02, -.23819100E-02, 0.31205100E-02, 0.20215700E-02, 0.34746000E-02, 0.12526300E-01, 0.29468100E-03, -.37712500E-03, 0.26218800E-03, 0.44176600E-03, 0.53903400E-03, 0.15271400E-02, -.27112600E-01, 0.19129700E-02, -.55574700E-03, -.50443900E-04 }, { -.16774000E+01, -.71370800E+00, 0.11458500E+01, 0.42364300E+00, 0.72430800E+00, 0.43943100E+01, 0.22452600E+01, -.12390000E+01, 0.19921400E+00, -.62723800E+00, 0.12798900E-01, 0.33615200E+00, -.86359200E+00, 0.38019200E+01, -.84656500E+00, -.20152900E+01, -.16360000E+01, -.11909600E+01, -.65854600E+00, 0.39629100E+00, 0.20386700E+00, -.62396200E-02, 0.17962600E+00, 0.38389400E+00, -.83453900E-01, 0.83149900E-01, -.45145200E+00, -.15875900E+00, 0.53136800E+00, 0.56152000E-01, 0.59744200E+00, -.32644700E-01, -.27679600E+00, -.11114700E+00, -.20997900E+01, 0.30565000E+00, 0.85341100E-02, -.35629200E-01, 0.21801100E+00, -.12814600E+00, 0.19070100E+00, 0.24283800E+00, 0.77555600E+00, -.72680200E-01, 0.39537600E-01, -.11119200E+01, 0.20838400E+00, 0.11424900E+01, 0.32687200E-01, -.15130200E-02, 0.56876400E-01, -.39610500E-01, -.25622600E+00, 0.22706800E-01, 0.25216600E+01, -.17739900E+00, -.51156400E-01, 0.40723800E+00, -.28347400E+00, -.27587500E+00, -.17616400E-01, -.13583100E+00, -.66397900E-01, 0.42044700E+00, 0.26113200E+00, -.31609000E-01, -.53889200E-01, -.16428800E+00, -.15087000E+00, 0.10610200E-01, 0.62492700E-01, -.26709100E+00, -.12213200E+00, 0.19080400E+00, 0.11721000E+00, -.68851000E-02, 0.31849700E+00, -.16016500E+00, -.96839600E+00, 0.79630900E+00, -.99311200E-01, -.29566500E-01, -.30116600E+00, -.55264200E-01, 0.32086600E+00, -.27019800E+00, 0.59839400E-01, 0.26796200E+00, 0.13956300E+00, 0.12132700E+01, 0.46036300E-01, -.10424400E+00, -.72815900E-01, 0.64745100E-01, 0.61737900E+00, 0.32296100E-01, -.36438400E+00, 0.20312400E-01, -.29997500E-01, 0.17159000E+00, -.20140000E+00, -.12811400E+00, 0.53931000E-02, -.86075100E-01, 0.71440700E-02, 0.15126400E-01, 0.57551900E-01, 0.35879500E-01, -.15734500E+00, 0.59924700E-01, -.12924800E+00, -.97140100E-01, -.26686400E+00, 0.11006800E+00, -.13191700E+00, 0.42010300E-03, -.96850900E-01, 0.46714300E-01, -.18713700E-01, -.19404200E-01, -.63392200E-01, 0.34637800E+00, -.37755200E-01, 0.89797900E-01, -.36590600E+00, -.13676100E+00, 0.10192300E+00, 0.10350800E-01, -.41827500E+00, 0.11564500E+00, 0.35647100E-02, 0.78145100E-01, 0.44691100E+01, 0.56448500E+00, -.19458800E+00, 0.71456100E-01, -.54665200E-02, -.16785800E-01, -.49807300E-01, 0.16289600E-01, -.26989800E-01, 0.47009600E-02, -.14617300E+00, 0.15252400E+00, -.57250200E-02, -.16488600E-01, -.50362100E-01, 0.15797700E-01, -.26847500E-01, 0.40607600E-02, -.14420800E+00, 0.15258700E+00, -.77624100E-01, -.50447000E-01, -.17606700E+00, 0.23587400E+00, 0.69985600E-02, 0.43806600E-04, -.80445100E-01, 0.16830700E+00, -.10258300E+00, 0.11911300E+00, 0.80607000E-01, -.11231500E-01, -.16034700E+00, -.15472400E+00, 0.33002500E-01, -.15044200E-01, 0.12739900E-01, -.10411500E+00, 0.35478100E-01, 0.36325100E-01, -.13649300E+00, 0.49105000E-01, -.25343000E-01, 0.83097100E-01, -.53135400E-01, -.67752100E-01, 0.25876600E-02, -.61579800E-01, 0.76844300E-01, -.27860800E-01, -.16980000E+00, -.30188100E-01, 0.19445400E-02, 0.67835500E-02, 0.11638300E-01, 0.18467500E-01, 0.57311900E-01, -.60143100E-02, -.16963500E-01, 0.79730600E-01, -.39011100E-02, -.15535400E-01, -.22029400E-01, -.29764900E-01, -.11032700E+00, 0.11805200E-01, 0.23345200E-01, -.12948800E+00, -.17311100E-01, -.17527200E+00, 0.16880200E-02, 0.11112500E+00, -.10035600E+00, -.16062100E-01, 0.45220700E-01, 0.67450100E+00, 0.48724700E-01, -.56234200E+00, 0.33460500E+00, -.23209600E-02, -.88144000E-02, -.95057500E-01, 0.66314300E-01, 0.26630000E+00, -.82825300E-01, 0.18740200E+00, -.10761100E-01, -.12497100E-01, 0.13083000E-01, 0.70797700E-01, -.28792200E+00, -.98726100E-02, 0.21090900E-01, -.27173800E-01 }, { -.86309900E+01, -.32553900E+01, 0.66680700E+01, 0.25073600E+01, 0.29978200E+01, 0.16802400E+02, 0.26964600E+01, -.81846200E+01, 0.25299300E+01, -.50355100E+01, 0.21110000E+00, 0.37840700E+01, -.48170300E+01, 0.25699700E+02, -.66218500E+01, -.10335900E+02, -.66372700E+01, -.10496700E+02, -.62257800E+01, 0.18567700E+01, 0.30824800E+01, -.12419500E-01, -.23381300E+00, 0.34032000E+01, -.32402700E+00, 0.34516300E+00, -.23842300E+01, -.10231000E+01, 0.22966900E+01, 0.65075600E+00, -.11958800E+01, 0.10352000E+01, -.92314700E+00, -.57331600E+00, -.18217500E+01, 0.22904100E+01, -.61231900E+00, 0.12440300E+01, 0.25479100E+00, -.78919200E+00, 0.16356500E+01, 0.35598500E+01, 0.28600600E+01, -.12695600E+00, 0.76316200E-02, -.86647100E+01, 0.22564200E+01, 0.43005800E+01, 0.15414100E+00, 0.80481000E-01, -.23321000E+00, -.79903800E+00, -.51248200E+00, 0.67808600E+00, 0.43191600E+01, -.14908200E+01, 0.12938700E+00, 0.44261200E+01, -.11857000E+01, -.30404400E+01, 0.19722400E+00, -.65379700E+00, -.69529800E+00, 0.22169100E+01, 0.16765700E+01, 0.67647100E-01, 0.12328900E+00, -.18350500E+01, -.24821400E+00, -.21955200E+00, 0.35232600E+01, 0.63943200E+00, -.16175100E+01, 0.67715000E+00, 0.49757000E+00, 0.11327300E+00, 0.17730900E+01, -.14613900E+01, -.31298200E+01, -.41055400E+01, -.33875300E+01, 0.71182300E+00, -.42055300E+00, 0.84579100E+00, -.73892400E+00, -.96838900E+00, 0.86800900E+00, 0.22113300E+01, 0.10564800E+01, 0.30437400E+01, 0.37498700E+00, -.53543100E-01, 0.11499100E+00, 0.25439300E+01, -.57065400E+01, -.13208900E+00, 0.41172300E+01, 0.30639700E+00, -.94679600E+00, -.61713900E+01, 0.57807700E+00, 0.72220300E+00, 0.12890900E+01, -.27989000E+00, -.95529300E-01, -.70234300E+00, -.23332700E+00, -.21870000E-01, -.11219400E+01, 0.80802000E+00, -.12627000E+01, 0.51360700E+00, 0.60281100E+00, 0.21884200E+01, -.42132900E+00, 0.65075600E-01, 0.13868100E+00, 0.92576200E+00, -.65186200E+00, -.34113300E-01, 0.62405300E+00, 0.37499800E+00, 0.20168800E+00, -.18423000E+00, 0.21324700E+00, -.64789800E+00, 0.14950300E+01, -.10762700E+00, 0.40379600E+01, -.33876000E+00, 0.83227300E+00, 0.57325700E-01, 0.13830900E+02, 0.36890000E+01, 0.13055400E+00, -.94425200E+00, -.14198200E+00, 0.24590900E-01, -.17986400E+00, 0.11550900E+00, 0.38290200E+00, 0.74018700E-01, 0.39828400E+00, 0.38922500E+00, -.14084900E+00, 0.22719500E-01, -.18464800E+00, 0.11464100E+00, 0.38105300E+00, 0.73160900E-01, 0.39080500E+00, 0.39846300E+00, 0.28058900E-01, -.29035700E+00, -.12505800E+01, 0.12115200E+01, 0.54782200E+00, 0.50712800E+00, -.46802200E+00, 0.25482700E+01, -.37322200E+01, 0.59494800E+00, -.21026100E+01, -.83164000E+00, -.73123100E+00, -.35915600E+00, 0.87318700E+00, 0.39376200E+00, -.21204700E+00, -.51352500E+00, 0.36724600E+00, 0.18354500E+01, -.26837000E+01, -.32094700E+00, 0.65028600E+00, 0.24137500E+01, 0.35517000E-01, -.45729900E+00, 0.51872100E+00, 0.10609000E+00, -.10932900E+01, 0.75685900E+00, 0.24996100E+01, -.54678800E+00, 0.25746700E-01, -.13156500E+00, 0.48697000E+00, 0.21357400E+00, 0.11711700E+01, -.21877300E+00, 0.96560200E-01, -.97631600E+00, -.65525000E-01, 0.25938300E+00, -.96666500E+00, -.33325400E+00, -.22219800E+01, 0.39847400E+00, -.34080000E+00, 0.20227600E+01, -.72023700E-01, -.23098900E+01, -.56432500E+00, -.18153600E+00, -.18376000E+02, -.18507100E+00, 0.11312100E+01, 0.33408700E+02, -.37377600E+01, -.26443900E+02, -.20251100E+01, 0.27862700E+01, 0.75960500E+00, 0.69071500E+00, 0.45590000E+01, 0.93459900E+01, -.71064100E+00, 0.93593600E+00, -.54927300E+00, -.60737800E+00, -.12611900E+01, 0.27088200E+01, -.14560800E+02, 0.16704100E+00, 0.10209100E+01, -.13276000E+01 }, { -.47779600E+01, -.16337600E+01, 0.56803900E+01, 0.26295900E+01, 0.22881500E+01, 0.23452000E+01, -.17655500E+02, -.44586300E+01, 0.89218600E+00, -.14800400E+01, 0.47932600E+00, 0.52255600E+01, 0.58502500E+00, 0.11818300E+02, -.33579900E+01, -.24781400E+00, -.23745700E+01, -.73792700E+00, -.75459500E-01, -.10743800E+01, 0.13446600E+01, 0.23632100E+00, 0.32128600E+01, -.28170200E+00, 0.37001800E+00, -.54602200E+00, -.23827800E+01, -.83176700E+00, 0.31250200E+00, -.90352900E+00, -.69716700E+01, 0.18698600E+01, -.80854100E+00, 0.13571600E+01, 0.73929400E+01, 0.20190200E+01, -.68355400E+00, 0.89139300E+00, 0.13853400E+01, 0.11519600E+00, 0.13213500E+01, 0.17730600E+00, 0.44367600E+01, 0.21940100E-01, 0.71768000E+00, -.45672000E+01, 0.55262100E+00, 0.66244100E+01, 0.83325600E-01, -.58269400E-01, 0.16922900E+00, 0.24983100E+00, -.62031500E+00, -.12239000E+00, -.43450900E+00, -.18342900E+00, -.19142000E+00, 0.19063500E+00, -.66286400E+00, 0.32064100E+00, 0.50009400E+00, -.88576400E-01, 0.38757700E+00, 0.29182200E+01, 0.21120200E+00, -.76375900E-01, -.25144600E+00, -.13232900E+01, -.54265200E+00, 0.13717700E+00, 0.62575100E+01, -.61447600E+00, -.18533000E+01, 0.11596400E+01, 0.21689400E+00, 0.26933400E+00, 0.37823600E+01, -.15507200E+01, -.53455300E+01, -.12508500E+01, -.42023000E+01, 0.79256300E+00, -.16864800E+00, 0.39681000E+00, 0.13119600E+01, -.50401200E-01, 0.21382100E+00, 0.15377800E+01, 0.76999100E+00, 0.10114200E+01, 0.27680100E+01, -.82404600E-01, -.11205200E+01, 0.14630900E+01, 0.14527000E+02, -.22886900E+01, -.49629200E+01, 0.51005400E+00, 0.12908600E+01, 0.59313800E+01, -.19756400E+01, -.12342200E+01, -.73287200E+00, -.61812900E+00, 0.31648500E-01, 0.18228900E+01, 0.41655300E+00, 0.18192400E+01, -.17291700E+01, -.12621700E+01, -.15646000E+01, -.19067600E+01, -.42100600E+00, -.13909200E+01, 0.52940100E-01, 0.12793000E-01, -.86388300E+00, 0.10472400E+01, -.55387200E-01, 0.14976700E+00, 0.15931000E+00, 0.59308800E-01, 0.88097500E-01, -.62346700E+00, 0.11517800E+01, -.21442200E+00, -.42960900E+00, -.94452400E-01, 0.40280500E+01, -.69279200E+00, 0.21200500E+01, -.42135200E+00, -.76808100E+01, -.99512200E+00, 0.50240800E+00, -.73779900E+00, 0.77249200E-01, -.10934000E+00, 0.32889200E+00, -.16346900E+00, 0.62516900E+00, 0.14517200E+00, -.19983300E+00, -.35495600E+00, 0.76003700E-01, -.10884800E+00, 0.32211500E+00, -.16825400E+00, 0.62208600E+00, 0.14611200E+00, -.19163500E+00, -.37356700E+00, 0.19412800E-01, -.23807200E-01, -.38967500E+00, 0.11686000E+01, 0.20577000E+00, 0.37817600E+00, -.73301200E+00, 0.10320500E+01, -.36177200E+00, 0.10565600E+01, -.66512600E+00, -.96779300E+00, -.55711300E+00, -.19963700E+01, -.11128200E+00, -.26418000E+00, -.31630500E+00, -.40328100E+00, 0.95796900E+00, 0.13752000E+01, -.17262600E+00, -.31187500E+00, -.33334100E+00, 0.17958400E+01, -.68027500E+00, -.14558600E+01, 0.19693900E+00, -.64000100E+00, 0.45040400E+00, -.42273500E-01, -.23507500E+01, 0.10487700E+00, 0.11385800E+00, -.29335600E+00, 0.70642200E-01, 0.31948400E+00, 0.33493700E-01, 0.10824900E+00, -.11648700E+01, 0.10701800E+01, -.19157100E+00, 0.54605700E+00, -.13911500E+00, -.53700200E+00, -.25228800E+00, -.24032600E+00, 0.18636500E+01, -.18322100E+01, -.31416800E+00, 0.48778600E+01, 0.17418000E+00, -.17658400E+01, 0.74337000E+01, 0.88966400E-01, 0.28504900E+00, -.44726600E+01, -.73160600E+00, 0.37293100E+01, -.23260200E+01, 0.49181300E-01, 0.63084900E+00, 0.30084300E+00, 0.26360300E+00, 0.32703800E+01, -.12807500E+00, 0.43935600E-01, 0.75497000E-01, 0.83732300E-01, 0.12219300E+00, 0.49011200E+00, 0.10647100E+01, 0.83408700E+00, -.14125600E+00, 0.18946000E+00 }, { 0.16110500E+01, 0.54054200E+00, -.89904400E+00, -.75440900E+00, -.77823400E+00, -.29634600E+01, -.57813000E+00, 0.10781500E+01, -.22338100E+00, 0.33203600E+00, 0.24604800E-01, -.15376500E+00, 0.53088300E+00, -.33405700E+01, 0.28128300E+00, 0.22073300E+01, 0.15414600E+01, 0.94551500E+00, 0.10658800E+00, -.43579700E+00, -.25420400E-02, 0.10004300E+00, -.19425100E+00, -.31137600E+00, 0.42977200E-01, -.15159700E+00, 0.69431100E+00, 0.21277900E+00, -.32288600E+00, -.47182300E-01, -.76546100E+00, -.60165600E-01, 0.54193700E+00, -.22858100E-01, 0.24588200E+01, -.39536900E+00, 0.73583100E-01, -.22036400E+00, -.23189900E-01, 0.11716600E+00, -.23130000E+00, -.35711900E+00, -.60608400E+00, -.45459600E-01, -.12504200E-01, 0.10235500E+01, -.18957900E+00, -.13177200E+01, -.15194400E-01, 0.10816000E-01, -.42292800E-01, -.46278700E-01, 0.18043900E+00, 0.36515900E-01, -.39258600E+01, 0.14278000E-01, 0.64832000E-01, -.42734900E+00, 0.64250800E-01, 0.28847600E-01, -.31207500E+00, 0.10536400E+00, -.63903000E-01, -.81563500E+00, -.19997100E+00, 0.73391000E-01, -.44741400E-01, 0.31669100E+00, 0.36240900E+00, -.53699200E-01, -.26107600E-01, 0.51719700E+00, 0.29219100E+00, -.21587400E+00, -.24377900E-02, -.94663700E-01, -.16495900E+00, 0.12083100E+00, 0.27475800E+00, -.17029900E+00, 0.59487800E-01, -.26135300E-01, -.25540800E+00, 0.31093900E-01, -.88161600E-01, 0.20662200E+00, -.30865800E-02, -.22048100E+00, -.24270700E-01, -.92453700E+00, -.10061500E+00, 0.69697100E-01, 0.92895300E-01, -.10969600E+00, -.15780600E+01, 0.50055600E-01, 0.40284500E+00, -.97589500E-01, -.85690000E-01, 0.10107200E+00, 0.31590500E+00, 0.30581000E+00, 0.10221500E+00, 0.12099700E+00, 0.19639100E-01, -.12079100E+00, -.10787200E+00, -.98077100E-01, -.45738700E-01, -.30644300E+00, 0.12490600E+00, 0.52685700E-01, -.68256400E-01, -.56354000E-01, 0.27719700E+00, 0.16157900E-01, 0.15774500E+00, -.83864700E-01, 0.15483300E-01, -.18166800E-02, 0.67856600E-01, -.18721700E+00, 0.63035500E-01, -.16075300E-01, 0.11907200E+00, 0.24037300E+00, -.21053600E-01, -.25909200E-01, 0.47856400E+00, 0.67425300E-01, -.12261800E+00, -.26255000E-01, 0.13418000E+00, -.60257500E+00, -.13620500E+00, -.20043300E-02, -.23272700E-02, 0.11425000E-01, 0.52261800E-01, -.69075300E-03, 0.10076400E+00, -.23058100E-01, 0.21500900E+00, -.88632500E-01, -.19240200E-02, 0.11001400E-01, 0.52058300E-01, -.10121900E-02, 0.98157400E-01, -.21851400E-01, 0.21179700E+00, -.89872000E-01, 0.33525500E-01, 0.81956600E-02, 0.56242100E-01, 0.43359200E-01, -.42028800E-02, -.78830800E-03, 0.47974500E-01, -.10853000E+00, 0.72817400E-01, -.11498700E+00, -.11305400E+00, -.12508300E+00, 0.15944700E+00, 0.53703900E-01, 0.34964300E-01, 0.42764000E-01, -.19543500E-01, 0.11223600E+00, -.11376900E+00, -.23602100E-02, -.62266700E-01, -.70269900E-01, 0.40020100E-01, 0.96739300E-02, 0.44982200E-01, 0.31215400E-01, 0.10427100E-01, 0.21341500E-01, -.44240600E-01, 0.27494600E-02, 0.11678300E+00, -.13305100E-01, 0.17114400E-01, -.95137700E-02, -.56347800E-03, -.12759800E-02, -.31860800E-01, 0.35644600E-02, -.16803200E-01, -.49164400E-01, -.31931900E-01, 0.17789000E-01, -.83574600E-04, 0.10040000E-02, 0.57586800E-01, -.81286000E-02, 0.23947800E-01, 0.80992500E-01, -.36801500E-01, -.35893100E+00, 0.18617200E-01, -.28510900E+00, -.12113800E+00, 0.25217300E-02, 0.43216400E-02, 0.17987200E+00, -.31738300E-01, -.13503300E+00, -.38231400E+00, 0.23250400E-01, -.27559300E-02, 0.16309400E+00, -.32245900E-01, -.57702300E-01, 0.37248500E-01, 0.15186900E-01, 0.59861900E-02, 0.66065000E-02, 0.13129000E-01, -.36103600E-01, 0.14182400E+00, 0.22130800E-01, -.10977200E-01, 0.14394500E-01 }, { -.84873200E+01, -.26210000E+01, 0.62738200E+01, 0.28367900E+01, 0.30080800E+01, 0.18415500E+02, 0.16299500E+02, -.36555000E+01, 0.81250600E+01, 0.82475100E+00, -.26742700E+01, -.42565900E+00, -.63312700E+01, 0.35943700E+02, -.80524400E+01, -.31572600E+02, -.20455400E+02, -.11530600E+02, 0.19649600E+01, 0.65567000E+01, -.20362400E+01, -.27416100E+01, 0.15960300E+01, 0.37845500E+01, 0.54180300E+00, 0.40493500E+00, -.64452200E+01, -.20142000E+01, 0.91533300E+01, -.91996300E+00, 0.12875500E+02, -.19453300E+00, -.36810900E+01, 0.48486100E+00, -.19244800E+01, 0.20016900E+01, 0.40742200E+00, -.22696900E+01, 0.42716600E+01, 0.17665100E+00, 0.14847700E+01, -.32369500E+00, 0.14081600E+02, -.39563100E+01, -.42014200E+00, -.50472200E+01, -.67042400E+00, 0.15537600E+02, 0.50976300E+00, -.73268300E+00, 0.71101600E+00, 0.30996800E+00, -.36757300E+01, -.57144700E-01, 0.48055200E+01, -.20016000E+01, -.88167500E+00, 0.77682000E+01, -.32077200E+01, -.35029800E+01, 0.50628100E+01, -.18203200E+00, -.92951900E+00, 0.40845700E+01, 0.30768400E+01, -.20422700E+00, -.29752700E+00, -.25557200E+01, -.13620600E+00, 0.17928100E+00, 0.93395200E+01, -.38342600E+00, -.19945800E+01, 0.11947300E+01, -.30213500E+00, 0.83692400E+00, -.30753200E+01, 0.60392600E+00, -.12363500E+01, -.25710200E+01, 0.24688000E+01, -.99568200E-02, 0.68802600E+01, -.52923500E+00, -.12302000E+01, -.36672600E+01, 0.46948200E+00, 0.22262900E+01, 0.94384600E+00, -.65894600E+01, 0.24385300E+01, -.70327100E-01, 0.10710900E+00, 0.10816500E+01, 0.11190100E+02, 0.11350700E+01, 0.71405600E+00, 0.60952100E+00, 0.46445700E+00, 0.59648200E+00, 0.17636200E-01, 0.23717500E+01, 0.62585100E+00, -.60278600E+00, -.58312700E+00, -.79538400E+00, 0.20451500E+01, 0.35245300E+00, 0.89338500E+01, -.22526400E+01, 0.82182800E-01, 0.33741400E+01, 0.17641800E+01, 0.10838500E+01, -.63846300E-01, 0.51329900E+00, -.20912800E+01, 0.27322300E+01, -.66656200E-01, 0.44232700E+00, 0.36990000E+00, -.29679100E+01, 0.48009900E+00, -.12714500E+01, 0.12649400E+01, 0.11707400E+00, -.15821900E+01, 0.74910600E-01, -.54532000E+01, 0.43547400E+00, 0.34081000E+01, -.97413300E+00, -.27568600E+02, -.13288500E+02, -.15001300E+01, -.66722800E+00, 0.69351100E-01, 0.15305500E+00, 0.18360800E+00, -.39433500E+00, -.72110600E+00, -.11332900E-01, 0.10991500E+01, -.13952900E+01, 0.69921000E-01, 0.15182800E+00, 0.18633200E+00, -.38735500E+00, -.70265500E+00, -.16673900E-01, 0.10938900E+01, -.13795300E+01, 0.12064900E+00, 0.70574800E-01, 0.95823200E+00, -.98645200E+00, 0.58161900E-01, 0.38132600E+00, -.22315900E+01, 0.45262400E+01, -.26077700E+01, -.15505000E+01, -.72803300E+00, 0.10928300E+01, -.22070400E+01, 0.71875400E+00, -.17397200E+01, -.10669700E+01, 0.29553000E+00, -.13614200E+01, 0.19357400E+01, 0.85825200E+00, -.12971500E+01, 0.18183300E+00, 0.74543400E+00, 0.23483000E+01, -.46836000E+00, -.96992900E+00, 0.44639400E+00, -.65667500E+00, -.32529600E+00, -.37543900E+00, -.53101600E+01, -.60156400E+00, 0.18851500E+00, 0.62757100E-01, -.43973000E+00, 0.76564300E+00, -.99339900E+00, 0.58184000E-01, -.24709400E+01, 0.25323200E+01, -.29881600E+00, -.17220700E+00, 0.83820800E+00, -.12971100E+01, 0.16430500E+01, -.15892300E+00, 0.39454200E+01, -.42615200E+01, -.65178400E+00, 0.12799100E+01, 0.16985800E+00, 0.23326000E-01, 0.61378100E+01, 0.12540300E+00, -.12872000E+00, -.84900100E+01, 0.12401000E+01, 0.64304900E+01, -.89444700E+00, -.25237500E+00, -.33535600E-01, 0.16918400E+01, 0.49897800E+01, 0.53995300E+00, 0.36672600E-01, 0.36661100E-01, -.23254900E-01, -.40308400E-01, -.44486700E+00, 0.83130700E+00, -.60449000E+00, -.71303500E-01, 0.62466100E-01, -.62206700E-01 }, { 0.16688900E+01, 0.83305700E+00, -.14090300E+01, -.52636700E+00, -.32275600E+00, -.31681400E+01, -.72530900E+00, 0.12785300E+01, -.36258500E+00, 0.87961900E+00, 0.13850900E-01, -.25139900E+00, 0.99496200E+00, -.54520400E+01, 0.94892100E+00, 0.39096000E+01, 0.21769300E+01, 0.16675500E+01, 0.27927500E+00, -.83831300E+00, 0.87907000E-01, 0.81202200E-01, -.48532900E+00, -.33742000E+00, 0.91279200E-01, -.16581100E+00, 0.34414900E+00, 0.74614400E-01, -.13925500E+01, -.98088500E-01, -.31294300E+01, -.12983900E-01, 0.10754300E+01, -.35493200E-01, 0.32695500E+01, -.69111400E+00, 0.10034900E-01, -.58599300E+00, -.44946700E+00, 0.10919800E+00, -.47689300E+00, -.24682700E+00, 0.71374100E+00, -.42267600E+00, -.73003000E-01, 0.19886900E+01, -.34532600E+00, -.20186500E+01, -.33106000E-01, 0.38724400E-01, -.84993200E-01, -.76038400E-01, 0.37904600E+00, 0.36151300E-01, -.57353300E+01, 0.86738700E-01, 0.10266700E+00, -.41400300E+00, 0.20285900E+00, 0.13318400E+00, -.44830000E+00, 0.13712500E+00, -.77625700E-01, -.12035700E+01, -.34543700E+00, 0.12236300E+00, -.31994100E-01, 0.45735700E+00, 0.51730300E+00, -.82505200E-01, 0.41003400E+00, 0.79656500E+00, 0.33297400E+00, -.22863700E+00, 0.14891100E+00, -.13181100E+00, 0.71877700E-01, 0.47320900E-01, 0.39514600E-01, -.70049600E-02, 0.16659000E+00, 0.80021800E-01, -.57934400E-01, -.87597200E-02, -.80840200E-01, 0.40697600E+00, 0.96388400E-01, -.31679800E+00, 0.93276200E-01, -.33980900E+00, 0.67863500E-02, 0.34029300E-01, 0.11530900E-01, 0.16003200E+00, 0.12086200E+00, -.17226300E+00, 0.40040400E+00, -.21532600E-02, 0.80023900E-01, 0.13707200E+00, 0.28067600E+00, 0.56224200E+00, 0.64978400E-01, 0.12786900E+00, -.31769900E-01, 0.13353000E+00, 0.32372900E-01, 0.46904300E-01, 0.40648500E-01, -.22922800E+00, -.28660000E+00, -.15382600E-01, -.64091800E-01, 0.93456900E-01, 0.15257300E+00, -.44331500E-01, 0.29985100E-01, -.12199700E+00, -.56349300E-01, -.10314400E+00, -.61986700E-01, -.21868800E+00, 0.34951800E-01, -.85606300E-01, 0.11841700E+00, 0.63469500E-01, -.21485900E+00, -.42491400E-02, -.37504700E+00, 0.12997800E+00, 0.26609400E+00, -.10967500E-01, -.12681100E+01, -.56003100E+00, -.17225600E+00, -.97769300E-01, -.19807300E-01, 0.25776700E-01, 0.35136300E-01, 0.32401700E-01, 0.15846800E+00, -.27680400E-01, 0.36238400E+00, 0.43700400E-01, -.19003900E-01, 0.24963200E-01, 0.33729000E-01, 0.31323900E-01, 0.15331000E+00, -.26226200E-01, 0.35757300E+00, 0.41570100E-01, 0.19398500E-02, -.46633400E-01, -.66157500E-01, 0.13616400E+00, 0.84870800E-02, 0.21068100E-01, 0.98461800E-02, -.30880900E-01, -.13211500E+00, -.12302800E+00, -.16981900E+00, -.88084900E-01, 0.65157100E-02, 0.50988700E-01, 0.15804600E-02, -.23859400E-01, -.28756400E-01, 0.34577000E-01, 0.34064400E-01, 0.98304600E-01, -.91990300E-01, -.42423600E-01, 0.39588500E-01, 0.17713500E+00, 0.17254800E-01, -.74862300E-04, 0.19210500E-01, 0.21054200E-01, -.62477200E-01, 0.15449000E-01, 0.13196800E+00, -.73713900E-02, 0.17992800E-01, -.16292500E-01, 0.17076800E-02, -.17883700E-02, -.67474100E-02, 0.19401100E-02, -.16350900E-01, -.38538800E-01, -.29814200E-01, 0.27420800E-01, -.18001200E-02, 0.11445500E-01, 0.24516800E-02, -.57201900E-02, 0.11272700E-01, 0.87571300E-01, -.54130400E-01, -.44126800E+00, 0.25517000E-01, -.47748600E+00, -.15476500E+00, 0.29798200E-02, -.15267500E-01, -.16554800E-01, -.37319600E-01, 0.35072100E-01, -.13603500E+00, -.42926000E-03, 0.23280400E+00, -.38429800E+00, -.76721400E-02, -.72132400E+00, 0.55309600E-01, -.47605000E-01, -.16621100E-01, -.18095500E-01, -.27964700E-01, -.10625400E+00, -.26555800E+00, -.18786900E+00, 0.30942700E-01, -.42828400E-01 }, { 0.15272700E+01, 0.45739500E+00, -.83425800E+00, -.54355600E+00, -.80885500E+00, -.27321500E+01, -.23738700E+01, 0.66443700E+00, -.39777900E+00, 0.58401400E+00, 0.24344800E-01, -.54088500E+00, 0.62691700E+00, -.48777600E+01, 0.12257200E+01, 0.30811400E+01, 0.17846100E+01, 0.16553200E+01, 0.46412900E+00, -.68563800E+00, 0.56807400E-01, 0.90004600E-01, -.91578400E-01, -.47641000E+00, 0.49125300E-01, -.15855700E+00, 0.35301000E+00, 0.14019700E+00, -.13637100E+01, -.12190900E+00, -.36213900E+01, 0.92404900E-01, 0.65526900E+00, 0.14877200E+00, 0.92958700E+00, -.41374500E+00, -.85741800E-01, -.15476200E+00, -.84369400E+00, 0.37122500E-01, -.34158100E+00, -.75206200E-02, -.47405700E+00, 0.16594700E+00, -.51354800E-01, 0.18687100E+01, -.16351700E+00, -.23084100E+01, -.91849700E-01, 0.11257100E+00, -.22956600E+00, -.37522400E-01, 0.86830600E+00, -.39810900E-03, -.24699500E+01, 0.43402500E+00, 0.16324000E+00, -.85293400E+00, 0.60733200E+00, 0.85540700E+00, -.53594800E+00, 0.14465200E+00, 0.14687000E+00, -.50884300E+00, -.48908600E+00, 0.75681600E-01, 0.12701600E-02, 0.14314800E+00, 0.34606300E+00, -.45758400E-01, -.67946000E+00, 0.49302400E+00, 0.21968300E+00, -.19383900E+00, -.41349400E-01, 0.30876900E-01, 0.88491100E+00, -.26067400E+00, 0.68053500E+00, 0.47340600E+00, 0.34543100E+00, 0.15567100E+00, 0.24205600E+00, 0.88456200E-02, -.23982100E+00, 0.74672100E+00, 0.59144700E-01, -.41995200E+00, 0.57550800E-01, -.57076000E+00, -.10189400E+00, 0.69720500E-01, -.50030900E-01, 0.22461700E+00, 0.10135700E+01, -.53354400E+00, -.49521500E-01, 0.47016900E-03, -.42686700E-01, 0.90283000E+00, 0.16567400E+00, 0.37768400E+00, 0.12110900E+00, 0.39720100E-02, -.31352100E-01, 0.10072300E+00, 0.14051000E-01, -.79760900E-01, -.48704300E+00, 0.24472100E+00, -.23047500E+00, 0.12494700E+00, -.22238500E+00, -.14630200E-01, -.16266300E+00, 0.79972200E-01, -.27311800E-01, -.66825100E-01, 0.25498800E+00, -.58302400E-01, -.41667300E-01, -.16078100E+00, 0.21916800E+00, -.39901200E+00, 0.20239200E+00, 0.30068900E-01, -.29776300E+00, 0.71832800E-01, -.84055700E+00, 0.94374900E-01, 0.51352600E+00, 0.19981100E-01, -.33406100E+01, -.47996700E+00, -.82939000E-01, -.77610600E-01, -.25493300E-01, 0.11632200E-02, -.53897700E-03, 0.35221600E-01, 0.20286100E+00, -.32527200E-01, 0.27315800E+00, 0.95418400E-01, -.24908100E-01, 0.51157400E-03, -.58174700E-03, 0.35747200E-01, 0.19814000E+00, -.31351000E-01, 0.26612100E+00, 0.98390000E-01, 0.31125700E-01, -.13533700E-01, -.66777600E-01, 0.30809800E-01, -.18882700E-01, -.23595400E-01, 0.30710700E+00, -.18739600E+00, 0.94327000E-01, -.13773400E+00, -.15763500E+00, -.14666100E+00, 0.25547700E+00, 0.68813600E-01, 0.88173100E-01, 0.38179800E-01, -.67178200E-03, 0.17694500E+00, -.21907500E+00, -.10884700E+00, -.27500000E-01, -.81432100E-01, 0.19351500E-01, -.12144400E+00, 0.25615400E-01, -.11713300E-01, 0.32237100E-02, 0.42879400E-03, -.38532200E-02, -.26130000E-01, 0.24344900E-02, -.69116300E-01, 0.98077600E-02, -.23871500E-01, 0.20235000E-01, 0.26086300E-01, -.41116100E-01, 0.56717900E-02, 0.13576900E-01, 0.82277700E-02, -.19033400E-01, 0.45011700E-01, -.37289500E-01, -.45940700E-01, 0.66454100E-01, -.12374000E-01, -.32131600E-01, -.30785900E-02, -.23109300E-01, 0.97126500E-01, 0.21882300E-01, -.27912300E+00, 0.39109800E+00, 0.71538000E-02, 0.27668900E-01, -.78911100E-01, -.44038000E-01, 0.77897800E-01, -.23241300E+00, 0.13994900E-01, 0.27535000E-01, 0.12715600E+00, -.98394400E-02, 0.15716500E+00, 0.16550300E+00, 0.14800900E-01, 0.60718200E-02, 0.64632000E-02, 0.61252900E-02, 0.11843400E-01, 0.13229400E+00, 0.43480900E-01, -.10982300E-01, 0.14589900E-01 }, { -.14985100E+01, -.74928600E+00, 0.13578200E+01, 0.44773000E+00, 0.59179800E+00, 0.47728000E+01, 0.31198300E+01, -.10856100E+01, 0.31620600E+00, -.77642700E+00, 0.75364700E-03, 0.18443800E+00, -.10979900E+01, 0.45321500E+01, -.76983000E+00, -.26184800E+01, -.18367300E+01, -.11709800E+01, -.54130100E+00, 0.57302000E+00, 0.19997900E+00, -.84333200E-01, -.40518300E-01, 0.55260400E+00, -.80153300E-01, 0.16103200E+00, -.40823700E+00, -.12235900E+00, 0.96945100E+00, 0.13376800E+00, 0.19658800E+01, -.12375300E+00, -.55724600E+00, -.12925500E+00, -.31661900E+01, 0.34482100E+00, 0.38516200E-01, 0.17094000E+00, 0.13962800E+00, -.10795000E+00, 0.30296000E+00, 0.27313300E+00, 0.95421700E+00, -.11164700E+00, -.71784700E-02, -.10788500E+01, 0.20621400E+00, 0.14414900E+01, 0.30151700E-01, -.84684100E-02, 0.14512800E-01, -.19858000E-01, -.23506500E+00, 0.27320400E-01, 0.36126900E+01, -.16674000E+00, -.49649900E-01, 0.70693900E+00, -.15014600E+00, -.36733800E+00, 0.29411300E-01, -.13504000E+00, -.18605700E-01, 0.65268500E+00, 0.24542900E+00, -.41919200E-01, -.32495500E-01, -.30628400E+00, -.21364100E+00, 0.14158900E-01, 0.22779600E+00, -.27389100E+00, -.15306500E+00, 0.23360900E+00, 0.45498600E-01, -.69868100E-01, 0.13014800E+00, -.95028800E-01, -.11680400E+01, 0.34134900E+00, -.14021200E+00, -.71754200E-01, -.33581100E+00, -.38249300E-01, 0.41891500E+00, -.29514500E+00, 0.41604100E-01, 0.38992500E+00, 0.18126400E+00, 0.13679400E+01, 0.16616600E+00, -.90175500E-01, -.24874600E-01, 0.11532900E+00, 0.62857600E+00, 0.13286300E+00, -.49673700E+00, 0.33881800E-02, 0.22333000E-01, 0.26108100E+00, -.16882600E+00, -.30861600E-01, -.31265600E-01, -.96398700E-01, 0.24567100E-01, 0.34031000E-01, 0.97498000E-01, 0.69954000E-01, -.19644000E+00, -.76399400E-01, -.18889900E+00, -.16297000E+00, -.23220100E+00, 0.41305200E-01, -.42278300E-01, -.88128400E-02, -.10788500E+00, 0.11264600E+00, -.41346300E-02, -.21406800E-02, -.23007400E-02, 0.22643500E+00, -.50114600E-01, 0.72983500E-01, -.31084400E+00, -.68163500E-01, 0.90012700E-01, 0.39762300E-02, -.12588100E+00, 0.51721300E-01, -.74696100E-02, 0.35587700E-01, 0.26733600E+01, 0.38432000E+00, -.56044100E-01, -.82950000E-01, 0.14198400E-01, -.29129700E-01, -.30222900E-01, -.21453400E-01, -.42702800E-01, 0.14506500E-01, -.28927200E+00, 0.31527400E-01, 0.13500000E-01, -.28522000E-01, -.30041400E-01, -.21449800E-01, -.41047000E-01, 0.13503300E-01, -.28668000E+00, 0.31575600E-01, -.52883000E-01, -.12239600E-01, -.51966700E-01, 0.13234800E+00, 0.21678500E-01, -.23789100E-01, -.29690700E-01, 0.76849100E-01, 0.41033500E-01, 0.10116000E+00, 0.12870600E+00, -.38608100E-01, -.93785100E-02, -.21039100E+00, 0.52928800E-01, 0.37744100E-01, 0.25268300E-01, -.27460300E-01, -.87473200E-01, -.62471200E-01, -.68471300E-01, 0.25396100E-01, -.27413300E-01, -.10518500E+00, -.34957000E-01, -.61288500E-01, -.84755700E-02, -.72355000E-01, 0.86711900E-01, -.29273000E-01, -.22464500E+00, -.14181800E-01, -.49127200E-02, 0.57574100E-02, 0.16165800E-01, 0.23530800E-01, 0.28120600E-01, -.19971200E-02, -.11922100E-01, 0.90241800E-01, 0.64086600E-02, -.10210000E-01, -.30976400E-01, -.43619600E-01, -.53141800E-01, 0.30303100E-02, 0.22083100E-01, -.15884400E+00, 0.13237400E-01, 0.25816700E+00, -.50012500E-02, 0.28488500E+00, 0.29230200E+00, -.10707900E-01, 0.52506200E-01, 0.33864800E+00, -.38908100E-01, -.27435500E+00, 0.44795700E+00, -.12474500E-03, -.48643400E-01, 0.27436500E+00, 0.27594500E-02, -.38208500E+00, 0.10021800E+00, 0.12256100E+00, -.50720400E-02, -.58799800E-02, -.29887100E-01, 0.32394200E-01, -.12133700E+00, -.24490300E-01, 0.10177900E-01, -.13473400E-01 }, { -.83336200E-01, -.80410700E-02, 0.16049600E+00, 0.10717800E+00, 0.61494400E-01, 0.34370200E+00, 0.42594300E+00, -.84790500E-01, 0.23904700E-01, -.52655500E-01, 0.34593700E-02, 0.52195600E-01, -.50073400E-01, 0.35669600E+00, -.64150400E-01, -.17548100E+00, -.99832200E-01, -.70492000E-01, -.18459200E-01, 0.35805800E-01, -.12794300E-01, -.37366800E-03, 0.28697800E-01, 0.18951100E-01, 0.12011100E-02, 0.56966900E-02, -.29253400E-01, -.10575200E-01, 0.15993600E-01, -.68328500E-03, -.19351100E-02, 0.11634100E-01, -.27350200E-01, 0.82806700E-03, -.61836800E-01, 0.31929800E-01, -.29371800E-02, 0.27791900E-01, 0.97048100E-02, -.44723500E-02, 0.15798900E-01, 0.90086500E-02, 0.17199000E-01, 0.17327300E-01, 0.67780100E-02, -.75161800E-01, 0.16420200E-01, 0.76309300E-01, 0.13867100E-03, -.75435200E-03, 0.36932300E-02, 0.58073600E-02, -.10183800E-01, -.42800300E-02, 0.22325900E+00, 0.45939100E-02, -.36324700E-02, -.29230800E-02, -.56881700E-03, 0.13474800E-01, 0.13492200E-01, -.25633000E-02, 0.88450600E-02, 0.60347200E-01, 0.77076900E-02, -.53259400E-02, 0.24350400E-02, -.24144300E-01, -.24779800E-01, 0.33292400E-02, -.19273200E-01, -.34661800E-01, -.14146800E-01, 0.11610900E-01, -.93395900E-02, 0.51891600E-02, 0.61085100E-02, -.85342000E-02, 0.18935000E-02, 0.11106500E-02, -.83550700E-02, -.12739200E-02, 0.65618700E-02, 0.92773000E-03, 0.27638300E-02, -.12052800E-01, -.17204200E-02, 0.12297300E-01, -.30761600E-02, -.22823500E-01, 0.11137000E-01, -.26202700E-02, -.18809800E-02, -.74156700E-02, 0.21355000E-01, 0.52463700E-02, -.33319600E-01, -.19779200E-03, -.58739700E-03, 0.21832100E-01, -.89618100E-02, -.23130200E-01, -.35191000E-02, -.50911500E-02, 0.16102300E-02, 0.27483300E-02, -.75476300E-02, 0.18811200E-02, -.91465600E-02, 0.21953900E-01, -.65313800E-03, -.14935900E-02, -.88903800E-02, -.46897900E-02, -.23076700E-02, -.22674900E-02, -.37084200E-02, -.64651600E-02, -.36644600E-03, -.84899800E-03, -.92126800E-02, 0.45727900E-02, 0.47031500E-03, -.10664100E-02, 0.15976300E-02, -.25784100E-02, 0.49746100E-02, -.74965100E-03, -.93034100E-02, -.12577100E-02, -.11747600E-02, 0.18424500E-02, 0.25661200E-01, 0.78942900E-02, -.18192500E-02, 0.20436600E-02, 0.47842700E-03, 0.24391300E-03, -.23468600E-02, -.14701500E-02, -.17253400E-03, 0.22342500E-02, -.68225200E-03, -.14142900E-02, 0.46155400E-03, 0.24192400E-03, -.23291300E-02, -.14354700E-02, -.15487800E-03, 0.21788100E-02, -.72780800E-03, -.12899300E-02, -.76092700E-03, -.93373700E-03, -.60307400E-02, 0.13320600E-02, 0.13332500E-03, 0.10274000E-02, -.37113100E-02, -.52353900E-03, -.79963800E-03, 0.11100300E-02, -.66572500E-03, 0.76716200E-03, -.67898200E-02, -.97559000E-03, -.33899200E-02, -.81509800E-03, 0.20433700E-02, -.48738800E-02, 0.22295000E-02, -.33387800E-03, 0.24706800E-02, 0.55443600E-02, -.24260700E-03, 0.12596000E-02, -.25418000E-02, -.25328500E-02, 0.73957200E-03, -.23993300E-02, -.14375700E-03, 0.97185500E-03, -.13998700E-01, 0.64654500E-03, -.12135200E-02, -.10403700E-02, 0.26247500E-02, 0.31566400E-02, 0.41791200E-04, -.13874200E-02, -.16694000E-02, 0.65313600E-02, 0.21586400E-02, 0.19947000E-02, -.45177300E-02, -.49239500E-02, -.89123600E-03, 0.23179800E-02, 0.14236000E-02, -.81266900E-02, 0.27419100E-02, 0.63582200E-01, -.22529800E-02, 0.13749400E-01, 0.13155500E-01, 0.23679000E-03, 0.64640500E-03, -.29867600E-02, -.90315300E-02, 0.77536300E-02, -.27492100E-02, -.69215100E-03, 0.39122000E-02, 0.15124800E-02, 0.90736400E-03, -.41949100E-02, -.76319600E-03, 0.84003700E-02, 0.33043500E-01, -.51259400E-03, -.59751100E-03, 0.29965900E-03, -.30995900E-01, -.24682800E-02, 0.98162300E-03, -.17696300E-02 }, { -.47177000E-01, 0.28196100E-01, 0.13573000E+00, 0.10202800E+00, 0.49156500E-01, 0.29808100E+00, 0.37426500E+00, -.60763300E-01, 0.18379800E-01, -.66510600E-01, 0.79452800E-02, 0.68436200E-01, -.45514000E-01, 0.34100200E+00, -.56396500E-01, -.11666400E+00, -.49379500E-01, -.49111200E-01, -.15874600E-01, 0.22435400E-01, -.22346300E-01, 0.84607700E-02, 0.48418500E-01, -.23806800E-02, 0.45902400E-02, -.23752400E-02, -.78306500E-02, -.27752700E-02, -.46263100E-02, -.65054600E-02, -.53465000E-01, 0.15285900E-01, -.15853400E-01, 0.77639200E-02, 0.21237300E-01, 0.28528600E-01, -.32245300E-02, 0.29173700E-01, 0.20492500E-01, -.19903100E-02, 0.15271400E-01, -.20912300E-02, -.33563700E-02, 0.24160000E-01, 0.10544900E-01, -.59196000E-01, 0.12127300E-01, 0.70169300E-01, -.31735100E-03, -.86672400E-03, 0.50373300E-02, 0.85947600E-02, -.98536400E-02, -.66127600E-02, 0.18213100E+00, 0.95190500E-02, -.49099300E-02, -.79217800E-02, 0.55029200E-02, 0.24818300E-01, 0.18007200E-01, 0.14698100E-02, 0.63303100E-02, 0.50856300E-01, 0.80739200E-02, -.48716300E-02, 0.28872700E-02, -.20524300E-01, -.23316900E-01, 0.27711900E-02, -.30045400E-02, -.31066200E-01, -.13692300E-01, 0.95971300E-02, -.13390300E-01, 0.61774300E-02, 0.13034400E-01, -.12496900E-01, 0.99954300E-02, -.18968300E-02, -.78124100E-02, 0.21980500E-02, 0.13017100E-01, 0.16385000E-02, -.38364800E-02, -.70604500E-02, 0.13195600E-02, 0.10171700E-01, -.31776400E-02, -.70313900E-01, 0.15013300E-01, -.21208700E-02, -.10407100E-02, -.37747400E-02, 0.44532600E-02, -.91045300E-03, -.17076200E-01, -.64747300E-03, 0.10433300E-03, 0.24504300E-01, -.33052800E-02, -.15180800E-01, -.13042600E-02, -.42789700E-02, 0.10742000E-02, 0.39930100E-02, -.85437900E-02, 0.24633000E-02, -.12866600E-01, 0.22793100E-01, -.54134700E-02, -.42160800E-03, -.90440300E-02, -.91042100E-03, 0.11118700E-02, -.28890700E-02, -.23772000E-02, -.74959800E-02, -.11127500E-02, -.16196900E-02, -.11357800E-01, -.16159300E-02, 0.24750400E-02, -.40928800E-02, 0.11847700E-01, -.10814600E-02, 0.42643000E-02, -.12533300E-02, -.12501400E-01, -.12000700E-02, 0.76912700E-03, 0.17993900E-02, 0.24420200E-02, -.38885600E-02, -.17553200E-02, 0.15865200E-02, 0.17774100E-03, 0.11780000E-02, -.21878000E-02, -.11570800E-02, 0.94740000E-04, 0.29453200E-02, -.33961500E-02, 0.13762700E-04, 0.17226000E-03, 0.11668900E-02, -.21808000E-02, -.11063300E-02, 0.75994500E-04, 0.28821400E-02, -.34222400E-02, 0.21695400E-03, -.17232100E-03, -.95138100E-03, -.66212000E-02, -.15990000E-02, 0.10081900E-02, 0.22549400E-02, -.38574600E-02, -.39129200E-02, -.28466500E-02, -.13363700E-02, -.80011000E-02, -.18925300E-02, -.54219000E-02, 0.19135600E-02, -.32507600E-02, -.13317600E-02, 0.10472100E-02, -.30077400E-02, 0.34860300E-02, 0.39909100E-02, 0.10262800E-02, 0.50218000E-02, 0.55507300E-03, 0.97285500E-02, -.20077900E-02, -.31376600E-02, 0.14485600E-02, -.17706100E-02, -.12531900E-02, 0.17837400E-02, -.10708400E-01, -.29015900E-03, -.54034600E-03, -.22374300E-02, 0.23755200E-02, 0.33929100E-02, -.10605700E-02, -.15742100E-02, -.16770600E-02, 0.56121600E-02, 0.98051600E-03, 0.41310500E-02, -.40400000E-02, -.51456700E-02, 0.87966000E-03, 0.26520400E-02, 0.92701400E-03, -.60778200E-02, 0.84704400E-03, 0.57092900E-01, -.13869200E-02, 0.45150700E-03, 0.13493400E-01, 0.48254300E-03, 0.79458700E-03, 0.13363500E-02, -.20879800E-01, 0.96665900E-02, -.60225900E-02, -.59249400E-03, 0.52206000E-02, 0.10235200E-02, 0.10959500E-02, -.13709300E-02, -.19368700E-02, 0.56221600E-02, -.16681600E-01, 0.33157800E-01, 0.12756400E-03, -.77821000E-03, -.35055500E-01, -.29199400E-02, 0.91709800E-03, -.20429700E-02 }, { -.59521500E+00, 0.10027600E-01, 0.86237000E+00, 0.85600500E+00, -.73375400E-03, -.88817800E+00, -.15706900E+01, -.50206500E+00, 0.32056300E+00, -.59997200E+00, 0.18365400E-01, 0.91865600E+00, -.57631900E-01, 0.28546700E+01, -.12628100E+01, -.15428100E+01, -.41401600E+00, -.95914000E+00, -.18151400E+00, 0.28673700E+00, -.43828600E+00, 0.28295200E+00, 0.11246900E+01, -.22821900E+00, 0.11222400E+00, -.89786800E-01, 0.15120800E+00, 0.19719100E-01, 0.49227200E+00, -.10921100E+00, 0.55575500E+00, 0.21219200E+00, -.33368300E+00, 0.20637600E+00, 0.25397700E+01, 0.44909500E+00, -.14135800E-01, 0.53477500E+00, 0.59225400E+00, 0.81415800E-01, 0.39403800E+00, -.99550800E-01, -.34624100E+00, 0.11051400E+00, 0.27320200E-01, -.10029000E+01, 0.24264000E-01, 0.21916200E+01, 0.40912900E-01, -.74132000E-01, 0.92119000E-01, 0.63715700E-01, -.41919800E+00, -.68112200E-01, 0.62910800E+00, -.13186300E+00, -.87767000E-01, 0.50344400E+00, -.25725300E+00, -.23295200E+00, 0.11963500E+00, -.75547700E-02, 0.10985700E+00, 0.68726700E+00, 0.64081900E-01, -.33363500E-01, 0.31956500E-01, -.35519400E+00, -.16392000E+00, -.34226000E-02, 0.10944400E+01, -.17843200E+00, -.23054300E+00, 0.20725600E+00, -.37198500E-01, 0.10271800E+00, 0.13982800E+00, -.24061700E+00, -.25259200E+00, -.69826900E+00, -.56404400E-01, 0.73443000E-01, 0.58634100E+00, 0.39255100E-01, -.16022500E+00, -.25342200E+00, 0.94619700E-01, 0.26804000E+00, 0.69148400E-01, -.19414800E+01, 0.35846300E+00, -.13664600E-02, 0.75052300E-01, -.95050700E-01, 0.32695800E+00, 0.46762200E-01, -.40053000E+00, 0.45548400E-02, 0.40491300E-01, 0.19852500E-01, -.39412000E-01, -.37031200E+00, -.60688900E-01, -.65907700E-01, 0.40787400E-01, 0.13417100E+00, -.47328800E-02, 0.82141400E-01, -.99982200E-02, 0.22203200E+00, 0.88281400E-01, 0.56935900E-01, 0.30992200E-01, 0.17961300E+00, -.83490500E-01, -.40087200E-01, -.47514700E-01, 0.21567200E-01, -.60738800E-01, 0.44735900E-02, 0.27158000E-01, -.27581400E-01, 0.74832000E-01, -.25624900E-01, -.12146500E+00, -.85916000E-01, 0.30585400E+00, -.57815800E-01, 0.12232700E+01, -.76695600E-01, 0.24320400E+00, -.36549400E-01, 0.95559200E+00, 0.63571400E+00, 0.10296900E+00, -.20668800E+00, -.24256300E-01, -.10620800E-01, 0.49994000E-02, 0.45851100E-01, 0.11455400E+00, 0.11070300E-01, 0.45304500E-01, 0.15115100E+00, -.24087900E-01, -.10825600E-01, 0.36827500E-02, 0.45147100E-01, 0.11295900E+00, 0.11410000E-01, 0.45163300E-01, 0.15009800E+00, -.44639300E-02, -.22285700E-01, -.11138600E+00, 0.12212200E+00, 0.68578200E-02, 0.13357300E+00, -.12988800E-01, 0.13257500E+00, -.76656300E-01, 0.56376000E-01, -.10595500E+00, -.13110400E+00, -.42760300E-01, -.71167700E-01, 0.24868100E-01, 0.46934900E-02, -.26059600E-01, -.41241200E-01, 0.10482600E+00, 0.10930000E+00, 0.85502700E-01, 0.22635100E-01, 0.19671100E-02, 0.12235300E+00, -.25795200E-01, -.33350600E-01, 0.21326300E-01, 0.41933400E-02, -.23123200E-01, 0.39052400E-01, 0.16752800E+00, -.29295100E-01, -.14968600E-02, -.15593000E-01, 0.10468700E-01, -.57347300E-02, 0.26784500E-01, -.18585100E-01, -.28966800E-01, -.69624000E-01, 0.19706500E-02, 0.30664200E-01, -.22751300E-01, 0.10660600E-01, -.50227100E-01, 0.36330200E-01, 0.52504000E-01, 0.12585000E+00, 0.95821900E-02, 0.18055100E+00, -.24799300E-01, 0.32320300E-01, -.53107000E+00, -.88996200E-04, 0.39790500E-01, 0.10743100E+01, -.11390800E+00, -.83021000E+00, -.60126000E-03, 0.38368300E-01, 0.24638100E-01, -.23854100E-01, -.10395200E-01, 0.57341400E-01, -.19121800E-01, -.19109000E+00, 0.75655600E-01, 0.10996700E+00, 0.16850400E+00, 0.39850300E-02, 0.29650700E-01, -.93711500E-02, -.55694200E-02, 0.50847000E-02 }, { 0.61622400E+01, 0.23202800E+01, -.54220700E+01, -.41739200E+01, -.43291500E+01, -.14662700E+02, -.74474800E+01, 0.81072500E+01, -.12424700E+01, 0.30668000E+01, 0.31639300E+00, 0.37516300E+00, 0.41995100E+01, -.20213800E+02, 0.20531000E+01, 0.15434100E+02, 0.27814700E+01, 0.15458000E+02, 0.57569200E+01, -.21002700E+01, -.59432500E+01, 0.26883100E+00, 0.16251200E+01, -.47938800E+01, 0.96682500E-01, -.67175300E+00, 0.89350700E+00, -.18438100E+00, -.84097500E+01, -.10475800E+01, -.13377100E+02, 0.13493100E+01, 0.28913900E+01, 0.74292400E+00, 0.21659600E+02, -.11379900E+01, -.36292200E+00, -.13846800E+01, -.20949600E+01, -.34628200E+00, -.20694400E+01, 0.17228900E+01, -.91160600E+01, -.13565300E+01, -.14101400E+01, 0.85501300E+01, -.17333700E+01, -.83418000E+01, 0.14781400E+00, 0.13599800E-01, -.22151100E+00, -.10496200E+01, 0.17105200E+00, 0.16596800E+00, -.32331600E+02, -.11071400E+01, 0.19489200E+00, 0.23379000E+00, -.30562500E+01, -.12403500E+01, -.48576700E+01, -.64287800E+00, 0.81829400E-01, -.46523800E+01, -.17106100E+01, 0.40155200E+00, -.56451200E+00, 0.26962100E+01, 0.19617400E+01, -.12117500E+00, 0.89932100E+01, 0.10530500E+01, 0.13457500E+01, -.10643100E+01, 0.40339700E+00, 0.57433700E+00, 0.19608000E+01, -.11892100E+01, -.23169700E+01, 0.12823700E+02, 0.34000800E+01, 0.11859300E+01, 0.92973500E+00, -.97265700E+00, -.11260400E+01, 0.21070100E+01, 0.14159400E+01, -.32019000E+01, 0.26823600E+00, 0.50851000E+01, -.33173400E+01, -.10019600E+00, -.82135200E+00, -.61385300E+00, 0.58382900E+01, -.77958700E+00, -.54347900E+00, 0.43551800E+00, 0.47309000E+00, 0.63452800E+01, 0.33392800E+00, 0.92753100E+00, 0.32629000E+00, -.13587800E-01, -.55247700E+00, -.97113100E-01, 0.29763200E+00, 0.94869900E+00, 0.19871200E+01, -.92468100E+00, -.25834300E+01, 0.95843600E-01, 0.47528700E+00, 0.10998500E+01, 0.33495500E+01, -.70922400E+00, 0.13433000E+01, 0.63311000E+00, 0.63382000E+00, 0.79835600E+00, -.81811500E+00, -.24741600E+01, 0.19447500E+01, -.16755800E+01, 0.68231500E+01, 0.18992100E+01, -.45164400E+01, 0.46940300E+00, 0.11725600E+02, -.13660100E+00, -.61233500E+00, 0.15689600E+00, -.25126700E+02, -.16111100E+01, 0.85352100E+00, 0.16490500E+01, 0.20369900E-02, -.13831100E+00, 0.62628300E+00, -.18780200E+00, 0.82950500E+00, 0.38145400E-01, 0.99258600E+00, -.92143100E+00, 0.26253800E-02, -.13900000E+00, 0.61586800E+00, -.19116100E+00, 0.81934500E+00, 0.44089300E-01, 0.98382000E+00, -.93165400E+00, 0.53177600E-01, 0.38199000E-02, -.89387700E+00, 0.22025600E+01, 0.50642400E+00, 0.11143700E+00, -.10407400E+01, 0.12641500E+01, 0.15195200E+00, 0.13693900E+01, -.17006600E+01, -.20573300E+01, 0.78710900E-01, -.46567400E+00, 0.22825000E+01, 0.22507900E+00, -.40002200E+00, -.63879200E-01, 0.45242000E+00, 0.69621600E+00, 0.31712400E+00, -.34852700E+00, -.59216900E+00, 0.55069800E+00, -.75706800E-01, -.39253900E-01, 0.30600200E-01, 0.16049600E+00, -.59741100E-01, 0.10566200E+00, 0.11510100E+01, -.16446600E+00, -.39346300E-01, 0.19084900E-01, -.95648800E-01, -.56252700E-01, 0.39934100E+00, -.93296400E-01, 0.45601900E+00, -.48140700E+00, 0.54478500E-01, -.30565200E-01, 0.17447400E+00, 0.95480400E-01, -.62369500E+00, 0.16727900E+00, -.74072100E+00, 0.92052900E+00, 0.12538700E+00, -.74262500E+00, -.12394000E+00, -.10425200E+01, -.40148800E+01, 0.12329300E+00, -.30583200E+00, 0.97723600E-01, 0.36430300E+00, -.35194000E+00, -.14491200E-01, 0.61449700E-01, -.10833100E+00, 0.94129300E+00, -.25160100E-01, -.62420800E+00, -.10340900E+00, -.81806700E+00, 0.47869900E+00, 0.31079200E+00, -.61512300E+00, -.38182900E+01, 0.49592700E+00, 0.23682400E+00, -.26710000E-01, 0.52502500E-01 }, { 0.19173300E+01, 0.64779600E+00, -.20129000E+01, -.11725100E+01, -.99011300E+00, -.50457100E+01, -.34129400E+01, 0.22201000E+01, -.46887000E+00, 0.74951200E+00, 0.19242500E-01, -.63820600E+00, 0.97407900E+00, -.67319000E+01, 0.13799300E+01, 0.42100400E+01, 0.26857700E+01, 0.15328000E+01, 0.47968400E+00, -.88975400E+00, 0.99069800E-01, 0.14343500E+00, -.58107200E-01, -.49744300E+00, 0.41176900E-01, -.16459300E+00, 0.82793300E+00, 0.28526000E+00, -.25276100E+00, -.77348000E-01, -.28206300E+00, -.16409300E+00, 0.49300800E+00, 0.10385500E+00, 0.23205700E+01, -.56053300E+00, 0.30366400E-01, -.42439800E+00, -.20178200E-01, 0.10092400E+00, -.24270700E+00, -.31536700E+00, -.12407400E+01, -.31423400E-01, -.71129100E-01, 0.16149300E+01, -.32151600E+00, -.12600100E+01, -.28913700E-01, 0.31628600E-01, -.72868600E-01, -.37530000E-01, 0.32849900E+00, 0.15281300E-01, -.42689800E+01, 0.10279600E+00, 0.69084100E-01, -.23504100E+00, 0.21640000E+00, 0.77463800E-02, -.48021200E+00, 0.68895800E-01, 0.19611500E-01, -.84835200E+00, -.35832700E+00, 0.82290100E-01, -.12888200E-01, 0.34322800E+00, 0.40295900E+00, -.54017400E-01, 0.75612700E+00, 0.54233200E+00, 0.22045600E+00, -.22349000E+00, 0.12240900E+00, -.66644600E-02, -.37401900E-01, 0.80765600E-01, 0.23487700E+00, -.31391500E+00, 0.31092000E+00, 0.53368300E-01, 0.18298300E-01, 0.45849500E-01, -.21298200E+00, 0.47951100E+00, 0.32288100E-01, -.30946600E+00, 0.55972600E-01, 0.20077800E+00, -.24864200E+00, 0.63244100E-01, 0.34360700E-01, 0.12983800E+00, 0.75625600E-01, -.18454300E+00, 0.35052400E+00, -.34039500E-01, -.34221100E-01, -.40641500E-01, 0.22523500E+00, 0.62283200E+00, 0.12953000E+00, 0.11268900E+00, -.21331200E-01, -.53512200E-01, 0.63719600E-01, -.45432000E-01, 0.22616300E+00, -.32501500E+00, -.18437600E+00, 0.45436700E-01, 0.53722100E-01, 0.19613700E+00, 0.15075400E-01, 0.60106400E-01, 0.86633700E-01, 0.12206300E+00, 0.22289200E+00, 0.48775100E-01, 0.87812900E-01, -.17190700E+00, 0.45123900E-01, -.97459600E-01, 0.22997300E+00, 0.15123300E+00, -.45079800E+00, 0.76126900E-01, -.21404300E+00, 0.16390300E+00, 0.37844300E+00, -.28369800E-01, -.45522200E+01, -.97898800E+00, 0.14527500E-02, 0.55622100E-02, -.15041400E-01, 0.36588200E-02, 0.69946900E-01, 0.21627100E-01, 0.61531700E-01, -.24954600E-01, 0.17197700E+00, 0.27168700E-01, -.14448700E-01, 0.33776300E-02, 0.68070500E-01, 0.20678100E-01, 0.60692900E-01, -.23595700E-01, 0.17231600E+00, 0.23136600E-01, 0.40384700E-01, 0.19414400E-01, 0.47163200E-01, -.43293000E-01, 0.20027700E-01, 0.10770800E-01, -.30452200E-01, 0.10687600E+00, -.88796600E-01, -.10815000E+00, -.14432000E+00, -.14975100E+00, -.14693500E-01, -.34543400E-01, -.40222700E-01, -.15673300E-01, -.25714900E-01, 0.12697500E-01, 0.99099400E-01, 0.15927400E+00, -.10306100E+00, -.11798800E+00, 0.44988100E-01, 0.22720000E+00, -.18534800E-01, -.49722400E-02, 0.40391300E-01, -.31859500E-01, -.10830200E+00, -.12296400E-01, 0.16479500E-02, -.58113700E-01, 0.10959100E-01, -.20212100E-01, -.32633500E-02, -.35286000E-03, -.21488900E-01, 0.26423300E-01, -.74897300E-01, 0.52672900E-02, -.17836800E-01, 0.38726800E-01, 0.81465300E-03, -.42946500E-02, 0.28895700E-01, -.48576600E-01, 0.12973400E+00, -.35542600E-01, -.24911200E-01, 0.17107600E+00, 0.18278500E-01, -.15088700E+00, 0.48387500E+00, 0.91997100E-03, 0.35375700E-01, -.10121000E+00, 0.40601400E-01, 0.38935700E-01, -.23314400E+00, 0.57697700E-01, -.80819800E-01, 0.86219900E-01, -.34413500E-01, 0.32926300E+00, 0.23074500E+00, -.39219900E+00, 0.10942700E+01, 0.11971800E+01, 0.41582900E+00, -.21818000E-02, 0.10282200E+01, 0.13953400E+00, -.67293900E-01, 0.96452400E-01 }, { 0.87230800E+00, 0.31875200E+00, -.23388800E-01, -.30728900E+00, -.14183200E+00, 0.96930000E+00, 0.24773700E+01, 0.94443700E+00, -.33433600E+00, 0.29922800E+00, 0.24750900E-01, -.20914200E+00, 0.35688200E+00, -.29601000E+01, 0.68046500E+00, 0.20586300E+01, 0.12155600E+01, 0.98202100E+00, 0.21309600E+00, -.44251500E+00, -.91455900E-01, 0.10710000E+00, 0.13872400E+00, -.32132700E+00, 0.42306500E-01, -.53726400E-01, 0.47162800E+00, 0.16622800E+00, -.33245900E+00, 0.27375200E-02, 0.35867300E+00, -.46685600E-01, 0.10070400E+00, 0.58573100E-01, 0.37115900E+00, -.22750900E+00, 0.15458000E-02, -.26008300E-01, -.20297400E+00, 0.61271800E-01, -.16547300E+00, -.11404700E+00, -.92184700E+00, -.37689000E-01, -.15690900E+00, 0.99801800E+00, -.20759400E+00, -.92549900E+00, -.10952400E-01, -.10222500E-01, -.84079400E-01, -.49608200E-01, 0.13454000E+00, 0.22351200E-01, -.16376400E+01, 0.21902300E-01, 0.63509000E-01, 0.13807700E-01, 0.17476000E-01, -.12347300E+00, -.40949200E+00, -.13106600E-01, 0.18308000E+00, -.17569000E+00, -.35845900E+00, 0.15620500E-01, 0.43953400E-01, 0.74960300E-01, 0.10947700E+00, -.73708900E-02, 0.46180800E-01, 0.12912800E+00, 0.16131700E+00, -.11200000E+00, -.46616100E-01, 0.10072800E-01, -.54070000E+00, 0.17355600E+00, 0.35971500E+00, -.34478200E+00, 0.59578400E+00, -.28828400E-01, 0.28243400E+00, -.23565500E-01, -.21692100E+00, 0.37054300E+00, -.15694600E-01, -.29525300E+00, -.21746500E-01, -.22789200E+00, -.71208300E-01, 0.22156500E-01, 0.46696600E-01, -.51738900E-01, 0.23912300E+00, 0.58586700E-01, 0.14068100E+00, -.48240800E-01, -.50742100E-01, 0.12250400E+00, 0.11322000E+00, 0.41826200E+00, 0.57449600E-01, 0.98538300E-01, 0.80467900E-02, -.56375100E-01, 0.19674000E-01, -.67542000E-01, 0.91855200E-01, 0.58040500E-01, -.15664600E+00, -.47089200E-01, -.23384600E+00, 0.20349800E+00, -.98618600E-01, 0.80423900E-01, 0.48521800E-01, -.40645900E-01, 0.23393200E+00, -.25661900E-01, 0.12401300E-01, -.11498700E+00, 0.34172400E-01, -.63801200E-01, 0.51195400E-01, 0.57339600E-01, -.32388500E+00, 0.53339300E-01, 0.46324000E+00, 0.12393200E+00, 0.44298400E-01, -.30800700E-01, -.23673000E+01, -.33487600E+00, 0.25767700E-01, 0.11340800E+00, 0.10746800E-01, -.25493800E-01, 0.77168100E-01, -.26698500E-02, 0.11276200E+00, -.30565500E-01, 0.19657100E+00, -.95018800E-01, 0.10923100E-01, -.25478200E-01, 0.76502700E-01, -.40949300E-02, 0.11178700E+00, -.28729800E-01, 0.19632800E+00, -.10155600E+00, 0.29625400E-01, 0.35824100E-01, 0.64468800E-01, 0.15098400E+00, -.49101700E-01, 0.11525900E-01, 0.49141000E-02, 0.35065200E-01, 0.15614400E+00, 0.29766100E-01, 0.82273800E-01, -.96858200E-01, 0.22177000E-01, -.18207200E+00, -.37877700E-01, -.12055600E-01, -.56744100E-02, 0.36574800E-01, -.31058200E-01, 0.29255200E-01, -.66090000E-01, -.45703100E-01, -.20376900E-01, 0.61591500E-01, -.19322900E-01, -.30219900E-01, 0.17365600E-02, -.65297100E-02, -.56869800E-01, -.28293100E-01, -.28698900E-01, 0.17330800E-01, -.95784500E-02, -.99411800E-02, 0.41409600E-01, 0.52348300E-02, 0.15686900E-01, 0.31150300E-02, 0.88800300E-01, 0.11012400E-01, 0.15090800E-01, 0.20589100E-01, -.75746100E-01, -.82135800E-02, -.28578000E-01, -.71838600E-02, -.15610500E+00, -.27646900E-02, 0.22229300E-01, 0.23936700E+00, -.10403000E-02, -.39004100E-01, 0.17756200E+00, -.71778900E-02, 0.16061700E-01, 0.19908700E-01, 0.31971200E-01, -.24897500E-01, -.26112300E-01, 0.92410700E-02, -.47383200E-01, 0.84702000E-01, -.93605600E-02, 0.22016500E-01, 0.18458200E+00, -.95069900E-01, 0.17269500E+00, 0.18603900E+00, -.26657400E-01, -.46266600E-02, 0.11807300E+00, 0.87136300E-01, -.34869900E-02, 0.44312600E-02 }, { 0.65003500E-01, -.36361800E-01, -.21635400E+00, -.15982700E+00, -.81847000E-01, -.47588300E+00, -.65386100E+00, 0.90210400E-01, -.24427100E-01, 0.88580300E-01, -.11000900E-01, -.92469600E-01, 0.62046900E-01, -.46112000E+00, 0.74324100E-01, 0.15620100E+00, 0.70513700E-01, 0.64151600E-01, 0.19022400E-01, -.28848200E-01, 0.27647400E-01, -.10372000E-01, -.64265500E-01, 0.12051300E-02, -.60326100E-02, 0.31628000E-02, 0.13684600E-01, 0.47863000E-02, 0.10003400E-01, 0.86957100E-02, 0.88260600E-01, -.22405900E-01, 0.20517100E-01, -.10259100E-01, -.17069800E-01, -.38200400E-01, 0.52027600E-02, -.38049400E-01, -.18805100E-01, 0.26055000E-02, -.18324500E-01, 0.48807800E-03, -.15027600E-02, -.32050600E-01, -.13189500E-01, 0.74943300E-01, -.16883600E-01, -.81246200E-01, 0.81280500E-03, 0.74254900E-03, -.46161900E-02, -.10609500E-01, 0.83046700E-02, 0.80316100E-02, -.23473800E+00, -.13985800E-01, 0.50220500E-02, 0.14957100E-01, -.84326100E-02, -.36570800E-01, -.21998000E-01, -.19573300E-02, -.10590300E-01, -.71572200E-01, -.83731100E-02, 0.65951900E-02, -.36973500E-02, 0.29368400E-01, 0.30938200E-01, -.38142200E-02, 0.10245700E-01, 0.41453000E-01, 0.17847400E-01, -.12135400E-01, 0.18134900E-01, -.80685400E-02, -.16260500E-01, 0.15679700E-01, -.14647500E-01, 0.21216000E-02, 0.97622100E-02, -.21917000E-02, -.14991900E-01, -.24479600E-02, 0.44032900E-02, 0.68302400E-02, -.74905800E-03, -.12290900E-01, 0.43266500E-02, 0.91740000E-01, -.22034500E-01, 0.32825500E-02, 0.13933900E-02, 0.52043800E-02, -.77569500E-02, -.16306900E-02, 0.25753100E-01, 0.11008900E-02, -.14868500E-03, -.40534900E-01, 0.38292600E-02, 0.18450400E-01, 0.13313500E-02, 0.55069000E-02, -.14212700E-02, -.50653700E-02, 0.11526100E-01, -.26476400E-02, 0.20819600E-01, -.30049800E-01, 0.72622400E-02, 0.57261000E-03, 0.14290300E-01, 0.29809100E-02, -.62804300E-03, 0.34774000E-02, 0.29089100E-02, 0.10864500E-01, 0.25020800E-03, 0.25073700E-02, 0.15751000E-01, 0.16351100E-02, -.25586000E-02, 0.48240400E-02, -.13572300E-01, 0.95088400E-03, -.30554400E-02, 0.10366300E-02, 0.18273500E-01, -.44908700E-03, -.27627100E-04, -.27516600E-02, -.11170800E-01, 0.63178100E-02, 0.42862400E-02, -.28095200E-02, -.35862600E-03, -.15622800E-02, 0.30691900E-02, 0.16908800E-02, -.95950000E-03, -.37638700E-02, 0.13837000E-02, 0.80518100E-03, -.35316100E-03, -.15442300E-02, 0.30525500E-02, 0.16356100E-02, -.91390200E-03, -.36891000E-02, 0.14557500E-02, 0.57979300E-03, 0.14535100E-03, 0.13362100E-02, 0.87026100E-02, 0.14204400E-02, -.68759900E-03, -.30556600E-02, 0.48142200E-02, 0.60866100E-02, 0.33267200E-02, 0.21913100E-02, 0.10769300E-01, 0.26246100E-02, 0.75973100E-02, -.22265300E-02, 0.53903600E-02, 0.21524100E-02, -.18096800E-02, 0.40818100E-02, -.34753900E-02, -.46112800E-02, 0.16829600E-04, -.69064000E-02, -.66574400E-03, -.12710300E-01, 0.30437100E-02, 0.42934600E-02, -.19123800E-02, 0.30154800E-02, 0.16810300E-02, -.16659400E-02, 0.17624700E-01, 0.44923600E-03, 0.82200600E-03, 0.30119700E-02, -.37347500E-02, -.48787200E-02, 0.14590600E-02, 0.20896900E-02, 0.24847400E-02, -.89160100E-02, -.14730400E-02, -.55839500E-02, 0.64150500E-02, 0.74878400E-02, -.12187400E-02, -.35058300E-02, -.16640100E-02, 0.10447300E-01, -.12885100E-02, -.80219900E-01, 0.18570200E-02, -.80078100E-03, -.22682000E-01, -.51715700E-03, -.11504700E-02, 0.22002700E-02, 0.27792800E-01, -.15758000E-01, 0.81424500E-02, 0.84107700E-03, -.69174300E-02, -.79974000E-03, -.14424600E-02, 0.19095100E-02, 0.19966100E-02, -.60397800E-02, 0.21637500E-01, 0.16658800E-01, -.35979400E-03, -.28031200E-03, 0.50587900E-01, -.40017700E-01, 0.35632700E-01, -.19959100E-02 }, { -.35420700E-01, 0.43187700E-02, 0.21825200E+00, 0.17689500E+00, 0.98974600E-01, 0.48545800E+00, 0.95695400E+00, -.49492900E-01, 0.10181600E-01, -.17830500E-01, 0.16593800E-02, 0.24006300E-01, -.16290000E-01, 0.13730800E+00, -.28290000E-01, -.63911000E-01, -.44057200E-01, -.23093700E-01, -.52383700E-02, 0.10974500E-01, 0.26067900E-03, -.19342200E-02, 0.86366400E-02, 0.96518800E-02, 0.15861200E-03, 0.30580800E-02, -.16425000E-01, -.61236200E-02, -.35211500E-02, -.44930100E-03, -.32685200E-01, 0.70413800E-02, -.77495800E-02, 0.49506400E-03, -.14888600E-01, 0.12182800E-01, -.21345900E-02, 0.11309700E-01, -.72398800E-02, -.19699000E-02, 0.31788500E-02, 0.74529500E-02, 0.67526700E-02, 0.79112300E-02, 0.73301400E-03, -.20263600E-01, 0.69864100E-02, 0.13184500E-01, -.60980900E-03, 0.67367800E-03, -.13509400E-02, 0.11873600E-02, 0.36800200E-02, -.82751800E-03, 0.72503900E-01, 0.42333500E-02, 0.50977600E-03, -.51501700E-02, 0.31553900E-02, 0.10209600E-01, -.20446200E-03, -.13898800E-02, 0.59699400E-02, 0.25486200E-01, -.77966700E-03, -.20021100E-02, 0.67007800E-03, -.10135400E-01, -.88909300E-02, 0.13690400E-02, -.67317100E-02, -.13136500E-01, -.42437300E-02, 0.33341300E-02, -.28960900E-02, 0.19224000E-02, 0.29095900E-02, -.26797200E-02, 0.15061500E-02, 0.37172200E-02, -.19772400E-02, -.12147300E-02, -.18969400E-02, 0.44700100E-03, 0.26752300E-02, -.96545900E-03, -.12267200E-02, 0.28893700E-02, -.10308500E-02, 0.29281500E-02, 0.52326200E-02, -.16497700E-02, -.96413900E-03, -.27281500E-02, 0.10741600E-01, 0.51718300E-02, -.17987300E-01, -.42919900E-03, 0.20282700E-03, 0.20347100E-01, -.29320400E-02, -.64050800E-02, -.11693300E-02, -.15995400E-02, 0.40564100E-03, 0.73343400E-03, -.26808700E-02, -.52118500E-04, -.72294700E-02, 0.76120300E-02, -.13823200E-02, -.99639700E-03, -.71142400E-02, -.43322300E-02, -.89375100E-03, -.64999600E-03, -.10777700E-02, -.44332100E-02, 0.62162100E-03, -.13080800E-02, -.47851800E-02, 0.10996400E-02, -.23020200E-03, 0.43505100E-03, -.18946600E-02, -.43601500E-03, -.11485400E-02, 0.12705600E-03, -.50592000E-02, 0.18917900E-02, -.18770800E-02, 0.98638200E-03, 0.42160000E-01, 0.21738800E-02, -.36302800E-02, 0.11198500E-02, 0.29430300E-03, 0.17672600E-03, -.12714600E-02, -.77628600E-03, 0.87845900E-03, 0.62936500E-03, 0.37490300E-02, -.15130800E-02, 0.28982600E-03, 0.17071200E-03, -.12479400E-02, -.76817100E-03, 0.84806400E-03, 0.61702500E-03, 0.36624700E-02, -.14827000E-02, -.25501100E-03, -.62546800E-03, -.20224300E-02, 0.12889700E-02, -.73668700E-03, 0.34239600E-03, -.77417000E-03, -.19034300E-02, -.34180900E-03, -.11744100E-03, -.48108600E-03, 0.59961100E-03, -.27637400E-02, -.13799200E-04, -.22772300E-02, -.42848800E-03, 0.12306100E-02, -.19687800E-02, -.80220700E-03, -.14417600E-02, -.12123100E-02, 0.25747600E-02, 0.30128500E-03, 0.21089300E-04, -.11141200E-02, -.91665100E-03, 0.32412100E-03, -.15886000E-02, -.25173900E-03, -.95489000E-04, -.88277500E-02, 0.10321000E-03, -.46600200E-03, -.44150000E-03, 0.16770300E-02, 0.18448400E-02, -.49683500E-04, -.55026900E-03, -.21710600E-02, 0.40213900E-02, 0.83364500E-03, 0.85005800E-03, -.29667700E-02, -.29973800E-02, -.41517600E-03, 0.90720000E-03, 0.30965800E-02, -.55778800E-02, 0.90951500E-03, 0.27733200E-01, -.73575100E-03, 0.35453100E-02, 0.11364700E-01, 0.30347200E-05, 0.43127200E-03, -.61765400E-02, -.23923700E-02, 0.61852200E-02, -.12932500E-02, -.38315500E-03, 0.19536400E-02, 0.80510600E-03, 0.39327300E-03, -.18698200E-02, 0.49429100E-03, 0.34768000E-02, -.74884200E-02, -.82113400E-02, -.25041800E-02, -.16371800E-03, -.39352500E-01, 0.50854400E-01, -.56013500E-01, 0.36267600E-01 } },
        { { -.13052700E+06, 0.67746300E+05, 0.22139100E+05, 0.28732200E+05, 0.98066600E+04, -.52105700E+05, -.10699600E+05, 0.26625100E+05, -.80326400E+04, 0.40720000E+04, 0.14276000E+04, 0.18308200E+04, 0.45395500E+03, -.31925800E+04, -.57389500E+03, 0.16959400E+04, 0.65901300E+05, -.33020500E+05, -.11779600E+05, -.15176000E+05, -.43933000E+04, 0.26858600E+05, 0.67897800E+04, -.14249700E+05, 0.80137600E+05, -.41482000E+05, -.13630700E+05, -.17282100E+05, -.65836100E+04, 0.31266400E+05, 0.40320400E+04, -.16171100E+05, -.82739900E+05, 0.43435300E+05, 0.11782900E+05, 0.16014200E+05, 0.85346400E+04, -.32707400E+05, -.61992300E+04, 0.14254100E+05, -.79271400E+05, 0.39905700E+05, 0.15039400E+05, 0.19201300E+05, 0.35159800E+04, -.32422600E+05, -.87761700E+04, 0.18017600E+05, -.57063300E+05, 0.29454700E+05, 0.92393600E+04, 0.11695500E+05, 0.52738400E+04, -.21891900E+05, -.15650100E+04, 0.10778600E+05, -.17930200E+05, 0.90877900E+04, 0.31831300E+04, 0.40826400E+04, 0.10186400E+04, -.71240900E+04, -.12789700E+04, 0.37812200E+04, -.58647600E+05, 0.28596900E+05, 0.87193200E+04, 0.11526500E+05, 0.56785400E+04, -.22697600E+05, -.24514700E+04, 0.10297300E+05, 0.24281200E+05, -.12305300E+05, -.43043200E+04, -.55205200E+04, -.13905200E+04, 0.96389700E+04, 0.17034100E+04, -.51114200E+04, -.19293400E+04, 0.97845400E+03, 0.34271800E+03, 0.43949900E+03, 0.10939800E+03, -.76670000E+03, -.13714400E+03, 0.40708800E+03, -.71152800E+04, 0.36067300E+04, 0.12648400E+04, 0.16219500E+04, 0.40171600E+03, -.28278400E+04, -.50751900E+03, 0.15025000E+04, -.86105800E+05, 0.44495900E+05, 0.13002500E+05, 0.17543300E+05, 0.77990900E+04, -.34369900E+05, -.67335100E+04, 0.15911700E+05, 0.11602100E+06, -.59359200E+05, -.20119300E+05, -.25966200E+05, -.79721100E+04, 0.46145200E+05, 0.83816800E+04, -.24114100E+05, -.70361400E+05, 0.35198900E+05, 0.12619900E+05, 0.16214400E+05, 0.36396600E+04, -.28145200E+05, -.57167800E+04, 0.14982700E+05, 0.62133100E+05, -.31256900E+05, -.11168300E+05, -.14365000E+05, -.22774300E+04, 0.24588600E+05, 0.45912200E+04, -.13136200E+05, -.70114300E+05, 0.35494500E+05, 0.10701100E+05, 0.14022300E+05, 0.71427700E+04, -.27527700E+05, -.40592000E+04, 0.12719400E+05, -.23440300E+05, 0.11897800E+05, 0.40972400E+04, 0.52649500E+04, 0.14330000E+04, -.92858800E+04, -.15721900E+04, 0.48636300E+04, -.57962700E+05, 0.28181100E+05, 0.87218700E+04, 0.11507300E+05, 0.58760900E+04, -.22666900E+05, -.32040700E+04, 0.10371700E+05, 0.97973600E+05, -.49911600E+05, -.16636800E+05, -.21582300E+05, -.69137600E+04, 0.39021900E+05, 0.75539900E+04, -.19965100E+05, -.26707200E+05, 0.13248400E+04, -.12935500E+04, 0.73385800E+04, 0.11302700E+05, 0.11800500E+05, 0.10609300E+05, 0.13143200E+05, -.65676800E+03, -.97697200E+04, -.20868800E+04, 0.58139800E+03, -.13434600E+04, -.11484900E+05, 0.46002800E+04, -.46592800E+04, -.16179900E+05, -.78957100E+04, 0.70307500E+04, 0.65870800E+04, 0.27335300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.71570800E-01, 0.54960900E+05, 0.30444700E+05, 0.38045600E+05, -.38131900E+05, -.19851700E+05, -.41615400E+05, 0.41655600E+05, 0.86488500E+03, 0.31437500E+04, 0.23020400E+04, 0.28907400E+04, -.32170100E+04, -.11106100E+04, -.27724800E+04, 0.31124200E+04, 0.10774700E+05, -.36463300E+05, -.15579900E+05, -.19815000E+05, 0.17040900E+05, 0.13005000E+05, 0.19574900E+05, -.21536000E+05, -.29594000E+05, -.26575500E+05, -.20892500E+05, -.26752600E+05, 0.32213600E+05, 0.61164300E+04, 0.31011800E+05, -.29751200E+05, 0.48790900E+05, 0.18469600E+05, 0.14809200E+05, 0.19292400E+05, -.31460100E+05, 0.27986100E+04, -.30316500E+05, 0.22363300E+05, -.20857100E+05, 0.51233700E+05, 0.21913300E+05, 0.27434200E+05, -.23213300E+05, -.18213500E+05, -.24205500E+05, 0.29404300E+05, 0.43644400E+05, 0.14830200E+05, 0.13688000E+05, 0.17566200E+05, -.27536400E+05, 0.24917100E+04, -.23071000E+05, 0.20110500E+05, 0.19128100E+04, 0.69704300E+04, 0.51332000E+04, 0.64480800E+04, -.71653200E+04, -.24781100E+04, -.61808300E+04, 0.69418000E+04, 0.12645200E+05, 0.11463500E+05, 0.95992100E+04, 0.11961100E+05, -.16473600E+05, -.25392300E+04, -.13436700E+05, 0.13340200E+05, -.28959700E+04, -.93617000E+04, -.69347600E+04, -.87108000E+04, 0.97650600E+04, 0.32594100E+04, 0.83721600E+04, -.93840400E+04, 0.22407500E+03, 0.75330300E+03, 0.55258700E+03, 0.69398500E+03, -.77656800E+03, -.26257800E+03, -.66807000E+03, 0.74756600E+03, 0.76002600E+03, 0.27821900E+04, 0.20402400E+04, 0.25618400E+04, -.28497100E+04, -.98639500E+03, -.24553000E+04, 0.27579300E+04, 0.37249200E+05, 0.20132900E+05, 0.19190900E+05, 0.24771500E+05, -.33354400E+05, -.34311000E+04, -.33095100E+05, 0.27704600E+05, -.15405500E+05, -.50204000E+05, -.28885800E+05, -.35441000E+05, 0.40829300E+05, 0.13768800E+05, 0.38407100E+05, -.39092700E+05, -.12517000E+05, 0.28902900E+05, 0.20097700E+05, 0.24840000E+05, -.22796100E+05, -.14798600E+05, -.20632200E+05, 0.26303200E+05, 0.12170600E+05, -.18208300E+05, -.21074600E+05, -.26537200E+05, 0.24403800E+05, 0.14548800E+05, 0.20450900E+05, -.27514100E+05, 0.26926900E+05, 0.20053600E+05, 0.12406900E+05, 0.14959400E+05, -.21772200E+05, -.84584800E+03, -.20777600E+05, 0.17261800E+05, 0.50611900E+04, 0.87353500E+04, 0.65230800E+04, 0.82195700E+04, -.97895000E+04, -.24668300E+04, -.82711300E+04, 0.89172300E+04, 0.45772700E+03, 0.14192100E+05, 0.90255300E+04, 0.10914200E+05, -.11339300E+05, -.59651700E+04, -.12179100E+05, 0.12027600E+05, -.18507000E+05, -.38077600E+05, -.25356500E+05, -.32432600E+05, 0.36430500E+05, 0.10482200E+05, 0.35019300E+05, -.35572300E+05, 0.30794100E+04, -.90759500E+04, 0.17482000E+04, -.12495300E+05, 0.45117900E+04, 0.14827700E+05, -.97296600E+04, 0.70263300E+04, 0.22135600E+04, -.33477700E+05, -.37901200E+04, 0.29697900E+03, 0.19079500E+04, -.79019000E+04, -.61317200E+04, 0.13859700E+05, 0.58418900E+04, -.26814800E+05, 0.70902800E+04, 0.37192900E+05, -.80305300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22916800E+00, 0.86660400E+00, -.39479600E+05, -.46703700E+05, 0.46940300E+05, 0.23101500E+05, 0.37635300E+05, -.52040600E+05, 0.12543900E+04, 0.13986500E+04, -.37288600E+04, -.45199800E+04, 0.42656800E+04, 0.23539000E+04, 0.25228900E+04, -.48702100E+04, -.37211000E+05, -.32022400E+04, 0.24113500E+05, 0.29199400E+05, -.18953200E+05, -.24586600E+05, -.15237800E+05, 0.32028500E+05, 0.20874900E+05, -.11284900E+05, 0.30964200E+05, 0.39135000E+05, -.39729600E+05, -.16823200E+05, -.36630600E+05, 0.42921200E+05, -.74230800E+05, 0.36957800E+05, -.18167100E+05, -.22479000E+05, 0.40519600E+05, -.87161000E+04, 0.29398300E+05, -.27228500E+05, 0.63529400E+05, -.53159300E+04, -.34463100E+05, -.41413900E+05, 0.26035600E+05, 0.34108800E+05, 0.17821100E+05, -.44435600E+05, -.29400500E+05, 0.20390400E+05, -.23030900E+05, -.29232100E+05, 0.33049000E+05, 0.87735200E+04, 0.28476300E+05, -.32441200E+05, 0.26936600E+04, 0.31299800E+04, -.83004400E+04, -.10064100E+05, 0.95184700E+04, 0.52040000E+04, 0.56405300E+04, -.10845900E+05, -.25392400E+04, 0.25113300E+05, -.17622300E+05, -.20568800E+05, 0.22186500E+05, 0.89642500E+04, 0.10070100E+05, -.23428900E+05, -.34845500E+04, -.44130300E+04, 0.11267500E+05, 0.13661500E+05, -.12961200E+05, -.70251900E+04, -.76393200E+04, 0.14725500E+05, 0.28894000E+03, 0.34319800E+03, -.89657500E+03, -.10869600E+04, 0.10285600E+04, 0.56408000E+03, 0.60826600E+03, -.11713800E+04, 0.11197600E+04, 0.12365400E+04, -.33057200E+04, -.40068600E+04, 0.37799300E+04, 0.20894100E+04, 0.22336700E+04, -.43168400E+04, -.56923300E+05, 0.36259200E+05, -.26007500E+05, -.32463700E+05, 0.44897000E+05, 0.28105700E+04, 0.33291400E+05, -.37307800E+05, -.17524700E+05, -.14156800E+05, 0.44868400E+05, 0.52764100E+05, -.49409400E+05, -.31763700E+05, -.35281100E+05, 0.58124400E+05, 0.22213400E+05, 0.38767000E+04, -.30289900E+05, -.35984400E+05, 0.32301100E+05, 0.21745600E+05, 0.18774700E+05, -.38563700E+05, -.35524000E+04, -.40580700E+04, 0.30811300E+05, 0.37502800E+05, -.38497100E+05, -.14246400E+05, -.20883000E+05, 0.39610200E+05, -.15463800E+05, 0.27372800E+05, -.20570800E+05, -.23692200E+05, 0.26136400E+05, 0.87600000E+04, 0.16978600E+05, -.27531000E+05, 0.15636300E+04, 0.55698300E+04, -.10811600E+05, -.13148300E+05, 0.12816600E+05, 0.63951300E+04, 0.75881800E+04, -.14228600E+05, 0.78009600E+04, 0.19627400E+05, -.15246600E+05, -.17424800E+05, 0.15017200E+05, 0.11424600E+05, 0.79745800E+04, -.20056600E+05, -.46732600E+04, -.22034200E+05, 0.40386200E+05, 0.49811700E+05, -.45570500E+05, -.22789800E+05, -.31703300E+05, 0.54779500E+05, 0.40222200E+04, 0.36375900E+05, -.97802000E+03, 0.14366900E+05, 0.25671300E+05, -.35608500E+05, 0.14244300E+05, 0.20831100E+05, -.24613000E+03, 0.34570200E+05, 0.17656900E+04, -.37007400E+03, -.13525500E+04, 0.23470900E+05, 0.23152200E+05, -.74761700E+04, 0.29134100E+04, 0.34037500E+05, -.64308500E+04, -.42911800E+05, 0.14811700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11649700E-01, -.11409700E+00, 0.17350200E+00, -.22067500E+04, 0.37958700E+04, 0.10142300E+05, 0.24590400E+05, -.92361300E+03, -.10490800E+04, -.11459100E+03, 0.40150700E+03, 0.34046200E+03, 0.14947900E+02, 0.19813300E+03, 0.17061700E+04, 0.43140300E+03, -.93274800E+04, 0.10254600E+05, 0.36711800E+03, 0.19202400E+04, 0.10619900E+03, -.73389600E+04, -.12027000E+05, 0.77619200E+03, 0.19432000E+05, -.13121900E+05, -.27423900E+04, -.26722100E+04, -.49367800E+04, 0.17832400E+04, -.12911000E+05, -.30463300E+04, 0.13092000E+05, -.66552000E+04, -.21763700E+04, -.41254200E+04, 0.18416500E+04, 0.11766000E+05, 0.16259700E+05, -.29226400E+04, 0.11172900E+05, -.12749600E+05, 0.39190600E+03, -.14113400E+04, -.18152700E+04, 0.84517900E+04, 0.14608700E+05, -.20043900E+03, -.22194500E+05, 0.13260200E+05, 0.31271800E+04, 0.34859800E+04, 0.46208400E+04, -.29632200E+04, 0.94864100E+04, 0.37831700E+04, -.22873400E+04, -.25682600E+03, 0.88607300E+03, 0.74827100E+03, 0.28878800E+02, 0.45288400E+03, 0.37917800E+04, 0.95057800E+03, -.10749600E+05, 0.75144000E+02, 0.25832700E+04, 0.20166400E+04, 0.20789900E+04, 0.11124300E+04, 0.13780100E+05, 0.28920900E+04, 0.33217400E+04, 0.26894000E+03, -.12386200E+04, -.10616200E+04, -.60714200E+02, -.54131000E+03, -.51663500E+04, -.13348000E+04, -.26019800E+03, -.25301000E+02, 0.97628200E+02, 0.83302700E+02, 0.47930900E+01, 0.45383900E+02, 0.41105800E+03, 0.10513000E+03, -.94258400E+03, -.96767500E+02, 0.35793100E+03, 0.30441500E+03, 0.14393700E+02, 0.17168200E+03, 0.15133900E+04, 0.38484900E+03, 0.83639300E+04, -.63042100E+04, -.75939600E+03, -.22899100E+04, 0.15208200E+04, 0.97262200E+04, 0.17234700E+05, -.10147200E+04, 0.14081600E+05, -.11244600E+04, -.31100300E+04, -.17444600E+04, -.33671600E+04, -.37462600E+04, -.22387100E+05, -.29618600E+04, 0.19387300E+04, -.34250800E+04, 0.17718200E+04, 0.75360900E+03, -.14903700E+04, 0.52958700E+04, 0.12782800E+05, 0.15712800E+04, -.52062100E+03, 0.16050300E+04, -.27202400E+04, -.21499000E+04, 0.26401400E+04, -.36696200E+04, -.10983800E+05, -.26979700E+04, -.81978800E+04, -.20527300E+04, 0.17319600E+04, 0.93286100E+03, 0.30473100E+04, 0.27063200E+04, 0.16162000E+05, 0.19886400E+04, -.36456800E+04, -.19797700E+03, 0.12458600E+04, 0.10924200E+04, 0.16782700E+03, 0.40672100E+03, 0.50892900E+04, 0.13637200E+04, -.50865600E+04, -.28085100E+04, 0.13699500E+04, 0.60927900E+03, 0.21088800E+04, 0.26777200E+04, 0.13350100E+05, 0.15998000E+04, 0.59536300E+04, 0.54872400E+04, -.29448300E+04, -.19005500E+04, -.12600400E+04, -.39599200E+04, -.20259600E+05, -.30743600E+04, -.35837800E+04, -.94982300E+04, -.89950500E+03, 0.97928700E+04, -.17003700E+05, 0.74496700E+04, 0.80672500E+04, -.18155100E+05, -.16236500E+04, 0.27625900E+04, 0.12063800E+04, -.61208300E+03, -.47311200E+03, -.66193700E+04, -.10814100E+05, -.76582100E+04, -.37240100E+04, 0.85017300E+03, -.60863000E+03, -.16490800E+04, 0.20686000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.38216900E+00, 0.14344600E+00, 0.29616200E+00, 0.33517700E+00, 0.71413300E+04, 0.43987100E+04, 0.28925900E+04, 0.16674800E+04, 0.72857600E+03, -.39354600E+03, -.23716100E+03, -.22540200E+03, 0.63268800E+03, 0.57234400E+03, 0.68500700E+02, -.10435300E+03, 0.47866300E+04, -.20663000E+04, -.40555600E+03, -.68486600E+03, -.43557500E+04, -.11093600E+04, -.15084200E+04, -.13776200E+04, 0.20161900E+04, -.79243300E+03, -.16603600E+04, -.24179200E+04, -.29786200E+04, -.27232700E+04, -.97404500E+03, -.35416700E+04, 0.24398600E+04, -.16384000E+04, 0.98391500E+03, 0.13412000E+04, 0.24798600E+04, 0.36525000E+04, 0.12921200E+04, 0.25249000E+04, 0.52191400E+04, -.28135100E+04, -.21634200E+04, -.23880500E+04, 0.59613000E+04, 0.39592800E+04, 0.15391900E+04, -.13591100E+04, -.67353100E+03, -.15885000E+03, 0.13808500E+04, 0.19820500E+04, 0.19071900E+04, 0.23524900E+04, 0.70605200E+03, 0.30224500E+04, 0.16293700E+04, -.87704600E+03, -.52498300E+03, -.49820100E+03, 0.14042400E+04, 0.12700900E+04, 0.14931100E+03, -.22837700E+03, 0.31090300E+03, -.52601800E+03, -.22718600E+03, -.18623900E+03, 0.36120500E+04, 0.28353600E+04, 0.82104900E+03, 0.76715000E+03, -.21637600E+04, 0.11668500E+04, 0.70436800E+03, 0.66451900E+03, -.19102500E+04, -.17132500E+04, -.19476800E+03, 0.29781700E+03, 0.17266800E+03, -.93649100E+02, -.56510500E+02, -.53473100E+02, 0.15220500E+03, 0.13743200E+03, 0.16458300E+02, -.24358400E+02, 0.64627700E+03, -.34900400E+03, -.21077500E+03, -.20046500E+03, 0.56125400E+03, 0.50781100E+03, 0.60796900E+02, -.93175500E+02, 0.21183600E+04, -.17006800E+04, 0.71147400E+03, 0.13174000E+04, 0.32686800E+04, 0.48306800E+04, 0.11785300E+04, 0.25059100E+04, 0.87547500E+03, 0.24852200E+03, 0.84219600E+03, 0.72115300E+03, -.82773500E+04, -.51602100E+04, -.22340300E+04, -.94941600E+03, 0.80686700E+04, -.38434900E+04, -.25745900E+04, -.27417200E+04, 0.55668700E+04, 0.55569000E+04, 0.62918400E+03, -.16947200E+04, -.20581100E+05, 0.98153200E+04, 0.45618400E+04, 0.50062800E+04, -.44584900E+04, -.82150600E+04, 0.75037800E+01, 0.38712800E+04, -.57928000E+04, 0.22128400E+04, 0.17592000E+04, 0.22154700E+04, 0.32732800E+04, 0.13143500E+04, 0.83636400E+03, 0.31892200E+04, 0.18301800E+04, -.10109700E+04, -.58196600E+03, -.51528500E+03, 0.17945200E+04, 0.16181400E+04, 0.17244900E+03, -.15685900E+03, -.43876700E+04, 0.17499000E+04, 0.10518600E+04, 0.12137400E+04, 0.31020300E+04, 0.13154800E+04, 0.98864900E+03, 0.20467700E+04, -.74230100E+04, 0.45500700E+04, 0.80470500E+03, 0.45615300E+03, -.42914700E+04, -.49516300E+04, -.59600900E+03, -.87815600E+03, 0.23916900E+04, 0.11210300E+04, -.12590900E+03, -.42781300E+04, 0.18306700E+04, -.20601100E+04, -.10772600E+04, 0.26897100E+04, -.21778900E+03, 0.35319000E+03, 0.65707300E+03, 0.45161000E+02, -.21349400E+03, 0.15615900E+04, 0.63531800E+02, -.13219500E+04, -.21247200E+04, 0.47203500E+04, -.13220800E+04, -.26410700E+04, 0.69441700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.55777300E+00, -.33207600E+00, 0.15222600E+00, 0.14869700E+01, 0.10597600E+00, -.13891100E+05, -.30968300E+05, -.15942600E+04, 0.18314600E+04, 0.29302200E+03, -.73114400E+03, -.90932900E+03, 0.41984700E+03, -.11882100E+03, -.21203900E+04, -.10273000E+04, 0.11416300E+05, -.16811000E+05, -.43710600E+02, -.50672600E+03, -.29548900E+04, 0.96357900E+04, 0.15021000E+05, 0.11193700E+04, -.25240100E+05, 0.16553000E+05, 0.42234200E+04, 0.68168500E+04, 0.25968300E+04, -.23523500E+04, 0.14652600E+05, 0.71446000E+04, -.18231400E+05, 0.98975200E+04, 0.27821800E+04, 0.28915500E+04, 0.11921600E+04, -.15883100E+05, -.19751200E+05, 0.13802100E+04, -.10989700E+05, 0.19521000E+05, -.18056000E+04, -.14143600E+04, 0.60852000E+04, -.94616400E+04, -.18272700E+05, -.30707600E+04, 0.30154700E+05, -.16739200E+05, -.48127800E+04, -.75520500E+04, -.31192700E+04, 0.41659800E+04, -.10788100E+05, -.78567200E+04, 0.39930100E+04, 0.65844000E+03, -.16147600E+04, -.20093900E+04, 0.94439200E+03, -.28243300E+03, -.47082600E+04, -.22714000E+04, 0.19591700E+05, 0.13989400E+04, -.42555100E+04, -.51120200E+04, -.86451000E+03, -.35687500E+03, -.18216700E+05, -.62436500E+04, -.57140000E+04, -.79832300E+03, 0.22421000E+04, 0.27937100E+04, -.12553500E+04, 0.28815800E+03, 0.64199800E+04, 0.31479200E+04, 0.45060600E+03, 0.67653100E+02, -.17731600E+03, -.22080100E+03, 0.99526600E+02, -.26034200E+02, -.51088100E+03, -.24915900E+03, 0.16418400E+04, 0.25264100E+03, -.65106600E+03, -.80964700E+03, 0.37029100E+03, -.99923800E+02, -.18813500E+04, -.91398400E+03, -.83559200E+04, 0.94232300E+04, -.91833200E+02, -.91417200E+03, 0.17165600E+04, -.12341800E+05, -.20790800E+05, -.25238100E+04, -.24466700E+05, 0.39352700E+03, 0.54524600E+04, 0.67849100E+04, -.26938000E+03, 0.38813000E+04, 0.28275100E+05, 0.83691200E+04, 0.23709600E+04, 0.48845700E+04, -.38368500E+04, -.43958100E+04, 0.51466500E+04, -.56362400E+04, -.16093500E+05, -.53749200E+04, -.46188200E+04, -.70636500E+03, 0.58680700E+04, 0.71297600E+04, -.70659100E+04, 0.22207400E+04, 0.13017900E+05, 0.76246800E+04, 0.13392100E+05, 0.54020600E+04, -.24012000E+04, -.32111100E+04, -.18554200E+04, -.36759200E+04, -.21288100E+05, -.46136600E+04, 0.60853100E+04, 0.76939600E+03, -.22351400E+04, -.28231500E+04, 0.10860400E+04, -.14629900E+03, -.63156800E+04, -.31789100E+04, 0.11516100E+05, 0.59194400E+04, -.20726100E+04, -.24412000E+04, -.15326400E+04, -.28087400E+04, -.17962400E+05, -.37058900E+04, -.11711600E+05, -.96280700E+04, 0.57597200E+04, 0.75333900E+04, -.31324300E+04, 0.31167300E+04, 0.24907600E+05, 0.90962300E+04, 0.62142100E+04, 0.15182700E+05, 0.12263900E+04, -.14465300E+05, 0.25746000E+05, -.11363300E+05, -.11123200E+05, 0.27083800E+05, 0.23383100E+04, -.22864600E+04, -.16614400E+04, 0.81684000E+03, 0.60489600E+03, 0.96642500E+04, 0.16819300E+05, 0.96063000E+04, 0.53426400E+04, 0.37518200E+04, 0.40442800E+03, -.96045000E+03, -.35891800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43627700E+00, -.27237300E+00, 0.34378400E+00, 0.10509200E+01, -.25787600E+00, -.17449300E+00, -.77452100E+04, 0.70378200E+03, -.30005400E+02, 0.27774800E+03, -.29734500E+03, -.41880500E+03, 0.28976200E+03, 0.20292800E+03, -.38174800E+03, -.38018300E+03, 0.30025300E+04, -.42862000E+04, -.81131000E+03, -.13185700E+04, 0.26958900E+03, 0.17936500E+04, 0.52423300E+04, -.14055900E+04, 0.76283000E+03, -.92460200E+03, 0.44554800E+04, 0.69011300E+04, -.54178200E+04, -.53005100E+04, -.49538900E+04, 0.61314300E+04, -.54770600E+04, 0.26721500E+04, -.30213900E+03, -.12415100E+04, 0.15749600E+04, -.70628700E+03, -.31416700E+04, -.70354100E+03, -.31714000E+04, 0.49094800E+04, 0.72687000E+03, 0.13709500E+04, -.11663000E+03, -.24304400E+04, -.70393800E+04, 0.14841700E+04, 0.79933000E+03, -.44213800E+03, -.38134900E+04, -.59638300E+04, 0.42769500E+04, 0.49030900E+04, 0.50645000E+04, -.52244100E+04, -.86425400E+02, 0.61888100E+03, -.66002100E+03, -.93223500E+03, 0.64946200E+03, 0.44790500E+03, -.84018700E+03, -.84534100E+03, 0.11759600E+05, -.25088000E+04, -.97004500E+03, -.12128600E+04, -.24378100E+04, 0.36485800E+04, -.64598100E+04, -.74992700E+03, 0.40925200E+02, -.81674700E+03, 0.91929500E+03, 0.12972600E+04, -.88460000E+03, -.65009200E+03, 0.11349600E+04, 0.11779600E+04, -.61781100E+01, 0.66701700E+02, -.72624000E+02, -.10225700E+03, 0.70478200E+02, 0.50182000E+02, -.90826200E+02, -.92959700E+02, -.22170900E+02, 0.24459800E+03, -.26466800E+03, -.37251700E+03, 0.25669100E+03, 0.18167600E+03, -.33916000E+03, -.33829800E+03, -.86317100E+04, 0.49441100E+04, -.17372600E+04, -.32044700E+04, 0.37024600E+04, -.12707400E+03, -.20117500E+04, -.27170600E+04, -.35693300E+04, 0.18469200E+03, 0.18645000E+04, 0.23046500E+04, -.11030100E+04, -.30000000E+04, 0.49663800E+04, 0.16086800E+04, -.92627100E+03, 0.17586300E+04, -.80292700E+03, -.11673700E+04, 0.11726600E+04, 0.18712600E+03, -.39101800E+04, -.81531500E+03, 0.31881600E+04, -.20453800E+04, 0.26907900E+04, 0.40973800E+04, -.36049300E+04, -.90162700E+03, 0.12927400E+04, 0.37330400E+04, 0.75144200E+04, 0.24764000E+03, -.11631200E+04, -.15729500E+04, -.11933500E+04, 0.29770700E+04, -.63137600E+04, -.11189900E+04, 0.54138800E+02, 0.81731200E+03, -.96822700E+03, -.13774300E+04, 0.90074100E+03, 0.74682600E+03, -.10206400E+04, -.12566600E+04, 0.82726100E+04, -.57054400E+03, 0.93309100E+02, 0.21747700E+03, -.26090100E+04, 0.18777200E+04, -.72365800E+04, 0.55507000E+03, 0.46691700E+02, -.36063400E+04, 0.32111800E+04, 0.46976200E+04, -.27944600E+04, -.21213100E+04, 0.49939700E+04, 0.42039900E+04, -.93793400E+02, 0.54889600E+04, 0.12452600E+03, -.34598300E+04, 0.53181200E+04, -.48397100E+04, -.18942900E+04, 0.55593600E+04, 0.42317700E+03, -.48563300E+03, -.27205300E+03, 0.19180500E+03, -.36284900E+02, 0.32025200E+04, 0.57647500E+04, 0.16937300E+04, 0.67735800E+03, 0.16798000E+04, -.12108700E+03, -.65656000E+02, 0.56731700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.63183000E+00, -.90128100E+00, -.61002700E-01, -.87028100E+00, -.18166100E+00, -.40979700E+00, -.90232700E+00, 0.10555200E+04, -.47598800E+03, 0.22688700E+03, -.17763400E+03, -.29368200E+03, 0.25624800E+03, -.22950400E+02, 0.23748100E+03, -.22763100E+03, -.11311200E+04, 0.13701300E+03, -.73295400E+03, -.10449600E+04, 0.12670400E+04, 0.10789300E+04, 0.14066000E+04, -.15743600E+04, 0.82055100E+04, -.60675800E+04, 0.37446900E+04, 0.59753700E+04, -.65586300E+04, -.15377500E+04, -.91434300E+04, 0.51375300E+04, -.58170400E+03, 0.39080400E+02, -.16160100E+04, -.29293800E+04, 0.18023700E+04, 0.13390400E+04, 0.25224600E+04, -.20661100E+04, -.31024400E+03, 0.44209600E+03, 0.11506500E+04, 0.16708200E+04, -.14806100E+04, -.11904700E+04, -.21637200E+04, 0.22481700E+04, -.67987500E+04, 0.43390500E+04, -.31085400E+04, -.49664200E+04, 0.54226300E+04, 0.14663800E+04, 0.79541700E+04, -.42435500E+04, -.10699500E+04, 0.51060100E+03, -.39655800E+03, -.65723500E+03, 0.57542000E+03, -.46424700E+02, 0.53761000E+03, -.50915000E+03, 0.92693200E+04, -.34846200E+04, -.22788000E+03, -.34547600E+03, -.25259800E+04, 0.20698100E+04, -.17306300E+04, 0.37194200E+03, 0.14436600E+04, -.69150500E+03, 0.55148100E+03, 0.91092100E+03, -.79149200E+03, 0.52173300E+02, -.74523100E+03, 0.70945300E+03, -.11548600E+03, 0.54787200E+02, -.43616100E+02, -.71894100E+02, 0.62768300E+02, -.54386700E+01, 0.58373900E+02, -.56041500E+02, -.42177800E+03, 0.20099900E+03, -.15775800E+03, -.26062400E+03, 0.22731100E+03, -.20361400E+02, 0.21004400E+03, -.20218600E+03, -.58400600E+04, 0.24515500E+04, -.25236600E+04, -.43609400E+04, 0.38708200E+04, -.15621900E+03, 0.42133700E+04, -.35099100E+04, 0.69568100E+03, 0.55419000E+03, 0.87525000E+03, 0.11385900E+04, -.92271400E+03, 0.12393100E+03, -.21059800E+04, 0.11268900E+03, -.34090200E+03, 0.35396100E+03, -.27501600E+03, -.71143200E+03, 0.77750400E+02, -.32588000E+03, 0.38945900E+03, -.99368000E+02, 0.60083400E+04, -.28061600E+04, 0.18326000E+04, 0.32830300E+04, -.30500200E+04, -.51107600E+03, -.29937700E+04, 0.27693500E+04, 0.60939300E+04, -.15665200E+04, -.88069000E+03, -.12372000E+04, -.94657700E+03, 0.14741800E+04, -.58340500E+03, -.45332200E+03, -.13940300E+04, 0.67673200E+03, -.61586200E+03, -.10067000E+04, 0.84629600E+03, -.71273300E+01, 0.84362600E+03, -.80560800E+03, 0.80592900E+04, -.27823100E+04, 0.42015500E+03, 0.59137600E+03, -.27535500E+04, 0.91130800E+03, -.26216100E+04, 0.12482500E+04, 0.53742700E+04, -.27324200E+04, 0.21905600E+04, 0.36155800E+04, -.31648600E+04, -.69871600E+03, -.26691100E+04, 0.27344200E+04, -.16005700E+04, 0.13076400E+04, -.14651300E+03, 0.49709000E+03, -.56997100E+03, -.12884500E+04, 0.94047300E+03, -.99914500E+03, -.52067300E+02, 0.98829800E+03, -.31074000E+02, -.17745900E+02, -.15649300E+03, 0.91587000E+03, 0.18412800E+04, -.12378400E+04, -.27960700E+03, 0.12583200E+04, -.42829500E+02, -.80865800E+02, 0.24663800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.28396400E+00, 0.11047100E+00, -.30140000E+00, -.12050100E+01, 0.21309400E+00, -.21810600E+00, 0.44677900E+00, -.36024900E+00, 0.10214600E+04, -.43164400E+03, -.14122100E+02, 0.67463300E+02, -.10736500E+03, 0.16616100E+03, -.20055400E+03, 0.71579500E+02, -.56950600E+04, 0.13323000E+04, 0.13248300E+04, 0.18452700E+04, 0.10507200E+03, -.18299900E+04, -.93386000E+03, 0.18095400E+04, -.12789900E+05, 0.41516600E+04, -.17862100E+04, -.32340400E+04, 0.48451800E+04, -.15178300E+04, 0.34399000E+04, -.31294000E+04, 0.27390000E+04, -.13102300E+04, 0.13834800E+04, 0.24502000E+04, -.21428000E+04, -.97070700E+02, -.15285700E+04, 0.23362100E+04, 0.64525200E+04, -.15558700E+04, -.19113800E+04, -.24672900E+04, 0.64935200E+03, 0.17868800E+04, 0.62004700E+02, -.23910500E+04, 0.11016000E+05, -.25732100E+04, 0.10227900E+04, 0.20909500E+04, -.32934800E+04, 0.25998000E+04, -.21638300E+04, 0.18957800E+04, 0.23018900E+04, -.96777100E+03, -.29990400E+02, 0.15388200E+03, -.24926900E+03, 0.37251200E+03, -.45534300E+03, 0.16264500E+03, 0.20284700E+04, 0.11699000E+04, -.13632900E+04, -.18042800E+04, 0.17703400E+04, 0.16867100E+04, 0.30484500E+04, -.18697200E+04, -.31489000E+04, 0.13266500E+04, 0.45113100E+02, -.20365000E+03, 0.33059700E+03, -.51834600E+03, 0.59760200E+03, -.21447100E+03, 0.24533800E+03, -.10467200E+03, -.28781700E+01, 0.16929400E+02, -.26010500E+02, 0.39890500E+02, -.47884900E+02, 0.17891400E+02, 0.90271900E+03, -.38219000E+03, -.12448500E+02, 0.59909700E+02, -.94195900E+02, 0.14690500E+03, -.17712200E+03, 0.63584900E+02, 0.84769200E+04, -.33569000E+04, 0.20740700E+04, 0.36878600E+04, -.40411100E+04, 0.25853700E+03, -.32654800E+04, 0.36593000E+04, -.72647500E+04, 0.15469400E+04, 0.14525500E+04, 0.20222800E+04, -.60939100E+03, -.23530200E+04, -.11636600E+04, 0.20935900E+04, 0.95246200E+04, -.26481000E+04, -.13466800E+04, -.11853600E+04, -.20692100E+03, 0.22848000E+04, -.13705700E+04, -.10893100E+04, -.11168600E+05, 0.49776900E+04, -.50725300E+03, -.20163400E+04, 0.21511000E+04, -.90582200E+03, 0.50938400E+04, -.21052000E+04, 0.30434200E+04, -.96745400E+03, -.21446200E+03, -.37459100E+03, -.42875600E+01, 0.12256800E+04, 0.25808300E+04, -.44483600E+03, 0.31445000E+04, -.13404300E+04, 0.33317400E+01, 0.26164400E+03, -.37464100E+03, 0.52547900E+03, -.53063200E+03, 0.26608100E+03, 0.25710400E+04, 0.84535100E+03, -.12820400E+04, -.18233500E+04, 0.97829700E+03, 0.17698300E+04, 0.33154700E+04, -.18309600E+04, -.10488500E+05, 0.48089900E+04, -.10040200E+04, -.22182300E+04, 0.26598500E+04, -.99592600E+03, 0.24837700E+04, -.21211100E+04, 0.33933200E+04, -.87206600E+03, 0.23290000E+03, -.19458500E+04, -.34723500E+03, 0.73368700E+03, -.22094800E+04, -.80937100E+03, 0.17280900E+03, 0.22369900E+03, 0.10090200E+03, 0.16022500E+02, 0.20848200E+03, 0.26564300E+03, -.11552100E+04, 0.13756700E+04, 0.94913000E+03, 0.15807500E+03, -.45158500E+03, -.42419100E+03, 0.87326200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49953800E+00, -.53103000E+00, 0.42791000E+00, 0.18880000E+01, -.30728500E-01, -.47185200E-01, -.68023000E+00, -.58187800E+00, -.12110300E+00, 0.44741600E+03, -.11868400E+03, -.19323500E+03, -.88383700E+02, 0.10594700E+03, -.18576500E+03, -.20735700E+03, 0.23428500E+04, -.63572500E+04, -.11596100E+04, -.18607700E+04, 0.11351600E+04, 0.22084700E+04, 0.30703300E+04, -.16727000E+04, 0.82951000E+04, -.62249900E+04, 0.24166700E+04, 0.41514600E+04, -.58192600E+04, -.17128800E+04, -.90015600E+04, 0.34664500E+04, 0.36003900E+03, -.23784000E+03, -.12018500E+04, -.19943600E+04, 0.99721200E+03, 0.47793800E+03, 0.23503600E+03, -.17580700E+04, -.26892700E+04, 0.73045700E+04, 0.14249200E+04, 0.22150700E+04, -.21420000E+04, -.13655900E+04, -.28485300E+04, 0.17779700E+04, -.84670900E+04, 0.45324900E+04, -.83440200E+03, -.20936700E+04, 0.36723600E+04, -.43546900E+03, 0.65557500E+04, -.13077600E+04, -.44715400E+02, 0.99909100E+03, -.25629900E+03, -.42228700E+03, -.18971700E+03, 0.23124700E+03, -.39793400E+03, -.45166900E+03, 0.11852000E+05, 0.46032800E+03, 0.88575300E+03, 0.12961500E+04, -.57686200E+04, 0.11463400E+04, -.88084300E+04, 0.16066400E+04, 0.11455800E+02, -.13607900E+04, 0.35747600E+03, 0.58716900E+03, 0.26933200E+03, -.32769700E+03, 0.57652000E+03, 0.62420000E+03, 0.17539600E+01, 0.10769000E+03, -.29811100E+02, -.48145500E+02, -.20643400E+02, 0.26082400E+02, -.44884400E+02, -.51552500E+02, 0.49853900E+01, 0.39532200E+03, -.10624000E+03, -.17255500E+03, -.79082800E+02, 0.95082800E+02, -.16692900E+03, -.18517000E+03, -.19648400E+04, 0.19130600E+04, -.24819700E+04, -.37721900E+04, 0.24581800E+04, 0.51427100E+03, 0.11852800E+04, -.36444300E+04, 0.15797300E+04, -.26097300E+04, -.43361200E+03, -.45426600E+03, 0.13525300E+04, 0.73361900E+03, 0.78152000E+03, -.60183700E+03, -.33536400E+04, 0.33585900E+04, 0.15151800E+04, 0.15868100E+04, -.20927900E+04, -.15656900E+04, -.12378300E+04, 0.15087200E+04, 0.64006400E+04, -.34209700E+04, -.17415300E+02, 0.78432300E+03, 0.24554200E+03, -.34130400E+03, -.15046000E+04, 0.94338700E+03, 0.12639900E+05, 0.24120900E+04, -.10080600E+04, -.12074600E+04, -.32330400E+04, 0.24847400E+04, -.73844600E+04, -.87825300E+03, 0.20858100E+03, 0.13573800E+04, -.43980100E+03, -.69532500E+03, -.23634600E+03, 0.38525800E+03, -.61970500E+03, -.71916900E+03, 0.82143700E+04, 0.27620200E+04, 0.12763600E+04, 0.18521300E+04, -.45106000E+04, -.39300600E+03, -.90766100E+04, 0.20391900E+04, -.45272800E+04, -.44928900E+04, 0.30384300E+04, 0.40982600E+04, -.39801300E+03, -.39812100E+04, 0.23244300E+04, 0.40364600E+04, 0.27230400E+02, 0.24683000E+04, 0.15270900E+03, -.19112200E+03, 0.70693400E+03, -.24894600E+04, -.37581700E+02, 0.30826000E+03, 0.33720200E+03, -.27667900E+04, -.37899100E+03, 0.38201300E+02, 0.11579700E+03, 0.18715900E+04, 0.25353700E+04, 0.13984400E+04, 0.16739400E+04, -.71777800E+03, 0.29507200E+03, 0.33976200E+04, -.13176200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14687100E+01, -.33356500E+00, -.47200400E+00, 0.13441800E+01, 0.10046300E+00, 0.54249900E+00, 0.11817500E+01, -.17618400E+01, 0.10057300E+01, 0.46377400E+00, -.41590600E+03, -.56000400E+03, 0.53786600E+03, 0.17406100E+03, 0.14357400E+03, -.54301000E+03, 0.17897900E+04, 0.64923300E+03, -.53972600E+03, -.82236600E+03, 0.57794800E+02, 0.28399500E+03, 0.41323400E+03, -.90139300E+03, 0.28753700E+05, -.99176800E+04, -.25140200E+04, -.16213900E+04, -.37631200E+04, 0.84409400E+04, -.12502500E+04, -.12925900E+04, -.28880700E+03, 0.19576500E+03, -.15021000E+04, -.27652100E+04, 0.92728000E+03, 0.15558500E+04, 0.27158300E+04, -.27450800E+04, 0.30047300E+04, -.28426300E+04, -.14303400E+04, -.13603800E+04, 0.18978800E+04, 0.13626900E+04, -.12919500E+03, -.11860100E+04, -.25227100E+05, 0.82011900E+04, 0.23726300E+04, 0.17553300E+04, 0.30328600E+04, -.81998400E+04, 0.58053700E+03, 0.14725600E+04, -.33777000E+02, 0.67927300E+01, -.92524900E+03, -.12483700E+04, 0.12047200E+04, 0.38063300E+03, 0.32940600E+03, -.12106600E+04, -.46207800E+02, -.27276800E+04, -.51695100E+03, -.29278000E+03, 0.19005400E+03, -.10019700E+03, -.15701200E+04, -.36792300E+03, 0.65955200E+02, -.21477400E+02, 0.12565900E+04, 0.16947200E+04, -.16346500E+04, -.50744400E+03, -.42705300E+03, 0.16438100E+04, -.25512000E+00, 0.15740500E+01, -.10011600E+03, -.13491200E+03, 0.12917900E+03, 0.41795600E+02, 0.34076000E+02, -.13081100E+03, 0.27225800E+01, -.82658300E-01, -.36915000E+03, -.49690500E+03, 0.47669400E+03, 0.15484600E+03, 0.12649800E+03, -.48184600E+03, -.53401500E+04, 0.22814900E+04, -.24165900E+04, -.42857800E+04, 0.34179700E+04, 0.10844500E+04, 0.38950900E+04, -.42827400E+04, 0.39897700E+04, -.10190100E+04, 0.20999600E+03, -.23089900E+03, -.15593000E+04, 0.15716800E+04, 0.19967200E+04, -.29247800E+03, -.63121800E+03, -.17222600E+04, -.28201700E+04, -.35078200E+04, 0.44041500E+04, 0.83604500E+03, 0.11315600E+04, -.34129500E+04, 0.15246300E+03, 0.57834400E+02, 0.59171100E+04, 0.81546200E+04, -.81755100E+04, -.24202400E+04, -.42128900E+04, 0.79866900E+04, -.30213700E+04, 0.47934900E+03, 0.22305200E+03, 0.35317700E+03, -.45560100E+03, -.55734500E+03, -.11124300E+04, 0.29022500E+03, -.32748000E+03, 0.16720900E+03, -.11842800E+04, -.16199000E+04, 0.15518400E+04, 0.42337900E+03, 0.38851000E+03, -.15745200E+04, -.16925300E+04, -.18455300E+04, 0.52931500E+03, 0.99282700E+03, -.78959000E+03, -.53041800E+03, -.13555400E+04, 0.85848500E+03, 0.71197100E+04, -.39424700E+04, 0.24478300E+04, 0.40182000E+04, -.41405800E+04, 0.13208100E+03, -.23416000E+04, 0.39495200E+04, 0.10899200E+01, 0.31125700E+04, -.85933500E+02, -.26311700E+03, 0.30573600E+04, -.31411200E+04, 0.24308900E+03, 0.40462400E+04, 0.65514200E+02, 0.29268700E+04, 0.12471300E+03, 0.49210100E+02, -.18067700E+03, 0.21934900E+04, 0.32511600E+04, -.10949200E+04, -.11415800E+03, 0.22500800E+04, -.64063600E+03, -.27070600E+04, 0.12270400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.54557600E+00, 0.25585300E+00, -.12599300E+00, -.10853700E+01, 0.21097600E-01, -.20116900E+00, 0.41988000E+00, 0.28498900E+00, 0.27199700E+00, 0.51458300E-01, -.31705700E-01, 0.23384300E+02, 0.80961500E+02, -.69731900E+01, 0.72349600E+02, 0.23969800E+02, -.20130300E+04, 0.20086500E+04, 0.35792400E+03, 0.53947800E+03, 0.19782700E+03, -.11436500E+04, 0.40636100E+03, 0.51402900E+03, 0.25414300E+04, 0.21687800E+04, -.13004000E+04, -.21430300E+04, 0.15782300E+04, 0.22729600E+04, 0.38254500E+04, -.17875300E+04, 0.45888700E+03, -.10123100E+03, 0.33917700E+02, 0.18229400E+03, -.10796100E+03, 0.38456700E+03, 0.19397800E+03, 0.64037500E+02, 0.30346500E+04, -.23614400E+04, -.64139700E+03, -.88105200E+03, 0.31665800E+03, 0.91638600E+03, -.55871800E+03, -.72271700E+03, -.50815900E+03, -.22096700E+04, 0.36020900E+03, 0.95735500E+03, -.91263400E+03, -.10286500E+04, -.29053200E+04, 0.57986500E+03, 0.75695400E+01, -.73386900E+01, -.23238300E+01, 0.49558300E+02, 0.17945800E+03, -.16754900E+02, 0.15676200E+03, 0.50222600E+02, -.42788400E+04, 0.96257900E+02, -.50845200E+03, -.68308500E+03, 0.23055100E+04, -.18035100E+03, 0.32733400E+04, -.86875000E+03, 0.15157400E+02, -.83581500E+00, 0.78040200E+00, -.71982400E+02, -.24982400E+03, 0.28550000E+02, -.22941400E+03, -.71232900E+02, -.32357200E+00, 0.91501500E+00, 0.35193800E+00, 0.61351300E+01, 0.19211200E+02, -.16790800E+01, 0.17504800E+02, 0.62692300E+01, -.18333500E+01, 0.14182500E+01, 0.35387000E+00, 0.21152800E+02, 0.72155000E+02, -.65944100E+01, 0.65603100E+02, 0.21706900E+02, -.92953100E+02, 0.12814200E+03, 0.55176000E+03, 0.88675900E+03, -.31493500E+03, 0.33303600E+03, 0.33384000E+02, 0.77460200E+03, -.26904800E+03, -.25637800E+03, 0.22135800E+03, 0.87856300E+02, -.44598200E+03, -.34349600E+03, 0.82977400E+03, 0.17762900E+03, 0.65935100E+03, -.12970000E+04, -.71820200E+03, -.75942800E+03, 0.11847300E+04, 0.62450900E+03, 0.17146700E+03, -.74213300E+03, -.19145200E+04, 0.87334300E+03, 0.54654600E+03, 0.44191500E+03, -.10827200E+04, -.21461000E+02, -.32261700E+03, 0.33827900E+03, -.49743200E+04, 0.64446700E+03, 0.17587000E+03, 0.27316100E+03, 0.13170500E+04, -.68731600E+03, 0.25866700E+04, 0.32262800E+02, -.10284500E+03, 0.39995400E+02, 0.25279300E+02, 0.11059300E+03, 0.23121100E+03, -.42300700E+02, 0.23142400E+03, 0.10202900E+03, -.26873700E+04, -.82616500E+03, -.60982600E+03, -.84860100E+03, 0.17016200E+04, 0.55673400E+03, 0.32931200E+04, -.10045000E+04, 0.18337000E+04, -.89711600E+03, -.82251800E+03, -.11643000E+04, -.75245000E+02, 0.13791500E+04, -.77799000E+03, -.10836500E+04, -.81680000E+01, -.28260500E+03, -.52976000E+02, -.32879600E+03, 0.47556900E+03, 0.21157200E+03, -.21339400E+03, 0.96241600E+03, -.84652200E+02, 0.11372800E+04, 0.84425900E+02, -.16287000E+02, -.45375700E+02, -.27233600E+03, -.32856000E+03, -.41958800E+03, -.59753700E+03, 0.40641400E+03, -.71286900E+02, -.14492500E+04, 0.70918600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10154000E+00, -.43145600E+00, 0.26936700E+00, 0.16581300E+01, -.29853700E+00, 0.10204800E+00, 0.19032600E+00, 0.79446700E-01, 0.24900300E+00, 0.51060700E+00, 0.11461500E+00, -.51058100E+00, 0.61203700E+02, 0.43740200E+02, 0.47982900E+02, -.12328200E+00, 0.57173800E+03, 0.16390900E+03, -.28119000E+03, -.19103500E+03, -.49459800E+01, -.10098400E+04, -.47165600E+03, -.32821800E+03, 0.97044200E+04, -.19355700E+04, -.29570800E+04, -.40882100E+04, 0.18908300E+04, 0.58981300E+04, 0.70555800E+04, -.36806400E+04, 0.87174200E+03, -.71825500E+03, -.11505000E+04, -.15032300E+04, 0.15038400E+04, 0.16258800E+04, 0.29592500E+04, -.16755900E+04, 0.16337300E+04, -.10877800E+04, -.51967400E+02, -.33778800E+03, 0.24101000E+03, 0.13507800E+04, 0.12085100E+04, -.20081100E+02, -.49932300E+04, 0.56641400E+03, 0.13548400E+04, 0.21651300E+04, -.12500800E+04, -.39203600E+04, -.54372900E+04, 0.16952700E+04, -.60706900E+01, 0.15513000E+01, -.28692700E+00, -.52123200E+00, 0.13737900E+03, 0.91480500E+02, 0.10396500E+03, -.14270600E+01, -.19261600E+04, -.59383900E+03, -.11343600E+04, -.13158700E+04, 0.20975000E+04, 0.83201800E+03, 0.22000000E+04, -.14923900E+04, 0.17123800E+02, -.56437500E+01, 0.25520100E+01, -.84311300E+00, -.18851400E+03, -.11954300E+03, -.13304600E+03, 0.26970700E+01, -.21268100E+00, 0.64073400E+00, 0.24068600E+00, 0.44509800E+00, 0.14414000E+02, 0.10379900E+02, 0.10871900E+02, 0.36763200E+00, 0.67373800E+00, 0.15929900E-01, 0.84305300E-01, 0.10988100E+00, 0.54029300E+02, 0.38787200E+02, 0.42651600E+02, 0.25708900E-01, -.58668900E+03, -.17801400E+03, -.19418500E+03, -.36342200E+03, 0.98266000E+03, 0.13987100E+04, 0.18532300E+04, -.55047900E+03, 0.43072100E+04, -.25184300E+04, -.84733200E+03, -.14349800E+04, -.13234800E+03, 0.13923400E+04, 0.23729100E+04, -.12948700E+04, -.15058400E+04, 0.30746900E+02, -.18201100E+03, -.29376000E+03, 0.11519400E+04, 0.43310200E+03, 0.71027200E+03, -.25465500E+03, -.13692200E+04, 0.57961600E+03, 0.33908700E+03, 0.70446100E+03, -.97193200E+03, -.28677500E+03, -.12097900E+04, 0.59569900E+03, -.32812300E+04, -.13526300E+03, -.43247300E+03, -.27806000E+03, 0.13230000E+04, 0.26589300E+03, 0.14995500E+04, -.53428400E+03, -.86868800E+02, 0.35688600E+02, -.31503400E+01, 0.16425200E+02, 0.19002900E+03, 0.11055700E+03, 0.10000300E+03, 0.24019000E+01, 0.13153800E+03, -.19814300E+04, -.12767000E+04, -.15436300E+04, 0.15520100E+04, 0.20044400E+04, 0.24331700E+04, -.16623400E+04, 0.15265800E+04, -.71896000E+03, -.47653300E+03, -.47406800E+03, -.29820100E+03, 0.69809500E+03, -.86556000E+03, -.44424000E+03, 0.93756500E+00, -.32832600E+02, -.41793800E+02, 0.13246000E+03, 0.18297200E+04, -.24993400E+03, 0.39430600E+03, 0.29711000E+04, -.65854200E+02, 0.11391200E+04, 0.78528400E+02, -.10449800E+02, -.37744800E+02, -.19093600E+03, 0.29904900E+02, -.41015200E+03, -.41341500E+03, 0.49777900E+03, -.95445700E+02, -.15938800E+04, 0.53280800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.61363900E+01, -.24948600E+01, -.22632500E+01, -.42948300E+01, -.13515400E+00, -.67942100E+00, -.33110300E+00, -.63119900E+00, -.12348000E+01, 0.20569600E+01, -.22838400E+01, -.10152600E+01, 0.98187400E+01, -.64172600E+03, 0.45182900E+03, 0.21155800E+02, -.29770600E+05, 0.15501600E+05, 0.94183600E+04, 0.11064200E+05, -.15134100E+04, -.35401000E+03, -.43422200E+03, 0.12167300E+05, -.10587600E+06, 0.40472300E+05, 0.25059000E+05, 0.34475700E+05, -.87628700E+04, -.51851600E+05, -.51712800E+05, 0.32700400E+05, -.11967200E+05, 0.93675100E+04, 0.12484000E+05, 0.16470100E+05, -.15037100E+05, -.16790300E+05, -.29204400E+05, 0.17510800E+05, 0.83870400E+04, -.55899000E+04, -.67659700E+04, -.64601200E+04, 0.22919200E+04, -.58471500E+04, -.94105300E+04, -.87394300E+04, 0.59667100E+05, -.19293000E+05, -.13198700E+05, -.20216600E+05, 0.80516600E+04, 0.39325600E+05, 0.40961400E+05, -.18151300E+05, 0.15132500E+03, -.55080800E+02, -.21522500E+02, -.22760600E+02, -.19221800E+02, -.13659000E+04, 0.99970800E+03, 0.24863700E+02, -.61610900E+04, 0.89598900E+04, 0.66085100E+04, 0.68484900E+04, -.43825200E+04, -.84871500E+04, 0.53996500E+04, 0.74511200E+04, -.12642600E+03, 0.54198200E+02, -.15962200E+02, 0.14247900E+02, 0.20757000E+01, 0.18473300E+04, -.15826500E+04, -.63696500E+02, -.19439700E+01, -.30407500E+01, 0.56439700E+00, -.75146900E+00, 0.17112800E+01, -.15377800E+03, 0.11723700E+03, 0.48655600E+01, -.23698000E+02, 0.86719200E+01, 0.31326800E+01, 0.37443800E+01, 0.43119000E+01, -.57239000E+03, 0.40863400E+03, 0.22589400E+02, 0.69590300E+04, 0.29855900E+04, 0.53266800E+04, 0.78124600E+04, -.11936000E+05, -.15625800E+05, -.17739400E+05, 0.92231800E+04, -.60345900E+05, 0.27046600E+05, 0.12996600E+05, 0.19651200E+05, -.26799700E+04, -.19590200E+05, -.25419000E+05, 0.18971300E+05, 0.26589300E+05, -.67366400E+04, -.46749700E+04, -.47944700E+04, -.37183400E+04, 0.64415800E+03, -.23875400E+04, -.50723100E+04, 0.37873100E+04, -.32929200E+04, -.61837800E+03, -.40494000E+04, 0.34088400E+04, 0.42741100E+04, 0.10100500E+05, -.35000000E+04, 0.41653800E+04, 0.18760100E+04, 0.49529800E+04, 0.34255200E+04, -.38719500E+04, -.78475700E+04, 0.71919100E+04, 0.47608600E+04, 0.30056400E+03, -.22016700E+03, 0.17894400E+03, 0.24742500E+02, -.76032200E+02, -.18595400E+04, 0.20623300E+04, 0.16327900E+03, -.13126300E+05, 0.15063500E+05, 0.71232200E+04, 0.79992600E+04, -.36667400E+04, -.15803900E+05, 0.25967400E+04, 0.84319500E+04, -.96975500E+03, 0.26828700E+04, -.21872600E+03, -.60374200E+03, 0.24156400E+03, 0.34974900E+04, -.16513300E+04, -.31392800E+03, -.91008500E+02, -.27010400E+04, -.18572700E+02, 0.31050900E+03, -.18118100E+05, 0.57065900E+04, -.28652100E+04, -.28399800E+05, -.19254400E+02, -.13913400E+04, -.22209100E+03, -.14540600E+03, 0.71224800E+02, -.94033500E+03, -.41925000E+04, -.33013800E+03, 0.11026600E+04, -.58894500E+03, 0.44815900E+03, 0.48040400E+04, -.10313600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13722400E-01, -.30318500E+00, 0.19127800E+00, 0.79379600E+00, -.51859500E-01, -.26416100E+00, -.16051600E+00, 0.22176000E+00, 0.59863800E-01, 0.18798800E+00, 0.10343200E+00, 0.61911000E+00, -.61604000E+00, -.50211600E-01, 0.46225000E+02, -.61678000E+00, 0.66660100E+03, -.12356000E+04, 0.47282400E+02, 0.18145000E+03, -.46261000E+03, 0.62708900E+02, -.10037300E+04, 0.18965200E+03, -.40460200E+04, 0.90846500E+02, 0.20475500E+03, 0.20245300E+03, 0.78083400E+03, -.86747600E+03, 0.75428000E+03, 0.10786500E+03, 0.35175400E+03, -.33935300E+03, -.89714200E+02, 0.42603900E+02, -.14575400E+02, 0.36246600E+02, -.15683500E+02, 0.20374900E+02, -.76848000E+03, 0.12560000E+04, -.45912700E+02, -.21349700E+03, 0.35331200E+03, 0.60849200E+02, 0.12446400E+04, -.24720600E+03, 0.38501700E+04, 0.22386800E+03, -.28380300E+03, -.33016400E+03, -.59412600E+03, 0.11399600E+04, -.51920200E+03, -.27856700E+03, 0.59989600E+01, 0.37595800E+01, -.34258600E+00, -.72373100E-01, -.18180500E+01, 0.98502500E+00, 0.10022100E+03, -.15205300E+01, 0.11097800E+04, 0.68902700E+03, -.10261500E+03, -.23045500E+03, 0.70015400E+02, 0.39436800E+03, 0.27188900E+03, -.20965300E+03, -.16203400E+02, 0.66420000E+00, 0.14836200E+01, 0.17190100E+01, 0.12428100E+01, -.36695400E+01, -.13668100E+03, 0.34750200E+01, -.48238100E+00, -.59739400E+00, 0.49076900E-01, 0.81045000E-01, 0.12447800E+00, -.17973100E+00, 0.11198500E+02, -.67416900E-01, -.23279000E+00, -.61621100E+00, 0.15158800E+00, 0.18661500E+00, -.75270600E-01, -.11401100E+00, 0.40727500E+02, -.33984800E+00, 0.80654200E+03, -.33226400E+03, -.13646400E+03, -.30269300E+02, -.11062100E+03, -.18072000E+01, 0.35073000E+02, -.42710000E+02, -.72666000E+03, -.34883800E+03, 0.15569100E+03, 0.29192400E+03, -.10152000E+03, -.27182600E+03, -.61113900E+03, 0.32336700E+03, 0.57879100E+03, 0.89297800E+03, -.64725100E+02, -.12396100E+03, -.13901200E+03, 0.20998800E+03, 0.30865100E+03, -.13011500E+03, 0.16287200E+03, -.32194700E+03, -.19959700E+03, -.35818500E+03, 0.52821700E+03, 0.23028600E+03, 0.41334600E+03, -.32799000E+03, 0.25142100E+03, -.15080900E+03, -.22404900E+03, -.37280300E+03, 0.50014800E+03, 0.23365900E+03, 0.94118500E+03, -.34144700E+03, 0.40549300E+02, -.27415300E+02, -.11872500E+02, -.13995600E+02, 0.13457100E+02, 0.12529900E+02, 0.15216800E+03, -.15071800E+02, 0.81088300E+03, 0.70427000E+03, -.11441600E+03, -.29760300E+03, 0.24081600E+03, 0.32321100E+03, 0.53069500E+03, -.26123600E+03, -.57131200E+03, 0.63328600E+03, 0.33012100E+03, 0.36331300E+03, -.31374800E+03, -.28261100E+03, -.73586800E+03, 0.37257100E+03, -.45055000E+01, -.16415400E+03, -.14871500E+02, 0.59964300E+03, 0.14958800E+02, 0.97353200E+02, 0.53488700E+03, -.54487200E+02, -.29124700E+02, 0.35051700E+02, 0.21990000E+02, -.17706800E+02, -.41684400E+01, -.15432400E+02, -.24851300E+03, -.10391700E+03, 0.12391500E+03, 0.30241000E+03, -.25847200E+02, -.16330300E+03, 0.51499200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.88363100E+00, 0.61841500E-01, 0.32350800E+00, -.23960400E-01, -.19679900E+00, 0.30531600E+00, 0.28385700E+00, 0.59556100E+00, 0.70327400E+00, 0.10519800E+00, -.23320100E-01, 0.47419400E+00, 0.12305700E+00, -.42118900E-01, -.11362000E+00, 0.93203500E+01, 0.15091700E+04, -.27518700E+03, 0.38478600E+03, 0.44784500E+03, -.99393500E+03, -.11225200E+03, -.99230900E+03, 0.45471500E+03, -.67391700E+03, 0.98783000E+03, -.55237100E+03, -.58831500E+03, 0.82530000E+03, 0.13580600E+03, 0.94516600E+03, -.62284500E+03, -.51781800E+02, 0.41097400E+03, 0.65072600E+03, 0.89633500E+03, -.10847400E+04, -.78475100E+03, -.16667000E+04, 0.92819200E+03, -.35379700E+03, -.24854200E+03, -.82896500E+03, -.10118300E+04, 0.12469000E+04, 0.54178200E+03, 0.13613700E+04, -.10228600E+04, -.77831800E+03, -.33430400E+03, 0.99026800E+03, 0.10853700E+04, -.93967100E+03, -.92535300E+03, -.12734600E+04, 0.11740700E+04, -.26229700E+01, -.49191000E+00, -.67377800E+00, -.50834500E+00, 0.92967400E+00, -.14043300E+01, -.30250400E+00, 0.19875500E+02, -.43586600E+04, 0.15911600E+04, 0.67326200E+03, 0.92556800E+03, 0.30883300E+03, -.15476700E+04, -.20505700E+03, 0.93726200E+03, 0.17526100E+02, -.43799000E+01, -.90598200E+01, -.10781500E+02, 0.68967400E+01, 0.11702800E+02, 0.10445400E+02, -.39500100E+02, 0.41651300E+00, 0.20149300E-01, 0.31639500E+00, 0.34458800E+00, -.48464000E+00, -.65641300E-01, -.50674300E+00, 0.26440200E+01, 0.26846500E+00, -.35099600E-01, 0.23260400E+00, 0.27752500E+00, -.30563400E+00, -.99529400E-02, -.57896800E-01, 0.85714700E+01, 0.21415500E+03, 0.20169900E+03, 0.43271400E+03, 0.62408300E+03, -.85325100E+03, -.32932700E+03, -.12644700E+04, 0.67695800E+03, -.98082400E+03, 0.25816500E+03, -.12612800E+03, -.15201600E+03, 0.26235300E+03, -.31948900E+03, 0.36684100E+03, -.26943700E+03, -.69961700E+03, 0.31501000E+03, -.37029400E+03, -.37273700E+03, 0.62930800E+03, 0.97859500E+02, 0.52232200E+03, -.38733100E+03, 0.29928100E+02, -.24835000E+02, 0.45878100E+03, 0.46376200E+03, -.42959700E+03, 0.47077600E+01, -.35005400E+03, 0.48897800E+03, -.35088100E+04, 0.13276700E+04, 0.70083900E+03, 0.85572600E+03, 0.55495900E+02, -.12140800E+04, -.33439700E+03, 0.91677200E+03, -.67851800E+02, 0.27243400E+02, 0.46217600E+02, 0.52418000E+02, -.42020800E+02, -.49136300E+02, -.64437700E+02, 0.84582400E+02, -.50667200E+04, 0.20951400E+04, 0.59339100E+03, 0.83366500E+03, 0.61011700E+03, -.15466400E+04, 0.14515100E+03, 0.82445500E+03, 0.11697000E+04, -.43439200E+03, -.15339900E+03, -.14560900E+03, 0.36688300E+02, 0.44672600E+03, -.15749800E+03, -.22013300E+03, 0.68767200E+01, -.32073300E+02, 0.19440500E+01, 0.31066300E+03, -.63246800E+01, 0.14153600E+03, 0.42038500E+03, 0.23533400E+03, 0.34400300E+01, -.27529700E+03, -.64089500E+01, 0.98339000E+00, 0.17655000E+01, 0.73254400E+01, -.12146300E+02, -.15417500E+03, 0.42693900E+02, -.28581700E+03, 0.24376300E+02, 0.46412900E+02, -.30909600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25226400E+01, -.42199500E+00, -.35365300E+00, -.22731300E+01, 0.11336600E+01, -.12762200E+01, -.33963500E-01, -.10459800E+01, 0.48771200E+00, 0.63364700E+00, 0.44694200E+00, -.15054100E+01, 0.20857600E+01, 0.20245900E+00, 0.42412100E+01, -.40632200E+00, -.90607600E+04, 0.83849000E+04, 0.72640700E+03, 0.55062400E+03, 0.25763100E+04, -.19391100E+04, 0.47036500E+04, 0.57845100E+03, 0.84997700E+04, 0.37523200E+04, 0.26273200E+04, 0.26880200E+04, -.42104500E+04, -.13952200E+03, -.52846800E+04, 0.33239700E+04, -.79198900E+03, 0.12797100E+04, 0.14909500E+04, 0.10890300E+04, -.11971000E+04, -.23572400E+03, -.87454900E+03, 0.13662100E+04, 0.70727700E+04, -.73394400E+04, -.11345900E+03, 0.35763800E+03, -.21637500E+04, 0.46524700E+03, -.63294400E+04, 0.42955900E+03, -.67588800E+04, -.46350300E+04, -.23709500E+04, -.24162200E+04, 0.34360300E+04, -.11174700E+03, 0.43473200E+04, -.28849600E+04, -.51303200E+01, -.22783100E+02, -.28641300E+01, -.42818900E+01, 0.59492600E+01, 0.26821000E+01, 0.74250600E+01, -.38561100E+01, -.39106100E+04, -.33249900E+04, 0.52028600E+03, 0.58332700E+03, 0.12768800E+03, -.93420600E+03, 0.19559400E+04, 0.46118500E+03, 0.62346700E+02, -.90398200E+00, -.46142400E+00, 0.24511800E+00, -.12603600E+02, 0.71488500E+01, -.41998500E+02, 0.16479900E+01, 0.11669400E+01, 0.26862400E+01, -.19789900E+00, -.33554500E+00, -.19957300E+00, 0.66571100E+00, 0.69125800E+00, -.34930500E+00, -.27003200E+01, 0.40286500E+01, -.18136400E+00, -.16560200E+00, 0.95534900E+00, -.45943600E+00, 0.26159900E+01, -.28426700E+00, -.16381300E+04, 0.11959500E+04, 0.10800600E+04, 0.67810600E+03, -.54622700E+03, 0.10234700E+03, -.11486300E+03, 0.90325900E+03, -.30484300E+04, 0.36302700E+04, 0.89257700E+03, 0.90770800E+03, 0.14391200E+03, -.12795900E+04, 0.66820300E+03, 0.90201800E+03, 0.81760800E+03, -.50842200E+04, -.15124900E+03, -.80821000E+02, 0.93551600E+02, 0.65358800E+02, -.96476600E+03, -.28230300E+02, -.72312300E+03, 0.12890400E+04, 0.78079000E+03, 0.12270500E+04, -.18084600E+04, -.10349800E+04, -.23065800E+04, 0.98749000E+03, -.10700400E+04, -.18473900E+03, 0.74788700E+03, 0.93352800E+03, -.13693900E+04, -.65060800E+03, -.81307600E+03, 0.73310900E+03, -.17088300E+03, 0.10150500E+03, 0.37544400E+02, 0.36514900E+02, -.25875500E+02, -.31873700E+02, 0.45132400E+02, 0.30265300E+02, -.24410300E+04, -.35841900E+04, 0.38098000E+03, 0.69319500E+03, -.52229000E+03, -.86093900E+03, 0.39353600E+03, 0.47815400E+03, 0.17493400E+04, -.21990700E+04, -.12466200E+04, -.13480600E+04, 0.12497000E+04, 0.86403800E+03, 0.10723200E+04, -.13355700E+04, -.20778800E+00, 0.14535200E+02, 0.21911000E+00, -.23255800E+04, -.12484900E+04, 0.42819000E+03, -.23611200E+04, -.17658200E+04, -.76385800E+00, 0.63340800E+03, 0.15080500E+00, -.16926100E+01, 0.52142700E+00, -.36483700E+03, 0.14248900E+03, 0.17480500E+02, -.46807200E+03, -.81277400E+03, 0.18567400E+02, 0.12713800E+03, -.20786800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.27203800E+00, 0.49011400E+00, -.30289300E+00, -.17308200E+01, 0.32767400E+00, -.19588600E+00, 0.63387000E+00, -.36499800E+00, 0.90836900E+00, -.23046200E-01, -.15956200E+00, -.40263300E-01, 0.18605100E-01, 0.50819100E-01, -.78341100E+00, -.23294500E+00, -.72025000E-01, 0.12850200E+04, -.87899800E+02, 0.13252300E+02, -.75883200E+02, -.47099200E+03, -.42337500E+03, -.99105100E+02, 0.99425600E+04, -.87333800E+03, -.21057000E+04, -.29632500E+04, 0.63249700E+03, 0.54452800E+04, 0.46021300E+04, -.26041300E+04, 0.54052300E+03, -.11924700E+03, -.57247200E+03, -.72421900E+03, 0.65960300E+03, 0.76923700E+03, 0.15300000E+04, -.79984400E+03, 0.14935100E+04, -.19488700E+04, -.71047300E+02, -.28196100E+03, 0.60816800E+02, 0.81341300E+03, 0.85797100E+03, -.77109300E+02, -.84473300E+04, 0.56603800E+03, 0.14659900E+04, 0.22158800E+04, -.26842000E+03, -.44574100E+04, -.37839100E+04, 0.18342100E+04, -.14415800E+02, -.85358000E+00, -.15473100E+00, -.22400500E+00, 0.37439000E+01, -.69222200E+01, 0.11695800E+01, -.86257100E+00, -.33849300E+04, -.72583700E+03, -.45405400E+03, -.49621600E+03, 0.14159600E+04, -.38390200E+03, 0.10111700E+04, -.65931800E+03, 0.35221500E+02, -.66575700E+01, -.20990000E+01, -.55974900E+01, -.19373100E+01, 0.19228900E+02, 0.14203700E+02, -.32623400E+01, 0.61181900E+00, 0.93490600E+00, 0.17307900E+00, 0.31718100E+00, -.51507600E+00, 0.17204200E-01, -.88453400E+00, 0.31577500E+00, 0.13057800E+01, 0.30174900E+00, -.70076100E-02, 0.49290000E-02, -.38130700E+00, 0.45627800E+00, -.16684300E+00, 0.21413100E-01, 0.99657500E+02, -.23746000E+03, -.24376800E+03, -.38403300E+03, 0.40548600E+03, 0.60252600E+03, 0.10394700E+04, -.46052300E+03, 0.34609300E+04, -.14742000E+04, -.86241400E+03, -.13646100E+04, 0.32258100E+03, 0.17610100E+04, 0.21268800E+04, -.12965000E+04, -.23444600E+04, -.46443300E+03, -.42264100E+02, -.11274400E+03, 0.83422700E+03, -.32940800E+03, 0.88253800E+03, -.12449200E+03, -.98224300E+02, 0.23009700E+03, 0.47528600E+03, 0.78437200E+03, -.81672300E+03, -.19881400E+03, -.16355500E+04, 0.76908200E+03, -.33261900E+04, 0.52377100E+02, -.24351500E+03, -.13149000E+03, 0.87846800E+03, -.61044400E+03, 0.30117800E+03, -.32167700E+03, -.10337200E+03, 0.48557000E+02, 0.10792400E+02, 0.28288300E+02, -.74351700E+01, -.52136900E+02, -.77599100E+02, 0.20545300E+02, -.15004600E+04, -.17267400E+04, -.73465800E+03, -.89186600E+03, 0.12157200E+04, 0.52152600E+03, 0.13193700E+04, -.10060200E+04, 0.10354100E+04, -.72209300E+03, -.15830800E+03, -.14545000E+03, 0.59548200E+02, 0.72091600E+03, -.67037600E+01, -.11755800E+03, 0.11121500E+02, -.16193100E+02, 0.13911600E+01, 0.16956900E+02, 0.12663500E+04, -.12295900E+03, 0.72596700E+02, 0.22072800E+04, 0.15196400E+01, 0.68376000E+03, -.33242600E+01, 0.52983800E+00, 0.14208100E+01, -.22793000E+02, 0.16543600E+03, -.30009400E+03, -.41642100E+02, 0.52355200E+02, 0.16266200E+02, -.10536500E+04, -.91250700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11817800E+01, 0.40693800E+00, -.32852400E+00, 0.68359700E-01, -.48623000E+00, -.12128400E+00, 0.77516900E+00, -.10645500E+01, 0.17540600E+00, 0.11769600E+01, -.76128800E+00, 0.44060800E+00, 0.20636800E+01, 0.11476700E+00, 0.23863000E+01, -.52074700E-01, 0.40327800E+00, 0.71319000E+00, 0.89401700E+03, 0.91515500E+03, -.12338500E+04, -.15562900E+03, -.14412300E+04, 0.98790200E+03, -.41439400E+04, 0.13573500E+03, 0.79718200E+03, 0.17418600E+04, -.13905800E+04, -.31076500E+04, -.45710500E+04, 0.15359900E+04, -.19482200E+04, 0.96129600E+03, 0.73970000E+03, 0.10802400E+04, -.59100000E+03, -.16696500E+04, -.19625100E+04, 0.11429900E+04, -.10306300E+04, 0.71024600E+03, -.73430700E+03, -.64269400E+03, 0.98063500E+03, 0.19701200E+03, 0.98528400E+03, -.83485700E+03, 0.39002500E+03, 0.17179100E+04, 0.28031700E+03, -.42514700E+03, 0.11371200E+04, 0.11615800E+04, 0.35230900E+04, -.21094200E+03, 0.83336400E+01, 0.40523900E+01, -.27723100E+00, -.79511100E-01, -.17867200E+01, 0.63050800E+01, 0.12914200E+01, -.75746000E-02, 0.37086600E+03, 0.66425700E+03, 0.74724300E+01, 0.22915700E+03, -.33122100E+03, -.49458000E+03, -.69244600E+03, 0.27358000E+03, -.17347400E+02, 0.11343900E+01, -.10195700E+01, 0.19079600E+01, 0.98804000E+00, -.10699300E+02, -.64752100E+01, 0.22764400E+00, -.30983100E+00, -.95114600E+00, 0.84798000E-01, -.77616000E-01, 0.22023200E+00, -.22410400E+00, 0.35966500E+00, -.28550500E-01, -.26663600E+00, -.57232700E+00, -.29897700E-01, -.77539000E-01, -.70784400E-02, -.21601800E+00, -.39082000E+00, -.69646900E-01, -.40754200E+03, 0.64913400E+03, 0.25560600E+03, 0.55924000E+03, -.40858800E+03, -.11289700E+04, -.14333800E+04, 0.63223700E+03, -.25945200E+04, 0.66410200E+03, 0.92690400E+03, 0.14525000E+04, -.92754900E+03, -.13712100E+04, -.26615200E+04, 0.14214000E+04, 0.17720900E+04, 0.85426600E+03, -.30595400E+03, -.17982700E+03, -.42371500E+03, 0.35647700E+03, 0.39347200E+01, -.26503000E+03, 0.41383400E+03, -.10804300E+04, -.54402700E+03, -.93488700E+03, 0.11209600E+04, 0.10041700E+03, 0.13301000E+04, -.79814700E+03, 0.16147300E+04, -.96946000E+03, 0.18913500E+03, 0.24803300E+03, -.34636800E+03, -.14154300E+03, -.60989600E+03, 0.46045500E+03, 0.38541300E+02, -.41584900E+02, 0.92060700E+01, -.68789800E+01, 0.14022200E+02, 0.32737400E+01, 0.32586000E+02, 0.23258900E+01, -.17783100E+03, 0.11038900E+04, 0.11450100E+03, 0.46047900E+03, -.28062800E+03, -.91678800E+03, -.91326100E+03, 0.53258700E+03, -.53431700E+03, 0.11631100E+04, 0.22731700E+03, 0.22753700E+03, -.47839300E+03, -.79712700E+03, -.16058600E+02, 0.18803400E+03, -.49829400E+01, 0.27275000E+02, -.47516000E+00, 0.45120100E+03, -.11111500E+04, 0.17690800E+03, 0.40022500E+03, -.18610600E+04, -.65848800E+00, -.11560600E+03, 0.14237700E+01, 0.11061000E+00, -.54865800E+00, 0.73127400E+02, -.16301500E+03, 0.13733500E+03, 0.19957000E+03, 0.13138400E+03, -.55448200E+01, 0.27886100E+03, 0.18909200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16657900E-01, -.36678400E-01, 0.26780100E-01, 0.14137700E+00, -.21664700E-01, 0.27553200E-02, -.99020900E-02, 0.30248200E-03, -.75005700E-01, 0.13639000E-01, 0.28305300E-02, 0.61785200E-02, 0.43798900E-01, 0.38917800E-02, 0.89545500E-01, 0.28737400E-01, -.46902800E-02, -.27967700E-01, -.38332400E-01, -.15614600E+02, 0.14892900E+02, 0.56352700E+02, 0.43977700E+02, -.11500000E+02, -.21432000E+02, -.82407300E+02, 0.58794000E+02, 0.10055000E+03, -.11974200E+03, -.13257400E+03, -.27862500E+03, 0.86706700E+02, -.67983800E+02, 0.30091000E+02, 0.16320700E+02, 0.12728400E+02, 0.21431000E+01, -.24981700E+02, -.25472000E+02, 0.17396500E+02, -.64697900E+02, 0.38277500E+02, 0.14210000E+02, 0.38551500E+02, -.19404100E+02, -.67218400E+02, -.72261400E+02, 0.28544800E+02, -.33671500E+02, 0.94994300E+02, -.27021700E+02, -.60334500E+02, 0.95708300E+02, 0.94482300E+02, 0.22848200E+03, -.45456400E+02, 0.34069200E+00, 0.24512000E-01, 0.51596900E-01, 0.59125100E-01, -.10079000E+00, 0.27137200E+00, -.42563700E+00, 0.89563200E-01, 0.16981400E+03, -.46666400E+02, 0.39263600E+01, 0.17030100E+02, -.78828800E+02, 0.93629900E+01, -.85377500E+02, 0.23390900E+02, -.10040100E+01, 0.22878000E+00, 0.14531500E+00, 0.32383300E+00, -.26373400E-01, -.86603800E+00, 0.43108700E-01, 0.20031000E+00, -.19340100E-01, -.22370400E-01, -.15210900E-01, -.27467900E-01, 0.30642600E-01, 0.83879400E-02, -.86926000E-02, -.26196500E-01, -.35674000E-01, 0.18941300E-02, -.17191000E-01, -.22270100E-01, 0.20729800E-01, -.49655100E-03, -.18173200E+00, -.23855900E-01, -.54016300E+02, 0.38967600E+02, 0.14012600E+01, -.64523900E+00, 0.17042800E+02, -.28580600E+02, -.10120400E+01, 0.43398900E+01, -.45748000E+02, 0.34621100E+02, 0.39946100E+02, 0.61320000E+02, -.45646500E+02, -.33638000E+02, -.10480500E+03, 0.55964600E+02, 0.79293900E+02, 0.17480300E+01, 0.14067500E+02, 0.26582400E+02, -.48611200E+02, -.15671800E+02, -.42472000E+02, 0.26387700E+02, 0.86055400E+01, -.26025200E+02, -.34706100E+02, -.49121600E+02, 0.39646000E+02, -.15418500E+01, 0.49157500E+02, -.46409100E+02, 0.26181900E+03, -.78887700E+02, 0.78433200E+01, 0.12434800E+02, -.84785900E+02, 0.32959900E+02, -.97969800E+02, 0.24474700E+02, 0.40724200E+01, -.21500300E+01, -.75909100E+00, -.17995700E+01, 0.82082600E+00, 0.24419200E+01, 0.22262200E+01, -.13236300E+01, 0.14829100E+03, -.26660500E+02, 0.14831200E+02, 0.37889700E+02, -.89017000E+02, -.30197000E+02, -.12755900E+03, 0.42582500E+02, -.41263200E+02, 0.33770000E+02, -.14005800E+02, -.18392300E+02, 0.14636900E+02, -.31075900E+02, 0.38167500E+02, -.21013100E+02, -.42539500E+00, 0.50966700E+01, 0.60436200E-02, -.12841200E+02, -.59979000E+02, 0.20634200E+01, -.18906900E+02, -.94603800E+02, 0.55469000E-01, -.19937500E+02, 0.42541400E-01, 0.54969800E-01, -.45635600E-01, 0.22027400E+00, 0.13190600E+01, 0.11692400E+02, -.21548200E+01, -.12800200E+02, -.65727900E+00, 0.54304600E+02, 0.46881800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19213400E+00, 0.57938300E+00, -.35852300E+00, -.15845100E+01, 0.11678200E+00, 0.19530400E+00, 0.13918600E-01, 0.41668500E+00, 0.94548700E-01, -.48775600E+00, 0.11135800E+00, -.74369900E+00, 0.12256300E+01, 0.78511300E-01, -.14849700E+01, -.29381300E+00, -.14360700E+00, 0.12596200E+00, 0.36331900E+00, -.24338300E+01, 0.22999500E+03, -.40550400E+02, 0.83197200E+03, 0.75382900E+02, -.44099600E+04, 0.22808000E+04, 0.82658800E+03, 0.82246600E+03, 0.62372500E+03, -.15953900E+04, 0.46611800E+03, 0.76562600E+03, 0.39473300E+03, 0.62414400E+02, 0.60245900E+03, 0.68681100E+03, -.87814300E+03, -.25465400E+03, -.10831600E+04, 0.70692800E+03, 0.27045900E+03, -.24884000E+03, -.15423700E+03, -.16643500E+03, -.14036200E+03, -.80416200E+02, -.91563300E+03, -.23327900E+03, 0.50951500E+04, -.28415300E+04, -.88568100E+03, -.97858500E+03, -.69144700E+03, 0.18051900E+04, -.44690400E+03, -.89713700E+03, 0.36076000E+01, -.46021800E+01, -.73450300E+00, -.94157700E+00, -.73602900E+00, 0.18652300E+00, -.27859900E+01, -.83107700E+00, -.19725900E+04, 0.98088600E+03, 0.53658500E+03, 0.44543900E+03, 0.29317300E+03, -.48581200E+03, 0.62627100E+03, 0.43301500E+03, 0.28038000E+01, 0.17607400E+01, -.21466800E+01, -.18311900E+01, -.14814500E+00, 0.14796300E+01, -.41692300E+01, -.21593200E+01, 0.62106800E-01, 0.27420500E+00, 0.10834400E+00, 0.13388100E+00, -.11310800E+00, 0.72447500E-01, 0.10640300E-01, 0.14501200E+00, -.86948900E+00, 0.56058800E+00, 0.15676900E+00, 0.21514700E+00, 0.28634000E+00, -.24780600E+00, 0.25539400E+00, 0.21862300E+00, 0.23870800E+03, 0.59109500E+02, 0.49980800E+03, 0.56061100E+03, -.76263500E+03, -.29584400E+02, -.86131700E+03, 0.57994400E+03, -.19524800E+04, 0.10852400E+04, -.64441500E+02, -.41336800E+02, 0.69655400E+03, -.72980600E+03, 0.74081300E+03, -.76669500E+02, 0.42640600E+03, -.67352200E+03, -.18953100E+03, -.25310000E+03, 0.65835900E+02, 0.29517000E+03, -.41615700E+03, -.24876700E+03, -.21239200E+03, 0.50161200E+03, 0.31695500E+03, 0.34825000E+03, -.24164100E+03, 0.71824900E+02, 0.19401500E+03, 0.31715300E+03, -.15712800E+04, 0.10582700E+04, 0.25642200E+03, 0.11671900E+03, 0.31415400E+03, -.14554000E+03, 0.93672800E+03, 0.71025800E+02, -.22262200E+02, 0.17763500E+02, 0.18131300E+02, 0.17938300E+02, -.14245500E+02, -.37560300E+01, 0.81746100E+01, 0.18505100E+02, -.23879800E+04, 0.12545400E+04, 0.43981100E+03, 0.33854400E+03, 0.46166800E+03, -.44576700E+03, 0.85120000E+03, 0.28495300E+03, -.41936000E+03, -.12919300E+03, 0.13264000E+03, 0.19152000E+03, 0.77571200E+02, 0.54490000E+02, -.93310900E+02, 0.19966500E+03, -.14387400E+01, -.63124800E+02, -.10428700E-01, -.24332300E+03, -.13267800E+03, 0.16283700E+03, -.23993400E+03, -.13482200E+03, 0.20685800E+00, -.16751000E+03, 0.45186400E-01, -.18969300E+00, -.44815200E-01, -.89863800E+02, -.42157400E+02, 0.93539400E+02, 0.68684900E+01, 0.69551100E+01, 0.43535600E+01, -.24267200E+02, -.52013000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16297900E+00, -.38439000E+00, 0.35558600E+00, 0.16845400E+01, -.31509300E+00, 0.27751100E-01, 0.20791500E+00, 0.13252300E+00, -.29229800E+00, 0.26028100E+00, 0.20629600E+00, -.21717900E+00, 0.43866700E+00, 0.26397000E-01, 0.21510900E+00, -.97372000E-02, -.13619700E+00, 0.16382700E+00, -.38914400E+00, 0.38823700E+01, 0.14357500E-01, 0.24672300E+03, 0.67239900E+02, 0.18891400E+02, 0.26514700E+03, 0.35151000E+02, 0.15412900E+03, 0.13793200E+03, -.25461400E+03, -.23710100E+02, -.22398700E+03, 0.79214900E+02, -.29969200E+03, -.18932500E+02, -.12497600E+03, -.11418800E+03, 0.31210800E+03, -.12906800E+01, 0.24237400E+03, -.10475400E+03, -.15485400E+03, 0.18502600E+03, 0.14569500E+03, 0.14446000E+03, -.15850800E+03, -.20046900E+03, -.16053000E+03, 0.10029200E+03, -.23721200E+03, 0.74225100E+02, -.14236300E+03, -.74017500E+02, 0.20416800E+03, 0.12507400E+03, 0.14750400E+03, -.13104300E+02, 0.22615600E+00, 0.87259500E+00, 0.68207900E+00, 0.56407700E+00, -.64260000E+00, 0.14664500E+00, 0.14219600E+01, 0.54593300E+00, 0.27885300E+03, -.21372900E+03, -.16180600E+03, -.90386700E+02, 0.34961500E+02, -.12311100E+02, -.10912400E+03, -.61465500E+02, -.36637300E+01, 0.50693900E+00, 0.18725700E+01, 0.15897000E+01, -.12486800E+01, -.18872400E+01, -.24473800E+01, 0.11510800E+01, -.97947700E-01, -.24627800E-01, -.67276500E-01, -.49592400E-01, 0.10383800E+00, 0.36034500E-02, 0.30545300E+00, -.30131900E-01, 0.96303600E-01, -.61893800E-01, -.15667900E+00, -.15380800E+00, 0.10573300E+00, 0.11024200E+00, 0.77760800E+00, -.14641300E+00, -.49295800E+03, 0.26367900E+02, -.18081900E+03, -.23721000E+03, 0.44524600E+03, -.23408700E+02, 0.54995400E+03, -.21822600E+03, 0.27651800E+03, -.19743300E+03, 0.38341500E+02, 0.32425100E+02, -.50159100E+02, 0.12226400E+03, -.18250400E+03, 0.57488500E+01, 0.12241200E+03, 0.44447000E+02, 0.97158400E+02, 0.78069200E+02, -.17781100E+03, -.87578800E+02, -.13599300E+03, 0.58804300E+02, 0.56654600E+01, -.12989000E+03, -.26162500E+03, -.23354100E+03, 0.31026600E+03, -.56764400E+02, 0.16926100E+03, -.20668400E+03, 0.25601400E+03, -.34581300E+03, -.25934300E+02, 0.34297300E+02, 0.22811000E+02, -.13028200E+03, -.18459800E+03, 0.84854100E+02, 0.11718300E+02, -.80030800E+01, -.88801000E+01, -.63528000E+01, 0.10212400E+02, 0.41472400E+01, 0.86727500E+01, -.34810200E+01, 0.15098300E+03, -.23410900E+03, -.85948200E+02, -.20096800E+02, 0.16525300E+02, -.20508300E+03, -.17474200E+03, 0.22156200E+01, -.62161000E+03, 0.38525500E+03, 0.11092900E+03, 0.13040800E+03, -.14020500E+03, -.25486700E+03, 0.50256400E+02, 0.10303500E+03, -.12683900E+01, -.58992600E+01, -.47126600E+00, 0.92951100E+00, -.49172000E+02, -.10472700E+02, -.52848800E+02, -.93964900E+01, -.72716400E+00, 0.89311000E+02, 0.76640500E+00, -.38078300E+00, -.29210600E+00, -.71715900E+01, 0.21613500E+01, 0.39842900E+02, 0.20637600E+02, 0.80765300E+02, -.32686300E+01, -.56137000E+02, 0.71730200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15034300E+00, -.72758100E-01, 0.16096300E+00, 0.71866400E+00, 0.88919300E-01, -.10334000E+00, -.34193500E+00, 0.13318900E+00, 0.57528700E-01, 0.67001600E-01, 0.74724400E-01, -.16286600E+00, 0.37285100E-01, 0.15389000E-01, -.19967400E+00, -.24022700E+00, -.92593700E-01, 0.26243700E+00, 0.16776700E+00, -.23379200E+01, 0.32816200E+00, 0.44951700E+00, 0.15041800E+03, 0.88030000E+01, -.27922900E+03, 0.18254200E+03, 0.12822300E+03, 0.15125000E+03, -.70661200E+02, -.29092800E+03, -.36235500E+03, 0.16235600E+03, 0.35120400E+02, 0.52723500E+02, 0.15623700E+03, 0.17151900E+03, -.22777700E+03, -.91419700E+02, -.31320300E+03, 0.18285100E+03, -.22322700E+01, -.34855700E+02, -.58315900E+02, -.58813200E+02, 0.90293500E+02, -.12999300E+02, -.11491100E+03, -.62103700E+02, 0.41967700E+03, -.21153600E+03, -.84207400E+02, -.12061000E+03, -.10051300E+02, 0.22382000E+03, 0.26374500E+03, -.11979200E+03, 0.56516300E+00, -.68413900E+00, -.23252100E+00, -.17893700E+00, 0.10545200E+00, 0.50957300E+00, -.14186300E+01, -.12047600E+00, -.32029900E+03, 0.10231500E+03, 0.19352500E+03, 0.18674000E+03, -.11823900E+03, -.18530800E+03, -.13728900E+03, 0.18077200E+03, 0.13513800E+01, -.10470700E+00, -.10267200E+01, -.94283300E+00, 0.85067700E+00, -.13415500E+00, 0.11378700E+01, -.96897600E+00, 0.53624200E-01, 0.19715200E-01, 0.10544400E-01, 0.11387600E-02, -.31175900E-01, 0.16287300E-01, -.15038200E+00, -.25241600E-02, -.14170600E+00, 0.87609500E-01, 0.36916400E-01, 0.32971200E-01, 0.28773500E-03, -.57704100E-01, -.54328100E+00, 0.27936100E-01, 0.12421600E+03, 0.31537300E+02, 0.10236800E+03, 0.12894500E+03, -.19354200E+03, -.53345500E+02, -.29868900E+03, 0.13328300E+03, -.47342000E+03, 0.22892800E+03, 0.96806100E+02, 0.14235400E+03, -.18287800E+02, -.23010700E+03, -.99716100E+02, 0.13783900E+03, 0.42896400E+01, -.64962900E+02, -.23139100E+02, -.24107700E+02, 0.49940600E+02, -.34135900E+01, -.21913000E+02, -.22097000E+02, 0.13761400E+01, 0.30406100E+02, 0.78302100E+02, 0.58785300E+02, -.10757000E+03, -.46562000E+01, -.46244100E+02, 0.44291700E+02, -.36575500E+03, 0.19465700E+03, 0.13663000E+03, 0.13173100E+03, -.86723500E+02, -.15589800E+03, -.11402300E+03, 0.11066300E+03, -.50261500E+01, 0.33037600E+01, 0.58029100E+01, 0.52962000E+01, -.65589300E+01, -.16835000E+01, -.38676300E+01, 0.49477600E+01, -.68899300E+03, 0.30771400E+03, 0.18809500E+03, 0.18617200E+03, -.14422800E+02, -.26835800E+03, -.10146800E+03, 0.16701800E+03, 0.29139100E+03, -.16239000E+03, -.77886900E+02, -.10280100E+03, 0.77647600E+02, 0.89599000E+02, 0.32979500E+02, -.90605200E+02, 0.12734300E+00, 0.12351700E+02, 0.24327400E+00, -.76474800E+02, -.99341000E+02, 0.17264600E+02, -.40357900E+02, -.17104900E+03, 0.42799200E+00, -.10828900E+03, -.32333100E+00, 0.21907800E+00, 0.93293600E-01, 0.42714200E+01, -.76174800E+00, -.40446100E+00, -.17569000E+02, -.74271900E+02, 0.17177400E+01, 0.91582900E+02, -.24373200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23977100E+01, 0.30630300E+00, 0.63202300E+00, 0.73917200E+00, -.10791400E+01, 0.72974700E+00, -.49047300E+00, 0.41898100E+00, -.23903000E+01, -.20735500E+01, -.74970500E+00, -.86133400E+00, -.26817100E+01, -.10711100E+00, -.30007400E+01, 0.55962600E+00, -.16042200E+00, -.19701700E+01, -.16836800E+01, 0.62679200E+01, -.18737200E+01, -.19746000E+01, -.19636400E+01, -.12817400E+03, 0.44432900E+03, 0.13783100E+04, -.40244100E+03, -.14784500E+03, 0.23316100E+03, 0.15580100E+04, 0.31343800E+04, -.55669000E+02, -.87106500E+03, 0.13426400E+03, -.64949100E+03, -.69724700E+03, 0.14254200E+04, 0.40555500E+03, 0.17515200E+04, -.72568800E+03, 0.40896600E+03, 0.12015300E+03, 0.37061100E+03, 0.42552200E+03, -.99803700E+03, 0.30959600E+03, -.20628500E+03, 0.59234900E+03, 0.67416700E+02, -.20096000E+04, 0.16451100E+01, -.23841600E+03, 0.11107700E+03, -.70457400E+03, -.24800000E+04, -.36614100E+03, -.43719100E+01, 0.18867400E+01, 0.19032700E+01, 0.13739400E+01, -.14498200E+01, -.25301100E+01, -.57396400E+00, 0.80379000E+00, -.64127900E+03, -.41443700E+03, -.99822600E+03, -.11709300E+04, 0.18993700E+04, 0.27662700E+03, 0.14671400E+04, -.11937000E+04, 0.26588400E+00, -.10687100E+01, 0.69763600E+01, 0.77859100E+01, -.13619700E+02, 0.21493700E+01, -.21313400E+01, 0.89479700E+01, -.32731500E+00, 0.34846800E+00, -.96018600E-02, 0.86542100E-01, 0.23522500E+00, -.20430700E+00, 0.20208600E+00, 0.98563100E-01, 0.65162100E+00, 0.25836500E-01, -.37862100E+00, -.38939700E+00, 0.43615000E+00, 0.25901900E+00, 0.83565300E+00, -.39064500E+00, -.72861000E+03, -.43184400E+03, -.38545900E+03, -.48028700E+03, 0.10125600E+04, 0.34103000E+02, 0.15336600E+04, -.48648800E+03, 0.25311100E+04, -.96911300E+03, -.70462300E+03, -.96990100E+03, 0.48273400E+03, 0.14216000E+04, 0.12974600E+04, -.95819400E+03, 0.19400900E+03, -.28204500E+03, 0.55443400E+02, -.75167200E+02, -.40875300E+03, 0.17597800E+03, -.32024200E+03, -.95065400E+02, -.77476200E+02, -.30235100E+03, -.60068900E+03, -.48798300E+03, 0.11880200E+04, -.58182000E+02, 0.59977800E+03, -.38853200E+03, 0.72930200E+02, -.11582900E+04, -.10140300E+04, -.11816900E+04, 0.19237200E+04, 0.50125300E+03, 0.22526900E+04, -.11470200E+04, -.18289000E+01, -.25162800E+01, -.31228100E+02, -.29100200E+02, 0.68452400E+02, -.33463200E+01, 0.27661800E+02, -.27768300E+02, 0.13037600E+04, -.14527400E+04, -.12040300E+04, -.15098400E+04, 0.17141700E+04, 0.10411500E+04, 0.21813500E+04, -.14576500E+04, -.33599300E+04, 0.19288800E+04, 0.11807200E+04, 0.13475000E+04, -.10436300E+04, -.12034300E+04, -.34982800E+03, 0.12260200E+04, -.28524900E+01, -.15523800E+03, -.58629900E+00, 0.27892700E+02, 0.77934200E+03, 0.13082600E+02, 0.48876800E+02, 0.13400000E+04, -.63627800E+00, 0.88600200E+03, 0.62588400E+00, -.23312000E+00, -.45842500E+00, -.88510800E+02, 0.40853900E+02, 0.12666900E+03, 0.25781600E+03, 0.10328400E+04, -.76802800E+01, -.14247500E+04, 0.30490000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17719900E+01, 0.42231300E+00, 0.53502500E+00, -.92745500E+00, -.74820200E-01, -.45341500E+00, -.15884400E+01, 0.12074100E+01, 0.20929000E+00, 0.11738500E+01, -.64824000E+00, -.46896700E+00, 0.30955800E+01, 0.22440700E+00, 0.99318800E+00, 0.70368800E+00, 0.31196400E+00, 0.12023100E-01, 0.65842900E+00, 0.81051000E+00, 0.38967400E-01, -.68666300E+00, 0.88948200E+00, 0.20132700E+00, 0.36279000E+04, -.32487900E+03, -.66682500E+03, -.11798300E+04, 0.37689000E+03, 0.20000800E+04, 0.17056000E+04, -.10843600E+04, -.11644800E+03, -.48582200E+03, -.15047200E+03, -.24879800E+03, 0.34918600E+03, 0.15599400E+03, 0.59163900E+03, -.28476800E+03, 0.49793000E+03, -.23607600E+03, -.83824400E+02, -.11301700E+03, 0.80529600E+02, 0.10925400E+03, 0.18749100E+03, -.89031600E+02, -.26494800E+04, 0.21632000E+03, 0.35754000E+03, 0.85928200E+03, -.27048700E+03, -.13476100E+04, -.13939200E+04, 0.76668500E+03, -.24540100E+01, 0.14468800E+00, 0.17511300E+00, -.43278300E+00, 0.77576600E+00, -.23792800E+01, 0.24116500E+01, -.57171900E+00, -.11470700E+04, -.72312600E+01, -.61817500E+02, -.15667000E+03, 0.47304600E+03, -.86833300E+02, 0.24618100E+03, -.20083400E+03, 0.39145400E+01, -.15934500E+01, -.26001200E+00, -.15825100E+01, 0.16948400E+01, 0.41307600E+01, 0.23188000E+01, -.10605800E+01, 0.18104400E+00, 0.23715000E+00, 0.15212000E-01, 0.13550400E+00, -.18519300E+00, 0.61504500E-01, 0.22578200E-01, 0.13917400E+00, 0.38279100E+00, 0.92525300E-01, 0.15167600E-01, 0.26137300E-01, -.15311900E+00, 0.23230300E+00, 0.10839800E+01, 0.40361700E-01, -.47909300E+03, -.62140600E+03, -.90591000E+02, -.27158500E+03, 0.38248300E+03, 0.14974000E+03, 0.61815800E+03, -.29458800E+03, 0.64830700E+03, -.17735000E+03, -.18674400E+03, -.43871800E+03, 0.19741700E+03, 0.40200700E+03, 0.72025700E+03, -.43937900E+03, -.91689500E+03, -.10984500E+03, 0.65903900E+02, -.50343500E+02, 0.32893600E+03, -.19450100E+03, 0.31349900E+03, -.50713700E+02, -.15849500E+02, 0.94990400E+02, 0.29459600E+02, 0.30493300E+03, -.32713900E+03, -.25183800E+02, -.58599000E+03, 0.26933500E+03, -.18523900E+04, -.17931600E+03, -.17844200E+02, 0.63279300E+00, 0.43179800E+03, -.43610300E+03, 0.17297500E+02, -.94370900E+02, -.21031500E+02, 0.10073200E+02, -.12874600E+01, 0.10841100E+02, -.70876600E+01, -.10124600E+02, -.24730700E+02, 0.85101600E+01, -.89279700E+03, -.60163900E+03, -.15633100E+03, -.32807500E+03, 0.51951800E+03, 0.28839700E+02, 0.31728400E+03, -.38177500E+03, 0.59393900E+03, -.35116900E+03, -.13024000E+03, -.12352200E+03, 0.58789700E+02, 0.38453400E+03, 0.15572100E+02, -.95242000E+02, 0.32187800E+01, -.14318700E+02, -.24180900E-01, 0.26799000E+02, 0.40894600E+03, -.74529300E+01, 0.23923100E+02, 0.76887700E+03, -.25075200E+00, 0.15105200E+03, -.35441400E+00, -.34947500E+00, 0.28599000E+00, -.60111200E+02, 0.26982900E+02, -.11993700E+03, -.39934600E+02, 0.28709200E+02, 0.31709000E+01, -.41725600E+03, -.53920900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.58714300E+01, -.21015000E+01, -.10690200E+01, -.66289900E+00, 0.26642000E+00, 0.35957900E-01, -.16411900E+01, 0.17073300E+01, 0.38723800E+01, 0.33428800E+01, 0.13593200E+01, -.99348800E+00, 0.65487400E+01, 0.24696400E+00, 0.76332900E+01, 0.16996200E+01, 0.17680600E+01, 0.90854400E+00, 0.92824400E+00, -.13181900E+01, -.31450700E+00, 0.12349000E+01, 0.34407100E+01, -.11413400E+01, 0.63362000E+00, 0.26441300E+04, 0.85284500E+03, 0.12908000E+04, -.17014400E+04, -.10986200E+03, -.46543200E+03, 0.13672900E+04, 0.27059400E+03, -.68146000E+03, 0.10885800E+03, 0.52395100E+03, -.65914000E+03, -.57718900E+03, -.12701700E+04, 0.51717900E+03, 0.29180500E+03, -.88090300E+01, 0.90582700E+02, 0.29223500E+03, -.97067800E+03, 0.17317800E+03, -.76800400E+03, 0.24255200E+03, -.65457400E+03, -.19783000E+04, -.58394100E+03, -.95798100E+03, 0.15681800E+04, -.17249400E+02, 0.25692700E+03, -.10518800E+04, 0.24506800E+01, -.16759500E+01, 0.48190900E+00, -.48252700E+00, -.16846100E+01, 0.20525400E+01, 0.17363300E+01, -.86744300E+00, -.14309700E+04, 0.32756700E+03, 0.16664600E+03, -.32080500E+03, 0.13544200E+04, -.31256400E+03, 0.14119700E+04, -.32527600E+03, 0.16516300E+01, 0.36956700E-02, 0.18418600E+01, 0.52684100E+01, -.13693400E+02, -.68875800E+00, -.15797700E+02, 0.49933100E+01, -.32276300E+00, 0.44372500E+00, 0.11341900E+00, 0.19784200E+00, 0.16822100E+00, -.24726000E+00, 0.56232800E+00, 0.25890600E+00, -.65073900E+00, 0.64111500E+00, -.96820000E-02, -.11846300E+00, 0.71605300E+00, -.22697600E+00, 0.14367100E+01, -.82252900E-01, 0.68254400E+03, -.15009300E+04, -.23770000E+03, 0.72161700E+01, -.38039200E+03, -.23219600E+03, -.59239800E+03, -.11663500E+02, -.14434100E+04, 0.16444900E+03, -.90982300E+02, -.98278400E+01, 0.57467600E+03, -.38289900E+03, 0.12840300E+02, -.66300500E+01, 0.17820500E+04, -.12063400E+04, -.33177400E+03, -.56011500E+03, -.45025100E+03, 0.79538800E+03, -.49409100E+03, -.63186200E+03, -.20784200E+02, 0.51527100E+02, -.13618700E+03, -.12699800E+03, 0.10008400E+04, -.14191900E+03, 0.12941500E+04, 0.26996700E+02, -.17550000E+04, -.79998600E+03, -.24443600E+03, -.67490600E+03, 0.18577100E+04, -.62816700E+02, 0.30037600E+04, -.60694700E+03, -.22046700E+02, 0.63022400E+01, -.40392700E+01, -.17130700E+01, 0.46013500E+02, -.18097800E+02, 0.51955700E+02, 0.35911100E+01, -.15502400E+04, -.77087500E+01, 0.13257900E+03, -.45039400E+03, 0.15171200E+04, -.16226700E+03, 0.22885200E+04, -.43697200E+03, -.42347900E+04, 0.21519100E+04, 0.13195000E+04, 0.14787200E+04, -.73899400E+03, -.16719200E+04, -.43839300E+03, 0.13867200E+04, -.59090400E+01, -.13679800E+03, -.83516700E+00, -.95166000E+01, -.27695500E+02, 0.85154600E+02, -.12928000E+03, 0.15780800E+02, -.11915600E+01, 0.29411800E+03, 0.13700300E+01, -.68286500E+00, -.61347300E+00, 0.82006200E+02, -.14652800E+03, 0.22712500E+03, 0.31646600E+03, 0.91831600E+03, -.21488500E+01, -.96077900E+03, 0.24222800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19427200E+01, -.11295600E+01, -.54847600E-01, 0.38774400E+00, 0.15056100E+00, -.27666700E+00, 0.12582400E+01, -.45335500E+00, 0.37643700E+00, 0.97756500E+00, -.78581800E-01, -.79556100E+00, 0.34001700E+01, 0.20813600E+00, 0.28045700E+01, 0.49867400E+00, 0.65456300E+00, 0.60836600E+00, 0.19936600E-01, 0.74946700E+01, 0.20169600E+00, -.50053900E+00, -.28444000E+01, -.37832900E+00, 0.44712900E+00, 0.21795700E+00, 0.48613900E+03, 0.97909600E+03, -.16612100E+04, -.10982600E+04, -.23509800E+04, 0.95949300E+03, -.10073100E+03, 0.39963400E+03, 0.24604800E+03, 0.41694900E+03, -.58032000E+03, -.39799100E+03, -.96976300E+03, 0.43832200E+03, -.55916000E+02, 0.74044000E+02, -.14659800E+02, 0.40631800E+02, -.25696800E+03, 0.15285200E+03, -.29338600E+03, 0.28265400E+02, -.49463300E+03, 0.37215800E+03, -.10864900E+03, -.55614500E+03, 0.13083800E+04, 0.32801800E+03, 0.17653300E+04, -.54159900E+03, 0.24414200E+01, -.54494100E+00, -.14574000E+00, 0.10485700E+00, -.30721700E+00, 0.43057900E+01, 0.90598000E+00, 0.18096700E+00, 0.20348400E+03, -.18565100E+03, 0.34254500E+03, 0.40126400E+03, -.41110200E+03, -.48915700E+03, -.46432500E+03, 0.40731900E+03, 0.60300500E+00, -.59680000E-01, -.53597000E+00, 0.12826300E+01, -.49332200E+01, -.48387500E+01, -.91695800E+01, 0.82309200E+00, -.18298600E+00, -.27633700E-01, -.19195400E-01, -.10786400E+00, 0.22904400E+00, -.15063300E+00, 0.25054100E+00, -.10521200E+00, -.52152300E+00, 0.16909100E+00, -.39466300E-01, -.76400300E-01, 0.24878100E+00, -.38282100E+00, -.24172400E+00, -.89092700E-01, 0.34405900E+03, 0.35596400E+03, 0.21672100E+02, 0.20967600E+03, -.39440200E+03, -.29457300E+03, -.72821600E+03, 0.20765100E+03, -.11951900E+04, 0.23182500E+03, 0.46305200E+03, 0.78403200E+03, -.49165300E+03, -.71468400E+03, -.12511400E+04, 0.79923600E+03, 0.12378400E+04, -.30780300E+03, -.12520100E+03, -.94792800E+02, -.36520200E+03, 0.30021700E+03, -.28245900E+03, -.11883400E+03, 0.12949800E+03, -.27183600E+03, -.11065500E+03, -.36979800E+03, 0.48993700E+03, -.10153100E+02, 0.81122300E+03, -.31034400E+03, 0.10007200E+04, -.16233500E+03, 0.23312100E+03, 0.18064200E+03, -.28251000E+03, 0.21339700E+02, 0.94213100E+02, 0.25381900E+03, 0.30519400E+01, -.22368700E+01, 0.70131300E+01, -.15533600E+01, 0.13466900E+02, -.16119800E+01, 0.28898500E+02, 0.97534400E+00, -.74406800E+03, 0.62339500E+03, 0.48211800E+03, 0.56710200E+03, -.26087700E+03, -.74688400E+03, -.26881100E+03, 0.57822300E+03, -.12565700E+04, 0.75693900E+03, 0.26295500E+03, 0.25402700E+03, -.41736500E+02, -.81763700E+03, -.56480400E+02, 0.21902700E+03, -.40532000E+01, 0.34320800E+02, -.25642400E+00, -.42885800E+02, -.34822700E+03, 0.81128500E+01, -.55403000E+02, -.67527000E+03, -.46255900E+00, -.18757300E+03, 0.87600200E+00, -.24455600E-01, -.36700200E+00, 0.84917400E+02, -.53047600E+02, 0.12919300E+03, 0.84194300E+02, 0.24804300E+02, -.12953400E+01, 0.33098300E+03, 0.81185900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15844300E+01, 0.15598400E+00, 0.42766800E+00, 0.84571200E+00, -.66493300E-01, 0.75328700E+00, -.74427900E+00, 0.65984500E+00, -.57938400E+00, -.12355600E+01, 0.71410200E+00, -.83352500E+00, -.20272100E+01, -.81708700E-01, -.28660300E+01, -.43450000E+00, -.44810500E+00, -.48552600E+00, -.67247900E+00, -.31103800E+01, 0.65276000E-01, -.24766400E+00, 0.11728000E+01, 0.43176900E+00, -.62399500E-03, -.88383200E-01, 0.13032300E+00, -.30313600E+03, 0.27011200E+03, 0.21081500E+03, 0.46228000E+03, -.35200700E+03, -.16155900E+00, -.30330900E+03, -.40005400E+01, -.54648500E+01, -.70556900E+02, -.42340200E+02, -.26792100E+02, -.45776500E+02, -.97981400E+02, 0.79439000E+02, -.68156400E+01, -.24193000E+02, 0.73055900E+02, -.12938200E+03, 0.59465800E+01, -.58751300E+02, 0.34588900E+03, 0.45229700E+02, -.14487900E+03, 0.15380200E+03, -.23019700E+03, 0.53600600E+02, -.33559600E+03, 0.20091500E+03, 0.17544400E+01, 0.67476000E-01, -.85174600E-01, -.27696400E+00, -.54290800E+00, -.59329800E+00, -.22404600E+00, -.28422500E+00, 0.68351400E+02, 0.98134800E+02, -.57522000E+02, -.39048600E+02, -.27487200E+02, 0.17972900E+03, 0.12785400E+03, -.13745500E+02, -.52456900E+01, 0.14795200E+01, 0.37005600E+00, -.31791900E+00, 0.21163400E+01, -.54055500E+00, 0.97369800E+00, -.74514300E+00, -.12683500E-01, -.63988600E-01, 0.24855300E-01, 0.62764800E-01, -.44138500E-01, 0.52658300E-01, 0.36421400E-01, 0.80734100E-01, -.41376500E-01, -.39321900E-01, 0.34247500E-01, 0.39625000E-01, 0.86344000E-02, 0.54840600E-01, 0.25672000E+00, 0.54532500E-01, -.23533900E+03, -.24801400E+03, 0.38224900E+02, 0.25203500E+01, 0.93087500E+00, 0.41436700E+02, 0.70071600E+02, -.19561200E+02, -.25091800E+03, 0.50140700E+02, -.17057500E+02, -.10351900E+03, 0.11612500E+03, -.13395200E+03, 0.12002500E+03, -.13851800E+03, -.33327400E+02, 0.92737400E+02, -.18348300E+02, -.39122000E+02, 0.31765700E+02, 0.19247200E+02, -.13344700E+02, -.49226600E+02, 0.18793800E+01, 0.18208400E+02, 0.42707100E+02, 0.13603400E+03, -.60281200E+02, 0.11494000E+03, -.41096000E+01, 0.17390200E+03, -.58656100E+03, 0.10671600E+03, 0.12198200E+03, 0.20863600E+03, -.79665200E+02, -.16410800E+03, -.14210200E+03, 0.23585500E+03, 0.54651900E+01, -.43365900E+01, -.14185100E+01, 0.40010200E+01, -.66276400E+01, 0.39569200E+01, -.32340200E+01, 0.54450700E+01, -.28173000E+03, 0.28298700E+02, 0.30275500E+02, 0.73146100E+02, -.50285000E+02, -.22771000E+02, -.64577300E+02, 0.89023500E+02, -.58775700E+02, 0.32394300E+02, -.19395500E+02, 0.60860000E+01, 0.39837300E+02, 0.13544800E+03, 0.22891200E+02, -.10138600E+01, 0.24715900E-01, -.71747200E+01, -.12010000E+00, 0.20249300E+02, 0.81364400E+02, 0.13194400E+02, 0.11091500E+02, 0.16395400E+03, -.82169100E-01, 0.58162400E+01, 0.19333000E+00, -.10635800E+00, -.54780400E-01, -.34816000E+02, -.28302400E+02, 0.56269400E+01, 0.35862700E+02, -.90478900E+02, -.51041100E+00, 0.20205800E+02, -.19515700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13591400E+01, 0.16180200E+00, 0.38620000E+00, -.68741600E+00, 0.44460300E+00, -.12816600E+00, -.14014200E+01, 0.16463000E+01, -.11135900E+00, -.77936600E+00, 0.28502200E+00, 0.33311000E+00, -.26925600E+01, -.14887900E+00, -.15368500E+01, -.57418100E-01, -.32965200E+00, 0.31106400E+00, -.37563000E+00, -.48686900E+01, -.21234200E-01, -.63454600E-01, 0.10434700E+01, 0.11922700E+00, 0.84426300E-01, -.12295900E+00, -.13471100E+00, -.47661600E+00, -.21975300E+03, -.14408500E+01, -.54144400E+02, -.67741400E+02, -.22214600E+03, -.43976000E+02, -.42290800E+02, -.92381400E+01, -.98708400E+01, -.10734100E+03, -.34769800E+02, -.53637200E+02, -.22835500E+02, 0.10778900E+03, 0.27765900E+01, 0.40633300E+02, -.10634700E+03, -.46758000E+02, -.15653200E+03, 0.51083300E+01, 0.19500100E+03, 0.12340200E+03, -.70296600E+02, -.55495100E+02, 0.21141300E+03, 0.91606000E+02, 0.78370300E+02, 0.11552400E+01, 0.27545200E+01, 0.40566400E+00, -.98155900E-01, -.22764400E+00, -.86919500E+00, 0.72296300E+00, -.11936800E+01, -.20898700E+00, 0.34994700E+03, -.44467600E+02, -.13547400E+03, -.10817500E+03, 0.15130200E+02, 0.18310500E+03, 0.16785500E+03, -.76087600E+02, -.71884400E+01, 0.17199100E+01, 0.12010000E+01, 0.16511000E+01, -.94047900E+00, -.29999500E+01, -.12288600E+01, 0.10144700E+01, -.14827400E+00, -.11375400E+00, 0.29261100E-01, 0.16194200E-01, 0.91085600E-01, -.17088200E-01, 0.57318100E-01, 0.36768000E-01, -.15806200E+00, -.36639400E-01, -.62545200E-02, -.15294200E-01, 0.11966800E+00, -.45781800E-01, -.16125300E+00, -.42734700E-03, -.17840900E+03, -.20744400E+02, 0.10911100E+02, 0.79958100E+01, -.36821700E+02, -.38856700E+02, 0.13810900E+02, -.29134600E+02, -.37257700E+03, -.93063400E+00, 0.34616900E+01, 0.31682000E+02, 0.68245300E+01, -.19779600E+03, -.10907000E+03, 0.65596500E+01, 0.54282900E+03, 0.38128800E+01, -.78177200E+02, -.53518000E+02, -.19479900E+03, 0.16161200E+03, -.20018000E+03, -.66890200E+02, 0.60693000E+02, -.18549700E+03, -.50571700E+02, -.10873000E+03, 0.31330200E+03, 0.16640300E+03, 0.42919600E+03, -.50420800E+02, 0.49738300E+03, -.36241500E+03, 0.24820700E+02, 0.51711900E+02, -.73128800E+02, 0.14177700E+03, 0.40630400E+02, 0.12462800E+03, 0.12675900E+02, -.91517100E+01, -.27955100E+01, -.39466500E+01, 0.76194300E+01, 0.76819000E+01, 0.12491600E+02, -.14014800E+01, 0.25781700E+03, -.89356900E+02, -.50743500E+02, 0.10169000E+02, -.59980900E+02, 0.62976000E+02, -.92007700E+01, 0.43684800E+02, -.93684700E+03, 0.56913600E+03, 0.17969900E+03, 0.24013000E+03, -.60915400E+02, -.29508600E+03, -.34324800E+02, 0.20724900E+03, -.21425800E+01, -.95588900E+01, -.19521000E+00, 0.16145100E+02, 0.24955300E+02, 0.15065200E+02, -.17550900E+01, 0.50667900E+02, -.56499100E-01, 0.57926800E+02, 0.48753100E+00, 0.44077400E-01, -.26062400E+00, -.30568700E+02, -.35055800E+02, 0.81109100E+02, 0.11740900E+03, 0.51411800E+02, -.28417500E+01, 0.14913100E+01, 0.37191500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16452300E+01, -.29827400E+00, -.49299500E+00, -.61676900E+00, 0.87413000E+00, -.66785200E+00, 0.30199400E+00, -.65792800E+00, 0.13776800E+01, 0.98691900E+00, 0.66397800E+00, 0.53319500E+00, 0.17312100E+00, 0.32677800E-01, 0.18881900E+00, 0.12772800E+00, -.14932300E+00, 0.10410100E+01, 0.23492900E+00, -.45011800E+01, 0.32376100E+00, 0.13241100E+01, 0.10584500E+01, -.34314000E+00, 0.10885700E+00, -.10335800E+00, 0.20540100E+00, 0.42916700E+00, 0.16152800E+00, 0.18071400E+03, 0.15702700E+03, 0.15957900E+02, -.40174300E+03, 0.41154500E+02, 0.28956200E+02, -.87009400E+01, 0.30452500E+03, -.48357000E+02, 0.29717400E+03, -.13782000E+02, 0.55296400E+01, 0.42912000E+01, 0.77155200E+02, 0.12988400E+03, -.20246100E+03, 0.18900800E+02, -.14951800E+03, 0.14546800E+03, -.46970700E+03, -.12886800E+02, 0.43189300E+02, 0.40717900E+02, 0.15303300E+03, -.22342500E+03, -.26761800E+02, 0.20773000E+02, 0.47545900E+00, 0.44684700E+00, -.67419300E-01, -.12826100E+00, -.20305900E+00, 0.21367600E+00, -.21220400E+01, -.14757700E+00, 0.44310300E+03, -.14079400E+03, -.22000200E+03, -.37629100E+03, 0.41533500E+03, 0.30601200E+03, 0.35205400E+03, -.37765800E+03, -.43123400E+01, 0.64806600E+00, 0.25025600E+01, 0.33860000E+01, -.34056700E+01, -.24445800E+01, 0.25426400E+00, 0.35985900E+01, -.12001200E+00, -.32656800E-01, -.18684300E-01, -.23607400E-01, 0.10473600E+00, -.49298000E-01, -.16818900E+00, -.33629600E-01, 0.76824100E-01, -.99402500E-04, -.21859900E-01, -.38954500E-01, 0.35796500E-01, 0.22726500E-01, -.88348600E+00, -.41838600E-01, 0.28437700E+02, -.21426500E+03, 0.53524300E+02, 0.42837200E+02, 0.64075700E+02, -.10137300E+03, 0.47613900E+02, 0.45366300E+02, 0.34783200E+03, 0.91540700E+02, -.87307800E+02, -.95752600E+02, 0.17977400E+02, 0.20887900E+03, 0.95907600E+02, -.83251500E+02, 0.31493900E+03, -.83458500E+02, 0.99145400E+00, -.21327600E+02, -.14050100E+03, 0.10319200E+03, -.62793800E+02, -.64204600E+01, 0.50609400E+02, -.18195500E+03, -.16883800E+03, -.19650600E+03, 0.30957500E+03, 0.47961400E+02, 0.23422900E+03, -.21667500E+03, 0.89053900E+03, -.65044500E+03, -.42594000E+03, -.58620700E+03, 0.49257800E+03, 0.52820100E+03, 0.63826800E+03, -.59423100E+03, 0.13191400E+02, -.84418800E+01, -.11781200E+02, -.15113300E+02, 0.21110200E+02, 0.86745800E+01, 0.14067400E+02, -.15689000E+02, 0.13178900E+04, -.63292200E+03, -.36940100E+03, -.55271600E+03, 0.32560600E+03, 0.64111800E+03, 0.44653400E+03, -.53861100E+03, -.55394700E+03, 0.44436800E+03, 0.23659900E+03, 0.25974000E+03, -.20415500E+03, -.26246200E+03, -.64786900E+02, 0.25095800E+03, -.16704400E+01, -.31598600E+02, 0.13079400E+00, -.94514500E+01, 0.49374400E+02, 0.42818500E+02, -.18150500E+02, 0.57239900E+02, 0.44780000E+00, 0.15305400E+03, -.97065300E-03, 0.38546500E+00, -.10063600E+00, -.25067300E+02, 0.36980200E+01, 0.32139900E+02, 0.59232600E+02, 0.32638400E+03, -.43934900E+01, -.33752700E+03, 0.50322500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16293600E+01, -.12471600E+01, -.31230100E+00, -.26007100E+00, 0.89112700E+00, 0.15102900E+00, -.29889100E+00, -.75165300E+00, 0.14241300E+00, 0.48609600E+00, 0.28121500E+00, -.13077000E+01, 0.24555700E+01, 0.17473500E+00, 0.21309700E+01, 0.55696300E+00, 0.61210500E+00, -.13256500E+01, -.39228400E+00, -.21277400E+01, -.96070900E+00, 0.46926900E+00, 0.28092500E+01, 0.16671400E+00, -.53929100E+00, -.15418600E+00, -.55866500E-01, 0.23492000E+00, -.96948600E+00, 0.62438000E+00, 0.27549700E+03, -.94308000E+02, 0.50030400E+03, -.51063700E+03, -.65199500E+02, -.75979900E+02, -.53558800E+03, -.65127600E+02, -.36164300E+03, -.17037400E+03, -.14651900E+03, -.47681400E+02, -.20166300E+03, -.13012700E+03, 0.19638700E+03, -.30791700E+03, -.12044500E+03, -.19664500E+03, 0.96569600E+02, -.11007500E+03, -.20449800E+03, -.17674700E+03, 0.12689100E+03, 0.26569800E+03, -.94498400E+02, -.12100400E+03, 0.36622700E+01, -.19467400E+01, -.18663400E+00, -.10530900E+01, -.74179900E+00, -.77351400E+00, 0.22992000E+01, -.11106200E+01, -.64501900E+02, 0.58187200E+03, 0.18267700E+02, -.27215900E+02, -.50481000E+01, 0.35959000E+03, 0.62490700E+03, -.15465100E+02, -.53386700E+01, 0.32436100E+01, -.16803400E+01, -.92228400E+00, 0.26547000E+01, 0.28451100E+00, -.52842800E+01, -.16150700E+01, -.26081600E-01, -.67739900E-02, 0.11552400E+00, 0.15551200E+00, -.11986400E+00, 0.93451600E-01, 0.35445100E+00, 0.19268800E+00, -.46376400E+00, 0.21368200E+00, 0.13714200E+00, 0.19265900E+00, 0.10927200E+00, -.26927900E-01, 0.16043300E+01, 0.22557200E+00, -.31938600E+03, -.29888100E+03, 0.46225200E+02, -.30985100E+02, -.34281200E+03, 0.15835000E+03, -.90168900E+02, -.10239400E+03, -.10062100E+04, 0.23942500E+03, -.89019700E+02, -.20267800E+03, 0.37550200E+03, -.35214100E+03, 0.45965100E+03, -.25358200E+03, 0.29151900E+03, -.99620700E+02, -.21529200E+03, -.22475600E+03, 0.10018400E+03, 0.23455300E+03, -.28424500E+02, -.24266800E+03, -.33980300E+02, 0.29131500E+03, 0.31266700E+03, 0.40282100E+03, -.20510900E+03, 0.16658700E+03, 0.15307800E+03, 0.49747100E+03, -.95390200E+03, 0.32555500E+03, 0.24478600E+03, 0.21493700E+03, -.38869100E+01, -.27480500E+02, 0.46329500E+03, 0.24202900E+03, -.14533300E+01, -.58091900E+00, 0.90373900E+01, 0.92668900E+01, -.16184500E+02, 0.43171700E+01, 0.86758700E+01, 0.11241700E+02, -.28968900E+03, 0.47011600E+03, 0.12300500E+03, 0.87151700E+02, -.28391400E+02, 0.20637300E+03, 0.46327000E+03, 0.92716500E+02, -.39135100E+03, 0.96033200E+02, -.22921300E+02, 0.10839700E+03, 0.17628800E+03, 0.18326600E+03, 0.38193400E+02, 0.11698000E+03, -.42719900E+00, -.22179000E+02, -.56124600E+00, 0.30298900E+02, 0.13267400E+02, 0.31072000E+02, 0.10830400E+02, 0.12581600E+03, -.88894500E+00, 0.11233600E+02, 0.83046500E+00, -.71035000E+00, -.16264300E+00, -.79899900E+02, -.62245900E+02, 0.20665100E+02, 0.78488600E+02, -.80266400E+02, 0.67263400E+00, 0.33405700E+02, -.74289600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22755000E+00, -.39405900E-01, -.66197700E-01, -.11067400E+00, 0.68391300E-01, -.98941000E-01, 0.10289700E+00, -.74026400E-01, -.22122000E-01, -.30361900E-01, -.27407400E-01, 0.25417100E-01, -.66656500E-01, -.39897700E-02, -.31067300E-01, 0.64801300E-01, 0.10155200E-02, -.38610200E-01, -.60162200E-01, -.23195000E-01, -.83096900E-01, -.33204800E-01, -.16214600E+00, 0.19065200E-02, 0.13065200E-01, -.11883200E-01, 0.10408800E-01, -.63730900E-01, 0.87324900E-01, 0.74738400E-01, 0.41893300E-01, 0.69825000E+01, 0.84108400E+01, 0.21085000E+02, -.33721400E+01, -.41879300E+00, 0.18129400E+02, 0.89928000E+01, 0.84604400E+01, 0.22095700E+01, -.34252600E+01, 0.24221200E+01, 0.12204700E+02, 0.72789700E+01, -.13502700E+02, 0.87999300E+01, 0.89525800E+01, 0.96193500E+01, 0.64519900E+02, -.81755700E+01, -.89117300E+01, -.17158700E+02, -.30373100E+01, 0.15427700E+02, 0.21222300E+01, -.25774100E+02, -.16803400E+00, 0.67831000E-01, 0.52530500E-02, 0.47839100E-01, 0.35111000E-01, 0.35716600E-01, -.15934800E+00, -.80750800E+00, -.26647700E+01, -.24195800E+02, -.52901000E+01, -.62215100E+01, 0.12022100E+02, -.12916200E+02, -.10973300E+02, -.12900200E+02, 0.34614000E+00, -.86945000E-01, 0.11141000E+00, 0.92621700E-01, -.23112100E+00, 0.71747700E-02, 0.22360800E+00, 0.13292200E+01, -.26587500E-03, 0.49166200E-02, -.37797800E-02, -.50042400E-02, 0.40696500E-02, -.49538800E-02, -.20114800E-01, -.99595500E-01, 0.14983900E-01, -.13214600E-01, -.65263300E-02, -.80687200E-02, -.78644600E-03, -.11033300E-02, -.86153400E-01, -.35016200E+00, 0.25909900E+02, 0.27547700E+02, -.77374400E+01, -.50182700E+00, 0.14633700E+02, -.13418400E+01, -.32768700E+01, 0.25669100E+00, 0.27661500E+02, -.36718600E+02, 0.65410700E+01, 0.13658600E+02, -.12445800E+02, 0.81718700E+01, -.19681600E+02, 0.20593100E+02, -.17565800E+02, 0.39804600E+01, 0.77338100E+01, 0.74088500E+01, -.19906500E+01, -.92504100E+01, 0.83362700E+00, 0.55137300E+01, -.22039400E+01, 0.10525700E+01, -.12182700E+02, -.15932200E+02, 0.81187600E+01, -.97228000E+01, -.37023300E+01, -.17486000E+02, 0.18171700E+02, 0.76324200E+00, -.15600100E+02, -.17526500E+02, 0.15506900E+02, 0.30310900E+01, 0.76540100E+01, -.23789400E+02, -.30469700E+00, 0.11188500E+00, -.45675100E+00, -.54053900E+00, 0.94737300E+00, -.22844400E+00, -.76648800E-02, -.19547900E+01, 0.10547800E+02, -.15029000E+02, -.10864500E+02, -.13225300E+02, 0.14708500E+02, 0.55269900E+00, 0.87313800E+01, -.18078500E+02, -.64817000E+01, -.15640500E+01, 0.70917700E+01, 0.29175000E+01, -.91817200E+01, -.13929900E+02, -.13093100E+01, 0.66948000E+01, 0.27082300E-02, 0.28990700E+01, -.12670600E-01, 0.23347600E+00, 0.60294800E+01, -.61740900E+01, -.56673300E+00, -.16059100E+01, -.49893500E-01, 0.77176300E+01, 0.13600100E+00, 0.10140900E-01, -.26502700E-01, 0.66167300E+01, 0.19759300E+01, 0.10447400E+01, -.42873700E+01, 0.87079700E+01, -.31352800E+00, -.11288100E+02, 0.19281200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.39012700E+00, -.16638800E+00, 0.25951100E+00, 0.10767100E+01, -.11434300E+00, 0.36453900E-01, -.28391300E+00, -.15382200E+00, -.51453300E+00, 0.13891800E+00, -.28202100E-01, -.40116600E+00, 0.10131000E+00, 0.33034900E-01, 0.14968500E+00, 0.34084000E-01, -.64578500E-01, 0.33802600E+00, -.19966300E+00, 0.44300300E+01, -.15931700E-01, 0.12121300E+00, 0.39591600E+00, 0.29972400E-01, 0.42673300E-02, -.56756400E-01, 0.54103300E-01, -.52288800E-01, 0.49617300E-01, 0.11885300E+00, -.21393000E+00, -.15064800E+01, 0.14735500E+03, -.18027100E+03, -.10271800E+02, 0.17863300E+02, -.15969300E+03, -.50386600E+02, -.15438200E+03, -.32545400E+00, -.40048300E+02, -.28759400E+02, -.55792200E+02, -.46467300E+02, 0.72210900E+02, -.48890000E+02, 0.96704600E+01, -.51909500E+02, 0.18201900E+03, -.62697900E+02, -.95377100E+02, -.99815200E+02, 0.56472800E+02, 0.11711000E+03, 0.62935900E+02, -.11270800E+03, 0.14685100E+01, -.50150800E+00, -.22481000E+00, -.52368200E+00, 0.17835700E-01, 0.21510200E+00, 0.33470500E+01, -.17966900E+01, 0.12755900E+03, 0.96864300E+02, -.47620500E+01, -.46177500E+02, 0.18800400E+02, 0.16110500E+03, 0.20490100E+03, -.55388500E+02, -.22888100E+01, 0.99782900E+00, -.20721500E+00, 0.13294500E+00, 0.28929300E+00, -.59137600E+00, -.57121900E+01, 0.19331600E+01, -.17501200E-01, -.25595100E-01, 0.32074800E-01, 0.51336200E-01, -.37654700E-01, 0.14681400E-02, 0.34191100E+00, -.87964200E-01, -.14936400E+00, 0.61985400E-01, 0.65952900E-01, 0.83154200E-01, -.19343900E-01, -.43123200E-01, 0.13300000E+01, -.42896700E+00, -.18115200E+02, -.13702300E+03, -.89176900E+01, -.50956300E+01, -.10769900E+03, 0.33745300E+02, -.10046500E+03, -.19901600E+02, -.47527700E+03, 0.13588700E+03, 0.51226100E+02, 0.42324900E+02, 0.24298700E+02, -.18619800E+03, -.10904800E+02, 0.47445100E+02, 0.14249700E+03, -.31011800E+02, -.74881500E+02, -.10039400E+03, 0.67318700E+02, 0.11262400E+03, 0.82058000E+02, -.96840400E+02, 0.23172500E+02, 0.35773500E+02, 0.60946900E+02, 0.94325000E+02, -.50030500E+02, 0.45448400E+02, 0.59153000E+02, 0.10003600E+03, -.25574400E+03, 0.89049100E+01, 0.18577100E+02, -.10494700E+02, 0.78544300E+02, 0.50402600E+02, 0.24934600E+03, -.25429000E+02, 0.64308800E+00, -.16560000E+01, 0.12140500E+01, 0.16358700E+01, -.25066400E+01, 0.15954800E+01, 0.82741400E+01, -.77329300E+00, 0.66470000E+02, 0.50527100E+02, 0.20583600E+02, -.23285400E+02, 0.13556700E+02, 0.13625700E+03, 0.16991700E+03, -.31388500E+02, -.21140500E+02, 0.20712100E+02, -.76693900E+01, 0.25068400E+02, 0.43720100E+02, 0.87373000E+01, -.99609600E+02, 0.39504100E+02, -.32964800E+00, -.37226300E+01, -.52953600E+00, 0.16046100E+02, -.96709500E+01, -.53061900E+00, 0.17496700E+02, -.22268000E+02, -.10565000E+01, 0.16498600E+02, 0.10467800E+01, -.61389700E+00, -.16192200E+00, -.12222600E+01, -.32130100E+02, -.14039200E+02, 0.18015100E+02, 0.50901900E+01, -.11902400E+01, -.20610100E+02, -.26774500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.39595200E+01, 0.11339700E+01, 0.44043000E+00, 0.15288600E+01, -.76599400E+00, 0.18451500E+00, 0.24923300E+01, -.10697100E+01, 0.99011000E+00, 0.21890500E+01, -.64637800E+00, 0.14140800E+01, 0.51617600E+01, 0.22654200E+00, 0.30749400E+01, 0.25259700E+00, 0.31344600E+00, 0.62539900E+00, 0.19432800E+01, -.10550600E+02, 0.10803900E+01, 0.24541700E+00, -.23894600E+01, -.31122100E+00, -.20989900E+00, -.51228300E+00, 0.10168800E+01, 0.10086900E+01, -.18707200E+01, 0.13082300E+01, -.76665900E+00, -.13427600E+02, 0.85987100E+01, 0.10996200E+04, -.57689900E+02, -.11428300E+03, 0.58806500E+03, 0.39820000E+03, 0.48724300E+03, -.25509900E+02, 0.71854800E+02, 0.29210600E+03, 0.34718400E+03, 0.29370900E+03, -.42404700E+03, 0.41235700E+02, -.75439300E+02, 0.26805400E+03, -.23992800E+01, 0.58575000E+03, 0.37683200E+03, 0.26954700E+03, -.45391900E+03, -.24408300E+03, -.32451600E+03, 0.32652900E+03, -.86219200E+01, 0.31159900E+01, 0.13167800E+01, 0.35406500E+01, -.96189200E+00, -.26307000E+01, -.34398100E+02, 0.29552200E+01, -.10510200E+04, -.45812000E+03, 0.13550000E+02, 0.23063100E+03, -.16998800E+03, -.92740600E+03, -.11812500E+04, 0.26698800E+03, 0.15995700E+02, -.47513400E+01, -.20887500E-01, -.20068200E+01, 0.99742200E+00, 0.56404000E+01, 0.55383000E+02, -.21093700E+01, 0.16970300E+00, 0.17579000E+00, -.12746800E+00, -.27757500E+00, 0.15664700E+00, 0.11514000E+00, -.33607100E+01, -.28669600E+00, 0.76404500E+00, -.58812200E+00, -.39570000E+00, -.50757200E+00, 0.26764400E+00, 0.36173700E+00, -.12802600E+02, -.65057300E+00, 0.47272500E+03, 0.12824200E+04, -.64785300E+02, 0.16295000E+02, 0.50299500E+03, -.71490400E+02, 0.32569400E+03, 0.55804300E+02, 0.26817600E+04, -.16553100E+04, -.47702800E+03, -.33841800E+03, 0.12437900E+03, 0.94629800E+03, 0.21579100E+03, -.38160400E+03, -.11408500E+04, 0.38106100E+03, 0.44146000E+03, 0.68302800E+03, -.44212800E+03, -.82004900E+03, -.76880500E+03, 0.60361200E+03, -.26536400E+03, 0.11596300E+03, -.11428100E+03, -.40608900E+03, 0.87259300E+02, -.21664200E+03, -.39792400E+03, -.34065100E+03, 0.99665000E+03, 0.12905700E+03, 0.11961900E+03, 0.33182800E+03, -.83504700E+03, -.55967700E+03, -.19309000E+04, 0.43986400E+03, -.12284300E+02, 0.11446000E+02, 0.32158400E+00, -.55085600E+01, 0.13449300E+01, -.10586700E+02, -.73345500E+02, -.25939500E+00, -.65938300E+03, -.10433400E+03, -.17038100E+03, 0.12593700E+03, -.19661700E+03, -.78518600E+03, -.10285400E+04, 0.15689000E+03, 0.97185600E+02, -.34250800E+03, -.10885100E+03, -.32886300E+03, -.20046800E+02, 0.34221600E+03, 0.10855300E+04, -.37774000E+03, 0.29173300E+01, 0.74225800E+02, 0.44724700E+01, -.93575800E+02, 0.10826200E+03, -.10205600E+03, -.13861900E+03, 0.15281600E+03, 0.89884600E+01, -.84558100E+02, -.73746100E+01, 0.54499900E+01, 0.10446900E+01, 0.89978400E+02, 0.21202900E+03, 0.17248600E+03, -.12207100E+03, -.21634600E+03, 0.92449400E+01, 0.15115100E+03, 0.91343100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.65330000E+01, 0.23183300E+01, 0.25773600E+01, 0.83088300E-01, 0.84131500E+00, -.94910700E+00, -.43156200E+00, 0.47236200E+00, -.12521700E+01, -.20684600E+01, 0.18280400E+00, -.24243600E+01, -.15518300E+01, -.99185500E-01, -.61991600E+01, -.35728100E+01, -.16038500E+01, 0.29373600E+01, 0.10500700E+01, 0.82403900E+00, 0.44990700E+01, 0.63360800E+01, 0.72240500E+01, -.14473100E+01, -.31809700E+01, 0.59160300E-01, -.17103300E+01, -.26620800E+01, 0.33972700E+01, 0.21955400E+00, 0.11622900E+00, 0.27142600E+02, 0.49504400E+00, 0.89067300E+00, 0.12008100E+04, 0.11026600E+04, -.18950000E+04, -.81350600E+03, -.16002200E+04, 0.11560700E+04, 0.11374200E+04, -.88629300E+03, -.83389700E+03, -.90898300E+03, 0.85491100E+03, 0.41422100E+03, 0.21109400E+03, -.88776400E+03, -.47269300E+04, -.92745100E+02, 0.89279900E+03, 0.11846500E+04, 0.29662700E+03, -.14080000E+04, -.40259700E+03, 0.12048500E+04, 0.44386000E+01, -.80994300E+01, -.11108300E+01, -.30131500E+01, 0.19175300E+01, -.37631100E+00, 0.54058000E+02, 0.21323600E+02, -.17995400E+04, 0.11695500E+04, 0.13861000E+04, 0.12848000E+04, -.72413200E+03, -.52717200E+03, -.22584300E+03, 0.13589400E+04, 0.50247900E+01, -.88176500E+00, -.10664300E+02, -.97794500E+01, 0.64874800E+01, 0.71381900E+01, -.73550000E+02, -.42802700E+02, 0.19026100E+00, 0.26234800E+00, 0.13655300E+00, 0.27763400E+00, -.31398200E+00, 0.72877900E-01, 0.51579700E+01, 0.28719200E+01, -.10032300E+01, 0.13573400E+01, 0.36674000E+00, 0.65954700E+00, -.34826200E+00, -.33490400E+00, 0.20134400E+02, 0.10260000E+02, -.69573600E+03, 0.12256000E+02, 0.85765700E+03, 0.59793300E+03, -.13557800E+04, -.12582000E+03, -.76836100E+03, 0.74550000E+03, -.18136200E+04, 0.34763100E+04, 0.36455800E+03, 0.28456700E+03, -.48117200E+03, -.64923800E+03, -.12988800E+03, 0.24408400E+03, 0.43691500E+03, -.10214800E+04, -.39199900E+03, -.64041600E+03, 0.72593400E+03, 0.62451500E+03, 0.12231400E+04, -.48326600E+03, 0.38439800E+03, -.20550000E+03, 0.58430500E+03, 0.81481500E+03, -.73475500E+03, 0.20550700E+03, -.32210300E+03, 0.71752800E+03, -.14537900E+04, 0.10432500E+04, 0.64092300E+03, 0.17943200E+03, 0.19370900E+03, 0.31415500E+03, 0.12953700E+04, 0.21426500E+03, -.36332600E+02, 0.31426100E+02, 0.50426900E+02, 0.50041400E+02, -.48982300E+02, -.21448600E+02, 0.37281100E+02, 0.81184600E+02, -.13396300E+04, 0.11759600E+04, 0.13490300E+04, 0.10959600E+04, -.63991800E+03, -.43377100E+03, -.39392000E+03, 0.11773100E+04, 0.93167500E+03, -.42560000E+03, -.34196800E+03, -.35480600E+02, 0.42745500E+03, 0.30294100E+02, -.10782700E+04, -.69866000E+02, 0.97696600E+00, -.20210200E+03, -.53817700E+01, -.83433000E+01, -.36205900E+03, 0.52582000E+03, 0.57278600E+02, -.18308400E+03, -.11045300E+02, -.75791400E+03, 0.44510400E+01, -.79047500E+01, -.25263300E+00, -.29532800E+03, -.19022700E+03, -.39361200E+03, 0.63931200E+02, -.13121200E+03, 0.11976400E+02, 0.67969200E+03, -.17463300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19246700E+01, -.30797600E+00, -.45863500E+00, 0.44826800E+00, 0.31385900E+00, 0.18961700E+00, 0.13389600E+01, -.16649500E+01, 0.43853300E+00, -.22569900E+00, 0.53240900E+00, -.65194700E+00, -.60007800E-01, -.26892400E-01, 0.11085300E+01, 0.13444900E+00, 0.42551400E+00, -.61944900E+00, -.74951400E-01, 0.50454800E+01, -.13571600E-02, -.11047100E+01, -.65955600E+00, 0.29490900E+00, -.67591900E-01, 0.52709800E-01, -.93923200E-01, 0.86045600E+00, -.47621000E+00, -.16355500E+00, 0.34032200E+00, 0.50805300E+01, -.30748600E+01, -.15689400E+00, 0.63777200E-01, -.21159100E+03, 0.72494600E+02, 0.57941100E+02, 0.15028200E+03, -.24834300E+03, -.43579800E+02, -.53479300E+02, -.86365100E+02, -.67046900E+02, 0.14718000E+03, -.79172000E+02, 0.73452100E+02, -.62540700E+02, 0.47305800E+03, -.55075300E+02, -.16920500E+03, -.18975800E+03, 0.42365500E+02, 0.18946500E+03, 0.10452100E+03, -.20816300E+03, 0.71488600E+00, -.35640700E+00, -.16590300E+00, -.50205600E+00, 0.42894600E+00, -.10717400E+00, 0.37833300E+01, -.17302500E+01, 0.32112000E+03, -.16820400E+01, 0.11201500E+02, 0.96444000E+01, -.17714500E+03, 0.18734300E+03, 0.82866500E+02, 0.25406900E+01, -.94365000E+00, 0.10591600E+01, -.50200400E+00, -.36492800E+00, 0.10929100E+01, 0.64154300E-01, -.49185800E+01, 0.14918100E+01, 0.53716200E-02, -.20031200E-01, 0.16734600E-01, 0.22262400E-01, -.42233200E-01, 0.25387300E-01, 0.33881300E+00, -.11694400E+00, -.68341100E-01, -.99074400E-02, 0.36720000E-01, 0.95584700E-01, -.95917800E-01, -.18057200E-01, 0.13562500E+01, -.38654900E+00, -.32990500E+03, 0.17445500E+03, 0.15338700E+03, -.10536500E+02, -.45256700E+01, 0.31496900E+02, 0.99877100E+02, -.42558900E+02, -.40935300E+03, -.10134900E+03, 0.80503500E+02, 0.45594800E+02, 0.21837100E+01, -.19347400E+03, -.37042800E+02, 0.55974200E+02, -.94199800E+01, 0.60399300E+02, -.32997000E+02, -.24766100E+02, 0.91121200E+02, 0.53805500E+02, 0.11490800E+03, -.14891400E+02, -.11744600E+02, 0.10266300E+03, 0.52219900E+02, 0.77755600E+02, -.11531000E+03, 0.49582100E+02, -.65392200E+02, 0.64169500E+02, 0.36766300E+03, -.39698800E+02, 0.41014300E+02, 0.40013600E+02, -.20258300E+03, 0.16157600E+03, -.10403900E+03, 0.19555100E+02, -.17896900E+00, 0.10118600E+00, 0.36675500E+01, 0.14989100E+01, -.62330800E+01, 0.17083900E+01, 0.53252000E+01, -.18148800E+01, 0.46791600E+03, -.43070300E+02, 0.24023500E+02, 0.32047200E+02, -.22582000E+03, 0.22831800E+03, -.20835900E+02, 0.30870700E+02, 0.20728400E+03, -.15746400E+03, -.13442000E+03, -.95897100E+02, 0.12844500E+03, 0.16410400E+03, -.76638200E+02, -.73694900E+02, 0.25928800E+00, 0.25100900E+02, -.50601000E+00, 0.24043400E+02, 0.31302700E+02, 0.23810500E+02, 0.34375500E+02, 0.30634400E+01, -.10615600E+01, -.14888800E+02, 0.96386800E+00, -.62498000E+00, -.11783200E+00, -.95240100E+02, -.23466600E+02, -.31513700E+02, -.21773400E+02, -.82959800E+02, -.51549300E+00, 0.12043700E+03, -.49132900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15930400E+01, -.39009400E+00, -.37749700E+00, -.91509400E+00, 0.64446300E+00, -.78872500E+00, 0.40855500E+00, -.39076600E+00, -.72718500E+00, -.10968400E+01, 0.24615400E+00, -.82235600E+00, -.15929300E+01, -.46885500E-01, -.21235400E+01, 0.25000600E+00, -.38362600E+00, -.30831100E+00, -.99775100E+00, 0.67893500E+01, 0.21456300E+00, -.36849100E+00, -.24574600E+00, 0.36069900E+00, 0.11483600E+00, -.15492700E+00, 0.19992400E+00, 0.14043900E+00, 0.36383900E+00, 0.60740600E-02, 0.43008100E-01, 0.59275700E+01, 0.85141300E+00, 0.87284300E-01, 0.10382300E-01, 0.56418800E+00, 0.20666000E+03, 0.76836700E+02, 0.11132400E+03, 0.69532000E+02, 0.21570700E+03, -.54231900E+02, 0.76223800E+02, 0.76319200E+02, -.21848800E+03, 0.10714900E+03, -.13954200E+03, 0.83724300E+02, -.62268300E+03, 0.83126700E+02, 0.19479100E+03, 0.25043300E+03, -.16187200E+02, -.28128300E+03, -.10344800E+03, 0.27917500E+03, -.39540400E+00, 0.71060800E-01, 0.57528600E-01, 0.19796700E+00, -.44295500E-01, 0.41569400E+00, 0.24564300E+01, 0.68568800E+01, 0.22771000E+01, -.50106700E+02, 0.83117600E+02, 0.13269900E+03, 0.19663000E+02, -.98583500E+02, -.76039300E+02, 0.19541300E+03, -.88353500E+00, -.15909900E+00, 0.13468800E+01, 0.13043700E+01, -.25686600E+01, -.11464400E+01, -.48964800E+01, -.79672700E+01, -.82262800E-01, 0.23946400E-01, -.42933200E-01, -.62626600E-01, 0.12238600E+00, -.37603200E-01, 0.30748000E+00, 0.65644300E+00, 0.88404400E-01, 0.26149000E-01, -.44140400E-01, -.64465300E-01, 0.37616000E-01, -.23003000E-01, 0.82509700E+00, 0.25751900E+01, 0.13526100E+03, -.78381300E+02, -.28078200E+02, -.39224800E+02, 0.13124400E+03, 0.51929000E+02, 0.12131800E+03, 0.25463200E+02, 0.23887900E+03, 0.23609600E+03, -.36200600E+02, -.36553800E+02, -.28883600E+02, 0.10924800E+03, -.32272200E+02, -.53618000E+02, 0.30303500E+03, -.14160800E+03, 0.42318300E+02, 0.62299300E+02, -.20077300E+03, 0.56899700E+02, -.12080600E+03, 0.80518400E+02, -.23489200E+02, -.11241600E+03, -.16579300E+03, -.20493200E+03, 0.31642100E+03, -.40213700E+01, 0.17792500E+03, -.23397600E+03, 0.10654500E+04, -.33240600E+03, -.12554600E+03, -.17069800E+03, 0.69449600E+02, 0.33038700E+03, 0.69383000E+02, -.90430100E+02, 0.81600400E+01, -.14746700E+01, -.50844600E+01, -.62340200E+01, 0.13429200E+02, 0.37764700E+01, 0.10381400E+02, 0.49277300E+01, 0.35526600E+03, -.18266100E+03, 0.36431100E+02, 0.56702800E+02, -.35581000E+01, -.12125900E+01, -.11367800E+03, 0.11573300E+03, -.81726500E+03, 0.45187600E+03, 0.18593100E+03, 0.24378800E+03, -.13611200E+03, -.39926700E+03, -.56456600E+02, 0.17124200E+03, -.13283400E+01, -.33014200E+02, -.98169500E-01, -.27471600E+02, -.50235800E+02, 0.24547600E+02, -.39118800E+02, -.19705600E+02, 0.37671200E-03, -.75368100E+02, -.62920800E+00, -.15883900E+00, 0.43066900E-01, -.11352400E+01, -.40019200E+01, 0.28176000E+02, 0.45070500E+02, 0.15285100E+03, -.54435800E+00, 0.51520900E+02, 0.80666900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25985700E+01, -.13202700E+01, 0.37305900E-01, -.45644300E+00, 0.57859500E+00, -.45981600E+00, 0.12530900E+00, -.32361700E+00, -.29806200E+00, 0.79438900E+00, -.49630900E+00, -.21366600E+01, 0.49565000E+01, 0.38959800E+00, -.42802000E+00, -.32124000E+00, -.65446200E-01, -.17851700E+00, -.31632600E+00, 0.66123600E+01, 0.46133400E+00, -.50095300E+00, -.47248400E+00, -.21469800E+00, 0.50107800E+00, -.98490100E-01, 0.45694900E+00, -.34714600E+00, -.83256900E+00, 0.39869400E+00, 0.29302800E+00, -.57913600E+00, -.17066500E+01, -.26044400E+00, -.70127500E-01, -.76110200E+00, -.17740500E+00, -.13120400E+03, -.30881000E+03, 0.11546100E+01, 0.74025200E+02, 0.78855300E+02, -.16100600E+01, 0.86648000E+01, -.13520700E+03, 0.11644500E+02, -.11113600E+03, -.21146900E+02, 0.64685200E+03, 0.32156700E+03, -.13975900E+03, -.15939800E+03, -.53997700E+02, 0.18869000E+03, -.35895300E+02, -.17647000E+03, 0.28243000E+01, 0.30716100E+00, -.90869500E-01, -.36707500E+00, -.63640400E+00, 0.90424600E+00, 0.60649600E+01, -.12597000E+01, 0.30330800E+03, -.44182200E+01, -.71563800E+02, -.46132200E+02, 0.82343000E+01, 0.20154600E+03, 0.38499600E+03, -.32127000E+01, -.47342900E+01, 0.18968500E+01, 0.11192300E+01, 0.14400500E+01, -.17906400E+01, -.16553200E+01, -.11892700E+02, 0.22750500E+01, -.14675700E+00, -.67440400E-01, 0.48522600E-01, 0.45472500E-01, 0.53049900E-01, -.36835600E-01, 0.85265200E+00, -.23689400E-01, -.29021300E+00, -.10900200E+00, -.13658000E-01, 0.31174000E-01, 0.13031600E+00, -.13589600E+00, 0.27613400E+01, -.29680400E+00, -.31048600E+03, 0.25239700E+03, 0.71145200E+02, 0.76844600E+01, 0.33401500E+02, 0.49026500E+02, -.88556100E+01, 0.64453900E+01, -.90952600E+03, -.28214400E+03, 0.24079800E+02, 0.95451400E+02, 0.14792900E+03, -.42934200E+03, -.22759900E+03, 0.92543000E+02, 0.64758300E+03, -.41464400E+02, -.10447200E+03, -.96193200E+02, -.16340500E+03, 0.27728200E+03, -.16739100E+03, -.11002500E+03, -.11146000E+03, 0.10220900E+03, -.54913100E+02, -.71140900E+02, 0.31839700E+03, 0.52038700E+02, 0.41902100E+03, -.32071100E+02, 0.58974200E+03, -.23130500E+03, 0.59282900E+02, 0.53009400E+02, -.71922500E+02, 0.24263900E+03, 0.24977000E+03, 0.14736900E+03, 0.50122700E+01, -.54359700E+01, 0.96692300E+00, -.10119600E+01, 0.55857300E+01, 0.34099400E+01, 0.25832100E+02, 0.83733500E-01, 0.44440700E+03, -.92731000E+02, 0.85684900E+01, 0.75019000E+02, -.13022700E+03, 0.16997800E+03, 0.17152800E+03, 0.12872900E+03, -.13075600E+04, 0.54919200E+03, 0.18732800E+03, 0.32694900E+03, -.55595800E+02, -.45413500E+03, -.23428700E+03, 0.27401900E+03, -.22296300E+01, -.11035100E+02, -.12143100E+01, 0.34271200E+02, -.50661500E+02, 0.23345200E+02, 0.12613500E+02, -.72112200E+02, -.21479700E+01, 0.60803700E+02, 0.20831500E+01, -.12662900E+01, -.51825200E+00, -.64850400E+02, -.82584700E+02, 0.76445600E+02, 0.87622800E+02, 0.62194600E+02, -.32860200E+01, 0.53487900E+02, 0.51695100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.75217400E+00, -.35422300E+00, 0.12856500E+00, 0.12254400E+01, -.39657000E-01, 0.28358900E+00, -.97949100E+00, -.24563600E+00, -.55020700E+00, 0.79819600E-01, 0.53784300E-02, -.10943200E+01, 0.18374700E+00, -.28968700E-01, 0.51660300E+00, 0.63244400E-01, 0.10855000E+00, -.40292500E+00, 0.11925300E+00, 0.55534800E+00, -.12035300E+00, 0.89474900E-01, 0.11164400E+01, 0.55502900E-01, -.27096000E+00, 0.17832000E-01, -.13124100E+00, 0.82915200E-01, -.26072000E+00, -.39198800E+00, -.13280800E+00, -.16471000E+01, 0.80143400E+00, 0.15128200E-01, 0.24209700E-01, 0.55207000E-01, 0.21633000E+00, 0.19839500E+00, 0.87379600E+02, -.23447100E+02, -.13550100E+03, -.26501700E+02, 0.47119200E+01, 0.20411400E+02, 0.46166800E+02, -.82070000E+02, 0.20643800E+02, 0.24795100E+02, -.24793100E+03, -.53359500E+02, 0.34167800E+01, -.18309900E+02, 0.92123000E+02, -.21775700E+02, 0.98597400E+02, -.23320800E+02, -.63305300E+00, -.10248300E+00, 0.11975000E-01, 0.58060500E-01, 0.29220800E-01, -.52670900E+00, -.41838000E+01, -.21219300E+01, 0.53977600E+02, 0.94830200E+01, -.82597600E+02, -.16511500E+03, 0.14170100E+03, 0.11382300E+03, 0.11042500E+03, -.18379500E+03, 0.77092700E+00, 0.15372400E+00, -.17065000E-01, 0.22461400E+00, 0.35617200E+00, 0.41440400E+00, 0.63651800E+01, 0.32887900E+01, 0.38678200E-01, 0.94467100E-02, 0.31077800E-02, 0.54219200E-02, -.34915500E-01, 0.21045200E-01, -.48191800E+00, -.23151400E+00, 0.71530900E-01, 0.39590100E-02, 0.79060700E-02, -.19492500E-02, -.10000600E-01, 0.65886100E-01, -.16290100E+01, -.85772700E+00, 0.51351200E+02, -.59316800E+02, 0.35700400E+01, 0.27427400E+02, -.29909300E+02, -.23686400E+02, -.30609200E+02, 0.58774300E+01, 0.28103900E+03, -.53819300E+02, -.66539600E+02, -.79251400E+02, 0.34219700E+02, 0.13451900E+03, 0.15011400E+03, -.78194000E+02, -.19032100E+03, 0.57900100E+02, 0.88305700E+01, 0.47923800E+01, 0.58253300E+02, -.59198900E+02, 0.26591000E+02, 0.16233200E+01, -.67535400E+01, 0.35033800E+02, 0.45016000E+02, 0.47713100E+02, -.11288100E+03, -.12201900E+02, -.11027500E+03, 0.47515300E+02, -.32441400E+03, -.38276400E+01, -.81806500E+02, -.13061900E+03, 0.14826900E+03, -.26905300E+02, 0.11564700E+03, -.17582900E+03, -.89993100E+00, -.84064400E+00, -.17415000E+01, -.25817700E+01, -.86564000E-01, 0.70393900E+00, -.68986100E+01, -.63031900E+01, 0.24485600E+03, -.10713600E+03, -.13965900E+03, -.22943000E+03, 0.13940200E+03, 0.21431500E+03, 0.18822000E+03, -.24360700E+03, 0.50173200E+03, -.18415400E+03, -.50322800E+02, -.95178600E+02, -.24206700E+02, 0.25537300E+03, 0.14268000E+03, -.59709300E+02, 0.67873600E+00, 0.47483000E+01, 0.52292600E+00, -.46083100E+01, 0.22480800E+02, -.65668100E+01, -.23042800E+01, 0.20425100E+02, 0.96520300E+00, 0.58251900E+02, -.52300400E+00, 0.64973400E+00, 0.12379400E+00, 0.11407100E+02, 0.25759000E+02, -.88438000E+01, -.24549900E+02, 0.40471100E+02, -.62910900E-01, -.14312000E+03, -.21001100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.21126400E+01, -.22265000E+00, -.34795400E+00, -.19972300E+01, 0.12352600E+01, -.11663900E+01, 0.10530600E+00, -.32054500E+00, 0.70505900E+00, 0.42936700E+00, 0.20191800E+00, -.11997000E+01, 0.15538500E+01, 0.14758600E+00, 0.29947200E+01, -.81490300E-01, 0.63075800E+00, 0.90413000E+00, 0.27254400E+00, 0.38530200E+01, 0.87152900E+00, -.36369300E-01, 0.30028300E+00, -.15542400E+00, 0.21795400E+00, 0.37367100E-01, -.28366900E+00, -.68017100E+00, 0.76140600E+00, -.72694500E-01, -.17589400E+00, 0.49932700E+01, -.83353900E+00, -.20300100E+00, -.22141000E-01, 0.18832900E-01, -.29824800E+00, -.62546400E-01, -.60029600E+00, 0.51197200E+02, 0.62131500E+02, 0.25393800E+02, 0.10018900E+02, -.36036800E+01, -.70850700E+01, 0.87808900E+01, -.14481100E+02, -.99682800E+01, -.54433900E+03, 0.13536300E+03, 0.15008800E+03, 0.20204100E+03, -.50594200E+02, -.20689600E+03, -.10355200E+03, 0.23170700E+03, -.19765000E+00, -.19743500E-01, 0.24538600E+00, 0.22503300E+00, -.29684100E+00, -.42053400E+00, 0.58109300E+00, 0.45027100E+01, -.34596400E+02, -.69509200E+01, 0.36793100E+02, 0.10315800E+03, -.11400000E+03, -.49160000E+02, -.13224100E+03, 0.16334200E+03, -.14202100E-01, -.11407700E+00, -.38167400E+00, -.76066200E+00, 0.10014400E+01, 0.80551400E+00, 0.31561500E+00, -.70024700E+01, 0.10628400E-01, -.14145800E-02, -.99275700E-02, -.70564500E-02, 0.73938600E-02, 0.24472600E-01, 0.95332600E-01, 0.47144300E+00, 0.41750200E-01, 0.80605900E-02, -.38364500E-01, -.30083400E-01, 0.29394400E-01, 0.35775100E-01, 0.34084500E+00, 0.16858200E+01, -.10767900E+03, 0.10126900E+02, -.25308400E+02, -.42053900E+02, 0.75379200E+02, 0.30202600E+02, 0.13565500E+03, -.27105700E+00, 0.13253100E+03, 0.94060400E+02, -.36917300E+02, -.65943800E+02, 0.23254300E+02, 0.18388500E+02, 0.81422200E+01, -.96750500E+02, -.45344800E+02, 0.32979600E+02, 0.42970300E+02, 0.55301300E+02, -.57459800E+02, -.34386800E+02, -.54836800E+02, 0.57555500E+02, -.14348100E+02, -.29062500E+02, -.19494200E+02, 0.92320400E+00, 0.11835800E+02, 0.15239300E+02, -.36044300E+02, 0.64197000E+01, -.53329300E+01, 0.65901100E+02, 0.10087400E+03, 0.15618900E+03, -.14592300E+03, -.10014800E+03, -.24317900E+03, 0.21464700E+03, 0.32318800E+00, 0.57745900E+00, 0.15028200E+01, 0.26195100E+01, -.29163500E+01, -.10874000E+01, -.41092400E+01, 0.11029000E+02, -.13649600E+03, 0.63592600E+02, 0.68297400E+02, 0.13997400E+03, -.11736800E+03, -.13662700E+03, -.21783300E+03, 0.18960000E+03, 0.10611100E+02, -.21871400E+01, -.24398000E+02, -.12657700E+02, -.20413700E+02, 0.64230800E+02, 0.78078200E+02, -.44807700E+02, 0.18454400E+00, -.18623100E+02, 0.86060500E-01, -.44240500E+01, -.38349700E+02, 0.24883300E+02, -.56627900E+01, -.47022700E+01, 0.27995300E+00, -.60352400E+02, -.80567600E+00, -.18167300E-01, 0.12417100E+00, -.87389500E+01, -.81391800E+01, 0.57126600E+01, 0.65664400E+01, -.58539800E+02, 0.20007400E+01, 0.10241200E+03, 0.19624300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20672400E+00, 0.28949600E+00, -.48161300E+00, -.14036400E+01, 0.26986000E+00, 0.27520800E-01, -.33913700E+00, -.12667200E+00, 0.45236100E+00, 0.12687700E+00, -.36486300E-01, 0.36608500E+00, 0.36923300E+00, 0.11938600E-02, 0.87521200E+00, 0.95585600E-01, 0.30614900E-01, 0.38184300E+00, 0.14964800E+00, 0.23092700E+01, 0.13428600E+00, -.27891100E+00, -.11128100E-01, -.29758000E-01, -.23246600E+00, -.56142800E-01, -.85867800E-01, 0.31058600E+00, -.51552500E-01, 0.11775200E+00, 0.28102000E-01, 0.16793000E+01, 0.11844600E+01, 0.10953200E+00, -.35318600E-01, 0.16572400E+00, 0.11459500E+00, -.18191100E-02, 0.49815200E+00, 0.15318800E+00, 0.14554600E+03, 0.14713300E+02, -.32753400E+02, -.62790700E+02, 0.50020400E+02, 0.10758900E+03, 0.54571200E+02, -.56344900E+02, -.20194300E+03, 0.12542900E+03, 0.31709200E+02, 0.60100600E+02, 0.20321900E+02, -.91809300E+02, 0.22726900E+02, 0.63517000E+02, -.20366200E+00, 0.12443500E+00, 0.27838700E-01, -.31049400E-01, 0.26400900E+00, 0.18160700E+00, 0.55944200E+01, 0.36689000E+01, -.15374700E+03, -.22566300E+02, 0.95134300E+02, 0.17796200E+03, -.15102300E+03, -.17510200E+03, -.21988400E+03, 0.18834300E+03, 0.68289000E+00, -.73038400E+00, -.51206900E+00, -.90003200E+00, 0.58486600E+00, 0.42228300E+00, -.66528500E+01, -.59654200E+01, 0.14424100E-01, -.78679500E-02, -.15367000E-01, -.69373200E-02, -.22439300E-02, -.13852600E-01, 0.54377700E+00, 0.39433500E+00, 0.36410100E-01, 0.99401400E-02, -.68685600E-02, 0.11373100E-01, -.64782800E-01, -.23609700E-01, 0.20386400E+01, 0.14923200E+01, -.10651700E+03, 0.57672700E+02, -.31474900E+02, -.51206700E+02, 0.67166800E+02, -.14492800E+02, 0.10648200E+03, -.38531200E+02, 0.76075300E+02, 0.37004100E+02, 0.58814100E+02, 0.45196400E+02, -.11720500E+03, 0.81845100E+01, -.12368600E+03, 0.40471200E+02, -.79278400E+01, 0.26615300E+00, 0.15236300E+02, 0.42485800E+01, 0.27886000E+02, -.54622900E+01, 0.68177100E+02, 0.10684100E+02, 0.52413900E+02, -.87337900E+02, -.26285300E+02, -.47674500E+01, -.20197900E+02, -.12310800E+01, -.64770300E+02, -.22673300E+02, 0.23242000E+02, 0.11310000E+03, 0.93408100E+02, 0.14339500E+03, -.12550600E+03, -.83980600E+02, -.20377700E+03, 0.16019300E+03, -.14671200E+01, 0.22564500E+01, 0.21535800E+01, 0.37411900E+01, -.29572900E+01, -.30083900E+01, 0.17431200E+01, 0.87270900E+01, -.43758400E+03, 0.14758400E+03, 0.14061700E+03, 0.21401300E+03, -.99576900E+02, -.27836600E+03, -.23310300E+03, 0.22004700E+03, 0.78130000E+02, -.67734600E+02, -.30676600E+02, -.22382300E+02, 0.12884300E+02, -.51191600E+02, -.12028500E+03, -.39954500E+02, 0.24096700E+00, -.14361800E+01, -.49621800E+00, 0.69893900E+01, -.36731400E+01, 0.23517000E+01, 0.17717200E+02, -.39753100E+01, -.10067600E+01, -.68635000E+02, 0.20385100E+00, -.75321200E+00, 0.12072000E-01, 0.81550200E-02, -.67610700E+01, -.29379400E+02, -.80837700E+01, -.66272200E+02, 0.11800900E+01, 0.12484800E+03, 0.57609400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.48237500E+01, 0.28530300E+01, 0.19823600E+01, 0.21610000E+01, 0.28979800E+00, 0.10570000E+01, -.52495900E+00, -.46059800E+00, 0.88924600E+00, 0.21901800E+01, 0.11259100E+00, 0.36382000E+00, 0.40048600E+01, 0.18872000E+00, 0.63331500E+01, 0.79670400E+00, 0.10329400E+01, -.16402500E+01, 0.75219000E+00, -.25060400E+00, -.10624900E+01, -.15330700E+00, 0.19459900E+01, 0.47360400E+00, 0.85936900E+00, 0.97804000E-01, -.58920800E+00, 0.36002400E+00, -.69830300E+00, -.18264700E+01, -.95632900E+00, -.18007400E+02, 0.17542700E+01, -.14856000E+00, -.22988700E-01, 0.35093300E-01, -.51529900E-02, 0.43378800E+00, 0.14104800E+01, -.14752100E+01, -.28163500E+01, 0.32580800E+03, 0.21284300E+02, -.29999000E+00, 0.66796800E+02, -.26661700E+02, 0.18204900E+02, -.10829100E+02, -.12090800E+04, 0.70790900E+03, 0.19079100E+03, 0.25605300E+03, 0.10457100E+03, -.33984700E+03, 0.12774700E+03, 0.27455700E+03, -.85012600E+00, 0.97886200E+00, 0.43236300E+00, 0.52571000E+00, -.47522600E+00, -.11016900E+01, 0.18217400E+01, 0.79236800E+01, -.58327800E+03, -.10158700E+03, 0.49089400E+02, 0.18083200E+03, -.12245400E+03, -.38312300E+03, -.45669100E+03, 0.20411000E+03, 0.75173700E-01, -.10295900E+01, -.80429200E+00, -.15159000E+01, 0.34704700E+01, 0.12875600E+01, 0.16250200E+01, -.12188800E+02, 0.75829400E-01, -.39008900E-01, -.29210900E-01, -.34086700E-01, -.21636500E-01, 0.83073500E-01, 0.26981200E+00, 0.82195700E+00, 0.17263900E+00, -.98420100E-01, -.68818700E-01, -.83022500E-01, -.85237800E-02, 0.14091600E+00, 0.10378100E+01, 0.29933800E+01, -.11786100E+02, -.68199200E+02, -.49413100E+02, 0.27077800E+02, 0.79692600E+02, -.14517200E+03, 0.57338200E+02, 0.55163400E+02, 0.83936000E+03, -.41462800E+03, -.51466400E+02, -.14383400E+03, -.48554400E+02, 0.23600700E+03, -.41736600E+02, -.19005600E+03, -.40477400E+03, 0.24977200E+03, 0.12169000E+03, 0.13989400E+03, -.11561800E+02, -.26189700E+03, -.10595800E+03, 0.10627200E+03, 0.13287700E+03, -.19344600E+03, -.37465800E+02, 0.18653600E+02, -.19260800E+03, 0.79874100E+02, -.30274300E+03, 0.35683600E+02, -.58961000E+03, 0.48181700E+03, 0.15306700E+03, 0.34960800E+03, -.27516200E+03, -.46792000E+03, -.66210800E+03, 0.38212300E+03, 0.11718400E+01, 0.47107700E-01, 0.98474700E+00, 0.39939000E+01, -.93853100E+01, -.13742300E+01, -.13695000E+02, 0.16845800E+02, -.12772500E+04, 0.24469900E+03, 0.69303000E+02, 0.22209200E+03, 0.22237400E+02, -.61689300E+03, -.34629400E+03, 0.22844300E+03, 0.86576800E+03, -.51003500E+03, -.12186900E+03, -.22036600E+03, -.30604800E+02, 0.45601500E+03, 0.25374000E+03, -.23566600E+03, 0.11883600E+01, 0.66011900E+00, 0.63128400E-01, 0.27107800E+01, -.23834800E+01, -.98811200E+01, 0.12159200E+02, 0.14941900E+02, 0.29915500E+00, -.51536300E+02, -.13961900E+01, -.21623000E+00, 0.24927300E+00, 0.37181900E+02, 0.21012800E+02, -.35826600E+01, -.44459100E+02, -.20365600E+03, 0.28007100E+01, 0.83193900E+02, 0.29533900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.32542000E+01, -.16898100E+01, -.45025700E-01, -.20381400E+00, 0.12951100E+01, -.27789200E+00, -.15941000E+00, -.92911700E+00, 0.31737600E+00, 0.12577100E+01, -.29555400E+00, -.21789400E+01, 0.41929600E+01, 0.32455500E+00, 0.32359200E+01, 0.77408200E+00, 0.94846900E+00, -.70070200E+00, -.10881600E+01, 0.38327300E+01, -.81455200E+00, -.80898200E+00, -.23888200E+01, -.24139800E+00, 0.61868100E+00, -.16271700E+00, 0.66355400E+00, -.18022600E+01, -.11772100E+00, -.62786000E+00, -.94582600E-01, -.13387100E+02, 0.14371800E+01, 0.70171000E-02, -.48028000E-01, -.80625200E+00, 0.37331800E-01, 0.12353300E+01, 0.14654000E+01, -.38135300E+00, -.55260800E-01, 0.32138400E+00, 0.91451300E+02, 0.76804900E+02, -.25499200E+03, 0.20110900E+02, -.14589900E+03, 0.61059500E+02, 0.14556100E+03, -.11439000E+03, 0.15037200E+02, 0.22443500E+02, -.60489100E+02, 0.11095400E+02, -.78644700E+02, 0.75395400E+01, 0.26125300E+00, -.24532800E+00, 0.41862600E-01, 0.92784900E-01, -.18176300E+00, 0.66229500E+00, -.63059300E+01, -.59694900E+01, -.19697800E+02, -.34643400E+02, -.91399000E+02, -.90720800E+02, 0.24802700E+03, -.90219100E+01, 0.12065500E+03, -.13618300E+03, -.68180400E+00, 0.27016800E+00, 0.17358200E+01, 0.18715200E+01, -.38410000E+01, -.14812500E+01, 0.54191700E+01, 0.10292100E+02, -.88454600E-01, 0.76700900E-01, -.15367100E-01, -.79254400E-02, 0.86044200E-01, -.53438900E-01, -.59974700E+00, -.66654900E+00, -.67835400E-01, 0.37360900E-01, -.35885800E-01, -.61597600E-01, 0.12970700E+00, -.50526100E-01, -.24723000E+01, -.24812100E+01, 0.26182300E+03, -.16976300E+03, -.13990400E+02, 0.47369200E+02, -.60638100E+02, -.32392100E+01, -.12653700E+03, 0.40843000E+02, -.94393500E+02, 0.47595500E+02, 0.79389300E+02, 0.44319800E+02, 0.27039300E+02, 0.91314900E+01, -.74240300E+01, 0.85002400E+02, 0.29218600E+03, -.22981300E+03, -.33986100E+02, -.58480200E+02, -.10868100E+03, 0.81742300E+02, -.10994300E+03, -.83375400E+02, 0.13182900E+02, 0.25354900E+02, -.11182700E+03, -.10484300E+03, 0.25609600E+03, -.67671600E+01, 0.28508000E+03, -.58304900E+02, 0.90982800E+02, 0.48991000E+02, -.22283600E+03, -.23055300E+03, 0.39568700E+03, 0.17099100E+03, 0.57763700E+03, -.24717900E+03, 0.19469000E+01, -.47954400E+00, -.72101500E+01, -.58056100E+01, 0.14838100E+02, 0.20471700E+01, 0.44067100E+01, -.14308200E+02, -.14599700E+03, 0.37185700E+02, -.86448100E+02, -.10685800E+03, 0.32673700E+03, 0.14703000E+02, 0.36711600E+03, -.14280700E+03, -.12184700E+04, 0.56291100E+03, 0.34112200E+03, 0.37772800E+03, -.12033200E+03, -.58112900E+03, -.94289000E+02, 0.37390600E+03, -.15714100E+01, 0.39441600E+01, 0.43066200E+00, -.17918400E+02, 0.16116000E+02, -.12901500E+02, -.51643100E+02, 0.12681000E+02, 0.86527400E+00, 0.10063900E+03, 0.35332400E+00, 0.85716700E+00, -.17845400E+00, 0.32802800E+02, 0.33937200E+01, 0.61011200E+02, 0.50573300E+02, 0.17691000E+03, -.29078600E+01, -.17683100E+03, 0.45873800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.21233200E+01, -.51775500E+00, -.70036400E+00, 0.11622900E+01, -.23377700E+00, 0.52062000E+00, 0.21644600E+01, -.17289700E+01, -.55038200E+00, -.13181600E+01, 0.56714500E+00, 0.60868500E+00, -.33485000E+01, -.23026600E+00, -.77517800E+00, -.97827100E+00, -.20391000E+00, -.25311400E+00, -.65613800E+00, -.64032200E+01, -.43255200E+00, 0.99179900E+00, -.21394800E+01, 0.14902900E-01, -.11901100E+01, -.18259700E+00, 0.35817900E+00, 0.73112600E+00, -.57578800E+00, 0.31554700E-01, -.26455200E+00, -.20505200E+01, 0.35537700E+01, 0.42204200E+00, 0.26773600E-01, 0.12608900E+00, 0.69518000E+00, -.19017600E+00, 0.11539600E+00, -.41937300E+00, -.16250400E+01, 0.30480300E+00, 0.11685500E+00, -.33420400E+02, 0.97731700E+02, 0.10071600E+03, 0.11245400E+03, -.13717000E+02, 0.15404000E+03, -.86882500E+02, -.32324400E+02, -.27449700E+02, -.28913700E+01, 0.12078000E+01, 0.10971100E+02, -.28760900E+02, -.32474300E+00, 0.29801800E+00, -.56857800E-01, -.61713500E-01, 0.41461400E+00, 0.45519400E+00, 0.48688300E+01, 0.42062300E+01, -.30661200E+02, 0.49710300E+01, 0.96144000E+02, 0.16492600E+03, -.18114100E+03, -.14759100E+03, -.21618000E+03, 0.16666500E+03, 0.76731200E+00, -.88237100E+00, -.68518900E+00, -.10015800E+01, 0.61772800E+00, 0.43628900E+00, -.55750600E+01, -.66602200E+01, 0.17647400E-01, -.46999800E-01, -.11578500E-01, -.37723600E-02, -.15873600E-01, -.44082300E-01, 0.41528000E+00, 0.43793000E+00, 0.70257200E-01, -.18688200E-02, 0.13522700E-01, 0.32057400E-01, -.11391800E+00, -.56254500E-01, 0.16281200E+01, 0.16916300E+01, 0.25359300E+02, 0.57535800E+02, -.14035600E+02, -.43958500E+02, 0.11905600E+02, 0.37428100E+02, 0.55366400E+02, -.34220900E+02, -.67444700E+02, 0.98239700E+02, 0.39690100E+02, 0.63775200E+02, -.10421300E+03, -.15098800E+02, -.94081700E+02, 0.61016300E+02, 0.80346300E+01, 0.39081700E+02, 0.54476600E+01, -.68615500E+01, 0.62121800E+02, 0.32750800E+02, 0.12118300E+03, 0.20888800E+02, 0.51856800E+02, -.13724100E+03, 0.10671900E+02, 0.30965300E+01, -.22976500E+02, -.42878800E+02, -.55300700E+02, -.37828100E+02, 0.10445000E+03, 0.63784800E+02, 0.94577700E+02, 0.12462200E+03, -.13709900E+03, -.52765600E+02, -.17448800E+03, 0.13172000E+03, -.71617600E+00, 0.18389100E+01, 0.24882200E+01, 0.37164500E+01, -.33375200E+01, -.41895400E+01, 0.69700100E+00, 0.85012100E+01, -.27435700E+03, 0.17591400E+03, 0.16194400E+03, 0.22735000E+03, -.16551500E+03, -.24505700E+03, -.26613000E+03, 0.22360400E+03, 0.27291100E+03, -.75035600E+02, -.60196100E+02, -.59976900E+02, -.38924200E+01, -.48451600E+02, -.23060200E+03, -.76377400E+02, 0.43659500E+00, 0.20488100E+01, -.29759900E+00, 0.52678700E+01, 0.63458400E+01, -.15936700E+01, 0.30468800E+02, -.18677000E+01, -.66301200E+00, -.83034100E+02, -.12488200E+00, -.53789300E+00, 0.10935800E+00, 0.28985600E+01, -.20179700E+01, -.44163600E+02, -.33616500E+01, -.65598400E+02, 0.16286900E+01, 0.15759500E+03, 0.71216300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20908100E+01, -.10285500E+01, -.44990100E-01, -.48717900E+00, 0.73213100E+00, -.51235100E+00, 0.21898200E+00, -.70688300E+00, -.30606500E+00, 0.58918500E+00, -.19875500E+00, -.50355800E-01, 0.12190400E+01, 0.10950200E+00, 0.19192200E+01, -.51709600E+00, 0.33510500E+00, -.20254400E-01, 0.33550000E+00, -.68168400E+01, -.52662900E-01, 0.20270300E-01, -.76104600E+00, 0.88421000E-03, 0.13939400E+00, -.20195100E+00, 0.25312400E+00, -.28691300E+00, -.26357600E+00, -.21766500E+00, -.11604300E+00, -.61807200E+01, 0.17570000E+01, 0.10931800E+00, -.41926800E-01, -.38156400E-01, 0.35995100E+00, 0.16583600E+00, 0.10857300E+00, -.44771200E+00, -.61607600E+00, 0.10053800E+00, 0.16663800E+00, 0.61521600E+00, -.56127700E+02, -.70491500E+02, -.73489300E+02, -.16786900E+02, -.31972900E+03, 0.14885300E+03, 0.50592100E+02, 0.70363300E+02, 0.22990700E+02, -.65579100E+02, 0.43777000E+01, 0.69182700E+02, 0.28936300E+00, -.33609700E+00, 0.28592100E-01, 0.41488500E-01, -.34288600E+00, -.32321700E+00, -.56451900E+01, -.21813400E+01, -.43593600E+02, 0.13231800E+02, -.63827900E+02, -.72457600E+02, 0.13021700E+03, 0.60175800E+02, 0.10627300E+03, -.70426300E+02, -.65283900E+00, 0.80541300E+00, 0.63706300E+00, 0.49731200E+00, -.34966500E+00, -.31880400E+00, 0.70427300E+01, 0.33669000E+01, -.35676800E-02, 0.37167400E-01, 0.71200000E-02, 0.14217700E-01, -.12015100E-02, 0.32828600E-01, -.54273200E+00, -.20708300E+00, -.34470900E-01, 0.54205100E-02, -.14842600E-01, -.26021100E-01, 0.85627600E-01, 0.53261100E-01, -.20348600E+01, -.87043900E+00, -.22752700E+02, -.61529500E+02, 0.68761000E+01, 0.16799500E+02, 0.22409500E+02, -.34103700E+02, -.79179500E+01, 0.10780300E+02, 0.46663300E+02, -.75334800E+02, -.19193800E+02, -.52138600E+02, 0.69487700E+02, -.21589900E+01, 0.34421600E+02, -.52641900E+02, -.47582600E+02, -.10324100E+02, 0.28131300E+01, -.34450700E+01, -.24301600E+02, -.34758700E+02, -.85106700E+02, -.26266900E+02, -.30443000E+02, 0.97284000E+02, -.19895100E+02, 0.20968600E+02, 0.31594900E+01, 0.25662800E+02, 0.33529800E+02, 0.49742900E+02, -.57779500E+03, 0.15456200E+03, -.89987300E+01, 0.18782600E+02, 0.17148500E+03, -.17675800E+03, 0.80429600E+02, 0.60579300E+01, -.57370300E-01, -.13233500E+01, -.21090900E+01, -.12551500E+01, 0.18237700E+01, 0.21311400E+01, -.45669200E+01, -.33962900E+01, -.21499500E+03, 0.46546500E+02, -.65971000E+02, -.81142300E+02, 0.19358700E+03, 0.66491100E+01, 0.16753000E+03, -.81057500E+02, -.18221200E+03, 0.58805000E+02, 0.67070600E+02, 0.72720500E+02, -.36994100E+02, 0.50138500E+02, 0.16988000E+03, 0.89313500E+02, -.17920400E+00, -.32111400E+01, 0.57579900E+00, -.75210900E+01, -.13903300E+02, 0.15082500E+01, -.26846500E+02, -.59690600E+01, 0.11966500E+01, 0.44875700E+02, -.51747300E+00, 0.79192900E+00, 0.47825600E-01, -.29551600E+01, -.29477700E+01, 0.31315500E+02, 0.22527300E+01, 0.39726600E+02, -.49241700E+00, -.10610400E+03, -.11326000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.43103100E+01, -.21812000E+01, -.16463600E+01, -.16302100E+01, -.87527500E+00, -.65577600E+00, 0.20598700E+00, 0.37014800E+00, -.95934700E+00, -.18405600E+01, -.69696300E-01, 0.33039400E+00, -.42618000E+01, -.19831600E+00, -.40282800E+01, -.17119800E+00, -.31227100E+00, 0.25178700E+00, -.10717800E+01, -.11903900E+02, -.15292900E+01, 0.47771200E+00, -.90481700E+00, 0.52007500E+00, -.13482100E+01, -.36600300E+00, 0.90512000E+00, 0.18543100E+01, -.54722800E+00, 0.20812600E+01, 0.59994400E+00, 0.82918400E+01, 0.33342200E+01, 0.62480700E+00, 0.88336000E-01, 0.16853900E+00, 0.82178800E+00, -.57421200E+00, -.78504700E+00, 0.14170400E+00, 0.92992200E+00, 0.28238900E+00, -.26285400E+00, -.40539400E+00, -.28147300E+00, 0.15129500E+03, 0.54862300E+02, 0.25943600E+02, 0.13293300E+04, -.76343600E+03, -.20332700E+03, -.27555800E+03, -.12049400E+03, 0.35632800E+03, -.99172600E+02, -.30764700E+03, 0.32302500E-01, 0.17347900E+00, -.29399400E+00, -.17258800E+00, 0.38540700E+00, 0.12034100E+01, -.60298000E+01, -.45958300E+01, 0.21919900E+03, 0.15993300E+03, 0.10010200E+03, 0.17655100E+02, -.40318100E+02, 0.58093500E+01, 0.14728300E+00, -.56166800E+02, 0.49921600E+00, -.11139800E+01, -.25340000E+00, 0.21538100E+00, -.15882700E+01, -.80169600E+00, 0.65888700E+01, 0.69382300E+01, -.38807400E-01, -.37975100E-01, -.16610600E-02, 0.12118300E-02, 0.25842600E-01, -.10450800E+00, -.72001000E+00, -.53085500E+00, -.11252200E-01, 0.20270600E-01, 0.61095200E-01, 0.60069200E-01, -.69258300E-01, -.13101100E+00, -.26843000E+01, -.18247900E+01, 0.28454700E+03, -.10628100E+02, -.21489000E+01, -.65372800E+02, -.91903500E+02, 0.82935300E+02, -.10524300E+03, -.85460800E+02, -.71974200E+03, 0.37900000E+03, 0.37048200E+02, 0.13507000E+03, 0.68622300E+02, -.13895700E+03, 0.91910800E+02, 0.18340700E+03, 0.15631300E+03, -.10256400E+03, -.33769400E+02, -.52609600E+02, 0.14815700E+02, 0.99850800E+02, 0.69446500E+02, -.23947400E+02, 0.25348300E+02, -.51407500E+02, 0.50914600E+02, -.39273100E+02, 0.11931500E+03, -.95652000E+02, 0.19506500E+03, -.71797300E+02, 0.46609100E+03, -.16852500E+03, -.83611900E+02, -.25644400E+03, 0.20139200E+03, 0.26814300E+03, 0.37771400E+03, -.30548400E+03, 0.78055500E+00, 0.26821700E+01, 0.93546200E+00, -.97953800E+00, 0.44971200E+01, -.26034600E+01, -.23370500E+01, -.10389400E+02, 0.46171100E+03, 0.15736400E+03, 0.10300000E+03, -.22246400E+02, -.36761900E+02, 0.12801700E+03, 0.34026100E+02, -.89405100E+02, -.43872200E+03, 0.18276200E+03, 0.12176100E+03, 0.15866900E+03, -.35037100E+02, -.45108800E+03, -.33049000E+03, 0.17220500E+03, -.47666300E+00, 0.14706400E+02, 0.69514600E+00, -.13987400E+02, 0.35662400E+02, -.10782500E+02, 0.80242700E+01, 0.60205300E+01, 0.12344000E+01, -.57724600E+02, -.30109700E+00, 0.10450000E+01, 0.59430800E-01, 0.91153600E+01, 0.12697500E+02, 0.89041300E+00, 0.34060600E+02, 0.14541300E+03, -.28113300E-02, 0.22394900E+02, 0.12198500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.55375900E+00, 0.19671100E+00, 0.10010500E+00, 0.17602500E+00, -.28911000E-01, 0.32952600E-01, 0.15694700E+00, -.13143400E+00, 0.66571800E-02, 0.70959600E-01, -.24045200E-01, 0.50134200E-01, 0.14377500E+00, 0.31864700E-02, 0.59554000E-01, -.14198100E-01, 0.20581700E-02, 0.71403100E-01, 0.12312900E+00, -.31836400E+00, 0.11908200E+00, 0.20937400E+00, -.11891100E+00, -.82292100E-02, -.51578000E-01, -.25531900E-02, -.44667000E-01, -.34422000E-01, 0.11973400E+00, -.14527800E+00, -.31180700E+00, -.16062600E+01, 0.10106800E+01, 0.76586900E-01, 0.39010700E-01, 0.89811600E-01, -.34325200E-01, -.51978200E-01, -.19423200E+00, -.21931000E+00, -.32556300E+00, 0.27202700E-01, -.92289300E-02, -.13563200E+00, -.70866000E-02, 0.15573900E-01, -.11202900E+02, 0.28700800E+00, -.24242200E+03, 0.63744900E+02, 0.48665200E+02, 0.61000600E+02, 0.13445300E+02, -.81520900E+02, 0.88373500E+01, 0.64866700E+02, -.42598200E+00, -.45885300E-01, 0.50724500E-01, 0.99192600E-01, 0.56819600E-03, -.44319000E+01, -.10626700E+01, 0.14828000E+01, -.11724400E+03, 0.39989100E+02, 0.32062500E+02, 0.51004300E+02, -.11817400E+02, -.84715600E+02, -.49263800E+02, 0.56994500E+02, 0.87208200E+00, -.24891400E+00, -.19101600E+00, -.30029700E+00, 0.13526900E+00, 0.63050500E+01, 0.17347100E+01, -.22643000E+01, 0.20018200E-01, 0.13781200E-01, -.40321800E-02, -.70851700E-02, -.22568400E-02, -.46613100E+00, -.11654300E+00, 0.14687100E+00, 0.25707300E-01, 0.12397700E-01, -.36560000E-02, -.91583100E-02, 0.77423500E-02, -.17136800E+01, -.40661000E+00, 0.55369500E+00, 0.41780300E+02, -.35170300E+02, -.61983500E+01, -.36145300E+01, -.39952600E+01, -.24292400E+02, 0.60747900E+00, -.14423400E+01, 0.10419100E+03, 0.12893300E+02, -.24309200E+02, -.37285500E+02, 0.21642700E+02, 0.64637400E+02, 0.42147000E+02, -.44675000E+02, -.41894600E+02, -.78162500E+01, 0.97668800E+01, 0.14847200E+02, -.55350000E+01, -.38542300E+02, -.28287000E+02, 0.13268400E+02, 0.99499000E+00, 0.61571800E+01, 0.14026900E+02, 0.15245700E+02, -.26056900E+02, -.10035400E+01, -.31265300E+02, 0.14529100E+02, -.79441200E+02, 0.10183200E+03, 0.24252800E+02, 0.32783200E+02, -.94391600E+01, -.70056700E+02, -.37403700E+02, 0.36823000E+02, -.80602400E+00, 0.12794900E+01, 0.45511000E+00, 0.70718500E+00, -.86935400E+00, -.70959700E+01, -.32083500E+01, 0.29350600E+01, -.21274900E+03, 0.92407400E+02, 0.34806800E+02, 0.46279000E+02, 0.21400400E+02, -.10709100E+03, -.13153400E+02, 0.49373500E+02, 0.69402900E+02, -.44348100E+02, 0.13001800E+01, -.58205400E+01, -.15730500E+02, 0.50549500E+02, 0.44274700E+02, -.96703000E+01, 0.26937100E+00, -.46487600E+01, 0.62852500E+00, -.84632900E+01, -.35568200E+01, 0.41048900E+01, -.77399400E+01, 0.15853700E+01, 0.12844200E+01, -.21966600E+02, -.19110900E+01, 0.32952000E+00, 0.45892800E+00, 0.27324700E+01, 0.62514100E+01, 0.95013100E+00, -.28078200E+01, -.99074900E+01, 0.30433700E+01, 0.18218000E+02, 0.95121800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16063600E+01, -.59272000E+00, 0.99469500E-01, -.10757900E+00, 0.67907700E+00, -.17537900E+00, -.55838400E-01, -.44377700E+00, -.19921300E+00, -.22236600E+00, -.55637700E-02, -.79230600E+00, 0.26434000E+00, 0.57437000E-01, -.12445700E+01, -.60968300E+00, -.19611400E+00, 0.40723600E+00, 0.98448900E-01, 0.27470100E+01, 0.65940500E+00, 0.24879300E+00, -.11673700E+00, -.10525000E+00, -.80451200E-01, 0.86581800E-01, -.19512800E+00, -.12946000E+00, 0.40816500E+00, -.91946900E-01, -.15368300E+00, 0.61063600E+01, -.16649100E+00, 0.13915600E-02, 0.91220500E-01, 0.37548300E-01, 0.81080700E-01, -.49977000E-01, 0.14122300E+00, -.32731400E-01, 0.37149100E+00, -.69745700E-01, 0.67821300E-01, -.13822200E+00, -.20255600E+00, -.22624700E+00, 0.16992900E+01, 0.79270800E+01, 0.72282600E+03, -.24973500E+03, -.13473800E+03, -.16625400E+03, -.48706800E+02, 0.23421600E+03, -.28022000E+02, -.17606900E+03, 0.12046900E+01, -.31973100E-01, -.25319500E+00, -.32598600E+00, -.41511100E-01, 0.77919200E+01, -.15948900E+01, -.12961700E+01, 0.18354000E+03, 0.13069100E+02, -.71143500E+02, -.10305900E+03, 0.80757400E+02, 0.16464800E+03, 0.15581800E+03, -.12038400E+03, -.23543600E+01, 0.80462700E+00, 0.59064600E+00, 0.84274800E+00, -.50422800E+00, -.11298200E+02, 0.76535200E+00, 0.23670100E+01, -.45966700E-01, -.41664800E-01, 0.15598000E-01, 0.20486600E-01, 0.34326100E-02, 0.78241300E+00, -.15338500E+00, -.94928400E-01, -.90343100E-01, -.89862400E-02, 0.34009200E-01, 0.42512000E-01, -.13610400E-01, 0.28876700E+01, -.62915300E+00, -.37305200E+00, 0.26919900E+02, 0.14230200E+02, 0.31265300E+02, 0.14289300E+02, -.43304600E+02, 0.74820000E+02, -.45802200E+02, 0.73543800E+01, -.44781000E+03, 0.42564100E+02, 0.19463500E+02, 0.63695200E+02, 0.35687700E+02, -.18580500E+03, -.27309000E+02, 0.72940200E+02, 0.13580900E+03, 0.20130700E+02, -.35366900E+02, -.43512600E+02, 0.58492200E+01, 0.95123700E+02, 0.19676100E+02, -.31178800E+02, 0.24444400E+01, -.15553300E+02, 0.83717700E+01, -.10446700E+02, 0.54565800E+02, -.96830700E+00, 0.12502200E+03, -.20834200E+02, 0.17843800E+03, -.23443500E+03, -.67399800E+02, -.83646100E+02, 0.35176800E+02, 0.14489200E+03, 0.11588300E+03, -.95850200E+02, 0.33979900E+01, -.34400300E+01, -.16123100E+01, -.21964300E+01, 0.22477500E+01, 0.13325100E+02, 0.44839500E+01, -.45061500E+01, 0.39718300E+03, -.98241200E+02, -.90770700E+02, -.10295200E+03, 0.53138600E+01, 0.21717600E+03, 0.83660800E+02, -.11997400E+03, -.15753600E+03, 0.11365700E+03, -.96491800E+00, 0.10229200E+02, 0.68440800E+02, -.10453600E+03, -.87448200E+02, 0.16718000E+02, -.68624700E+00, 0.68292400E+01, -.55133900E+00, 0.17841400E+01, 0.51732900E+01, -.57696000E+01, 0.50297400E+01, -.98865700E+01, -.10989000E+01, 0.34765200E+02, 0.23935400E+01, 0.53150000E-01, -.62328500E+00, -.68855900E+01, -.12727600E+02, 0.77418100E+01, 0.17030200E+02, 0.23813300E+02, -.46695400E+01, -.36530000E+02, -.12527700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17076200E+01, -.39348600E+00, -.45628900E+00, 0.11711800E+01, 0.27633000E+00, 0.56988600E+00, 0.12869900E+01, -.17816900E+01, -.39322500E+00, -.11643200E+01, 0.83964500E+00, -.85339900E+00, -.16753700E+01, -.91559200E-01, -.10985900E+01, -.59212600E+00, -.68318900E-01, -.91678300E+00, -.79945500E+00, 0.68437200E+00, -.40627800E+00, 0.31649800E+00, 0.11674300E+01, 0.62444900E-01, -.72422200E+00, 0.19572500E+00, -.28241800E+00, 0.39338200E+00, 0.46150700E-01, -.38975600E+00, 0.79259900E+00, 0.70668900E+01, -.30760800E+01, -.13744900E+00, 0.35981800E-01, -.40737800E-01, -.14556000E+00, -.14140400E+00, -.18453700E+00, 0.46808400E+00, 0.24596100E+00, -.31888800E+00, -.16489300E+00, 0.52468900E-01, -.28463800E+00, 0.99456600E-01, -.71439300E+00, 0.45071300E+00, -.90439100E+03, 0.31314700E+03, 0.15541200E+03, 0.20085600E+03, 0.78283200E+02, -.28770800E+03, 0.45257900E+02, 0.21302200E+03, -.14569600E+01, -.74302400E-01, 0.18900100E+00, 0.26045400E+00, 0.20989100E+00, -.69069800E+01, 0.16985300E+01, 0.13300000E+01, -.27644000E+03, -.56396400E+02, 0.63231900E+02, 0.96129100E+02, -.15541000E+02, -.19570500E+03, -.15113600E+03, 0.98175000E+02, 0.33135700E+01, -.96579600E+00, -.52693300E+00, -.79818400E+00, 0.21392700E+00, 0.10168000E+02, -.81191800E+00, -.23403800E+01, 0.64523700E-01, 0.70781900E-01, -.14076300E-01, -.15989000E-01, -.19510900E-01, -.67747500E+00, 0.13734600E+00, 0.11313100E+00, 0.10061900E+00, 0.19301300E-01, -.26932500E-01, -.38294700E-01, 0.75749700E-02, -.24963000E+01, 0.61519200E+00, 0.43222900E+00, 0.14426500E+01, -.95029500E+02, -.38509600E+02, -.12995000E+02, 0.42895800E+02, -.11758900E+03, 0.59393200E+01, -.40661900E+01, 0.47737500E+03, -.97375700E+02, -.10180600E+02, -.68019500E+02, -.40509000E+02, 0.20479300E+03, 0.25701400E+02, -.77138100E+02, -.18739200E+03, -.37164500E+02, 0.37762700E+02, 0.31074700E+02, 0.33814600E+02, -.10832000E+03, 0.17186000E+02, 0.16889500E+02, -.11044300E+02, 0.52466700E+02, -.59598700E+01, 0.28937500E+02, -.94312500E+02, -.19425000E+02, -.17170800E+03, 0.31959600E+02, -.53473200E+03, 0.31247900E+03, 0.77640500E+02, 0.86275500E+02, 0.84079400E+02, -.24402000E+03, -.38638400E+02, 0.76369900E+02, -.56900500E+01, 0.40612400E+01, 0.10055200E+01, 0.20130400E+01, -.15641800E+01, -.12806500E+02, -.51612000E+01, 0.40649700E+01, -.62220800E+03, 0.68799700E+02, 0.93003300E+02, 0.85439100E+02, 0.11428800E+03, -.26097900E+03, 0.81894800E+01, 0.88208400E+02, 0.29373200E+03, -.16994400E+03, 0.10648700E+02, -.11345600E+02, -.11188000E+03, 0.14346500E+03, 0.83232200E+02, -.97265100E+01, 0.88618500E+00, -.73101500E+01, 0.51412800E+00, -.35588400E+01, -.24462100E+01, 0.52035500E+00, -.42505000E+01, 0.15287100E+02, 0.97615100E+00, -.19507600E+02, -.21819300E+01, -.65172100E-01, 0.59337400E+00, 0.17045700E+02, 0.15116100E+02, -.19897900E+02, -.32260800E+02, 0.43346900E+01, 0.42557800E+01, -.15210400E+02, 0.16426800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.24684400E+01, -.49428800E+00, -.74007400E+00, -.85603400E+00, 0.43383100E+00, -.64036500E+00, 0.13444300E+01, -.84015600E-01, -.57542600E+00, -.15959900E+01, 0.21746900E+00, 0.59607200E+00, -.36451000E+01, -.24613800E+00, -.21751400E+01, -.40076100E-01, -.43060600E+00, -.31233300E+00, -.90739000E+00, 0.28135800E+01, -.68455400E+00, -.15845400E+01, -.27653400E+01, 0.70686300E+00, -.85631800E-01, -.14598000E+00, 0.40834400E+00, 0.15482000E+01, -.25960000E+00, -.59582900E+00, -.84312100E+00, 0.12650100E+00, 0.31400000E+01, 0.15340900E+00, -.41947500E-01, 0.37418300E+00, 0.11764600E+01, 0.16212800E+00, 0.79086100E+00, -.10123800E+01, -.19013100E+01, 0.38287000E+00, -.49732000E+00, 0.62150300E-01, -.11462800E+00, 0.38325700E+00, 0.26329100E+01, 0.11267500E+01, 0.72450800E+00, 0.13522100E+03, 0.26138500E+02, 0.45976100E+02, -.46594000E+02, -.46900700E+02, -.54555200E+02, 0.48154700E+02, 0.11812000E+01, 0.11844100E+00, 0.58898300E-01, -.12471800E+00, -.11758000E+00, 0.80306500E+01, 0.65138000E+01, 0.29778200E+01, 0.17464700E+03, -.10145100E+03, -.38085200E+02, 0.17320200E+02, -.92809200E+02, 0.51910500E+02, -.42319200E+02, 0.47390900E+02, -.31443700E+01, 0.74590900E+00, 0.40854400E+00, 0.43952200E+00, -.11001700E+00, -.11609000E+02, -.94386000E+01, -.39115700E+01, -.70477800E-01, -.44441400E-01, -.66212800E-02, -.57083200E-02, 0.43450400E-01, 0.83870400E+00, 0.73503000E+00, 0.32680500E+00, -.51738300E-01, -.95753400E-02, -.35268700E-01, -.36299700E-02, -.16713700E-01, 0.30536600E+01, 0.25618100E+01, 0.12269300E+01, -.35715000E+03, 0.23910800E+03, -.92795200E+01, -.32677300E+02, 0.97053500E+02, 0.21534500E+02, 0.14917300E+03, -.27090700E+02, 0.18057400E+02, -.26978600E+02, 0.65503300E+02, 0.67167500E+02, -.13065700E+03, -.10067800E+03, -.20273500E+03, 0.66952500E+02, 0.20634700E+03, 0.13941700E+02, -.18305400E+02, -.14947200E+02, -.40619500E+02, 0.10044100E+03, 0.18758000E+02, -.37668000E+00, 0.61048800E+02, -.15102500E+03, -.96837100E+02, -.88237000E+02, 0.13369200E+03, 0.65379300E+02, 0.10319000E+03, -.94935100E+02, 0.55477700E+03, -.14738100E+03, -.45013000E+01, 0.39910700E+02, -.14898000E+03, 0.17525000E+03, -.10891300E+03, 0.75169500E+02, 0.53306200E+01, -.32093300E+01, -.45394400E+00, -.66563100E+00, 0.22056200E+01, 0.13835300E+02, 0.11795500E+02, 0.39002900E+01, 0.14310500E+03, -.36004100E+02, -.13372400E+02, 0.56830700E+02, -.12295100E+03, 0.50688000E+01, -.12753200E+03, 0.82895600E+02, -.31676100E+03, 0.23193900E+03, 0.58555500E+01, 0.39839500E+02, 0.44468100E+02, -.15280700E+03, -.13721600E+03, 0.12504300E+02, -.10097100E+01, 0.33679100E+01, -.15518800E+01, 0.18073500E+02, -.89378300E+01, 0.69387900E+00, 0.19293200E+02, -.69059600E+01, -.29968900E+01, 0.11504900E+02, 0.33302100E+01, -.12129100E+01, -.82867500E+00, -.18543600E+02, -.22023000E+02, -.26009900E+01, 0.24804900E+02, -.30707600E+02, -.48890200E+01, 0.62726000E+02, 0.11785000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19584300E+00, -.41571300E-01, -.62506400E-01, 0.11686600E+00, -.13427000E-01, 0.37864600E-01, 0.19201400E+00, -.21645000E+00, -.41805700E-01, -.44668300E-01, 0.18590600E-01, -.62089800E-01, 0.28016900E-01, 0.20178800E-02, -.60488100E-01, -.63585400E-01, -.55104400E-02, -.41029000E-01, -.23590200E-01, 0.11098300E+00, -.15004400E-02, 0.32892900E-01, -.51151100E-01, -.15298300E-01, -.69415800E-01, 0.40587600E-02, 0.10256600E-01, 0.42618600E-01, -.51856700E-01, 0.22033900E-01, 0.47700600E-01, 0.50250400E+00, -.32618800E-01, 0.14040100E-01, 0.58921600E-02, -.34443900E-01, -.13631500E-01, -.90445600E-02, -.14250200E-01, 0.20940300E-01, 0.62516700E-01, -.21538700E-01, -.12387700E-01, -.39024800E-01, -.23278200E-01, 0.35543800E-01, 0.45380200E-01, 0.37824300E-01, 0.66604500E-01, 0.64507200E-01, -.35451200E+01, -.37880000E+01, 0.38767200E+01, 0.24101200E+01, 0.46126500E+01, -.36293700E+01, -.19980500E-01, 0.57429000E-02, -.53139000E+00, -.10751300E-02, 0.32711400E-02, -.15797600E+00, -.37199300E-01, 0.48184600E-03, 0.21226100E+01, -.87998900E+00, -.56605500E+01, -.53910600E+01, 0.64618400E+01, 0.38738900E+01, 0.84139200E+01, -.51895900E+01, 0.80420900E-01, -.30605000E-02, 0.73332400E+00, 0.85574000E-02, -.16244800E-01, 0.23588000E+00, 0.45114600E-01, 0.36472100E-02, 0.13115000E-02, 0.15250300E-03, -.56129100E-01, 0.10063300E-02, -.20583200E-02, -.17367700E-01, -.44240600E-02, 0.21187400E-02, 0.22476700E-03, -.17974800E-02, -.20875500E+00, 0.56393200E-03, 0.61158800E-03, -.61226400E-01, -.11670700E-01, 0.31143000E-02, 0.16929900E+02, -.12330400E+02, 0.24965700E+01, 0.64461900E+01, -.83585300E+01, 0.83483000E+00, -.65686700E+01, 0.65383800E+01, -.29333300E+01, -.79604300E+01, -.64631100E+00, -.17248400E+01, 0.46368600E+01, 0.19988900E+01, 0.44086500E+01, -.24186200E+01, -.11076700E+01, 0.23894900E+01, -.25520500E+01, -.11083600E+01, 0.14430800E+01, -.20187500E+00, -.49146300E+00, -.15910700E+01, -.10437700E+01, 0.51969300E+01, 0.53982400E+01, 0.22445200E+01, -.33727300E+01, -.19812000E+01, -.17305800E+01, 0.25243700E+01, -.10819900E+02, 0.12866100E+01, -.59715300E+01, -.30935100E+01, 0.39402300E+01, -.23337300E+01, 0.58642700E+01, -.30627200E+01, -.20584600E+00, -.18073500E-01, -.78714500E+00, -.26829900E-01, -.17981300E-01, -.31441800E+00, 0.21018500E-01, 0.17160900E-02, 0.68309100E+01, -.54830900E+01, -.60489000E+01, -.43756000E+01, 0.36898500E+01, 0.53063700E+01, 0.80650300E+01, -.40190200E+01, 0.95740300E+01, -.63177100E+01, 0.27891600E+01, -.17268000E+01, -.35650500E+00, 0.47491100E+01, 0.22272800E+01, -.14230100E+01, 0.24346400E-01, 0.10840000E+00, 0.14143100E-01, 0.70886400E+00, 0.48887500E+00, -.42102200E+00, 0.62870100E+00, 0.21853500E+00, 0.18323200E-01, 0.40731000E+01, 0.25931600E-01, 0.27122600E-02, -.27803400E-02, 0.16217200E+01, 0.40637500E+00, 0.21037800E+00, -.84058400E-01, -.10619200E+01, -.83120400E-01, -.35926100E+01, -.56504300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23492800E-01, -.11674200E+00, 0.76253700E-01, 0.42419300E+00, -.74129000E-01, 0.37024900E-02, 0.13886900E-01, 0.15660700E-01, -.20077000E+00, 0.34482400E-01, 0.13623400E-01, 0.45333100E-01, 0.13448600E+00, 0.10805100E-01, 0.28801700E+00, 0.94688300E-01, -.13371300E-01, -.11008200E+00, -.11562900E+00, 0.26953500E+01, -.10470100E-01, 0.14779200E-01, -.40494700E-01, 0.67252300E-02, 0.37491400E-02, -.12354900E-01, 0.16227700E-01, 0.22447200E-01, -.24511300E-01, 0.25143000E-01, 0.98158900E-02, 0.17895000E+00, 0.13277000E+00, 0.16720300E-01, 0.46623700E-02, -.46520500E-03, 0.25424200E-01, -.32903200E-01, -.91016300E-01, -.53313900E-01, -.71396600E-01, 0.11279600E-01, -.15598900E-01, 0.47329700E-02, 0.28926500E-02, -.90570200E-02, -.13841600E+00, 0.85912500E-02, 0.20676000E-01, 0.44649100E-01, 0.22455500E-02, -.12698200E+01, 0.10406400E+01, 0.13840700E+01, 0.37456500E+01, -.84785000E+00, -.31939200E-01, 0.67120800E-02, -.59239400E-02, 0.10262700E-01, -.17072100E-01, -.87638100E+00, 0.61227300E+00, 0.13261100E+00, -.12053100E+02, 0.11556800E+02, 0.13196500E+01, 0.21842700E+01, 0.29723100E+01, -.68160500E+01, 0.51870500E+01, 0.29521800E+01, 0.14597800E+00, -.33294700E-01, -.14323900E-01, -.27451800E-01, 0.16376100E-01, 0.12468800E+01, -.85182600E+00, -.20935600E+00, 0.15555600E-02, -.15168400E-03, 0.10906700E-02, 0.23236300E-04, -.11020000E-02, -.95721800E-01, 0.71872600E-01, 0.14076100E-01, -.23558100E-02, -.86458700E-03, 0.25803700E-02, 0.22067100E-03, 0.44455400E-02, -.34897500E+00, 0.26783500E+00, 0.50071200E-01, 0.25379800E+02, -.11716700E+02, 0.14143800E+01, 0.15830300E+01, -.67090700E+01, 0.81691300E-02, -.40669300E+01, 0.10580300E+01, -.97319100E+01, -.29402800E+01, -.66933700E+01, -.58697600E+01, 0.13964100E+02, 0.39873800E+01, 0.14348700E+02, -.75439600E+01, -.26393500E+01, 0.30356200E+01, -.47625700E-01, 0.19385400E+01, -.28993700E+01, -.53777000E+01, -.86883900E+01, 0.15383100E+01, -.48766000E+01, 0.64367500E+01, 0.72579100E+01, 0.48088800E+01, -.45957900E+01, -.22323400E+01, -.44766700E+01, 0.48485400E+01, -.28143700E+02, 0.13286300E+02, 0.47548400E+01, 0.59625300E+01, 0.22473800E+00, -.16764900E+02, 0.34398000E-01, 0.63673300E+01, -.14731100E+00, 0.75347400E-01, 0.83142900E-02, 0.13473600E-03, -.10182900E+00, -.13749200E+01, 0.10549300E+01, 0.23562500E+00, -.29124400E+02, 0.18165200E+02, 0.18238700E+01, 0.31560800E+01, 0.70769300E+01, -.11907100E+02, 0.81236600E+01, 0.31728400E+01, 0.16300100E+02, -.97278000E+01, 0.77679400E+00, -.14648900E+01, -.48195800E+01, 0.12489500E+02, 0.61223900E+01, -.16261100E+01, 0.22681400E-01, -.22051000E+01, -.54510000E-02, 0.82855900E-01, -.15350200E+01, 0.20844000E+01, 0.64038300E-01, -.16822800E+01, -.19952500E-02, -.72643700E+00, -.17030500E+00, -.90723000E-01, 0.52606100E-01, -.68160000E+00, -.63428200E+00, 0.61325600E+00, 0.27264300E+00, -.86949600E+00, 0.38374500E+00, -.46263400E-01, 0.37350500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15007400E+01, 0.96166000E+00, 0.21464100E+00, 0.55446200E-01, -.73597900E+00, -.22949300E-01, -.21304000E+00, 0.10038900E+01, 0.21138500E+00, -.52249300E+00, 0.84559700E-01, 0.12009100E+01, -.25636800E+01, -.19243500E+00, -.14765500E+01, 0.59538000E-01, -.33956100E+00, 0.24268100E+00, -.29091600E+00, -.92719500E+00, -.25889800E+00, -.18057500E-01, -.10727000E+01, -.46036200E-01, 0.23411600E+00, 0.16121700E+00, -.13774900E+00, -.26479200E+00, 0.80317000E+00, -.57826800E+00, -.69951900E+00, -.34469700E+01, -.59382900E-01, 0.31139700E-01, 0.69947600E-01, -.16243300E+00, 0.13243300E-01, 0.25255800E+00, 0.90163700E+00, -.45239400E+00, -.67571200E+00, 0.19413000E+00, -.99730600E-01, 0.55511100E+00, 0.49348200E+00, 0.30084800E+00, -.17574300E+00, -.32906800E+00, -.16083500E+00, 0.51803400E+00, 0.32430800E+01, 0.33082500E+01, 0.12057100E+02, 0.10016600E+02, 0.13809000E+02, 0.14770300E+01, -.49948600E+00, -.42338400E-01, 0.17225000E+01, 0.63801100E-02, 0.19710100E+00, -.91477800E-01, -.27532900E+01, -.22768700E+01, -.10726400E+03, -.61522100E+02, 0.16508200E+02, 0.26444500E+01, 0.35305600E+02, -.41388800E+02, -.56118600E+02, -.17132200E+02, 0.97638500E+00, -.29348900E+00, -.24015000E+01, 0.87388400E-02, -.12179100E+00, 0.70145000E-01, 0.42037300E+01, 0.32659900E+01, 0.27831000E-01, 0.29166800E-01, 0.17871400E+00, -.80621300E-02, -.65218400E-02, 0.80740700E-02, -.33707200E+00, -.25630300E+00, 0.46348700E-01, 0.11202800E-01, 0.67565900E+00, -.13012200E-01, -.18166500E-01, 0.28582900E-01, -.12011200E+01, -.91525100E+00, 0.36010600E+02, -.53911900E+02, -.27565300E+02, 0.41166200E+01, -.18465300E+01, -.52127200E+02, -.65566700E+02, 0.68353500E+01, 0.14653500E+03, -.12128900E+02, 0.35926700E+02, 0.58651800E+01, -.53964000E+02, 0.62033200E+02, -.55800600E+01, 0.16601900E+02, -.10084200E+03, -.23595000E+02, 0.18807700E+02, 0.96693700E+01, 0.28097500E+02, -.48525000E+02, 0.33513200E+02, 0.48184700E+00, 0.26668200E+02, 0.13602200E+01, -.24473800E+02, -.29776300E+01, -.37598800E+02, -.61062700E+00, -.62728400E+02, 0.37859700E+00, -.94201600E+01, -.17481900E+02, -.37538900E+02, -.56268800E+02, 0.55261600E+02, 0.33425500E+02, 0.20497400E+02, -.78140900E+02, -.19858900E+01, 0.97172200E+00, 0.20759300E+01, -.32519700E+00, 0.53465800E+00, -.22096700E+00, -.66642500E+01, -.40174700E+01, -.43107900E+02, -.10281200E+03, -.17691100E+02, -.47910300E+02, 0.64756000E+02, 0.20168000E+02, 0.21969900E+02, -.62794000E+02, 0.96652000E+02, -.66633300E+02, -.22122500E+02, -.24924200E+02, 0.98711700E+01, 0.16362200E+02, 0.53146400E+02, -.10042200E+02, 0.32739400E+00, 0.90322000E+01, 0.36552300E+00, -.67983900E+01, 0.17589200E+02, -.12520300E+02, -.75960700E+01, 0.16554400E+02, 0.66470700E+00, 0.43394400E+01, -.49014500E+00, 0.47609500E+00, 0.11861500E+00, 0.19779400E+02, 0.11961300E+02, -.69256400E+01, -.18331100E+02, 0.17942900E+02, 0.59183500E+00, -.42719300E+02, -.85846000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.38248000E+01, -.32386500E+00, -.71460400E+00, -.12545700E+01, 0.12242000E+01, -.10323900E+01, 0.13974800E+01, -.12108900E+00, 0.18260700E+01, 0.17008700E+01, 0.64192100E+00, -.18238500E+01, 0.68251500E+01, 0.44447800E+00, 0.39089300E+01, -.89543800E+00, 0.45252900E+00, 0.18171200E+01, 0.18499400E+01, -.56655300E+01, 0.31910500E+01, 0.24389500E+01, 0.28538300E+01, -.63157000E+00, -.22989000E+00, -.11201300E+00, -.18122000E+00, -.19118700E+00, -.18594400E-01, -.35259100E+00, -.34884000E+00, 0.44619500E+01, 0.27886100E+01, 0.84977000E-01, 0.78736100E-01, 0.25864700E+00, -.77258500E-01, -.36118800E+00, -.22659200E+01, 0.22930200E+00, -.16353900E+01, 0.26198200E+00, -.66670700E-01, -.39177100E+00, -.11115100E+01, -.21101400E+00, 0.24254500E+01, -.45678500E+00, -.10816600E+00, 0.87100900E+00, -.79405600E+01, -.17643600E+01, -.14167800E+01, 0.70265200E+02, 0.28537400E+02, 0.19682900E+02, -.17445000E+01, 0.16866100E+00, -.17802600E+01, 0.43582200E+00, -.12168000E+00, 0.28680400E+01, -.19610100E+02, -.68543600E+01, -.23924500E+03, -.61426800E+02, -.64923700E+02, -.16893500E+03, 0.25643300E+03, 0.16115000E+02, 0.95195900E+01, -.20123900E+03, 0.43124200E+01, -.10770700E+01, 0.21564800E+01, -.44662100E+00, 0.40704400E+00, -.36832600E+01, 0.28410000E+02, 0.96579400E+01, 0.10983700E+00, 0.79895300E-01, -.17209700E+00, 0.90792100E-02, -.62997900E-01, 0.42882400E+00, -.21188800E+01, -.77209800E+00, 0.13361600E+00, -.62685300E-01, -.68843100E+00, -.73890700E-01, 0.81847600E-01, 0.15908500E+01, -.76270100E+01, -.29613800E+01, 0.63237400E+03, -.43048500E+03, 0.20370300E+02, 0.11250900E+03, -.18576500E+03, -.39272300E+02, -.33337900E+03, 0.95032900E+02, 0.37158800E+03, -.14547100E+03, -.70115400E+02, -.10254800E+03, 0.10147300E+03, 0.18632300E+03, 0.18701800E+03, -.10318300E+03, -.48698400E+03, 0.34632900E+02, 0.28835100E+02, 0.48803300E+02, 0.68705900E+02, -.20280900E+03, -.63185700E+02, 0.19005500E+02, -.94789200E+02, 0.21983800E+03, 0.10405100E+03, 0.70245700E+02, -.15627200E+03, -.11678200E+03, -.14237900E+03, 0.83751900E+02, -.12937800E+04, 0.88747400E+02, -.28617900E+02, -.48516000E+02, 0.33644200E+03, -.42733700E+03, -.16786100E+02, -.12262000E+03, -.10397700E+02, 0.29238300E+01, -.26436700E+01, 0.81749100E+00, -.20444300E+01, 0.43719700E+00, -.34120900E+02, -.95834300E+01, -.31590000E+03, -.21281500E+03, -.10208100E+03, -.22030000E+03, 0.33329900E+03, 0.70326000E+01, 0.10346000E+03, -.25159600E+03, 0.52795100E+03, -.31232300E+03, -.14643600E+02, -.97062100E+02, -.72399600E+02, 0.25656200E+03, 0.35870200E+03, -.32644500E+02, 0.15348600E+01, 0.18148600E+02, 0.20880200E+01, -.26933900E+02, 0.29267000E+02, -.26245900E+02, -.30014600E+02, 0.38234900E+02, 0.39050000E+01, 0.47114700E+02, -.13701600E+01, 0.29647400E+01, 0.15267700E+00, 0.53679100E+02, 0.53449000E+02, 0.26155700E+02, -.46454600E+02, 0.70443200E+02, 0.38461400E+00, -.24198500E+03, -.11021200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20101600E+00, -.11170500E+00, 0.32948800E-02, -.12986300E-01, 0.80731400E-01, -.13403900E-01, 0.99279500E-02, -.69592400E-02, 0.24676900E-02, -.10876600E-01, 0.53047200E-01, -.65923900E-01, 0.88639700E-01, 0.71075300E-02, 0.46517500E-01, 0.48432400E-03, 0.11950100E-01, -.90229900E-01, -.48418200E-01, -.85368500E-01, -.50080000E-02, 0.19978100E-01, -.24441500E-01, 0.19363700E-02, -.24326700E-01, -.94948000E-02, 0.28888300E-01, 0.51033800E-01, -.85464800E-01, 0.22178400E-01, 0.30187500E-01, -.14819700E-02, 0.14758200E+00, 0.22525500E-01, 0.19643500E-02, 0.91662800E-02, 0.47074300E-01, -.18708000E-01, -.46481900E-01, -.30732400E-01, -.51904800E-01, 0.61152700E-02, -.37709900E-02, 0.89080300E-02, 0.13025000E-01, 0.29179400E-02, -.22970500E+00, -.27716900E-01, 0.35091600E-01, 0.25965300E-01, -.12145900E+00, -.32189400E-01, 0.24436200E-01, -.33621500E-02, 0.27942700E+01, 0.61827700E+00, -.34303700E-01, 0.33789600E-02, -.11637700E+00, 0.69703400E-02, -.46071400E+00, -.80370500E+00, -.39674400E+00, 0.20996800E+00, -.14258800E+02, 0.12851800E+02, 0.26780500E+01, 0.56100000E+01, -.16090500E+01, -.89985300E+01, -.11646600E+01, 0.69347000E+01, 0.69596300E-01, -.58594500E-02, 0.12522900E+00, -.43835300E-01, 0.65614600E+00, 0.11322800E+01, 0.56631600E+00, -.33792100E+00, 0.31718700E-02, -.10349700E-02, -.11402900E-01, 0.41365400E-04, -.50179700E-01, -.86857000E-01, -.41716300E-01, 0.22415000E-01, 0.25121800E-02, -.13985100E-02, -.42278400E-01, 0.94044600E-03, -.17940500E+00, -.31902100E+00, -.14920100E+00, 0.81542500E-01, 0.20662300E+02, -.99235700E+01, 0.26611600E+01, 0.15899000E+01, -.74848700E+01, 0.28856200E+01, -.30044600E+01, 0.12222100E+01, -.11560900E+02, 0.13363300E+01, -.80993600E+01, -.65725500E+01, 0.13126900E+02, 0.14143500E+01, 0.11364700E+02, -.85574000E+01, -.46144100E+01, 0.35869200E+01, 0.47024300E-01, 0.22199600E+01, -.36220300E+01, -.47966900E+01, -.73446400E+01, 0.23437200E+01, 0.14552700E+01, 0.19229400E+01, 0.74950000E+01, 0.40693900E+01, -.10086200E+01, 0.12688500E+01, 0.10541400E+00, 0.37991100E+01, -.48041500E+01, 0.31977500E+01, 0.42070800E+01, 0.76233300E+01, -.10098000E+02, -.12166600E+02, -.14120100E+02, 0.89155300E+01, 0.42905100E-01, 0.42728300E-01, -.86208900E-01, 0.10366400E+00, -.84226800E+00, -.12445800E+01, -.67915400E+00, 0.44843100E+00, -.27281600E+02, 0.17417100E+02, 0.31953200E+01, 0.78121600E+01, -.71390900E+00, -.15188600E+02, -.41251900E+01, 0.82042700E+01, 0.11477200E+01, -.13518200E+01, 0.87468900E+00, -.14614700E+01, 0.56470600E+01, 0.78355400E+01, 0.89543200E+01, -.18837800E+01, 0.52865300E-01, -.10388100E+01, 0.19859400E+00, -.51674600E+00, -.97654200E+00, 0.11649400E+01, -.56170500E+00, -.10533500E+01, 0.34088900E+00, -.40111700E+01, -.45064300E+00, 0.56702000E-01, 0.17316000E+00, -.41414100E+00, 0.31259400E+00, 0.16777300E+01, 0.27405700E+01, -.58836100E+01, 0.65026100E+00, 0.58316600E+01, -.34999900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19048700E+01, -.46540300E+00, -.52137400E+00, -.72663000E+00, 0.74974100E+00, -.71138700E+00, 0.24507600E+00, -.13097400E+01, 0.13369100E+01, 0.12719000E+01, 0.94277700E+00, 0.15139000E+00, 0.90884400E+00, 0.78435200E-01, 0.20578600E+01, -.11807300E+00, 0.40350800E+00, 0.29345600E+00, 0.13803600E+00, -.85978000E+01, -.50915200E+00, 0.11682500E+01, 0.64916800E+00, -.23534900E+00, -.46642100E-01, -.57081400E-01, 0.44554900E+00, 0.99030600E+00, -.62070500E+00, 0.84348700E+00, 0.42661700E-01, -.20357600E+00, 0.12233700E+01, 0.12088700E+00, -.33635900E-04, 0.12863600E+00, 0.27808300E+00, -.26696700E-01, 0.34898600E+00, -.20707600E+00, 0.70945300E-01, 0.54682700E-01, -.19091100E-01, -.80879500E+00, -.53450100E+00, 0.10832300E+00, 0.26799900E+01, -.27199400E+00, -.67877500E+00, 0.20608400E+00, 0.66669400E+01, -.45719200E+01, 0.27315900E+00, 0.13390600E+00, -.69851700E+00, -.80296500E+01, 0.65913500E+00, -.62674500E-01, 0.30636100E+01, -.17178800E+00, -.34998300E+00, 0.38148600E+01, 0.55477300E+01, 0.15797000E+01, 0.61158000E+02, 0.38615700E+02, 0.28719700E+02, 0.28274100E+02, -.33835600E+02, 0.20313700E+02, 0.13682300E+02, 0.27415700E+02, -.10659900E+01, 0.20624900E+00, -.43626200E+01, 0.63677400E-01, 0.35426700E+00, -.53472900E+01, -.80557400E+01, -.23347100E+01, -.32950400E-01, -.18446400E-01, 0.35533600E+00, 0.10200300E-01, -.26930600E-01, 0.38602600E+00, 0.61500700E+00, 0.19308200E+00, -.47801500E-01, 0.54300400E-02, 0.12989600E+01, 0.27759600E-01, -.13093700E+00, 0.14253900E+01, 0.22402300E+01, 0.70219900E+00, -.46353100E+02, 0.51902700E+02, 0.84704300E+01, -.45733400E+02, 0.37341700E+02, 0.27494000E+02, 0.48418500E+02, -.47408900E+02, -.20897700E+03, 0.41407200E+02, -.30743000E+02, 0.81571100E+01, 0.35407000E+02, -.94289300E+02, -.86870500E+00, 0.52693900E+01, 0.10689200E+03, -.15662300E+02, -.42725100E+01, -.19968400E+02, -.87005200E+01, 0.61848400E+02, 0.13565000E+02, -.77639300E+01, -.26526500E+02, -.96261500E+01, -.52042500E+01, 0.45523400E+01, 0.53144600E+02, -.20893500E+01, 0.52396200E+02, -.50802400E+01, -.14280500E+03, -.13233600E+02, 0.87679000E+02, 0.74547200E+02, 0.18035500E+02, -.61632100E+02, 0.15667500E+02, 0.80077900E+02, 0.19235300E+01, -.99265500E+00, 0.46143300E+01, 0.19643700E-02, 0.28925400E+00, 0.57070600E+01, 0.10497900E+02, 0.22350500E+01, -.12959200E+03, 0.92563600E+02, 0.75062700E+02, 0.73537000E+02, -.10508900E+02, -.66759100E+02, -.19530500E+02, 0.67673100E+02, -.18666000E+03, 0.12600400E+03, 0.26525300E+02, 0.65346600E+02, -.35894800E+02, -.86121500E+02, -.11715000E+03, 0.54031800E+02, -.45155800E+00, -.13300600E+02, -.97323700E+00, 0.68310900E+01, -.19336500E+02, 0.14365400E+02, 0.80273200E+01, -.21890100E+02, -.18863000E+01, -.28693900E+02, 0.14207300E+01, -.99149000E+00, -.27248600E+00, -.25356200E+02, -.18097600E+02, -.72235600E+01, 0.17107500E+02, 0.23483200E+02, -.14317400E+01, 0.33564300E+02, 0.16442100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15538700E+01, 0.59211300E+00, 0.23273600E+00, 0.34243000E+00, -.90463100E-01, 0.38742800E+00, -.68037800E+00, 0.64510100E+00, 0.15064400E+00, -.25767000E-01, -.15095500E+00, 0.20861700E+00, -.60135800E+00, -.41487000E-01, -.58446200E+00, 0.16471300E+00, -.10540300E+00, 0.37348000E+00, 0.43634800E-01, 0.13321000E+01, -.82317300E-01, -.17277200E-01, 0.82682600E+00, -.38345800E-01, 0.11453500E+00, 0.12399400E+00, -.21748500E+00, -.21714200E+00, 0.31739500E+00, 0.10263900E+00, 0.66638300E-01, 0.90602600E+00, -.17601500E+01, -.20682100E+00, -.23445700E-01, -.15665100E+00, -.37497800E+00, 0.10200600E+00, 0.32082300E+00, 0.39119600E+00, 0.47702100E+00, -.68243800E-01, 0.30039600E-01, 0.10051200E+00, 0.59561300E-02, -.56976000E-01, -.78718700E+00, 0.24821100E-01, -.51366100E-01, -.13624200E+00, -.18257400E+01, -.10628700E+01, 0.87924200E-01, -.19652800E-01, 0.20936000E+01, 0.11422800E+00, -.65710200E+01, 0.62606100E-01, -.12873300E+01, 0.32136800E-02, 0.10272800E+01, -.27481200E+01, 0.15582900E+01, -.17987500E+00, -.32669000E+02, -.21801600E+02, 0.89536700E+01, 0.11329000E+02, -.47876900E+01, -.19666400E+02, -.23734000E+02, 0.10495600E+02, 0.91018800E+01, -.13933100E+00, 0.17718300E+01, -.16741600E-02, -.13193400E+01, 0.37755800E+01, -.20347700E+01, 0.26142500E+00, -.69374000E+00, 0.27867000E-02, -.14199000E+00, -.42802100E-02, 0.10570700E+00, -.29566500E+00, 0.16681200E+00, -.21867000E-01, -.25689000E+01, -.58968500E-02, -.51210300E+00, -.42035500E-02, 0.38804700E+00, -.10879500E+01, 0.61295700E+00, -.68390600E-01, 0.94959800E+01, -.73184400E+01, -.81701300E+01, 0.58873900E+01, -.48994600E+01, -.19478800E+02, -.12556700E+02, 0.67771800E+01, 0.64974700E+02, 0.91489000E+01, 0.17548500E+02, 0.48724000E+01, -.17994100E+02, 0.28931800E+02, -.75058600E+01, 0.77181600E+01, -.40945200E+02, 0.13511000E+01, 0.19239400E+01, 0.68327100E+01, 0.52188300E+01, -.23005000E+02, 0.38210400E+01, 0.37006800E+01, 0.41380400E+02, -.14813100E+02, 0.31984400E+01, -.41188900E+00, -.24722000E+02, 0.87363000E+01, -.32555000E+02, 0.14373200E+01, -.10059500E+02, 0.24196500E+02, -.24128500E+02, -.23779000E+02, 0.18697800E+02, 0.87605900E+01, 0.11094800E+02, -.25816000E+02, -.96292900E+01, 0.39414400E+00, -.18243400E+01, -.80232700E-01, 0.13601400E+01, -.38628500E+01, 0.18498600E+01, -.34472500E+00, -.33356200E+01, -.18927300E+02, -.48953000E+01, -.85782300E+01, 0.77974600E+01, 0.26729200E+01, -.59717400E+01, -.85677400E+01, 0.93889100E+02, -.44195700E+02, 0.15345000E+01, -.70333400E+01, -.12298600E+02, 0.22968600E+02, 0.14624100E+01, -.58102300E+01, -.96297300E+01, 0.26117000E+01, -.76714300E+00, 0.49387300E+01, 0.44000500E+01, -.31347500E+01, 0.47523700E+01, 0.41589900E+01, -.80645600E+00, 0.62782800E+01, 0.30787100E+00, -.43401400E-02, -.75290100E+00, 0.72119000E+01, 0.45112800E+01, -.63848600E+01, -.10489000E+02, 0.82944900E-02, 0.60824300E+00, -.10835300E+02, -.32132300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.55716700E+00, 0.23579600E+00, 0.21608900E+00, 0.18236100E+00, 0.23887800E-01, -.44823800E-02, 0.25172900E-01, -.54845700E-01, 0.74883800E-02, 0.19828100E+00, -.65307000E-02, 0.73342000E-01, 0.38522600E+00, 0.23532700E-01, 0.36296800E+00, -.46848500E-01, 0.32054300E-01, 0.87958000E-01, 0.15893800E+00, 0.10272800E+00, 0.12806200E+00, 0.12002900E+00, 0.44877100E-01, -.43015000E-01, -.63227900E-01, 0.97455200E-02, -.23677400E-01, 0.77828200E-01, -.84832800E-01, 0.49470000E-01, 0.19288600E-01, 0.66851400E+00, -.13389600E+00, -.33983000E-01, 0.43273500E-02, 0.33779200E-02, -.68378800E-01, -.94803800E-01, -.20157300E+00, 0.15717600E-01, -.40557100E-01, -.86969800E-02, -.43294000E-01, -.70135500E-01, -.35677500E-01, -.45320900E-01, -.74617800E-01, -.77221600E-01, -.12615500E+00, 0.21262300E+00, -.20351800E+00, 0.13803100E+01, 0.33238600E-01, 0.80275900E-01, 0.14402700E+01, 0.17111200E+00, 0.15254900E-01, -.46393900E+01, -.36013600E+00, 0.26286400E-01, 0.70796200E+00, -.77356300E+00, -.19143200E+01, -.44182900E+00, -.53121400E+02, -.13091900E+02, 0.15323100E+02, 0.12299300E+02, 0.16394000E+00, -.27876100E+02, -.20462500E+02, 0.77762000E+01, 0.10237100E+00, 0.62718100E+01, 0.47669800E+00, -.59892800E-01, -.89813000E+00, 0.11170900E+01, 0.27753600E+01, 0.60326900E+00, 0.16513700E-01, -.50198300E+00, -.45124100E-01, -.47600700E-03, 0.72041700E-01, -.80656300E-01, -.21208800E+00, -.50339000E-01, 0.50436600E-01, -.18755300E+01, -.16268100E+00, -.55371800E-02, 0.27575800E+00, -.29592900E+00, -.77776600E+00, -.18812600E+00, -.14878300E+02, -.10931000E+02, -.54577400E+01, -.22984500E+01, 0.74155300E+01, -.13500200E+02, -.59169800E+00, -.17162900E+01, 0.33096600E+02, 0.47369200E+01, 0.67485900E+01, 0.14182500E+01, -.85884500E+01, 0.15254100E+02, -.38052700E+01, 0.32621800E+01, -.25733000E+02, -.17367100E+02, 0.49028800E+01, 0.98526200E+00, 0.97235400E+01, -.13567500E+02, 0.18861900E+01, -.21725900E+01, -.12325700E+02, 0.22004200E+02, 0.18365400E+01, 0.50329400E+01, -.17762700E+02, -.65293900E+01, -.97916200E+01, 0.69843500E+01, -.52674500E+02, 0.94970800E+01, 0.44404300E+01, -.36861800E+01, 0.13716400E+02, -.12816300E+02, 0.88003000E+01, -.78727200E+01, -.97435800E+00, -.57690200E+01, -.12435200E+00, 0.53071900E+00, 0.45802700E+00, -.15269400E+01, -.36513200E+01, -.15998600E+00, -.51530800E+02, -.12237700E+02, 0.11904200E+02, 0.10112400E+01, 0.10753300E+02, -.15468300E+02, 0.55398000E+01, -.20533100E+01, 0.36580400E+02, -.80094200E+01, -.47083900E+01, -.86554100E+01, -.39896900E+01, 0.10999400E+02, 0.14509900E+02, -.61598600E+01, 0.22688000E+00, 0.95238700E+00, 0.66644100E-01, -.57721000E+01, 0.23700800E+01, -.15094700E+01, -.58497400E+01, 0.22258500E+01, 0.32120500E-01, 0.13912800E+00, 0.67298300E+00, 0.48732800E+00, -.24257200E+00, 0.28507400E+01, 0.24964300E+01, -.90630700E+00, -.90254300E+01, 0.33381200E+01, -.11297100E+01, -.85342600E+01, 0.13481800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.51843200E+01, 0.22070300E+01, 0.22267200E+01, 0.16690000E+01, 0.10606100E+01, 0.15192600E+00, -.84131100E+00, -.84608300E+00, 0.25543100E+00, 0.11444700E+01, 0.34368500E+00, 0.47336400E+00, -.23818100E+00, 0.39894400E-02, 0.26502600E+01, -.28062000E+00, 0.45565800E+00, 0.15398800E-01, 0.15639400E+00, -.11319300E+02, 0.32335200E-01, 0.13977800E+01, 0.18838400E+00, -.15227900E+00, -.76744000E+00, -.34695400E+00, -.31738300E-01, -.63254800E+00, -.10095600E+01, -.28730200E+00, 0.48070900E+00, -.90224800E+01, -.15664700E+01, -.29452100E+00, -.98809600E-01, -.68486500E+00, -.15589300E+01, 0.62570400E-01, -.12498500E+01, 0.16593000E+00, 0.11832200E+01, -.19104000E-01, 0.55071100E+00, -.33146400E+00, 0.37709100E+00, -.36958700E+00, 0.38971900E+01, 0.59828400E+00, -.51517000E+00, -.74286300E+00, -.12989000E+02, 0.50947800E+01, 0.93084800E+00, 0.72880000E+00, -.23844200E+02, 0.78157000E-01, -.41429400E+00, -.12220400E+00, -.10776400E+02, -.45139100E-01, -.11405200E+02, -.53132900E+01, 0.37264200E+01, 0.77690500E+01, 0.30028800E+03, 0.31076700E+03, -.39095900E+02, 0.40992100E+02, -.17704600E+03, 0.93308500E+02, 0.18592600E+03, 0.13240000E+03, -.42439900E+01, 0.24690500E+01, 0.14996300E+02, 0.27147700E+00, 0.15186900E+02, 0.64448200E+01, -.68720800E+01, -.11004900E+02, -.41931900E+00, -.28626700E+00, -.11237000E+01, 0.21623200E-01, -.10541600E+01, -.67263700E+00, 0.57749100E+00, 0.85994500E+00, -.11831300E+01, -.29479100E+00, -.42150400E+01, 0.54322800E-01, -.40607000E+01, -.24661000E+01, 0.19079400E+01, 0.31214800E+01, 0.60488900E+02, 0.23186400E+03, 0.13617600E+03, 0.62312400E+02, -.16381500E+03, 0.20010700E+03, 0.10531800E+03, 0.52744200E+02, -.63096500E+03, 0.26213200E+03, -.11744800E+03, -.28858600E+02, 0.23423900E+03, -.23664100E+03, 0.68968100E+02, -.61218600E+02, 0.39925900E+03, 0.19216900E+03, -.11364300E+03, -.38716800E+02, -.17158900E+03, 0.16835400E+03, -.16176200E+03, 0.10142000E+01, 0.13477400E+03, -.30606500E+03, 0.10417100E+03, -.35699300E+02, 0.26022100E+03, 0.13205000E+03, 0.33376300E+03, -.52559200E+02, 0.63371500E+03, 0.42292800E+03, 0.19730800E+02, 0.85528000E+02, -.26569800E+03, 0.89649600E+02, -.40829500E+02, 0.17599200E+03, 0.13934700E+02, -.74731100E+01, -.13831100E+02, -.21145900E+00, -.14755800E+02, -.27677200E+01, 0.15932800E+02, 0.12701600E+02, 0.24183600E+03, 0.60223500E+03, 0.33517800E+02, 0.17588400E+03, -.29176800E+03, -.80249400E+02, -.99018300E+02, 0.24712300E+03, -.36546600E+03, 0.24671300E+03, 0.17305400E+03, 0.19145600E+03, -.84924800E+02, -.77849200E+02, -.22078000E+03, 0.14860800E+03, -.54655100E+01, -.31556200E+02, 0.10061100E+01, 0.38749500E+02, -.57306200E+02, 0.46046500E+02, 0.40813500E+02, -.56778900E+02, 0.11443600E+01, -.31717600E+02, -.21137500E+01, -.12533900E+01, 0.17068700E+01, -.58109300E+02, -.41758400E+02, 0.55752700E+02, 0.16101400E+03, -.88744100E+02, 0.16141000E+01, 0.20522900E+03, -.11324000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25852000E+00, -.55106500E-01, -.67403700E-01, -.12398400E+00, 0.55809200E-01, -.10475200E+00, 0.10120500E+00, -.15771800E+00, -.41652900E-01, 0.41438500E-02, -.30168900E-02, -.22457400E-02, 0.14631700E-01, 0.27420500E-02, 0.13534800E+00, -.95818500E-01, 0.26123700E-01, -.12627900E-01, 0.13055900E-01, -.11486000E+00, -.16573000E-01, -.50889600E-01, -.17964800E+00, 0.13403900E-02, -.19055600E-01, -.10636600E-01, 0.39373300E-01, 0.20889900E-01, -.11665500E+00, -.12636300E-01, 0.18715200E-02, -.95258700E+00, 0.12345300E+00, 0.28497700E-01, -.52364800E-02, 0.44272500E-02, 0.12152900E-01, 0.21739200E-01, 0.20276300E-01, -.12614200E-01, 0.42458500E-01, -.20838500E-01, 0.10252000E-01, 0.28885000E-01, 0.56914100E-01, 0.14900300E-01, -.33940600E-01, 0.62264600E-01, 0.73630800E-01, -.21530100E-01, -.72969800E-01, 0.95076000E-01, 0.10064500E+00, -.30387400E-01, 0.14504700E+00, -.26948200E-01, -.10215700E-01, -.25610400E-02, 0.17353300E-01, -.47393200E+00, 0.25461400E+00, 0.50595700E+00, 0.27585300E+00, -.38252100E+00, 0.68439500E+01, -.39357700E+01, -.89078000E+00, -.18857300E+01, 0.30475300E+00, 0.39829900E+01, 0.71914100E+00, -.16579900E+01, -.17927900E-01, 0.17239300E-01, -.69665500E-02, 0.64951800E+00, -.35248000E+00, -.71060700E+00, -.38978900E+00, 0.52382900E+00, -.34749800E-02, -.61978000E-03, 0.15377700E-02, -.50276600E-01, 0.27357300E-01, 0.54640200E-01, 0.29514300E-01, -.40427100E-01, -.86532200E-02, -.15355300E-02, 0.49155800E-02, -.18414700E+00, 0.97566800E-01, 0.20038600E+00, 0.10646700E+00, -.14803900E+00, -.78695900E+00, 0.91230800E+00, -.76931100E+00, -.14519600E+01, 0.63533600E+00, 0.13706600E+01, -.76350400E+00, -.12873300E+01, -.32249200E+01, 0.25593200E+01, -.78477800E+00, 0.10082400E+01, -.15985700E+01, -.27537300E+01, -.18540000E+01, 0.74278800E+00, 0.54891200E+01, -.10752300E+01, -.10621300E+01, -.16760800E+01, 0.19535700E+00, 0.31960000E+01, 0.12250900E+01, -.12060700E+01, 0.18477500E+01, -.18698700E+01, -.59336700E+00, 0.70508400E+00, 0.12201300E+01, 0.39062300E+00, 0.16701600E+01, 0.33020600E+00, 0.17317900E+02, -.17712900E+02, -.10821000E+01, -.15618300E+01, -.26670900E+01, 0.63286000E+01, -.32651200E+01, -.91739200E+00, 0.16954900E-01, -.82407500E-01, -.45925300E-03, -.68570600E+00, 0.42467800E+00, 0.75408600E+00, 0.49741000E+00, -.56424600E+00, 0.11588400E+02, -.11293500E+02, -.29572300E+00, 0.22851800E+00, -.31251000E+01, 0.32339800E+01, -.51992700E+01, 0.48446600E+00, -.87804800E+01, 0.73310600E+01, 0.59491300E+00, 0.30619800E+01, 0.17527400E+01, -.51991000E+01, -.35926700E+01, 0.24717100E+01, -.49160000E-01, 0.89602100E+00, -.53109700E-01, 0.48433700E+00, 0.65116100E+00, -.67880500E+00, 0.49491900E+00, 0.64548200E+00, -.36359500E-01, 0.51482100E+00, 0.80585700E-01, -.23564600E-01, -.49721100E-01, 0.20759000E+00, 0.81170100E+00, -.45145700E+00, 0.73711500E+00, 0.15976000E+01, -.29753400E+00, -.25508200E+00, -.30791700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.61000700E+01, 0.20248100E+01, 0.54094000E+00, 0.36612500E+01, -.87996300E+00, 0.10880900E+01, 0.27098100E+01, -.13468300E+01, -.64171700E+00, -.79598900E+00, -.14517000E-01, 0.31078500E+01, -.46781000E+01, -.31887200E+00, -.27047600E+01, -.81466200E+00, -.11669300E+01, 0.18182900E+01, 0.49424900E+00, 0.28080300E+01, 0.10397400E+01, 0.18373700E+00, -.22868800E+01, 0.39022000E-01, -.47630300E+00, -.31661900E+00, 0.20426300E+00, 0.61848300E+00, -.65904800E+00, 0.75600300E+00, -.63178500E-01, -.78471200E+00, 0.31232600E+01, 0.49390700E+00, -.18300500E+00, 0.12375200E+00, -.28858000E+00, -.17688600E+01, -.46393300E+01, -.69307200E+00, -.81483600E+00, -.18948500E+00, -.84027000E+00, 0.13478800E+01, 0.22153700E+01, 0.43545000E+00, -.21699500E+01, 0.22178400E+00, 0.17596400E+01, 0.71595100E-01, 0.11000700E+02, 0.10510400E+02, 0.58693400E+00, -.49321700E+00, -.13642500E+02, -.22337200E+01, -.50819800E+00, -.43967400E-01, -.80433800E+00, 0.76656900E+00, -.16657100E+02, 0.40999900E+01, 0.90682300E+01, 0.12262600E+02, 0.73955800E+03, 0.41934700E+03, -.10170100E+03, -.61153100E+02, -.19285400E+03, 0.38795500E+03, 0.46593800E+03, 0.10128100E+03, -.73068700E+01, 0.46415100E+01, 0.50342500E+00, 0.71701600E+00, 0.21126700E+02, -.75686300E+01, -.16289100E+02, -.17034500E+02, -.85630900E+00, -.43694700E+00, 0.10731700E+00, 0.10069100E+00, -.14959900E+01, 0.27170500E+00, 0.12713200E+01, 0.14122900E+01, -.24342200E+01, -.35781800E+00, 0.17973300E+00, 0.24383100E+00, -.58225300E+01, 0.10126800E+01, 0.42850300E+01, 0.50251100E+01, -.15079200E+03, 0.46755700E+03, 0.21842500E+03, -.10242100E+01, -.15317300E+03, 0.42640800E+03, 0.28043800E+03, -.17844900E+02, -.11592400E+04, 0.46841800E+03, -.27064700E+03, -.52239600E+02, 0.34248900E+03, -.51429500E+03, 0.37488900E+02, -.11179500E+03, 0.87500900E+03, 0.26592500E+03, -.16974000E+03, -.10138800E+03, -.30491400E+03, 0.43146000E+03, -.23604500E+03, -.24566400E+02, 0.10132000E+03, -.45223300E+03, 0.76435700E+02, -.94637200E+02, 0.58622100E+03, 0.20640100E+03, 0.70664300E+03, -.12081600E+03, 0.12782800E+04, -.18451400E+03, 0.13030800E+03, 0.14968600E+03, -.43643400E+03, 0.31567900E+03, -.28745200E+02, 0.32566900E+03, 0.23248400E+02, -.16513800E+02, 0.13368200E+01, -.19696400E+01, -.16782200E+02, 0.15694100E+02, 0.34910200E+02, 0.18655800E+02, 0.93172200E+03, 0.50733600E+03, 0.33444900E+02, 0.21172100E+03, -.51691700E+03, 0.13062300E+03, -.20519800E+03, 0.34856500E+03, -.10941100E+04, 0.81668600E+03, 0.21706500E+03, 0.37081500E+03, -.86492500E+02, -.33176900E+03, -.46809400E+03, 0.27472600E+03, -.11338200E+02, -.73768000E+02, -.15716200E+00, 0.59013400E+02, -.12297800E+03, 0.10939800E+03, 0.65675900E+02, -.12057000E+03, -.11155400E+01, -.59673300E+02, -.98260800E+00, -.25065400E+01, 0.17274200E+01, -.16688100E+03, -.98888700E+02, 0.91859600E+02, 0.27642800E+03, -.44111300E+02, 0.79596600E+00, 0.28966600E+03, 0.77206500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15690200E+01, 0.90480500E+00, 0.92908500E+00, -.83047300E+00, 0.63596100E+00, 0.23917000E+00, -.16134100E+01, 0.11717600E+01, 0.18495000E+00, -.74200500E-01, -.40576800E-01, -.51301000E+00, -.92084600E-01, -.40306700E-01, 0.12883900E+01, 0.20584800E-01, 0.47715900E+00, -.10440100E+00, 0.73938700E-02, -.34979300E+01, -.36320000E+00, -.45839800E+00, -.92833100E+00, -.89439300E-01, 0.46417200E+00, 0.87981600E-01, 0.21499700E+00, -.56005800E+00, 0.53089400E+00, -.49080100E+00, -.56203900E+00, -.63518000E+01, 0.15420900E+01, 0.40314800E-01, -.19484700E-01, 0.14569600E+00, 0.14997500E+00, 0.12258200E+00, 0.10100700E+01, -.24477500E+00, 0.12230700E+00, 0.13799700E+00, 0.37154800E+00, -.19919900E+00, -.73887900E-01, -.13886900E+00, 0.12324100E+01, -.61700000E+00, -.81410500E+00, -.38797600E+00, -.44970900E+00, -.20096500E+01, -.51983800E+00, 0.93437000E-02, -.19671300E+01, -.19015800E+00, -.45650900E-02, 0.14216000E-01, -.94098200E-01, 0.23265500E+00, 0.11547500E+00, 0.38112800E+01, 0.95788100E+00, -.72120800E+00, -.63121600E+02, -.54591300E+02, 0.16177400E+02, 0.12949200E+02, 0.17913400E+01, -.25776100E+02, -.58331800E+02, -.81877900E+01, 0.60183300E+00, -.41233500E+00, -.96099400E-01, -.15896000E+00, 0.24551900E+00, -.51250500E+01, -.86427000E+00, 0.94545600E+00, 0.55264200E-01, 0.43553800E-01, -.78795100E-02, 0.29783200E-02, -.36628900E-01, 0.42768000E+00, 0.62434500E-01, -.75275200E-01, 0.16635000E+00, 0.45549300E-01, 0.35320300E-02, 0.30745600E-01, -.13855700E+00, 0.15655400E+01, 0.27128700E+00, -.25086100E+00, -.77479600E+02, 0.25256900E+01, -.25387400E+02, -.26861300E+02, 0.53338600E+02, -.33427600E+02, 0.76347000E+01, -.23514200E+02, 0.95271200E+02, -.59997500E+02, 0.28090100E+02, 0.17110700E+02, -.56734500E+02, 0.25478300E+02, -.19046900E+02, 0.21920800E+02, -.62554800E+02, -.32750400E+02, 0.17434200E+02, -.17452900E+01, 0.36823500E+02, -.16627900E+02, 0.61085900E+02, -.57916300E+01, 0.57851900E+01, 0.22506100E+02, -.17461300E+02, 0.72781500E+01, -.36870400E+02, -.16324600E+02, -.71515500E+02, 0.89219600E+01, -.13507000E+03, 0.70405600E+01, 0.47193800E+01, -.15274600E+02, 0.53017100E+02, -.63412600E+01, 0.21138900E+02, -.33058500E+02, -.19588500E+01, 0.12448700E+01, -.16921100E+00, 0.10056600E+00, -.24522200E+00, 0.48134000E+01, -.70502400E+00, -.13952500E+01, -.77518000E+02, -.65299300E+02, 0.83129900E+01, -.19868900E+02, 0.41829800E+02, 0.56074100E+01, 0.17522200E+02, -.37336500E+02, 0.23117000E+02, -.25343300E+02, -.22237400E+02, -.21845000E+02, 0.30875800E+02, -.22094700E+02, 0.57596800E+01, -.15523200E+02, 0.73168900E+00, 0.88255800E+01, -.38726100E+00, 0.34478600E-01, 0.17692400E+02, -.15056400E+02, -.89557900E-01, 0.17381700E+02, -.93341200E+00, 0.17778400E+01, 0.13583900E+01, -.26695800E+00, -.23820200E+00, 0.13017100E+02, 0.85548400E+01, -.16673800E+02, -.18668500E+02, 0.92282900E+01, -.20174600E+01, -.23039300E+02, -.56971500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43380000E+01, 0.23589600E+01, 0.21958300E+01, 0.37910700E+01, -.73189000E-01, 0.51400100E+00, 0.72934400E-01, -.33015400E-01, 0.84502100E+00, -.13825800E+01, 0.19148300E+01, 0.92578100E-03, -.69890700E+01, -.61061200E+00, 0.21462600E+00, -.11165300E+01, -.22033500E+00, 0.11188500E+01, -.35782200E+00, 0.61017400E+01, -.80526300E-01, 0.68199400E+00, 0.11574200E+01, -.83765100E+00, 0.16187500E+00, 0.51435000E+00, -.10954200E+01, -.18969300E+01, 0.20353200E+01, -.33242200E+00, 0.48865700E+00, 0.80071000E+01, -.75563700E+01, -.65614200E+00, 0.16229900E+00, -.87748100E+00, -.11241000E+01, 0.11438700E+01, 0.57035100E+00, -.26426300E+00, 0.52059000E+00, 0.72519200E-01, 0.28449300E+00, 0.41140300E+00, -.90040800E-01, -.61382200E+00, -.15602700E+01, 0.10255500E+00, 0.10775800E+00, 0.15834000E+01, -.59014800E+01, 0.30286300E+02, -.24142200E+00, 0.38969000E+00, -.14201400E+02, 0.17348300E+01, 0.42440000E+00, 0.13881500E-01, 0.77206800E+00, -.74892600E+00, -.19954800E+00, -.17680400E+01, -.46746500E+02, -.11886000E+02, -.52053200E+03, -.26498000E+03, 0.71634200E+02, -.33944600E+02, 0.18306600E+03, -.18001900E+03, -.33670600E+03, -.15455100E+03, 0.27586000E+01, -.26578900E+01, -.68952700E+00, -.52701800E+00, 0.15866600E+01, 0.74359800E+00, 0.67706900E+02, 0.16524400E+02, 0.72240900E+00, 0.30109700E+00, -.80467400E-01, -.43027300E-01, -.27386100E+00, 0.16456400E+00, -.54315000E+01, -.13326600E+01, 0.21028400E+01, 0.26517500E+00, -.15983200E+00, -.11284700E+00, -.80249700E+00, 0.56642200E+00, -.19615900E+02, -.48114300E+01, 0.17797200E+02, -.32025400E+03, -.13067700E+03, 0.15488200E+02, 0.39377100E+02, -.22307700E+03, -.27609900E+03, 0.32606800E+02, 0.76155600E+03, -.19507500E+03, 0.12136900E+03, -.65242300E+00, -.23278300E+03, 0.33916100E+03, -.15378600E+02, 0.48245400E+02, -.70423700E+03, -.19695700E+03, 0.11096200E+03, 0.32217800E+02, 0.24597500E+03, -.25821200E+03, 0.26147400E+03, -.14973300E+02, 0.79205600E+02, 0.21231500E+03, -.34135700E+02, 0.54187000E+02, -.32466300E+03, -.75713500E+02, -.33127300E+03, 0.77623800E+02, -.14793300E+03, -.36887900E+03, -.23365400E+03, -.35641700E+03, 0.26685700E+03, 0.16558400E+03, 0.27654700E+02, -.48357800E+03, -.11981400E+02, 0.11141700E+02, 0.55981400E+00, 0.20037200E+01, -.52205400E+01, -.50218200E+01, -.89324500E+02, -.17455900E+02, 0.16209000E+03, -.69772800E+03, -.10813400E+03, -.31026000E+03, 0.23719300E+03, 0.26306600E+03, 0.57390000E+02, -.39574900E+03, 0.47322900E+03, -.38969200E+03, -.14559100E+03, -.23517000E+03, 0.27370800E+03, 0.97704400E+02, 0.42286000E+03, -.15160400E+03, 0.99057800E+01, 0.10126800E+03, 0.72127500E+01, -.73413500E+02, 0.13790200E+03, -.11686100E+03, -.78235000E+02, 0.13539100E+03, 0.13098500E+02, -.37914700E+01, -.86710900E+01, 0.79147400E+01, 0.23731000E+01, 0.14182800E+03, 0.12058100E+03, -.26271200E+02, -.12867900E+03, 0.33162300E+02, 0.79563400E+01, -.20344900E+03, -.10495100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.25196500E+01, 0.14607600E+01, 0.57759700E-01, 0.10672900E+00, -.60818200E+00, 0.10617300E+00, 0.50250700E-01, 0.55446700E-01, 0.31444200E+00, -.27106400E+00, -.25574200E+00, 0.87614400E+00, -.19263900E+01, -.13990900E+00, -.10548100E+01, 0.46459500E+00, -.22548300E+00, 0.72468100E+00, -.31471800E+00, 0.79566400E+01, -.40074100E+00, -.10341000E+00, -.54636000E+00, -.28915800E+00, 0.17774500E+00, 0.28302000E+00, -.30455200E+00, -.91630200E+00, 0.55207200E+00, 0.22755200E+00, -.76259700E-01, 0.17659100E+00, -.26758200E+01, -.26318900E+00, -.28037600E-01, -.35393500E+00, -.10680100E+01, -.12219900E-02, 0.84822900E-02, 0.30878300E+00, 0.15554500E+01, -.38317600E+00, 0.59730500E-01, -.72495000E+00, 0.30113500E+00, 0.35011100E-01, 0.12322400E+01, -.55731800E-01, -.46934400E+00, -.16329000E+00, 0.11360900E+02, -.63286400E+01, 0.14161700E+01, -.43647400E+00, 0.69842000E+01, -.27889300E+00, -.15833100E+00, -.91718200E-03, -.37701700E+00, 0.35629600E+00, 0.74393800E-01, 0.15086500E+01, -.28468800E+00, 0.27936000E+01, 0.15486100E+03, 0.57103200E+02, 0.15925100E+02, 0.17753700E+01, -.62593800E+02, 0.55258700E+02, 0.14983900E+02, 0.34389500E+02, -.10089300E+01, 0.62236600E+00, -.21724100E+00, 0.87701900E-01, -.41223300E+00, -.36299500E+00, -.72473800E+00, -.39085800E+01, -.15603200E+00, -.69838500E-01, 0.31926500E-01, 0.86837400E-02, 0.63883600E-01, -.38002800E-01, 0.52487200E-01, 0.30471500E+00, -.42664600E+00, -.82789500E-01, 0.71783900E-01, 0.14299700E-01, 0.13352500E+00, -.13466200E+00, 0.86552600E-01, 0.10988100E+01, 0.10569800E+03, 0.54267800E+02, 0.40436700E+02, 0.15391300E+02, -.87540900E+02, 0.76605700E+02, -.16120700E+02, 0.82482900E+01, -.16093100E+03, 0.12645000E+03, -.36495400E+02, 0.17843500E+02, 0.21920600E+02, -.78512700E+02, -.32639700E+02, 0.86265300E+01, 0.17727400E+03, 0.16193300E+02, -.37016900E+02, -.16520000E+02, -.59391900E+02, 0.69776800E+02, -.47777800E+02, 0.22456000E+01, 0.56077500E+02, -.10593600E+03, 0.20470200E+02, -.57645800E+02, 0.12621100E+03, 0.72710900E+02, 0.17682200E+03, -.65211200E+02, 0.46786300E+03, -.20089400E+03, -.21704900E+02, -.76739500E+02, -.38958000E+02, 0.15741900E+03, 0.95543800E+01, -.44749400E+02, 0.33301400E+01, -.19620000E+01, 0.16694700E+01, 0.19421900E+00, 0.10691900E+01, 0.16198100E+01, 0.31441100E+01, 0.46133300E+01, 0.29913600E+03, 0.33327500E+02, 0.31636300E+02, 0.20353700E+02, -.10917600E+03, 0.45741400E+02, -.12312600E+03, 0.46376200E+02, -.39653400E+03, 0.25091400E+03, 0.48718500E+02, 0.82859400E+02, 0.66902700E+02, -.14970100E+03, -.90469200E+02, 0.67962000E+02, -.20789300E+01, -.88079800E+01, -.93113800E-01, 0.60437500E+01, -.21942400E+02, 0.17771200E+02, 0.71923300E+01, -.21783400E+02, 0.87399400E-01, -.34096200E+02, -.28695300E+00, 0.10177500E+00, -.12561900E+00, -.21644000E+02, -.92251300E+01, 0.14316800E+02, 0.48426500E+02, 0.31227800E+02, 0.57620100E+00, 0.45126900E+02, -.84997700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23330500E+01, 0.12646500E+01, 0.36542900E-02, -.46102400E+00, -.34837200E+00, 0.24595500E+00, -.10865900E+01, 0.48606400E+00, -.12609400E+00, -.10528900E+01, 0.11374700E+00, 0.14312400E+01, -.42503500E+01, -.23292200E+00, -.31998100E+01, -.36509900E+00, -.89773700E+00, -.22310800E+00, -.27273100E+00, -.51055600E+01, -.52102000E+00, 0.79833900E+00, 0.35602600E+01, 0.61746800E+00, -.87780600E+00, -.38091100E+00, -.10512700E+01, 0.74261600E+00, -.33082400E+00, 0.59383400E+00, -.27629300E+00, -.42123900E+01, 0.30022500E+01, 0.35870300E+00, 0.13591900E-01, 0.25891800E+00, 0.41556300E+00, -.70475700E-01, 0.51956800E+00, -.36509100E+00, 0.42318300E+00, 0.17102300E+00, -.14904500E+00, 0.50812000E+00, 0.81303100E+00, 0.22962000E+00, -.25599000E+01, 0.30431900E+00, 0.74430300E+00, -.75698500E+00, -.11138300E+01, 0.98032200E+00, 0.51815000E-01, -.43558900E+00, -.36053100E+01, -.95723700E+00, -.78290000E-01, -.16027200E-01, -.96897100E-01, -.24233500E-01, 0.19010700E+00, -.31303000E+00, -.15330900E-01, -.75174100E-01, -.13203900E+03, -.12512700E+02, 0.40797800E+02, 0.53695300E+02, -.22508900E+02, -.92714500E+02, -.11195500E+03, 0.42824000E+02, 0.66565800E+00, -.39179100E+00, -.25292100E+00, -.23101400E+00, 0.26177700E+00, 0.13975900E+00, 0.37796100E+00, -.22079000E+00, 0.60954100E-01, 0.28709900E-01, 0.30106200E-03, -.15512200E-01, -.14913000E-01, 0.11642700E-01, -.75312700E-02, -.15611000E-01, 0.16906400E+00, 0.81238200E-02, 0.18073200E-01, -.37404100E-01, -.45118200E-01, 0.32004000E-01, -.52379600E-02, -.39825700E-01, 0.13581500E+03, -.65300600E+02, -.13563800E+02, 0.22028500E+01, -.16189200E+02, -.19199600E+02, -.45021200E+02, -.15221000E+01, 0.11123800E+03, -.43666500E+02, 0.68891500E+01, 0.30050400E-01, -.13786500E+02, 0.32867200E+02, 0.73876400E+00, -.26526800E+00, -.76841700E+02, -.14001700E+02, 0.14489500E+02, 0.24013600E+02, 0.36386400E+01, -.51996600E+02, -.13337100E+02, 0.20210000E+02, 0.11097500E+02, 0.13471100E+02, 0.97265600E+01, 0.74843400E+00, -.24313600E+02, -.28708400E+01, -.45684000E+02, 0.18136700E+01, -.13281800E+03, -.64968800E+01, 0.29615800E+02, 0.61261900E+02, -.33184800E+02, -.10678700E+03, -.12941900E+03, 0.51022900E+02, -.17064700E+01, 0.13280900E+01, 0.56499700E+00, 0.91230400E+00, -.11902800E+01, -.11609200E+01, -.21564800E+01, 0.76008700E+00, -.33027800E+03, 0.50984400E+02, 0.41748800E+02, 0.59202600E+02, 0.27053000E+02, -.15616200E+03, -.82948700E+02, 0.41256700E+02, -.68769700E+01, -.79624900E+01, -.10954500E+02, -.27764400E+02, 0.44915100E+02, 0.75084400E+01, 0.43001600E+02, -.21200900E+02, 0.80326400E+00, 0.44467400E+01, 0.83821700E-01, -.39802700E+01, 0.41411100E+01, -.68559200E+01, -.51126700E+01, 0.48876000E+01, 0.93502000E-01, -.22477200E+02, -.13369300E+00, -.15025300E-01, 0.89180700E-01, 0.14324900E+02, 0.10143400E+02, -.25025900E+01, -.89830300E+01, -.28664700E+02, 0.50975700E+00, 0.12125100E+02, -.11000500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43920000E+01, 0.13930900E+01, 0.16903800E+01, 0.56266000E+00, 0.67435400E+00, -.42424600E+00, -.89633600E+00, -.11054700E+01, 0.96759700E+00, 0.28594000E+01, -.53737400E-02, -.18862000E+01, 0.74551500E+01, 0.50496700E+00, 0.48940900E+01, 0.77632900E+00, 0.90599300E+00, -.72204000E+00, 0.81135400E+00, 0.55080400E+01, 0.85269100E+00, 0.10685900E+01, 0.29432900E+01, -.17328900E+00, 0.41706000E+00, 0.50240300E-01, -.35022800E+00, -.36064300E+00, -.11024400E+01, -.12530700E+00, 0.70978200E+00, 0.15406900E+01, -.13630300E+01, -.30237000E+00, 0.36270400E-01, -.86435200E-01, -.13801200E+00, -.38640500E+00, -.14537100E+01, -.78829300E+00, -.72724600E+00, 0.19263600E+00, 0.91040000E-01, -.47536100E+00, -.57559500E+00, -.77936600E+00, 0.17400900E+00, -.56081200E+00, -.10184700E+01, 0.73875900E-01, -.11846700E+02, 0.86701400E+01, -.92764100E+00, 0.31632200E+00, -.11138100E+01, 0.16194600E+00, 0.96297500E-01, 0.35455100E-02, 0.42069600E+00, -.31350100E+00, -.26482700E+00, 0.11625500E+01, 0.28358200E+00, 0.61338700E+00, -.11193800E+01, 0.13648000E+03, -.10757600E+02, 0.11946800E+01, 0.19169100E+01, 0.52654200E+01, 0.54035100E+02, 0.18232700E+02, -.22797400E+00, 0.39855000E+00, 0.12871000E+00, 0.15589400E+00, -.49708900E+00, 0.41389200E-01, -.45112600E+00, 0.21132900E-02, -.63530100E-01, -.26525900E-01, 0.97642100E-02, -.69738700E-02, 0.47736300E-01, -.37508500E-02, 0.69651400E-01, -.77238900E-02, -.16393600E+00, -.50151300E-01, -.15862400E-01, -.82544200E-01, 0.23375900E+00, -.25979600E-03, 0.22539200E+00, -.10178000E+00, 0.15402800E+03, -.33622100E+02, 0.40556700E+02, 0.13378300E+02, -.39902800E+02, 0.87097000E+02, 0.17911100E+02, -.44252500E+00, -.80875600E+02, -.23000500E+02, -.81567100E+02, -.46641500E+02, 0.97063000E+02, -.56310800E+02, 0.39339700E+02, -.53806000E+02, 0.32952400E+02, 0.40633600E+02, -.10496400E+02, 0.17109500E+02, -.47329900E+02, 0.18686900E+02, -.10433100E+03, 0.20397500E+02, -.12303000E+03, 0.69832100E+02, 0.55036000E+02, 0.21995400E+02, 0.69322400E+02, -.41108900E+02, 0.83110900E+02, 0.21750600E+02, -.38004900E+03, 0.21632800E+02, 0.13535900E+03, 0.20122400E+03, -.58503000E+02, -.24657800E+03, -.13755400E+03, 0.22127700E+03, 0.80842800E+00, -.11776800E+01, 0.12025400E+00, 0.39454800E+00, 0.37899700E+00, -.59832500E+00, 0.24623000E+01, 0.11122100E+01, -.30014100E+03, 0.21796900E+03, 0.43901200E+02, 0.10321100E+03, -.85022700E+01, -.16641400E+03, -.57119000E+02, 0.11237900E+03, -.11239600E+03, 0.87407500E+02, 0.57557700E+02, 0.57922500E+02, -.12679600E+03, 0.11449900E+02, -.23020800E+02, 0.49442000E+02, -.80023200E+00, -.15027900E+02, -.18826900E+00, -.31697700E+01, -.26663700E+02, 0.19427000E+02, -.15284000E+01, -.24413500E+02, -.20433400E+00, -.15117800E+02, 0.23330800E+00, -.64376500E-01, -.17744300E+00, -.25851600E+02, -.15309100E+02, 0.27102800E+02, 0.28818200E+02, -.14278100E+02, -.70818600E-01, 0.32053100E+02, 0.38220400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.50738500E+00, -.87448300E-01, -.14726100E+00, -.24668900E+00, 0.15299200E+00, -.21965200E+00, 0.22648600E+00, -.16377200E+00, -.45284900E-01, -.62545000E-01, -.61123700E-01, 0.57242200E-01, -.14115200E+00, -.86095900E-02, -.59657900E-01, 0.52543600E-01, -.11059700E-01, -.42511000E-02, -.71266900E-01, 0.32858300E+00, -.88910400E-01, -.11688800E+00, -.31136100E+00, 0.23473800E-01, 0.17708700E-01, -.30689400E-01, 0.54476000E-01, -.36531600E-01, 0.16555800E-01, 0.36594100E-01, -.13707000E-01, -.21825400E+00, 0.23544400E+00, 0.30307900E-01, -.21325900E-02, -.63056300E-03, 0.44709800E-01, 0.53588300E-01, 0.99903000E-01, -.38123900E-01, 0.33213900E-01, -.20965900E-02, 0.63358700E-02, 0.10058000E-01, 0.51085200E-01, 0.37421500E-01, 0.18907600E+00, 0.89606300E-01, 0.45777300E-01, 0.33312800E-01, 0.39059100E+00, 0.52185000E+00, 0.30562900E-01, -.29105100E-01, -.46700800E+00, -.81798100E-02, 0.61776400E-03, -.20735400E-03, -.67576500E-02, 0.15369300E-01, 0.16829000E-01, 0.93969300E-01, 0.11125800E-01, 0.17156100E+00, 0.15773200E+00, -.77604300E-01, -.12693500E+02, -.10239300E+02, 0.13904300E+02, 0.64153300E+01, 0.19594300E+02, -.12061400E+02, 0.48737400E-01, -.53164500E-02, 0.84983400E-01, 0.30828000E-01, 0.99824600E-03, 0.46007200E-01, 0.27821000E-01, 0.56918200E+00, 0.11896400E-01, 0.36483300E-02, -.41715100E-02, -.39129100E-03, -.42201600E-02, 0.45104500E-02, -.73789000E-03, -.40738400E-01, 0.31544600E-01, 0.43966400E-02, -.15321500E-01, -.51500500E-02, 0.49994300E-02, 0.17947800E-01, 0.80996300E-02, -.15382900E+00, -.17393000E+02, -.56258900E+01, -.97098100E+00, 0.20619900E+01, 0.90248500E+01, -.36848400E+01, 0.59036500E+01, 0.28204400E+01, 0.45684000E+01, -.14297100E+02, -.25129400E+00, -.72189700E+01, 0.72638500E+01, 0.46939000E+01, 0.89595300E+01, -.62040500E+01, -.15601100E+02, 0.37850600E+01, 0.23173100E+01, 0.14985600E+01, 0.47420200E+01, -.32893500E+01, -.77966200E+00, -.67847700E+00, -.19248400E+02, 0.21144800E+02, -.11452400E+01, 0.10349000E+02, -.12601400E+02, -.15236300E+02, -.16324000E+02, 0.10916000E+02, -.71096000E+02, 0.37436100E+02, 0.57333800E+01, 0.17994300E+02, 0.29956600E+01, -.26653100E+02, 0.21140900E+01, 0.16202100E+02, -.23363700E+00, 0.19611700E-01, -.35143100E+00, -.13005000E+00, -.14773400E-01, -.17494900E+00, -.38570500E-01, -.67607700E+00, -.15695400E+02, -.50896700E+00, -.10717100E+02, -.37728400E+01, 0.10515300E+02, 0.28103300E+01, 0.24634500E+02, -.41509800E+01, 0.62338000E+02, -.37337200E+02, -.21964700E+01, -.60469100E+01, -.27019400E+02, 0.27281900E+02, 0.88038100E+01, -.51944900E+01, 0.16230300E+00, -.27434600E+00, -.95448500E-02, -.32868200E+00, 0.63776600E+00, -.22416000E+00, -.30537700E+00, 0.65570800E+00, -.37214400E-01, 0.92388000E+01, 0.71791600E-01, -.18423500E-01, -.45642100E-02, -.49997400E-01, -.11043300E+01, 0.47963100E+00, -.50861300E+01, -.34186800E+01, -.16272100E+00, -.58896900E+01, 0.57466200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23071700E+01, 0.54513700E+00, 0.59029500E+00, 0.89230100E+00, -.61084200E+00, 0.59446700E+00, -.99519800E+00, 0.63147300E+00, 0.35377100E+00, 0.10170900E+01, -.56528400E+00, 0.11229200E+00, 0.18650100E+01, 0.12371700E+00, 0.91369300E+00, 0.94622600E+00, 0.31844500E+00, -.87784800E-01, 0.41993400E+00, -.72706500E+01, -.54362100E+00, 0.82795900E+00, 0.17651700E+01, 0.13171900E+00, 0.48711600E+00, -.20868400E+00, 0.25765200E+00, -.34779900E+00, -.13633200E+00, 0.62647600E+00, 0.11602600E+00, -.64955900E+01, 0.18366900E+01, 0.28469200E+00, 0.44610800E-01, -.16964700E+00, -.70264800E-01, -.65646900E-01, -.14244700E+00, -.40120500E-01, -.48510100E+00, 0.18850900E+00, 0.31028400E+00, 0.38548700E+00, -.28982300E+00, 0.21485400E-01, -.20507500E+01, -.12921900E+01, -.62560000E+00, -.43653300E+00, 0.19848400E+01, -.10988100E+01, 0.35378700E+00, 0.12263200E+00, 0.28357300E+01, 0.94210800E+00, 0.69412500E-01, 0.22511100E-02, 0.16991900E+00, -.21229100E+00, -.21366100E+00, -.79998800E-01, 0.11508500E-01, 0.23356200E+00, -.43995900E+00, -.14900300E+00, 0.23246600E+01, 0.34199500E+02, -.41744500E+02, -.26693500E+02, -.58398900E+02, 0.43025900E+02, -.20080500E+00, 0.17089500E+00, 0.48473800E-01, -.63659700E-01, 0.57858100E-01, -.25019000E-01, 0.91558200E-02, -.13685700E+01, -.19481800E-01, -.92587300E-02, -.39908300E-02, -.93217400E-02, 0.17128500E-01, 0.98244800E-03, 0.18372500E-01, 0.89763300E-01, -.54417300E-01, -.14016100E-01, -.20595800E-01, -.31037600E-01, 0.41052100E-01, -.89657900E-02, 0.42882700E-01, 0.32398100E+00, 0.41057500E+01, 0.38210300E+02, -.15508000E+00, -.81333300E+01, 0.22617700E+01, 0.23776600E+02, 0.31759000E+02, -.14397000E+02, 0.21140000E+02, 0.14290900E+02, 0.22250700E+01, -.26986100E+01, -.38541800E+01, -.68376800E+01, -.12505600E+02, -.34128500E+01, 0.14558800E+02, 0.14507000E+02, 0.24036600E+01, 0.20683900E+02, -.28935200E+02, -.54022100E+01, -.40018700E+02, 0.21454000E+02, 0.26962000E+02, -.32218400E+02, -.20015900E+01, -.92454100E+01, 0.16093300E+02, 0.17699200E+02, 0.17530100E+02, -.63825100E+01, 0.20770700E+03, -.48176800E+02, 0.20881000E+01, 0.40860900E+02, -.10397400E+03, 0.26537200E+02, -.11373400E+03, 0.57204600E+02, 0.49826900E+00, -.29632500E+00, 0.31661000E+00, 0.65545000E+00, -.68603200E+00, 0.40807700E-01, -.13800800E+00, 0.22175100E+01, -.13830900E+02, 0.32325600E+02, 0.30518100E+01, 0.60192900E+02, -.70368000E+02, -.59241600E+02, -.12023800E+03, 0.64524100E+02, -.97665400E+02, 0.46070000E+02, -.12474900E+02, -.75344800E+01, 0.56994800E+02, -.20596100E+02, 0.10718000E+02, -.12096100E+02, -.25414200E+00, 0.49817500E+00, -.25027700E-02, -.57602000E+00, -.39093500E+01, 0.16564100E+01, -.13762900E+01, -.34457600E+01, 0.57828500E-01, -.11546800E+02, -.12216200E+00, 0.17889500E-01, -.12224300E-01, -.50973500E+01, -.13456000E+01, 0.83805500E+01, 0.73162800E+01, -.39422900E+02, 0.38839400E+00, 0.49197600E+02, -.95101200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16702200E+01, -.38653800E+00, -.36540600E+00, -.67548100E+00, 0.71763900E+00, -.57769900E+00, 0.47514700E+00, -.30294200E+00, -.55959000E+00, -.12332100E+01, 0.45125600E+00, -.76995200E+00, -.18761900E+01, -.89833400E-01, -.20366200E+01, 0.27805700E+00, -.30822100E+00, -.71549700E+00, -.10334500E+01, 0.37356600E+01, -.74900600E-01, -.49055000E+00, -.33218600E-01, 0.40582900E+00, -.69834900E-01, -.68309300E-01, 0.13478600E+00, 0.51887300E+00, 0.18236600E+00, -.35283400E+00, 0.17644700E+00, 0.55008200E+01, -.57932000E+00, -.55191800E-01, -.14399600E-01, 0.34621200E+00, 0.59352000E+00, 0.82644100E-01, 0.16403300E+00, 0.23615000E+00, -.64635900E-01, -.15885300E+00, -.32922400E-01, 0.77344200E-02, 0.10580000E+00, 0.69062500E-01, 0.29537000E+00, -.58926400E-01, 0.25396300E+00, 0.21407200E+00, 0.29923400E+01, -.38538800E+01, 0.48534300E+00, 0.56133300E-01, 0.25367600E+01, 0.15696700E+00, -.40721400E-01, 0.83848300E-02, -.50510300E-01, 0.12367200E+00, -.35469400E-01, -.43225500E-01, -.12801900E+00, 0.34770300E+00, 0.25092500E+00, -.35239500E-01, 0.65066800E+00, 0.40276000E+00, 0.16847800E+02, 0.12069700E+02, 0.25407200E+02, -.69842300E+01, 0.28810600E+00, -.22035200E+00, -.82182600E-02, -.33865800E-01, 0.46184800E-02, 0.12663100E+00, 0.36633000E-01, 0.20688500E+00, 0.32378700E-01, 0.27004400E-01, -.33613900E-02, 0.11378200E-01, -.27465700E-01, 0.14446500E-03, -.30880300E-01, -.99117400E-03, 0.87540600E-01, 0.58310300E-01, -.31632000E-03, 0.47762500E-01, -.79475400E-01, 0.88256500E-02, -.80702500E-01, 0.93020600E-02, -.50405200E+02, -.25950000E+02, -.32328500E+01, 0.24516500E+01, 0.14966200E+02, -.18017000E+02, 0.29943800E+01, 0.10071400E+02, -.45688900E+02, -.61551600E+01, -.34653300E+00, -.24798200E+01, 0.14267200E+02, -.33938000E+00, 0.19141800E+02, -.19031100E+01, -.64126300E+01, -.24880300E+02, 0.26773300E+01, -.12851800E+02, 0.25152300E+02, 0.11186500E+02, 0.38546100E+02, -.13143600E+02, -.19797400E+02, 0.39353500E+02, -.12556800E+01, 0.14954600E+02, -.24871700E+02, -.19633400E+02, -.27102300E+02, 0.10351500E+02, -.34851100E+02, 0.18146700E+02, -.64986000E+01, -.10298600E+02, 0.28946200E+02, 0.18831200E+02, 0.69263400E+02, -.15199200E+02, -.71169600E+00, 0.69009200E+00, -.41894200E+00, -.19234800E+00, 0.16354600E+00, -.40862500E+00, -.21088400E+00, -.68740300E+00, -.83616500E+01, -.26613900E+02, 0.72944600E+01, 0.37258800E+01, 0.20411400E+02, 0.28726000E+02, 0.68320700E+02, 0.27713300E+01, 0.67129000E+02, -.45682900E+02, 0.10576800E+02, 0.14660100E+01, -.27319700E+02, 0.12780400E+02, -.17683500E+02, 0.58551600E+00, 0.43398300E+00, 0.25552600E+00, 0.80288900E-01, -.59323000E+00, 0.15298100E+01, -.24996600E+01, -.20000100E+00, 0.92848100E+00, 0.78323700E-01, 0.26311700E+01, -.86858400E-01, 0.12297700E-01, 0.79453300E-01, 0.42146900E+01, 0.52628500E+00, -.92152900E+01, -.10906000E+02, 0.67649900E+01, 0.22316400E-02, -.35176100E+01, 0.44730600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27815700E+01, 0.48816500E+00, 0.78781400E+00, 0.15774100E+01, -.10511100E+01, 0.10572700E+01, -.49542400E+00, 0.42263200E-01, -.21204200E+00, 0.94262200E+00, -.86199300E-01, -.70988400E+00, 0.27581600E+01, 0.21110300E+00, 0.88150100E+00, -.12701200E+01, 0.27796300E-02, 0.98458400E+00, 0.13441200E+01, -.42788600E+01, 0.18849400E+01, 0.45368400E+00, 0.77014200E+00, -.23191500E+00, 0.54177900E-01, -.48366200E-01, -.25415400E-03, 0.10592600E+00, -.48924900E-01, -.29964300E+00, -.56625000E-01, 0.75273900E+00, -.97470500E+00, -.18539400E+00, -.25461800E-01, -.78450300E-01, -.55260900E+00, -.75664700E-01, -.10386600E+01, 0.69108200E+00, 0.38411600E+00, -.91526800E-01, 0.15236200E+00, -.40380200E+00, 0.15987300E+00, -.17058000E+00, -.43648100E+00, -.64806800E+00, -.27168800E+00, 0.27833800E-01, -.55109700E+01, -.39298200E+01, -.14001600E+00, 0.36839100E+00, 0.23777400E+01, 0.22021500E+00, -.29499600E-01, 0.11731000E-01, 0.22946600E+00, -.41048000E-01, -.22351500E+00, -.37555700E+00, -.12390600E+00, 0.38545700E+00, 0.89380800E+00, 0.32314300E+00, 0.95925500E+00, -.81154300E-02, 0.96628600E+00, 0.28181100E+02, 0.49825400E+02, 0.20973300E+01, -.54341800E+00, 0.19751100E+00, 0.12254200E+00, 0.99735500E-01, -.14966600E+00, -.13160400E+00, -.26294100E+00, -.53917400E+00, -.42866100E-01, 0.20161900E-02, -.58639900E-02, 0.12892200E-01, -.27304500E-04, -.77664900E-02, -.19313700E-01, 0.65703900E-01, -.11758800E+00, 0.53887700E-01, -.21253500E-01, 0.53361400E-01, -.49734900E-01, -.37054800E-01, -.89825600E-01, 0.24800500E+00, -.16756700E+03, 0.83621200E+02, 0.18529900E+01, -.14217900E+02, 0.27169000E+02, 0.25831700E+02, 0.58525000E+02, -.55003600E+01, -.62254800E+02, 0.61083000E+02, 0.82845800E+01, 0.19099700E+02, -.25851700E+02, -.27040500E+02, -.25617900E+02, 0.19808800E+02, 0.81239700E+02, -.19530900E+02, -.83818600E+01, -.18741800E+02, -.34102900E+01, 0.47142500E+02, 0.34370700E+02, -.16716500E+02, 0.39948800E+02, -.39126300E+02, -.16691300E+02, -.15645200E+02, 0.23602400E+02, 0.37454000E+02, 0.36805900E+02, -.14236200E+02, 0.36754700E+03, -.88736900E+02, -.43021200E+02, -.81415400E+02, -.23922200E+02, 0.20305000E+03, 0.10489400E+03, -.68702100E+02, 0.13513400E+01, -.49050800E+00, 0.10235900E+00, -.24532500E+00, 0.53361400E+00, 0.13067100E+01, 0.97156900E+00, 0.46249200E+00, 0.28341000E+03, -.83356000E+02, -.24526400E+02, -.32992100E+02, -.53352700E+02, 0.13157500E+03, 0.39206700E+02, -.23966700E+02, -.13671700E+03, 0.49485200E+02, 0.43599400E+01, 0.28220100E+02, 0.39868900E+02, -.78905100E+02, -.55341100E+02, 0.20261300E+02, -.58232200E+00, 0.32048800E+00, 0.15966500E-01, 0.87703600E+00, 0.14693600E+01, 0.11865100E+01, 0.16029200E+01, 0.58215900E+00, 0.53975700E-01, 0.54745100E+01, -.71444800E-01, 0.53666700E-01, -.13179900E-02, -.88479400E+01, -.30288300E+01, -.33036600E+01, 0.85463500E+01, 0.72058200E+01, -.85913000E-01, 0.12871300E+02, -.65714300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12354800E+01, 0.43661500E+00, 0.22147500E+00, 0.39087300E+00, -.64873500E-01, 0.74266200E-01, 0.34463800E+00, -.28748600E+00, 0.12526400E-01, 0.15397600E+00, -.54023900E-01, 0.11447200E+00, 0.30873500E+00, 0.12741100E-01, 0.63654300E-01, -.50989800E-01, -.25220300E-01, 0.20175600E+00, 0.24482500E+00, -.67113600E-01, 0.24055000E+00, 0.15538500E+00, 0.35392100E-01, -.46514900E-01, -.60329300E-01, 0.47662600E-02, -.18730500E-01, 0.64376500E-01, -.22228600E-01, 0.70549500E-01, -.11152200E-01, 0.92401700E+00, -.14860000E+00, -.16177800E-01, 0.61187900E-02, -.28976400E-01, -.19214000E+00, -.72551200E-01, -.24826700E+00, 0.11365300E+00, 0.76316100E-01, -.48429300E-01, -.45023400E-01, -.94465100E-01, -.82377100E-01, -.17375600E-01, 0.46730500E+00, 0.85579800E-01, -.92932800E-03, 0.83399400E-01, 0.21825500E+00, 0.17358500E+00, 0.80080100E-01, 0.68324900E-01, -.35149500E+00, 0.11287300E+00, -.76241100E-02, -.26906800E-02, 0.28715100E-01, -.12678300E-01, -.11728000E-01, 0.55701600E+00, 0.82208900E-02, 0.24204300E+00, -.10508900E+00, 0.12497400E+00, 0.65780300E+00, 0.16585500E+00, 0.17087000E+00, -.18152900E+00, 0.16385300E+02, 0.51852500E+01, -.20582400E+00, 0.94265200E-01, 0.41888200E-01, 0.60373000E-01, -.24335200E-01, 0.26214800E+01, -.12175700E+00, -.24962000E+00, -.94571800E-02, -.10885200E-01, -.10426400E-02, -.23028000E-02, 0.72369100E-02, -.21490300E+00, 0.52317400E-02, 0.21394400E-01, -.35011300E-01, -.34433700E-02, -.70872900E-02, -.38353600E-02, 0.17122500E-01, -.79264300E+00, 0.63850900E-02, 0.82810200E-01, -.90042300E+01, 0.12197700E+02, 0.10191700E+01, 0.56505600E+01, -.95624500E+01, -.69984600E+00, 0.21949200E+01, 0.77450900E+01, -.11113700E+02, 0.27889600E+02, 0.43770800E+01, 0.23717700E+01, 0.15699000E+01, 0.31525700E+01, -.25286400E+01, 0.16968200E+01, 0.19045700E+02, 0.55975100E+01, -.39956700E+01, -.43386400E+00, -.88131900E+01, 0.83569900E+00, -.83348700E+01, -.73422800E+00, 0.19431900E+02, -.21159400E+02, -.37390500E+01, -.81738700E+01, 0.13693700E+01, 0.16156300E+02, 0.10732800E+02, -.76940200E+01, 0.12986500E+03, -.92199900E+01, -.23573200E+02, -.27196800E+02, -.18781300E+02, 0.48738900E+02, 0.15187600E+02, -.23169800E+02, 0.68665900E+00, -.29313800E+00, 0.58085400E-01, -.13780900E+00, 0.44860200E-02, -.23240500E+01, 0.45117600E+00, 0.26597100E+00, 0.68384100E+02, -.96012200E+01, -.11872400E+02, -.11223000E+02, -.13232800E+02, 0.22597300E+02, 0.93404600E+01, -.63580800E+01, 0.15952300E+02, -.13497800E+02, -.40277100E+01, -.41516100E+01, 0.94232400E+01, 0.95476500E+01, 0.51371800E+01, -.57338600E+01, -.13916000E+00, -.15307300E+01, 0.16981200E+00, 0.10347600E+00, -.28202500E+01, 0.33599500E+01, -.12843000E+00, -.30732600E+01, 0.37395600E+00, 0.26834600E+01, -.62203600E+00, 0.58335500E-01, 0.14373000E+00, -.14579400E+01, -.10462300E+01, 0.23010900E+01, 0.17861500E+01, -.41405500E+01, 0.98227500E+00, 0.31506700E+01, -.39843100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13696600E+01, -.36166800E+00, -.35664100E+00, 0.67797400E+00, 0.74989000E-01, 0.20349900E+00, 0.98459900E+00, -.14526800E+01, -.68670400E+00, -.10551800E+01, 0.53794400E+00, -.49425300E+00, -.20836200E+01, -.10253500E+00, -.10128300E+01, -.45056200E+00, -.14774500E+00, -.52485000E+00, -.77367400E+00, 0.49058100E+01, -.40984100E-01, -.36771200E+00, -.56119600E+00, 0.11666200E+00, -.13738100E+00, 0.79623400E-01, 0.42929100E-01, 0.21229300E+00, -.12422100E+00, -.30479600E+00, 0.31955200E+00, 0.44968600E+01, -.10179800E+01, 0.28905500E-01, 0.81571800E-02, 0.54468800E+00, 0.72442600E+00, -.22760400E+00, -.32043900E+00, -.19430800E+00, 0.19448100E-01, 0.15744500E-01, -.17702000E+00, -.22293800E+00, 0.29312400E-01, 0.28614700E+00, -.12303300E+01, -.43151700E+00, 0.26154200E+00, -.10894600E+00, 0.29403300E+01, -.17877000E+01, -.81873700E-01, -.16854100E+00, -.48349900E+00, -.46652700E+00, -.65571000E-01, 0.10453100E-01, -.24975800E+00, 0.18787400E+00, 0.19698800E+00, -.29147100E+00, -.35071100E-01, -.30551500E+00, 0.49574500E+00, 0.19232200E+00, -.15314200E+01, -.53056000E+00, -.39054000E+00, 0.27973200E+00, 0.99164900E+00, -.12540800E+02, 0.27318100E+00, -.22058700E+00, -.91125000E-01, -.21827500E+00, 0.16622600E+00, -.24688800E+01, 0.17747700E+00, 0.52266000E+00, 0.17764200E-01, 0.20731900E-01, -.65665100E-03, 0.12618700E-01, -.21141700E-01, 0.20953700E+00, -.22764700E-01, -.43442900E-01, 0.47224600E-01, 0.40674200E-01, 0.14660500E-01, 0.39762200E-01, -.57170200E-01, 0.77593600E+00, -.46461100E-01, -.16283500E+00, -.27386900E+02, -.20797200E+02, -.42099700E+00, -.52557700E+01, 0.22455300E+02, -.31525900E+01, 0.34616900E+01, -.61680000E+01, -.68315800E+02, -.16674600E+02, 0.45879200E+01, 0.35654400E+01, 0.34757600E+01, -.21856200E+02, 0.10118400E+02, 0.52684900E+01, -.23851900E+02, -.14821100E+02, 0.29966600E+01, -.10294400E+02, 0.26182300E+02, 0.59485200E+01, 0.31400200E+02, -.10615400E+02, -.30614500E+02, 0.34075000E+02, 0.26562900E+01, 0.29511700E+02, -.21632400E+02, -.30657900E+02, -.25197800E+02, 0.30000900E+02, -.16064300E+03, 0.76948100E+02, 0.26956600E+02, 0.41150300E+02, 0.11957300E+02, -.57887800E+02, -.12992400E+01, 0.34274800E+02, -.97646300E+00, 0.81114900E+00, -.12298400E+00, 0.66118500E+00, -.64418900E+00, 0.18306400E+01, -.77944700E+00, -.28265600E+00, -.35700400E+02, -.24936500E+01, 0.17715800E+02, 0.25610800E+02, -.11494000E+02, -.10494700E+02, 0.82594300E+01, 0.18059300E+02, 0.30379600E+02, -.19958100E+02, -.39896300E+01, -.35569600E+01, -.13135200E+02, 0.15222500E+01, -.13996200E+02, -.13876000E+00, 0.25634300E+00, 0.22729700E+01, -.14951400E+00, 0.59925900E+00, 0.63264300E+01, -.46624000E+01, 0.59690900E+00, 0.61230500E+01, -.37024700E+00, -.48933600E-01, 0.62571300E+00, -.55080600E-01, -.12104200E+00, 0.18459200E+01, -.12053000E+01, -.74535600E+01, -.57225200E+01, -.64886900E+01, -.99924700E+00, 0.10835900E+02, 0.34102300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.34653200E+01, 0.13138400E+01, 0.51384700E+00, 0.75690000E+00, -.20072500E+00, 0.85534100E+00, -.14991100E+01, 0.14223800E+01, 0.32511800E+00, -.67792300E-01, -.33360400E+00, 0.47721600E+00, -.13915500E+01, -.97736500E-01, -.12597300E+01, 0.36878100E+00, -.21609600E+00, 0.76565700E+00, 0.10918600E+00, 0.20080800E+01, -.19061900E+00, 0.70193200E-01, 0.16317900E+01, -.52188000E-01, 0.33028200E+00, 0.24389800E+00, -.52316600E+00, -.64744500E+00, 0.10136700E+01, -.87464700E-01, -.23152900E+00, 0.61256300E-01, -.24130700E+01, -.33805200E+00, 0.33416800E-03, -.20536300E+00, -.63710800E+00, 0.14451600E+00, 0.57490700E+00, 0.39572600E+00, 0.54822000E+00, -.23181100E-01, 0.76318600E-01, 0.68456100E-01, 0.38398000E-01, -.85006500E-01, -.39134700E+00, -.13755600E+00, -.34845800E+00, -.30204800E+00, -.99595500E+00, -.10380300E+00, -.79854800E-01, -.81364100E-01, -.27849000E+00, 0.30223000E-02, -.39927100E+00, -.82820900E-02, 0.10087200E+00, -.76754900E-01, -.93399100E-01, -.25109800E+00, -.32148300E-01, -.29111900E+00, -.79950100E-01, -.33403000E+00, -.13953000E+01, -.17529200E+00, -.20539800E+00, 0.15441800E+00, -.15298300E+01, -.85112500E+00, 0.40934200E+01, -.31497900E-01, 0.19228800E-01, -.40959800E-01, 0.27540500E-01, 0.19217700E+01, 0.51791100E-01, 0.75470900E+00, -.29673900E+00, 0.18803500E-02, -.22618300E-05, 0.28317600E-03, -.71427500E-02, -.14174100E+00, -.25387100E-02, -.61037200E-01, -.11163500E+01, -.64791000E-02, -.37480000E-02, -.12340100E-01, 0.92024100E-02, -.51527100E+00, 0.10273900E-01, -.24021100E+00, 0.42819800E+02, -.29688900E+02, 0.27565500E+01, 0.10249800E+02, -.11472300E+02, 0.42996800E+01, -.14604200E+02, 0.76162100E+01, -.57414100E+01, 0.14739000E+02, 0.96180200E+00, -.43104200E+01, 0.98026600E+01, 0.13816900E+01, 0.69852600E+01, -.12189600E+01, -.29111500E+02, 0.39141700E+01, 0.10571700E+01, 0.59943600E+01, 0.22107200E+01, -.85338600E+01, -.96746700E+01, 0.32811400E+01, -.11502400E+02, 0.19146100E+02, 0.89908200E+01, 0.16174600E+02, -.13399600E+02, -.17047200E+02, -.17277000E+02, 0.19157400E+02, -.95607500E+02, 0.26905900E+02, 0.10911000E+02, 0.34488900E+02, -.36257700E+01, -.45942400E+02, -.25622500E+02, 0.37496600E+02, -.46994700E+01, 0.32261300E+00, -.54543000E-01, 0.33621700E+00, -.27885800E+00, -.23867300E+01, -.34023700E+00, -.38822100E+00, 0.54589100E+01, -.11944000E+02, 0.26869400E+01, 0.21130200E+02, -.19768000E+02, -.71052700E+01, -.27919100E+02, 0.24278700E+02, 0.70579400E+02, -.31936900E+02, 0.60623200E+01, 0.47754000E+01, -.44398800E+02, 0.24863800E+02, -.60848800E+01, 0.48804600E+01, -.41117600E+01, -.46383600E-01, -.18047400E+00, 0.41538700E+00, 0.27745300E-01, 0.10364700E+01, 0.56753700E+00, 0.14223900E+00, -.10761900E+00, 0.19996300E+01, -.13180600E+00, 0.74322200E-01, -.20193300E+00, -.19057100E-01, -.46640900E+00, 0.13110000E+01, -.33837500E+01, -.75685900E+01, 0.83449100E+00, 0.63963400E+01, 0.61445800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.12453500E+01, 0.52240500E+00, 0.48026100E+00, 0.40466500E+00, 0.53776900E-01, -.88410300E-02, 0.49415800E-01, -.11678100E+00, 0.13236800E-01, 0.42290200E+00, -.97679700E-02, 0.14581500E+00, 0.81617000E+00, 0.48488500E-01, 0.81819300E+00, -.12222800E+00, 0.76929500E-01, 0.16402900E+00, 0.36215500E+00, -.64180300E-01, 0.29014500E+00, 0.24164500E+00, 0.15112000E+00, -.77926600E-01, -.38717100E-01, 0.12411000E-01, -.51487500E-01, 0.84543800E-01, -.10534700E+00, 0.29427400E-02, -.25656400E-01, 0.33020800E+00, 0.57855000E-01, -.11324900E-01, 0.57640300E-02, 0.23244200E-01, -.12805700E+00, -.16955700E+00, -.40085700E+00, -.14855400E-01, -.11246900E+00, -.12342100E-01, -.66666700E-01, -.93100400E-01, -.30664500E-01, -.85141400E-01, 0.20605400E+00, 0.18699400E-02, -.63578100E-01, 0.70158600E-01, -.70962600E+00, 0.10602700E+00, 0.47606300E-01, 0.88043400E-01, 0.46821800E+00, 0.62095200E-01, -.15408800E-01, -.45621800E+00, 0.58470100E-01, -.39242400E-01, -.72457500E-01, -.52180000E-03, -.47152600E-03, 0.18260400E+00, 0.12058500E+00, 0.85073700E-01, -.62601700E-01, 0.13766000E-01, 0.58772000E-01, 0.21649100E+00, 0.59949900E+00, 0.18221900E+00, -.11434800E-01, 0.29522000E+01, 0.46523900E-01, 0.28029800E-01, -.16317000E-01, -.11153800E+01, 0.22089100E-01, 0.26416200E+00, -.14363400E-01, -.23619200E+00, -.19710000E-02, 0.93792900E-03, 0.45723300E-02, 0.86825900E-01, 0.75424300E-02, -.18329900E-01, -.37000600E-01, -.86542600E+00, -.95510100E-02, -.34570700E-02, 0.21998300E-01, 0.32148300E+00, 0.23018400E-01, -.74410400E-01, -.33108700E+02, 0.11454300E+02, -.13798800E+01, -.11177200E+02, 0.18732400E+02, -.24554900E+01, 0.19102900E+02, -.12285600E+02, 0.52708000E+01, -.14988800E+02, -.57697400E+01, -.49838200E+01, 0.40543500E+01, -.29888400E+01, 0.13821400E+01, -.55529100E+01, -.27003400E+01, 0.15708800E+01, 0.26737200E+01, -.11235600E+01, 0.11026300E+01, 0.24509800E+01, -.27810700E+01, -.11481800E+01, -.21335200E+02, 0.11749700E+02, 0.34442500E+00, 0.49129200E+01, 0.30852800E+01, -.11169500E+02, 0.65073100E+00, 0.51077800E+01, -.10406700E+03, 0.11469700E+02, 0.24408200E+02, 0.23037100E+02, 0.11152400E+02, -.40530000E+02, -.71771600E+00, 0.22004800E+02, -.17743700E+00, -.31261100E+01, -.55918500E-01, -.28587100E-01, 0.13387700E+00, 0.10650700E+01, 0.92056900E-01, -.24384700E+00, -.61315800E+02, 0.16185500E+02, 0.94417700E+01, 0.56445100E+01, 0.13203400E+02, -.19589900E+02, 0.88531000E+01, 0.52585000E+01, 0.23701300E+02, 0.10969200E+02, -.75381200E+00, -.56718200E+00, -.21738500E+02, 0.12412100E+02, -.28646200E-01, -.10306800E+01, -.18742600E+00, -.16924400E+01, -.18727500E+00, -.69374200E+00, -.11049800E+01, 0.10723300E+01, -.39818600E+00, -.89528300E+00, -.43321900E+00, 0.15563700E+01, 0.79032800E+00, 0.15271400E-01, -.19919200E+00, -.36345900E+01, -.21886500E+01, 0.63481500E+00, -.46349400E+00, 0.51340400E+01, -.13067200E+01, -.59547100E+01, 0.56011500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43673800E+00, -.92289700E-01, -.13902900E+00, 0.26079400E+00, -.29561600E-01, 0.85116700E-01, 0.42639000E+00, -.48187600E+00, -.90255400E-01, -.96079500E-01, 0.42965200E-01, -.10779100E+00, 0.15970700E-01, 0.12136900E-02, -.92445800E-01, -.13450400E+00, -.53807600E-02, -.90360300E-01, -.50677400E-01, 0.19018800E+00, -.10172400E-01, 0.46660700E-01, -.18921700E+00, -.26698800E-01, -.13672900E+00, 0.22635300E-02, 0.33037000E-01, 0.68077800E-01, -.12997000E+00, 0.43348900E-01, 0.93592000E-01, 0.63746800E+00, -.12738100E+00, 0.21745500E-01, 0.59877100E-02, -.55516300E-01, -.61403900E-01, -.72336100E-04, -.43885600E-01, 0.60658200E-01, 0.11137600E+00, -.48644700E-01, 0.13241600E-04, -.32638800E-01, -.54397200E-01, 0.30774700E-01, 0.12838800E+00, 0.96872900E-01, 0.10875900E+00, 0.25902900E-01, 0.11204700E+01, -.31029200E+00, 0.13310800E+00, -.70920900E-02, -.44893800E-01, 0.21044900E-01, -.16286800E-01, -.21306200E-02, -.45057200E-01, 0.16849200E-01, 0.32949400E-01, -.66390900E-01, -.14248300E-01, 0.16760000E-01, 0.50726000E-01, -.94744900E-02, 0.11462900E+00, 0.25467500E-01, -.23699700E-01, -.23364900E-01, 0.15838600E-01, 0.83748900E-01, -.22900500E-02, -.24552000E-02, 0.33546600E+00, 0.19788600E-01, -.24604200E-03, 0.17281700E+00, 0.37365300E-02, -.65567400E-01, 0.16304100E-02, -.48008800E-03, -.26790000E-01, -.91061900E-03, -.78105400E-03, -.13778800E-01, -.18434100E-02, 0.65870700E-02, 0.55932100E-02, -.21185200E-02, -.96205000E-01, 0.67274000E-03, -.70467000E-02, -.51352000E-01, -.82234300E-02, 0.29174300E-01, -.86339700E+01, 0.48006500E+01, -.15978800E+01, -.17066300E+00, 0.95037400E+00, -.33855000E+01, 0.94582400E+00, 0.72685800E+00, 0.77598000E+01, 0.74178700E+00, 0.26089600E+01, 0.20804900E+01, -.37472000E+01, 0.46948500E+01, -.16519000E+01, 0.23396300E+01, -.47813000E+00, -.10486400E+01, -.13485900E+00, -.63863100E+00, 0.13688600E+01, -.10141600E+01, 0.38139100E+01, -.73113000E+00, 0.64508700E+01, -.35890700E+01, -.11082400E+01, -.25231400E+01, -.29486700E+01, 0.29182700E+01, -.27003900E+01, -.29450600E+01, 0.20226500E+02, 0.62491800E+01, -.94617700E+01, -.14019600E+02, 0.65987100E+01, 0.14754700E+02, 0.12853000E+02, -.14746000E+02, 0.63726700E-01, 0.35446700E-01, -.37649000E+00, -.11741200E+00, 0.66093300E-01, -.84815000E-01, 0.37227300E-02, -.45554600E-01, 0.15854100E+02, 0.82133700E+00, -.35912900E+01, -.77600600E+01, 0.34957100E+01, 0.99097000E+01, 0.84612200E+01, -.74800800E+01, 0.81308400E+01, -.77541000E+01, 0.10472600E+01, -.75248800E+00, 0.17522100E+01, 0.15197300E+00, 0.59901600E+00, -.49327200E+00, 0.20265700E-01, 0.80314400E+00, 0.17390700E-01, 0.57065100E-01, 0.11092900E+01, -.11641900E+01, 0.47835300E-01, 0.97120700E+00, 0.27835300E-01, 0.12201500E+01, -.20642500E-01, 0.48561500E-02, 0.89442600E-02, 0.15973600E+01, 0.10825300E+01, -.97104600E+00, -.11867300E+01, 0.21162900E+01, -.44259400E-01, -.28098700E+01, -.93644000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.57650000E+00, -.12230100E+00, -.14982600E+00, -.27628400E+00, 0.12493200E+00, -.23266400E+00, 0.22294800E+00, -.35047600E+00, -.89129000E-01, 0.13550400E-01, -.67013300E-02, -.23937400E-01, 0.63841400E-01, 0.82828600E-02, 0.29429600E+00, -.16614500E+00, 0.66093200E-01, -.68192100E-01, -.22132000E-02, -.46537500E+00, -.84290000E-01, -.81414600E-01, -.37477100E+00, -.11895100E-01, -.46407500E-01, -.16227500E-01, 0.54150300E-01, -.22185400E-02, -.11513600E+00, 0.24698800E-03, 0.57791200E-01, -.31259200E+00, 0.12766500E+00, 0.38406100E-01, -.57287600E-02, 0.26655000E-02, 0.41974500E-01, 0.12626400E-01, 0.35053200E-01, -.32162500E-01, 0.68969900E-01, -.31728400E-01, 0.40816400E-02, -.81823600E-02, 0.49306700E-01, 0.30709600E-01, 0.78098700E-01, 0.79318400E-01, 0.91805600E-01, 0.18404600E-02, 0.73370400E+00, -.23491800E+00, 0.81482500E-01, -.31021100E-01, -.18342200E+00, -.56924500E-01, -.16538600E-01, -.50442500E-03, -.29560000E-01, -.40314900E+00, 0.20405500E-01, 0.92500500E-01, -.11973900E-01, 0.34173900E-02, -.31711300E-01, 0.51504600E-01, -.19457900E+00, 0.59233100E-02, 0.17840800E-01, -.42177800E-01, 0.22643000E+00, 0.74873900E-01, -.99121700E-02, 0.51871200E-02, -.40318300E-01, 0.27928000E+00, 0.98987500E-02, -.39373400E+00, -.74101400E-02, 0.88484500E-01, -.62073300E-02, -.18830200E-03, 0.17574200E-03, -.21739300E-01, -.19966400E-03, 0.29255800E-01, -.84209900E-03, -.69991000E-02, -.19899100E-01, 0.33650800E-02, 0.12654400E-02, -.77576400E-01, -.55975900E-02, 0.10625500E+00, -.50096100E-02, -.23082000E-01, 0.50566800E+00, 0.38331100E+00, -.11974800E+00, 0.40293000E+00, -.14021800E+01, 0.50948100E+00, -.21939500E+01, 0.81192000E+00, -.49685400E+01, 0.34362500E+01, -.79547600E+00, 0.80313600E+00, 0.96979800E-01, -.22797700E+01, -.40229400E-01, 0.27722600E+00, 0.44829500E+01, -.77136100E+00, -.12107300E+01, -.14654100E+01, 0.21890500E+00, 0.22211500E+01, 0.17104400E+01, -.83100100E+00, 0.55930300E+01, -.49409700E+01, -.58270600E+00, -.56321900E+00, 0.13012600E+01, 0.25058600E+01, 0.23546900E+01, -.11308800E+01, 0.22286200E+02, -.90488500E+01, -.31839300E+01, -.31746900E+01, -.37228400E+01, 0.73953900E+01, -.27446700E+01, -.31089800E+01, 0.91233400E-01, -.49886100E-01, -.66684600E-02, -.30604800E+00, 0.22255700E-01, 0.44875700E+00, 0.68120200E-01, -.12756900E+00, 0.37638600E+01, -.35832500E+01, -.35069500E+00, 0.43233200E+00, -.17590900E+01, 0.19160300E-02, -.22916800E+01, 0.19616500E+00, -.77654700E+01, 0.57174100E+01, 0.10804000E+01, 0.17528600E+01, 0.48164200E+01, -.42394300E+01, -.28221300E+01, 0.17480000E+01, -.86151700E-01, 0.79304100E+00, 0.60902400E-02, 0.37903000E+00, 0.52410800E+00, -.64088300E+00, 0.32797800E+00, 0.49706300E+00, 0.32490700E-01, -.35543200E+00, -.15101300E-01, 0.60954200E-02, 0.93545200E-03, 0.61007200E+00, 0.95197000E+00, -.35135800E+00, 0.98009000E+00, -.44159200E+00, -.11661000E+00, 0.10053300E+01, -.16495300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.44835500E+00, -.24778100E+00, 0.83007400E-02, -.27249000E-01, 0.17931900E+00, -.28110600E-01, 0.18848700E-01, -.11665200E-01, 0.33765900E-02, -.26692500E-01, 0.11720400E+00, -.14604300E+00, 0.18244100E+00, 0.14793500E-01, 0.10841700E+00, 0.27514100E-02, 0.27909500E-01, -.19480000E+00, -.10765700E+00, -.16859700E+00, -.67028300E-02, 0.29622200E-01, -.71819400E-01, 0.51266700E-02, -.44971400E-01, -.22947900E-01, 0.59430200E-01, 0.91627300E-01, -.15197300E+00, 0.11751100E-01, 0.43256000E-01, -.65416900E-01, 0.32340700E+00, 0.41138900E-01, 0.25772900E-02, 0.29040400E-01, 0.11149200E+00, -.31328400E-01, -.79357300E-01, -.79837200E-01, -.12055700E+00, 0.16856700E-01, -.35149600E-02, -.28727900E-02, 0.35498400E-02, -.82059100E-02, -.12450400E+00, -.56566600E-01, -.76684900E-02, 0.28081200E-01, 0.18824000E+00, -.31541300E+00, 0.44981500E-01, 0.11266900E-02, 0.86725000E+00, -.33465900E-02, -.61082300E-02, 0.14025900E-02, -.11457300E-01, 0.58306100E-02, -.27281600E-01, 0.28060300E-01, -.11870000E-01, 0.12868000E+00, 0.43199200E-02, 0.79236000E-01, 0.26497200E+00, 0.19177600E-01, -.21628000E-03, 0.63978000E-01, 0.13719300E+00, 0.10274000E+00, -.15887400E-01, 0.80937800E-02, -.10690900E-01, -.19839500E-01, 0.29982600E+00, -.92122200E-01, 0.53485500E-02, -.10126100E+00, -.89525400E-02, -.97291600E-03, -.15470600E-03, 0.10906200E-02, -.21398200E-01, 0.41603400E-02, -.17676000E-03, 0.84508400E-02, -.29501800E-01, 0.59731500E-02, 0.11836500E-02, 0.55365000E-02, -.83294600E-01, 0.14473600E-01, -.11780300E-02, 0.33145200E-01, -.12698200E+02, 0.63226100E+01, -.55829200E+00, -.35967600E+01, 0.52897500E+01, -.23488900E+01, 0.48718500E+01, -.32821600E+01, -.47511400E+01, -.20769000E+01, -.11262000E+01, -.57135400E+00, 0.13052500E+01, -.18451200E+01, 0.15470200E+01, -.13087900E+01, 0.17770500E+01, 0.22736500E+01, 0.15777500E+00, -.19490600E+01, 0.54796000E+00, 0.12473500E+01, 0.30547600E+01, -.14159000E+01, 0.54274400E+01, -.79402500E+01, -.13948000E+01, -.50461500E-01, 0.12090700E+01, 0.32585500E+01, 0.59505000E+00, -.39207500E+00, -.48177500E+01, 0.44484700E+01, 0.84806400E+00, -.87000600E-01, -.17448100E+00, -.12443100E+01, 0.20364800E+01, -.10507600E+01, 0.14916800E+00, -.11649000E+00, -.49835100E-01, -.64509000E-01, -.24176400E+00, 0.18086800E+00, 0.79285600E-01, 0.25245900E-01, -.11857500E+02, 0.61874900E+01, 0.23021100E+00, -.15302200E+01, 0.38211500E+01, -.21553800E+01, 0.63766500E+01, -.21956600E+01, 0.47849600E+01, 0.28895500E+01, -.15733900E+01, -.21574900E+01, 0.43552700E+01, 0.33323700E+01, 0.10394900E+01, -.18952600E+01, -.12111300E+00, -.18473300E-01, 0.18000200E-01, 0.63404000E+00, 0.20924100E+00, -.24127000E+00, 0.57495800E+00, 0.22366600E+00, 0.19035500E-01, -.26509300E+00, -.35865700E-01, -.11493100E-01, 0.30254900E-01, -.31523600E+00, 0.33397400E-02, -.53901300E+00, 0.13972100E+01, -.11121900E+01, 0.92873900E-02, -.62694100E+00, -.20961900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20919400E+01, 0.35049100E+00, 0.59641200E+00, -.16974400E+01, -.13536400E+00, -.73449000E+00, -.16002000E+01, 0.19318100E+01, -.17070900E+01, -.11333000E+01, -.12117100E+01, -.42639000E+00, -.12289000E+01, -.16473600E-01, -.21693900E+01, 0.27138200E+00, -.30386600E+00, -.23033900E+00, -.79998800E+00, 0.11289300E+01, -.63661700E+00, 0.68175600E-01, -.56060800E-02, 0.19808700E+00, -.99342300E-01, -.99788600E-02, 0.26672000E-01, 0.31167700E-01, 0.37840600E+00, 0.82554300E+00, -.12095600E-01, 0.19243800E+01, -.22044800E+00, 0.68101400E-01, 0.95801000E-01, -.10179300E+00, -.71691300E-01, 0.34133300E-01, -.24440300E-01, -.16007200E+00, -.42272500E-01, 0.35465800E-01, -.84979900E-02, 0.24274800E-01, 0.19790200E+00, -.22060700E-01, -.26217600E+00, -.96175300E-01, -.67872600E-01, 0.41207600E-01, -.42954000E+01, 0.13635700E+02, -.22313200E+00, -.24222900E+00, -.10371700E+02, -.11388800E+00, 0.69376200E-01, 0.67620900E-02, 0.27805900E+00, -.18989000E-01, 0.86477400E-01, 0.11171200E+01, 0.41751900E+00, 0.46224100E+00, -.20297100E+00, -.13879400E-01, 0.32960300E+01, 0.50806700E+00, 0.61453100E+00, -.17182600E+00, 0.64738600E+00, -.94669700E+00, 0.84304500E-01, -.91857700E-02, -.77559700E+00, -.10065600E+01, 0.57558900E-01, -.45317400E+01, -.50258500E-01, -.85883000E+00, -.11173000E-01, -.74656600E-03, 0.36034500E-02, -.77665100E-02, 0.30130000E-02, 0.35593000E+00, 0.11907700E-01, 0.53708700E-01, -.31158000E-01, -.13567100E-01, -.81317300E-02, -.67480500E-01, 0.41758100E-01, 0.13126900E+01, 0.53254200E-01, 0.14686600E+00, 0.15783400E+03, -.99765300E+02, 0.26394800E+02, 0.18378700E+02, -.45226900E+02, 0.40587200E+02, -.40900600E+02, 0.10838400E+02, -.10640400E+03, -.17616600E+02, -.28499000E+02, -.31947700E+01, 0.27440900E+02, -.62810200E+02, -.93407500E+01, -.11947800E+02, 0.76736200E+01, 0.46289100E+01, -.11815400E+02, -.32724400E+01, -.41348700E+01, 0.10843800E+02, -.19120100E+02, 0.57572200E+00, -.39270700E+02, 0.40125100E+02, 0.25475200E+02, 0.10081400E+02, 0.37015400E+02, -.17351200E+02, 0.44913400E+02, 0.79269000E+01, -.26329200E+03, -.67415600E+02, 0.71177400E+02, 0.11515300E+03, -.25419200E+02, -.17386800E+03, -.14014200E+03, 0.11681200E+03, -.83261200E+00, -.37567000E+00, 0.51120000E+00, 0.12860900E+01, -.88440200E+00, 0.33892600E+01, -.16557900E+00, 0.22353500E+01, -.21309300E+03, 0.86390200E+01, 0.45460400E+02, 0.76093500E+02, -.10185200E+02, -.12818900E+03, -.94283300E+02, 0.69269600E+02, -.16203800E+03, 0.10540200E+03, 0.17254900E+02, 0.16583600E+02, 0.23866600E+02, -.44744200E+02, -.96748100E+01, 0.15805300E+02, -.12235600E+00, -.57916100E+01, -.28496600E+00, 0.39992300E+01, -.13744500E+02, 0.78996200E+01, 0.38316400E+01, -.12574400E+02, -.53916200E+00, -.14332200E+02, 0.91059000E+00, -.77511100E-01, -.25625300E+00, -.80365200E+01, -.68413500E+01, 0.42630100E+01, 0.14015200E+02, -.17376200E+02, -.13240500E+01, 0.20813700E+02, -.11914300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.37498600E-01, -.81007800E-01, 0.60261200E-01, 0.31618700E+00, -.49046700E-01, 0.76241900E-02, -.24476700E-01, 0.44137800E-02, -.16688700E+00, 0.29515300E-01, 0.61522000E-02, 0.15400300E-01, 0.91334700E-01, 0.80119300E-02, 0.18253200E+00, 0.62075100E-01, -.11688900E-01, -.64374600E-01, -.80714300E-01, 0.20792700E+01, 0.35740700E-03, 0.84126400E-02, -.16162100E-01, -.93248500E-03, -.19685000E-03, -.16660700E-03, 0.36823900E-02, 0.58854600E-02, -.98718900E-02, 0.13629800E-01, 0.95947100E-02, 0.17039900E+00, 0.49234600E-02, 0.14744400E-02, 0.23125500E-02, -.49435800E-03, 0.11904400E-02, -.20541500E-01, -.49182700E-01, -.16277400E-01, -.15117900E-01, 0.24803600E-02, -.10450200E-01, -.96457100E-02, 0.35611600E-03, -.15606900E-02, -.11190000E+00, -.20570400E-01, 0.70040200E-03, 0.34569900E-01, 0.12889500E+00, 0.59638400E+00, 0.22367100E-01, -.34800800E-02, 0.70401400E-01, -.16264200E-02, -.73595800E-03, 0.46371600E-03, -.29330000E-02, 0.39337300E-02, 0.16564700E-03, 0.48205300E-03, -.78476900E-02, -.22037300E-01, -.49340300E-02, 0.34238800E-02, -.12472400E+00, -.40015200E-01, -.72336000E-02, -.23019200E-03, -.54437400E-01, -.26051000E-01, 0.28782500E-02, -.30146700E-02, -.30218300E-01, -.45549700E-01, 0.30729500E-01, -.15699000E-01, 0.29927400E+00, -.36843500E-02, 0.24628800E-02, 0.26917600E-03, -.63401000E-03, -.85660400E-03, -.17299000E-03, 0.13144300E-02, -.24096700E-01, -.57892900E-03, 0.67322600E-02, -.87060400E-03, -.28724600E-02, -.44653500E-02, 0.11883800E-02, 0.47197200E-02, -.87060300E-01, -.38463100E-02, 0.37409700E+01, -.30885100E+01, 0.85682000E+00, 0.88383400E+00, -.19527800E+01, 0.16801900E+01, -.14016900E+01, 0.64059200E+00, -.55842900E+01, 0.22369300E+01, -.40396700E+00, 0.23925000E+00, 0.79102000E+00, -.18242300E+01, -.18975900E+00, 0.18147700E+00, -.64720600E+00, -.71271400E+00, -.39256000E+00, -.18669800E+00, 0.30368500E+00, 0.18890500E+00, -.13964400E+00, -.19755300E+00, -.37068800E+00, 0.16860300E+01, 0.12090300E+01, 0.84435500E+00, -.20048200E+00, -.43655400E+00, 0.13516400E+01, 0.94041000E+00, 0.46452000E+01, -.46570400E+01, -.20933900E+00, 0.35176300E+00, -.22533800E+01, 0.26520000E+00, -.33154000E+01, 0.69426100E+00, -.52948800E-01, 0.45135100E-01, 0.44809200E-01, 0.78211400E-01, -.83317300E-01, -.59633200E-01, -.53983700E+00, 0.86631400E-01, 0.62065000E+01, -.38783800E+01, 0.38664200E+00, 0.15074900E+01, -.34419300E+01, 0.39850900E+00, -.42007000E+01, 0.16542800E+01, -.48297500E+01, 0.16766300E+01, -.23986400E+00, -.15808500E+00, 0.32483800E+01, -.13750200E+01, 0.91134000E+00, 0.16524300E-02, 0.35769600E-01, 0.15564000E+00, 0.33159300E-01, -.18708400E+00, -.10413500E+00, 0.27334200E-01, -.22334000E+00, -.10732300E+00, 0.64445700E-01, -.67134300E+00, -.46088300E-01, 0.37886300E-01, 0.98292600E-02, -.75274400E-01, 0.71902300E-01, 0.22745300E+00, 0.19391800E+00, -.93680800E+00, 0.51319400E-01, 0.16104000E+01, -.80807500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.68645000E+00, 0.11945100E+00, 0.19979600E+00, 0.33578000E+00, -.21088000E+00, 0.29997200E+00, -.30284200E+00, 0.22731900E+00, 0.71088100E-01, 0.91098300E-01, 0.83013000E-01, -.69706500E-01, 0.20044900E+00, 0.11537900E-01, 0.98047500E-01, -.72189500E-01, 0.17230000E-01, 0.10076600E-01, 0.10590900E+00, -.48694500E+00, 0.12434300E+00, 0.16094000E+00, 0.42191200E+00, -.32990200E-01, -.25692200E-01, 0.42611500E-01, -.77164600E-01, 0.52804400E-01, -.23777000E-01, -.57782100E-01, 0.15060700E-01, 0.31195000E+00, -.31008700E+00, -.41045100E-01, 0.33431200E-02, 0.21382800E-02, -.55686400E-01, -.76676300E-01, -.14266700E+00, 0.42563800E-01, -.60514100E-01, 0.56949600E-02, -.11719500E-01, -.12806200E-01, -.68872900E-01, -.52538200E-01, -.25198700E+00, -.11515200E+00, -.57640900E-01, -.44235100E-01, -.60119300E+00, -.74030300E+00, -.49934500E-01, 0.41421300E-01, 0.66599500E+00, 0.91560000E-02, -.11077400E-02, 0.21410300E-03, 0.10041900E-01, -.21713400E-01, -.24230000E-01, -.12991200E+00, -.15601500E-01, -.46064500E-01, 0.92206500E-03, 0.50277200E-01, -.37714800E+00, -.51759900E-01, 0.44209300E-01, 0.74933300E-01, -.15317500E+00, -.36918500E-01, -.69686500E-02, 0.35307900E-02, 0.57353800E-01, 0.24102600E-01, 0.11833500E-01, -.71098500E-01, 0.17117500E-03, 0.49536200E+00, -.25591200E-02, -.31557000E-03, 0.52032700E-03, -.10605300E-03, 0.12708100E-02, -.66872000E-03, 0.12420200E-02, -.94359400E-02, -.91859600E-02, 0.22016100E-02, 0.13597700E-02, -.40051000E-02, 0.77509200E-02, -.17955600E-02, 0.57503800E-02, -.39377500E-01, 0.43060200E+00, -.13422000E+01, 0.74097000E+00, -.20664500E+01, 0.22757100E+01, 0.15594200E+01, 0.29143500E+01, -.30459600E+01, -.71975800E+01, -.26859800E+01, -.86626700E+00, -.29152800E+00, 0.81336800E+00, -.35309700E+01, -.86235500E+00, -.66167500E+00, -.13356600E+01, 0.26555500E+01, 0.21058900E+00, -.14585200E+00, -.33565800E+00, -.42123500E+00, -.14872200E+01, -.38148000E+00, -.30449100E+01, 0.48591500E+00, 0.86485800E+00, 0.23208100E+01, 0.66367400E+00, -.12867800E+01, 0.13005800E+01, 0.31895100E+01, -.29475400E+02, 0.26751500E+01, 0.61473700E+01, 0.97449400E+01, -.16002500E+01, -.15589600E+02, -.84075000E+01, 0.96535900E+01, -.25037500E-01, -.60235100E-01, -.14121200E-02, 0.72966200E-01, -.58527200E-01, -.45406900E-01, 0.36161800E-01, -.12191000E-01, -.13143300E+02, 0.37988400E+01, 0.18385300E+01, 0.34970400E+01, -.57280000E+00, -.70737400E+01, -.40156300E+01, 0.30672800E+01, 0.13264300E+01, 0.25445900E+01, -.21957900E+01, -.21170600E+01, 0.40471000E+00, 0.24957300E+01, 0.22526500E+01, -.19605600E+01, -.32718300E-01, -.53847600E+00, -.93571300E-02, 0.10518600E+00, -.54693300E+00, 0.58838800E+00, 0.58974500E-01, -.46670500E+00, -.13406400E-01, -.45959700E+00, 0.20312200E-01, -.32212600E-02, -.85368200E-02, -.11260000E+01, -.92844200E+00, 0.51862500E+00, 0.96217400E+00, -.21848500E+01, -.53501500E-02, 0.96984700E+00, 0.61073100E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.37394600E+00, 0.14298500E+00, 0.56087300E-01, 0.82198000E-01, -.21954300E-01, 0.93716900E-01, -.16487400E+00, 0.15633300E+00, 0.35769200E-01, -.70054100E-02, -.36353500E-01, 0.51914400E-01, -.15174000E+00, -.10707400E-01, -.13801300E+00, 0.40447600E-01, -.23355600E-01, 0.84143200E-01, 0.12544000E-01, 0.20982400E+00, -.20300800E-01, 0.76088700E-02, 0.17671300E+00, -.58756300E-02, 0.35897300E-01, 0.26774600E-01, -.56642500E-01, -.70222600E-01, 0.10971400E+00, -.93129400E-02, -.25222300E-01, 0.63312700E-02, -.26416400E+00, -.36904500E-01, -.86091100E-04, -.22285900E-01, -.69804500E-01, 0.15741700E-01, 0.62817300E-01, 0.43877700E-01, 0.61199100E-01, -.31439000E-02, 0.82369100E-02, 0.68227200E-02, 0.38646600E-02, -.91311300E-02, -.40860600E-01, -.15437700E-01, -.38218900E-01, -.32744300E-01, -.94123300E-01, -.18706000E-01, -.77533500E-02, -.90392000E-02, -.27579300E-01, 0.31763500E-03, 0.46162900E-02, -.23784400E-03, 0.46741600E-02, -.72877000E-02, -.29111400E-02, -.74978800E-02, -.71651300E-03, -.25640800E-01, -.85141000E-02, -.25801900E-01, -.11760300E+00, -.11477800E-01, -.10278900E-01, -.79346700E-02, -.95920700E-01, -.60073600E-01, 0.28783100E-02, -.14748800E-02, 0.89436600E-02, -.31986000E-02, -.56421900E-02, -.20759400E-01, 0.31544300E-02, 0.76362300E-01, 0.29075000E+01, 0.18977000E-03, 0.17246100E-03, -.38936100E-03, -.59753400E-03, 0.81365700E-03, 0.35761400E-04, -.26512100E-02, 0.64537800E-02, -.11890200E-02, -.27826300E-03, -.30092800E-02, 0.68227100E-03, 0.34636700E-02, 0.16025700E-02, -.11689900E-01, 0.65533100E+01, -.37198600E+01, 0.73731500E+00, 0.13206800E+01, -.20599900E+01, 0.12160600E+01, -.21110100E+01, 0.10698900E+01, -.16059500E+01, 0.96986200E+00, -.19653600E+00, -.19144000E-01, 0.79639000E+00, -.82742700E+00, 0.98334000E-01, 0.10750200E+00, -.85101600E+00, -.12215900E+00, -.20214800E+00, 0.41932900E+00, -.77413100E-01, -.15707900E+00, -.10727500E+01, 0.30132500E+00, -.18744900E+01, 0.22556700E+01, 0.91604400E+00, 0.83063000E+00, -.79861800E-01, -.12693300E+01, -.24385600E+00, 0.97983300E+00, -.81593000E+01, 0.57449400E+00, 0.15483400E+01, 0.34884700E+01, -.39518700E+00, -.44705200E+01, -.32075200E+01, 0.37933700E+01, -.58601900E-01, 0.25989000E-01, 0.14786100E-01, 0.44553500E-01, -.32847400E-01, -.48326900E-01, -.29460200E-01, 0.21369600E-01, -.16245800E+01, -.86084800E+00, 0.76423900E+00, 0.23917400E+01, -.15001500E+01, -.18994400E+01, -.33698000E+01, 0.25186800E+01, -.94376800E+00, 0.65274600E-01, 0.10976600E+01, 0.12418200E+01, -.24795800E+01, -.38935600E+00, -.11151900E+01, 0.12238800E+01, 0.30068500E-01, -.10019800E+00, 0.10166900E-02, -.72513200E-01, -.25621100E+00, 0.18867500E+00, -.54217400E-01, -.23261500E+00, -.39705400E-03, -.11510200E+00, 0.32652800E-02, -.16968300E-02, 0.13907000E-02, -.76243500E-01, -.12095200E+00, 0.24179700E+00, 0.51711900E-01, -.48569300E+00, 0.11494400E-01, 0.74183100E+00, 0.58526600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13387900E+00, 0.56999800E-01, 0.52247100E-01, 0.44231600E-01, 0.58261500E-02, -.11741900E-02, 0.64054800E-02, -.13512800E-01, 0.16303400E-02, 0.46582600E-01, -.12179100E-02, 0.16362900E-01, 0.89869300E-01, 0.54242800E-02, 0.88298600E-01, -.13176400E-01, 0.81250700E-02, 0.19237800E-01, 0.39224000E-01, 0.22454000E-02, 0.32366600E-01, 0.26898800E-01, 0.14620200E-01, -.87492800E-02, -.45321800E-02, 0.13627900E-02, -.49931700E-02, 0.96790300E-02, -.12368000E-01, 0.95591100E-03, -.28347400E-02, 0.38891000E-01, 0.69234400E-02, -.10978200E-02, 0.62601700E-03, 0.26884700E-02, -.14486000E-01, -.18833700E-01, -.44733300E-01, -.10923300E-02, -.10556000E-01, -.19537600E-02, -.73263300E-02, -.11683200E-01, -.34552300E-02, -.91064100E-02, 0.25154200E-01, 0.77533600E-03, -.66453000E-02, 0.83107300E-02, -.68411900E-01, 0.13104200E-01, 0.62901100E-02, 0.97298200E-02, 0.51530600E-01, 0.78186100E-02, -.17402600E-02, -.13713500E-03, 0.47477200E-02, -.13561200E-02, -.46720500E-02, 0.46456800E-02, -.15399600E-02, 0.14462700E-01, 0.44335600E-02, 0.85039300E-02, -.88999300E-02, 0.35608300E-02, 0.10472900E-01, 0.10788000E-01, 0.27713900E-01, 0.10820000E-01, -.12136600E-02, 0.98077100E-03, 0.88774400E-02, 0.85114000E-02, -.52779900E-02, 0.94263900E-02, 0.12223100E-02, 0.52018400E-01, -.16732300E-03, 0.21093100E+01, -.11384400E-04, 0.25574900E-03, 0.93725400E-05, -.34947700E-04, 0.22487200E-04, -.12911300E-02, -.11931800E-02, 0.75182200E-03, 0.20974600E-03, 0.14086600E-02, -.56720800E-03, -.25606200E-03, -.31452100E-03, -.40722500E-02, -.40284500E+01, 0.22426800E+01, -.47393500E+00, -.78474000E+00, 0.14738500E+01, -.58472200E+00, 0.15379800E+01, -.68474900E+00, 0.19898300E+01, -.63042800E+00, 0.16657300E+00, -.92788500E-01, -.44216600E+00, 0.68767900E+00, -.30398200E-01, -.14656100E-01, 0.27048000E-02, 0.43406900E-01, 0.25792700E+00, -.83642000E-02, 0.43323000E-01, 0.92537600E-01, 0.29361400E+00, -.24121900E-01, -.19369900E-01, -.46147200E+00, -.45084700E+00, -.21091500E+00, -.10035800E+00, 0.12064000E-01, -.40500500E+00, -.20387200E+00, 0.15138000E+01, 0.18289000E-01, -.11103900E+00, -.96681500E+00, 0.48256800E+00, 0.14811400E+01, 0.17559400E+01, -.10327600E+01, 0.16531700E-01, -.51228800E-02, -.84093300E-02, -.23755000E-01, 0.21963900E-01, 0.20601400E-01, 0.16142700E-02, -.45768300E-01, 0.89125500E+00, 0.13204500E+00, -.31419200E+00, -.97099400E+00, 0.64984400E+00, 0.10898900E+01, 0.15849900E+01, -.91259100E+00, 0.22097300E+01, -.68681000E+00, -.33688900E+00, -.32673900E+00, -.66185500E+00, 0.82658300E+00, 0.17354500E+00, -.34348300E+00, -.68116300E-02, 0.69852800E-01, -.13620300E-02, -.49667700E-01, 0.17990400E+00, -.10726500E+00, -.33992900E-01, 0.17434000E+00, -.28330700E-02, 0.20248000E+00, 0.34474500E-02, -.48407100E-03, -.10397000E-02, -.16465000E-01, 0.49721400E-01, -.33723400E-01, -.13563000E+00, 0.46819900E+00, -.16698700E-01, -.49889400E+00, 0.15130900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.47040000E-01, -.10010300E-01, -.15033700E-01, 0.28160000E-01, -.31516500E-02, 0.91060400E-02, 0.46141500E-01, -.52233800E-01, -.10169200E-01, -.10905900E-01, 0.46620800E-02, -.12012100E-01, 0.12090400E-02, 0.12008800E-03, -.11260300E-01, -.14897400E-01, -.87029900E-03, -.95905700E-02, -.55910400E-02, 0.23082600E-01, -.71364500E-03, 0.51002500E-02, -.19824900E-01, -.29817000E-02, -.15008000E-01, 0.25297900E-03, 0.34244400E-02, 0.71911200E-02, -.13544300E-01, 0.49051900E-02, 0.10207200E-01, 0.73002400E-01, -.14148000E-01, 0.23657100E-02, 0.68059600E-03, -.60761900E-02, -.67801100E-02, -.10385200E-03, -.50824900E-02, 0.68265900E-02, 0.12435400E-01, -.54233800E-02, -.12899400E-03, -.35372900E-02, -.55398900E-02, 0.34223300E-02, 0.13969900E-01, 0.10733500E-01, 0.12084500E-01, 0.28113700E-02, 0.12450600E+00, -.32157800E-01, 0.14512300E-01, -.84282300E-03, -.73830100E-02, 0.23090300E-02, -.17922600E-02, -.22988500E-03, -.25844700E-02, 0.16972100E-02, 0.20612500E-02, -.22811000E-02, -.15725500E-02, 0.34975500E-02, 0.17843600E-02, -.76608000E-03, 0.13331200E-01, 0.16893700E-02, 0.80012100E-03, -.29949900E-02, -.13998600E-02, 0.15777300E-02, -.29620800E-03, -.10450600E-03, 0.22082100E-02, 0.36321200E-02, 0.59044000E-03, -.19301700E-02, -.70251800E-03, -.17586800E-01, -.11734100E-04, 0.71651900E-05, 0.23686000E+00, 0.18245200E-04, -.12711700E-04, -.21419600E-04, -.10665900E-03, 0.57916400E-03, -.18077100E-03, 0.12091600E-03, 0.12235700E-03, 0.19949600E-03, -.24231200E-03, -.16479500E-03, -.44769200E-03, 0.22550600E-02, -.44618100E+00, 0.19811700E+00, -.84537700E-01, -.11263500E+00, 0.13565200E+00, -.51239300E-01, 0.16806100E+00, -.96394000E-01, 0.31738200E-01, 0.75569200E-01, 0.96445700E-01, 0.15319500E+00, -.23563800E+00, 0.50888700E-01, -.21357800E+00, 0.14277100E+00, 0.25983200E-01, -.32926000E-01, 0.85545300E-02, -.35294900E-01, 0.49713600E-01, -.37949500E-01, 0.16854100E+00, -.42854400E-01, 0.31882700E+00, -.19026300E+00, -.10376800E+00, -.99017700E-01, -.11217000E+00, 0.16553800E+00, -.27989000E-01, -.99528900E-01, 0.99834400E+00, -.92340200E-01, -.40236600E+00, -.45653100E+00, 0.49955600E-01, 0.51928900E+00, 0.15094200E+00, -.47470300E+00, 0.37581800E-02, -.53894700E-03, -.22761700E-02, -.18483600E-02, 0.45906800E-03, 0.37668200E-02, 0.10882600E-02, 0.52536800E-02, 0.82889500E+00, -.40602900E-01, -.17157200E+00, -.24908600E+00, -.28004800E-01, 0.34488400E+00, 0.89522900E-01, -.24874000E+00, 0.12194100E+00, -.18881400E+00, -.92474200E-01, -.16024200E+00, 0.39266300E+00, -.54329200E-01, 0.13183900E+00, -.14710900E+00, -.63209200E-03, 0.28536800E-01, 0.40226100E-03, -.32786100E-02, 0.27394500E-01, -.36178600E-01, -.86313700E-02, 0.22014100E-01, 0.78746800E-03, 0.19567900E-01, -.12425500E-02, 0.33896200E-03, 0.29100400E-03, 0.29961000E-01, 0.28911300E-01, -.43510300E-01, -.48925700E-01, -.37991000E-01, -.14960700E-02, -.19703000E-01, -.96456200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.62095600E-01, -.13268900E-01, -.16209000E-01, -.29865100E-01, 0.13558400E-01, -.25271300E-01, 0.24255100E-01, -.38151900E-01, -.10154500E-01, 0.85443300E-03, -.67009900E-03, -.28995800E-02, 0.61137200E-02, 0.87132100E-03, 0.30482000E-01, -.18288000E-01, 0.68637400E-02, -.74414300E-02, -.41882100E-03, -.48661100E-01, -.88334300E-02, -.90798000E-02, -.40489300E-01, -.12277200E-02, -.48248400E-02, -.18188100E-02, 0.58893900E-02, -.38100000E-03, -.12050700E-01, 0.84392100E-04, 0.60984900E-02, -.33823900E-01, 0.14082000E-01, 0.41381700E-02, -.63262000E-03, 0.39422600E-03, 0.45418600E-02, 0.14024700E-02, 0.39151600E-02, -.31945300E-02, 0.75914500E-02, -.34280100E-02, 0.48731800E-03, -.70754900E-03, 0.58187700E-02, 0.33960200E-02, 0.81472500E-02, 0.84091500E-02, 0.98310700E-02, 0.49249700E-04, 0.78549100E-01, -.27628600E-01, 0.87314800E-02, -.34186900E-02, -.18720400E-01, -.61092300E-02, -.17707300E-02, -.42372800E-04, -.31604200E-02, 0.40220500E-02, 0.28734600E-02, 0.28664500E-02, -.11064300E-02, 0.29441000E-02, 0.87642900E-02, 0.22445400E-02, 0.67398300E-02, -.25130600E-02, 0.19998200E-02, -.55903900E-03, 0.15028900E-01, 0.10487200E-01, -.73650100E-03, 0.28341200E-03, -.28469400E-03, 0.13461800E-02, 0.88685900E-03, 0.25417700E-02, -.14018200E-02, -.14428400E-01, -.15574200E-03, -.15251000E-04, -.74603200E-06, 0.20830000E+00, 0.59726000E-04, -.14429500E-03, -.89024500E-04, 0.50446300E-03, -.14298100E-02, 0.25189300E-03, 0.14421300E-03, 0.51097400E-03, -.27428600E-03, -.61667000E-03, -.55017600E-03, 0.21639000E-02, -.10133900E+01, 0.62275100E+00, -.11570800E+00, -.14284600E+00, 0.24367000E+00, -.17611500E+00, 0.23591800E+00, -.10654900E+00, 0.11928400E+00, 0.14361500E+00, 0.13179900E+00, 0.12539000E+00, -.23056200E+00, 0.10069800E+00, -.88112900E-01, 0.12343300E+00, 0.25515100E+00, -.28026600E-01, -.46565500E-02, -.83919000E-01, 0.35290000E-01, 0.81683400E-01, 0.23415100E+00, -.62573800E-01, 0.51565400E+00, -.54126800E+00, -.19285900E+00, -.15969700E+00, -.33063100E-01, 0.28305200E+00, 0.31362800E-01, -.16294500E+00, 0.20183700E+01, -.17246300E+00, -.48067900E+00, -.78923000E+00, 0.11307900E+00, 0.11072100E+01, 0.60676200E+00, -.82116700E+00, 0.95298300E-02, -.27797700E-02, -.20226700E-02, -.63607300E-02, 0.55684000E-02, 0.90683300E-02, 0.56848200E-02, -.14655300E-02, 0.11593700E+01, -.13638000E+00, -.22569500E+00, -.44716800E+00, 0.71636300E-01, 0.60196300E+00, 0.37667600E+00, -.44588400E+00, 0.98078300E-01, 0.35190300E-01, -.11323000E+00, -.93426100E-01, 0.38297000E+00, -.10401700E+00, -.67116300E-01, -.70932100E-01, -.63556300E-02, 0.44273700E-01, -.60494300E-04, 0.99056300E-02, 0.70540500E-01, -.50689000E-01, 0.70118100E-02, 0.63758400E-01, 0.27780600E-03, 0.35928600E-01, -.81571800E-03, 0.43448700E-03, -.17324000E-03, 0.32498700E-01, 0.45091900E-01, -.50131200E-01, -.12584500E-01, 0.99337000E-01, -.23768100E-02, -.93728600E-01, -.11072100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.48506800E-01, -.27014900E-01, 0.75286800E-03, -.30745400E-02, 0.19363900E-01, -.33574900E-02, 0.28884900E-02, -.19045600E-02, 0.66412200E-03, -.24017600E-02, 0.12758900E-01, -.15654300E-01, 0.21074200E-01, 0.16845500E-02, 0.13376800E-01, 0.32602000E-03, 0.32224200E-02, -.21380800E-01, -.11597200E-01, -.17758400E-01, -.91509600E-03, 0.35542900E-02, -.74738800E-02, 0.63812900E-03, -.51570000E-02, -.25503300E-02, 0.64294900E-02, 0.10448400E-01, -.16839700E-01, 0.12985700E-02, 0.48675900E-02, -.57246600E-02, 0.35997500E-01, 0.46000000E-02, 0.34810000E-03, 0.31564900E-02, 0.12441100E-01, -.35864600E-02, -.91020300E-02, -.92124900E-02, -.13906400E-01, 0.21222300E-02, -.48462400E-03, -.22582400E-03, 0.33941300E-04, -.96697100E-03, -.14197600E-01, -.58959100E-02, -.64930600E-03, 0.32333300E-02, 0.13614700E-01, -.28889800E-01, 0.44727700E-02, 0.32847000E-03, 0.92937800E-01, -.43443100E-03, -.65193800E-03, 0.13602900E-03, -.10243800E-02, 0.46472200E-03, -.17482100E-02, 0.13145000E-02, -.94514400E-03, 0.87168200E-02, 0.11472600E-02, 0.68061200E-02, 0.16590400E-01, 0.25067500E-03, 0.18905000E-03, 0.34955100E-02, 0.12820800E-01, 0.10308100E-01, -.14314700E-02, 0.69961200E-03, -.87569100E-04, -.26067100E-03, 0.27858500E-02, 0.13609300E-02, -.53559300E-03, -.14860900E-01, -.31162700E-03, -.79564000E-05, -.75819700E-04, 0.57104200E-03, 0.20359400E+00, -.28084300E-03, 0.64490800E-05, 0.51446300E-03, -.28394600E-02, 0.67084600E-03, 0.80319900E-04, 0.54354700E-03, 0.17006500E-03, -.11138600E-02, -.17544500E-03, 0.20394800E-02, -.16086000E+01, 0.86366200E+00, -.82261600E-01, -.42355700E+00, 0.63631900E+00, -.17161200E+00, 0.68162700E+00, -.40497300E+00, -.27822300E+00, -.15431400E+00, -.39559300E-01, 0.13598200E-01, -.53043600E-01, -.14550200E+00, -.57105500E-02, -.34456100E-01, 0.28391400E+00, 0.12339100E+00, 0.33066400E-01, -.17146000E+00, 0.36674400E-01, 0.14391000E+00, 0.25606300E+00, -.12993300E+00, 0.45716500E+00, -.72264300E+00, -.17132000E+00, -.63112600E-01, 0.11200600E+00, 0.37339700E+00, 0.17061100E+00, -.71601300E-01, 0.27308900E+00, 0.64602000E-01, 0.16609700E-01, -.21155800E+00, 0.19193400E-01, 0.29898900E+00, 0.43072100E+00, -.27561800E+00, 0.12184800E-01, -.89041600E-02, -.28099700E-02, -.49108600E-02, 0.53957600E-02, 0.96195100E-02, 0.86336400E-02, 0.19913100E-03, -.41970800E+00, 0.42112600E+00, -.29192400E-01, -.25388300E+00, 0.26833600E+00, 0.72427300E-01, 0.59111400E+00, -.29953200E+00, -.33274000E-01, 0.45341000E+00, -.18765700E+00, -.18505600E+00, 0.52506600E+00, 0.11710600E+00, 0.77787000E-01, -.16119800E+00, -.12276100E-01, 0.79274000E-03, -.68756100E-03, 0.29644700E-01, 0.22586300E-01, -.20461400E-01, 0.26088600E-01, 0.23093100E-01, -.21797100E-03, 0.66876500E-04, -.45665300E-03, 0.44660600E-03, -.78898800E-03, -.57558400E-01, -.95869000E-02, -.51398200E-01, 0.86473800E-01, -.63557300E-02, -.14419400E-02, -.84925500E-01, -.15186100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13313100E+00, 0.47474600E-01, 0.24122200E-01, 0.42265500E-01, -.70069800E-02, 0.77245600E-02, 0.38691700E-01, -.32273000E-01, 0.17113100E-02, 0.17201900E-01, -.57799800E-02, 0.12011200E-01, 0.35352800E-01, 0.15805300E-02, 0.72034000E-02, -.55730900E-02, -.28991500E-02, 0.22820000E-01, 0.26291400E-01, 0.15057500E-02, 0.26603200E-01, 0.17760200E-01, 0.43956200E-02, -.49830300E-02, -.71536900E-02, 0.46152700E-03, -.23212800E-02, 0.74149200E-02, -.23946200E-02, 0.72761500E-02, -.17265300E-02, 0.10145900E+00, -.12741700E-01, -.14574200E-02, 0.81217100E-03, -.27059400E-02, -.20373900E-01, -.79359600E-02, -.27142400E-01, 0.11780100E-01, 0.74455000E-02, -.48929600E-02, -.49730800E-02, -.10725700E-01, -.92837200E-02, -.18531700E-02, 0.51167600E-01, 0.10370400E-01, 0.91692900E-03, 0.94159600E-02, 0.14164000E-01, 0.25527300E-01, 0.76672900E-02, 0.78173700E-02, -.42955400E-01, 0.12890900E-01, -.75238100E-03, -.28790900E-03, 0.35750100E-02, -.16905300E-02, -.14754600E-02, 0.45931100E-02, -.68296800E-04, 0.74611700E-02, -.25158100E-02, -.22622100E-02, 0.12765400E-01, 0.84199500E-02, 0.38492200E-02, 0.13099900E-02, 0.10668200E-01, -.12343900E-02, 0.10922000E-02, -.45025600E-03, 0.27864500E-02, 0.42975600E-02, -.39762100E-02, 0.69245200E-02, 0.36358500E-02, 0.28393700E-01, 0.28192700E-03, 0.61687500E-04, -.25564700E-03, 0.14086000E-03, -.89082600E-03, 0.19429600E+01, -.76433400E-05, -.72770300E-03, 0.27971300E-02, -.31575500E-03, -.11175600E-03, 0.46962900E-03, -.65233600E-03, 0.11033900E-02, -.85394400E-04, -.21885800E-02, -.13364700E+01, 0.69295500E+00, -.28132000E+00, -.12909400E+00, 0.41571100E+00, -.30653000E+00, 0.40949600E+00, -.39983300E-01, 0.18576000E+01, -.34661200E+00, 0.14195100E+00, -.80353600E-01, -.28883300E+00, 0.74331000E+00, -.28535400E-01, 0.87576300E-02, -.39271100E+00, -.15471000E+00, 0.16323100E+00, 0.15059500E+00, 0.47738000E-01, -.15502000E+00, 0.62737000E-01, 0.10077200E+00, -.34684900E+00, 0.44377300E+00, -.17840800E+00, -.15264000E+00, -.27677900E+00, -.30467900E+00, -.53769800E+00, -.18972500E+00, 0.14127200E+01, -.68646900E-01, -.32123300E+00, -.73750900E+00, 0.30218300E+00, 0.10102500E+01, 0.90005800E+00, -.75351100E+00, -.58685300E-03, 0.72359000E-02, -.36336500E-02, -.12694700E-01, 0.85287000E-02, 0.42787100E-02, -.49454900E-02, -.25455200E-01, 0.10110500E+01, -.24199900E+00, -.23139600E+00, -.53797900E+00, 0.28802600E+00, 0.74059900E+00, 0.72061100E+00, -.46488200E+00, 0.17009200E+01, -.11641600E+01, -.10480100E+00, -.20934300E+00, -.63206400E+00, 0.54705300E+00, 0.31439500E+00, -.24182100E+00, 0.10968200E-01, 0.51940500E-01, 0.27791100E-03, -.57473600E-01, 0.94335600E-01, -.68927200E-01, -.47648800E-01, 0.86501000E-01, -.86904500E-03, 0.13962600E+00, 0.15180100E-02, -.60568600E-03, 0.53744700E-03, 0.78149900E-01, 0.64276500E-01, -.16849600E-01, -.24349700E+00, 0.28745600E+00, 0.21578800E-02, -.28681000E+00, 0.17369800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.37850600E-02, -.89243100E-02, 0.64097500E-02, 0.33995100E-01, -.52535800E-02, 0.52982100E-03, -.18714400E-02, -.51028900E-04, -.17960000E-01, 0.33082800E-02, 0.71403700E-03, 0.17265500E-02, 0.10840900E-01, 0.97061500E-03, 0.20959600E-01, 0.69378000E-02, -.12145700E-02, -.73907300E-02, -.93190800E-02, 0.23173100E+00, -.38997100E-03, 0.12956800E-02, -.11593100E-02, 0.47576100E-04, -.81775700E-04, -.12918000E-03, 0.28918000E-03, 0.58439600E-03, -.11460600E-02, 0.13645100E-02, 0.10748800E-02, 0.15995000E-01, 0.19888900E-02, 0.41447600E-03, 0.33704500E-03, -.17185400E-03, 0.28345500E-03, -.20139300E-02, -.53136300E-02, -.23555200E-02, -.22604500E-02, 0.57341000E-03, -.10376700E-02, -.90599200E-03, -.21104500E-03, -.53458800E-04, -.12623900E-01, -.15929300E-02, 0.75628700E-03, 0.38847000E-02, 0.92371300E-02, 0.73046200E-01, 0.19701500E-02, -.19673900E-03, 0.13417000E-02, -.24819300E-03, -.86099400E-04, 0.25746400E-04, -.14453500E-03, 0.36100300E-03, 0.73569600E-04, -.38323400E-03, -.23763000E-03, -.57824800E-03, -.89848600E-04, 0.19239900E-03, -.57056200E-02, -.22391300E-02, 0.40477300E-03, -.29960500E-03, 0.59649600E-03, -.16789800E-03, 0.46021000E-03, -.26110200E-03, -.27418900E-02, -.37529000E-02, 0.18350100E-02, 0.65300200E-03, 0.19496200E-02, -.62590800E-03, 0.63796900E-04, -.11703700E-05, -.15526800E-03, -.24473200E-03, -.19283500E-04, 0.49097800E-04, 0.21272200E+00, -.24649700E-04, 0.55912700E-03, -.13531800E-03, -.14655500E-03, -.21422300E-03, 0.54533500E-04, 0.34031700E-03, 0.13903100E-03, -.13842800E-03, 0.66542400E-01, -.46264500E-01, 0.19379500E-01, -.60507000E-02, -.28651400E-01, 0.49480000E-01, -.10930300E-01, -.19687200E-01, -.18338400E+00, 0.71093500E-01, 0.17495900E-02, 0.34689200E-01, 0.19914700E-02, -.43201300E-01, -.32061300E-02, 0.37281300E-01, -.31627200E-01, -.37818900E-01, -.52134000E-02, -.58147900E-02, 0.15963600E-01, -.37034500E-02, 0.17978400E-01, -.11022700E-01, -.46165600E-02, 0.70981100E-01, 0.58861400E-01, 0.44543400E-01, -.50376500E-01, -.16700200E-01, -.26916400E-01, 0.55895600E-01, 0.16942700E+00, -.11278600E+00, -.23261200E-01, -.75184300E-01, -.62233000E-02, 0.87499400E-01, 0.11304200E-01, -.60703100E-01, -.29336100E-02, 0.28391500E-02, 0.20471100E-02, 0.26515300E-02, -.32667400E-02, -.22811400E-02, -.19525900E-01, 0.33144600E-02, 0.44081300E+00, -.16143900E+00, -.16721700E-01, -.27692700E-01, -.10345300E+00, 0.13693400E+00, -.85734200E-01, -.16931000E-01, -.13495300E+00, 0.92842300E-02, -.25964800E-01, -.59711600E-02, 0.12636100E+00, -.49075700E-01, 0.15845700E-01, 0.48194700E-02, 0.25834100E-02, 0.20772600E-02, 0.11648200E-03, -.93448900E-03, 0.12752900E-02, -.12665800E-02, -.18777700E-02, 0.68534900E-03, 0.86417000E-04, -.18949600E-01, 0.21463900E-04, -.74122700E-04, 0.12674300E-03, -.72261200E-02, -.23446100E-03, -.60122700E-02, -.20843100E-02, 0.19436400E-03, 0.11697900E-03, 0.33851500E-01, -.32541600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.54639800E-01, -.94746000E-02, -.15910800E-01, -.26662200E-01, 0.16586000E-01, -.23881700E-01, 0.24692000E-01, -.18054800E-01, -.54903000E-02, -.74948700E-02, -.65306100E-02, 0.58821300E-02, -.16372100E-01, -.96376800E-03, -.79432400E-02, 0.55454400E-02, -.14962200E-02, -.63187700E-03, -.81378800E-02, 0.38598700E-01, -.96012900E-02, -.12947800E-01, -.33726400E-01, 0.27439400E-02, 0.20921200E-02, -.34128100E-02, 0.59907900E-02, -.38520000E-02, 0.21433700E-02, 0.40704000E-02, -.17579800E-02, -.24912900E-01, 0.26500200E-01, 0.33519100E-02, -.24387100E-03, 0.15022700E-03, 0.49461500E-02, 0.58833700E-02, 0.11189100E-01, -.39168800E-02, 0.38585900E-02, -.18463000E-03, 0.73645100E-03, 0.11638200E-02, 0.60428600E-02, 0.41988100E-02, 0.20295000E-01, 0.98043400E-02, 0.50416400E-02, 0.32921100E-02, 0.42645200E-01, 0.56141000E-01, 0.33027300E-02, -.33221100E-02, -.52099300E-01, -.87949100E-03, 0.73972000E-04, -.14834100E-04, -.70367300E-03, 0.17788500E-02, 0.18404200E-02, 0.10338300E-01, 0.11632000E-02, 0.36974300E-02, -.13740700E-03, -.40581900E-02, 0.30017400E-01, 0.49051600E-02, -.27289600E-02, -.55299300E-02, 0.10566700E-01, 0.25009400E-02, 0.49370500E-03, -.23974000E-03, -.41589800E-02, -.98755400E-03, -.16111700E-02, 0.49070500E-02, -.60333100E-03, -.16836700E-01, 0.46542800E-04, 0.92389100E-05, -.99664100E-04, 0.57727500E-04, -.39265400E-03, 0.13488700E-04, -.34784300E-03, 0.38467600E+00, 0.50206800E-03, -.12854500E-03, -.70082600E-04, 0.25539200E-03, -.48385300E-03, 0.59577900E-04, -.36037400E-03, 0.23068500E-02, 0.13803300E+00, -.71572400E-02, -.29907900E-01, 0.16560100E+00, -.20825400E+00, -.77312600E-01, -.24259400E+00, 0.22419100E+00, 0.42620000E+00, 0.12498500E+00, 0.40987600E-01, 0.64593200E-02, -.35317400E-01, 0.20195700E+00, 0.46894400E-01, 0.24061800E-01, 0.90425400E-01, -.15537500E+00, -.21569300E-01, 0.16200100E-01, 0.50356100E-02, 0.21965400E-01, 0.65778100E-01, 0.32638400E-01, 0.15894500E+00, -.14298500E-01, -.36913600E-01, -.14986400E+00, -.19251800E-02, 0.80068600E-01, -.40329100E-01, -.20371600E+00, 0.18358200E+01, -.24701900E+00, -.35867300E+00, -.54840700E+00, 0.48637200E-01, 0.91233500E+00, 0.43043400E+00, -.54110900E+00, 0.16996300E-02, 0.29842600E-02, 0.14336100E-03, -.43552200E-02, 0.37291300E-02, 0.26784400E-02, -.19817800E-02, 0.57846600E-03, 0.70999200E+00, -.22825900E+00, -.10088800E+00, -.17984400E+00, 0.24772100E-01, 0.37417900E+00, 0.20523900E+00, -.15835600E+00, -.16784000E+00, -.98604000E-01, 0.14323600E+00, 0.12905200E+00, -.18262800E-01, -.16997900E+00, -.12977500E+00, 0.11495700E+00, 0.17033900E-02, 0.27803100E-01, 0.55151400E-03, -.50309100E-02, 0.25442200E-01, -.29178300E-01, -.21512100E-02, 0.21414000E-01, 0.79833500E-03, 0.22474400E-01, -.12038200E-02, 0.19086400E-03, 0.50158300E-03, 0.69883200E-01, 0.51131300E-01, -.25134800E-01, -.45766400E-01, 0.11958400E+00, 0.50999000E-03, -.45896800E-01, 0.25864300E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13761300E+01, 0.52374300E+00, 0.20573800E+00, 0.30196800E+00, -.79896800E-01, 0.34326400E+00, -.60345200E+00, 0.57201200E+00, 0.13139800E+00, -.24572600E-01, -.13311900E+00, 0.19012500E+00, -.55361900E+00, -.39138100E-01, -.50220900E+00, 0.14780000E+00, -.85151000E-01, 0.30806200E+00, 0.46716000E-01, 0.76582000E+00, -.74229000E-01, 0.28423300E-01, 0.64713600E+00, -.21480200E-01, 0.13100700E+00, 0.98012800E-01, -.20753800E+00, -.25621300E+00, 0.40140500E+00, -.34541300E-01, -.92960500E-01, 0.21153000E-01, -.96328500E+00, -.13492300E+00, -.26646200E-03, -.81068200E-01, -.25425900E+00, 0.57196900E-01, 0.23019300E+00, 0.15944200E+00, 0.22167400E+00, -.10754800E-01, 0.29953300E-01, 0.25950100E-01, 0.14586100E-01, -.33757700E-01, -.15174100E+00, -.57048900E-01, -.14045800E+00, -.12000700E+00, -.35874100E+00, -.67385400E-01, -.29680600E-01, -.33005200E-01, -.95210300E-01, 0.46432600E-03, 0.16956300E-01, -.86822300E-03, 0.17303600E-01, -.26814300E-01, -.10934000E-01, -.27444800E-01, -.25967700E-02, -.93893500E-01, -.31519900E-01, -.94009100E-01, -.43075900E+00, -.42224700E-01, -.38272000E-01, -.29066100E-01, -.35072100E+00, -.21927100E+00, 0.10284500E-01, -.52720200E-02, 0.33092700E-01, -.11043200E-01, -.21004100E-01, -.76177600E-01, 0.11140000E-01, 0.27908500E+00, 0.26874600E-02, 0.33131600E-03, 0.26841800E-02, -.67312200E-02, -.10666800E-01, 0.15056200E-02, 0.58538100E-03, -.25113700E-01, 0.29284700E+01, -.42367000E-02, -.99359000E-03, -.10905300E-01, 0.24590700E-02, 0.12477300E-01, 0.57943200E-02, -.42551100E-01, 0.23866000E+02, -.13533100E+02, 0.26908100E+01, 0.47990500E+01, -.75023000E+01, 0.44400900E+01, -.76804600E+01, 0.38858800E+01, -.59051700E+01, 0.35444400E+01, -.72563800E+00, -.65422600E-01, 0.29084100E+01, -.30486800E+01, 0.36043100E+00, 0.39326200E+00, -.30469900E+01, -.44217900E+00, -.74115700E+00, 0.15132100E+01, -.28778800E+00, -.54344300E+00, -.38938000E+01, 0.10896600E+01, -.67837500E+01, 0.81414800E+01, 0.33383800E+01, 0.30180300E+01, -.25142100E+00, -.45772900E+01, -.84760000E+00, 0.35617800E+01, -.29642500E+02, 0.20372900E+01, 0.56533000E+01, 0.12711500E+02, -.14520300E+01, -.16234800E+02, -.11654600E+02, 0.13827000E+02, -.21241000E+00, 0.93713700E-01, 0.53764900E-01, 0.16207900E+00, -.11877200E+00, -.17503300E+00, -.10650600E+00, 0.77613300E-01, -.59054000E+01, -.31394700E+01, 0.27889800E+01, 0.87230300E+01, -.54776400E+01, -.69037900E+01, -.12264600E+02, 0.91870300E+01, -.35586200E+01, 0.34661300E+00, 0.40225000E+01, 0.45594900E+01, -.90251300E+01, -.14597600E+01, -.41163200E+01, 0.44936900E+01, 0.10791700E+00, -.36551100E+00, 0.36216600E-02, -.26225900E+00, -.93346400E+00, 0.68638500E+00, -.19478300E+00, -.84678400E+00, -.14919900E-02, -.42067600E+00, 0.11895700E-01, -.61412200E-02, 0.49780300E-02, -.28141700E+00, -.44137400E+00, 0.87979500E+00, 0.21106500E+00, -.17648600E+01, 0.42503100E-01, 0.27092700E+01, 0.21273000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.49370500E+00, 0.20849200E+00, 0.19117900E+00, 0.16160600E+00, 0.21064800E-01, -.42999100E-02, 0.23218600E-01, -.49375400E-01, 0.72990800E-02, 0.17309400E+00, -.46240500E-02, 0.59167900E-01, 0.33688000E+00, 0.20282700E-01, 0.33031900E+00, -.46555500E-01, 0.31156500E-01, 0.67584000E-01, 0.14438800E+00, -.74075400E-02, 0.11651500E+00, 0.99429600E-01, 0.60348900E-01, -.31770700E-01, -.16806900E-01, 0.46882000E-02, -.18871400E-01, 0.35733600E-01, -.45547200E-01, 0.46802700E-02, -.87456800E-02, 0.14360400E+00, 0.25480600E-01, -.41253800E-02, 0.24301500E-02, 0.87345100E-02, -.52651700E-01, -.68969400E-01, -.16384300E+00, -.47374300E-02, -.41892400E-01, -.59948600E-02, -.26787800E-01, -.40293800E-01, -.13349800E-01, -.34081300E-01, 0.87255300E-01, 0.21759900E-02, -.25719000E-01, 0.30370800E-01, -.26710700E+00, 0.60453200E-01, 0.22037000E-01, 0.35954100E-01, 0.19006100E+00, 0.28491300E-01, -.60782600E-02, -.55391700E-03, 0.17867300E-01, -.57590600E-02, -.17467500E-01, 0.14100800E-01, -.52140700E-02, 0.51224700E-01, 0.15772100E-01, 0.31322600E-01, -.31338800E-01, 0.12097800E-01, 0.35927600E-01, 0.38852200E-01, 0.10266700E+00, 0.40640400E-01, -.48197900E-02, 0.38093700E-02, 0.32834200E-01, 0.31527700E-01, -.18599700E-01, 0.34567900E-01, 0.41976100E-02, 0.18679600E+00, -.69353900E-03, 0.28249100E-03, -.12159200E-03, 0.46661900E-02, 0.42972300E-03, -.11099900E-03, 0.47517000E-03, -.11950400E-01, -.17410500E-02, 0.21119700E+01, 0.83296300E-03, 0.52736100E-02, -.19808900E-02, -.12377600E-02, -.11239400E-02, -.14467100E-01, -.15128900E+02, 0.84568200E+01, -.17713000E+01, -.30332300E+01, 0.55700700E+01, -.21945500E+01, 0.58053700E+01, -.26751500E+01, 0.70914200E+01, -.23141500E+01, 0.59856700E+00, -.32215900E+00, -.15881300E+01, 0.24564700E+01, -.83657900E-01, -.45625700E-01, 0.51482700E-01, 0.21510000E+00, 0.95513000E+00, -.69629300E-01, 0.16705500E+00, 0.35648200E+00, 0.11134400E+01, -.11958400E+00, 0.70339100E-01, -.18714900E+01, -.16812200E+01, -.78753200E+00, -.36233800E+00, 0.13087200E+00, -.14541600E+01, -.76670000E+00, 0.53079000E+01, 0.18576600E+00, -.37264900E+00, -.36418100E+01, 0.19403300E+01, 0.54396200E+01, 0.66036200E+01, -.39002100E+01, 0.62997600E-01, -.20795700E-01, -.31113600E-01, -.88281300E-01, 0.81823000E-01, 0.77838300E-01, 0.85632200E-02, -.16761700E+00, 0.32303300E+01, 0.60280900E+00, -.11379100E+01, -.36377000E+01, 0.24838800E+01, 0.40496600E+01, 0.59389000E+01, -.34274400E+01, 0.81283500E+01, -.24503100E+01, -.12476700E+01, -.11827100E+01, -.23702300E+01, 0.30421900E+01, 0.64265100E+00, -.12250300E+01, -.27858800E-01, 0.25749400E+00, -.51797900E-02, -.17423200E+00, 0.66799400E+00, -.40115800E+00, -.11709000E+00, 0.64815000E+00, -.10457100E-01, 0.74501400E+00, 0.12551200E-01, -.16817500E-02, -.40151200E-02, -.76411500E-01, 0.18389700E+00, -.13208300E+00, -.47992100E+00, 0.17883800E+01, -.61090000E-01, -.18784400E+01, 0.52595900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17347700E+00, -.36797600E-01, -.55362800E-01, 0.10361800E+00, -.11946200E-01, 0.33493700E-01, 0.17011500E+00, -.19182500E+00, -.37177200E-01, -.39404800E-01, 0.16871500E-01, -.43008000E-01, 0.52158700E-02, 0.47160800E-03, -.39210400E-01, -.54017500E-01, -.28254000E-02, -.35792200E-01, -.20665900E-01, 0.80905400E-01, -.34555100E-02, 0.18200400E-01, -.75921500E-01, -.10906800E-01, -.54371600E-01, 0.68196200E-03, 0.13288200E-01, 0.26368800E-01, -.50532500E-01, 0.18019900E-01, 0.37086800E-01, 0.25728600E+00, -.48539000E-01, 0.89200100E-02, 0.23942500E-02, -.22418300E-01, -.24273400E-01, -.35073600E-03, -.18407900E-01, 0.24104400E-01, 0.44996200E-01, -.19504800E-01, -.10068500E-03, -.12731500E-01, -.20455900E-01, 0.12448900E-01, 0.51017500E-01, 0.39009000E-01, 0.43670800E-01, 0.10000600E-01, 0.45012000E+00, -.12004200E+00, 0.52150700E-01, -.30609000E-02, -.23479400E-01, 0.77257200E-02, -.65550300E-02, -.83291400E-03, -.95963800E-02, 0.63222300E-02, 0.75556800E-02, -.78587900E-02, -.58138200E-02, 0.12554000E-01, 0.62977700E-02, -.24693900E-02, 0.48814500E-01, 0.59629300E-02, 0.23444400E-02, -.10982800E-01, -.36885100E-02, 0.67571100E-02, -.11330000E-02, -.35611300E-03, 0.79411500E-02, 0.13444800E-01, 0.20838500E-02, -.68078400E-02, -.28402200E-02, -.64783300E-01, -.54507200E-04, 0.21777900E-04, 0.45946800E-05, 0.35423100E-03, -.19760700E-03, -.50699600E-04, -.18376400E-02, 0.55554000E-02, -.25828200E-03, 0.20801500E-03, 0.23731700E+00, 0.76783400E-03, -.89426500E-03, -.66695600E-03, -.16534600E-02, 0.83217800E-02, -.16507200E+01, 0.74855900E+00, -.31345500E+00, -.41207400E+00, 0.50013000E+00, -.20341300E+00, 0.60304700E+00, -.35177600E+00, 0.12914700E+00, 0.27466400E+00, 0.35404900E+00, 0.55323300E+00, -.85231200E+00, 0.19824500E+00, -.75720900E+00, 0.51631400E+00, 0.11335900E+00, -.12071900E+00, 0.28794900E-01, -.13669100E+00, 0.18256500E+00, -.13211800E+00, 0.61995400E+00, -.16281700E+00, 0.11825300E+01, -.71921500E+00, -.38537200E+00, -.36979800E+00, -.40364400E+00, 0.61260700E+00, -.95799900E-01, -.37495500E+00, 0.36628400E+01, -.28912200E+00, -.14781400E+01, -.17050800E+01, 0.22415600E+00, 0.19313600E+01, 0.62060800E+00, -.17739800E+01, 0.14428300E-01, -.22150100E-02, -.85871500E-02, -.74261400E-02, 0.23335200E-02, 0.14289100E-01, 0.44868900E-02, 0.18525500E-01, 0.30013700E+01, -.12360000E+00, -.62172500E+00, -.92603900E+00, -.70803700E-01, 0.12707300E+01, 0.37664300E+00, -.92493800E+00, 0.43219300E+00, -.69047200E+00, -.32828300E+00, -.56828200E+00, 0.14247900E+01, -.21249800E+00, 0.47124300E+00, -.51957800E+00, -.27471600E-02, 0.10575600E+00, 0.14497700E-02, -.10834300E-01, 0.10515800E+00, -.13618700E+00, -.30450000E-01, 0.85378100E-01, 0.28684300E-02, 0.73991700E-01, -.45538700E-02, 0.12578100E-02, 0.10397600E-02, 0.11458900E+00, 0.10879300E+00, -.15957300E+00, -.17721300E+00, -.11711100E+00, -.54875000E-02, -.85808500E-01, -.35130600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22897900E+00, -.48770500E-01, -.59696000E-01, -.10959500E+00, 0.49344300E-01, -.92790400E-01, 0.89750300E-01, -.13984600E+00, -.37028600E-01, 0.38250700E-02, -.27636000E-02, -.99243400E-02, 0.24129700E-01, 0.32916600E-02, 0.11375800E+00, -.66454600E-01, 0.25468800E-01, -.27538900E-01, -.15500600E-02, -.17841900E+00, -.32741400E-01, -.33700800E-01, -.15088200E+00, -.45655800E-02, -.17418000E-01, -.69415200E-02, 0.22139100E-01, -.15243100E-02, -.44782800E-01, 0.72832600E-03, 0.22438100E-01, -.12631300E+00, 0.54206900E-01, 0.15482800E-01, -.23323400E-02, 0.12235300E-02, 0.16980000E-01, 0.51164100E-02, 0.13874000E-01, -.12416200E-01, 0.27723300E-01, -.12441500E-01, 0.18901700E-02, -.30018800E-02, 0.20559900E-01, 0.12401300E-01, 0.31165600E-01, 0.31291600E-01, 0.36043200E-01, 0.40318300E-03, 0.28698000E+00, -.98513500E-01, 0.31448100E-01, -.12431500E-01, -.69889200E-01, -.22819500E-01, -.65036200E-02, -.15944000E-03, -.11754300E-01, 0.14785100E-01, 0.10694500E-01, 0.10851500E-01, -.39688300E-02, 0.10760400E-01, 0.32146000E-01, 0.85179500E-02, 0.26359400E-01, -.96723700E-02, 0.67714100E-02, -.23232200E-02, 0.56265100E-01, 0.38909800E-01, -.27700600E-02, 0.10787100E-02, -.89823500E-03, 0.51002500E-02, 0.33126000E-02, 0.97255800E-02, -.54566700E-02, -.55051100E-01, -.58720500E-03, -.58862700E-04, 0.17401600E-04, 0.12768500E-02, 0.11206200E-02, -.28289200E-03, -.15527700E-02, 0.49943300E-02, -.18411600E-02, 0.44502600E-03, 0.23766000E-02, 0.21012700E+00, -.99610600E-03, -.23143100E-02, -.20373300E-02, 0.81201800E-02, -.37810700E+01, 0.23278500E+01, -.42947800E+00, -.54053100E+00, 0.92594600E+00, -.65764400E+00, 0.88694900E+00, -.40737000E+00, 0.44227200E+00, 0.54774000E+00, 0.48607200E+00, 0.46010900E+00, -.84477700E+00, 0.37624100E+00, -.31279100E+00, 0.45452500E+00, 0.94623300E+00, -.96424700E-01, -.16106300E-01, -.31346000E+00, 0.13303000E+00, 0.30356400E+00, 0.86209200E+00, -.23601900E+00, 0.19119000E+01, -.20071900E+01, -.72135400E+00, -.58423200E+00, -.13493700E+00, 0.10419900E+01, 0.10879700E+00, -.59556900E+00, 0.72723100E+01, -.51294900E+00, -.17626600E+01, -.29006100E+01, 0.46300200E+00, 0.40360800E+01, 0.22751300E+01, -.30204600E+01, 0.35422700E-01, -.10366300E-01, -.78121000E-02, -.23733600E-01, 0.20722600E-01, 0.33657000E-01, 0.21350600E-01, -.52889900E-02, 0.41936200E+01, -.45667500E+00, -.82432400E+00, -.16465800E+01, 0.29311900E+00, 0.21995100E+01, 0.14125000E+01, -.16423200E+01, 0.39378100E+00, 0.10106000E+00, -.41214100E+00, -.32841700E+00, 0.13833500E+01, -.38312000E+00, -.26424400E+00, -.24455200E+00, -.23727700E-01, 0.16344900E+00, -.22259000E-03, 0.36185300E-01, 0.26169000E+00, -.18824300E+00, 0.25302600E-01, 0.23639000E+00, 0.10563000E-02, 0.13632000E+00, -.30788600E-02, 0.16243800E-02, -.64484800E-03, 0.11878700E+00, 0.16782500E+00, -.18441600E+00, -.50544500E-01, 0.37360100E+00, -.85977400E-02, -.35648200E+00, -.40347700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17799700E+00, -.98785300E-01, 0.30281200E-02, -.11330600E-01, 0.71551100E-01, -.11897900E-01, 0.89451700E-02, -.61828800E-02, 0.22772200E-02, -.99920900E-02, 0.47213400E-01, -.58199800E-01, 0.74410900E-01, 0.60234200E-02, 0.45760300E-01, 0.94134800E-03, 0.11408400E-01, -.78282500E-01, -.43083000E-01, -.64694900E-01, -.33838600E-02, 0.13456000E-01, -.24505900E-01, 0.23696200E-02, -.19156600E-01, -.89861100E-02, 0.22827000E-01, 0.37896400E-01, -.61030900E-01, 0.42098400E-02, 0.18010900E-01, -.18823100E-01, 0.12733200E+00, 0.16437500E-01, 0.13006200E-02, 0.11475100E-01, 0.44678100E-01, -.12716500E-01, -.32344800E-01, -.32757100E-01, -.50173400E-01, 0.73086700E-02, -.17930200E-02, -.78295700E-03, 0.54663100E-03, -.34603500E-02, -.51966600E-01, -.21406300E-01, -.19309200E-02, 0.11851600E-01, 0.60419400E-01, -.10603100E+00, 0.17896400E-01, 0.98282000E-03, 0.33750800E+00, -.50517200E-03, -.23569900E-02, 0.49473900E-03, -.36417700E-02, 0.15439000E-02, -.64243000E-02, 0.43873100E-02, -.34273500E-02, 0.32154500E-01, 0.44132600E-02, 0.24455100E-01, 0.59940100E-01, 0.11563600E-02, 0.15423500E-02, 0.12780800E-01, 0.45155200E-01, 0.36258300E-01, -.50972200E-02, 0.24875100E-02, -.39422300E-03, -.14815100E-02, 0.10322300E-01, 0.48286900E-02, -.17092400E-02, -.52910000E-01, -.11106600E-02, -.25372300E-04, -.28860200E-03, 0.20196900E-02, 0.33269300E-02, -.51003000E-03, 0.87731900E-04, 0.47448100E-02, -.34576700E-02, 0.11384800E-02, 0.11108200E-02, 0.88369800E-02, 0.20406100E+00, -.38684400E-02, -.57195700E-03, 0.69883200E-02, -.56394000E+01, 0.30040200E+01, -.27197900E+00, -.14912900E+01, 0.22474900E+01, -.57436600E+00, 0.24212000E+01, -.14327700E+01, -.10609400E+01, -.54155100E+00, -.14577400E+00, 0.47552300E-01, -.17280500E+00, -.55828000E+00, -.32104100E-01, -.12369100E+00, 0.98800200E+00, 0.44435800E+00, 0.11409600E+00, -.60610000E+00, 0.13318300E+00, 0.51343100E+00, 0.89191100E+00, -.46074800E+00, 0.15726300E+01, -.25263200E+01, -.59062500E+00, -.19340900E+00, 0.39669500E+00, 0.12965900E+01, 0.60487800E+00, -.21768500E+00, 0.73470800E+00, 0.23307200E+00, 0.11058300E+00, -.62734400E+00, 0.13046800E-01, 0.91305200E+00, 0.14091000E+01, -.84973400E+00, 0.41772500E-01, -.31240300E-01, -.95660300E-02, -.15817200E-01, 0.17816300E-01, 0.32743600E-01, 0.30152900E-01, 0.20681600E-02, -.15787200E+01, 0.15011100E+01, -.85443500E-01, -.83384400E+00, 0.90360700E+00, 0.18363500E+00, 0.20140800E+01, -.99756800E+00, -.11094800E+00, 0.16350800E+01, -.66522200E+00, -.66329000E+00, 0.18461400E+01, 0.43927200E+00, 0.27226200E+00, -.57861700E+00, -.43082100E-01, -.12970900E-02, -.24378100E-02, 0.10553700E+00, 0.71085900E-01, -.65387000E-01, 0.92687600E-01, 0.73567100E-01, -.78551800E-03, -.56791900E-02, -.15506800E-02, 0.15564100E-02, -.27951500E-02, -.21444800E+00, -.42439600E-01, -.17851700E+00, 0.31175700E+00, -.62878500E-01, -.50353100E-02, -.27254400E+00, -.53502900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49033800E+00, 0.17399300E+00, 0.88552000E-01, 0.15543900E+00, -.25481600E-01, 0.28877800E-01, 0.13986700E+00, -.11713500E+00, 0.61468300E-02, 0.63190400E-01, -.21287900E-01, 0.43723700E-01, 0.12894100E+00, 0.56961400E-02, 0.26693500E-01, -.20546500E-01, -.10362000E-01, 0.83544700E-01, 0.96966700E-01, -.32083400E-02, 0.97323500E-01, 0.64575000E-01, 0.16743200E-01, -.18338600E-01, -.25874200E-01, 0.18728400E-02, -.83751200E-02, 0.27195100E-01, -.88712500E-02, 0.27584100E-01, -.58865800E-02, 0.37214100E+00, -.49722900E-01, -.56076300E-02, 0.27586900E-02, -.10268800E-01, -.75643100E-01, -.28906000E-01, -.98748900E-01, 0.44924000E-01, 0.29059200E-01, -.18608700E-01, -.18227800E-01, -.38398100E-01, -.33736300E-01, -.65591900E-02, 0.18787900E+00, 0.36933500E-01, 0.25335500E-02, 0.34499200E-01, 0.65452300E-01, 0.81692200E-01, 0.28669700E-01, 0.28537800E-01, -.15123100E+00, 0.46527900E-01, -.27926000E-02, -.10505300E-02, 0.12288600E-01, -.57382600E-02, -.50025700E-02, 0.16228700E-01, -.64180400E-03, 0.25798300E-01, -.86844000E-02, -.84431200E-02, 0.41891900E-01, 0.29428700E-01, 0.13581800E-01, 0.54886700E-02, 0.37018100E-01, -.49627200E-02, 0.41630000E-02, -.17690700E-02, 0.96781300E-02, 0.14467100E-01, -.12604000E-01, 0.24459200E-01, 0.14823200E-01, 0.10425500E+00, 0.10747100E-02, 0.20287700E-03, -.96440400E-03, 0.33099900E-03, -.31222900E-02, 0.61534400E-03, 0.78826700E-04, -.70513100E-02, 0.36167900E-02, -.63442600E-03, -.18680700E-02, 0.75311400E-02, -.10729200E-01, 0.19467400E+01, -.10765500E-03, -.80487000E-02, -.47816000E+01, 0.24574700E+01, -.10197100E+01, -.46393600E+00, 0.14962300E+01, -.11347800E+01, 0.14490100E+01, -.14717700E+00, 0.66802300E+01, -.12654200E+01, 0.51503100E+00, -.30366600E+00, -.10134600E+01, 0.27064200E+01, -.69423200E-01, 0.17957000E-01, -.15366200E+01, -.52767900E+00, 0.59934500E+00, 0.55785700E+00, 0.18612500E+00, -.62189400E+00, 0.21571800E+00, 0.37330600E+00, -.12629900E+01, 0.16456700E+01, -.64490100E+00, -.53002400E+00, -.10687200E+01, -.11438100E+01, -.20058000E+01, -.67029100E+00, 0.48732700E+01, -.13186500E+00, -.11606900E+01, -.26623600E+01, 0.11148400E+01, 0.35215800E+01, 0.31784200E+01, -.27423100E+01, -.35041600E-02, 0.26829500E-01, -.12868600E-01, -.45132100E-01, 0.29095100E-01, 0.13884100E-01, -.19532400E-01, -.91592000E-01, 0.35434000E+01, -.84498600E+00, -.82631400E+00, -.19482100E+01, 0.10721500E+01, 0.26178500E+01, 0.25814000E+01, -.16917200E+01, 0.64160600E+01, -.43525800E+01, -.44798500E+00, -.84542900E+00, -.22241800E+01, 0.21006100E+01, 0.12718900E+01, -.94542800E+00, 0.41214600E-01, 0.18388400E+00, 0.98092800E-03, -.20073500E+00, 0.33677200E+00, -.24553500E+00, -.16755900E+00, 0.30771600E+00, -.32259100E-02, 0.50330500E+00, 0.56298100E-02, -.22563000E-02, 0.19356400E-02, 0.28481600E+00, 0.23027500E+00, -.64798800E-01, -.90549800E+00, 0.10271500E+01, 0.76223100E-02, -.10471700E+01, 0.60718200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14626400E-01, -.32472900E-01, 0.23741400E-01, 0.12523300E+00, -.19132500E-01, 0.22969100E-02, -.85116400E-02, 0.18033600E-04, -.66668900E-01, 0.12101900E-01, 0.24714700E-02, 0.57980300E-02, 0.39240300E-01, 0.35135900E-02, 0.75291200E-01, 0.25261400E-01, -.45852800E-02, -.26603200E-01, -.33821300E-01, 0.85121300E+00, -.97250800E-03, 0.49226700E-02, -.29308700E-02, -.90779500E-04, -.63160500E-03, -.13223500E-03, 0.73300400E-03, 0.18042100E-02, -.40120900E-02, 0.50830300E-02, 0.41294100E-02, 0.60574900E-01, 0.35127300E-02, 0.10365200E-02, 0.11520800E-02, -.61761700E-03, 0.25001700E-03, -.74299100E-02, -.18775400E-01, -.75113400E-02, -.69573000E-02, 0.15983000E-02, -.39078100E-02, -.32624500E-02, 0.23802900E-03, -.10330100E-03, -.46281200E-01, -.69702900E-02, 0.19395500E-02, 0.14214900E-01, 0.46301200E-01, 0.26119100E+00, 0.85976200E-02, -.11060600E-02, 0.82427400E-02, -.56704700E-03, -.32936100E-03, 0.12874000E-03, -.77853600E-03, 0.14875500E-02, 0.33877500E-03, -.12738100E-02, -.10543500E-02, -.21644400E-02, 0.11510500E-03, 0.66635300E-03, -.24518700E-01, -.89676200E-02, 0.18923000E-02, -.75902700E-03, 0.19787700E-02, -.10110800E-02, 0.18889800E-02, -.10662300E-02, -.10490900E-01, -.14765400E-01, 0.72003700E-02, 0.25559400E-02, 0.79881700E-02, 0.43265700E-04, 0.27504200E-03, 0.10146400E-05, -.62998500E-03, -.98263300E-03, -.14875800E-03, 0.20760900E-03, 0.30417000E-03, -.44791100E-03, 0.82911600E-03, -.25540100E-03, -.25195100E-02, -.40943500E-02, 0.97925700E-03, 0.73587300E-03, 0.21325400E+00, -.74933400E-03, 0.18616000E+00, -.14687900E+00, 0.65135800E-01, -.34818800E-01, -.84326200E-01, 0.18778800E+00, -.95793800E-02, -.86814000E-01, -.63825300E+00, 0.27110400E+00, 0.17905500E-01, 0.13250800E+00, -.83259800E-02, -.14415600E+00, -.20735400E-01, 0.14908700E+00, -.14817800E+00, -.15372600E+00, -.14170900E-01, -.18268100E-01, 0.70156400E-01, -.16356400E-01, 0.69310600E-01, -.41811200E-01, -.60792800E-01, 0.31308900E+00, 0.22796500E+00, 0.18110400E+00, -.21442000E+00, -.98829600E-01, -.13531900E+00, 0.22545200E+00, 0.64986200E+00, -.41497200E+00, -.87587200E-01, -.29507600E+00, -.23046200E-01, 0.34660500E+00, 0.56891900E-01, -.23779900E+00, -.12246900E-01, 0.11784800E-01, 0.80420800E-02, 0.10420900E-01, -.12863000E-01, -.93054100E-02, -.72745000E-01, 0.12296000E-01, 0.17802700E+01, -.63236900E+00, -.70535500E-01, -.11566700E+00, -.41742700E+00, 0.55912300E+00, -.33244100E+00, -.70351400E-01, -.41229700E+00, -.25094800E-01, -.11410500E+00, -.40483600E-01, 0.44775800E+00, -.14591700E+00, 0.74522300E-01, -.74398700E-03, 0.10947600E-01, 0.10922300E-01, 0.48312600E-03, -.60187700E-02, 0.99069400E-02, -.76362200E-02, -.92542700E-02, 0.73051600E-02, 0.30473100E-03, -.68062600E-01, 0.17521300E-03, -.32433500E-03, 0.53487800E-03, -.27834900E-01, -.60659600E-03, -.23565600E-01, -.19334400E-01, 0.62880100E-02, 0.13653300E-03, 0.12744000E+00, -.11438600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20156500E+00, -.34890000E-01, -.58640600E-01, -.97847400E-01, 0.60502700E-01, -.87672000E-01, 0.91300200E-01, -.65750400E-01, -.19718500E-01, -.26702900E-01, -.24380100E-01, 0.22432200E-01, -.58114000E-01, -.34503700E-02, -.27370700E-01, 0.21107400E-01, -.52384300E-02, -.24799900E-02, -.29665200E-01, 0.13979400E+00, -.35376100E-01, -.47978400E-01, -.12605600E+00, 0.98753300E-02, 0.80891300E-02, -.12788300E-01, 0.22497600E-01, -.14559900E-01, 0.74207800E-02, 0.15319900E-01, -.63511600E-02, -.92261100E-01, 0.99311700E-01, 0.12509400E-01, -.89337600E-03, 0.18371500E-03, 0.18404200E-01, 0.21574900E-01, 0.40449500E-01, -.15232500E-01, 0.13738000E-01, -.51965100E-03, 0.27717600E-02, 0.39889700E-02, 0.21405100E-01, 0.15315600E-01, 0.76567800E-01, 0.36050400E-01, 0.18044300E-01, 0.12778700E-01, 0.15318300E+00, 0.20663700E+00, 0.11268100E-01, -.11832800E-01, -.18947100E+00, -.35570600E-02, 0.29433100E-03, -.48501300E-04, -.27366900E-02, 0.65792800E-02, 0.68207900E-02, 0.38036100E-01, 0.42893900E-02, 0.13262100E-01, -.63979100E-03, -.14515200E-01, 0.11063900E+00, 0.17710900E-01, -.10510100E-01, -.20261300E-01, 0.40439400E-01, 0.10223200E-01, 0.17831500E-02, -.85958900E-03, -.15219000E-01, -.34343400E-02, -.57806900E-02, 0.18367300E-01, -.21607500E-02, -.62495800E-01, 0.16500200E-03, 0.28369000E-04, -.36296100E-03, 0.23604800E-03, -.13897300E-02, 0.43319800E-04, -.12325800E-02, 0.53480300E-02, 0.61267200E-03, -.23174100E-03, -.10074000E-02, 0.47236100E-02, -.86509700E-02, 0.72639800E-04, -.61504000E-02, 0.39276500E+00, 0.32833200E+00, 0.79697000E-01, -.12923500E+00, 0.56405700E+00, -.69431200E+00, -.32548100E+00, -.83459700E+00, 0.78345000E+00, 0.16033000E+01, 0.44027600E+00, 0.14954500E+00, 0.15464700E-01, -.12963000E+00, 0.76641900E+00, 0.19708200E+00, 0.80564200E-01, 0.33270200E+00, -.56000200E+00, -.71606800E-01, 0.49056300E-01, 0.27045600E-01, 0.79731700E-01, 0.26059700E+00, 0.11122200E+00, 0.61241000E+00, -.89946600E-01, -.15550900E+00, -.55624500E+00, -.20486800E-01, 0.30737300E+00, -.16113100E+00, -.75851400E+00, 0.66884200E+01, -.80036500E+00, -.13178900E+01, -.20701600E+01, 0.24512100E+00, 0.33793400E+01, 0.16847600E+01, -.20552200E+01, 0.72550600E-02, 0.10632000E-01, 0.13017400E-03, -.17135400E-01, 0.14485100E-01, 0.10761200E-01, -.69444200E-02, 0.10957700E-02, 0.25502300E+01, -.78287700E+00, -.37197500E+00, -.70946300E+00, 0.15861900E+00, 0.13967000E+01, 0.85162400E+00, -.63299400E+00, -.53981300E+00, -.39525600E+00, 0.50800500E+00, 0.46380700E+00, -.62550000E-01, -.59718200E+00, -.46108300E+00, 0.41606800E+00, 0.57324200E-02, 0.10389500E+00, 0.19781600E-02, -.16729700E-01, 0.10170200E+00, -.11240500E+00, -.62261000E-02, 0.86369800E-01, 0.28931500E-02, 0.88615600E-01, -.44287300E-02, 0.71502200E-03, 0.17964000E-02, 0.25699800E+00, 0.19150300E+00, -.97331200E-01, -.17396400E+00, 0.46783000E+00, 0.17162200E-02, -.20007800E+00, 0.54687400E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.46861300E+01, -.17991600E+01, -.11119100E+01, -.13658100E+01, 0.63379600E+00, -.37094000E-01, -.41054500E+00, 0.66099100E+00, 0.15339500E+00, -.12721100E+01, 0.50603300E+00, -.91031800E+00, -.21221300E+01, -.34805300E-01, -.16997300E+01, -.37001900E-02, -.67361400E+00, 0.10763400E+01, -.17588800E+01, 0.31709100E+02, 0.71203200E+00, 0.47280800E-01, -.29381100E+00, -.39053500E-01, -.34457100E+00, 0.27142600E+00, -.66404900E+00, -.32596200E+00, 0.31987100E+00, -.81249000E+00, -.76033300E+00, 0.43866500E+01, -.65450100E+00, -.52653000E+00, -.72056400E-01, 0.71736700E+00, 0.17152200E+00, 0.33635300E+00, 0.68384800E+00, 0.72128500E-01, 0.78643300E+00, 0.16574100E+00, 0.90623000E-01, -.10537600E+01, -.89635700E+00, -.25988700E+00, 0.41144900E+01, 0.17950200E+01, 0.20029800E+00, 0.81599600E-01, -.13688200E+02, 0.84010900E+01, -.23940600E+01, 0.20379600E-01, -.15073600E+02, -.11327600E+01, 0.73345200E-01, -.13522700E-01, 0.11425700E+00, 0.32725700E-01, 0.34658400E+00, 0.45995000E+00, 0.25385900E+00, -.15030400E+01, -.85416900E+00, -.30876700E+00, -.67355000E+01, -.15603500E+01, 0.19637000E+00, -.78920800E+00, -.26375800E+01, -.19848000E+01, 0.25773900E+00, -.92290900E-01, -.73395700E+00, -.91767500E+00, -.25320700E+00, -.32269200E+00, -.22731200E+00, 0.18198100E+01, 0.42165700E-01, -.10112300E-02, 0.25278100E-01, -.15332300E+00, -.86131600E-01, 0.19173700E-01, 0.65085400E-01, -.22678600E+00, 0.12468400E+00, -.44562300E-01, -.10135800E+00, -.82970800E+00, 0.28914600E+00, 0.79718400E-01, 0.45388900E+00, -.99511300E+00, 0.50326300E+03, -.24656100E+03, 0.53978800E+02, 0.11862800E+03, -.18244900E+03, 0.76001500E+02, -.19374900E+03, 0.10579400E+03, -.65948100E+02, 0.41520900E+02, -.22954800E+02, -.19901300E+02, 0.61593100E+02, -.25356100E+02, 0.32701200E+02, -.18413200E+02, -.32698600E+02, -.60084000E+01, -.20008900E+02, 0.30763500E+02, -.24176300E+02, -.19617400E+02, -.85967000E+02, 0.24628700E+02, -.75352500E+02, 0.11494000E+03, 0.63601900E+02, 0.36509600E+02, 0.51647400E+01, -.56367600E+02, 0.75488300E+01, 0.43264600E+02, -.28295200E+03, 0.10679000E+02, 0.49988300E+02, 0.16034100E+03, -.54627600E+02, -.20828400E+03, -.18396300E+03, 0.17654200E+03, -.25471800E+01, 0.11368100E+01, 0.10121300E+01, 0.22107600E+01, -.21286100E+01, -.25397100E+01, -.19883200E+01, 0.18235200E+01, -.15394200E+03, -.38473300E+02, 0.38767100E+02, 0.12048700E+03, -.60651200E+02, -.13532100E+03, -.16689500E+03, 0.12061700E+03, -.16454700E+03, 0.20664800E+02, 0.58286700E+02, 0.63735800E+02, -.59267500E+02, -.57729200E+02, -.26173000E+02, 0.62340800E+02, 0.16529800E+01, -.81005800E+01, 0.79350200E-01, -.33106100E+01, -.18361600E+02, 0.12997700E+02, -.34870700E+01, -.17390000E+02, 0.56011100E-01, -.14532400E+02, 0.54873600E-01, -.72013000E-01, 0.86736200E-01, 0.29984600E+01, -.48363600E+01, 0.19111800E+02, 0.83003800E+01, -.40490500E+02, 0.27718200E+00, 0.44459700E+02, 0.16352900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.63174700E+01, 0.24395200E+01, 0.26982500E+01, 0.27328200E+00, 0.96010500E+00, -.45383600E+00, -.17330200E+01, 0.59629900E+00, -.21879500E+01, -.44746100E+01, 0.31706900E+00, -.35954800E+01, -.80543900E+01, -.37481300E+00, -.99362600E+01, -.25407800E+01, -.18513900E+01, 0.18877600E+01, -.20974600E+01, 0.19825800E+02, 0.11638800E+01, 0.19369100E+01, 0.64525200E+01, -.32746700E-02, -.15638200E+01, 0.18964600E+00, -.14893000E+01, -.20660300E+01, 0.38723500E+01, 0.16222300E+01, 0.45708200E+00, 0.21964300E+02, -.55616700E+01, 0.26024000E+00, 0.54380700E+00, -.44711700E+00, -.15113600E+01, 0.98868700E+00, 0.14361800E+01, 0.24993100E+01, 0.26705300E+01, -.67882500E+00, -.30564200E-01, 0.10391900E+01, 0.63638900E+00, 0.90910900E+00, -.31444800E+01, 0.74911300E+00, 0.15186100E+01, -.10787700E+01, 0.19104400E+02, -.73903100E+01, 0.20889000E+01, -.98238600E+00, 0.30414400E+01, -.45667700E+00, -.12636700E+00, -.28849600E-01, -.58295700E+00, 0.28666800E+00, 0.33165300E+00, -.41415100E+00, -.46078600E+00, -.89974300E+00, 0.16109000E+00, -.95869800E+00, 0.84175300E-01, -.66362800E+00, -.18977900E+00, -.56437300E-01, -.42302300E+01, -.27052900E+01, 0.55083500E-01, -.10270000E+00, 0.59287300E-01, -.78040100E+00, 0.11416500E+01, -.86345100E+00, 0.15025400E+00, -.20394300E+01, 0.20998300E-01, -.98225200E-02, 0.24944700E-01, -.14466300E+00, 0.42397700E-01, 0.20686500E-02, -.16155800E-01, 0.81234200E-01, 0.42155600E-01, -.41316200E-01, 0.12816500E+00, -.74796100E+00, 0.59616400E+00, 0.16874100E-01, 0.15650000E+00, 0.12996600E+00, 0.96534200E+00, -.11621800E+03, -.10564900E+02, -.29294000E+01, 0.81985400E+01, -.93226400E+01, 0.14547000E+02, -.16308900E+01, -.80614200E+02, 0.65355500E+02, 0.34734800E+02, 0.28655900E+02, -.34207900E+02, -.18149500E+02, -.51395800E+02, 0.24800800E+02, -.24896200E+02, 0.98971600E+01, 0.75341100E+01, -.66544900E+01, 0.16803100E+02, -.19623300E+02, 0.40889700E+02, -.49549000E+01, 0.58412300E+02, -.35690100E+02, -.50513600E+02, -.65813600E+01, -.38908200E+02, 0.13902800E+02, -.15145100E+02, -.10714700E+02, 0.12394400E+03, 0.46714700E+01, -.74107000E+02, -.34178200E+02, -.39462400E+02, 0.15450900E+02, -.82302200E+02, -.45435500E+02, 0.77411400E+00, -.86986100E+00, -.11951400E+01, 0.50574100E+00, -.70195500E+00, 0.10543400E-02, -.30745900E+00, 0.18660700E+01, 0.83128600E+02, -.11055300E+02, -.21738500E+02, 0.55762000E+01, -.44538700E+02, -.33361200E+01, -.72346900E+02, 0.18502000E+01, 0.17776100E+03, -.67307900E+02, -.67739700E+02, -.87508400E+02, 0.11155200E+03, 0.57781400E+02, 0.54228900E+02, -.79459000E+02, -.77966400E+00, -.12519300E+01, 0.11654300E-01, 0.70086900E+01, -.56831600E+01, 0.43319800E+01, 0.41477400E+01, -.69033100E+01, 0.11188800E+00, -.64911700E+00, -.22137000E+00, 0.10026000E+00, -.25727100E-01, 0.67693300E+00, -.34913800E+01, -.13450900E+02, -.18729600E+02, -.42202300E+02, -.12963200E+00, 0.19634100E+02, -.30966500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18124000E+01, -.27610800E+00, -.35941200E+00, 0.63060200E+00, 0.28526300E+00, 0.37104800E+00, 0.12176700E+01, -.17867100E+01, 0.36275100E+00, -.18590400E+00, 0.68315900E+00, -.94208200E+00, -.59058700E-01, 0.12881900E-01, 0.22495200E+01, 0.10640600E-01, 0.64362200E+00, -.38564300E+00, -.23371000E+00, 0.63339300E+01, -.23370700E-03, -.95713100E+00, -.10230400E+01, 0.26737200E+00, 0.69140400E-01, 0.47421800E-01, -.61099000E-02, 0.78340300E+00, -.49015300E+00, 0.15572700E+00, 0.28533600E+00, 0.39803600E+01, -.25107400E+01, -.12532000E+00, -.18536900E-01, 0.78650300E+00, -.36746700E+00, -.78376400E-01, -.13864300E+00, 0.73583400E+00, 0.63870700E+00, -.14607500E+00, 0.10190100E+00, 0.10703000E+00, -.13744500E+00, 0.38671600E-01, -.11048300E+00, 0.29216500E+00, 0.20889700E+00, -.12361200E+00, -.82703800E+00, 0.21943700E+01, 0.26794000E+00, -.35698400E-01, -.32570900E+01, -.14962200E+00, -.26747500E-01, -.17625800E-01, 0.83800300E-01, -.40518300E-01, 0.36414600E-01, -.37316100E-01, 0.91953200E-02, -.70539800E-01, 0.20148500E+00, -.10677900E+00, 0.77425500E+00, 0.10721400E-01, 0.11925000E-01, 0.16311100E-01, 0.12146300E-01, -.25082800E+00, 0.37217100E-01, -.11585200E-01, -.20067500E+00, -.14979400E+00, -.21942700E-01, 0.16433500E+00, -.91896500E-01, -.31152600E+00, 0.52118200E-02, -.29993600E-02, 0.76700100E-03, -.12624400E-01, -.15659700E-01, -.32214700E-02, -.26378900E-01, 0.17561500E-01, 0.16333200E-01, -.93932100E-02, 0.21428400E-02, -.38041000E-01, -.48663000E-01, -.82823900E-02, -.75216800E-01, 0.69069200E-01, 0.66997700E-01, -.62259500E-01, -.12582700E+02, -.87136000E+01, 0.41936300E+01, -.80858800E+01, 0.70470900E-02, -.80447000E+01, 0.85198400E+01, 0.62089900E+01, 0.53420200E+01, 0.74560500E+01, -.12404600E+02, 0.98621500E+01, -.58750200E+01, 0.68898600E+01, -.10089300E+01, 0.26991200E+01, -.53545800E+00, -.28423900E+01, 0.39261800E+01, -.53708700E+01, 0.78982600E+01, -.32179200E+01, 0.17107800E+02, -.15240000E+02, -.85380700E+01, -.72849800E+01, -.45355100E+01, 0.80767900E+00, -.99844500E+00, -.80513400E+01, 0.29912400E+02, -.26506600E+02, -.15887000E+02, -.14642300E+02, -.20536400E+01, 0.76756900E+01, -.45015600E+01, -.17044400E+02, 0.14437000E+00, -.15887100E+00, -.12441700E+00, -.70384200E-01, 0.40004800E-01, 0.85997000E-02, -.88067700E-01, 0.15906300E+00, 0.20286200E+02, -.11347000E+02, -.35336800E+01, -.42313600E+01, -.38918100E+01, 0.14301100E+01, -.58585800E+01, -.44370900E+01, 0.34349800E+02, -.67284300E+01, -.13722000E+02, -.19947400E+02, 0.25162000E+02, 0.85619300E+00, 0.13495800E+02, -.19722200E+02, 0.46795000E-01, 0.15826600E+01, 0.28574400E-01, 0.16156800E+01, 0.27141400E+01, -.21187700E+01, 0.10112700E+01, 0.24026900E+01, 0.45994800E-01, 0.20574800E+01, -.61916200E-01, 0.21089500E-01, 0.21113500E-01, 0.53486400E+01, 0.27466000E+01, -.24228900E+01, -.34508700E+01, -.44588600E+01, -.86888100E-01, -.81267900E+00, -.55781000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23038900E+01, -.30312500E+00, -.49386600E+00, -.22234500E+01, 0.12914500E+01, -.14078200E+01, 0.35255800E+00, -.23582700E+00, 0.88419800E+00, 0.30964300E+00, 0.58764800E-02, -.13158000E+00, 0.29652300E+00, -.23605600E-02, 0.20370500E+01, 0.57732100E+00, 0.48688000E+00, 0.35481300E+00, 0.26211100E+00, 0.31897100E+01, 0.26812600E+00, -.77803000E+00, -.52893900E+00, 0.13843700E+00, 0.10676900E+00, -.40677700E-01, -.22764000E+00, -.18020700E+00, 0.42088100E+00, -.38818700E+00, -.28658200E+00, 0.29016900E+01, -.59083200E-01, -.40653700E-01, 0.74371400E-01, 0.82660200E+00, 0.43539600E+00, 0.12179700E+00, 0.50542200E+00, 0.66079400E-01, -.45888000E+00, 0.28148900E+00, 0.11888300E+00, 0.17806100E+00, 0.35764800E+00, -.22828200E-01, -.26715900E-01, -.31175300E+00, -.53187900E+00, 0.88394700E-01, -.20405800E+01, 0.12895400E+01, -.44390600E+00, 0.18306100E-01, 0.12748900E+01, 0.68350700E-01, 0.97266400E-01, 0.25998400E-01, 0.17122000E-01, 0.24520800E-01, -.58304800E-01, 0.21041500E-01, 0.55977200E-01, -.92408400E-01, 0.20151400E+00, -.81174700E-02, -.93756400E+00, -.27396000E+00, -.32533800E-01, 0.28212600E+00, 0.38249900E+00, 0.31656300E+00, 0.94131600E-02, -.76825600E-02, -.39487900E-01, 0.13914200E+00, -.15893900E+00, 0.27968300E-01, -.45035700E-01, 0.59267300E+00, 0.34385100E-02, 0.24715100E-02, -.14296400E-01, -.71121500E-03, -.19343400E-01, 0.42967900E-02, 0.55162900E-02, -.45097200E-01, 0.11927200E-01, -.29713800E-02, -.65717000E-01, 0.15324900E-01, -.39905800E-01, 0.14214400E-01, 0.84424300E-02, -.13513300E+00, 0.10893800E+00, 0.98405800E-01, -.58732300E+00, 0.30872100E+02, -.19520200E+02, -.10985000E+02, -.22675700E+02, 0.38024500E+02, 0.60477000E+02, -.99805800E+01, 0.41296500E+01, -.91184500E+01, -.25262200E+01, 0.21031800E+02, 0.79390100E+01, -.72392200E+01, 0.44437200E+01, -.89198800E+01, -.19174900E+01, 0.12375600E+01, 0.19236400E+01, 0.39493600E+01, -.28515000E+00, 0.28664100E+01, -.15511300E+02, 0.79843300E+01, -.35558300E+01, -.69449000E+01, 0.67673500E+01, -.65147600E+01, -.18169300E+01, -.11568800E+02, 0.70545400E+02, -.98164700E+01, -.38320300E+01, -.99314500E+01, -.25467600E+01, 0.31600600E+02, 0.19275300E+02, -.13177500E+02, 0.14259600E+00, 0.11093100E+00, 0.41054600E-02, -.40281800E+00, 0.41969300E+00, 0.14671800E+00, 0.17470200E-01, -.74712200E+00, -.26840300E+02, -.95947700E+01, 0.15781900E+01, -.10441500E+01, 0.13075300E+02, -.15770500E+01, 0.20426300E+02, -.11816500E+01, 0.20817200E+02, -.45520000E+00, 0.18711100E+01, 0.17492700E+01, -.21086500E+02, 0.88896200E+01, -.88075100E+01, -.14053800E-02, 0.44346000E-01, 0.13505000E+01, 0.52025200E-02, -.25814100E+00, 0.27158300E+01, -.64054700E+00, 0.12442100E+00, 0.25155600E+01, -.11847900E-01, 0.24515200E+01, 0.16932600E-01, -.38650700E-02, 0.71070300E-02, 0.61227400E+01, 0.17079500E+01, -.28224000E+00, -.22936600E+01, 0.76600000E+01, -.27053900E-01, -.54418600E+01, 0.56735600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.82272100E+01, -.37298500E+01, -.32623400E+01, -.25457900E+01, -.11820300E+01, 0.21190500E+00, 0.39055600E+00, 0.93247500E+00, -.10331700E+01, -.14914300E+01, -.90472300E+00, -.17208200E+00, 0.53748200E-02, 0.14363000E+00, -.65545600E+01, 0.13239400E+01, -.10121100E+01, -.14647200E+01, -.14045200E+01, -.77971500E+00, -.58394500E+00, -.24397900E+01, -.83148900E+00, 0.86786400E+00, 0.12248100E+01, -.92828200E+00, 0.18990900E+01, 0.16659400E+01, -.16472200E+01, 0.33200600E+01, 0.17386000E+01, 0.11653000E+02, -.27208800E+01, -.45096300E+00, -.20638400E+00, -.97752100E+00, -.56556800E+00, -.15762600E+00, -.21117600E+01, 0.16477000E+01, 0.15135700E+01, -.20081500E+00, -.18088100E-01, -.13108900E+01, -.18787900E+01, -.15818300E-01, 0.17127300E+01, -.16623500E+01, -.28219200E+01, 0.72688900E+00, 0.87359700E+00, 0.29520600E+01, 0.23365900E+01, 0.51089000E+00, 0.78173900E+00, 0.19257500E+01, 0.69114200E-01, 0.22943500E-01, 0.77372900E+00, -.51187200E+00, -.57784700E+00, -.74671400E+00, 0.55930500E-01, 0.92006800E+00, 0.70634600E-03, 0.40701300E+00, 0.71242400E+01, 0.56332200E+00, -.14305800E+00, 0.72264700E+00, 0.58017100E+01, 0.27254700E+01, 0.25105900E+00, -.73641100E-01, -.45280500E+00, -.11489700E+01, 0.64753100E+00, 0.19439300E+01, 0.16730300E+01, -.29745700E+01, 0.45168500E-01, 0.13343600E-01, -.82708700E-01, -.19390300E-01, -.98248600E-01, 0.23972400E-01, 0.37015400E-01, 0.25543400E+00, 0.15227700E+00, 0.92771700E-04, -.15652300E+00, 0.14595700E+00, -.25224400E+00, 0.82340500E-01, 0.32922800E+00, 0.10807000E+01, -.12817000E+01, -.35515500E+00, 0.89204600E+00, -.90074500E+00, 0.42518300E+02, -.10958400E+02, 0.22506900E+02, 0.10600400E+01, 0.14153900E+03, 0.51111100E+02, -.33122300E+02, -.34710200E+02, 0.48512800E+02, 0.63612000E+02, 0.83375900E+02, -.30762600E+02, -.10538300E+03, -.20727200E+02, 0.28798800E+02, 0.35076300E+02, 0.10146400E+02, -.33096400E+02, -.51765800E+02, 0.24867500E+02, -.12070800E+03, 0.18684800E+03, 0.29880500E+02, 0.54182900E+02, -.76497500E+02, -.10270300E+03, -.12497500E+03, 0.48233100E+02, -.74075600E+03, 0.14808400E+03, 0.12787800E+03, 0.12444700E+03, 0.11844600E+03, -.26848100E+03, -.18698700E+02, 0.12336100E+03, -.32126800E+01, 0.25737700E+01, 0.64929000E+00, 0.71451800E+00, -.15283300E+01, -.23556100E+01, -.19961900E+01, 0.10962000E+01, -.27392200E+03, -.13443400E+01, 0.59564500E+02, 0.44498800E+02, 0.70858700E+02, -.84388900E+02, -.25311500E+00, 0.46744100E+02, 0.11562200E+03, -.12241100E+03, 0.29689000E+02, 0.50769400E+02, -.16249500E+03, 0.59725900E+02, 0.10127900E+02, 0.45871000E+02, 0.36418400E+01, 0.12306400E+01, 0.21288500E+00, -.12048600E+02, -.88296600E+00, -.33931100E+00, -.10138300E+02, -.54748700E+00, 0.16511600E+00, -.16928000E+01, -.12222100E+00, -.12233800E+00, 0.24972900E+00, -.16429200E+01, 0.13525300E+02, 0.49670800E+01, -.35171000E+02, 0.34155200E+02, 0.39587700E+00, -.26150500E+02, 0.38766400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.56075800E+01, 0.22964500E+01, 0.14888200E+01, 0.17410300E+01, -.29492500E+00, 0.47119200E+00, -.12496200E+01, 0.10130300E+01, 0.26974800E-01, 0.11786500E+01, -.77045800E+00, 0.80527700E+00, 0.12703300E+01, -.31031000E-01, -.76431300E-01, 0.22367200E-03, 0.14954300E+00, 0.56112600E+00, 0.21426000E+01, -.20133400E+02, 0.84785100E+00, -.18916800E+00, 0.11197700E+01, -.57607400E+00, 0.88880400E+00, 0.82719900E-01, 0.75886800E-01, -.13986300E+01, 0.11518400E+01, 0.12098100E+01, 0.84914600E+00, 0.47739100E+01, -.52187300E+01, -.25721600E+00, -.43711600E-01, -.11203400E+01, -.18273400E+01, 0.14543600E-01, -.77795100E+00, 0.20481300E+01, 0.33575200E+01, -.77402600E+00, 0.21114100E+00, -.34228600E+00, -.50575000E+00, 0.49835800E-01, -.14270000E+01, -.14015500E+01, -.99760300E+00, -.56251200E+00, 0.12130400E+02, -.12158200E+02, 0.60313200E+00, 0.29830900E+00, 0.91663700E+01, 0.11880900E-01, -.70176400E-01, 0.11672600E-02, -.63397400E+00, 0.29360800E+00, 0.19363600E+00, -.12874400E+01, -.32315200E+00, -.63733900E+00, 0.97030100E+00, -.63493200E-01, 0.18615600E+00, 0.60506900E-01, -.13874500E+01, 0.84491400E+00, 0.94005300E+00, 0.20755700E+01, -.77157300E-01, -.48199500E-02, 0.37512000E+00, 0.37468900E+00, 0.12113700E+01, -.67871600E+00, 0.12335900E+01, -.12591900E+01, 0.31342400E-03, -.12196900E-01, -.18769800E-01, 0.99235100E-02, 0.14312700E+00, -.22656800E-02, 0.16148500E+00, 0.10375100E+00, -.11547000E-02, -.37740700E-01, -.73484000E-02, 0.10406600E+00, 0.46076500E+00, -.13866000E-01, 0.57782400E+00, 0.42587000E+00, -.36093900E+00, 0.15543700E+00, -.10736200E-02, -.41163100E+00, 0.62680700E-01, -.39659700E+02, -.24250000E+02, -.16647700E+01, -.23615900E+02, -.55915400E+02, -.14019600E+02, -.18448500E+02, 0.36420000E+02, 0.38451800E+01, 0.33201600E+02, -.22008000E+02, -.74745800E+02, 0.21333200E+02, 0.51886300E+01, 0.48707000E+01, 0.10874600E+02, -.39993300E+02, -.26838200E+01, 0.51643100E+01, -.78759800E+00, 0.22883300E+02, 0.17673200E+01, 0.25139500E+01, -.21939600E+02, -.51609900E+00, -.28061100E+02, -.62331800E+01, -.26747900E+03, 0.79164900E+02, 0.28245000E+02, -.21980100E+01, 0.76475800E+02, -.10804800E+03, -.20260100E+02, -.24613900E+02, -.53433200E+00, 0.13666800E+00, 0.25984500E+00, -.15414900E+00, -.30369000E+00, -.31967400E+00, -.21320600E+00, -.48263900E+00, -.20117700E+03, 0.56488500E+02, 0.23270600E+02, -.14834600E+02, 0.87931000E+02, -.56288900E+02, 0.36004800E+02, -.22664700E+02, 0.96710200E+02, -.41264000E+02, -.12789100E+02, -.22597000E+02, 0.17470600E+02, 0.67335100E+02, 0.78882800E+02, -.83520900E+01, 0.56693400E+00, -.37588900E+01, -.52053000E-01, 0.50246800E+01, -.38846600E+01, 0.19241200E+01, 0.46020400E+01, -.36227900E+01, -.93417000E-01, -.13916700E+01, 0.11262600E+00, -.54690900E-01, -.31158600E-01, 0.59731000E+00, -.19849500E+01, -.39400300E+01, -.90648600E+01, 0.24757600E+02, -.21378700E+00, -.30682600E+02, -.11007400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.38816600E+01, -.76817900E+00, -.27211700E+00, -.13580400E+01, -.45948000E+00, -.69886300E+00, -.87803800E-01, 0.10414800E+00, 0.24980300E+00, 0.29436900E+00, 0.66747800E-01, 0.62397800E-01, 0.92174400E+00, 0.60892700E-01, 0.10222600E+01, 0.28112300E+00, 0.10835300E+00, -.53096200E+00, -.17606500E+00, 0.13565100E+01, -.32033500E+00, -.40986500E-01, 0.97428100E+00, 0.12493200E+00, -.23213400E+00, -.83413600E-01, -.12244500E+00, 0.30763700E+00, 0.29484300E+00, -.20302600E+00, -.12209600E+00, -.84472300E+00, 0.24148100E+01, 0.22160000E+00, 0.87859300E-01, 0.40403300E+00, 0.11116500E+01, -.25705700E+00, 0.24581800E+00, -.67337700E+00, -.12679200E+01, 0.52914700E+00, -.11678100E+00, 0.35846100E+00, 0.80045000E+00, 0.39560700E-01, -.40761000E+01, -.69887800E+00, 0.88809100E-01, -.37747800E+00, -.69257900E+01, 0.33591300E+00, -.43171000E+00, -.12497200E+00, 0.54081500E+01, 0.14548400E-01, 0.42851900E-01, 0.29873700E-01, 0.22529700E+00, -.78980500E-01, -.30709300E+00, -.65643900E+00, -.30939300E-01, 0.45422100E+00, 0.84142100E+00, 0.11507200E+00, 0.21524100E+01, 0.42779300E+00, 0.20562200E+00, 0.38798800E+00, 0.58478200E+00, 0.90862600E+00, -.24313100E+00, 0.12411100E+00, 0.59327900E+00, 0.10171600E+01, -.86136400E+00, -.23829800E+00, -.70129800E+00, -.14353100E+01, -.49827900E-01, 0.12437200E-01, 0.31911000E-01, 0.14046400E+00, -.10268400E-01, -.20356000E-01, -.10171900E+00, 0.17779700E+00, -.15000200E+00, 0.73560400E-01, 0.13048300E+00, 0.53928100E+00, -.44556100E+00, -.83604400E-01, -.54832400E+00, 0.63987000E+00, -.34310700E+00, -.91139500E-01, -.80172200E+00, -.65179900E+00, -.28976800E+00, -.17619900E+00, 0.10143200E+02, 0.44141800E+01, 0.27121200E+02, 0.13006700E+02, -.17207000E+02, -.23166200E+01, -.34766500E+01, -.38478800E+01, -.26484100E+01, -.59982500E+01, 0.22983200E+02, -.13310400E+02, 0.34649300E+01, -.11262200E+01, -.18729000E+01, 0.12721600E+02, 0.37323300E+01, 0.24385100E+01, 0.75261000E+00, 0.17881900E+01, 0.45528900E+01, -.72234800E+01, 0.26162400E+02, 0.22705000E+02, 0.11208000E+02, -.10928200E+02, -.68317700E+02, -.93668800E+02, 0.36490400E+02, 0.19415500E+02, 0.21912100E+02, -.13537400E+02, 0.22265200E+01, 0.20644800E+02, 0.14032300E+00, -.26932200E+00, 0.16595900E+00, -.11682400E+00, 0.48496900E+00, 0.37676600E+00, -.67182800E+00, 0.51165800E+00, -.62940200E+02, -.23324700E+02, 0.18925200E+02, 0.11216600E+02, 0.18296900E+02, -.15167500E+02, -.16722700E+01, 0.10548500E+02, -.12045300E+03, 0.91521200E+02, 0.21413600E+02, 0.32230700E+02, -.65351600E+01, -.38193700E+02, -.36486700E+02, 0.25034400E+02, -.25044700E+00, -.80237700E+00, 0.52115900E-01, -.26476300E+01, -.30099200E+01, 0.12385600E+01, -.14070400E+01, -.24623700E+01, 0.10432800E+00, -.38915900E+01, -.16176800E+00, 0.22498300E-01, 0.47803100E-01, -.12634800E+01, 0.20887800E+01, -.16125500E+01, 0.87092100E+01, 0.16651800E+02, 0.10367400E+00, -.48496000E+01, 0.30312100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.26823700E+01, -.47973300E+00, -.48717900E+00, -.25136300E+01, 0.11955500E+01, -.15295700E+01, 0.20349800E+00, -.99432300E+00, 0.63858200E+00, 0.56996300E+00, 0.24695000E+00, -.45409500E+00, 0.10099100E+01, 0.58653900E-01, 0.34183500E+01, -.25629200E-01, 0.86287300E+00, -.41535600E+00, 0.21757900E+00, -.17307900E+01, -.32402100E+00, -.65767900E+00, -.80346600E+00, 0.15219000E+00, -.14239600E+00, -.38717700E-01, -.78355200E-03, 0.25900000E+00, -.31566200E+00, -.39470100E+00, -.62663300E-01, -.15423900E+01, 0.39586100E+00, 0.12056000E+00, 0.76320900E-01, 0.77436900E+00, 0.59826400E+00, 0.95401600E-01, 0.77477500E+00, -.60321900E+00, -.41710500E+00, 0.18872400E+00, 0.10772900E+00, 0.62712400E-01, 0.31927300E+00, -.44768000E-01, -.22213900E+00, -.29084900E+00, -.34971100E+00, -.19950400E-01, -.10843100E+01, -.34339400E+00, -.20699600E+00, -.21558100E-01, 0.16836000E+01, 0.73641900E-02, 0.47691700E-01, 0.20734800E-01, 0.66706900E-03, 0.55162800E-01, -.52658900E-01, 0.80696200E-01, 0.16004100E-01, 0.51155600E-01, 0.23789500E+00, 0.13078300E+00, -.10899400E+01, -.15184800E+00, 0.19062900E+00, 0.19117600E+00, 0.57765600E+00, 0.42569100E+00, -.19860500E-01, 0.53194900E-02, 0.37825300E-01, 0.10128800E+00, -.78390500E-01, 0.76802400E-01, 0.17785200E-01, 0.93534100E+00, -.16753000E-02, 0.23237900E-02, -.14529200E-01, 0.80947600E-02, -.62500700E-02, 0.27891900E-02, 0.17658400E-02, -.68438000E-01, -.36733900E-02, 0.27967800E-02, -.43651400E-01, 0.61302500E-01, -.48206200E-01, 0.82353700E-02, -.14640600E-01, -.21640100E+00, 0.98670400E-02, 0.62207500E-01, -.58327500E+00, 0.95672100E+00, 0.50681300E-01, -.69975000E-01, -.11431300E+00, -.35206200E+01, -.19167000E+02, 0.33990600E+01, 0.22348500E+01, 0.35354800E+01, -.29957100E+01, -.69059600E+01, -.36204800E+01, 0.31812300E+01, 0.38028500E+01, 0.22640700E+01, -.80381400E+00, -.12401200E+01, -.73579500E+00, 0.91397200E-01, 0.39015700E+01, -.12443400E+01, 0.14203700E+02, -.14289000E+02, -.34752000E+01, -.18938200E+01, 0.32682900E+01, 0.98213100E+01, 0.39583600E+01, 0.92269800E-01, 0.21472800E+02, -.12138700E+02, -.80437800E+01, -.74545500E+01, 0.12487700E+01, 0.88588100E+01, -.26777100E+01, -.74605000E+01, 0.16245100E+00, -.16957100E+00, -.32494300E-01, 0.32962300E-01, 0.38175400E-01, 0.14047600E+00, -.49656400E-01, -.16194600E-01, 0.24045100E+02, -.41944900E+01, -.41025500E+01, -.44669000E+01, -.26117100E+01, 0.66273400E+01, -.52549300E+01, -.48444400E+01, -.20118200E+02, 0.14237500E+02, -.50359500E+00, 0.83745900E+00, 0.13598900E+02, -.91756000E+01, -.26406900E+00, 0.24028000E+01, -.23407900E+00, 0.13584100E+00, -.19368700E-01, 0.60612800E+00, 0.29174700E-01, -.18943400E+00, 0.46469900E+00, 0.79622700E-01, -.19764600E-01, -.56243800E+00, 0.21060100E-01, 0.40273900E-02, -.19809400E-01, -.48597300E+00, -.71014700E+00, -.43733000E+00, 0.26809900E+01, -.73084100E+00, -.11196700E+00, 0.10783900E+01, -.40401700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.45105600E+01, -.69318100E+00, -.95694400E+00, -.12577300E+00, 0.77053800E+00, 0.57916400E+00, -.38932900E+00, 0.18842400E+00, 0.45620100E+00, -.59074800E+00, -.10036500E+00, -.48534100E+00, -.15410100E+01, -.81111600E-01, -.16166600E+01, 0.65045600E-01, -.92438900E-01, 0.25893500E+00, -.81093000E+00, 0.52069800E+01, 0.14297100E+00, -.15135600E+01, -.38270600E+01, -.34235300E+00, 0.99112400E+00, 0.13226100E+00, 0.35577500E+00, -.16973300E+01, -.59216800E+00, -.11547400E+01, -.45624000E+00, -.14515300E+02, -.22650000E+01, -.27416800E+00, -.25836900E+00, -.39981400E+00, -.11690700E+01, 0.11653900E+01, 0.12449100E+01, 0.72555700E+00, 0.23835400E+01, -.80714900E+00, 0.67466000E+00, -.13034800E+01, 0.56486000E+00, 0.34801200E+00, 0.26389000E+01, 0.64647300E-01, 0.85220100E+00, -.14290300E+00, 0.16134000E+02, -.14333400E+02, 0.25581300E+00, -.32090400E+00, 0.16836400E+01, 0.97999400E-01, -.11505600E+00, 0.38710800E-01, -.65473000E+00, 0.50609800E+00, 0.39620500E+00, 0.11163000E+01, -.34372900E+00, 0.19067000E+00, 0.74197300E+00, -.91432200E-01, -.24760000E+01, 0.17765500E-01, 0.16356700E+01, 0.65624300E+00, -.12910400E+01, -.11626300E+01, 0.31256800E+00, -.18772800E+00, -.40596200E+00, -.61757900E+00, 0.16687300E+00, -.39141900E-01, 0.54942700E+00, 0.32428900E+01, 0.68199300E-01, -.29300500E-02, -.45456000E-01, -.16195300E+00, -.11334300E+00, 0.34265900E-01, 0.20301300E-01, -.31488600E+00, 0.21327600E+00, -.77379200E-01, -.20633600E+00, -.58316700E+00, -.75090500E-02, 0.13159000E+00, 0.24898900E+00, -.10980700E+01, 0.56769600E+00, 0.44035200E+00, 0.32855100E+00, 0.17801300E+01, 0.91680500E-02, -.18967400E-01, -.87646400E+00, 0.39086400E+00, 0.10405000E+03, -.10138700E+02, -.34603200E+01, -.79309700E+01, -.15320000E+02, 0.33989000E+02, -.28436500E+01, -.11646900E+01, -.19947200E+02, -.27692600E+02, 0.36191400E+01, 0.11144900E+02, 0.32457700E+01, -.12404900E+01, -.50340700E+01, 0.70255000E+01, -.79684900E+02, 0.11641000E+03, 0.20809400E+02, 0.98229700E+01, -.26391800E+01, -.37187900E+02, -.25971700E+02, 0.12073900E+02, -.11921700E+02, 0.22682500E+02, 0.13472900E+02, -.47720600E+01, 0.21497100E+02, 0.10165700E+02, 0.27565300E+02, 0.39526200E+01, -.14296400E+01, 0.14421400E+01, 0.39602300E+00, 0.10656300E+00, -.19022700E+00, -.83696100E+00, -.12330600E+01, -.45357200E+00, 0.72454700E+02, -.14005600E+02, -.15303500E+01, -.13021700E+02, -.42478200E+01, 0.34713900E+02, 0.39805900E+01, -.86904300E+01, -.81155400E+02, -.46762800E+02, 0.24693800E+02, 0.32739800E+02, -.69668800E+02, -.34677500E+02, -.24237700E+02, 0.18644400E+02, 0.18057600E+01, 0.11796800E+01, 0.10223500E+00, -.50699500E+01, 0.26507000E+01, -.11992400E+01, -.34437600E+01, 0.24574400E+01, 0.29815300E-01, 0.52994900E+00, 0.50465800E-01, -.75043400E-01, 0.12775300E+00, -.28010100E+00, 0.10869500E+01, 0.16653700E+01, -.82879300E+01, 0.20902400E+02, 0.19766800E+00, -.61982900E+01, 0.26310000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.78039200E+00, 0.16693500E+00, 0.20335200E+00, 0.37589200E+00, -.17274100E+00, 0.31754900E+00, -.29778600E+00, 0.48035900E+00, 0.12988600E+00, -.13228900E-01, 0.91872300E-02, 0.40451600E-01, -.80219200E-01, -.11455200E-01, -.38434100E+00, 0.22767800E+00, -.87719800E-01, 0.94760100E-01, 0.92138100E-02, 0.60282700E+00, 0.11508400E+00, 0.11290900E+00, 0.50779200E+00, 0.16294500E-01, 0.61473500E-01, 0.22685700E-01, -.76078400E-01, 0.77834400E-02, 0.15538900E+00, -.69098200E-02, -.82215800E-01, 0.42687800E+00, -.16080300E+00, -.51559300E-01, 0.82153200E-02, -.18976500E-02, -.51035700E-01, -.20430800E-01, -.51808100E-01, 0.33848100E-01, -.10941300E+00, 0.46104000E-01, -.80110500E-02, 0.13711300E-01, -.66363400E-01, -.44355100E-01, -.10784500E+00, -.10179400E+00, -.12084400E+00, -.33213000E-02, -.10601800E+01, 0.32483100E+00, -.11711500E+00, 0.42649700E-01, 0.25822000E+00, 0.75504600E-01, 0.22373400E-01, 0.56307400E-03, 0.41477800E-01, -.50633700E-01, -.37934700E-01, -.36897600E-01, 0.13391300E-01, -.35884000E-01, -.11110100E+00, -.27881900E-01, -.81608700E-01, 0.39588400E-01, -.16664000E-01, 0.10727400E-01, -.20415400E+00, -.13576900E+00, 0.79787600E-02, -.27586600E-02, 0.88626800E-02, 0.73966600E+00, -.43510800E-01, -.10354900E+00, 0.17457600E-01, -.60201100E-01, 0.27765700E-02, 0.19123800E-03, 0.14487700E-02, 0.71837400E-01, -.29391400E-02, 0.12997000E-02, 0.14141900E-01, -.38147800E-04, 0.88264200E-02, -.25626300E-02, -.11055100E-01, 0.22233500E+00, 0.50274700E-01, 0.63508900E-02, 0.76563000E-01, -.30667700E-01, 0.48349400E-01, 0.33285100E-01, -.10659900E+00, -.13379200E+00, 0.33469800E-01, 0.70890100E-02, 0.14872800E+00, 0.16832300E+00, 0.25746300E-01, -.15211700E+02, 0.12182500E+01, -.18274100E+01, 0.11448100E+01, -.38432500E+00, -.10492200E+01, -.15670500E+01, -.28739400E+01, 0.39762700E+01, -.88934000E+00, -.56750500E+00, 0.34236500E-01, -.10216600E+01, -.18748500E+01, -.75451300E+00, -.93069100E+01, 0.11219500E+01, 0.51033500E+00, -.31592700E+00, 0.23346500E+01, -.60246000E+01, 0.40501500E+01, -.26110900E+00, -.11498700E+02, 0.96733300E+01, 0.40063900E+01, 0.78634500E+01, -.62977900E+01, -.10888700E+02, -.37450800E+01, 0.70067400E+01, -.12171800E-01, -.62567200E-01, -.12618000E-01, 0.21058000E+00, 0.44698900E-02, -.73740300E-01, 0.19782500E+00, -.77407700E-01, -.19033100E+02, 0.10204500E+02, 0.11761900E+01, 0.30144300E+01, 0.21406700E+00, -.84511900E+01, 0.29494200E+01, 0.26734400E+01, 0.20896800E+02, -.64594100E+01, -.50983800E+01, -.89249000E+01, -.20987600E+01, 0.99380200E+01, 0.78950600E+01, -.84552200E+01, -.17095400E-01, -.90166600E+00, -.38990700E-01, 0.75269300E+00, -.24856700E+00, 0.65165300E+00, 0.63530800E+00, -.19717300E+00, -.87221600E-01, 0.70034800E+00, 0.10840200E+00, -.12341600E-01, -.32114000E-01, -.14111300E+00, -.18282500E+01, 0.74506100E+00, 0.34388600E-01, -.30357900E+01, -.16445700E-02, 0.32170000E+00, 0.14177400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.45585500E-01, 0.11076500E+00, -.81374100E-01, -.42945400E+00, 0.67811500E-01, -.88777000E-02, 0.26052500E-01, -.82250100E-02, 0.22435300E+00, -.39666000E-01, -.76045900E-02, -.31614700E-01, -.12482300E+00, -.10910900E-01, -.25501300E+00, -.88747400E-01, 0.15606000E-01, 0.92599600E-01, 0.11201700E+00, -.28479400E+01, 0.25652000E-02, -.92553400E-02, 0.31122500E-01, 0.17053700E-02, -.22356500E-02, 0.15068400E-02, -.84591300E-02, -.81370200E-02, 0.16825300E-01, -.23336600E-01, -.17020700E-01, -.24696100E+00, -.25001200E-02, -.23182200E-02, -.28611000E-02, 0.33910000E-02, -.13821100E-03, 0.31451800E-01, 0.78255500E-01, 0.24667900E-01, 0.18730400E-01, -.11493200E-02, 0.14775600E-01, 0.14835800E-01, -.39322900E-02, 0.33511200E-02, 0.14532800E+00, 0.23969000E-01, -.59821100E-03, -.46754500E-01, -.20726500E+00, -.83201300E+00, -.34209100E-01, 0.52517000E-02, -.88709200E-01, 0.67232100E-03, 0.17210800E-02, -.65594500E-03, 0.42586900E-02, -.61769800E-02, -.59737800E-03, -.32010900E-02, 0.49444200E-02, -.17696100E-03, -.29321600E-02, -.62201700E-02, 0.76343400E-01, 0.27113700E-01, -.11624100E-01, -.32666300E-02, -.15332300E-01, -.13688800E-02, -.57275900E-02, 0.30994700E-02, 0.27904800E-01, 0.43285400E-01, -.22183700E-01, -.10590200E-01, 0.68500600E+00, -.81349900E-02, -.14730100E-02, -.12219600E-03, 0.38554100E-02, 0.57198100E-02, 0.92919100E-03, -.11409200E-02, 0.79385400E-01, 0.34467200E-02, -.42948100E-02, 0.98069100E-03, 0.15978200E-01, 0.26507700E-01, -.77764700E-02, -.40513100E-02, 0.28170000E+00, 0.16088200E-01, -.27765600E-02, -.84599200E-02, 0.43107300E-01, 0.20813000E-01, 0.15075400E-01, 0.17179700E-01, 0.33073700E-01, 0.34631400E-02, 0.37638000E-02, 0.12117800E+00, 0.12370300E+01, 0.64657300E+00, -.12335100E+01, -.50295400E+00, -.16541900E+01, 0.64093400E+00, 0.33224700E+01, 0.10611900E+01, -.28210200E+00, -.23585700E+00, -.92671800E+00, 0.79947500E+00, 0.54372600E+00, -.74129100E-01, 0.37327200E+01, -.55493900E+01, -.20259900E+01, -.13537600E+01, 0.11720100E+01, 0.25141400E+01, 0.13369200E+01, -.11138500E+01, 0.12565600E+02, 0.37072000E+01, -.36104900E+01, -.16117700E+01, -.21215900E+01, 0.50180100E+01, 0.12569600E+01, -.14203400E+01, 0.12562100E+00, -.10024900E+00, -.76873200E-01, -.92023900E-01, 0.87140700E-01, 0.98930500E-01, 0.67563600E+00, -.75478600E-01, 0.15375700E+01, 0.35938100E+01, -.20048900E+01, -.88789400E+00, -.33874900E+00, 0.89431000E+00, 0.13904500E+01, -.10020300E+01, 0.89514700E+00, -.27820600E+00, 0.56138900E+00, 0.29993600E+00, -.47458400E+00, -.88460100E+00, -.24038500E+01, 0.20499600E+00, -.12820900E+00, -.12766000E+00, -.25564900E-01, 0.27162000E+00, -.10432400E+00, 0.83000500E-01, 0.24387700E+00, -.11552200E+00, -.40589100E-01, 0.53892100E+00, 0.23797900E-01, -.22029400E-01, -.10968300E-01, -.95812500E-01, -.27888900E+00, -.75409200E-01, 0.50849700E+00, -.11362900E+01, -.35183200E-01, 0.14522600E+00, 0.15390600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16748500E+01, -.59548800E+00, -.30088300E+00, -.52985800E+00, 0.91261500E-01, -.99594900E-01, -.48490800E+00, 0.39631800E+00, -.27456600E-01, -.21651200E+00, 0.73157100E-01, -.16002900E+00, -.44096400E+00, -.18489500E-01, -.10382200E+00, 0.65458300E-01, 0.33267600E-01, -.27510400E+00, -.33606400E+00, 0.76367200E-01, -.32836800E+00, -.21801100E+00, -.57050000E-01, 0.61991700E-01, 0.83767500E-01, -.52792900E-02, 0.29321300E-01, -.92059900E-01, 0.28145100E-01, -.86163400E-01, 0.22199200E-01, -.12367100E+01, 0.16844400E+00, 0.21007600E-01, -.97998500E-02, 0.36169800E-01, 0.24995000E+00, 0.10290600E+00, 0.34580700E+00, -.13494000E+00, -.72945800E-01, 0.56850700E-01, 0.63825700E-01, 0.12707200E+00, 0.10916900E+00, 0.27473700E-01, -.62747600E+00, -.12111900E+00, -.39773800E-03, -.11290500E+00, -.15008800E+00, -.33786200E+00, -.10081600E+00, -.94997100E-01, 0.52272700E+00, -.15836800E+00, 0.99102000E-02, 0.37864600E-02, -.46304000E-01, 0.20993800E-01, 0.19815100E-01, -.66031200E-01, -.26421000E-03, -.99770800E-01, 0.43158300E-01, 0.24299100E-01, -.18036600E+00, -.11445600E+00, -.51214700E-01, -.12979700E-01, -.13045300E+00, 0.13578200E-01, -.11377800E-01, 0.39963700E-02, -.41450300E-01, -.61968600E-01, 0.53466600E-01, -.51208400E+00, -.10931800E+00, -.10896500E+01, -.52781200E-02, -.99698200E-03, 0.10405700E-01, -.19435700E-01, 0.20819300E-01, 0.76602100E-01, 0.20028500E-01, 0.64297100E-01, -.17236200E-01, -.57793000E-03, -.82205300E-02, -.18581500E+00, 0.15361300E+00, 0.28280000E+00, 0.10193900E+00, 0.15675300E+00, 0.17493300E+00, 0.97245100E-01, -.59816900E+00, -.53763600E+00, -.29596800E-01, 0.94913100E-02, -.87854700E-01, -.46132200E+00, -.19802000E+00, 0.10884700E+01, -.95712100E+01, 0.70310700E+01, -.16892500E+02, -.15219100E+02, -.19375900E+02, 0.33893900E+01, 0.49611400E+02, 0.19141800E+01, -.61407200E+01, -.83434200E+01, -.50873700E+01, 0.19772200E+02, 0.12366500E+02, -.37541700E+01, 0.27709600E+02, -.41373200E+02, -.15273500E+02, -.16138900E+02, 0.33447900E+02, 0.27443700E+02, 0.28356900E+02, -.16386400E+02, 0.55942000E+02, -.30332000E+02, -.75470100E+01, 0.47039100E+01, -.96533000E+01, 0.15017500E+02, -.10968800E+02, 0.55487600E+01, 0.10711300E+01, -.10619600E+01, -.48582200E+00, -.96226300E+00, 0.94391400E+00, 0.27614600E+01, 0.61668000E+01, -.15779000E+00, -.46801500E+02, 0.20333000E+02, -.15598700E+01, 0.41515100E+01, 0.73813500E+01, -.21459500E+02, -.26153000E+01, 0.21271000E+00, -.95948700E+02, 0.67230300E+02, 0.14980900E+02, 0.18869600E+02, 0.68263100E+01, -.47888500E+02, -.44646600E+02, 0.13332400E+02, -.12426900E+01, -.26346700E+00, -.30396600E+00, 0.36713600E+01, -.11494300E+01, 0.28125400E+00, 0.38691600E+01, -.96508700E+00, -.50566800E+00, 0.64652100E+00, 0.47688400E+00, -.22333400E+00, -.15966700E+00, -.53702200E+00, -.88969300E+00, -.25489500E+01, 0.11151700E+02, -.20920600E+01, -.10264900E+01, 0.13087200E+00, 0.98747800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.59113600E+00, 0.12603200E+00, 0.18876200E+00, -.35454500E+00, 0.38056600E-01, -.11498800E+00, -.57548000E+00, 0.65803600E+00, 0.12974600E+00, 0.13505800E+00, -.58182700E-01, 0.15585000E+00, -.21135800E-01, -.21354100E-02, 0.14125800E+00, 0.18490200E+00, 0.97575800E-02, 0.12354200E+00, 0.73690100E-01, -.31524500E+00, 0.12122700E-01, -.60886400E-01, 0.24946500E+00, 0.37287700E-01, 0.18625300E+00, -.37857900E-02, -.44407000E-01, -.87127100E-01, 0.17234100E+00, -.62078400E-01, -.13164800E+00, -.91164700E+00, 0.19485600E+00, -.28333900E-01, -.84581200E-02, 0.78407700E-01, 0.89190800E-01, -.29065900E-02, 0.56105700E-01, -.90551100E-01, -.16526300E+00, 0.69071000E-01, 0.63102600E-04, 0.51505200E-01, 0.78651500E-01, -.45222300E-01, -.18111800E+00, -.12954200E+00, -.14782800E+00, -.39684800E-01, -.16099200E+01, 0.43086000E+00, -.18793500E+00, 0.10114100E-01, 0.62418600E-01, -.30433100E-01, 0.22148600E-01, 0.27721400E-02, 0.33802000E-01, -.21337600E-01, -.25951700E-01, 0.29115700E-01, 0.20132800E-01, -.42472700E-01, -.23825700E-01, 0.76201600E-02, -.16068200E+00, -.11944400E-01, -.54941400E-02, 0.38326800E-01, 0.62703800E-02, -.22934400E-01, 0.27393300E-02, 0.20249900E-02, 0.68563600E+00, -.84832200E-01, -.13299200E-01, 0.50169700E-01, -.20451800E-02, 0.38695300E+00, -.23859700E-03, 0.14262700E-03, 0.79657500E-01, -.15182000E-02, 0.20646300E-02, 0.12966000E-03, 0.89987000E-02, -.33114000E-01, -.48202600E-03, 0.29955000E-03, 0.28184400E+00, -.19013100E-01, 0.26093500E-01, 0.12517000E-02, 0.39176000E-01, -.13183500E+00, 0.15819800E-01, -.69366000E-02, -.33332400E-01, -.19556900E-01, 0.18893400E-01, -.24125200E-02, -.28503600E-01, -.19119700E-01, -.16867100E-01, 0.11256800E+00, -.11765200E+01, -.19732100E+00, -.29709500E+01, -.49919800E+01, -.38943700E+01, -.63616200E+00, 0.16992100E+02, 0.14672600E+01, -.12825900E+01, -.19197200E+01, -.32081400E+01, 0.69848900E+01, 0.20782000E+01, -.30313200E+00, 0.70209500E+01, -.15415100E+02, -.60386400E+01, -.46251400E+01, 0.12264600E+02, 0.87831300E+01, 0.97682600E+01, -.44018400E+01, 0.34083400E+02, -.12005400E+02, -.54254600E+00, 0.34959200E+01, -.91316100E+01, 0.10276500E+02, -.27856800E+01, 0.44192700E+01, 0.40109200E+00, -.38852700E+00, 0.64803800E-01, -.34251400E+00, 0.35947200E+00, 0.69366900E+00, 0.20002700E+01, -.27148100E+00, -.11231600E+02, 0.50351700E+01, -.11639200E+01, 0.25523100E+01, -.72981800E+00, -.50223400E+01, -.66411700E+00, 0.16871800E+01, -.25711100E+02, 0.22085900E+02, 0.33475700E+01, 0.60195200E+01, -.20419000E+01, -.11760000E+02, -.15438000E+02, 0.41038500E+01, -.47736700E+00, -.60569000E+00, -.94065400E-01, 0.10691900E+01, -.61304600E+00, 0.81919300E+00, 0.11785100E+01, -.50024300E+00, -.14619500E+00, 0.30409800E+00, 0.10363000E+00, -.69015300E-01, -.44064700E-01, -.10218600E+01, -.10788900E+01, -.20578600E+00, 0.42221900E+01, -.94779200E+00, -.16680000E+00, 0.11899100E+01, 0.11504100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.43609800E+01, 0.18975600E+01, 0.89904200E+00, 0.52323000E+00, -.97370800E-01, -.85137600E-01, 0.18315100E+01, -.11856800E+01, -.23071500E+01, -.19610200E+01, -.11624500E+01, -.14930300E+00, -.18635700E+01, 0.10039800E+00, -.42807900E+01, -.19867900E+01, -.16206200E+01, 0.12323000E+01, -.51536200E+00, 0.22715800E+02, 0.21634900E+01, -.48221300E+00, 0.27541200E-01, 0.56989500E+00, -.28933400E+00, -.64109600E+00, -.90914700E+00, -.81715000E+00, 0.71643100E+00, -.10273400E+01, 0.61177400E-01, 0.94919500E+01, -.16312600E+01, -.35213800E+00, -.28641300E-01, -.21233600E+00, -.79616600E+00, 0.18216200E+00, -.11004200E+01, 0.11307300E+01, 0.37252800E+00, -.17134900E+00, -.43165100E-01, -.24276300E+00, -.17469500E+01, -.19681800E+00, 0.21560900E+01, 0.17849300E+01, 0.87941600E+00, 0.10715200E+01, -.10573700E+02, 0.16082600E+02, 0.72492900E+00, 0.10063700E+01, -.12861900E+02, 0.45993300E+00, -.34671900E-01, -.36879400E-01, 0.73640600E+00, -.17309700E+00, -.15866400E+00, -.13182800E+01, 0.10830800E+00, 0.11531000E+00, 0.43180300E+00, -.64279700E+00, 0.33902100E+01, 0.35063400E+00, 0.25405900E+00, 0.35816300E+00, -.12087000E+01, 0.72173100E-01, 0.95504800E-01, -.39484000E-01, 0.27579800E+00, 0.17510900E+00, -.11082200E+00, -.73536300E+00, -.21712500E+00, -.44634200E+01, 0.23323300E-01, 0.56328100E-02, 0.26106200E-01, -.45871400E-01, -.12699200E+00, 0.27660800E-02, -.90887800E-01, 0.32314000E+00, 0.64890200E-01, -.23597500E-02, 0.67102400E-01, -.35501900E+00, -.71784400E-01, 0.15454900E-01, -.99472100E-01, 0.10191200E+01, 0.26370700E+00, 0.22012600E+00, -.57058200E+00, -.71818000E+00, 0.41926600E+00, 0.53857200E-01, 0.36384000E+00, -.70974800E-01, -.13099400E+00, 0.48180800E+01, -.92066700E+01, 0.22733900E+01, 0.31500700E+01, 0.36631000E+02, -.23895100E+01, -.66479800E-02, -.70316600E+02, -.15881000E+02, 0.68583400E+01, 0.93024000E+01, 0.18764600E+02, -.36387300E+02, -.61117800E+00, -.40066500E-01, 0.20332700E+01, 0.53849800E+02, 0.20960400E+02, 0.26648200E+02, -.82451000E+02, -.26333000E+02, -.55782400E+02, 0.32360500E+02, -.75056000E+02, -.40013400E+02, -.37804600E+02, -.33312900E+02, 0.24914700E+02, -.22254100E+02, -.73910000E+01, -.30026200E+02, -.18357600E+01, 0.18411600E+01, -.66694100E-01, 0.13409300E+01, -.22329700E+01, -.70847400E+01, -.15179100E+02, 0.20433100E+01, 0.13570100E+03, -.79344000E+02, -.14935100E+02, -.28558100E+02, -.94174400E+01, 0.51228700E+02, -.37220200E+01, -.21881700E+02, 0.12245100E+03, -.94289200E+02, -.23104400E+02, -.45155800E+02, 0.59772900E+02, 0.45391600E+02, 0.71185900E+02, -.39919500E+02, 0.27007000E+01, 0.33407200E+01, 0.10166300E+01, -.87265200E+01, 0.30729800E+01, -.35532000E+01, -.99842900E+01, 0.23237500E+01, 0.18246100E+01, -.28488000E+01, -.19559100E+01, 0.66180300E+00, 0.60446000E+00, 0.55186200E+01, 0.63550100E+01, -.12444200E+01, -.24375600E+02, -.18408500E+02, 0.28837400E+01, 0.13028700E+01, -.21280600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.30801900E+01, 0.18008500E+01, 0.12695900E+00, 0.55512200E+00, -.13138600E+01, 0.56407900E+00, -.33671900E+00, 0.98254000E+00, -.44850100E+00, -.11006200E+01, 0.12448900E-01, 0.57099500E+00, -.25713200E+01, -.15611400E+00, -.46956700E+01, -.78021100E+00, -.11410300E+01, 0.10538000E+01, 0.77012800E+00, -.44056700E+00, 0.16128200E+01, 0.62585800E+00, 0.23462600E+01, 0.22584000E+00, 0.78686700E-01, 0.12021100E+00, -.65655100E+00, 0.83897000E+00, 0.70628400E+00, 0.16703100E-01, -.39201000E+00, 0.10241100E+02, -.23873400E+01, -.29810800E+00, 0.35835400E-01, 0.40348400E+00, -.47221200E+00, -.11113300E+00, -.39766600E+00, 0.89782000E+00, -.30062200E+00, -.35716300E-01, -.55389000E+00, -.35108600E+00, -.56069500E+00, 0.84195200E-01, 0.19297000E+01, 0.50097200E+00, -.33194000E-02, 0.51320300E+00, -.11467000E+01, 0.82284500E+01, -.33886000E+00, 0.29927400E+00, -.85775600E+01, 0.12943700E+01, 0.16275900E+00, -.75810400E-02, 0.39774200E+00, -.23200700E+00, -.75112100E-01, -.57640100E+00, 0.29687700E+00, -.26131600E+00, 0.11436900E+00, -.52509400E+00, 0.49314300E+00, 0.76552900E+00, 0.58363300E+00, -.23286700E-01, -.51310200E+00, -.41845900E+00, 0.64909700E-01, -.23085400E-01, -.51238200E-01, 0.11645300E-03, -.14541200E+00, -.46146200E-01, 0.85680200E-01, 0.12653800E+01, 0.12610200E-01, -.34306900E-02, 0.21823000E-01, -.23801700E-01, -.27155000E-01, 0.48226900E-02, 0.45982600E-01, -.10828400E+00, 0.38735100E-01, -.29035200E-01, 0.36718300E-02, -.14576400E+00, 0.76456200E-01, 0.20367400E-01, 0.19430900E+00, -.42002400E+00, 0.33501500E+00, 0.62768900E-01, 0.47663400E+00, 0.29223000E+00, -.75044300E-01, 0.24905500E+00, 0.40076100E+00, 0.30109900E+00, 0.12170700E+00, 0.67567900E+00, 0.64488100E+01, -.88375500E+00, -.10783700E+01, -.44667100E+00, -.15688800E+02, -.86866100E-01, -.44159000E+01, -.10493700E+02, 0.22459200E+01, 0.64683700E+01, 0.16615100E+01, -.17035300E+01, 0.28035400E+01, 0.61919200E+01, -.44048200E+00, 0.17423700E+02, -.23779100E+01, -.23901800E+01, -.89344000E+01, -.55474900E+01, -.10663000E+02, -.29909200E+01, 0.31127400E+02, -.62115700E+02, -.14384400E+02, -.96629400E+01, 0.57521600E+01, 0.10930000E+02, -.12283400E+02, -.48874300E+01, -.32899400E+00, 0.24009400E+00, -.15849600E-01, -.33995100E+00, -.18160800E+00, -.60860300E+00, -.37043900E+01, 0.31770200E+00, 0.44370600E+02, -.30685400E+02, -.79643700E+01, -.10689700E+02, -.76536400E+00, 0.12447100E+02, -.11245100E+02, -.10210100E+02, -.46240900E+01, -.99212200E+01, 0.11741300E+02, 0.73842600E+01, -.13760500E+02, -.14735600E+02, -.14917000E+02, 0.14660800E+01, 0.46490300E+00, 0.16308500E+01, 0.23763000E+00, -.20681800E+01, -.16009600E+01, -.34462300E+00, -.19860200E+01, -.16607300E+01, 0.45117300E+00, -.74050200E-01, -.45916900E+00, 0.15179400E+00, 0.14470100E+00, 0.21190500E+00, 0.13887500E+01, -.91859600E+00, -.62971800E+01, 0.10023700E+01, 0.44249500E+00, -.19746400E+01, 0.38161700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14731800E+01, -.48798900E+00, 0.69272200E-01, -.30806800E+00, 0.74171200E+00, -.30753800E+00, -.12552400E+00, -.65091700E+00, -.43382000E+00, 0.25087500E-01, -.10393000E+00, -.84280000E+00, 0.69640300E+00, 0.93627900E-01, -.14648600E+00, -.71279700E+00, 0.22101600E-01, 0.27689000E+00, 0.27035700E+00, -.25273500E+01, 0.40537900E+00, 0.30728800E+00, 0.10921200E+01, -.23821500E-01, 0.71510900E-01, -.25594400E-01, -.18864600E+00, -.47296500E+00, 0.57526200E+00, -.91241500E-01, 0.17305200E+00, 0.38120600E+01, -.97205000E+00, -.17406600E+00, 0.11307300E-01, -.21928400E+00, -.12495700E+00, 0.16141900E-01, -.21763800E+00, 0.12520800E+00, 0.16941500E+00, -.99120900E-01, 0.13232700E+00, 0.12203500E+00, 0.32590000E+00, -.20001900E+00, 0.94802600E+00, 0.77049000E+00, 0.16916800E+00, 0.83683000E-02, -.20280500E+01, -.98226900E+00, -.13157700E-01, 0.38033800E-01, 0.36357200E+01, 0.15661300E+00, 0.20867500E-01, -.52586800E-02, 0.91538200E-01, -.88083100E-01, -.16600500E+00, 0.44934000E+00, -.45790800E-01, 0.40021400E+00, -.25206900E+00, 0.57000900E-01, 0.16033200E+01, 0.39786700E+00, 0.56344700E+00, 0.22115700E+00, -.10975300E+01, -.10659700E+01, -.62330600E-01, 0.32851200E-01, 0.19804800E+00, 0.20534800E+00, 0.19350100E-01, -.47049000E-01, -.12604800E+00, 0.34932700E+00, -.10599800E-01, -.32210800E-02, 0.14503000E-01, 0.14954400E-01, 0.49526600E-01, -.55746800E-02, 0.23657100E-01, -.23839000E-01, -.34810500E-01, 0.20997800E-02, 0.52870300E-01, 0.48128400E-01, 0.14401900E+00, -.20187100E-01, 0.33459500E-01, -.93340200E-01, 0.36620300E-01, -.73574900E-02, 0.41189900E-02, 0.20125100E+00, -.27237600E-01, -.43640800E-01, 0.92496100E-01, 0.44516700E+00, -.76627600E-01, 0.21259900E+00, 0.46452900E+01, -.74514800E+00, 0.14393100E+01, 0.17945900E-01, -.82869800E-01, -.19316000E+01, -.16019500E+02, 0.48784600E+01, -.95235000E+00, 0.24183300E+01, 0.27139900E+01, -.79968300E+01, -.37342100E+01, 0.20537100E+01, -.94126000E+01, 0.17084100E+02, 0.80856500E+00, 0.16539600E+01, -.52701100E+01, -.86743000E+01, -.34192100E+01, -.10149600E+00, -.90093100E+02, 0.23413200E+02, 0.64824800E+01, 0.13374400E+02, 0.11102300E+02, -.46877200E+02, -.29165500E+02, 0.82749700E+01, -.32487300E+00, 0.11471700E+00, -.19737900E+00, 0.88672400E-01, -.25239700E+00, 0.66208800E+00, -.11626700E+01, 0.46601600E+00, -.55068700E+02, 0.13473500E+02, 0.45507000E+01, 0.45210400E+01, 0.14523100E+02, -.27826700E+02, -.14485800E+02, 0.95371800E+00, 0.18581500E+02, -.13454000E+02, -.91484700E+01, -.10157900E+02, 0.51909900E+01, 0.93054600E+01, 0.18033200E+02, -.10488800E+02, 0.25154200E+00, 0.79874200E+00, 0.41494800E-02, 0.10258800E+01, -.33772200E+00, 0.96530300E-02, 0.88532100E+00, -.48130700E+00, 0.27304800E-03, -.81061200E-01, 0.11926600E+00, 0.32000100E-01, -.28325400E-01, 0.33538900E+00, 0.12228700E+01, 0.13121800E+00, -.35407700E+01, -.78468400E+00, -.38225200E+00, -.40162500E+01, 0.32040900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27116200E+01, 0.50311200E+00, 0.66272800E+00, 0.88171000E+00, -.94537400E+00, 0.81065500E+00, -.49123900E+00, 0.12984600E+01, -.22663400E+01, -.23335700E+01, -.10999100E+01, -.43047500E+00, -.33264700E+01, -.15047400E+00, -.50939000E+01, 0.62649400E+00, -.83262700E+00, -.81473000E+00, -.13775100E+01, 0.11232100E+02, -.62703600E+00, -.16707800E+01, -.12837100E+01, 0.72159400E+00, 0.15920000E+00, -.61082200E-02, -.39284600E+00, -.92060400E+00, 0.10702100E+01, -.60635500E-03, -.29881600E-01, 0.48307200E+00, -.20260400E+01, -.18779800E+00, 0.30923000E-01, -.23607400E+00, -.38849600E+00, 0.68846800E-01, -.47405000E+00, 0.34123800E-01, -.25529800E+00, 0.35925700E-01, 0.90009100E-02, 0.11234100E+01, 0.10319000E+01, -.36069800E-01, -.35495500E+01, 0.40038600E-01, 0.71059400E+00, -.14997100E+00, -.86276000E+01, 0.41576700E+01, -.76400100E+00, -.17945500E+00, 0.26944100E+01, -.63301500E+00, 0.91127400E-01, 0.28810100E-02, 0.94184800E-01, -.20416400E+00, -.12985000E+00, -.33234500E+00, 0.32874200E-01, -.38458800E+00, -.43377300E+00, -.96996400E-01, -.43522000E-01, -.26066500E-01, -.44034700E+00, 0.28677900E+00, -.73653700E+00, -.84859000E+00, 0.63036000E-01, -.35706100E-01, -.44590000E+00, -.27203800E+00, -.28726900E-01, 0.74025900E-01, 0.25956800E-01, 0.11004000E+01, 0.10100100E-01, -.69882600E-03, -.26653500E-01, -.22025100E-01, -.18968500E-01, 0.30761100E-02, -.92340100E-02, -.97899800E-01, 0.35097700E-01, -.11628100E-01, -.10974500E+00, -.41467300E-01, -.10496500E+00, 0.12907700E-01, -.22098800E-01, -.31549400E+00, 0.14743100E+00, 0.79910400E-01, 0.24749100E+00, 0.43995300E+00, -.21790400E+00, 0.16779500E-01, -.19105600E+00, -.17145800E+00, 0.22406000E+00, -.18799800E+00, -.73925500E+01, 0.24330600E+00, -.27202300E+01, -.24745400E+00, -.27835000E+00, 0.10452000E+01, 0.51987400E+02, -.59513400E+01, 0.12136800E+01, -.37560700E+01, -.10662900E+02, 0.19676100E+02, 0.86637000E+01, -.10493300E+01, 0.42771300E+02, -.63343700E+02, -.12595900E+02, -.94918400E+01, 0.14719300E+02, 0.32056800E+02, 0.78160400E+01, -.50972600E+01, 0.28394700E+03, -.91293400E+02, -.33735600E+02, -.32226800E+02, -.48802900E+02, 0.12420000E+03, 0.38681200E+02, -.18934600E+02, 0.12650700E+01, -.78396800E+00, 0.12381700E+00, -.11707300E+01, 0.93338100E+00, -.84863900E+00, 0.51604100E+01, -.12262700E+01, 0.12161000E+03, -.37500800E+02, -.20627300E+02, -.96093000E+01, -.33681200E+02, 0.60532000E+02, 0.28803200E+02, -.27115100E+01, -.36853500E+02, 0.44954800E+02, 0.16369500E+02, 0.14975600E+02, 0.37111600E+01, -.21171900E+02, -.45043500E+02, 0.12162100E+02, -.93635900E+00, -.80600300E+00, -.39763600E-01, -.11133500E+01, 0.17936700E+01, -.20341100E+00, -.90505700E+00, 0.21400100E+01, -.15340300E-02, 0.21042300E+01, -.37078300E+00, -.14600600E+00, 0.83733400E-01, -.77058400E+00, -.35426000E+00, -.13449800E+01, 0.93685400E+01, -.85066300E+01, 0.79965000E+00, 0.11849800E+02, -.46716500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.29508500E+01, 0.60055500E+00, 0.86454600E+00, -.19337000E+01, 0.30463900E-01, -.73718500E+00, -.27839200E+01, 0.28880000E+01, -.67063600E-01, 0.52923200E+00, -.11627100E+01, 0.61933600E+00, 0.63064700E+00, 0.46447900E-01, 0.40321200E-01, 0.10592100E+01, -.22402200E-01, 0.34102400E+00, -.17949500E-01, 0.53867300E+01, -.66934400E+00, -.46326500E+00, 0.17934600E+01, -.23951500E+00, 0.10627800E+01, 0.17130900E+00, -.20748100E+00, -.15711200E+01, 0.91687900E+00, 0.98403200E-01, 0.14516300E+00, -.39388200E+01, -.32333300E+01, -.43899100E+00, -.22654000E-02, -.46026100E+00, -.30054200E+00, 0.48578000E+00, 0.80690500E+00, 0.17314400E+00, 0.56385300E+00, 0.11050600E+00, 0.39532700E+00, 0.16949700E+00, 0.56231800E+00, -.67679400E-01, -.32496200E+01, -.11586000E+01, -.90728000E+00, -.28727300E+00, -.96031700E+00, 0.34016000E+01, 0.20711100E+00, -.32306200E+00, 0.40759000E+01, -.54576600E-01, 0.13654800E+00, 0.21905100E-01, 0.51452600E-01, -.13914500E+00, -.15231300E+00, -.13678600E+00, 0.88444500E-01, -.15734000E+00, -.18571000E+00, 0.83498700E-01, -.77799800E+00, 0.22565400E+00, 0.17712900E-01, 0.37392000E-02, 0.16991800E+01, 0.68764200E+00, 0.80163400E-01, -.86841500E-02, -.36467500E+00, -.67345100E+00, 0.19397300E+00, 0.64711900E+00, 0.57203600E+00, 0.20809000E+01, 0.86660500E-02, -.14768500E-02, -.14341100E-01, -.10354200E-01, 0.97668200E-02, 0.79665100E-02, 0.91538400E-01, -.16554500E+00, 0.32830600E-01, -.18144400E-01, -.75324500E-01, -.12022500E-01, 0.74283600E-01, 0.30154500E-01, 0.34246600E+00, -.56150700E+00, -.27426700E+00, -.16007500E+00, 0.37824300E+00, -.88202800E-01, 0.43224200E-01, 0.16685100E+00, -.11758700E-01, 0.53351100E+00, -.16522800E+00, -.65407700E+00, 0.88981700E+01, -.16616900E+01, -.82792000E+00, -.63948300E+00, -.12078000E-01, 0.79370500E+00, 0.14726500E+00, -.22126800E+02, 0.33533100E+00, 0.36404300E+01, 0.65901800E+01, 0.72666600E+01, -.24456700E+01, 0.26250500E+01, -.35580600E+02, 0.61380500E+02, 0.18517200E+02, 0.15196400E+02, -.60928600E+01, -.21228000E+02, -.13336800E+02, 0.17013700E+02, -.71559900E+02, -.46594700E+02, 0.24026700E+02, 0.11003500E+02, 0.29331600E+02, -.17132600E+02, 0.23993600E+01, 0.17886900E+02, -.11508200E+01, 0.10185500E+01, 0.44807000E+00, 0.20650900E+00, -.47870800E+00, -.12900300E+01, -.42440200E+01, 0.54658200E+00, 0.42991700E+02, -.49075500E+02, 0.68400700E+01, -.31687000E+01, 0.47508200E+00, 0.19336000E+02, -.99106900E+01, -.12162500E+00, -.91722700E+02, 0.26809500E+02, 0.27946400E+02, 0.40234300E+02, -.38920500E+02, -.45478100E+02, -.45061600E+02, 0.34557300E+02, 0.11852100E+01, 0.30401800E+01, 0.26879300E+00, -.39877900E+01, 0.48849100E+01, -.15297400E+01, -.27163500E+01, 0.50827700E+01, 0.43772600E+00, -.48212200E+01, -.40556100E+00, 0.11314200E+00, 0.19009400E+00, 0.40932600E+00, 0.30825100E+01, 0.53458200E+00, -.24942800E+01, 0.17491800E+02, 0.47006900E+00, -.20879500E+01, 0.10945300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17145800E+01, -.32032800E+00, -.50281000E+00, 0.95738900E+00, -.21864900E+00, 0.28866000E+00, 0.18050900E+01, -.18860900E+01, -.23447400E+00, -.16740900E-01, 0.19389400E+00, -.12787900E+00, 0.44356300E+00, 0.22543400E-01, 0.73948500E+00, -.65515400E+00, 0.13118000E+00, -.20214900E+00, 0.71948700E-01, -.76863400E+00, 0.11484700E+00, 0.96898700E-01, -.15998500E+01, -.93645300E-01, -.38625500E+00, -.37150800E-01, 0.22003100E+00, 0.44626100E+00, -.82904400E+00, 0.74624500E-03, 0.13298600E+00, 0.18511000E+00, 0.49952700E+00, 0.12999100E+00, -.24520300E-01, -.16832600E-01, -.46286700E-01, -.11844000E+00, -.43571900E+00, 0.16734000E+00, -.25775900E+00, 0.13420900E-01, -.40170500E-01, 0.13102700E+00, 0.13643700E-01, 0.14742300E+00, 0.44698000E-01, 0.21145800E+00, 0.40580700E+00, -.13313400E-01, 0.16912600E+01, -.28704700E+01, 0.26628100E+00, -.64594900E-02, 0.87592300E+00, -.12492200E+00, -.86172400E-01, -.44930800E-02, -.72175300E-01, 0.11488300E+00, 0.34294900E-01, -.10782900E+00, -.11215900E+00, 0.48866200E-01, -.51107200E-02, 0.93589800E-01, -.17145700E+00, 0.73369900E-01, 0.31713000E+00, 0.13955100E+00, -.18885100E+00, 0.10452200E+00, -.23978800E-01, 0.11347000E-01, 0.14574200E+00, 0.21980000E+00, -.70466900E-01, -.18197300E+00, -.86347300E-01, 0.14360900E-01, -.26711700E-02, -.13893400E-03, 0.95215500E-02, -.41642100E-04, 0.83650700E-02, -.33585300E-02, -.89124500E-03, -.34983700E-02, -.80791900E-02, 0.23133000E-02, 0.45246300E-01, 0.12672600E-01, -.11043000E-01, -.12153400E-01, -.37087600E-01, -.11906200E-01, 0.71451800E-01, 0.44040100E-01, 0.24663300E+00, -.43893000E-01, -.18936100E-01, 0.55737300E-01, 0.27435100E+00, 0.97843700E-01, 0.41154900E-01, 0.81270000E+00, 0.11676500E+01, 0.11337800E+00, 0.47407300E+00, 0.15988800E+00, -.20032700E+00, 0.36967900E-01, -.64465200E-01, 0.21496600E-01, 0.36022600E+01, 0.41120100E+01, -.46738500E+01, -.86269500E+00, -.17289600E+01, 0.41629600E+01, -.46466300E+00, 0.97366700E+00, 0.17157700E+00, -.12931500E+01, 0.11739900E+01, -.61058500E+00, -.96979700E+00, -.11242200E+01, 0.64791400E+02, -.20392500E+02, -.44595800E+01, -.10094700E+02, -.10835800E+02, 0.25388300E+02, -.22338200E-02, -.82321100E+01, 0.20708900E+00, -.72120700E-01, 0.56308400E-03, -.32534300E+00, 0.10177800E+00, 0.40680900E+00, 0.68597900E-01, -.43332400E+00, 0.36756600E+02, -.10586500E+02, -.56434800E+01, -.79045500E+01, -.64707800E+01, 0.14659900E+02, 0.69519300E+00, -.77947000E+01, -.50653200E+01, -.50056500E+01, -.22719100E+01, -.54263500E+00, -.10250000E+01, -.16934700E+01, 0.29320400E+01, -.13949800E+01, -.47942900E-01, 0.59593900E+00, -.74200400E-02, -.83129500E+00, 0.55637200E+00, -.34979400E+00, -.82993800E+00, 0.56394100E+00, -.20831000E-02, -.10414400E+01, 0.27971800E-01, 0.23453600E-02, -.10867700E-01, -.12054900E+00, 0.48486900E+00, 0.85121600E+00, 0.62136100E-01, 0.10915000E+01, -.12497800E+00, 0.17131600E+01, 0.10052500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.34449300E+01, 0.54651500E+00, 0.88175200E+00, 0.12725000E+01, -.11204700E+01, 0.12242300E+01, -.15836400E+01, 0.63634900E+00, -.23740500E+00, 0.29178400E+00, -.61847700E+00, 0.15809000E+01, -.16762300E+01, -.13853500E+00, 0.19787000E+01, 0.55716400E+00, 0.47185100E+00, -.64115700E+00, -.29380400E+00, 0.52096300E+01, -.19067300E+01, -.11718800E+01, -.47610900E+00, -.40117100E+00, 0.44683900E+00, 0.42910300E+00, -.41765900E+00, -.15393000E+01, 0.24330600E+00, -.34766100E+00, 0.96525300E+00, -.90470300E+00, -.71428300E+01, -.59619800E+00, -.12351000E+00, -.69419300E+00, -.11886100E+01, 0.19414000E+00, 0.95346100E+00, 0.11290500E+01, 0.24490400E+01, -.54445200E+00, 0.34472500E+00, -.39657300E+00, 0.26022100E+00, -.20469100E-02, -.18813400E+01, -.81846800E-01, -.25721300E+00, -.79419400E+00, 0.89680400E+01, -.59979900E+01, 0.20876500E+01, -.61797900E+00, 0.21541900E+01, -.93744300E-01, -.14102900E+00, -.92974400E-02, -.27331200E-01, 0.15818400E+00, -.24114700E-01, -.74724500E+00, -.24839900E+00, -.16647100E+00, 0.46631900E+00, 0.33067600E+00, -.29580100E+01, -.53949600E+00, 0.66356500E+00, 0.14027600E+00, 0.48129800E+00, 0.78560700E+00, 0.31564900E-01, -.12252200E-01, -.66268400E-02, -.50629700E+00, 0.55297500E+00, -.14783300E+00, 0.52910800E+00, 0.53520500E+00, 0.63417500E-02, -.24925900E-02, -.49846300E-02, -.39306900E-01, 0.30663000E-01, 0.65889700E-02, 0.56792600E-01, -.64294100E-01, 0.15600500E-01, -.96231500E-02, -.24731400E-01, -.19213900E+00, 0.20957200E+00, 0.22732900E-01, 0.27148700E+00, -.27312700E+00, -.17524800E+00, -.10982100E+00, 0.62503700E-01, -.60216900E+00, 0.13196500E+00, -.44357100E-01, -.10849900E+00, 0.93651700E+00, -.56894900E+00, -.61792700E+00, 0.31750700E+01, 0.34953200E+00, -.16752400E+01, 0.75368600E-01, -.53850900E+00, -.20591300E+01, -.10891500E+01, 0.45433000E+00, 0.86519200E+00, 0.66839100E+01, -.87230600E+00, -.17073600E+01, -.25803800E+01, 0.76158300E+01, -.20281500E+02, 0.20023000E+02, -.46142400E+01, 0.24110200E+01, -.41824600E+00, -.78126700E+01, -.11279600E+02, 0.48350000E+01, 0.48689500E+02, -.70061800E+02, -.23353100E+01, 0.15634000E+02, -.30678000E+02, -.79533200E-01, -.45259900E+02, 0.18240900E+02, -.39578500E+00, 0.82084400E-01, 0.61370200E+00, -.53999700E+00, 0.93301200E-01, -.10742500E+00, 0.23477500E+01, -.38600200E+00, 0.31456200E+02, -.34377500E+02, -.10411800E+02, 0.33201500E+01, -.14565000E+02, 0.18578400E+01, -.30109700E+02, 0.20531600E+01, 0.22807600E+02, 0.91817000E+00, -.12145400E+02, -.14594200E+02, -.97675900E+01, 0.74321500E+01, -.84474000E+01, -.23040900E+02, 0.33837200E+00, 0.67509100E-01, -.45533900E-01, 0.90959700E+00, 0.83036000E+00, 0.23323400E+01, 0.12351700E+01, 0.83021100E+00, -.90629800E-01, 0.31207800E+01, -.25136400E-01, -.14908300E+00, 0.50696500E-01, -.26889600E+01, -.23732000E+00, -.91008000E+00, -.26494200E+01, -.82396200E+01, 0.26511200E+00, 0.28067000E+01, 0.59520600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16941600E+02, -.63093300E+01, -.22813700E+01, -.30132200E+00, 0.84452000E+00, -.31074800E+01, 0.77106300E+01, -.57586700E+01, 0.87404500E+01, 0.10487000E+02, 0.45795300E+01, -.35467900E+01, 0.26809800E+02, 0.12021500E+01, 0.25821300E+02, 0.23109100E+01, 0.55161600E+01, 0.69420600E+00, 0.43696600E+01, -.11834000E+02, 0.24617200E+01, 0.56329200E+01, 0.87848800E+00, -.36941300E+01, -.45609700E-01, 0.17735800E+01, 0.27746100E+01, 0.22650400E+01, -.54354500E+01, -.15180800E+01, 0.25129700E+01, 0.22946700E+02, -.42260700E+01, -.36696900E+00, 0.15135900E+00, -.47584800E+00, 0.13669800E+01, -.14316400E+00, -.28008700E+01, -.15445900E+01, -.28796800E+01, 0.26450900E-02, -.49541500E+00, -.49832200E+01, -.54708900E+01, -.43985200E+00, 0.13192000E+02, 0.60384000E+00, -.21852300E+01, 0.42176000E+01, 0.33832800E+02, -.39940300E+01, 0.65791000E+01, 0.12346600E+01, 0.13856900E+02, 0.47377000E+01, -.24440700E+00, -.56702200E-01, 0.49578900E+00, -.51628700E+00, -.76689900E+00, 0.66300300E+00, 0.27529800E+00, 0.36873500E+01, -.58979600E+01, 0.13773200E+01, -.27345900E+01, 0.44261900E+00, 0.12573700E+00, -.36092300E+01, 0.46229200E+01, 0.40366900E+01, -.13427400E+00, 0.15587900E+00, 0.17277300E+01, 0.70434600E+00, -.72331000E+00, 0.41070600E+00, -.70415600E+00, -.26289400E+01, -.39470300E-01, 0.23519400E-01, 0.12432200E+00, 0.11536500E+00, 0.40445300E-01, -.46082500E-02, 0.95878200E-01, 0.26880100E+00, -.13527800E+00, 0.10004500E+00, 0.52396500E+00, 0.28506800E+00, 0.37341800E+00, -.35380500E-01, 0.14652500E+00, 0.80469800E+00, -.87031100E+00, -.18434300E+00, -.13941000E+01, -.35524500E+01, 0.14974700E+01, -.52704800E+00, 0.22835000E+01, -.89948800E+00, -.19388100E+01, 0.12814000E+02, 0.16570300E+02, 0.21480600E+01, 0.16418100E+01, 0.62907400E+00, 0.98343800E+00, -.46696900E+01, -.34956700E+01, 0.10081800E+01, 0.39623700E+01, 0.12775300E+01, -.16876300E+02, -.16053100E+02, -.91777500E+01, -.85850400E+01, 0.53336700E+02, -.25198000E+02, 0.63585500E+01, 0.90258300E+01, -.24966700E+02, 0.66298100E+02, 0.13173700E+02, 0.17264900E+02, 0.15366700E+03, 0.20006600E+03, -.44383900E+02, -.22918200E+02, -.51946600E+02, 0.89599200E+02, 0.71212800E+02, -.22337300E+02, 0.18548000E+01, -.29315100E+00, -.36514400E+00, -.19573900E+01, 0.37950800E+00, -.19345100E+01, 0.23659700E+01, -.29103800E+01, -.31928200E+02, 0.10099100E+03, -.23580400E+02, -.11349600E+02, 0.10124400E+02, 0.25193300E+02, 0.77744900E+02, -.88602700E+01, -.18404700E+02, -.92452400E+02, 0.35243200E+02, 0.33472800E+02, 0.38391800E+01, 0.24032100E+02, 0.38571300E+02, 0.49880000E+02, -.12540900E+01, -.57341000E+00, 0.30656700E+00, -.79275500E+01, 0.16514600E+01, -.26894300E+01, -.75417000E+01, 0.46049000E+00, 0.79564100E+00, -.15131500E+01, -.11252100E+01, 0.19374900E+00, 0.20015700E+00, 0.10065600E+00, -.18181800E-01, 0.71256100E+01, 0.64911500E+01, -.29328100E+02, 0.85199100E+00, 0.82296000E+01, -.13518200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14120100E+01, -.32967600E+00, -.33406500E+00, 0.75805600E+00, 0.19726700E+00, 0.31204200E+00, 0.96646100E+00, -.13483600E+01, -.55086300E+00, -.11740800E+01, 0.72697800E+00, -.29060600E+00, -.26567800E+01, -.15387100E+00, -.71407500E+00, -.37927700E+00, -.47803600E-01, -.90908600E+00, -.91876200E+00, 0.10736900E+01, -.50922000E+00, -.42322400E+00, -.40409500E+00, 0.16105000E+00, -.22088800E+00, 0.13301200E+00, -.15684100E-01, 0.33748700E+00, -.12543000E+00, -.59232200E+00, 0.50464900E+00, 0.35643000E+01, -.24831400E+01, -.18280100E+00, -.60466200E-01, 0.31869300E+00, 0.37901200E+00, -.16134200E+00, -.21487900E+00, 0.94841200E-01, -.11569800E+00, -.11479800E+00, -.16624700E+00, -.35672700E-01, 0.13840700E+00, 0.31246300E+00, -.10378000E+01, -.57269000E+00, 0.41625400E+00, 0.52656500E-01, 0.33784300E+01, -.54812500E+01, 0.14958600E+00, -.73323600E-02, 0.21746700E+01, -.14293800E+00, -.66078300E-01, 0.15288200E-01, -.19163000E+00, 0.21508300E+00, 0.78082200E-01, -.38956300E+00, -.14891500E+00, -.84206400E-01, 0.54168000E+00, 0.48568600E-01, -.93964900E+00, -.90406400E-01, 0.27376000E+00, 0.35018400E+00, 0.49231000E+00, 0.79948000E+00, 0.20488000E-01, -.89475100E-02, -.83040500E-01, 0.32541100E-01, 0.20528600E-01, -.17571200E+00, 0.49148800E-01, 0.16403800E-01, 0.42306900E-02, -.28817400E-04, -.42036900E-02, -.11130600E-01, 0.17860000E-02, 0.14043400E-02, 0.15573900E-01, -.85293700E-02, 0.14280900E-01, -.43809000E-02, -.28808900E-01, -.39656700E-01, 0.86842400E-02, 0.44557700E-02, 0.59211900E-01, -.30907000E-01, 0.25538900E-01, 0.25462400E-01, -.74115100E-01, -.77613000E-01, -.63215900E-01, 0.19560200E+00, 0.19098200E+00, 0.32902400E-01, 0.18242400E+00, 0.36916900E+00, -.17194100E+01, 0.36924600E+00, -.74317300E+00, 0.62123700E-01, -.59307000E-01, 0.33623100E+00, 0.29934100E+00, -.17710200E+00, 0.58788500E-01, 0.10055400E+00, 0.71715000E-01, 0.25671300E+01, -.49526400E+01, 0.60650000E-01, -.12746600E+02, 0.80323200E+01, 0.48237500E+01, 0.25061400E+01, 0.17151600E+01, -.13618300E+02, 0.21807600E+01, 0.21126900E+01, -.16564600E+02, -.24063400E+02, 0.11561800E+02, 0.48657100E+01, -.23848400E+01, -.11984100E+02, -.85719900E+01, 0.50130400E+01, -.24091700E+00, 0.12931500E+00, 0.17969300E+00, 0.34998200E+00, -.22414600E+00, -.14943700E-01, -.10899300E+01, 0.28559500E+00, 0.82705600E+01, -.12833500E+02, 0.70368100E+01, 0.15787500E+01, -.81467800E+01, -.19034700E+01, -.99382900E+01, 0.62194600E+00, 0.20954500E+01, 0.59501700E+01, -.46731400E+01, -.50562400E+01, -.43140200E+00, 0.68010100E+00, 0.54465500E+00, -.56531700E+01, 0.21440900E+00, 0.29806300E+00, 0.68224700E-02, 0.43161500E-01, 0.72806200E+00, 0.23657300E+00, -.73119800E-01, 0.89852500E+00, -.89824800E-02, -.20343700E+01, 0.71634100E-01, 0.24452500E-01, -.11582000E-01, 0.21350200E+00, 0.18810200E+00, 0.12820000E+01, -.20046100E+00, 0.21931500E+01, -.24931000E-01, 0.13045300E+01, 0.15696000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.61161000E+00, 0.33790500E+00, -.11061800E-01, 0.36051000E-01, -.24319000E+00, 0.39738300E-01, -.30950300E-01, 0.16294200E-01, -.71334200E-02, 0.34755000E-01, -.16006900E+00, 0.19233100E+00, -.24704400E+00, -.19804300E-01, -.15282300E+00, -.53273800E-03, -.38005400E-01, 0.26077800E+00, 0.14162300E+00, 0.23548700E+00, 0.43945800E-02, -.41250400E-01, 0.10760300E+00, -.65158000E-02, 0.63766700E-01, 0.30679900E-01, -.82983200E-01, -.13287200E+00, 0.21196000E+00, -.17245700E-01, -.58817300E-01, 0.53345100E-01, -.44329300E+00, -.57529300E-01, -.33049100E-02, -.40894900E-01, -.15293300E+00, 0.47103200E-01, 0.11635700E+00, 0.10873300E+00, 0.16243200E+00, -.19473800E-01, 0.76190400E-02, 0.38519300E-02, -.89500500E-02, 0.11121100E-01, 0.16657700E+00, 0.70611100E-01, 0.39114200E-02, -.39325900E-01, -.30507000E+00, 0.44557600E+00, -.66365100E-01, -.25720400E-03, -.12114600E+01, 0.78302600E-02, 0.95495500E-02, -.19042400E-02, 0.18059400E-01, -.94909500E-02, 0.19539800E-01, -.24010700E-01, 0.14678000E-01, -.11435700E+00, -.19131300E-01, -.85828200E-01, -.19493500E+00, -.24361100E-02, -.11523300E-01, -.49906200E-01, -.14386200E+00, -.12069400E+00, 0.17205300E-01, -.82766400E-02, -.28893400E-02, 0.31818000E-02, 0.64124900E+00, -.25910700E-01, -.99870200E-02, 0.28948400E+00, 0.58122700E-02, 0.43016700E-03, 0.11961600E-02, -.10555900E-01, 0.59310500E-01, 0.28240700E-02, -.15786000E-02, -.25815500E-01, 0.18599100E-01, -.58983100E-02, -.89512600E-02, -.48223600E-01, 0.26177000E+00, 0.11471200E-01, 0.59047200E-02, -.10223500E+00, 0.60787100E-01, 0.77394000E-02, 0.13111700E+00, 0.69596200E-01, -.17133800E-01, -.26898700E-01, 0.91506300E-02, 0.75559200E-01, 0.84478200E-01, -.18256200E-01, 0.41101700E+00, -.43254800E-02, -.71067800E+00, -.74497800E-01, 0.11443700E+00, 0.24403700E-01, 0.34375300E-01, -.11202900E-01, 0.10635900E+00, 0.10902300E-01, -.15050000E-01, -.20914600E+00, -.24531200E+01, -.12178800E+00, -.22419800E+01, 0.11228700E+01, 0.32155700E+00, 0.71793700E+00, -.10046600E+01, -.15565300E+01, 0.10221100E+01, 0.74124500E+00, -.16274200E+02, -.85907900E+00, 0.43590400E+01, 0.21372000E+01, 0.36968200E+01, -.59415500E+01, -.86155100E+00, 0.17958100E+01, -.47269300E-01, 0.22017000E-01, 0.13074200E+00, 0.58170100E-01, 0.16945500E+00, -.10167100E+00, 0.78815400E-01, 0.69611900E-02, -.47755300E+01, -.19515800E+01, 0.28062700E+01, 0.16799400E+01, 0.83469600E+00, -.18042400E+01, -.22732800E+01, 0.18823500E+01, 0.15575500E+01, 0.22554100E+01, -.23174700E+00, 0.87867000E+00, -.14517000E+01, 0.14055500E+01, 0.28089200E+00, 0.19858200E+01, 0.15271700E-02, -.23647500E+00, -.18157500E-01, -.29185400E+00, -.37893100E-01, 0.37509500E+00, -.25277900E+00, 0.21458900E-01, -.16132700E-01, -.21500200E+00, 0.15887600E-01, 0.11298700E-01, -.25712500E-01, -.39960100E+00, -.17557400E+00, 0.38640000E+00, -.56660400E+00, 0.23415100E+01, 0.46607800E-01, -.70282000E+00, 0.36405400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.49079900E+01, 0.15499800E+01, 0.14512900E+01, 0.96190500E+00, 0.16538600E+00, -.23354300E+00, 0.58645800E+00, -.12256500E+01, 0.75572800E-01, 0.14373500E+01, 0.12738000E+00, -.82210300E-01, 0.33137200E+01, 0.16536900E+00, 0.45413900E+01, 0.37804300E+00, 0.72422300E+00, -.11429700E+01, 0.65726700E+00, -.80802100E+01, -.77650200E+00, 0.15776800E+01, 0.26425000E+01, 0.59069800E+00, -.81569400E+00, -.45280400E+00, 0.11093600E+00, 0.16483100E+01, -.14554800E+01, -.22231500E-01, -.55292900E+00, -.10599800E+02, 0.79614400E+01, 0.74961300E+00, 0.14131200E+00, 0.39907900E+00, 0.12065400E+01, -.17819500E+00, 0.59151700E+00, -.15826600E+01, -.29125100E+01, 0.83686200E+00, -.23819400E+00, 0.81689800E+00, 0.47187100E-01, -.88986200E-01, -.67193100E-01, 0.86056900E+00, 0.34241200E+00, -.68319400E-01, -.54222600E+01, 0.13354500E+02, 0.19362900E+00, 0.23063400E-01, -.86390200E+01, -.65048500E-01, -.21300500E-01, -.52836500E-01, 0.36162100E+00, -.29213200E+00, -.47726700E-02, 0.56129000E+00, 0.32702200E+00, 0.32443400E+00, -.10140800E+01, -.78301200E-01, 0.13525900E+01, 0.65999800E+00, -.46311000E+00, -.94984700E+00, 0.57877000E+00, -.20632400E+00, -.10421000E+00, 0.81470600E-01, 0.35496200E+00, 0.31497500E+00, -.33595700E+00, 0.44476900E+00, -.25879900E+00, 0.65635000E+00, -.22841000E-01, -.13372200E-04, 0.37140200E-01, 0.62933700E-01, 0.27672600E-01, -.11967700E-01, 0.11501800E-01, -.22309500E-01, -.69636800E-01, 0.23368100E-01, 0.14571100E+00, 0.24519300E+00, 0.98151800E-02, -.42615000E-01, -.55498700E-01, -.78638500E-01, -.15395300E+00, -.93168400E-01, 0.13332600E+00, -.19268900E+00, 0.23419000E+00, -.85699300E-01, 0.29887300E+00, -.17670500E-01, -.27779000E+00, 0.90696300E+00, 0.45528200E+01, -.24554900E-01, -.13614500E+01, -.26783200E+00, 0.60240600E+00, -.40694800E+00, -.86989500E-01, -.80070600E+00, -.20895900E+00, 0.69792000E+00, 0.64165600E-01, 0.17195500E+01, -.22662300E+01, -.27473600E+01, 0.18755800E+02, 0.30809400E+01, 0.27761400E+01, 0.12594800E+01, -.18232500E+01, 0.19424200E+02, 0.73035100E+01, 0.39860700E+01, -.69184900E+02, 0.58382200E+02, 0.26518000E+01, 0.24831700E+01, 0.37014600E+02, -.54029000E+01, 0.33630600E+02, 0.51032800E+01, 0.12849500E+00, 0.12742000E+00, -.18147600E+00, -.72507000E-01, 0.55421100E+00, -.11111800E+01, -.46015300E+01, -.43450800E+00, -.51118500E+02, 0.17228200E+02, 0.45826500E+01, 0.40004400E+01, 0.26284900E+02, -.60835800E+01, 0.22548500E+02, 0.82621200E+01, -.90617100E+02, 0.12548800E+02, 0.41191500E+02, 0.52749700E+02, -.25018800E+02, -.41128500E+02, -.28292900E+02, 0.58580800E+02, -.13773200E+00, 0.85008500E+00, 0.21730200E+00, -.31035000E+01, 0.48625600E+00, -.14170400E+01, -.22960400E+01, 0.47739900E+00, 0.47658800E+00, -.13654600E+01, -.44947200E+00, 0.26448100E+00, 0.53128300E-01, 0.20062700E+00, 0.17303800E+01, 0.24216200E+01, 0.21878100E+01, 0.10871700E+02, 0.22249600E+00, -.53890400E+01, 0.14170700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.12622300E+02, -.53219400E+01, -.28843200E+01, -.28332300E+01, 0.21445500E+01, -.18939600E+01, 0.57154900E+01, -.58911900E+01, -.63598700E+00, -.15718300E+01, 0.18266700E+01, -.28855100E+01, 0.15509300E+01, 0.86046800E-01, 0.59312100E+00, -.18831000E+01, -.44784300E+00, -.42818800E+00, -.79324300E+00, 0.39582200E+02, 0.43663700E+01, -.13657400E+01, -.75159600E+01, -.74403800E+00, -.23991000E+01, -.24932400E-01, 0.79999400E+00, 0.22124200E+01, -.43193500E+01, 0.50951200E+00, 0.31870500E+00, 0.12794700E+02, 0.26579000E+00, -.48411800E+00, -.52014600E+00, 0.17408500E+01, 0.78354200E-02, -.96747300E+00, -.34119200E+01, 0.18271200E+01, 0.30811600E+01, -.98486700E+00, -.58092800E+00, -.24222200E+01, 0.94858500E-01, -.53658600E+00, 0.60914100E+01, 0.19627900E+01, 0.10366400E+01, -.22614600E+00, -.14415900E+02, -.58215700E+01, -.31430200E+01, -.15488900E+00, -.16717200E+02, -.22685500E+01, -.26863700E+00, 0.22346800E-01, -.19727400E+00, 0.71523200E+00, 0.64717900E+00, 0.10831800E+01, -.15210900E+00, -.16109500E+01, -.12907900E+00, 0.58351300E+00, -.13038500E+02, -.26105500E+01, 0.23455700E+01, -.28378800E+00, 0.74086200E+00, -.86115300E+00, 0.48239700E+00, -.16604200E+00, -.13215800E+01, -.15791400E+01, -.64124900E+00, 0.10557900E+01, 0.87426300E+00, 0.79052300E+01, 0.79777400E-01, 0.13800300E-01, -.84035800E-01, -.18701200E+00, -.15803000E+00, 0.50689300E-01, 0.11818900E+00, -.69457500E+00, 0.26139100E+00, -.50121200E-01, -.44409800E+00, -.65736500E+00, -.26380500E+00, 0.18320600E+00, 0.52525300E+00, -.24691100E+01, 0.33577600E+00, -.27411700E+00, 0.13810500E+01, 0.40437900E+00, -.32676600E+00, -.89161100E+00, 0.12225700E+01, 0.33126400E+01, 0.16126700E+01, 0.25270000E+01, -.41959900E+01, -.31638800E+01, 0.73574400E+00, 0.90485200E-02, -.42206000E+00, 0.32819800E+01, 0.10952800E+01, -.77535400E+00, 0.30875300E+01, 0.40411000E+00, 0.32945500E+00, 0.21356300E+00, -.16076900E+01, -.15634400E+01, 0.74526900E+02, -.24304700E+02, -.11911400E+02, -.57507900E+01, -.61230300E+01, 0.22311300E+02, -.15204700E+02, -.89096600E+01, -.27896300E+03, 0.42073800E+02, 0.15016000E+02, -.33644000E+02, 0.16496200E+03, -.54812100E+02, 0.59296300E+02, -.43329700E+02, -.75681000E-01, -.80009100E-01, -.47076000E+00, -.71683700E+00, 0.11748000E+01, 0.25938200E+01, 0.48591700E+01, -.28427300E+00, -.15342900E+03, -.86502400E-01, 0.23117700E+02, -.19637900E+02, 0.11059500E+03, -.42236300E+02, 0.18338300E+02, -.16902400E+02, -.17819000E+03, 0.97519500E+02, 0.71462800E+02, 0.10912900E+03, -.29941700E+01, -.91836200E+02, -.55404500E+02, 0.13730300E+03, -.47968700E+00, -.23644200E+01, -.46448000E+00, 0.17025200E+01, -.59050100E+01, 0.22219900E+01, 0.28189000E+01, -.55091200E+01, -.77584600E+00, -.31533900E+01, 0.91739600E+00, -.27737500E+00, -.33397700E+00, -.49578500E+01, -.11203400E+00, -.30203200E+01, -.14753900E+01, 0.64333000E+02, -.25056600E+01, -.41427200E+02, -.14550000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.50922600E+01, 0.18551200E+01, 0.76670500E+00, 0.18545900E+01, -.91294600E+00, 0.13561900E+00, 0.28738200E+01, -.15382400E+01, 0.44600600E+00, 0.13470400E+01, -.54873500E+00, 0.11060000E+01, 0.32963700E+01, 0.14378800E+00, 0.11037500E+01, 0.12666600E-01, -.16641600E+00, 0.12530600E+01, 0.16354700E+01, 0.33820200E+01, 0.20776600E+01, -.35762800E+00, -.33297200E+01, -.24262800E+00, -.14465900E-01, -.43443900E+00, 0.82288000E+00, 0.87610600E+00, -.11882900E+01, 0.12726900E+01, -.52265400E+00, 0.66808500E+00, 0.50809200E+01, 0.55793900E+00, -.74318400E-02, 0.27156300E+00, -.10251300E+00, -.36673400E+00, -.12239500E+01, 0.27737000E+00, 0.67653200E+00, 0.50811800E-01, -.17033300E+00, -.12216100E+01, -.96569800E+00, 0.11250700E+00, 0.16208900E+01, -.23775100E+00, -.45761500E+00, 0.40045800E+00, -.35815100E+00, -.81311400E+01, 0.94382600E+00, 0.16470900E+00, 0.68872900E+01, 0.24935900E-01, -.16066500E+00, -.34115300E-02, 0.10004200E+00, 0.18503600E+00, -.24587000E+00, 0.43340400E+00, -.29257900E+00, 0.98704000E+00, 0.20822700E+00, 0.39830700E+00, 0.33221300E+01, 0.57889800E+00, 0.11095300E+01, 0.99530100E+00, -.34173500E+00, 0.20429100E-01, -.50494800E-01, 0.49000300E-01, -.12828600E+00, 0.37139100E+00, -.21329100E+00, -.23647200E+00, -.61012600E+00, -.16534700E+01, -.16279800E-01, -.42448600E-02, 0.24811000E-01, 0.35552000E-01, 0.54811500E-01, -.13758700E-01, 0.16171400E-01, 0.13523100E+00, -.52225300E-01, 0.50843100E-02, 0.70889700E-01, 0.11771200E+00, 0.95753900E-01, -.50222100E-01, -.59606000E-01, 0.46112100E+00, 0.10524800E+00, -.25044700E-01, 0.98264500E-01, -.51619100E+00, -.37087200E+00, 0.31194600E+00, 0.11379400E+01, 0.67181000E+00, 0.14454500E+00, 0.11334400E+01, 0.31172700E+01, -.14753400E+01, 0.14854500E+01, 0.13980700E+00, -.25748400E+00, 0.30494400E+01, 0.15484000E+01, -.74052400E-01, -.76633900E+00, 0.14563500E+00, 0.11794600E+00, 0.20681900E+01, 0.14503700E+01, -.48322100E+00, -.17579300E+00, 0.31506600E+02, 0.18621700E+01, -.54680100E+01, 0.15233500E+01, -.49001400E+01, 0.54026800E+01, -.11100400E+02, -.16877900E+03, 0.11796200E+03, 0.88024800E+01, -.20531300E+02, 0.10086300E+03, -.32501200E+02, 0.51718500E+02, -.24428600E+02, 0.27779200E+00, -.65253200E-01, -.90953200E+00, -.61644800E+00, 0.30183500E+00, 0.30716500E+01, 0.22091200E+01, 0.98118100E-01, -.12052900E+03, 0.63507200E+02, 0.10943300E+02, -.13765400E+02, 0.70154800E+02, -.39792300E+02, 0.24256700E+02, -.15664000E+02, -.94446400E+02, -.80471200E+01, 0.32274500E+02, 0.55873300E+02, -.33197800E+02, -.57551100E+02, -.19892400E+02, 0.59430400E+02, -.17855900E+00, 0.41512600E+00, -.18946300E+00, 0.49843200E+00, -.24340800E+01, -.10363200E+01, 0.85826300E+00, -.28816700E+01, -.35187300E+00, -.34738200E+01, 0.62527000E+00, -.57491500E-01, -.18407600E+00, 0.37128900E+00, 0.84034900E+00, 0.13930500E+00, -.38013400E+01, 0.37197900E+02, -.17635100E+01, -.22383800E+02, 0.77872800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25047800E+01, -.12139500E+01, 0.13836700E+00, -.63722500E+00, 0.64951600E+00, -.69227600E+00, 0.34594600E+00, -.17781700E+00, -.65672700E+00, 0.50678900E+00, -.28286200E+00, -.16352100E+01, 0.42861000E+01, 0.32391000E+00, -.41304900E+00, -.52591700E+00, -.13106300E+00, -.36552500E+00, -.44691700E-01, 0.23922400E+01, 0.84938500E+00, 0.31792900E+00, -.12188000E+01, -.23694900E+00, 0.25521500E+00, -.11744100E+00, 0.56447400E+00, 0.19135100E+00, -.94733400E+00, -.22774900E+00, -.24526500E+00, -.13641500E+01, 0.17686400E+01, 0.55199100E-01, -.27528800E-02, -.47521300E+00, 0.54093500E+00, 0.48644400E+00, 0.16136800E+00, -.53707100E+00, -.46512600E+00, 0.10507300E+00, -.75916900E-01, -.62453400E+00, 0.90465500E-01, 0.31612400E-01, 0.14536400E+01, -.24342300E-01, -.13794300E+00, 0.18656600E+00, -.59848900E-01, -.45906400E+01, -.50799700E+00, -.22851400E-01, 0.28599900E+01, -.85318300E-01, -.39000300E-02, 0.25928100E-01, -.12462500E+00, 0.16494800E+00, 0.65807200E-02, 0.53590000E+00, -.43428100E-01, 0.22816400E+00, 0.16110500E+00, 0.30814700E+00, -.27689900E+00, 0.25928300E-01, 0.45744100E+00, -.51064700E-01, 0.12240400E+01, 0.67104500E+00, -.20888200E-01, 0.19200000E-01, -.10969800E+00, -.15983500E-01, -.80214600E-01, 0.32552500E+00, -.15879600E-01, 0.47460200E+00, -.80881900E-02, 0.43005600E-03, -.91878400E-02, 0.25893100E-01, 0.17253900E-01, -.13479900E-02, 0.54264100E-02, -.21939100E-01, -.20179000E-01, 0.94643400E-02, -.89459300E-02, 0.18266700E+00, -.11246300E+00, -.68361900E-02, -.60404400E-01, -.19538500E-01, -.27407700E+00, -.14286000E+00, -.11140500E+00, -.36776100E-01, -.41524800E-02, 0.93328700E-01, -.61773400E+00, -.58273300E+00, 0.12703500E+00, -.19519800E+01, -.21909900E+01, 0.42720500E+00, -.15183000E+00, -.97464900E-01, 0.97143500E-01, -.97110800E+00, -.13398400E+00, -.27886600E+00, -.20646600E+00, 0.29691200E+00, 0.76070000E-01, 0.93977500E+00, 0.49588700E+00, 0.12407700E+00, 0.18875400E-01, -.55609300E-01, 0.51113700E+01, -.26813800E+01, 0.46987100E+01, 0.23994500E+01, 0.50489800E+01, -.35458200E+01, -.28771000E+02, 0.51669400E+01, 0.33761900E+01, -.33049400E+01, 0.16327000E+02, -.36342500E+01, 0.15258400E+02, -.34474000E+01, -.71116600E-01, 0.49218200E-01, -.41037600E+00, 0.49829800E+00, -.18038100E+00, -.45606900E+00, -.29618700E+01, 0.58064600E+00, 0.15801600E+00, 0.49030900E+01, 0.27121300E-01, -.28651100E+01, 0.63656800E+01, 0.21170500E+01, 0.46935600E+01, -.27275700E+01, -.19109700E+02, 0.11176600E+02, -.35132800E+00, 0.17129100E+01, 0.33722300E+01, -.82611900E+01, 0.78206700E+00, -.16331000E+00, 0.77312400E-01, 0.33888100E+00, 0.10427600E+00, -.63110200E+00, 0.16191500E+00, -.12651100E+01, -.61524700E+00, 0.12079700E+00, 0.15596600E+00, -.16842800E+00, -.10110500E+00, 0.10315500E+00, 0.38313000E-01, 0.17435600E+01, 0.45511000E+00, 0.65873900E+00, 0.16868300E+01, 0.41845800E+01, 0.18917100E+00, -.18556800E+01, 0.11371600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43839900E+01, 0.11708300E+01, 0.13972900E+01, 0.70133200E+00, 0.89403100E+00, -.17491900E+00, -.46625400E+00, -.15797500E+01, 0.13058500E+01, 0.30883000E+01, 0.30630900E+00, -.20229800E+01, 0.81081300E+01, 0.51761000E+00, 0.64318100E+01, 0.10174600E+01, 0.13410100E+01, -.13305200E+01, 0.65242700E+00, -.13757000E+02, 0.28238900E+00, 0.37221700E+01, 0.54478400E+01, -.28628400E+00, -.10541500E+01, -.35146700E+00, 0.10760800E+00, -.55894900E+00, -.16262500E+01, 0.43200000E+00, 0.10492200E+01, -.86009600E+01, 0.19312400E+01, 0.44603300E-01, 0.93637300E-01, -.77626000E+00, -.28064900E+00, -.34796800E+00, -.17268000E+01, -.83446100E+00, -.18701800E+01, 0.50461600E+00, 0.52247100E+00, 0.76983500E+00, 0.86808200E+00, -.52229200E+00, -.20877600E+01, -.17540300E+01, -.13491500E+01, -.29874600E-02, -.90061800E+01, 0.86350700E+01, -.90603800E+00, 0.64768300E+00, 0.23474200E+01, 0.17645400E+01, 0.17677300E+00, -.13963300E-01, 0.63926600E+00, -.81757800E+00, -.54027300E+00, 0.16191300E+00, 0.25262900E+00, 0.53675900E+00, -.78998100E+00, 0.67138200E+00, 0.10869100E+01, 0.89217900E+00, -.11402100E+01, 0.81564600E+00, -.99004700E+00, -.41568700E+00, -.93878500E-01, -.17307800E-01, 0.59461300E+00, 0.78861500E+00, 0.23998300E+00, -.39992500E+00, 0.64477500E+00, 0.26360300E+01, 0.15279300E-02, -.73284600E-04, -.39326000E-01, 0.31625100E-01, 0.21571300E-01, 0.44247800E-02, 0.99292600E-02, -.17747700E+00, 0.10734800E-01, -.51757400E-02, -.10568600E+00, 0.20815100E+00, -.35668800E-01, 0.13217400E-01, 0.41387700E-01, -.54112500E+00, -.17824900E+00, 0.33725500E+00, 0.92853500E-01, 0.80370700E+00, -.11150500E+00, 0.19108200E+00, -.14317000E+00, -.49484000E+00, 0.83252800E+00, -.48333500E+00, 0.22010900E+00, 0.27569300E-01, -.50839000E+01, -.90937500E+00, 0.10494500E+01, -.85333300E-01, 0.21877100E+00, -.85321500E+00, -.39038400E+00, -.59713800E+00, -.19027300E+00, -.94391400E-01, 0.12423200E+01, 0.34491000E+00, 0.12263100E+00, -.69701400E+00, 0.14792900E+01, 0.12706200E+02, -.13407800E+02, 0.28461000E+01, -.11542000E+02, 0.15270400E+02, 0.75668600E+02, 0.49827900E+01, -.87349700E+01, 0.18060100E+02, -.50604200E+02, 0.18429300E+02, -.35355900E+02, 0.20541300E+02, 0.26526400E+00, -.87415500E-01, 0.70944600E+00, -.15339100E+01, -.20147700E+00, -.14724300E+00, 0.28767300E+01, -.16443000E+01, -.26157700E+02, 0.41029600E+02, -.66749900E+01, 0.10539400E+02, -.16016600E+02, -.11172000E+02, -.51389100E+01, 0.10306600E+02, 0.54208100E+02, -.32383500E+02, 0.47204600E+01, -.12677000E+01, -.19189000E+02, 0.27856700E+02, -.86762100E+00, -.53889600E+00, -.11669900E+00, 0.17423600E+01, 0.71794300E-01, -.77885200E+00, 0.15906700E+01, -.10976200E+00, -.41276800E+00, 0.14993200E+01, 0.22004700E+00, -.11672200E+01, -.42011300E+00, -.93382100E-01, 0.13927000E+00, -.16234800E+01, 0.11271500E+01, -.24111200E+00, 0.46458100E+00, -.19591300E+02, 0.11522100E+00, 0.92606300E+01, -.97728200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.46684900E+01, 0.14014300E+01, 0.73879000E+00, 0.15782000E+01, -.16809300E+00, 0.31060600E+00, 0.11104700E+01, -.74400500E+00, -.81374300E-01, 0.29534300E+00, -.27869100E+00, 0.69595500E+00, 0.44795700E+00, -.37364700E-01, -.32535000E+00, 0.29272300E+00, -.69747600E-01, -.50728100E-01, 0.82419700E+00, -.62053600E+01, 0.48807900E+00, 0.79269700E-02, -.49786300E+00, -.80626200E-01, -.40079600E-02, -.84746700E-01, 0.30748800E+00, 0.30985200E+00, -.41961700E-01, 0.75372600E+00, 0.92479300E-01, 0.17038400E+01, 0.17343400E+00, 0.81730900E-01, -.12780300E-01, -.11224900E+00, -.47523100E+00, -.20389900E+00, -.34769800E+00, 0.66817900E+00, 0.50151800E+00, -.34872300E+00, 0.12105000E-01, 0.25389100E+00, 0.80565000E-01, -.25114500E+00, -.15926800E+00, -.28472400E+00, -.33111300E+00, -.48215000E-01, 0.15393200E+01, -.37161400E+01, 0.24079100E-01, 0.59260000E-01, 0.63665300E+01, 0.64363400E+00, 0.91776600E-01, 0.18572900E-01, 0.22817700E-01, -.15239000E+00, -.20797200E+00, 0.96201800E-01, -.61346800E-01, 0.28362900E+00, 0.14147500E+00, -.70526700E-01, 0.11105700E+01, 0.28305700E+00, -.13454800E+00, 0.95391300E-01, 0.12444000E+01, 0.18905200E+00, -.16725300E-01, 0.19218700E-02, 0.85854400E-01, 0.13974700E+00, 0.13035200E-01, 0.59887000E+00, 0.27403400E+00, 0.13399800E+01, 0.69500400E-03, 0.33824300E-02, -.38547300E-01, 0.44235000E-01, -.11132300E-01, 0.52233000E-02, -.28603200E-01, -.69915500E-01, 0.86443500E-02, 0.97584500E-02, -.75207600E-01, 0.30225900E+00, -.20504200E+00, 0.16578900E-01, -.13377300E+00, -.13802000E+00, -.40807700E+00, -.12763100E+00, 0.21457600E+00, 0.69058100E+00, 0.32558800E-01, -.22435700E+00, -.57963800E+00, 0.89769200E-01, 0.42809800E+00, -.17135400E+01, 0.39399200E-01, -.59759400E+00, -.21570800E+00, -.27882000E+00, 0.20233300E+00, 0.14909200E+00, 0.16416900E+00, -.36100300E+00, -.30005700E+00, -.54663400E+00, -.20993800E+00, 0.42663900E+00, -.82485000E+00, 0.31710100E+00, 0.18324500E+00, -.26751500E+00, -.55745600E+00, 0.38822700E-01, -.76455700E+01, 0.79029200E+01, -.34698900E+01, -.83154900E-01, -.85317200E+01, 0.11828200E+02, -.97907700E+01, -.39969900E+01, 0.19860500E+01, 0.42832900E+01, 0.37862100E+01, -.48352100E+01, 0.62660200E-01, -.55677000E-01, -.23248900E+00, -.19250300E+00, -.14380000E+00, -.29827900E+00, -.14525200E-01, 0.71171800E-01, 0.48404200E+01, 0.11020700E+02, -.83414700E+01, -.38810400E+01, 0.41418200E+01, 0.57892900E+01, -.33746400E+00, -.46851700E+01, 0.47812900E+02, -.21402700E+02, -.13373200E+02, -.17695600E+02, 0.62561700E+01, 0.27789200E+02, 0.21019400E+02, -.20596700E+02, -.52783000E-01, 0.98340700E-01, 0.81650200E-01, -.11946500E+01, 0.43213500E+00, -.10245800E+01, -.12181800E+01, 0.46830800E-01, 0.15337200E+00, 0.25855900E+01, -.21647500E+00, 0.24855800E-01, 0.69973600E-01, 0.67350400E+00, 0.76863800E-01, -.16395600E+00, -.17984600E+01, -.48776400E+01, 0.45263700E+00, -.16844800E+01, -.16594500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.61667300E+01, 0.19761600E+01, 0.63608700E+00, 0.39781100E+01, -.88726100E+00, 0.11024200E+01, 0.37633200E+01, -.33300900E+01, -.81653800E+00, -.19055600E+00, 0.11437400E+00, 0.23427200E+01, -.23658700E+01, -.21444000E+00, -.19329800E+00, -.11911900E+01, -.39934400E+00, 0.77581900E+00, 0.98782800E+00, -.81074800E+01, 0.98114500E+00, 0.13357900E+01, -.36966600E+01, -.30993500E+00, -.92238600E+00, -.34384000E+00, 0.45815700E+00, 0.62962200E-01, -.81136400E+00, -.23864100E-01, -.23121700E+00, -.26139200E+01, 0.47633700E+01, 0.54081400E+00, -.34173300E-01, 0.22291500E+00, 0.27901900E+00, -.99778500E+00, -.16348800E+01, -.22131100E+00, -.59426700E+00, 0.43414800E-01, 0.22760900E+00, 0.61563800E+00, 0.10023900E+00, -.27302400E+00, 0.47562000E+00, 0.16380600E+00, -.81550400E-01, -.23467400E+00, -.42372500E+01, -.27388100E+01, -.40650900E+00, 0.15399400E+00, 0.28985100E+01, -.68564500E+00, -.13365200E+00, -.22758500E-01, -.97026800E-01, 0.63208200E-01, 0.12083200E-01, 0.66665500E+00, -.12600100E+00, 0.22298200E+00, -.68609400E+00, 0.46229700E+00, -.63030900E+00, -.25951700E+00, -.62467300E+00, 0.40067500E+00, -.23220500E+00, 0.19256400E+00, 0.20933100E-02, -.68565300E-02, -.85038400E-01, 0.39362800E+00, -.23861400E+00, -.29060900E+00, -.31590500E+00, -.46914900E-01, 0.26780800E-02, -.53164600E-02, -.59652400E-02, 0.40846300E-02, 0.37529300E-02, -.12993300E-02, 0.13601400E-01, 0.42591700E-03, 0.80495800E-02, -.15249100E-01, -.64076300E-01, -.21179400E-01, 0.83599200E-01, -.97006500E-03, 0.51185600E-01, -.17821300E-01, 0.32251000E+00, -.13466100E+00, 0.12017800E+00, 0.96678300E-01, -.97009400E-01, -.36238400E+00, -.56268800E+00, -.16779600E+01, -.15611700E+00, 0.11258100E+01, -.11866700E+02, -.10279300E+00, 0.41100300E+00, 0.31463200E-01, -.18184300E+00, 0.30355000E+01, 0.15738100E+01, -.54721000E-01, -.97609400E-01, -.14356900E+01, -.24128100E+00, -.36230100E+01, 0.10417100E+01, -.49056300E+00, -.29133600E+00, 0.62195200E+00, -.71552600E+00, -.37794500E-01, -.11293600E+01, 0.20282800E+02, -.41582500E+01, 0.29392500E+01, -.89870300E+02, -.69111000E+02, 0.11912400E+02, -.38832500E+01, 0.27123700E+02, -.19623100E+02, 0.91463800E+01, -.10433100E+02, -.31521100E+00, 0.21274000E-03, 0.47787000E+00, -.60328300E-03, -.32276200E-01, -.18922900E+01, -.14995000E+01, -.33484000E+00, -.35441200E+02, -.10382600E+02, 0.59504500E+01, -.15470600E+02, 0.28650500E+02, -.27144800E+01, -.41625700E+00, -.22775200E+02, 0.11564900E+02, 0.21986200E+02, -.49692500E+01, -.81370100E+01, 0.37287900E+01, 0.20450200E+02, 0.64003700E+01, -.10431600E+02, -.38410200E-01, -.22526100E+01, 0.11989700E+00, -.27438100E+00, -.16941600E+01, 0.25178500E+01, 0.24064000E+00, -.14776900E+01, 0.24014700E+00, 0.25725900E+01, -.43629100E+00, 0.37236900E-02, 0.12742100E+00, -.34264700E+01, -.13822500E+01, -.35575200E+00, 0.19440800E+01, 0.10852000E+02, 0.10741800E+01, -.17786900E+02, -.29399700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20118200E+01, -.32203900E+00, -.53974500E+00, -.78791400E+00, 0.38199900E+00, -.76367600E+00, 0.12099100E+01, -.73487200E+00, -.12369100E-01, 0.21864200E+00, -.17890400E+00, 0.14035000E-01, 0.97204800E+00, 0.56914800E-01, 0.62035300E+00, -.22079200E+00, 0.25529900E-01, 0.37072200E+00, 0.22986400E+00, 0.14878800E+01, 0.43129100E+00, -.20378700E+00, -.13895300E+01, -.67335800E-01, -.10032100E+00, -.12130200E+00, 0.14525600E+00, 0.47249300E-02, -.21443100E+00, -.35408800E-01, -.11679700E+00, 0.18774900E+01, 0.16653900E+01, 0.16865900E+00, 0.91007700E-02, 0.82796200E-01, 0.24643800E+00, 0.60804100E-01, -.19954900E+00, -.68646700E-02, -.44903700E+00, 0.63594200E-01, -.10837900E+00, -.36696200E-01, -.17627100E+00, 0.13677100E+00, 0.12148800E+01, 0.65588800E+00, 0.54605500E+00, 0.45676900E+00, -.30228700E+01, 0.16027000E+00, -.46452000E+00, 0.21688500E+00, 0.17621400E+00, 0.15965100E+00, 0.13944700E-01, -.54891700E-02, 0.78275000E-01, -.33996700E-01, -.62493000E-01, -.11727700E+00, -.11058900E-01, -.10301100E+00, -.11899700E+00, -.49807600E-01, 0.51211500E+00, 0.24534100E+00, 0.27009800E-01, 0.29557000E+00, -.55470800E+00, -.22525200E+00, -.17232700E-01, 0.88497100E-02, 0.28731600E-01, 0.22652800E+00, -.12302600E+00, -.20876000E+00, -.10868000E+00, 0.18027100E+00, -.13378100E-02, -.22028600E-02, 0.11324400E-01, -.37537700E-02, 0.31323200E-02, -.40621300E-02, 0.70723100E-02, -.20904900E-01, -.34343600E-02, -.70991700E-02, 0.22018400E-01, -.14101700E-01, -.64518800E-03, -.12795500E-01, 0.24334400E-03, -.75641300E-01, 0.21569800E+00, 0.80120300E-01, 0.13172400E+00, 0.30066900E+00, -.91969700E-01, 0.16457900E+00, 0.15948200E+00, -.42418900E-01, 0.12559200E+00, 0.48181700E+00, 0.46520800E+00, -.11232200E+00, 0.89851800E+00, 0.98051200E-01, -.15601600E+00, 0.82632000E+00, 0.32790900E+00, 0.25189300E-01, 0.31963900E+00, 0.61762900E-02, 0.48697200E-02, 0.26836200E+00, -.14938100E+01, -.32005900E+00, 0.10703800E+00, -.56066000E-01, 0.25059700E+00, -.30005600E-01, 0.11171400E-01, 0.21421800E+00, 0.76850400E+01, 0.19062100E+00, 0.14838100E+02, 0.34254100E+02, -.25544700E+00, 0.58014000E+01, -.50648300E+01, 0.54984000E+01, 0.55809300E+01, 0.84030700E+01, 0.22045600E+00, -.32591900E-01, -.20332400E-01, 0.20404700E-01, 0.45219400E+00, 0.49911000E-01, -.12526000E+01, -.18843300E+00, -.10698800E+02, 0.12030800E+02, 0.13263500E+01, 0.82628800E+01, -.38901500E+01, -.26594100E+01, 0.86251200E+01, 0.11411200E+02, -.16366500E+02, -.60268900E+01, 0.11114600E+02, 0.13231500E+02, -.13122900E+02, -.11105800E+02, -.72075900E+01, 0.15424400E+02, -.13750700E+00, 0.60553200E+00, 0.32656800E-01, -.10557700E+01, 0.62191800E+00, -.61602400E+00, -.89090200E+00, 0.56742700E+00, 0.10755300E+00, -.10196200E+01, -.43012100E-01, 0.13130200E+00, -.48261700E-01, 0.60251700E+00, 0.62509900E+00, 0.10217800E+01, -.21385000E+00, -.18057800E+01, -.57996600E-01, 0.46874900E+01, 0.32536300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18162300E+01, 0.21911100E+00, 0.40213600E+00, 0.95212600E+00, 0.55372100E-01, 0.82556200E+00, -.72837700E+00, 0.12729500E+01, -.34594000E+00, -.13064700E+01, 0.52229100E+00, -.67587900E+00, -.20585600E+01, -.10332100E+00, -.37312000E+01, -.86597600E-01, -.68520800E+00, -.12395700E-01, -.54398900E+00, -.77528300E+00, 0.62734800E+00, -.23066100E+00, 0.11828900E+01, 0.21267500E+00, 0.27579900E+00, -.37375000E-01, -.68223500E-01, 0.26117900E+00, 0.64321500E+00, -.43604300E-01, -.12383200E+00, 0.34448900E+01, -.10652200E+01, -.21652300E+00, 0.41326600E-03, -.11618800E+00, -.27207400E+00, 0.81590400E-01, -.22281500E+00, 0.27641000E+00, -.75660500E-01, 0.29456700E-01, 0.12449600E-01, 0.41226400E-01, -.92381900E-01, -.90844800E-01, 0.91774100E+00, 0.10215400E+00, -.18708300E+00, 0.22747000E+00, -.37184800E+01, -.45101200E-01, -.33158200E+00, 0.15129700E+00, 0.77216700E+00, -.15173600E-02, 0.35750100E-01, 0.74169700E-03, 0.88182900E-01, -.36654500E-01, -.83080300E-01, 0.15499100E+00, -.28532600E-02, -.60946700E-01, -.47536600E+00, -.57123100E-01, -.31834300E+00, 0.26908900E+00, 0.77519400E-01, 0.31141200E-01, -.21459700E+00, -.12661000E+00, 0.60233800E-01, -.25775600E-01, -.15912500E+00, -.81605200E-01, -.73744400E-02, -.40959100E-01, 0.22488000E+00, 0.87370200E+00, 0.12572800E-01, -.11520000E-02, -.12154300E-01, -.24179800E-01, -.96400300E-02, 0.46999000E-02, 0.45631800E-01, -.80640900E-01, 0.42325700E-01, -.17411700E-01, -.72949400E-01, -.90414000E-01, 0.39725300E-01, 0.19241900E-01, 0.19640500E+00, -.28220600E+00, 0.10984000E+00, 0.38748100E-01, 0.33255000E+00, 0.10554400E+00, 0.19181800E-01, 0.17485200E+00, 0.13487400E+00, -.19007800E+00, 0.11002100E+00, 0.13467400E+01, -.21061000E+01, -.25979300E+00, 0.53525100E+00, -.53211200E-01, -.16849900E+00, 0.63628600E+00, 0.37216300E+00, 0.21944000E+00, 0.32532500E+00, -.51809200E-01, 0.67140700E-01, -.12426500E-01, -.14464500E+01, -.25186200E+00, 0.10748300E+00, -.54235300E-01, 0.57106300E-01, -.51901200E-01, 0.30113000E-01, 0.11099000E+00, 0.40831000E+00, -.13584300E+01, 0.18135900E+02, 0.66089200E-01, -.49454100E+01, -.43946400E+01, 0.76862900E-01, 0.89664300E+01, 0.33433400E+00, -.40593000E+01, 0.32916100E-01, -.25209500E-02, -.14110100E+00, -.14639100E+00, 0.21417700E+00, 0.70965600E-01, -.10537900E+00, -.78607500E-01, 0.16163000E+02, 0.42277100E+01, -.24523300E+01, -.27490300E+01, -.32463000E+01, 0.66985800E+01, 0.75508800E-01, -.30630800E+01, 0.19473800E+01, -.88024800E+01, 0.33117600E+01, 0.11914600E+01, -.63743700E+01, 0.18472200E+00, 0.12075700E+01, 0.45539500E-02, -.30918700E-01, 0.65132100E+00, 0.20088400E-02, -.66341600E-01, -.18946300E-01, -.80376500E+00, -.89213400E-01, 0.14426600E+00, 0.27931600E-01, 0.52796900E+00, -.74498200E-02, 0.24949700E-01, -.17645200E-01, 0.68737200E+00, 0.60526800E+00, -.22870900E-01, -.84912100E-01, 0.54031600E+00, 0.11224700E-01, 0.31823200E+00, 0.23593200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16874300E+01, -.71356300E+00, -.65760400E+00, -.55514200E+00, -.76856200E-01, 0.13906400E-01, -.61875800E-01, 0.16249600E+00, -.15845200E-01, -.58887400E+00, 0.15242000E-01, -.19666200E+00, -.11396100E+01, -.68424800E-01, -.11286300E+01, 0.16715500E+00, -.10794000E+00, -.22803300E+00, -.49627800E+00, 0.59944500E-01, -.39913700E+00, -.32776700E+00, -.19683100E+00, 0.10988400E+00, 0.50773900E-01, -.17786800E-01, 0.64565300E-01, -.11415700E+00, 0.15415700E+00, -.16978700E-01, 0.25652400E-01, -.47339700E+00, -.44106900E-01, 0.17255000E-01, -.64932900E-02, -.25173300E-01, 0.19061600E+00, 0.23218600E+00, 0.55891100E+00, 0.56957700E-02, 0.12315900E+00, 0.25911900E-01, 0.90877800E-01, 0.14021400E+00, 0.48511600E-01, 0.11351900E+00, -.29718100E+00, 0.54167300E-04, 0.88299000E-01, -.10179000E+00, 0.80009000E+00, -.11357200E+00, -.80994600E-01, -.12080100E+00, -.65733500E+00, -.86578600E-01, 0.22329200E-01, 0.20756300E-02, -.53901000E-01, 0.14424400E-01, 0.54671800E-01, -.45442700E-01, 0.20353600E-01, -.16597600E+00, -.59516500E-01, -.10886600E+00, 0.13558000E+00, -.27476500E-01, -.11898000E+00, -.13530300E+00, -.33935900E+00, -.13791400E+00, 0.15174900E-01, 0.70248900E+00, -.20253400E+00, -.15880200E+00, 0.86651000E-01, -.28733400E+00, -.10793100E+00, -.12967200E+01, 0.45045700E-02, 0.79099200E-01, -.50225100E-03, -.32461000E-01, -.84271500E-02, 0.40122300E-03, -.25339900E-01, 0.81747000E-01, 0.10755000E-01, 0.28837400E+00, -.26076300E-01, -.17070600E+00, 0.23599400E-01, 0.19219900E-02, -.43699600E-01, 0.27164800E+00, 0.21000900E+00, 0.42590300E-01, -.12270900E+00, -.16006100E+00, -.11082900E+00, 0.40269300E-01, 0.11846400E-01, -.46595100E+00, -.15911300E+00, -.66591700E+00, -.29942600E+00, 0.42704300E+00, -.60768600E+00, 0.81129800E-01, -.19760600E+00, -.30494700E+00, -.20346400E+00, 0.17250900E+00, 0.45681200E-01, 0.60794900E-01, -.18103600E-01, -.11102800E+00, -.10992500E+01, -.94780300E-01, -.62951800E-02, 0.74248800E-01, -.17322700E+00, -.19267600E+00, 0.66044000E-01, 0.82095800E-01, 0.17413700E+00, 0.40163000E+00, 0.37845800E+02, -.11296600E+02, 0.20880200E+01, 0.49921300E+01, -.19226500E+02, 0.63296500E+01, -.12863800E+02, 0.61224400E+01, 0.30115500E-01, 0.22258200E+01, 0.50982200E+00, 0.47035200E-01, -.30093800E-01, -.74183100E+00, 0.42462200E+00, 0.17114300E-01, 0.40793100E+01, -.70293100E+00, 0.14588200E+01, 0.70094700E+01, -.11286900E+02, -.14098500E+01, -.66661200E+01, 0.75363400E+01, -.74577600E+01, -.40801100E+01, -.24937200E+01, -.29376700E+01, 0.86784800E+01, 0.18027400E+01, 0.27729600E+01, -.25057700E+01, 0.20529500E+00, 0.46047900E+00, 0.10169100E+00, 0.35097000E+00, 0.44837000E+00, 0.16650500E+00, 0.31601000E+00, 0.49460400E+00, 0.25691800E+00, -.22937700E+01, -.52680500E+00, -.28780800E-01, 0.12663200E+00, -.85386200E-01, 0.34463600E+00, -.40832700E-01, 0.30249700E+00, -.54362900E+01, 0.11552600E+01, 0.63657800E+01, -.16325000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20800100E+01, 0.41113400E+00, 0.56450900E+00, 0.80580000E+00, -.68370000E+00, 0.57236200E+00, -.92853400E+00, -.10432000E+00, 0.20217700E+00, 0.13109700E+01, -.36863700E+00, -.28745200E+00, 0.28982300E+01, 0.20914400E+00, 0.21428000E+01, -.97180900E-02, 0.52430800E+00, -.63002900E-01, 0.78687900E+00, -.75683800E+01, -.83022000E-02, 0.11220600E+01, 0.12270700E+01, -.30861100E+00, 0.31223700E+00, -.38659200E-01, 0.12285400E-01, -.84902200E+00, -.20531700E+00, 0.60530600E+00, 0.61066200E+00, -.19552600E+01, -.51594400E+00, 0.94978700E-01, 0.44458200E-02, -.20823600E+00, -.50069600E+00, -.33560700E+00, -.89257100E+00, 0.49025300E+00, -.62291700E-01, -.34560500E-01, 0.35811500E+00, 0.46460100E+00, -.30962800E+00, -.19183500E+00, -.22025400E+01, -.94036700E+00, -.28989500E+00, -.69477300E+00, 0.26818500E+00, -.41142300E+01, 0.34229100E-01, 0.87535000E-01, 0.37801800E+01, 0.21640200E+00, -.89724000E-02, -.25092500E-03, -.33257500E-03, -.49536300E-01, -.10389300E+00, -.77096600E-01, -.89847500E-01, 0.12582100E+00, -.37988900E+00, 0.19742100E-02, 0.17071400E+00, 0.50529000E+00, 0.84959700E-01, 0.12196300E+00, -.34966600E+00, -.60137200E-01, 0.84689200E-02, -.16534200E-01, 0.10315700E+00, -.66326800E-01, 0.21473300E+00, -.16821700E+00, 0.29127800E+00, 0.80681900E+00, 0.65714900E-02, -.14422000E-02, -.81747300E-02, -.20202800E-01, 0.78005900E-02, 0.30407100E-02, 0.21442100E-01, -.75324400E-01, 0.20792600E-01, -.77144400E-02, -.15618400E-01, -.89967900E-01, 0.93519000E-01, 0.12889200E-01, 0.13168200E+00, -.28233000E+00, 0.30604800E-01, 0.10046600E+00, 0.40747800E-01, 0.69729300E-01, 0.18345500E+00, 0.34119700E-01, -.30757500E+00, -.11781800E+00, -.10271800E+00, 0.14879000E+01, -.25020800E+01, 0.68854900E+00, 0.12553300E+01, 0.25298200E+00, -.43534900E+00, -.32531500E+00, -.31868500E+00, 0.35460500E+00, 0.89592600E+00, -.18001900E+00, 0.68069600E-02, -.48206200E+00, -.17608500E+01, 0.11436200E+00, -.24996500E-01, -.36329100E+00, -.21900100E+00, -.13922700E+00, -.14491800E-01, 0.12838000E+00, -.20547300E+00, -.11229900E+00, -.22720200E+00, 0.24683600E+02, 0.42342300E+00, -.37186700E+01, 0.14323500E+02, 0.93273200E+01, 0.72839700E+01, -.13773000E+01, 0.15345500E+00, 0.45010900E+00, -.26360100E-01, -.32775800E+00, 0.57635300E+00, 0.49802800E+00, 0.90644100E+00, -.37222200E+00, 0.16278200E+01, 0.16488900E+02, 0.87837600E+00, 0.13713200E+01, 0.22337700E+01, 0.21223900E+01, 0.22902400E+01, 0.40514800E+01, -.13319200E+02, -.63839000E+01, 0.12916500E+02, 0.17157900E+02, -.21580000E+02, -.10051400E+02, -.57800400E+01, 0.18214200E+02, -.98254000E-01, 0.70922300E+00, -.53537600E-01, -.79739700E+00, -.42719400E+00, -.76753900E+00, -.25204700E+00, -.25043400E+00, -.35084400E-01, -.85351000E+00, 0.38057100E-01, 0.13269000E-03, -.61788500E-01, 0.17567700E+00, 0.49698500E+00, 0.30921900E-01, 0.64464200E-01, 0.83134400E+01, -.17540000E+00, -.18548900E+00, 0.53727300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17224400E+02, 0.62277600E+01, 0.11357100E+01, 0.82828100E+01, -.24569100E+01, 0.55477800E+01, -.26627000E+01, 0.47277800E+01, -.17527900E+01, -.42443500E+01, -.76396700E+00, 0.11889100E+02, -.24648700E+02, -.18788900E+01, -.99719800E+01, -.17453900E+00, -.26164600E+01, 0.28842900E+01, 0.17517400E+01, -.26469900E+02, -.39748200E+00, 0.67524700E+00, -.69060100E+01, 0.50182400E+00, 0.20466600E+00, -.20847900E+00, -.80998900E+00, -.13044700E+01, 0.29281900E+01, -.34674000E+01, -.49758800E+01, -.36617800E+02, 0.18553400E+02, 0.15369900E+01, -.96705200E-01, 0.28987700E+01, 0.30938500E+01, -.29057900E+01, 0.15095300E+01, -.37107400E+01, -.22473300E+01, 0.12015500E+01, 0.24991700E+00, 0.17358600E+01, 0.47033300E+01, 0.11834600E+00, -.10207700E+01, -.99682300E+00, -.90650100E+00, -.25496100E+01, -.17514000E+02, -.17181000E+02, -.28669900E+01, -.63057300E+00, -.87709300E+01, -.37286800E+01, -.51481300E+00, 0.15420700E-02, -.41362500E+00, 0.12379300E+01, 0.60876300E+00, 0.55815300E+00, -.64181000E+00, -.12734200E+01, 0.82921700E+00, -.37656600E+00, -.82124500E+01, 0.28039600E+00, 0.94947700E-01, 0.41152700E+00, -.59650200E+00, 0.23180800E+01, 0.40329700E-01, -.23592200E-01, -.46832600E+00, 0.17552900E+01, -.25258500E+01, -.18080200E+01, -.16228700E+01, 0.34268900E+01, 0.44536400E-02, 0.11357700E-01, -.40430900E-01, 0.27965100E-01, -.23698400E+00, -.17419000E-02, -.15032200E+00, -.27522600E+00, 0.30674600E-01, 0.71628300E-02, -.42956800E+00, 0.45456000E-01, -.10208300E+01, -.49913400E-02, -.69836900E+00, -.10059800E+01, 0.10139200E+01, -.56354400E-01, -.25079100E+00, 0.37012200E+00, -.11578300E+01, -.14911500E+00, 0.63948700E+00, -.40770200E+01, 0.99508900E+00, 0.83631400E+00, -.34427100E+02, 0.26556900E+01, -.58098300E+01, 0.71740500E-01, -.10308600E+01, 0.20970900E+01, 0.33155500E+01, -.27530400E+00, 0.60238100E+00, -.56059500E+00, 0.48233000E-01, 0.68995800E-01, -.57740800E+01, -.95536500E+00, -.37002600E+00, 0.26561100E+00, -.82766200E+00, -.87610200E+00, -.16714400E+00, 0.68172500E+00, 0.18866400E+01, 0.75989300E+00, -.85745400E+01, -.76796700E+01, 0.84773200E+02, 0.50149700E+02, 0.31670000E+02, 0.25042700E+02, -.35410800E+02, 0.64321600E+02, 0.86281300E+00, 0.22394500E+02, 0.50645100E+01, -.27488700E+01, 0.49929900E+01, -.23235700E+01, 0.12939900E+02, -.42281000E+01, -.20943000E+03, 0.12952900E+03, 0.46271900E+02, 0.67012300E+02, 0.22772300E+02, -.84961700E+02, -.39458300E+02, 0.84059900E+02, -.18455400E+03, -.92156900E+01, 0.89534900E+02, 0.13855800E+03, -.11089000E+03, -.76866200E+02, -.37708700E+02, 0.16452300E+03, 0.71124200E+00, 0.54866400E+01, 0.23471900E+00, -.14382800E+01, -.89262300E+01, 0.18640200E+01, 0.39040400E+01, -.65968300E+01, 0.16181100E+01, -.24900500E+02, -.38758400E+01, -.37890400E+00, 0.43904300E+00, -.70429500E+01, 0.47135300E+01, -.84502900E+00, 0.21398300E+01, 0.53040300E+02, 0.78929900E+01, 0.12883600E+02, 0.25057800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.32734800E+01, -.42766100E+00, -.72996200E+00, 0.21135600E+01, 0.29349300E-01, 0.97989300E+00, 0.27284700E+01, -.26098600E+01, 0.12317300E+01, 0.78512900E+00, 0.12976300E+01, 0.33809400E-02, 0.14935500E+01, 0.63319500E-01, 0.49529100E+01, -.20389500E+00, 0.97657100E+00, -.47658600E+00, 0.53407200E+00, -.45305600E+01, 0.22788500E+00, -.17633400E+00, -.21557000E+01, 0.27930400E+00, -.23222100E+00, -.16538800E+00, 0.36803400E+00, 0.15507200E+01, -.17876700E+01, -.41747700E+00, -.43082100E-01, -.36814600E+01, 0.27882100E+01, 0.26142200E+00, -.22744300E+00, 0.79765400E+00, -.20748800E+00, -.64057500E+00, -.10915300E+01, 0.77388900E+00, 0.50191000E+00, -.39419300E+00, -.80450600E-01, -.62942100E+00, -.98453500E+00, -.50092300E-01, 0.33257500E+01, 0.12793000E+01, 0.10267200E+01, -.12252800E+00, -.61660200E+00, -.83602200E+01, 0.75170500E+00, 0.50895300E+00, -.44988700E+01, 0.24514800E+00, -.27307600E+00, -.61436400E-01, 0.23097500E+00, 0.10432300E+00, -.20788000E-01, -.72228800E-01, -.28555400E+00, 0.30836100E+00, 0.36438900E+00, -.11792500E+00, 0.74474900E+00, -.13439000E+00, 0.21517900E+00, 0.10491700E+00, -.17768200E+01, -.79803000E+00, -.98148400E-01, 0.21397300E-01, 0.23477700E+00, 0.39165700E+00, -.25213900E-01, -.63391300E+00, -.65846700E+00, -.17616700E+01, -.13159200E-01, -.15011100E-02, 0.83719100E-03, -.12673800E-02, 0.59042500E-02, -.11547400E-01, -.11486100E+00, 0.12599000E+00, -.49619200E-01, 0.19702200E-01, 0.28077400E-01, -.65605500E-01, -.69718800E-02, -.40305000E-01, -.39187200E+00, 0.39618000E+00, 0.26133200E+00, 0.58639100E-03, -.19712000E+00, 0.34125000E+00, 0.36060600E-02, -.40842200E+00, -.29285600E+00, 0.45222800E+00, -.51614000E+00, -.43282700E-01, -.11497800E+01, 0.13847200E+01, 0.12003100E+01, 0.73077700E+00, -.54070500E+00, -.58700500E+00, -.77841400E+00, 0.10519100E+00, 0.72914000E+00, -.17416300E+00, 0.35543600E-02, -.82803000E+00, -.38506600E+00, -.49656900E+00, -.10347700E+00, -.82225200E-01, -.83572300E+00, -.59276600E+00, -.54850200E+00, 0.52087100E+00, 0.95645300E-01, 0.89507500E+00, 0.16714400E+01, -.80510000E+00, -.99231900E-01, 0.13501300E+02, 0.89922900E+01, 0.12203100E+02, 0.94447500E+00, 0.20262400E+02, 0.21520500E+00, -.12235200E+01, 0.67367400E-01, -.87526900E+00, 0.93817700E+00, 0.12865900E+01, 0.17984800E+01, -.11037600E+01, -.51696000E+02, 0.33254700E+02, 0.15101200E+01, 0.21206900E+02, 0.44623100E+01, -.24159700E+02, -.30442100E+01, 0.29373200E+02, -.46768000E+01, 0.79049500E+01, 0.23010900E+02, 0.25909600E+02, -.33267100E+02, -.12421000E+02, -.33235800E+01, 0.27777200E+02, -.24970300E+00, 0.99016000E+00, -.13769500E+00, -.22515700E+01, -.22253300E+01, -.12787800E+01, -.11149600E+01, -.23070900E+01, -.20132500E+00, -.26236200E+00, 0.36692700E+00, 0.59028400E-02, -.15276400E+00, 0.34879000E+00, 0.42291200E+00, -.12925000E+00, -.13114300E+00, 0.40445800E+01, -.14194800E+01, 0.32918300E+01, 0.61826700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.82889500E+01, -.30593500E+01, -.15754800E+01, -.26686700E+01, 0.81658100E+00, -.42936500E+00, -.29134800E+01, 0.21676600E+01, 0.15002900E+01, 0.39844100E+00, 0.98898200E+00, -.16257500E+01, 0.51339900E+00, -.28387000E-01, 0.35114900E+01, 0.12094600E+01, 0.13029000E+01, -.15086500E+01, -.13026100E+01, -.81943600E+01, -.22849200E+01, 0.76761300E+00, 0.10486500E+00, 0.24526300E+00, -.65257100E+00, 0.29195300E+00, -.15800900E+00, -.82084200E-02, -.24423500E+00, -.10341900E+01, -.70522900E+00, -.14067200E+02, 0.54860700E+01, 0.54157300E+00, 0.12620900E+00, 0.50452800E+00, 0.20648300E+01, 0.95637500E-01, 0.18035900E+01, -.30335300E+01, -.18339700E+01, 0.61924600E+00, 0.18939100E+00, 0.53840700E+00, 0.32083300E+00, -.60112100E-01, -.11715800E+01, -.76989700E+00, -.73118500E-01, -.42995700E+00, 0.13632700E+01, -.31922900E+01, -.17308700E+01, -.89058500E-01, 0.27201000E+01, -.78114700E+00, 0.75395200E-01, 0.11578600E-01, -.59761500E+00, -.13638700E+00, 0.34269300E+00, 0.44257000E+00, 0.11848600E+00, -.50651600E+00, -.72753700E+00, 0.19651900E-01, -.13898100E+01, -.13697400E+01, -.26608800E+01, -.79146000E+00, -.26868300E+01, -.10956900E+01, -.12818200E+00, -.53763600E-02, 0.46986100E+00, 0.64576100E+00, -.11283800E+00, -.99855700E+00, -.78578000E+00, -.33247800E+01, -.15817700E-01, 0.71146900E-02, -.84198400E-02, 0.31088600E-02, -.14231100E-01, -.67574300E-02, -.15294200E+00, 0.25752000E+00, -.57279300E-01, 0.44308600E-01, 0.25744900E-01, -.57288100E-01, -.82871800E-01, -.26118900E-01, -.52028300E+00, 0.87158800E+00, 0.19232100E+00, 0.35866900E+00, -.19569000E+01, -.10364300E+00, 0.83384600E-02, -.48605900E+00, -.78256200E+00, -.25248500E+01, 0.33107800E-01, -.39982700E+00, -.17422100E+02, 0.32896300E+01, -.16044800E+01, 0.63335100E+00, -.26675000E+00, -.81363000E+00, 0.20357000E+00, -.10457100E+01, -.15151300E+01, -.45373000E+00, -.13340000E-01, 0.40286900E-01, 0.23963400E+00, 0.24837600E+00, -.19416600E+00, -.44401000E-01, 0.51315600E+00, 0.59887800E+00, -.12863000E+01, 0.60913200E+00, 0.59286300E+00, 0.37241200E+00, -.13294700E+01, 0.13004500E+01, 0.10369800E+00, 0.17543000E+01, -.62875600E+02, -.54836700E+02, -.37669200E+02, -.15538700E+02, -.67789000E+00, 0.22051400E+01, -.89806200E-01, 0.27270600E+01, -.33005400E+01, -.30652200E+01, -.26750600E+01, 0.36393100E+01, 0.98519600E+02, -.10586400E+03, -.11342700E+02, -.27146300E+02, -.24361200E+02, 0.37615000E+02, -.10240200E+02, -.43646500E+02, 0.30329700E+02, 0.84682800E+00, -.87896900E+02, -.95034800E+02, 0.13225500E+03, 0.47854300E+02, 0.30294600E+02, -.10130100E+03, 0.77574300E+00, -.37365900E+01, 0.32505700E+00, 0.61164600E+01, 0.53953600E+01, 0.34391200E+01, 0.25005600E+01, 0.46033600E+01, 0.33787800E+00, 0.16667600E+01, -.75226900E+00, -.11034900E+00, 0.43748300E+00, -.45783000E-01, -.28195700E+01, -.54075200E+00, -.35504300E-01, -.36932700E+02, 0.31565500E+01, 0.57213700E+01, -.27193200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.40334000E+01, 0.12802000E+01, 0.44900400E+00, 0.15386100E+01, -.53908100E+00, 0.23779700E+00, 0.25668900E+01, -.10915500E+01, 0.11639900E+01, 0.21954700E+01, -.43613600E+00, 0.10935700E+01, 0.53420300E+01, 0.28708200E+00, 0.41483600E+01, 0.45009500E+00, 0.47728800E+00, 0.44204800E+00, 0.13203100E+01, -.99230500E+01, 0.26324500E+00, 0.60874900E+00, -.33937500E+00, -.14891100E+00, -.22616100E+00, -.44524200E+00, 0.62907400E+00, 0.93137800E+00, -.14294200E+01, 0.98274000E+00, -.46476800E+00, -.13196400E+02, 0.64533000E+01, 0.57519400E+00, -.80426800E-01, -.54003400E+00, -.77742700E+00, 0.24340700E+00, -.14045500E+00, 0.59501300E+00, -.33172700E+00, -.12345100E+00, 0.13623400E+00, 0.44705900E+00, 0.35252700E-01, -.66920000E-01, 0.75257500E+00, 0.70218900E+00, 0.74484600E+00, 0.43085900E+00, -.68184000E+01, 0.11773000E+01, -.75796400E+00, 0.52177200E+00, 0.19962400E+00, 0.76968600E+00, 0.11682900E+00, -.18624100E-01, 0.32820800E+00, -.28918100E+00, -.25168300E+00, -.48887700E+00, -.19474300E-01, -.21061300E-01, 0.34317700E+00, -.45325900E+00, 0.22008800E+01, 0.83604800E+00, 0.10025200E+01, 0.79536600E+00, -.32594100E+01, -.22267700E+01, 0.64634300E-02, -.17793400E-01, -.60873600E-01, 0.48443300E-01, 0.31843200E+00, -.64811200E+00, -.40392300E-01, 0.63163400E+00, 0.88051400E-02, -.12469300E-01, 0.74283100E-02, -.58869700E-01, 0.48308200E-01, -.37393600E-02, 0.42573700E-01, -.93736900E-01, 0.24682400E-01, -.35922800E-01, -.32641000E-01, -.31684400E+00, 0.35721200E+00, -.33152300E-02, 0.24928400E+00, -.39389800E+00, 0.48947000E+00, 0.16178200E+00, 0.11050500E+00, 0.62541600E+00, -.12305400E-01, 0.38313800E+00, -.36024900E+00, 0.99416400E-01, 0.64131400E-01, 0.60142200E+00, -.94674000E+00, 0.19886700E+00, 0.17856600E+01, 0.15740500E+00, -.10583600E-02, 0.12557200E+01, 0.39804500E+00, -.33814100E+00, -.12752500E+01, -.16256200E+00, -.32275800E-01, 0.92702500E+00, -.44238500E+00, 0.35454100E-01, -.14166900E+00, -.11606400E+00, 0.60668000E+00, 0.15675300E+00, -.71299400E+00, 0.27089800E+00, 0.12188800E+00, 0.41321900E+00, 0.55428300E+00, 0.12627600E+01, -.41144500E-01, 0.49733600E+00, 0.23854000E+00, -.71482000E+01, -.78034700E+00, -.11793700E+01, 0.33496700E-01, -.84258900E+00, -.33029000E+00, -.26093700E+00, 0.27587100E-01, 0.85378900E-01, -.75561700E+00, -.36554700E+00, -.14988000E+02, -.20612500E+01, -.12259000E+01, -.15558700E+01, 0.55432600E+01, -.11814900E+02, 0.45607800E+01, -.29045600E+01, 0.88465300E+01, -.10884300E+00, -.81886200E+00, -.10805600E+01, -.17869700E+01, 0.33297800E+01, -.43368400E+00, -.78171200E-01, -.54175800E-01, 0.25580200E+00, -.43662200E-02, -.13809600E-01, 0.67577300E+00, -.16660800E+00, -.25362400E+00, 0.44081900E+00, -.21169700E-01, 0.21976200E+01, 0.12826800E+00, 0.25844000E-01, -.27059800E-01, 0.22697700E+00, 0.29382900E+00, 0.22114300E+00, -.66984100E-02, 0.70394900E+00, -.35151900E+00, -.25538800E+01, -.65552400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.27558300E+01, -.67152200E+00, -.78234000E+00, -.97163400E+00, 0.32279800E+00, -.69455900E+00, 0.14670900E+01, -.10603000E+01, -.73752800E+00, -.11561900E+01, 0.48007500E+00, 0.40143100E-01, -.21600900E+01, -.11983600E+00, -.45640600E+00, -.12218600E+01, -.14583500E+00, -.27813600E+00, -.47635600E+00, 0.24260900E+01, -.13012800E+00, -.11429200E+01, -.30086900E+01, 0.24036500E+00, -.39035800E+00, 0.54883600E-01, 0.89132900E-01, 0.11479700E+01, -.40406000E+00, -.70416400E+00, -.24143400E+00, 0.43436500E+01, 0.50076800E+00, -.19893700E-01, -.64702500E-01, 0.32861500E+00, 0.78181700E+00, -.13968100E+00, -.31096900E-01, -.59008300E+00, -.16068900E+01, 0.14589200E+00, -.45095300E+00, 0.30083000E+00, 0.48229400E-01, 0.13147100E+00, 0.16028800E+01, 0.86599800E+00, 0.74540300E+00, 0.77519800E+00, 0.74412800E+00, -.36803800E+01, 0.68460500E-01, -.79294500E-01, 0.22512300E+01, -.44692100E+00, -.61379200E-01, 0.48351500E-02, -.15326900E+00, 0.13036300E+00, 0.57179100E-01, -.31782900E+00, -.97853200E-01, -.44973700E-01, 0.42283600E+00, 0.28180500E+00, -.88479100E+00, -.86649200E+00, 0.31092400E+00, 0.10034500E+00, -.44635400E+00, -.22526200E+00, -.51986500E-01, 0.23842500E-01, 0.37081600E-01, -.88794300E-01, 0.12563800E+00, -.13582700E+00, -.31528000E+00, -.13146300E+01, -.13415100E-01, -.53154200E-03, 0.11382300E-01, 0.11399000E-01, 0.34777600E-01, -.63992100E-02, -.32356300E-01, 0.10401900E+00, -.46482200E-01, 0.16400700E-01, 0.67741500E-01, 0.73397700E-02, 0.66739100E-01, -.23940000E-01, -.13895700E+00, 0.33911700E+00, -.60922800E-01, -.37633400E-01, -.32893300E+00, -.39590200E+00, -.71046000E-01, -.13103800E+00, -.18513100E+00, 0.14550000E+00, -.31379300E+00, -.84224300E+00, 0.13407100E+01, 0.61599400E-01, 0.13096800E+01, 0.23818800E+00, -.35722000E+00, -.33153400E+00, -.40878900E+00, 0.31592900E+00, 0.20219200E-01, -.16971400E+00, -.80535100E-01, -.35431400E+00, 0.21543700E+01, -.67241400E-01, -.18134400E+00, 0.31136500E+00, 0.18030400E+00, 0.30567400E+00, -.27511400E+00, 0.66329300E-01, -.57048100E+00, -.19333000E+00, 0.68423000E+00, 0.46626500E+00, -.57625800E-01, -.18465700E+00, -.40275700E-01, -.35260700E+00, 0.11149900E+02, 0.55039200E+00, -.65090300E-01, -.80325300E+00, -.26891500E+00, 0.63371700E-01, 0.14635800E+00, 0.14006500E+00, 0.23872300E+00, 0.32331900E-01, 0.98041400E+01, -.15768800E+02, -.18576800E+01, 0.21606400E+01, -.14555500E+01, 0.30874600E+01, 0.52900300E+01, 0.41009100E+01, 0.31515700E+01, 0.71550100E+01, -.42398100E+01, -.31226700E+01, 0.72726300E+01, 0.11011400E+01, 0.21731000E+01, -.26655300E+01, -.80810300E-03, -.57999900E+00, -.53948400E-01, -.49467000E+00, 0.46525000E+00, -.22097700E-01, -.43515800E+00, 0.18458400E+00, -.13383700E+00, 0.25973700E+01, 0.23447300E+00, 0.72506400E-03, -.58668900E-01, 0.34734300E+00, -.49459300E+00, -.14633300E+00, -.36009800E+00, -.39889300E+00, -.40541700E+00, 0.17613500E+00, -.16183100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19887400E+01, -.40285700E+00, -.46991000E+00, -.79695900E+00, 0.10192000E+01, -.63525100E+00, 0.52300200E+00, -.49005600E+00, -.38505700E+00, -.11054200E+01, 0.48995000E+00, -.13053100E+01, -.70953500E+00, -.59703700E-02, -.21445100E+01, -.30164400E-01, -.29680900E+00, -.60411000E+00, -.85478500E+00, 0.14267300E+01, -.53376300E-01, 0.45758800E+00, 0.19004300E+01, 0.27465700E+00, -.37707100E+00, 0.56114900E-02, -.11062000E+00, 0.37840700E+00, 0.47634300E+00, -.22489300E+00, 0.28243100E+00, 0.52320600E+01, -.42611600E+00, -.92034100E-02, 0.66399300E-01, 0.82566100E-02, 0.31909400E+00, 0.72823400E-01, 0.74467400E-01, 0.31147600E+00, -.43261800E+00, -.84277900E-01, 0.24406500E-01, 0.38692200E+00, -.83502700E-01, -.75846800E-01, -.98538100E+00, 0.14498200E+00, 0.52927500E+00, 0.66834900E-01, -.15097000E+01, 0.13837600E+01, -.31151900E+00, 0.87212400E-01, 0.26829300E+01, 0.53353800E+00, 0.13019300E+00, 0.12440200E-01, 0.11486600E+00, -.21504900E+00, -.16973800E+00, -.60227000E-02, 0.73258200E-01, 0.14609100E+00, -.40521300E+00, -.17699000E+00, 0.15470600E+01, 0.41871000E+00, 0.73802900E-01, -.27443900E+00, -.64236100E+00, -.60761600E+00, -.53415500E-02, -.14223900E-02, 0.15324200E-01, -.41450000E-01, -.48400900E-01, -.23093100E-01, -.85919400E-01, -.58692100E+00, -.10691900E-02, 0.28189700E-02, -.31816800E-02, 0.32570500E-02, -.18434700E-01, 0.76855300E-03, -.27455400E-01, 0.48101800E-01, -.44115500E-02, 0.93498900E-02, -.13863500E-01, -.27542600E-01, -.23837400E-01, 0.35139100E-02, -.61481100E-01, 0.14580500E+00, 0.68081100E-01, 0.61679100E-02, -.34861000E+00, -.47833200E-01, 0.73173900E-01, -.20286000E+00, -.11567400E+00, -.39331600E+00, -.15114100E+00, 0.34663800E+00, -.10914100E+01, 0.15115900E+00, 0.87916400E+00, 0.10065200E+00, -.78743900E-01, -.33238100E+00, -.19651300E+00, 0.17485300E+00, -.13664500E+00, -.32941300E+00, -.62653000E-01, -.92134400E+00, -.13470600E+01, -.51191700E-01, -.32818700E-02, -.36731500E-01, -.37776000E+00, -.10352900E+00, 0.17337200E+00, 0.39092900E-01, 0.19740700E+00, 0.97613300E-01, 0.13342900E+00, -.54919300E+00, 0.10117100E-01, 0.10458100E-02, -.71123900E-01, 0.81272800E-01, -.27687700E+00, 0.12637500E+01, -.13685200E+00, -.22448300E+00, 0.15772600E-01, 0.50633700E-01, 0.17055800E+00, 0.80716200E-01, 0.23224900E-02, 0.17364200E+00, 0.52977500E+01, -.70951400E+01, 0.42342500E+00, 0.43359900E+00, -.95807700E+00, 0.25027400E+01, -.19535300E+01, 0.27149000E+00, -.70314600E+01, 0.57432700E+01, -.41124900E+01, -.14901400E+01, 0.76062700E+01, -.21851800E-01, 0.18979300E+01, -.17701700E+01, 0.40106300E-01, -.20883700E+00, -.42546800E-01, 0.27223500E+00, 0.72216100E-01, 0.11893900E-01, 0.27846700E+00, 0.67070800E-01, -.72422400E-01, 0.62368800E+00, 0.11158800E+00, 0.91958500E-03, -.46157200E-01, -.16535900E+00, -.18294900E+00, -.37545600E+00, -.33321700E+00, 0.53199700E+00, -.13225300E+00, -.15521700E+00, -.11701700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.46376800E+01, 0.18511100E+01, 0.70986900E+00, 0.10687200E+01, -.31080400E+00, 0.12100200E+01, -.20470400E+01, 0.19992700E+01, 0.53090800E+00, 0.89117200E-02, -.48516600E+00, 0.70754100E+00, -.16980000E+01, -.12442800E+00, -.15241500E+01, 0.57898700E+00, -.26674100E+00, 0.10456800E+01, 0.19314300E+00, 0.25225400E+01, -.29375300E+00, 0.13614300E+00, 0.23228600E+01, -.70842800E-01, 0.46685800E+00, 0.33060500E+00, -.73884200E+00, -.88931000E+00, 0.13986200E+01, -.15746400E+00, -.34798800E+00, -.24151600E+00, -.31509200E+01, -.46465200E+00, 0.70726700E-02, -.29429500E+00, -.82823400E+00, 0.19621800E+00, 0.79943000E+00, 0.43796800E+00, 0.58648800E+00, 0.27421000E-01, 0.11162100E+00, 0.12956900E+00, 0.30613800E-01, -.15424600E+00, -.59839300E+00, -.17263100E+00, -.51133000E+00, -.41627900E+00, -.24170600E+01, 0.44206700E+00, -.19863200E+00, -.95317100E-01, -.42797200E+00, 0.58528700E-02, 0.69015200E-01, -.39174400E-02, 0.98873800E-01, -.12537300E+00, -.62241600E-01, -.11482100E+00, 0.13618800E-01, -.31878700E+00, -.15748500E+00, -.31274000E+00, -.13447700E+01, -.10890200E+00, -.16937900E+00, -.13158400E+00, -.11421700E+01, -.72397300E+00, 0.19977300E-01, -.80919600E-02, 0.15737300E+00, 0.39638800E-01, -.14222800E+00, -.24585300E+00, -.28395700E-01, 0.93874700E+00, 0.59816700E-02, 0.15637600E-02, 0.12798100E-01, -.12648100E-01, -.36564100E-01, 0.34613900E-02, -.21950200E-02, -.79911000E-01, 0.17558100E-01, -.29224900E-02, 0.10486800E-02, -.13351500E+00, 0.15828800E-01, 0.15318600E-01, 0.61065400E-01, -.34029700E+00, 0.13759000E+00, 0.33912200E-01, -.65098700E-01, -.12465700E+00, 0.35389300E-01, -.50895000E-01, 0.56493000E-02, 0.65073000E-01, -.33785700E-01, 0.23600400E+00, 0.37743400E-01, 0.16606200E+00, -.11175900E+01, -.17936800E+00, 0.21122300E+00, -.68927600E+00, -.23693300E+00, -.26605500E-01, -.13567500E+00, 0.94413600E-01, -.86652400E-01, -.20360500E+00, 0.86308000E+00, 0.27368300E+00, -.34292600E-01, -.12945600E+00, 0.16215800E+00, 0.20760400E+00, -.42650200E-01, -.38799500E-01, -.23241600E+00, 0.89874700E-01, -.51806100E+00, 0.23966700E+00, 0.27942000E-01, 0.10340000E+00, 0.88968400E-01, -.31734000E-01, 0.11429900E+00, 0.21061000E-01, 0.29759100E+01, 0.38204900E+00, -.68687700E-01, -.10318200E+00, -.14378200E+00, -.16209400E+00, 0.18196900E+00, -.13753200E+00, 0.49416700E+01, -.43953600E+01, 0.12230900E+00, 0.52158600E+00, -.12842700E+01, 0.24904300E+01, -.36734500E+00, 0.79606600E+00, 0.40112300E+01, -.16057900E+01, 0.67436900E+00, 0.65446600E+00, -.22257300E+01, 0.23155200E+01, -.80922800E-01, 0.10126200E+01, 0.97131800E-02, 0.30513400E+00, 0.63209700E-01, -.14998600E+00, 0.10106200E+01, -.29564600E+00, -.17777600E+00, 0.98681900E+00, 0.11768100E+00, -.61237800E-01, -.17106800E+00, 0.46203100E-02, 0.62452800E-01, 0.23053000E+00, 0.31375000E+00, 0.28166800E+00, 0.36379700E+00, 0.85821400E-01, 0.36979100E+00, 0.47583400E+00, -.40190400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16276100E+01, 0.74729400E+00, 0.69078400E+00, 0.57593100E+00, 0.88240000E-01, -.11050500E-01, 0.32503200E-01, -.15676400E+00, -.10215100E-01, 0.55702900E+00, -.10977400E-01, 0.19208000E+00, 0.10349500E+01, 0.63409700E-01, 0.10084100E+01, -.19069800E+00, 0.87869500E-01, 0.25515100E+00, 0.48355400E+00, 0.21469000E-01, 0.42198100E+00, 0.32002100E+00, 0.16684500E+00, -.11289900E+00, -.48537700E-01, 0.21308600E-01, -.57618900E-01, 0.10335400E+00, -.14852300E+00, 0.30133100E-01, -.20130000E-01, 0.59525600E+00, -.49577600E-01, -.22246900E-01, 0.43812100E-02, 0.27185600E-01, -.21737400E+00, -.23172700E+00, -.56878000E+00, 0.30778000E-01, -.41746600E-01, -.47174900E-01, -.90623200E-01, -.17625000E+00, -.56409000E-01, -.10263800E+00, 0.33672100E+00, -.15040400E-01, -.92364800E-01, 0.10464300E+00, -.54688800E+00, -.38456800E-01, 0.11409100E+00, 0.11960500E+00, 0.64366000E+00, 0.91381700E-01, -.25701800E-01, -.18382800E-02, 0.49276500E-01, -.80307100E-02, -.51104200E-01, 0.63565200E-01, -.25537400E-01, 0.17620500E+00, 0.61833400E-01, 0.10786200E+00, -.18202300E+00, 0.23498900E-01, 0.12411700E+00, 0.13958500E+00, 0.35900000E+00, 0.14643600E+00, -.73572100E-02, 0.71733000E-02, 0.81830300E-01, 0.61058900E-01, -.28366200E-01, 0.12127800E+00, 0.55993400E-01, 0.65532800E+00, -.57765300E-03, 0.77973100E-03, -.29724400E-02, 0.10848200E-01, 0.77534000E-03, 0.63168800E-03, 0.42474000E-02, -.44353500E-01, -.54495500E-03, 0.23885400E-02, 0.16397800E-02, 0.66052500E-01, -.23572600E-01, 0.15321200E-02, -.37895600E-03, -.13977600E+00, -.95422400E-01, -.23903300E-01, 0.63820200E-01, 0.90147600E-01, 0.43497200E-01, -.43672800E-01, -.21667900E-01, 0.19965500E+00, 0.70492300E-01, 0.35485900E+00, -.88809700E-01, -.10773600E+00, 0.87284400E-01, -.32184100E-01, 0.67703800E-01, 0.12476700E+00, 0.27495100E-01, -.95217900E-01, 0.17298100E+00, -.12828400E-01, -.58724100E-02, -.12928100E-01, 0.22027300E+00, 0.65381800E-01, 0.46070300E-01, -.93887000E-01, 0.96792300E-01, 0.81132900E-01, 0.79921200E-01, -.48848300E-01, -.88733600E-01, -.20218600E+00, -.19379600E+00, -.82977200E-01, 0.43756900E-02, -.12604600E+00, -.57110900E-01, 0.33319200E-01, 0.11540400E-01, 0.12548400E+00, 0.16820400E-01, 0.24903800E+01, -.27363000E-01, 0.13461800E-01, -.52013600E-01, 0.48160400E-01, 0.11144900E+00, -.56796000E-02, 0.90345700E+00, -.16810300E+01, -.67300200E-01, -.26549600E+00, -.18421600E+00, 0.34927400E+00, 0.38693900E+00, -.12157200E+00, -.78813400E+00, -.14155300E+01, 0.20067300E+00, -.34911000E-01, -.18330900E+00, -.82334700E+00, -.44242300E+00, -.21473400E+00, 0.60504100E-03, 0.48793800E-01, 0.10141500E-01, 0.34978800E-01, -.12257500E-01, -.22521700E-01, -.84477900E-02, -.14640000E-01, 0.23568900E-01, -.39156700E+00, -.54294300E-01, -.10625900E-01, 0.16367900E-01, 0.97025000E-01, 0.46969000E-01, 0.99560300E-01, 0.68502900E-01, -.38427000E+00, -.20394800E-01, 0.36045500E+00, 0.14274600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.56956100E+00, -.12868300E+00, -.18519500E+00, 0.34137100E+00, -.22991800E-01, 0.11156900E+00, 0.54857700E+00, -.65771800E+00, -.14583600E+00, -.18143200E+00, 0.71601000E-01, -.19046100E+00, -.72926400E-01, -.27617000E-02, -.24496100E+00, -.20450900E+00, -.24720600E-01, -.11908600E+00, -.94858900E-01, 0.50313800E+00, -.81425200E-03, 0.62309700E-01, -.18175300E+00, -.38521300E-01, -.20018100E+00, 0.12371300E-01, 0.25069400E-01, 0.63998000E-01, -.13903100E+00, 0.59925900E-01, 0.15260000E+00, 0.12467200E+01, -.34605300E+00, 0.19814900E-01, 0.11626900E-01, -.69798000E-01, -.10213500E+00, 0.65563400E-02, -.53747700E-01, 0.12154400E+00, 0.20752600E+00, -.81076400E-01, -.69798300E-02, -.66534600E-01, -.80603600E-01, 0.57721900E-01, 0.15866600E+00, 0.11154700E+00, 0.15486000E+00, 0.42951700E-01, 0.18440900E+01, -.47322800E+00, 0.21629200E+00, -.12972400E-01, -.13441100E+00, 0.39716200E-01, -.23031500E-01, -.25989600E-02, -.36524500E-01, 0.24423200E-01, 0.29603000E-01, -.44574800E-01, -.21204200E-01, 0.37500100E-01, 0.37894700E-01, -.16687500E-01, 0.14355800E+00, 0.14228000E-02, -.36481800E-02, -.37243500E-01, -.27883700E-02, 0.30626300E-01, 0.10628400E-02, -.43989800E-02, 0.43206400E-02, 0.14147700E-01, 0.26268000E-01, -.20103300E-01, 0.12181200E-01, -.25766000E+00, 0.66521100E-03, 0.14870400E-03, -.20064100E-02, -.12974700E-02, -.19404800E-02, 0.40739700E-03, -.66239600E-02, 0.20805600E-01, 0.16299000E-02, 0.11741100E-03, -.12801000E-02, 0.20218800E-02, -.14093000E-01, 0.82859500E-03, -.22877800E-01, 0.78153100E-01, -.10845500E-01, 0.59861200E-02, 0.19942200E-01, 0.29554800E-02, -.10120200E-01, -.18651600E-01, -.57039000E-02, 0.33872900E-02, 0.53220200E-03, -.74850000E-01, 0.68063800E-01, 0.11559900E+00, -.41858200E+00, 0.10139700E-01, 0.29540200E-02, -.26236200E-01, -.28779200E-01, 0.58971800E-02, 0.95560700E-01, -.13735900E-02, -.28727700E-02, -.12808400E+00, 0.22522300E+00, -.28363500E-02, 0.17672200E-02, -.79216600E-02, -.18494100E-01, 0.68339900E-03, -.20693600E-01, 0.63697400E-02, -.41669500E-01, 0.39875400E-01, 0.70276200E-01, 0.73257900E-01, -.61793000E-02, 0.53742000E-01, 0.24561900E-01, -.38502000E-01, 0.43202300E-01, -.63854200E-01, -.25114100E-02, -.18413200E-01, 0.31662700E+00, 0.17509400E-01, -.31019000E-01, -.35908000E-02, 0.43571500E-02, 0.22674800E-01, -.18070900E+01, 0.12427600E+01, 0.17387100E+00, -.28691200E+00, 0.47821700E+00, -.70796600E+00, 0.43695700E+00, -.51753700E+00, -.43698600E+00, -.51235300E-01, 0.15751900E+00, 0.13710300E+00, 0.30935200E-01, -.59982200E-01, -.93245400E-01, 0.21931500E+00, 0.21369200E-02, -.71304100E-01, -.20927700E-02, 0.44946400E-01, -.13920700E+00, 0.10747800E+00, 0.33901200E-01, -.13217900E+00, -.63928100E-02, -.12362300E+00, 0.27118900E-02, -.23775500E-02, 0.10858400E-02, -.13827400E+00, -.60359600E-01, -.21732800E-01, -.32090700E-01, -.64075000E-01, -.67674000E-02, -.10826900E+00, -.78250800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.75337500E+00, -.17058500E+00, -.19957600E+00, -.39154800E+00, 0.19161300E+00, -.32288000E+00, 0.26674000E+00, -.48686600E+00, -.15219600E+00, -.39694500E-01, 0.62092400E-02, -.57046200E-01, -.66413600E-01, 0.33174500E-02, 0.28368300E+00, -.24537800E+00, 0.75448200E-01, -.10214400E+00, -.39725800E-01, -.46059400E+00, -.12629300E+00, -.13856700E+00, -.49399200E+00, -.13275300E-01, -.59687900E-01, -.11731300E-01, 0.61840800E-01, -.22829300E-01, -.13061900E+00, -.47991800E-02, 0.97136700E-01, -.24456100E+00, -.25501400E-01, 0.34066300E-01, -.11083500E-01, 0.96168300E-02, 0.32829900E-01, 0.23730500E-01, 0.67128900E-01, 0.44189100E-02, 0.16390600E+00, -.60439200E-01, 0.58925700E-02, -.23964800E-01, 0.77596800E-01, 0.55113100E-01, 0.91531900E-01, 0.75763100E-01, 0.11520200E+00, -.63119200E-02, 0.12124100E+01, -.61604200E+00, 0.15293700E+00, -.47473300E-01, -.22164800E+00, -.69315900E-01, -.25231200E-01, -.36726100E-03, -.40325900E-01, 0.58256600E-01, 0.36138900E-01, 0.26526700E-01, -.22156500E-01, 0.31464500E-01, 0.12208100E+00, 0.20724900E-01, 0.38860300E-01, -.41221500E-01, 0.32079600E-01, 0.15259000E-02, 0.18310900E+00, 0.13783700E+00, -.29161700E-02, -.20480100E-03, -.35711900E-01, -.21700000E-01, 0.31642300E-01, 0.27170800E-01, 0.63761600E-02, -.19295800E+00, -.87975700E-03, -.19066700E-03, -.21872000E-02, 0.58398300E-03, 0.25435200E-02, -.30527900E-03, -.46871200E-02, 0.15515200E-01, -.28411200E-02, 0.46508500E-03, -.19901700E-02, 0.15067600E-01, -.15121800E-01, -.16763200E-02, -.24515300E-01, 0.63479100E-01, -.18380100E-01, -.90841200E-02, 0.10896700E-01, 0.34444800E-01, -.23450800E-01, -.25224700E-02, -.36772500E-01, 0.69591200E-03, -.39286900E-02, -.35007500E+00, 0.56902800E-01, 0.39813700E-01, -.16064800E+00, 0.12637400E-01, -.37663100E-01, 0.27337000E-01, 0.87428800E-02, 0.19505700E-01, 0.42650200E-01, 0.76405700E-02, -.25271300E-02, 0.34550200E-02, 0.14288600E-01, -.23818700E-01, 0.21335700E-02, -.42210000E-02, -.35737400E-01, -.30112800E-01, 0.15841300E-01, -.40712300E-03, 0.32198400E-01, -.30028600E-01, -.67832600E-02, -.48656300E-01, 0.41935100E-02, 0.29709000E-02, -.36242300E-03, -.99902800E-02, 0.59375500E-02, -.40957200E-01, -.30297700E-02, -.24569200E-01, 0.10949100E+00, 0.25443500E+00, -.14350500E-01, -.32732500E-02, 0.18448200E-01, 0.43886100E-01, -.64083500E+00, 0.65667600E+00, -.38711600E-01, -.20281600E+00, 0.19833000E+00, -.38795500E+00, 0.41157500E-01, -.26638100E+00, -.16088400E+00, 0.18904400E+00, -.45562200E-01, -.88396000E-01, 0.14692700E+00, -.38229500E-01, -.64484100E-01, -.58058900E-01, -.27145400E-02, -.86651500E-01, -.66239200E-02, 0.41199600E-01, -.14714500E+00, 0.89161700E-01, 0.34596900E-01, -.14978000E+00, -.15951800E-01, -.86738400E-01, 0.18995400E-01, -.17759400E-02, -.48702700E-02, -.78834100E-01, -.89719400E-01, -.25244900E-01, -.40081500E-01, -.51092500E-01, -.34150700E-01, -.33618800E-01, 0.26078800E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.61985200E+00, -.35088800E+00, 0.27708000E-02, -.34543200E-01, 0.22580500E+00, -.51859600E-01, 0.77833400E-01, -.39416400E-01, 0.56163100E-02, 0.93328300E-03, 0.14496600E+00, -.17877600E+00, 0.35273200E+00, 0.25955700E-01, 0.22051300E+00, -.70730400E-02, 0.44368500E-01, -.24799800E+00, -.10594300E+00, -.34916900E+00, 0.19330000E-01, 0.48809000E-01, -.15075500E+00, 0.66829700E-02, -.66992900E-01, -.40493100E-01, 0.10378100E+00, 0.16732900E+00, -.23459200E+00, 0.37610100E-01, 0.47504800E-01, -.44989200E-01, 0.60881800E+00, 0.74966100E-01, 0.39246000E-02, 0.46318400E-01, 0.18045400E+00, -.60628500E-01, -.13845200E+00, -.12348100E+00, -.19457300E+00, 0.24648400E-01, -.12345100E-01, 0.14431700E-01, 0.14342700E-01, -.14013600E-01, -.16945900E+00, -.56093900E-01, 0.38281600E-02, 0.45446500E-01, 0.19303200E+00, -.36441400E+00, 0.35515100E-01, 0.34872700E-02, 0.12887300E+01, -.20201600E-01, -.82510600E-02, 0.22450600E-02, -.22867500E-01, 0.94661300E-02, -.18156600E-01, 0.24362600E-01, -.13703300E-01, 0.10945200E+00, 0.15374900E-01, 0.90763200E-01, 0.20442200E+00, 0.77489000E-02, 0.10318200E-01, 0.50322700E-01, 0.14502900E+00, 0.12607300E+00, -.20764700E-01, 0.99253900E-02, 0.20113800E-01, 0.15998700E-01, 0.33814400E-01, 0.85735500E-02, -.72725300E-02, -.16725000E+00, -.41741400E-02, -.14974000E-03, 0.99064900E-04, 0.78057700E-02, 0.13033500E-01, -.19793300E-02, 0.13833300E-02, 0.15620300E-01, -.13038000E-01, 0.41061900E-02, 0.84988800E-02, 0.34019400E-01, 0.15719600E-01, -.76516400E-02, -.72770300E-02, 0.58636300E-01, -.38920400E-01, -.61767900E-02, -.83045200E-01, -.37029500E-01, 0.12637300E-01, 0.96681400E-02, -.47318100E-02, -.37276000E-01, -.48039800E-01, 0.15920100E-01, -.96101600E-01, 0.17393100E-01, 0.42356400E+00, 0.46159200E-01, -.60042300E-01, -.36016000E-01, -.49036500E-01, 0.53157800E-02, -.27458600E-01, -.11017000E-01, 0.79830500E-02, 0.24036400E-01, -.27204800E+00, -.21124400E-01, 0.27371100E-02, -.27738100E-02, 0.35200900E-01, -.40381900E-02, -.73379200E-02, 0.61907500E-02, 0.42139500E-01, -.26560100E-02, 0.13170500E+00, -.44334500E-01, -.95978300E-02, -.35288500E-01, -.26954900E-01, -.62960100E-02, -.22751600E-01, -.44238600E-01, -.65224400E-02, -.27241600E-01, -.83969400E-01, -.25627100E-01, 0.27147900E+00, 0.42679300E-01, 0.30140300E-01, -.15126200E-03, -.14455400E+00, -.79961600E+00, -.91919900E-01, -.98246300E-01, 0.15618300E+00, -.27170900E+00, -.19211600E+00, -.19560500E+00, -.91626100E+00, 0.80323100E+00, -.57165500E+00, -.32463900E+00, 0.97953300E+00, -.22476600E+00, 0.36577300E+00, -.37290000E+00, -.23849900E-02, -.31258600E-01, -.14865700E-01, 0.27906200E-01, -.82301600E-01, 0.46441800E-02, 0.27342300E-01, -.91329200E-01, -.23339600E-01, 0.17097800E+00, 0.37226700E-01, -.42557000E-04, -.16523400E-01, -.11238000E-01, -.26308300E-01, -.73544200E-01, -.89816900E-01, 0.41135100E-01, -.78153300E-01, -.16588800E+00, -.29956200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16392300E+01, 0.61407800E+00, 0.30380200E+00, 0.54289400E+00, -.10289200E+00, 0.97055700E-01, 0.54697200E+00, -.41990500E+00, 0.57915800E-01, 0.25868800E+00, -.78636400E-01, 0.18684600E+00, 0.55774200E+00, 0.24352400E-01, 0.19851500E+00, -.46009900E-01, -.23996400E-01, 0.26926000E+00, 0.35585700E+00, -.10203100E+00, 0.33347500E+00, 0.25407700E+00, 0.61754100E-01, -.61958700E-01, -.95940800E-01, -.38339500E-02, -.32249400E-01, 0.10359900E+00, -.39860000E-01, 0.55441800E-01, -.47914000E-01, 0.10201300E+01, 0.22326000E-01, -.79365800E-02, 0.17362700E-01, -.29727600E-01, -.20062500E+00, -.11864000E+00, -.37713300E+00, 0.41695600E-01, -.47968700E-01, -.19820900E-01, -.66017800E-01, -.12640400E+00, -.10294700E+00, -.48547700E-01, 0.57582500E+00, 0.14019600E+00, 0.43700000E-02, 0.10674900E+00, -.38836200E+00, 0.83794300E+00, 0.72696900E-01, 0.96405700E-01, -.65964000E+00, 0.16682600E+00, -.82180800E-02, -.41801700E-02, 0.71105800E-01, -.38241300E-01, -.33272200E-01, 0.95307100E-01, 0.16896600E-01, 0.15294200E+00, -.78949600E-01, -.77471000E-02, 0.33701000E+00, 0.16261200E+00, 0.56206000E-01, -.10601900E-01, 0.18310400E+00, 0.26502000E-02, 0.39247100E-03, 0.34759200E-02, 0.83796100E-01, 0.12785100E+00, -.12166400E+00, 0.10190600E+00, -.23794700E-01, 0.33687400E+00, 0.67875800E-03, 0.14094400E-02, 0.34645600E-03, 0.11153000E-01, -.11750700E-01, 0.60111000E-03, -.52089900E-02, -.17804900E-01, 0.34874500E-02, 0.24077100E-02, 0.94342700E-02, 0.66823900E-01, -.62538700E-01, 0.14183400E-02, -.36260600E-01, -.45532900E-01, -.57098200E-01, -.17526000E-01, 0.14185800E+00, 0.83994900E-01, 0.22101700E-01, -.47616700E-01, 0.67895700E-01, 0.11159600E+00, 0.90429400E-01, 0.47952800E+00, 0.22602900E+00, -.10361700E+00, -.33138200E+00, -.69001500E-01, 0.14283000E+00, 0.25785500E+00, 0.12292700E+00, -.75646100E-01, 0.15771100E+00, -.33418700E-01, 0.11637300E-01, -.76789900E-01, 0.42686900E+00, 0.35373800E-01, 0.34400700E-01, -.33711800E-01, 0.22713100E-01, 0.40409300E-01, 0.31823800E-01, -.17871700E-01, -.78548900E-01, -.83385200E-01, -.69326000E-01, 0.61831800E-01, -.10133700E-01, -.10724900E-01, -.72099700E-02, 0.13305600E-01, -.12031700E-01, 0.73910200E-01, 0.13028800E-01, 0.14234600E+00, 0.10839900E+00, 0.87392100E-02, -.21809000E+00, 0.19347500E+01, -.41063400E-01, 0.59030600E-02, -.21593200E+00, 0.56884600E+00, 0.37391200E-01, -.19051700E+00, 0.56110600E-01, 0.97840200E-01, 0.57203800E+00, -.21742700E+00, -.87900600E+00, -.99598900E+00, 0.38224900E+00, 0.23299500E+00, -.27936200E+00, -.49095400E+00, -.97922900E-01, 0.15728800E+00, 0.11218300E-01, 0.10552500E+00, 0.18054100E-01, -.38158300E-01, -.27907200E-01, -.56878500E-01, -.36416800E-01, 0.31842900E-02, 0.37856800E-01, -.22050100E+00, -.67140000E-01, -.17795000E-02, 0.20171900E-01, 0.66438400E-01, 0.96767400E-01, 0.87626200E-01, 0.70702200E-01, -.21882300E+00, 0.22672900E+00, 0.16828200E+00, 0.79552200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.47050600E+01, -.17920900E+01, -.69790900E+00, -.10252100E+01, 0.28100400E+00, -.11701300E+01, 0.20348400E+01, -.19459900E+01, -.46589700E+00, 0.77957200E-01, 0.45513100E+00, -.65531300E+00, 0.18603300E+01, 0.13203000E+00, 0.16842800E+01, -.51448800E+00, 0.28931300E+00, -.10365400E+01, -.15900600E+00, -.26293000E+01, 0.26439100E+00, -.99745800E-01, -.22524900E+01, 0.68019200E-01, -.45259700E+00, -.33186800E+00, 0.72198400E+00, 0.87655700E+00, -.13878700E+01, 0.13596000E+00, 0.32322600E+00, -.59834600E-01, 0.32581800E+01, 0.46338900E+00, -.20627800E-02, 0.27621100E+00, 0.84841800E+00, -.19458800E+00, -.78567600E+00, -.51355100E+00, -.69221200E+00, 0.13007000E-01, -.10329100E+00, -.10755700E+00, -.49957700E-01, 0.12544200E+00, 0.56504800E+00, 0.19187200E+00, 0.48535300E+00, 0.41393800E+00, 0.17523300E+01, 0.72979500E-01, 0.13990600E+00, 0.10404000E+00, 0.34406300E+00, -.75439200E-02, -.61807700E-01, 0.32343300E-02, -.78314300E-01, 0.10238800E+00, 0.50240500E-01, 0.11385000E+00, 0.34910800E-02, 0.32247800E+00, 0.11825800E+00, 0.32214400E+00, 0.13991800E+01, 0.11654700E+00, 0.13296800E+00, 0.10027300E+00, 0.11886500E+01, 0.73460500E+00, 0.68035500E+00, 0.21829000E-01, -.16414400E+00, 0.11177200E+00, 0.33392000E-01, 0.55448600E+00, -.80448600E-01, -.15590000E+01, 0.65217500E-01, -.10773500E-02, -.18348100E-01, 0.39784700E-01, 0.53700200E-01, -.79946100E-02, -.12881300E-01, 0.14474500E+00, 0.24857900E+00, 0.13764200E-01, 0.18736600E-01, 0.33762200E+00, -.12574100E+00, -.36248400E-01, -.20396200E+00, 0.66069100E+00, -.32203400E+00, -.15157100E+00, 0.22661000E+00, 0.27659100E+00, -.61596600E-01, 0.63621500E-01, 0.13086900E+00, -.23044000E-01, 0.53880100E-01, -.70159100E+00, 0.62010600E+01, -.39036800E+00, 0.98613400E+00, 0.31167400E+00, -.50004900E+00, 0.10130400E+01, 0.44045800E+00, 0.24140900E+00, 0.34397900E+00, -.15451000E+00, 0.12044400E+00, -.57630400E+00, 0.96457200E+00, -.54260100E+00, -.11881500E+00, 0.43737100E+00, -.74464200E+00, -.64111100E+00, -.60664500E-01, 0.66841100E-01, 0.13960400E+00, 0.97414200E-01, 0.89801600E+00, -.69373300E+00, -.19679500E-01, -.12234800E+00, -.93320600E-01, -.23818200E-01, -.45248000E+00, -.44846900E+00, 0.89362000E+00, -.73877300E+00, 0.38366200E+00, 0.10776500E+01, -.17351000E+00, 0.61571200E+00, -.39498200E+01, 0.27409400E+00, -.25259500E+02, 0.15107300E+02, 0.10302500E+01, 0.13715900E-01, 0.58462000E+01, -.13172100E+02, 0.15127300E+01, -.30986700E+00, -.31915400E+02, 0.15109800E+02, -.83869800E+00, 0.10492700E+01, 0.17371100E+02, -.12217300E+02, 0.61936900E+01, 0.20246200E+01, 0.32339800E+01, -.28345600E+00, 0.10849200E+00, -.13002100E+01, -.26849600E+01, -.14957400E-01, -.11674300E+01, -.27836000E+01, 0.80586200E-03, -.90612500E+00, 0.43751600E+00, 0.49083300E-01, 0.46274800E-01, 0.27952300E+00, -.29858300E+00, 0.57978500E+00, 0.61620900E+00, -.99616500E+00, -.19181500E+01, -.77749200E+00, -.19746800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.65945300E+00, -.12135600E+00, -.19496600E+00, -.35010900E+00, 0.22872500E+00, -.30522900E+00, 0.27284700E+00, -.24017400E+00, -.99229600E-01, -.14940200E+00, -.65930300E-01, 0.51771400E-01, -.36290400E+00, -.20166700E-01, -.20028200E+00, 0.64626200E-01, -.28003300E-01, -.29150000E-01, -.14933300E+00, 0.65905400E+00, -.15255900E+00, -.18847200E+00, -.41391500E+00, 0.46545900E-01, 0.26723400E-01, -.34791700E-01, 0.69693000E-01, -.50398100E-01, 0.40227100E-01, 0.50836700E-01, -.58873600E-02, -.23734900E+00, 0.17853300E+00, 0.29557300E-01, -.67983600E-02, 0.12349500E-01, 0.49724400E-01, 0.81005500E-01, 0.17139100E+00, -.55703600E-02, 0.11020300E+00, -.17819800E-01, 0.11290600E-01, 0.51638700E-02, 0.76696900E-01, 0.62754100E-01, 0.20397900E+00, 0.95613300E-01, 0.60479600E-01, 0.20436600E-01, 0.80428900E+00, 0.57286500E+00, 0.96639600E-01, -.53150900E-01, -.74130400E+00, -.21046500E-02, -.21185400E-02, -.39265900E-03, -.69919100E-02, 0.26582800E-01, 0.24168300E-01, 0.12756600E+00, 0.10679000E-01, 0.51837700E-01, 0.10153800E-01, -.60739800E-01, 0.37720900E+00, 0.47172600E-01, -.39371200E-01, -.79097200E-01, 0.12670400E+00, 0.27572900E-01, 0.10282900E-01, -.58498400E-02, -.77589800E-01, -.51060000E-01, -.17193300E-02, 0.62428500E-01, 0.51233300E-02, -.27866400E+00, 0.11427600E-02, 0.26995300E-03, -.30152800E-02, -.17340900E-02, -.63836600E-02, 0.60435200E-03, -.65306600E-02, 0.22104000E-01, 0.36679500E-02, -.73832100E-03, -.10106000E-01, 0.40005000E-02, -.31187200E-01, 0.17957600E-02, -.23955700E-01, 0.86794800E-01, 0.47723500E-02, -.26042400E-02, 0.26501800E-01, 0.50621500E-01, -.22630200E-01, -.53831600E-02, -.10330600E-01, -.90155500E-01, 0.70164800E-02, -.30081300E+00, -.53515600E-01, 0.27213600E-01, -.35610200E+00, -.21539900E-01, 0.19212800E-01, 0.38016000E-01, 0.48739100E-01, 0.23123700E-01, -.41095500E-02, -.13603400E-01, 0.29405300E-02, -.43719500E-01, -.94477100E-01, -.46583100E-01, 0.43035600E-02, 0.53452400E-02, -.87453200E-01, -.61329300E-01, 0.18706900E-01, 0.18266100E-01, 0.78015600E-01, 0.50827300E-01, 0.43193400E-01, -.46903200E-01, 0.27208300E-02, 0.44744800E-01, 0.13229400E-01, -.17719800E-01, -.78967200E-02, -.60965100E-01, -.80755200E-02, -.52744300E-01, 0.12887100E+00, 0.13695100E+00, -.52039400E-01, -.27398400E-02, 0.22510400E-01, 0.42709800E+00, -.69002900E+00, 0.72067000E+00, 0.26577900E-01, -.80619100E-01, 0.20761300E+00, -.26753700E+00, -.64164500E-01, -.19646000E+00, 0.56002300E+00, 0.44688800E+00, 0.62094800E-01, 0.47840900E-01, -.25377400E+00, 0.35635000E+00, -.21517700E+00, 0.81890800E-01, -.70654100E-01, -.59378900E-01, -.68543100E-02, 0.69040100E-01, -.61716200E-01, 0.70012100E-01, 0.77210800E-01, -.47361800E-01, -.12344700E-01, 0.17516700E-01, 0.10182800E-01, 0.87049600E-04, -.55156200E-02, -.95451500E-01, -.57710700E-01, -.58246000E-01, -.58118400E-01, 0.62528700E-01, 0.41993100E-02, -.11808100E+00, -.33667900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22705600E+01, -.43191600E+00, -.54023200E+00, -.90964100E+00, 0.27701400E+00, -.82195500E+00, 0.11970800E+01, -.14520100E+01, -.23930900E+00, 0.41218100E+00, 0.37969000E-01, -.26335600E+00, 0.14840400E+01, 0.10581700E+00, 0.18079200E+01, -.94282300E+00, 0.30227600E+00, 0.51072500E-01, 0.39670300E+00, -.12392300E+01, 0.32397800E+00, -.95166600E-01, -.16651200E+01, -.13529100E+00, -.34162300E+00, -.68360300E-01, 0.15648500E+00, 0.23493400E+00, -.68512100E+00, -.15186300E+00, 0.13924500E+00, 0.14443900E+01, 0.12560200E+01, 0.20384800E+00, -.85998800E-02, 0.15256400E+00, 0.28123100E+00, -.10389300E+00, -.38090000E+00, -.23484000E-01, -.21964600E+00, -.23636300E-01, -.11470400E+00, -.19878700E+00, -.16134900E+00, 0.13016600E+00, 0.78561000E+00, 0.59440600E+00, 0.66535000E+00, 0.21933000E+00, -.28746300E+00, -.19985200E+01, -.13496600E+00, 0.96961200E-01, 0.25153700E+00, -.10801500E+00, -.59409800E-01, -.58745500E-02, -.48770400E-01, 0.77016300E-01, 0.32783100E-01, -.11873600E+00, -.58421400E-01, 0.27791900E-01, 0.21487900E+00, 0.16365200E+00, 0.28918400E+00, -.11604800E+00, 0.23003400E+00, 0.32813000E+00, -.50165800E+00, -.13327000E+00, -.51769600E-01, 0.24523400E-01, 0.12786900E+00, 0.20316400E+00, -.11566600E-01, -.23486900E+00, -.23507600E+00, -.58727300E+00, -.90399500E-02, -.26581900E-02, 0.19587700E-01, 0.33983900E-02, 0.27636800E-01, -.72673500E-02, -.63002000E-02, 0.41539500E-01, -.30661500E-01, 0.26187900E-02, 0.77429500E-01, -.16637700E-02, 0.63829300E-01, -.25472300E-01, -.62552900E-01, 0.12913300E+00, 0.13371100E+00, 0.56503100E-01, -.85310800E-01, 0.54706900E-01, -.43323800E-01, 0.62482100E-01, 0.65857000E-01, 0.15086700E+00, -.84937200E-01, 0.25560300E+00, 0.21055200E+01, 0.89406400E-01, 0.13692400E+01, 0.25571500E+00, -.21184600E+00, 0.44379700E+00, -.48245000E-01, 0.47324500E-01, 0.32439600E+00, 0.83963000E-01, 0.17201600E-01, 0.29918200E+00, -.58389100E+00, 0.10865100E+00, -.74782500E-01, -.50980300E-01, -.91303700E-01, -.18218300E+00, -.73376300E-01, 0.80850600E-02, 0.11066900E+00, 0.42987600E+00, -.78249400E+00, 0.54846700E-02, 0.97416500E-01, 0.36793400E-01, 0.15026900E+00, -.13135700E+00, 0.31948900E+00, -.12621800E+00, 0.25832100E-01, -.27243700E+00, 0.24047200E+00, -.67607100E+00, -.42564100E+00, 0.21730400E+00, -.11023700E+00, -.23810000E+00, -.28493800E+02, 0.17463000E+02, 0.32367300E+01, 0.29979100E+01, 0.39153700E+01, -.13321900E+02, 0.21974700E+01, 0.28177400E+01, 0.34994600E+00, 0.64235300E+01, 0.76833900E+00, 0.59054300E+00, 0.23310100E+01, -.54620900E+00, 0.61163000E+00, 0.12338900E+01, 0.27476500E+00, -.23271400E+00, -.38143400E-01, 0.49015800E-01, -.48121500E+00, 0.32352500E+00, 0.15392300E-01, -.67188700E+00, -.11377000E+00, -.10458600E+01, 0.21323900E+00, -.23225700E-01, -.25286500E-01, -.31175900E+00, -.38715400E+00, -.18520000E+00, 0.25526400E-01, 0.88511100E-01, -.79384700E+00, -.46977300E+00, -.13691600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15062000E+01, -.72880400E+00, 0.92659500E-01, -.30908700E+00, 0.81219900E+00, -.12116300E+00, -.22837800E+00, -.17397700E+00, -.46684400E-01, -.29141400E+00, 0.44306700E+00, -.82606100E+00, 0.16153000E+00, 0.41803200E-01, -.23706400E+00, -.49292300E-01, 0.54130400E-01, -.61387700E+00, -.60789600E+00, -.11740500E+01, -.25891800E+00, 0.27640900E+00, 0.45930500E+00, -.77674600E-02, -.17389000E+00, -.49872700E-01, 0.62231200E-01, -.73134800E-01, -.37382600E+00, -.93189500E-01, 0.14498500E+00, -.17530400E+01, 0.48569800E+00, 0.39264300E-01, 0.17250400E-01, -.42342100E-01, 0.14850800E+00, 0.79221600E-01, 0.60029500E-01, -.39705300E+00, -.24140300E+00, -.43486400E-02, 0.39068900E-01, 0.24938800E-01, 0.22909900E+00, 0.30068600E-01, 0.63194100E+00, -.42946300E-01, -.25906500E-01, 0.17773700E+00, 0.33941700E+01, -.26926600E+00, 0.40559600E+00, -.11759300E-01, -.74835000E+00, -.83509200E-01, -.55704000E-01, 0.23310300E-02, -.10627600E+00, 0.11997600E+00, 0.97361300E-01, 0.11675900E+00, -.11950800E-01, 0.20205100E+00, 0.16386300E+00, 0.67704400E-01, -.22690000E+00, 0.86788000E-01, 0.11459800E-01, -.45403300E-01, 0.75032500E+00, 0.59186500E+00, 0.24596900E-01, -.16518700E-01, -.63379300E-01, -.39750900E-01, 0.27088200E-01, 0.10174500E+00, 0.17533400E+00, 0.16007500E+00, 0.53912400E-02, 0.12281500E-02, -.17062400E-01, 0.15648700E-02, -.18585200E-01, 0.36726300E-02, -.57673300E-03, -.78941300E-02, 0.19152400E-01, -.36690300E-02, -.57483500E-01, 0.39478800E-01, -.76615700E-01, 0.11963100E-01, 0.14512300E-01, 0.28748900E-02, -.11783600E+00, -.34786600E-02, 0.32172300E-01, 0.13889500E+00, 0.32251800E-01, 0.34014200E-01, -.56737500E-01, -.55854500E-01, 0.89266800E-01, 0.30016000E+00, -.18442600E+01, 0.11327300E+00, -.45243800E+00, -.76250900E-01, 0.66608400E-01, -.17018000E+00, 0.18325900E-01, 0.68435400E-01, -.17640800E+00, 0.17468400E-01, -.11770900E-01, -.47746100E+00, 0.62192900E+00, -.33601400E-01, 0.64830000E-01, -.10921900E+00, 0.41229000E+00, 0.11463800E+00, -.22148300E-02, -.10540200E+00, -.31286600E-01, 0.37112900E-02, 0.62462500E+00, -.43650600E-01, -.71096000E-01, -.31344400E+00, -.17950100E+00, -.53461400E-01, -.12271300E+00, -.45975200E+00, -.42859800E-02, -.52449800E-02, 0.16421300E-01, -.30539800E+00, 0.32444000E+00, 0.17032100E+00, -.28329200E+00, 0.15244400E+00, 0.34390800E+00, -.78012500E+01, -.19220100E+01, -.37812700E+01, 0.38360600E+01, -.26017000E-01, 0.40214400E+00, -.46849000E+01, -.14731300E+02, 0.37864800E+01, -.21223400E+01, -.13587300E+00, 0.79492300E+01, -.38961300E+01, 0.44000800E+01, 0.56172000E+00, 0.79374900E+00, -.22065800E+00, -.12531600E-01, -.14811900E+00, -.96470200E+00, 0.86795300E-01, -.10812400E+00, -.10019300E+01, -.54829100E-01, 0.18776100E+00, 0.17167600E+00, -.57847800E-02, -.22105300E-01, -.18783200E+00, -.13732400E+00, -.10393300E-01, -.75361400E-01, -.20736900E+00, -.49938100E+00, -.12193800E+01, -.65545000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22934700E+01, -.54818300E+00, -.47449800E+00, -.95896300E+00, 0.92932900E+00, -.69017000E+00, 0.45323300E+00, -.11915700E+01, -.54343800E+00, -.82861300E+00, 0.72509400E+00, -.16333100E+01, 0.76698200E-01, 0.57207600E-01, -.80990800E+00, -.93056400E+00, 0.84562100E-02, -.89088100E+00, -.58710500E+00, -.23061000E+01, -.57272000E-01, 0.65913900E+00, 0.17189800E+01, 0.66986100E-01, -.61074000E+00, 0.91758200E-01, -.15904800E+00, 0.36673300E+00, 0.62645200E-02, -.34857100E+00, 0.61746600E+00, 0.55736000E+01, -.12760100E+01, -.37212300E-01, 0.56480400E-01, -.45947200E-01, 0.20455900E+00, -.12151800E+00, -.30967300E+00, 0.22699400E+00, -.37557900E+00, -.20864200E+00, -.38900200E-01, 0.38753700E+00, 0.83031800E-01, -.61407700E-01, -.90938600E+00, 0.29034400E+00, 0.79441200E+00, 0.11603200E+00, -.80510700E+00, -.15105000E+00, -.42616400E+00, 0.14446700E+00, 0.30315000E+01, 0.36814600E+00, 0.81931600E-01, 0.13302500E-01, 0.64638900E-02, -.12913200E+00, -.98571600E-01, -.25496200E+00, 0.23856500E-01, 0.83193200E-02, -.35001600E-01, -.20441600E-01, 0.40849200E+00, 0.24689400E+00, -.21428000E-01, 0.96464000E-01, -.39100100E+00, -.18845600E+00, -.37056400E-01, 0.29608200E-02, 0.18233600E+00, 0.13685800E+00, 0.49317800E-01, -.13518400E+00, 0.10540100E+00, 0.30356500E+00, -.24112800E-02, 0.14991600E-02, -.96148800E-02, 0.70083300E-02, 0.12668700E-02, 0.65630800E-03, -.73263500E-02, -.19326400E-01, -.77962100E-02, 0.54270900E-02, -.29133500E-01, 0.14298300E-01, 0.10960300E-01, 0.18259900E-02, -.32396600E-02, -.69431200E-01, 0.22772100E-02, 0.43952400E-01, -.31266400E+00, 0.29362700E+00, 0.84899200E-01, -.11255300E+00, -.26278500E+00, -.32549400E+00, -.10570100E+00, 0.27177600E+00, -.24564700E+00, 0.34017300E+00, 0.54387900E+00, 0.57828400E-01, -.11649700E+00, -.34517600E+00, -.46917500E+00, 0.19105800E+00, 0.39797200E+00, -.30973100E+00, -.73609000E-01, -.11848600E+01, -.81496700E+00, 0.73267600E-02, 0.64123900E-01, -.41954200E+00, 0.17059500E-02, 0.40041800E-01, -.29886900E-01, 0.76264000E-01, 0.17810500E+00, 0.61108300E+00, -.20207600E+00, -.32488900E+00, 0.24784600E-01, 0.32945500E+00, 0.96533100E-01, -.19056400E+00, 0.13808500E+00, -.94970400E+00, -.44048300E-01, -.95874000E-02, 0.22442400E+00, 0.65050300E-01, 0.59709200E+00, 0.17472200E-01, 0.37425000E-01, 0.26349900E+00, 0.87094600E-01, 0.10278600E+01, 0.40355700E+01, 0.33290500E+01, -.38468000E+01, -.69530600E-01, -.16421700E+01, 0.23889500E+01, 0.68633000E+01, 0.27359700E+00, -.13077100E+01, -.78139000E+00, -.16198400E+01, 0.42187400E+01, -.40331000E+01, -.16383800E+01, -.90513200E+00, 0.11712100E+00, -.11256800E-01, 0.65266700E+00, 0.13086600E+01, -.56292300E-01, 0.58098500E+00, 0.13248100E+01, 0.38251800E-01, -.17280600E-01, -.17221400E+00, 0.59452700E-02, -.26340100E-02, -.14309200E+00, 0.15379200E+00, -.31426600E+00, -.21204500E+00, 0.11344600E+01, 0.68356700E+00, 0.43780900E+00, -.51412200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17467700E+02, 0.60158600E+01, 0.12070400E+01, 0.93991300E+01, -.26022500E+01, 0.70248200E+01, -.42925500E+01, 0.36190800E+01, -.61497800E+00, -.29377200E+01, -.83553800E+00, 0.73370400E+01, -.19322600E+02, -.12834200E+01, -.68360600E+01, -.13283700E+00, -.16463900E+01, 0.38589100E+01, -.23332200E+00, -.65417500E+01, -.22047100E+01, 0.18482900E+00, -.62642800E+00, -.70059500E-01, 0.53859900E+00, 0.36390500E+00, -.14796700E+01, -.36704100E+01, 0.41763900E+01, 0.11687400E+00, -.20043200E+01, -.22852500E+02, 0.19407900E+01, 0.19428800E-01, -.38727200E+00, -.17506900E+00, -.17425900E+01, -.12394900E+01, 0.43012800E+00, 0.16091400E+01, 0.17226000E+01, 0.25593600E-01, 0.10067700E+01, 0.41259300E+01, 0.25972200E+01, -.14172300E+00, -.72829100E+01, -.13286600E+01, -.83427800E+00, -.32489700E+01, -.92703800E+00, 0.16499700E+01, -.13372200E+01, -.47155200E+00, -.14830900E+02, -.23363100E+01, -.22964200E+00, -.69359700E-01, -.58290900E+00, 0.39386400E+00, 0.85552500E+00, -.24499900E+01, -.39105100E+00, -.30407000E+01, 0.12860700E+01, -.18957700E+01, -.71834400E+01, -.11135700E+01, -.29777300E+01, 0.53044700E-02, -.56162400E+01, -.58569900E+00, 0.64200800E-01, -.11515600E+00, 0.67242500E+00, 0.12527800E+01, -.66757400E+00, -.30098000E+01, -.32501200E+00, -.12059400E+01, 0.38040300E-01, 0.25868600E-02, 0.32576800E-01, -.10750400E+00, -.21631400E+00, 0.57402800E-02, -.12903800E+00, 0.28610900E-01, 0.10760300E+00, -.38914900E-01, -.10877000E+00, -.80522900E+00, -.17782600E+00, 0.33634500E-01, -.13427700E+00, -.16360300E+00, 0.16652400E+01, 0.41273100E+00, 0.94254400E+00, -.10584800E+01, -.28264500E+00, -.25986100E+00, 0.13845200E+01, -.34419600E+01, -.11768600E+00, 0.42760200E+01, -.82514700E+01, 0.20918600E+01, -.50520100E+00, 0.80913200E+00, -.90599000E+00, -.27448600E+01, -.78675400E+00, 0.10241000E+01, 0.17602000E+01, -.21488300E+01, -.71618700E+00, -.62824600E+01, -.88551800E+01, -.11814500E+01, -.16746200E+00, -.20440900E+00, -.35947600E+01, -.77935300E+00, 0.58630300E+00, 0.98568900E+00, 0.27278600E+01, 0.10350000E+01, 0.86472300E-01, -.47949900E+01, 0.39108000E+00, -.32402700E+01, -.15000400E+01, -.29403500E+00, -.70988700E+00, -.61935200E+00, -.15546700E+00, -.33015000E+01, -.35807500E+01, -.16235900E+01, -.17429300E+01, 0.17558800E+01, -.19889900E+00, -.12981900E+00, 0.32500800E-01, 0.95939000E+01, 0.14490300E+01, 0.37011300E+02, -.18786200E+02, -.87089300E+00, -.10851000E+02, 0.52674100E+02, 0.16029400E+03, 0.20622700E+02, -.20411000E+02, -.24725100E+02, -.17393900E+02, 0.50552500E+02, -.17508500E+02, -.27697900E+02, -.60917300E+01, -.34823200E+00, -.31527900E+00, 0.13803900E+00, 0.87133800E+01, -.62734400E+00, -.64128300E+00, 0.73233700E+01, -.67097200E+00, 0.63072800E+01, 0.74087600E+00, -.36224000E-02, -.22945700E+00, 0.69941900E+00, -.13409500E+01, -.95849500E+00, -.65560400E+00, 0.54082700E-01, -.17564700E+01, 0.74288900E+01, -.90045900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11464500E+02, 0.37007900E+01, 0.95326000E+00, 0.34176500E+01, -.19389200E+01, 0.32814900E+01, -.22126400E+01, 0.56229400E+01, 0.31862300E+01, 0.40414300E+01, -.18010700E+01, 0.47216400E+01, 0.54269600E+01, 0.83379300E-01, 0.73713500E+01, 0.33589000E+01, 0.11497600E+01, 0.23839100E+00, 0.22120300E+01, -.29565400E+02, -.26230600E+01, 0.37960300E+00, 0.20949400E+01, -.32758100E+00, 0.10028400E+01, -.19082600E+00, 0.42499800E+00, -.67792500E-01, -.10851200E+01, 0.11407600E+01, -.11739500E+01, -.38486000E+02, 0.46148500E+01, -.65465400E-01, -.31373500E+00, -.21134600E+01, -.23835900E+01, 0.10260800E+01, 0.16856700E+01, 0.25868300E+00, -.14490500E+01, 0.90676300E-01, 0.34596700E+00, 0.12387800E+01, 0.83577700E+00, -.37837800E+00, -.12230100E+01, -.11374100E+01, -.76754700E+00, 0.35867400E+00, 0.26641500E+01, 0.59248800E+01, -.78146100E+00, 0.24548800E+00, 0.21085900E+01, 0.19920500E+01, 0.37893000E+00, -.10223000E-01, 0.20173700E+00, -.79998300E+00, -.25398300E+00, -.67229600E+00, 0.31059600E+00, -.21542900E+00, -.11787500E+01, -.11853500E+01, 0.36387000E+00, 0.13992600E+01, 0.15375400E+00, -.18010800E+01, -.23018300E+01, -.27174700E+01, -.89507700E-01, 0.77534800E-02, 0.75920500E+00, 0.17052000E+00, 0.23002800E+00, 0.20759300E+00, 0.88922500E+00, 0.39047500E+01, -.17275700E-02, 0.52950600E-02, -.17175200E-01, 0.56874400E-02, 0.10726100E-01, 0.11587700E-01, 0.32170900E-01, -.28797800E+00, -.24744300E-02, 0.14475400E-01, -.49149700E-01, 0.63403300E-01, 0.35798700E-01, 0.36194200E-01, 0.17868300E+00, -.97790900E+00, -.31342600E+00, -.11830300E+00, -.32786100E+00, 0.11031500E+01, 0.52212200E+00, -.52900500E+00, -.15367400E+01, -.13390700E+01, -.24374900E+00, -.13521000E+01, 0.17715500E+01, 0.20343900E+01, -.18950300E+01, -.23273000E+00, 0.39309800E+00, -.38959600E+01, -.30836700E+01, -.41501700E+00, 0.24734700E+01, -.46932600E+00, -.35807600E+00, -.45150500E+01, 0.15492100E+00, 0.10515500E+01, 0.37810400E+00, -.21264600E+01, 0.18208700E+01, 0.10355300E+01, -.33946100E+00, -.84818800E-01, -.55377900E+00, -.50227400E+00, 0.99522600E+00, 0.36628400E+00, -.20014300E-01, -.69034600E+00, -.22864600E+00, -.15473600E+01, 0.34347600E+00, -.20721100E+00, -.37185300E-02, -.13341000E+01, -.24889700E+01, -.82937700E-01, -.11683200E+01, 0.52278400E+00, -.17842900E+00, -.19277400E+00, 0.39435500E+00, 0.50843000E+01, 0.64185100E+00, 0.17235700E+00, -.10137900E+02, -.98572200E+01, 0.81507100E+01, -.12711300E+01, 0.48563200E+02, -.22420200E+02, 0.79036300E+01, -.13681300E+01, -.33434200E+02, 0.40740000E+01, -.19174900E+02, -.43280900E+01, -.22483200E+01, -.76374900E-01, -.15630300E-01, 0.51520300E+00, 0.31639200E+01, -.76856900E-01, -.35796600E+00, 0.30361400E+01, -.12759700E-01, 0.42489300E+01, -.11182900E+00, 0.43879800E-01, -.96666700E-02, 0.89672000E+00, 0.23587200E+00, 0.29617300E+00, -.45325300E+00, -.33750400E+01, 0.67095000E+00, -.32724500E+00, 0.50402800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12979200E+02, 0.56960800E+01, 0.19700200E+01, 0.19134500E+00, -.32111700E+00, 0.28811500E+01, -.67825900E+01, 0.58264800E+01, -.60921600E+01, -.69087300E+01, -.39361100E+01, 0.23669000E+01, -.15613200E+02, -.86504700E+00, -.15464300E+02, -.36956400E+01, -.36270400E+01, -.28645300E+00, 0.26629200E+00, 0.49492400E+01, 0.25101600E+01, -.44610600E+01, 0.77996300E+00, 0.14547700E+01, 0.10126700E+01, -.87844700E+00, -.32510500E+01, -.45766600E+01, 0.50330100E+01, -.33143200E+01, -.16788000E+01, -.62692100E+01, -.34966200E+01, -.78338400E+00, -.28228900E+00, 0.86733100E-01, -.15335400E+01, 0.60680600E-01, 0.13064200E+01, 0.28025300E+01, 0.19453300E+01, -.67773100E+00, 0.69531800E+00, 0.23096600E+01, 0.67191100E+00, -.80132000E+00, -.46903400E+01, -.46880000E-01, -.57123900E-01, -.16826300E+01, -.31762000E+02, 0.84315100E+01, -.53960000E+00, 0.12432700E+00, -.34141200E+01, -.25774200E+01, 0.84390700E-01, 0.34756100E-01, 0.69323000E+00, 0.31096400E+00, -.34778400E+00, 0.16916600E+01, -.30854200E+00, -.31355900E-01, 0.99848100E+00, -.23227900E+00, 0.78869000E+01, 0.26199700E+00, 0.99427900E+00, 0.13097000E+01, -.21701900E+01, -.11931900E+01, 0.13922500E+00, -.99434800E-01, -.78358000E+00, -.10640700E+01, 0.13160400E+01, -.55199700E+00, 0.66631100E+00, -.73901200E+01, 0.29778400E-01, -.37334600E-02, -.68153600E-01, -.11694900E+00, -.10814900E-02, 0.10837100E-01, -.44959900E-01, 0.51154700E+00, 0.77842000E-01, -.17803600E-01, -.23232300E+00, -.56325700E+00, 0.27684000E+00, 0.40997000E-01, 0.16481900E+00, 0.17224000E+01, 0.92435000E-01, 0.76772900E-01, -.95068600E+00, -.77252300E+00, -.99254600E-02, -.34177400E+00, -.30177700E-01, 0.85334200E+00, -.28176300E+00, -.26162100E+00, -.22253300E+02, 0.14503100E+00, 0.45492700E+01, 0.12247100E+01, -.13557400E+01, 0.38707500E+01, 0.20893500E+01, -.32716100E+00, -.27183900E+01, -.26301100E-01, -.99476000E-01, 0.25579900E+00, -.51073600E+01, -.10084200E+01, -.79708500E-02, 0.10667400E+01, -.58339500E+00, 0.17865300E+00, 0.77350100E+00, -.39716200E+00, 0.61673700E+00, -.30422400E+01, 0.10716100E+01, -.32138800E+01, -.94048800E-01, -.25681400E+01, -.13753300E+01, 0.79361700E+00, -.15138600E+01, 0.34770500E+00, -.23601300E+00, 0.38439100E+00, 0.89156000E+00, 0.50261500E+01, 0.64714300E+01, 0.91243100E-02, -.14993100E+01, 0.39172700E+01, -.23684700E+01, -.13622600E+01, 0.24448700E+00, 0.20675300E+00, 0.31919400E+00, -.15408700E+02, -.21347900E+02, -.55510400E-01, -.16110300E+03, 0.50754100E+02, -.18104900E+02, -.36944300E+01, 0.91067000E+02, -.55622700E+02, 0.33506300E+02, -.33624800E+00, 0.92315000E+01, -.40672300E+01, -.22387700E+00, -.74089700E+00, -.16003000E+02, 0.21595600E+01, -.38555300E+00, -.15232500E+02, -.78401700E+00, -.10490100E+01, 0.18179800E+01, -.19507400E+00, -.22734700E+00, -.47372000E+00, -.42079300E+01, -.17595000E+01, -.49754600E+00, -.19917000E+01, -.50887400E+01, 0.14614900E+01, -.50396900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11073500E+02, 0.32378900E+01, 0.95555200E+00, 0.37435400E+01, -.27016200E+01, 0.31709000E+01, -.17924100E+01, 0.56408900E+01, 0.30394300E+01, 0.39955400E+01, -.24102900E+01, 0.48029900E+01, 0.57544200E+01, 0.15334700E+00, 0.40598800E+01, 0.31190000E+01, 0.24322200E+00, 0.24210200E+01, 0.24947100E+01, -.38777200E+01, -.48027200E+00, -.83207600E-01, -.23605900E+01, -.50829200E+00, 0.98982100E+00, -.30014400E+00, 0.74438800E+00, 0.13679200E+00, -.14285400E+01, 0.20732000E+01, -.23211300E+01, -.30959500E+02, 0.11055500E+02, 0.10763700E+01, 0.38943000E-01, -.55250600E+00, -.80948000E+00, 0.86411100E+00, 0.23152800E+01, -.73779800E+00, 0.27664200E-01, 0.51586600E+00, 0.10293200E+00, -.96625000E-01, -.98665600E+00, -.22094900E+00, 0.15445200E+00, -.57850300E-02, -.13025900E+01, -.15634900E+00, 0.21538200E+01, 0.21538700E+02, -.55547500E+00, -.39154400E+00, -.18357900E+02, -.92705500E-01, 0.22784300E+00, -.28960800E-01, 0.60542700E-02, -.46821800E+00, 0.48545600E+00, -.46189800E+00, 0.73821900E+00, -.14120500E+01, -.10916200E+01, -.70773000E+00, -.39199900E+01, -.15487200E+01, -.31050400E+01, -.25819400E+01, 0.15869400E+01, 0.15769000E+00, 0.11654000E+00, -.74774300E-01, -.18243100E+00, -.10524400E+01, 0.12280800E+00, 0.92545100E+00, 0.52647500E+00, -.44098300E+00, 0.19103900E-01, 0.11876100E-01, -.26522100E-01, -.32200500E-01, -.14079300E+00, 0.18291100E-01, -.10538700E+00, 0.40032400E-01, 0.57074200E-01, 0.13866000E-01, -.55015100E-01, -.12916200E+00, -.33182900E+00, 0.63220800E-01, -.17801600E+00, 0.14709500E+00, -.27299600E+00, -.17693200E+00, -.19882500E+00, 0.93823700E-01, 0.59768700E+00, -.83612800E+00, -.16498400E+01, -.13728700E+01, -.83764100E+00, -.27454900E+01, -.64603000E+01, 0.26312600E+01, -.40361000E+01, -.21130300E+00, 0.51974100E+00, -.58704800E+01, -.26642300E+01, 0.52197400E+00, 0.99063800E+00, -.28234500E+00, -.26024200E+00, -.53999900E+01, 0.11609900E+01, 0.56403500E+00, 0.88481200E-01, -.95154900E+00, -.11685500E+00, 0.99400700E-01, -.27694200E+00, -.12343700E+00, -.70474200E+00, -.13378300E+01, 0.11449100E+01, -.23695500E+00, -.14452700E+00, -.38993600E+00, -.34826100E+00, -.77329000E+00, -.42349600E+00, 0.90803500E+00, 0.24779600E-01, 0.13697400E+00, -.53069000E+00, 0.37729400E+00, -.22186400E+00, -.11835500E+00, -.14118700E+00, 0.10754100E+00, -.43609900E+00, 0.52580700E+00, -.49400800E+00, 0.19165800E-01, 0.10626100E+00, 0.62969100E+00, 0.15245500E+02, 0.33245800E+00, 0.10145000E+03, -.34035100E+02, 0.10550900E+02, 0.14654100E+01, -.57617100E+02, 0.32335600E+02, -.22042200E+02, -.12910900E+01, -.57357800E+01, 0.25517300E+01, 0.17625300E+00, 0.35280400E+00, 0.10211400E+02, -.13610900E+01, -.20310600E-01, 0.96668400E+01, 0.55452100E+00, 0.18418400E+01, -.12469100E+01, 0.12719500E+00, 0.17880500E+00, 0.60591600E+00, 0.27702600E+01, 0.11087800E+01, 0.25751500E+00, -.17171900E-01, 0.35430500E+01, -.12870700E+01, 0.35328700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14819800E+02, 0.68112300E+01, 0.39620700E+01, 0.36264100E+01, -.10312500E+01, 0.20740200E+01, -.67125000E+01, 0.75224700E+01, 0.92577100E+00, 0.12982200E+01, -.22883800E+01, 0.28206100E+01, -.24128300E+01, -.17461000E+00, -.54652900E+01, 0.11865400E+01, -.11438200E+01, 0.46109600E+01, 0.21658600E+01, -.83960400E+01, 0.98973200E+00, 0.98876000E+00, 0.67164600E+01, -.10581200E+01, 0.32398400E+01, 0.76225800E+00, -.20351200E+01, -.61538400E+01, 0.75097200E+01, -.29025900E+00, -.75209200E+00, 0.42972100E+01, -.10542200E+02, -.91206200E+00, 0.32167900E+00, -.19213700E+01, -.29542600E+01, 0.81331000E+00, 0.99986900E+00, 0.17581400E+01, 0.54348900E+01, -.32963000E+00, 0.11581800E+01, -.12281100E+01, -.15049200E+01, -.83451700E+00, -.51049700E+01, 0.89836100E-01, -.12212100E+01, -.27332900E+01, -.11416900E+02, 0.68716500E+01, 0.21198000E-01, -.17985900E+00, 0.14317800E+01, -.99600000E-01, 0.14051200E+00, -.83964000E-01, 0.51087100E+00, -.64626700E+00, -.38811500E+00, 0.44556200E+00, 0.32236400E+00, 0.62064200E+00, -.20704100E+01, -.62099300E+00, 0.65437300E+01, 0.16720900E+01, -.21321500E+01, -.13757300E+01, -.13930700E+01, -.65592900E+00, -.29689500E+00, 0.15819000E+00, 0.65398000E+00, 0.11091100E+01, -.54849700E+00, -.49200200E+00, -.12320100E+01, -.39796600E+01, -.59120200E-01, -.87838700E-02, 0.91719300E-01, 0.14356500E+00, 0.72300600E-01, -.44998400E-01, -.30937900E-01, 0.35687100E+00, -.18528900E+00, 0.36102500E-01, 0.32910100E+00, 0.41012800E+00, 0.98481300E-01, -.15449300E+00, -.20282400E+00, 0.11849300E+01, 0.45583700E-01, -.45398800E-01, -.28542100E+00, -.69852400E+00, 0.32848000E+00, 0.56962300E+00, -.20526400E+00, -.11207100E+01, -.13151700E+01, 0.10701400E+01, -.24583900E+01, 0.14890100E+01, -.21330100E+01, -.41855100E+00, 0.39409700E+00, 0.49422000E+00, 0.11059500E+01, 0.35542600E+00, -.34316500E+01, 0.49182400E+00, 0.54790300E+00, 0.22203800E+01, -.37408200E+01, 0.27736100E+00, -.28831900E+00, 0.46075700E+00, -.26432800E+01, -.21457100E+01, -.21709600E+01, 0.17084300E+01, 0.19125000E+01, 0.22558400E+01, 0.25055900E+01, 0.35743200E+01, -.51297600E+00, 0.40854800E+01, 0.11896400E+01, 0.10269700E+01, -.32313400E+01, -.19943700E+01, -.16687800E+00, 0.17465700E+01, 0.57679000E+00, -.19667600E+01, 0.12703200E+01, -.13406400E+01, 0.99242000E+00, 0.20007400E-01, -.12967900E+01, -.74098400E+01, -.48257800E+01, -.23518700E+00, -.58955200E+00, -.74128300E-01, -.45363900E+00, -.11802400E+02, 0.53282100E+02, 0.27267400E+01, -.35237700E+02, -.21829100E+02, 0.17137200E+02, 0.44402200E+02, 0.87744200E+01, -.26336100E+02, -.53131000E+01, 0.33592200E+01, 0.18677100E+00, 0.30035700E+01, 0.12658000E+02, -.24614100E+01, 0.24642000E+01, 0.12090300E+02, 0.76070500E+00, 0.97933600E+01, -.16060700E+01, 0.16157400E+00, 0.15056200E+00, 0.12878900E+00, 0.42140400E+01, -.12404900E+01, -.10763900E+01, 0.25433700E+01, 0.56319200E+01, -.61702800E+01, -.10144700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.91599900E+01, 0.26654300E+01, 0.12497800E+01, 0.24939200E+01, -.87269900E+00, 0.37163900E+00, 0.19740500E+01, -.14348400E+01, -.31556300E+01, -.28677900E+01, -.93461800E+00, 0.24204300E+01, -.81712700E+01, -.33889400E+00, -.10367900E+02, -.22687600E+01, -.28286800E+01, 0.26699100E+01, -.34972300E+00, 0.19613300E+02, 0.16267000E+01, -.22278000E+01, -.16176900E+01, 0.35324300E+00, 0.31069100E+00, -.40356200E+00, 0.23450200E+00, 0.10193000E+01, 0.25392800E+00, 0.31398100E+01, 0.12797600E+01, 0.18423500E+02, -.75137700E+01, -.41835900E+00, -.29149000E+00, -.99368800E+00, -.27604700E+01, -.38663700E+00, -.30966400E+01, 0.27840500E+01, 0.34085500E+01, -.11637800E+01, -.10045000E+01, 0.15184300E+01, 0.16106400E+01, 0.73532700E+00, -.19403000E+01, 0.12947100E+01, 0.17262600E+01, 0.12049300E+00, 0.38001900E+01, -.76460000E+00, 0.98914200E+00, -.72479900E+00, -.11906900E+01, -.24183900E+01, -.32552100E+00, -.48740000E-01, -.55566700E+00, 0.62233900E+00, 0.48393800E+00, -.77328600E+00, -.50733900E+00, -.12257700E+01, 0.60687900E+00, -.29898400E+00, -.16052600E+01, -.79602000E+00, 0.14174500E+01, 0.12171100E+01, -.15330500E+01, -.20222100E+01, 0.21053000E+00, -.72010300E-01, -.11869800E+01, -.12401800E+01, 0.76392700E+00, 0.33578200E+00, 0.57575900E+00, 0.24874900E+01, 0.37159600E-01, -.23564700E-01, 0.41745000E-03, -.12789100E+00, 0.44554900E-01, 0.29121200E-02, 0.12515600E+00, -.26732000E+00, 0.11713600E+00, -.93171300E-01, -.88263300E-01, -.50545500E+00, 0.39830100E+00, 0.29700800E-01, 0.60610900E+00, -.96819600E+00, 0.62636800E+00, -.13318200E+00, 0.21665500E+01, 0.82037900E+00, -.29604300E+00, 0.84893600E+00, -.83357900E+00, 0.14901400E+01, 0.51514200E+00, -.54795200E+01, 0.83217100E+01, -.21201700E+01, 0.17313700E+01, -.15278100E+00, -.81794700E+00, 0.12276500E+01, 0.90298500E+00, -.28758300E+00, -.11996800E+01, 0.44059100E+00, -.38703600E+00, 0.23624500E+01, 0.92895300E-01, 0.31457000E+00, -.59452400E-01, 0.28635200E+00, -.14218300E+00, -.53835700E+00, 0.20645800E+00, 0.18243400E+00, 0.49933200E+00, 0.22334500E+01, -.14604800E+00, 0.16078100E+01, 0.84835400E-01, 0.40304500E+00, 0.50322700E+00, -.73341300E+00, 0.76433900E+00, -.10904200E+01, 0.73013200E-01, -.13451900E+01, -.15035800E+01, -.40785200E+01, -.26066600E+01, 0.80218900E+00, 0.41033000E+00, -.22906200E+01, 0.98347400E+00, -.61392900E+00, -.53780300E+00, -.26667800E-01, -.30798500E-01, 0.14098300E+00, -.11585900E+00, 0.26609600E+00, 0.76593800E+02, -.20140100E+02, 0.12495900E+02, 0.64123300E+01, -.46891700E+02, 0.24862900E+02, -.14815300E+02, 0.76272100E+01, -.28800200E+01, 0.11740600E+01, -.82064800E-01, -.15423500E+00, 0.69906000E+01, -.71620600E+00, -.26275700E+00, 0.63964000E+01, -.14639900E+00, -.77124700E+00, 0.22328000E+00, 0.44210900E-01, -.80530600E-01, -.61782700E+00, 0.12418000E+01, 0.95051200E+00, 0.39340900E+00, 0.36032600E+01, -.12492800E+01, -.91512600E+00, 0.34328000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.67940900E+01, -.30695100E+01, -.27882000E+01, -.20736400E+01, -.29139000E+00, -.43743700E+00, 0.15292000E+01, -.10968500E+01, -.56924800E+00, -.14649200E+01, -.43079700E+00, -.83545500E+00, -.18024800E+01, -.66933400E-01, -.25923600E+01, 0.43010000E+00, -.20064200E+00, -.58620900E+00, -.13359500E+01, -.64936000E+00, -.13430800E+01, -.13334200E+01, -.14958900E+01, 0.79011100E+00, -.55405000E-01, -.40537900E+00, 0.10916000E+01, 0.10568200E+01, -.17037800E+00, 0.54571700E+00, 0.23494300E+00, -.14572400E+01, 0.34510800E+01, 0.57251500E+00, -.11143400E-02, 0.97957500E-01, 0.16363300E+01, 0.57390300E+00, 0.17291900E+01, -.48867600E+00, -.52528600E+00, -.22629400E+00, 0.36247200E+00, 0.11641000E+01, 0.10959300E+01, 0.13716100E+00, -.32538300E+01, -.91555500E+00, 0.78518000E-01, 0.17620800E+00, 0.12295200E+02, -.32287800E+01, 0.10442500E+01, -.79103800E+00, 0.15634400E+02, 0.56678200E+00, 0.13399600E+00, 0.51277300E-01, -.31755200E+00, 0.28091100E-01, -.23860000E+00, 0.96534700E+00, -.53757000E-01, 0.15504600E+01, 0.20182500E+00, -.21721200E-01, 0.63791000E+01, 0.11704700E+00, -.27813400E+00, -.28716200E+00, -.16330900E+00, -.37750200E+00, -.18065600E+00, 0.79298600E-01, -.10441900E+00, -.31061600E+00, 0.71641300E-01, 0.12756000E+00, -.81207100E+00, -.60274100E+01, -.45612400E-01, 0.73338100E-02, 0.24477800E-01, 0.70668100E-01, 0.58564300E-02, -.21717300E-01, -.17390300E+00, 0.49542200E+00, -.15376800E+00, 0.66671000E-01, 0.12593300E+00, 0.18510500E+00, -.15179400E+00, -.83242300E-01, -.64188600E+00, 0.17306500E+01, -.12714100E+00, -.23900000E-01, -.14442200E+01, -.39268400E+00, -.15261800E+00, -.39178900E+00, -.21216700E+00, -.13271400E+01, -.11376100E+01, -.45656800E+01, 0.63721300E+01, 0.52046800E+00, 0.66433900E+00, 0.14094400E+00, -.26974200E+00, -.26198700E+01, -.17159500E+01, 0.10243400E+01, -.11199800E+01, -.16047400E+00, -.22612000E+00, -.20389200E+01, 0.18891100E+01, -.78502300E+00, -.23254500E+00, -.60730900E-01, 0.70078900E+00, 0.32419200E+00, -.13446300E+00, 0.65288900E-01, 0.99393600E+00, 0.15047500E+01, 0.24389200E+00, -.10868500E+01, 0.34845300E-01, 0.43772700E+00, 0.20920600E+00, -.86666200E+00, 0.14393800E+01, -.15975900E+01, -.92632000E-01, -.21048100E+00, 0.82036600E+00, -.10990700E+00, 0.10374800E+01, 0.29733200E-01, 0.16406300E-01, 0.58813500E+00, 0.15678900E+01, 0.35150400E+01, 0.27319400E+01, 0.10649100E+00, -.54043200E-01, 0.84767500E-01, -.10090600E+00, -.15539500E+00, 0.24847900E+00, 0.21292200E+02, 0.10143000E+02, 0.76497100E+01, -.14972500E+02, -.16883500E+01, -.45009700E+01, 0.84048400E+01, -.16165300E+01, 0.11840600E+01, 0.21220100E+00, 0.17317100E+00, 0.12719000E+01, -.58011500E+00, 0.41446800E+00, 0.15998000E+01, 0.56275000E+00, 0.41984200E+00, -.10527400E+01, 0.91527500E-01, 0.18237500E+00, 0.46231500E+00, 0.12611100E+01, 0.12322700E-01, -.92298200E-01, -.91234600E+00, 0.33264600E+01, -.24183100E+00, 0.64973100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18437700E+01, -.47132800E+00, -.36180000E+00, -.99606400E+00, 0.54687800E+00, -.80781800E+00, 0.34753000E+00, -.10134400E+01, -.89973900E+00, -.92234500E+00, 0.46668400E+00, -.11086500E+01, -.10901400E+01, -.10318300E-02, -.11133400E+01, -.67384900E+00, -.17094400E+00, -.37054600E+00, -.67632600E+00, 0.48050000E+01, 0.40996500E+00, -.21127600E+00, -.45997500E+00, 0.17311700E+00, -.10811800E+00, -.69243700E-01, 0.11401900E+00, 0.13821400E+00, 0.46790300E-01, -.18797100E+00, 0.30786000E+00, 0.68766200E+01, 0.28118600E-01, 0.79095100E-01, 0.18224500E-01, 0.56709000E+00, 0.92347100E+00, -.23838100E+00, -.48021300E+00, -.14294000E+00, 0.11130900E+00, -.40298300E-01, -.70693200E-01, -.14014900E+00, 0.12339200E+00, 0.82696400E-01, -.21956100E+00, 0.12939000E+00, 0.28606500E+00, -.91346200E-01, -.30298500E+00, -.20967900E+01, -.15659400E+00, -.34331300E-01, 0.95777100E+00, -.24449600E+00, -.44488200E-01, 0.56058000E-02, -.80234100E-01, 0.99655300E-01, 0.36059700E-01, -.32447700E-01, -.61790700E-01, -.54293600E-01, 0.25560200E+00, 0.19593200E+00, -.35230100E+00, -.10742100E+00, 0.60971000E-01, 0.45153100E+00, 0.19756300E+00, 0.37594600E+00, -.10051300E-01, 0.11207400E-01, -.33566500E-02, 0.13868800E+00, -.56924900E-01, -.11505900E+00, -.10630100E+00, 0.12685000E+00, -.20704400E-02, -.19283900E-02, 0.59488200E-02, -.11946100E-02, 0.19525800E-01, -.23596000E-02, 0.17583800E-01, -.14842200E-01, -.58658800E-02, -.30971300E-02, 0.53229400E-02, -.43907900E-02, 0.47907200E-01, -.81515000E-02, 0.31970700E-01, -.56416800E-01, 0.60731400E-01, -.44791400E-02, 0.80565700E-01, 0.12283100E-01, -.10149900E+00, 0.99331600E-01, 0.28040300E+00, 0.30764600E+00, 0.17927300E+00, 0.31669200E+00, 0.73532900E+00, -.35452300E+00, 0.28254100E+00, 0.11347100E-01, -.17785700E-01, 0.11066100E+01, 0.48716700E+00, -.22718200E+00, -.27300600E+00, 0.97441800E-01, 0.62389500E-01, 0.99605800E+00, -.36138800E-01, -.86238400E-01, 0.17146700E-01, 0.12337000E+00, 0.73038000E-01, 0.15188600E-01, 0.56870500E-01, -.32989700E-01, 0.11583700E+00, -.35092200E+00, 0.82887100E-01, -.18348600E+00, -.15073800E-01, -.18909300E+00, -.11824900E+00, 0.30617400E+00, -.30861900E+00, 0.63542900E+00, 0.13511600E-01, 0.17334600E+00, 0.50834400E-01, 0.41274800E+00, -.16619500E+00, -.84225400E-01, -.67154000E-01, 0.19819000E+00, -.35750500E+00, -.43372800E+00, -.51432100E+00, 0.79549800E-03, 0.84269500E-02, 0.22553400E-01, 0.20191400E-01, -.71781500E-01, -.75050200E-03, 0.17022600E+00, -.50334400E+01, -.28024000E+01, 0.69843000E+01, 0.25392300E+01, 0.19231300E+01, -.29080300E+01, 0.49137900E-01, -.36336300E-01, -.16080500E-01, 0.20714000E+00, 0.64647100E+00, 0.25010600E-01, 0.17278100E+00, 0.49847500E+00, -.34421000E-01, -.16179300E+00, 0.50705800E-01, -.10599700E-01, -.10009400E-01, -.12795100E+00, -.24607700E-01, -.15796500E+00, -.25605300E-01, 0.39095300E+00, -.15630200E+00, -.31130100E+00, -.15914400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23973900E+01, 0.52084000E+00, 0.74261600E+00, -.12870700E+01, -.26998400E-01, -.59994800E+00, -.18238100E+01, 0.20296900E+01, 0.60633500E-01, 0.10393100E+01, -.66353000E+00, 0.32658200E+00, 0.14792600E+01, 0.12006800E+00, 0.92951600E+00, -.10856900E+00, -.17642000E-01, 0.13235900E+01, 0.11425400E+01, -.27844700E+01, 0.11741100E+01, -.75848200E+00, 0.14827000E+00, 0.83880000E-01, 0.93484400E+00, -.11747500E+00, 0.38575800E-01, -.25808100E+00, 0.74210500E+00, -.51158900E+00, -.65755200E+00, -.38965900E+01, -.24241500E-01, -.24090100E+00, -.90941700E-01, 0.80399200E-01, -.34817200E-02, 0.11102200E+00, -.33769700E+00, -.23878400E-01, -.33992900E+00, 0.20971900E+00, 0.19437500E-01, -.19464800E+00, 0.85342400E+00, 0.25958100E-02, -.86502500E+00, -.84127500E+00, -.43310400E+00, 0.73234000E-01, -.36853600E+01, -.10744400E+01, -.30233500E+00, 0.55339900E-01, 0.10189700E+01, -.32143300E-01, 0.36887500E-02, 0.30349300E-01, 0.10182000E+00, 0.75298400E-01, -.99085200E-01, -.18791700E+00, -.33833100E-01, 0.36157300E+00, 0.79071900E+00, 0.19095200E+00, 0.11108600E+01, 0.16800400E+00, 0.11834900E+01, 0.63936500E+00, 0.41569000E+00, 0.84030900E-01, 0.27894500E-01, -.23253500E-02, -.13032600E+00, -.13360300E+00, -.15018600E+00, 0.21443500E+00, 0.29697200E-02, 0.67029200E-01, 0.83628700E-03, 0.30396000E-02, 0.63055000E-03, 0.10642500E-01, -.23284900E-01, 0.18635600E-02, -.66865300E-02, 0.28502400E-02, 0.55034900E-02, 0.56471400E-02, -.83470900E-02, 0.51794300E-01, -.11786200E+00, 0.56890000E-02, -.33564500E-01, 0.20405000E-01, -.99452900E-01, -.18103500E-01, -.22030700E-01, -.17754600E+00, -.20903000E-01, 0.88328500E-01, 0.15743200E+00, -.11903800E+00, 0.14912700E+00, 0.29798800E-01, 0.25275300E+00, -.16145600E-01, 0.15450700E+00, -.28470900E-01, 0.80449100E-01, -.59000300E+00, -.10341500E+00, -.43312000E-01, -.19391300E+00, 0.28173000E+00, 0.76598500E-01, 0.11465900E+01, -.11988300E+01, 0.61038700E-01, 0.15329200E+00, -.65772500E-01, -.13957700E+00, -.22039900E+00, 0.35907400E+00, -.37733800E-01, 0.19216700E+00, 0.15761500E+00, 0.94594000E+00, 0.46507000E+00, -.62930300E-01, -.16573400E+00, -.48266700E-01, -.30008300E+00, -.92880200E-01, -.75327000E+00, -.41692600E-01, -.57786500E+00, -.82508800E+00, -.10085800E+01, 0.48234800E+00, 0.23166800E+00, 0.34941000E-01, -.33121400E+00, 0.20654000E+00, 0.36153600E-01, -.56066800E+00, 0.25002400E-01, -.18141900E-01, -.10390200E-01, -.16945400E-01, 0.14430700E+00, 0.34589400E-01, 0.67111000E-02, -.10618900E+01, -.21881600E+01, 0.35661200E+01, 0.25590800E+01, 0.10565800E+01, -.33533800E+01, 0.25224100E+00, -.25800100E+00, -.97977700E-01, 0.77566000E-02, -.40292500E+00, -.95967600E-02, 0.11269500E-01, -.49977600E+00, -.21862700E+00, 0.27759400E+00, 0.40250900E+00, -.10638600E-01, -.10064200E+00, -.21259700E+00, -.37778900E+00, -.25110900E+00, -.22470700E+00, 0.14100900E+01, -.10689500E+01, -.82802300E+00, -.98701600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10531800E+02, -.22695500E+01, -.33780600E+00, -.22825300E+01, -.15471800E+01, -.25057100E+01, 0.29835700E+01, -.21413100E+01, -.72905000E+00, 0.11222200E+01, 0.54378300E+00, -.32975000E+00, 0.50705500E+01, 0.31242200E+00, 0.42919300E+01, -.31882700E+00, 0.48525700E+00, -.14247700E+01, 0.70359600E+00, -.61604300E+01, 0.85050500E+00, 0.73727900E+00, -.79155500E+00, 0.26189100E+00, -.10104900E+01, -.58154900E+00, 0.83754000E+00, 0.23862200E+01, -.16934900E+01, 0.79706700E+00, 0.62668500E+00, 0.89471000E+01, 0.63577200E+01, 0.81090200E+00, 0.13441800E+00, 0.74313200E+00, 0.18169600E+01, -.10325700E+01, -.24213500E+01, -.10146300E+01, -.25596100E+01, 0.49245200E+00, -.66874600E+00, 0.21266900E+00, -.24422100E+00, 0.86678200E-01, -.21034600E+00, 0.28104400E+00, 0.43518900E+00, 0.10159700E+01, -.55385300E+01, 0.10095000E+02, 0.11456600E+00, 0.45748500E+00, -.12939200E+01, 0.23681300E+00, -.23303900E-01, -.78885300E-02, 0.29044300E+00, -.12551600E+00, -.15902400E+00, -.39426600E+00, 0.23366300E+00, 0.74092400E+00, 0.18863400E+00, 0.48548500E+00, 0.52432100E+01, 0.57386000E+00, -.11810700E+00, 0.21218100E+00, 0.25761900E+01, 0.15712800E+01, -.22158900E+00, 0.13360800E+00, 0.16936300E+00, 0.40172400E+00, 0.61634800E-01, 0.57471000E+00, -.18232500E+00, -.30825000E+01, -.50077300E-01, -.83776100E-03, 0.27756700E-01, 0.11764500E+00, 0.13450600E+00, -.26221600E-01, 0.17831600E-01, 0.29161100E+00, -.15306000E+00, 0.49334500E-01, 0.20254000E+00, 0.58256000E+00, 0.11012000E-01, -.10382900E+00, -.17641200E+00, 0.11208200E+01, -.55300600E+00, -.25520600E+00, 0.20623900E+00, -.82170500E+00, 0.42255700E-01, 0.27587300E+00, 0.81058000E+00, -.22822200E+00, -.36329400E+00, 0.50899500E+00, 0.47789000E+01, -.57073900E+00, 0.32509400E+01, 0.31742400E+00, -.90447000E-01, 0.94866100E+00, 0.10120800E+00, -.13454700E+00, 0.54176100E+00, 0.55921200E-01, 0.20756400E+00, 0.14285100E+01, -.30917400E+01, -.11217300E+00, 0.26317700E+00, 0.15520900E+00, -.10258600E+00, -.26093000E+00, 0.38618200E+00, -.14471300E+00, 0.42077100E+00, -.88877300E+00, 0.24966700E+01, 0.32751800E+00, -.17445000E+00, -.43778200E+00, -.25409600E+00, -.50180200E+00, -.29326100E+00, -.21058000E-01, -.34087500E-01, -.93872600E+00, -.11514500E+01, 0.14633000E+00, 0.21642000E+01, 0.19132400E+00, 0.24602200E+00, -.54238500E+00, -.42317300E+00, -.13724900E+01, -.13471800E+01, -.10638600E+00, 0.18269200E+00, 0.13053500E-01, 0.41394000E-02, 0.11166600E+00, 0.38964200E+00, -.14140800E-01, 0.18476400E+01, 0.22732200E+01, -.12245000E+02, -.80401500E+01, 0.18056500E-01, -.73574200E+00, -.36575000E+00, -.54410000E+00, 0.16629300E-01, -.16062900E+00, -.45794200E+01, 0.44889600E+00, -.44060300E-01, -.38388300E+01, 0.11581500E+00, 0.22597200E+01, -.33729200E+00, 0.22016800E-01, 0.92954600E-02, 0.35759400E+00, -.62471000E+00, -.20148500E+00, -.56305300E+00, -.26150100E+01, 0.16554400E+01, 0.49784900E+00, 0.59313300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.97073900E+01, 0.30629300E+01, 0.27837600E+01, 0.19229100E+01, 0.15704400E+01, -.13205900E+00, -.98349300E+00, -.21317500E+00, 0.91357800E-01, -.24752700E+01, 0.15992200E+01, -.18448400E+01, -.81088300E+01, -.54020400E+00, -.49483300E-01, -.10176200E+01, 0.22371300E+00, 0.52098600E+00, -.14591800E+01, 0.11791500E+02, -.66454700E+00, -.29676300E+00, 0.18843000E+01, 0.61860400E+00, -.69625200E-01, 0.55292500E+00, -.18273400E+01, -.12878800E+01, 0.34555500E+01, -.24292300E+01, -.14934200E+01, 0.42405000E+01, 0.26908800E+00, -.22057400E+00, 0.50605900E-01, 0.15590000E+01, 0.87418100E+00, 0.84150300E-02, 0.23682200E+01, 0.80673000E+00, -.24185800E+00, 0.32273600E+00, 0.11826200E+00, 0.19438500E+00, -.28427000E+00, 0.45199500E+00, 0.98965200E+00, 0.41830700E+00, 0.87882300E+00, -.86904600E+00, -.11012900E+02, -.19000600E+02, -.19306100E+01, 0.41534400E+00, 0.13531700E+01, -.33474000E+00, 0.15436800E-02, -.13164900E-01, 0.60399100E-01, 0.21369900E+00, -.80915700E-01, -.86371500E+00, -.53882700E+00, -.15610300E+01, 0.24585700E+00, -.12773700E+01, -.18413600E+01, -.52053800E-01, -.67261300E+00, -.62810700E-01, -.69517000E+01, -.18934800E+01, -.16168800E-01, -.71099500E-01, -.24983800E+00, 0.71157500E+00, -.47269300E+00, -.30388600E+01, -.13181700E+01, -.44693300E+01, 0.16361100E-02, -.86916000E-03, 0.17191000E-01, -.10928500E+00, -.63988500E-01, -.89806200E-02, -.13740400E+00, 0.25987900E+00, -.97735800E-02, -.36447500E-02, -.12824900E+00, -.72732100E+00, -.37987400E-01, -.28922700E-01, -.40216600E+00, 0.68121700E+00, 0.15084100E+01, 0.65433500E+00, -.16133700E+01, -.76157200E+00, -.10222700E+01, 0.80720800E-01, 0.11633100E+01, -.19369700E+01, -.29687800E-02, 0.14439800E+01, -.26033000E+02, 0.31152700E+01, -.31007500E+01, 0.92821600E+00, -.11933200E+01, 0.16522600E+01, 0.17950500E+01, -.32132700E-01, -.15967800E+00, 0.39112100E+00, 0.28474600E+00, 0.12822100E+01, -.49369500E+01, -.12618900E+01, -.24309900E+00, 0.57215300E+00, -.10126500E+01, -.73201300E+00, -.61217800E+00, 0.51779300E+00, 0.15316900E+01, 0.35391800E+00, -.16940700E+01, -.20042600E+01, 0.27032100E+00, 0.81914600E+00, 0.19529700E+00, 0.12269000E+01, -.72588400E+00, 0.35104000E+00, -.97675800E-01, -.77359300E-01, 0.14702500E+01, 0.27419600E+01, 0.10275400E+01, -.57189600E+00, -.38207100E+00, 0.17113500E+01, -.12767300E+01, -.21787100E+01, -.11542300E+01, -.35626400E-01, -.18526100E+00, -.10154400E+00, 0.16078100E-01, -.57419500E-01, -.64164400E+00, 0.91342100E+00, 0.23532100E+01, 0.35763900E+00, -.61165100E+00, -.91406500E+01, -.15072600E+01, 0.33803600E+01, 0.18531700E+01, -.45106800E+01, -.28152900E+00, -.38919800E+00, -.58208500E+01, 0.29094100E+01, -.49210600E+00, -.56390100E+01, -.75739500E+00, 0.13535300E+01, 0.13329100E+01, -.95902600E-01, -.24447400E+00, -.17427300E+01, -.35433700E+01, -.63714100E+00, -.44708400E+00, -.10889300E+01, -.35552200E+01, 0.11717700E+01, 0.19857200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12799900E+02, 0.41215100E+01, 0.16691600E+01, 0.33759100E+01, -.71141000E+00, 0.32708100E+01, -.55519800E+01, 0.64507900E+01, 0.10333300E+01, -.96925900E+00, -.13464500E+01, 0.25300900E+01, -.65452200E+01, -.50180600E+00, -.54862400E+01, 0.29391700E+01, -.89320000E+00, 0.12341300E+01, -.45580100E+00, 0.70327300E+01, -.16979200E+01, -.69059500E+00, 0.46339500E+01, 0.11464100E+00, 0.18476000E+01, 0.66719800E+00, -.13091000E+01, -.23848300E+01, 0.43265400E+01, 0.58824600E+00, -.77583800E+00, -.26787900E+01, -.70334100E+01, -.92591100E+00, -.15361900E-01, -.82346100E+00, -.17288800E+01, 0.58140700E+00, 0.26528000E+01, 0.12070800E+01, 0.20704900E+01, -.16839400E+00, 0.64074600E+00, 0.11036500E+01, 0.35044600E+00, -.74065700E+00, -.48726900E+01, -.10018000E+01, -.16463700E+01, -.18880900E+01, -.31676600E+01, 0.22957100E+01, -.91831300E+00, -.79942000E+00, 0.60359400E+01, 0.27107800E-01, 0.36411900E+00, 0.19125300E-01, 0.29429800E-01, -.48663200E+00, -.21600400E+00, 0.33314600E+00, 0.12505400E+00, -.51320200E+00, -.26346700E+00, -.99267800E+00, 0.18066200E+00, -.52841600E+00, -.14901000E+01, -.10423700E+01, -.20933100E+01, -.21892200E+01, -.88063500E-01, 0.30924400E-01, 0.46577400E+00, 0.97239500E-01, -.19433300E+00, 0.27333500E-01, -.42226600E+00, -.35269200E+00, -.14639000E-01, 0.75387100E-02, 0.14999800E-01, 0.48566100E-01, -.51561500E-01, -.12356000E-02, -.11648900E+00, 0.57881700E-01, -.50281500E-01, 0.40370500E-01, 0.56282500E-01, 0.54374900E-01, -.10658600E+00, -.17342900E-02, -.31484500E+00, 0.13759300E+00, -.13204300E+00, -.14359100E+00, -.71733000E+00, -.15524200E+00, 0.12870700E+00, -.62205500E+00, -.96271600E+00, -.40665600E+00, -.43987600E+00, -.43061200E+01, 0.36877300E+01, 0.24373600E+00, -.20846700E+01, -.49669800E+00, 0.53103500E+00, -.28651100E+01, -.11449200E+01, -.91937300E-01, -.18392400E+01, -.52931300E+00, -.47706200E+00, -.21920100E+01, 0.55344000E+01, 0.79863200E+00, -.36044800E+00, 0.15718700E+00, 0.85826200E-01, 0.61736800E+00, -.14212800E+00, -.25691300E+00, -.17187700E+01, -.59432400E+00, 0.33918700E+00, -.52318600E+00, -.60431800E-01, 0.12982300E+00, -.56566400E-01, -.31682700E+00, -.24714300E+00, 0.47076800E+00, -.21347800E-01, 0.34488500E+00, -.10444600E+01, 0.41722000E+00, 0.11995400E+00, -.44772700E+00, 0.67782800E+00, -.81292700E+00, -.20416300E+01, 0.12885700E+00, 0.14274100E+01, 0.15362500E+00, -.78795100E-01, 0.17930700E+00, 0.39557100E+00, -.78090900E-01, -.33886200E-01, -.82948000E-01, -.11370000E+01, 0.20469100E-01, -.45083000E+00, -.77595700E+00, 0.21224500E+02, 0.62558800E+01, 0.16905600E+01, -.29343700E+01, -.11867400E+00, -.14554500E+01, -.54307900E+01, 0.15332000E+01, -.12162400E+01, -.51722000E+01, -.34771900E+00, 0.20334300E+01, 0.71332800E+00, -.12460200E-01, -.13336100E+00, -.72524900E+00, -.23242800E+01, 0.76557600E-01, -.12266300E+00, -.11215300E+01, -.17537400E+01, 0.90359100E+00, 0.15460700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.31758700E+01, 0.69063900E+00, 0.80103700E+00, 0.17510700E+01, -.91302700E+00, 0.11395300E+01, -.50523600E+00, 0.11033000E+01, -.21461000E-01, 0.50283900E+00, -.41621900E+00, -.17636500E+00, 0.14539500E+01, 0.96764800E-01, -.10717500E+01, -.12702800E+00, -.41078600E+00, 0.13475200E+01, 0.10927100E+01, -.69457300E+00, 0.19342900E+01, 0.10927200E+00, 0.91055100E+00, -.55314600E-02, 0.45171300E+00, -.14103900E+00, 0.53549200E-01, -.19557000E-01, 0.61782000E+00, -.21104900E+00, -.49888000E+00, 0.34466900E+00, -.22150200E+00, -.20740300E+00, -.19475200E-01, -.33650000E-01, -.41351700E+00, 0.11312900E+00, -.72197000E+00, 0.59220100E+00, 0.14397900E+00, 0.10510800E+00, 0.17980200E+00, -.33526300E+00, 0.25308400E+00, -.99726900E-01, -.32373200E+00, -.74704900E+00, -.47098000E+00, 0.38172700E-01, -.73886200E+01, -.17383800E+01, -.63233300E+00, 0.30464700E+00, 0.22399700E+01, 0.34677300E+00, 0.57464500E-01, 0.18634300E-01, 0.27723500E+00, -.11280000E+00, -.26287600E+00, 0.70479400E-01, -.46660800E-01, 0.35577300E+00, 0.23203500E+00, 0.23206300E-01, 0.15591500E+01, 0.39397500E+00, 0.80998000E+00, 0.80202400E+00, -.42266400E+00, -.48205700E+00, 0.71139700E-01, -.25450900E-01, -.19521200E+00, -.59752300E-01, -.24641400E+00, 0.47122400E-01, -.19085900E-01, 0.44531400E+00, 0.11932800E-01, 0.11119400E-02, -.19448900E-02, -.19419000E-01, -.37603300E-01, 0.42410700E-02, 0.11945900E-01, -.42713300E-01, 0.40287500E-01, -.10923800E-01, -.48324300E-01, -.90373900E-01, -.50307700E-01, 0.18087600E-01, 0.69316900E-01, -.16060500E+00, 0.18674600E+00, 0.49336700E-01, 0.19800000E+00, 0.56003400E-01, -.36013100E-01, 0.82118000E-01, 0.30632800E+00, -.33074300E+00, 0.23526600E+00, 0.92009700E+00, -.10796500E+01, -.30498300E+00, -.17899700E+00, -.12066800E+00, 0.14314700E+00, 0.56598700E+00, 0.52258500E+00, -.97031400E-01, -.28103900E+00, -.24573500E-01, 0.70815400E-01, 0.53912300E+00, -.14720500E+01, -.12022900E+00, 0.19632900E-01, 0.14946300E+00, -.23528900E+00, -.14429500E+00, 0.46685200E-01, 0.80228800E-01, 0.38074800E+00, 0.23114700E+00, -.59619700E-01, -.12050600E+00, 0.12621900E-01, 0.92832900E-01, 0.15413600E-01, 0.27220700E+00, -.45877800E+00, 0.57362100E+00, -.67124300E-02, -.83496900E-03, -.18524300E+00, 0.57670600E-01, 0.21019800E-02, -.81463700E-01, 0.67202400E-01, 0.50728300E-01, -.37885700E+00, -.57611800E+00, -.20774400E+00, 0.19358000E-01, -.43979100E-01, 0.23042300E-01, 0.16609900E-01, 0.15726500E-01, -.29769100E-01, -.14175700E-01, -.23031200E+00, -.20637300E+00, -.89436000E-01, -.19553900E-01, 0.59288300E-01, -.20100100E+01, 0.35387400E-01, -.55470400E-01, -.19384000E-01, 0.23668600E-01, -.19018100E-01, -.49760500E-01, 0.50540800E-01, -.38560900E-01, -.43487300E-01, -.24331600E-01, 0.83272600E-01, -.69076000E-03, -.20760200E-01, 0.29681400E-01, -.10103600E+00, -.13881900E+00, -.85655200E-02, 0.27074900E+00, -.25551100E+00, -.11369500E+00, 0.36337700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.69858500E+01, -.25284800E+01, -.12465600E+01, -.24698500E+01, 0.49310300E+00, -.83278400E+00, -.73092400E+00, 0.63581400E+00, 0.27624100E+00, -.95956600E+00, 0.76355300E+00, -.73757200E+00, -.10634700E+01, -.30367500E-01, -.38565000E+00, 0.10144600E+01, 0.15302000E+00, -.22021500E+01, -.20778100E+01, 0.56593600E+00, -.22627800E+01, 0.31348900E+00, 0.16952900E+01, 0.52787300E+00, -.60275700E+00, -.59218900E-01, -.24412500E+00, 0.67065500E+00, -.38984400E-01, -.40412700E+00, -.10037500E+00, -.12019500E+01, 0.49502900E+01, 0.52239700E+00, 0.20283300E+00, 0.76292700E+00, 0.22195300E+01, 0.72850200E-02, 0.18198500E+01, -.17257300E+01, -.31774000E+01, 0.83106700E+00, -.24820100E+00, 0.14364800E+01, 0.82909700E-01, -.88092200E-01, -.24472000E+01, 0.87059900E+00, 0.89489900E+00, 0.77801800E-01, -.12526100E+02, 0.15541300E+02, -.18721900E+01, 0.94547200E-01, -.80436800E+01, 0.61268300E+00, 0.30581500E+00, 0.12845300E-01, 0.49856900E+00, -.58807800E+00, -.14901300E+00, -.14097700E+01, 0.53712200E+00, -.91159700E+00, -.40222000E+00, -.42898900E+00, -.30137900E+00, 0.60139100E+00, -.11234700E+01, -.12372000E+01, 0.14963600E+01, 0.73255800E+00, -.16603200E+00, 0.60575400E-01, 0.51335300E+00, 0.73093300E+00, -.67517600E+00, 0.40247100E+00, -.73254300E-01, 0.16289400E+01, -.26131300E-01, 0.17115800E-01, -.30564500E-01, 0.11670100E+00, -.78094800E-01, -.12271700E-02, -.12951800E+00, -.56029900E-01, -.70363000E-01, 0.62534800E-01, -.55766200E-01, 0.57136800E+00, -.64621000E+00, -.13938400E-01, -.54968100E+00, -.83245200E-01, -.47879200E+00, -.57377600E-01, -.70716500E+00, 0.10377200E+01, -.25566100E-02, -.49869300E+00, -.50798100E+00, -.59141000E+00, 0.40102100E+00, -.17370900E+01, -.42950400E+01, 0.97636500E+00, -.23464500E+01, -.39745300E+00, 0.30068800E+00, -.14107900E+01, -.48737300E+00, -.27047600E+00, 0.29165300E+00, -.55894000E+00, -.28478000E+00, -.16146000E+01, -.35926300E+00, 0.60622800E+00, 0.32260900E+00, -.11507900E+01, 0.60993500E+00, 0.41096300E+00, 0.77527200E+00, -.35968300E+00, 0.12506700E+00, -.49649300E+00, -.31326700E+00, -.17643600E+01, 0.19003600E-02, -.10315600E+01, -.62663900E+00, -.90818200E-01, -.85352700E+00, -.68246600E-01, -.97121500E-02, 0.31494800E+00, -.12290700E+00, 0.15641100E+01, -.20716200E+00, 0.11953300E+00, -.39435300E+00, 0.13396900E+01, -.67953600E+00, 0.23937700E+01, 0.50310900E+00, 0.14790600E+00, 0.14698200E+00, 0.13279400E+00, 0.24469200E+00, -.14730100E-01, -.25224300E+00, 0.15804100E-01, 0.56152600E+00, 0.42935000E+00, -.15988800E+00, -.70479400E+00, 0.22829200E+00, -.13846200E+01, 0.15318200E+01, -.23421400E+01, -.11593200E+00, -.50524700E+00, -.26094400E+01, 0.14031100E+01, -.57370500E+00, -.26701200E+01, -.38302700E+00, -.14915200E+01, 0.68795400E+00, -.78334700E-01, -.80711100E-01, -.65110300E+00, -.19505400E+01, -.17792400E+00, 0.18700500E+00, -.22170500E+01, -.21755500E+01, 0.29571100E+01, 0.19016700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43239400E+01, -.57752500E+00, -.73621600E+00, -.14651900E+01, 0.10442500E+01, -.11130100E+01, 0.13205900E+01, -.13866100E+01, 0.14996900E+01, 0.19838700E+01, 0.10980600E+01, -.24204600E+01, 0.75660300E+01, 0.51742600E+00, 0.63299100E+01, -.10965000E+01, 0.12030200E+01, 0.21648700E+00, 0.13029100E+01, -.11573200E+02, 0.16648500E+01, 0.24842000E+01, 0.18753200E+01, -.22326600E+00, -.56102200E+00, -.22348400E+00, 0.37156100E+00, 0.98959500E+00, -.14212100E+01, -.25837400E+00, -.37182700E+00, -.30853500E+01, 0.64130700E+01, 0.54252700E+00, 0.71770000E-01, 0.55369400E+00, 0.73699400E+00, -.43211700E+00, -.14804600E+01, -.56221800E+00, -.18431000E+01, 0.28010300E+00, -.12343800E-01, -.75343900E+00, -.16064000E+01, -.22525100E+00, 0.29139600E+01, -.16191600E+00, -.22640300E-01, 0.71990500E+00, -.23420700E+01, 0.15782700E+01, -.66478800E+00, 0.99339700E+00, -.32036800E+01, 0.79353000E+00, -.37608200E-02, -.99273500E-02, 0.11191500E+00, -.19045100E+00, -.40485100E-02, 0.17757300E+00, 0.15202500E+00, 0.55096800E+00, 0.68138100E-01, -.98867500E-02, 0.17940700E+01, 0.65176800E-01, -.85523800E+00, -.32256900E+00, 0.63174200E+00, 0.48380600E+00, -.78727600E-01, 0.16913800E-01, 0.53566800E+00, 0.40609700E+00, -.60857300E-01, 0.66975000E-01, -.16253700E+00, -.16839800E+01, -.99629800E-02, 0.69571400E-02, 0.66486000E-03, 0.40047900E-01, -.20402000E-01, -.20972400E-02, -.79158600E-01, 0.15972700E+00, -.35599000E-01, 0.30982200E-01, 0.76125500E-01, 0.16351500E+00, -.95169700E-01, -.12769400E-01, -.28861200E+00, 0.58355900E+00, -.23333400E+00, 0.77885900E-01, -.74380100E+00, 0.59719600E-01, 0.32745700E+00, -.35592200E+00, -.17857300E+00, -.60439500E+00, -.25023500E+00, 0.71154700E+00, 0.63982900E+00, 0.15932100E+01, -.15735100E+01, 0.17060500E+00, 0.50057900E+00, -.13307100E+01, -.91677900E+00, -.24071900E+00, 0.42911200E+00, -.42250000E+00, -.37804400E-02, -.11954400E+01, 0.13550200E+01, 0.92179900E-01, -.68662700E-01, -.30104400E+00, -.32393400E+00, 0.14584100E+00, -.52884700E+00, 0.26608300E+00, -.75220500E-01, -.10249200E+00, 0.36568700E+00, -.21516900E+00, -.62062000E-01, 0.78417100E+00, 0.15140200E+00, -.17973900E+00, 0.26315100E+00, 0.25693400E+00, 0.95306300E-02, 0.55883100E+00, 0.61609200E+00, 0.69384400E+00, -.50865800E+00, -.33709800E+00, 0.32774300E+00, -.29925100E-01, -.11708000E+00, 0.59992200E+00, 0.30519300E+00, 0.25278100E-01, 0.80313200E-01, -.38480300E-02, -.17448800E+00, -.12720500E-01, 0.28502600E+00, -.46808500E+00, -.71955100E+00, 0.13461400E-01, 0.40874200E+00, -.37878500E+00, -.17261000E+00, -.18133900E+00, -.38840300E+00, -.20074700E+01, 0.53172200E-01, 0.65855000E-01, -.17614200E+01, 0.15452300E+01, 0.11751000E+00, -.16473200E+01, 0.99406300E-01, -.87325500E+00, -.26762800E+00, -.21826000E-01, 0.78591200E-01, -.74805300E+00, -.94471400E+00, -.20795600E+00, 0.80454000E-01, -.21143000E+01, 0.88511400E+00, 0.15819600E+01, -.25800000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.32013100E+00, 0.17347500E+00, 0.57899100E-01, 0.57764200E-01, -.45917600E-01, 0.11625100E+00, -.20651600E+00, 0.21859500E+00, 0.67961400E-01, -.13133600E-01, -.47326000E-01, 0.66925700E-01, -.19807100E+00, -.14689500E-01, -.20491200E+00, 0.60171300E-01, -.31519700E-01, 0.11232100E+00, 0.25208200E-01, 0.22806100E-01, -.18120100E-01, 0.51314800E-02, 0.22574900E+00, -.19451000E-02, 0.51405400E-01, 0.29579400E-01, -.67232000E-01, -.81760000E-01, 0.14166100E+00, -.15441900E-01, -.40300500E-01, -.23830800E-01, -.29078100E+00, -.44565800E-01, -.31423800E-03, -.22536100E-01, -.74227000E-01, 0.22354900E-01, 0.81796900E-01, 0.48995800E-01, 0.56977500E-01, 0.24286300E-02, 0.10775800E-01, 0.14194800E-01, 0.24073600E-02, -.12045400E-01, -.40912400E-01, -.21226900E-01, -.50962300E-01, -.42565200E-01, -.25382300E+00, -.19884400E-01, -.31588900E-01, -.75223000E-02, -.85312300E-01, 0.32763900E-02, 0.80828100E-02, -.20399600E-03, 0.92742700E-02, -.12720800E-01, -.47671800E-02, -.10752000E-01, 0.26770100E-02, -.38050500E-01, -.20657800E-01, -.33759600E-01, -.12999000E+00, -.66373000E-02, -.14677000E-01, -.11015000E-01, -.12594100E+00, -.79955700E-01, 0.39269300E-02, -.17737900E-02, 0.11461100E-01, -.42849100E-03, -.11998000E-01, -.26714200E-01, 0.15048900E-03, 0.97391300E-01, 0.97964100E-03, 0.10144100E-03, 0.11348200E-02, -.23355400E-02, -.37746300E-02, 0.48374700E-03, 0.55043200E-03, -.87875600E-02, 0.29292100E-02, -.79860400E-03, -.10570100E-02, -.17859800E-01, 0.42126900E-02, 0.20912200E-02, 0.99003400E-02, -.37214100E-01, 0.18643900E-01, 0.56052200E-02, -.32202100E-02, -.10039400E-01, 0.37471900E-02, -.23366200E-02, 0.42984300E-02, 0.44627800E-02, -.21193300E-04, 0.46397900E-01, 0.11052800E-01, 0.10844800E-01, -.89052600E-01, -.15472000E-01, 0.20063300E-01, -.57853500E-01, -.20396000E-01, -.28992200E-02, -.12538100E-01, 0.93229500E-02, -.67727600E-02, -.12417500E-01, 0.60341900E-01, 0.22271500E-01, -.31859100E-02, -.10793100E-01, 0.12281400E-01, 0.17590600E-01, -.34959400E-02, -.31521200E-02, -.18722400E-01, 0.14981400E-01, -.47790000E-01, 0.22892800E-01, 0.32443900E-02, 0.11303300E-01, 0.94870000E-02, -.64225300E-03, 0.10891800E-01, 0.41875900E-02, 0.18335000E-02, 0.88505800E-02, -.24448600E-01, -.43980100E-01, -.48157800E-01, -.62554100E-02, -.74152200E-02, -.21822500E-01, -.43801400E-02, 0.16393200E-01, 0.18846200E-01, 0.16551800E-02, -.13492200E-02, 0.38273900E-03, 0.31434800E-02, -.12889300E-02, -.21589700E-02, 0.62017000E-03, -.24884600E-01, -.21215400E-01, -.12498600E-01, -.56151200E-02, 0.60132500E-02, 0.21630200E-03, 0.26228400E-01, -.28553500E-01, 0.59234600E-01, -.13700700E-02, 0.72868900E-02, 0.30766300E-02, 0.73090000E-03, 0.14224800E-01, 0.14115200E-01, 0.28515400E-01, -.21968200E-01, 0.15957600E-02, 0.61082500E-02, 0.16601500E-02, 0.19978100E-01, 0.95586200E-02, 0.17065400E-01, 0.89104300E-02, 0.57864900E-01, -.43269300E-01, -.54677200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16573800E+01, -.44231600E+00, 0.26131800E+00, -.44802300E+00, -.33625000E+00, -.10289500E+01, -.18722600E-01, -.64303200E+00, -.39440800E+00, 0.89983200E+00, 0.11513300E+00, -.74574400E+00, 0.27416300E+01, 0.18451500E+00, 0.23878800E+01, -.49705900E+00, 0.23397900E+00, -.18001100E+00, 0.50216800E+00, 0.69779500E+01, 0.10148200E+01, -.23740200E+00, -.14638900E+01, -.22315400E+00, 0.15649700E+00, 0.66648000E-01, 0.27581500E-01, 0.15266600E+00, -.60009700E+00, -.44041400E+00, -.12213700E+00, 0.68836500E+00, 0.26506000E+00, -.88515900E-02, -.40521200E-01, 0.29469000E+00, 0.10939600E+00, -.17844000E+00, -.54596100E+00, -.17501400E-01, -.28951300E+00, -.77220400E-01, -.19166700E+00, -.10861200E+00, 0.19670900E+00, -.30407400E-01, 0.49183800E+00, 0.66401300E-01, 0.30487600E+00, 0.40476700E+00, -.79253800E+00, 0.90394900E+00, -.95774100E-01, 0.90122400E-01, -.12695900E+01, -.37245200E+00, -.51021000E-01, 0.41061900E-02, -.76076800E-01, 0.13824900E+00, 0.97523100E-01, 0.58516200E-01, -.27109300E-01, -.12537400E+00, 0.18135800E+00, 0.27169700E+00, -.15932300E+01, -.56377000E+00, 0.41086000E+00, 0.17778400E+00, 0.15158600E+00, -.71151600E-01, 0.52255700E-01, -.25300700E-01, -.28820400E+00, -.41033700E+00, 0.24939800E+00, 0.14639100E+00, 0.24142800E+00, 0.58290100E+00, 0.84753600E-02, -.20443300E-02, -.19570500E-01, -.32839000E-01, 0.16529600E-01, 0.51000200E-02, 0.24720300E-01, -.62613500E-01, 0.26594000E-01, -.11379000E-01, -.63812700E-01, -.10965200E+00, 0.84609700E-01, 0.19442700E-01, 0.11148800E+00, -.21830900E+00, 0.18289600E-01, 0.13957100E-01, 0.75955300E-01, 0.74898200E-01, -.12965900E-01, -.42114900E-01, -.15518100E+00, 0.21628800E+00, 0.85659500E-01, 0.17436800E+00, -.10656800E+01, -.27402300E+00, 0.14130700E+01, 0.16385200E+00, -.31708500E+00, 0.47330200E+00, 0.57578900E-01, 0.11686800E+00, 0.39747500E+00, -.12330700E+00, 0.52290100E-02, 0.34212000E-01, -.80146400E+00, -.12770600E+00, 0.18627700E-01, -.78312500E-02, 0.92103200E-01, 0.87711100E-01, 0.98653100E-01, -.41634000E-01, -.15689600E+00, -.16801800E+00, -.12025300E+00, -.43491600E-01, 0.32146700E-01, -.43955800E+00, -.15360200E+00, 0.69898200E-01, 0.34006600E+00, 0.37795100E+00, 0.35245200E-02, -.78527600E-01, 0.18328900E+00, 0.59292500E+00, -.23350800E-01, 0.11260000E+00, -.13066100E+00, 0.36804600E+00, 0.66948300E-01, 0.24662800E+00, 0.24928300E+00, 0.21553600E-01, 0.36958800E-01, 0.29426000E-01, 0.93534400E-02, -.81070300E-01, -.26376400E-01, 0.18190700E-01, 0.27823200E+00, 0.10898400E+00, 0.48858300E-01, 0.79665200E-01, -.19679200E-01, 0.19129400E+00, -.12635200E+00, -.63343200E-02, 0.12530000E+00, 0.57403800E+00, 0.23420400E+00, 0.51273800E-01, 0.26537100E+00, 0.14740900E+00, 0.86006300E-02, -.70452400E+00, -.34817500E-01, -.13389300E-01, 0.15902300E-01, 0.56499500E-01, -.34502400E-02, 0.11738400E-01, 0.52558200E-01, -.70199600E+00, 0.23946100E-02, 0.82689900E+00, -.57539600E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23362400E+02, -.92582000E+01, -.37945200E+01, -.60405000E+01, 0.29341600E+01, -.63066100E+01, 0.94046600E+01, -.10730900E+02, 0.31236000E+01, 0.49555800E+01, 0.36259600E+01, -.44480100E+01, 0.15083700E+02, 0.81758900E+00, 0.20545500E+02, 0.51464300E-01, 0.47134200E+01, -.51238600E+01, -.82376000E+00, -.31856700E+02, -.24157200E+01, 0.30944500E+01, -.96833900E+01, 0.11259800E+00, -.52032100E+01, -.80661900E+00, 0.28992800E+01, 0.55789200E+01, -.82756900E+01, 0.13694400E+00, 0.68631700E+00, -.17177000E+02, 0.25695600E+02, 0.33423200E+01, 0.25110300E+00, 0.19295600E+01, 0.58419900E+01, -.12033300E+01, -.99233200E+00, -.58971500E+01, -.43913800E+01, 0.45830100E+00, -.47940300E+00, -.14744500E-01, -.67230300E+00, 0.47485000E+00, 0.30449800E+01, 0.13924100E+00, 0.28102400E+01, 0.18429000E+01, 0.52191500E+01, -.21645800E+02, -.37888200E+01, 0.15655500E+01, 0.17061100E+02, -.17498200E+00, -.95216000E-01, 0.42821600E-01, -.13397200E+01, -.82110800E-01, 0.45836100E+00, -.72492600E+00, -.30551600E+00, 0.47847900E-01, 0.19497400E+01, 0.82660900E+00, 0.23876600E+01, -.27352900E+01, -.48462500E+01, 0.89099300E+00, -.85588600E+00, 0.57961500E+00, -.47935900E+00, 0.49950900E-01, 0.11011100E+01, 0.24578600E+01, -.42546300E+00, -.10756400E+01, -.16461400E+01, -.76084300E+01, -.62180900E-01, 0.16768500E-01, -.94489500E-01, 0.17467500E+00, -.37287300E-01, -.32035500E-01, -.52261300E+00, 0.69118700E+00, -.19073300E+00, 0.12308500E+00, -.13655400E-01, 0.93741000E+00, -.10219900E+01, -.12501800E+00, -.20146400E+01, 0.27042700E+01, -.41776700E+00, 0.58937400E+00, -.37154800E+01, 0.21466600E+01, -.40681400E+00, -.88473000E+00, -.26233500E+01, -.48158500E+01, 0.22644400E+01, -.68801100E+01, -.38844300E+02, 0.52098100E+01, 0.48743800E+01, 0.15508400E+01, -.66020800E+00, 0.10302900E+01, 0.14663800E+01, -.34446700E+01, -.56102000E+01, -.34732500E+01, -.75273900E+00, -.25244400E+01, 0.52289900E+01, 0.69153300E+00, -.26002900E+00, -.74523900E+00, 0.27035100E+01, 0.20249000E+01, -.37642700E+00, -.10331000E+01, 0.30448700E+00, -.46704600E+01, -.28446000E+01, -.81761500E+01, 0.21083600E+00, -.33628000E+01, -.20364400E+01, 0.32111200E+01, -.51035800E+01, 0.61848300E+01, 0.11024800E+00, 0.22631000E+01, -.66202400E+00, 0.82342600E+01, -.14164700E+01, 0.77012800E-01, -.24153900E+01, 0.67406900E+01, -.43571500E+01, 0.50698900E+01, 0.18016300E+01, 0.89197600E+00, 0.23069700E+00, 0.97691800E+00, 0.13253900E+01, -.60826400E+00, -.20621500E+01, -.49872500E-01, -.17698000E+00, 0.67312800E-01, -.11287400E+01, -.15937400E+00, 0.16587800E+01, 0.40810300E+01, -.21244400E+00, -.21846100E+01, 0.11798800E+02, -.18399800E+01, 0.12103300E+02, 0.89882500E+00, -.28046800E+00, 0.95940800E+01, 0.11733100E+01, -.17575700E+02, -.21971100E+01, -.11933000E+00, 0.75960600E+00, 0.11803300E+01, 0.20831000E+01, 0.15506300E+01, 0.26773100E+01, -.11672300E+02, 0.38866700E+01, 0.16534600E+02, -.28775200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18769500E+01, -.89831100E+00, -.87486700E+00, 0.10422300E+01, -.10673900E+00, 0.63460300E+00, 0.37707600E+00, -.54102800E+00, 0.17038500E+00, -.56631600E+00, 0.40385100E+00, -.25270900E+00, -.15951100E+01, -.12985200E+00, 0.20923300E+00, 0.35378300E+00, 0.21373400E+00, -.56282300E+00, -.50753800E+00, 0.39676100E+01, -.56073100E+00, -.68887100E+00, -.38181800E+00, 0.21982300E+00, 0.17822500E-01, 0.13412500E+00, -.21947200E+00, 0.15372600E+00, 0.15792700E+00, -.27278500E+00, 0.12244600E+00, 0.22411700E+01, -.18424500E+01, -.12804200E+00, -.86563800E-02, 0.47639700E+00, -.12632600E+00, 0.12556500E+00, 0.80587500E+00, 0.66856900E+00, 0.70918000E+00, -.12253200E+00, 0.15281100E+00, -.10983200E+00, -.28392900E+00, 0.67834200E-01, 0.19535900E+00, 0.31851500E+00, 0.17166900E+00, -.22960900E+00, -.67036200E+00, -.21617600E+01, 0.20555600E+00, -.68672500E-02, -.92428500E+00, 0.20642300E+00, 0.14112100E-01, -.97882100E-02, 0.13660500E+00, -.43187100E-01, -.73769200E-01, -.25072000E+00, -.64762900E-01, -.20059500E+00, 0.22414500E+00, -.21266200E+00, 0.15698900E+00, -.21571800E-01, -.19231600E-01, 0.42922800E-01, -.83351100E+00, -.29675600E+00, 0.12849300E-01, -.16218700E-01, -.10982200E+00, -.25492000E-01, 0.27174500E-01, -.31856400E+00, -.13984600E+00, -.82230300E+00, 0.28520300E-02, -.17706800E-02, -.50291700E-04, -.22751200E-01, -.90932700E-02, -.19943800E-02, -.26470700E-01, 0.48094700E-01, 0.59119800E-02, -.57769800E-02, -.19399400E-01, -.12503100E+00, 0.84428500E-02, -.57090900E-02, -.66235200E-01, 0.14008400E+00, 0.21470200E+00, 0.81570500E-01, 0.13290600E+00, -.36481000E-01, -.10641200E+00, -.13000900E-02, 0.19225100E+00, -.30354200E-01, -.66421400E-01, 0.35301100E+00, -.20382500E+01, 0.26776400E+00, 0.20666300E+00, 0.20237600E+00, -.22221100E+00, 0.17879800E+00, 0.77839400E-01, 0.10977600E+00, 0.27639800E-01, 0.87243200E-01, 0.48549200E-01, 0.97074500E-01, -.11618000E+01, -.23134700E+00, -.18985100E-01, 0.45290200E-01, -.28523500E+00, -.20604500E+00, -.23402600E-01, 0.41485300E-01, 0.21337500E+00, 0.12313000E+00, -.88567000E-01, -.44068700E+00, 0.33252400E-01, 0.64348000E-01, -.28924200E-01, 0.17260000E+00, -.14333600E+00, -.24853400E-01, -.17032900E-01, -.71848300E-01, 0.21430700E+00, 0.23558400E+00, 0.35244700E+00, 0.16941400E-01, -.13896800E+00, 0.25620600E+00, 0.45332200E-01, -.15452300E+00, -.10875000E+00, -.13139800E-02, -.36103500E-01, -.18334500E-01, 0.13963300E-01, -.12860100E-01, -.13968600E+00, 0.10997300E+00, 0.17211800E+00, -.52952500E-01, -.11231100E+00, 0.13473000E+00, -.21461100E-02, -.27434400E-01, 0.48903400E-01, -.98398600E-01, -.25337800E+00, 0.50021500E-01, 0.68103700E-02, 0.25823200E+00, 0.21488400E-01, 0.12378800E-01, -.33658000E-01, 0.38675200E+00, 0.58973400E-01, 0.16286900E-02, -.20226100E-01, -.15196900E+00, -.64492800E-01, -.46115000E-01, -.80466400E-01, 0.32018700E+00, -.12370000E+00, -.40021100E+00, 0.11433500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.21968300E+01, -.39216900E+00, 0.28138000E+00, -.31536000E+00, 0.16802800E+00, -.94044100E+00, 0.32763300E+00, -.46888900E+00, -.29792000E+00, 0.77364700E+00, -.25889600E-01, -.41427500E+00, 0.24548800E+01, 0.13282100E+00, 0.19822600E+01, 0.33894900E+00, 0.26220500E+00, -.65139400E+00, 0.35589200E+00, 0.23324700E+01, 0.33723800E+00, -.57552100E+00, -.56158900E+00, 0.20552100E+00, 0.18609600E+00, -.18143100E+00, 0.34864200E+00, 0.69699400E+00, -.81865800E+00, -.11693500E+00, -.13944600E+00, -.22212900E+01, 0.21116100E+01, 0.15238000E+00, -.32228100E-01, 0.23446200E+00, 0.41619100E+00, -.72121100E-02, -.16544200E+00, -.33798900E+00, -.57810300E+00, 0.55403100E-01, -.24469700E+00, -.26154300E+00, 0.88888700E-01, 0.12567800E+00, 0.73236700E+00, -.59956800E-01, 0.17028500E+00, 0.53630200E+00, 0.12915800E+01, 0.85917900E+00, 0.43553500E-01, 0.13385600E+00, 0.14593200E+00, 0.18161800E+00, -.65313200E-02, 0.56081700E-02, -.26055300E-01, 0.48495100E-01, 0.11325500E-01, 0.64529000E-01, 0.41158700E-02, 0.81567200E-01, 0.15556900E+00, 0.14360800E+00, 0.48403500E+00, 0.77713700E-01, 0.10870600E+00, 0.20937500E+00, 0.76621600E+00, 0.37308800E+00, 0.23227500E-01, -.12364600E-01, -.21497900E+00, -.20761000E+00, 0.23316000E+00, 0.23940900E+00, 0.30350200E+00, 0.17457800E+00, 0.35687000E-02, -.20651700E-02, -.20667900E-01, -.64755600E-02, 0.25025900E-01, 0.27322300E-02, 0.30260200E-01, -.14460600E-01, 0.12758100E-01, -.96787200E-02, -.57070100E-01, 0.34488600E-01, 0.35946000E-01, 0.85959800E-02, 0.87734900E-01, -.86351400E-02, -.11255100E+00, -.24130700E-02, 0.11269400E+00, 0.11732100E+00, -.63091700E-01, 0.72625200E-01, 0.40692400E-01, 0.14036200E+00, 0.17927900E+00, -.28417200E+00, 0.84828000E-01, -.58518900E+00, 0.38426900E+00, -.43201000E-01, -.43408600E-02, 0.70159800E+00, 0.30013800E+00, -.83034800E-01, -.51602200E-01, -.13235300E-01, 0.26463700E-01, 0.35054600E+00, -.71931200E+00, -.14948300E+00, 0.68098100E-01, 0.56708600E-01, 0.12442100E+00, 0.71137100E-01, 0.21700600E+00, -.11882800E+00, 0.11974600E+00, -.17549900E+00, -.17850400E+00, -.59046200E+00, 0.41250600E-01, -.39486900E+00, -.15817500E+00, 0.15084100E+00, 0.86670000E-01, 0.32533400E+00, -.24695700E-02, -.37122700E-01, 0.24435600E+00, 0.70972100E+00, 0.10632600E+00, 0.74074500E-01, -.11181400E+00, 0.43953600E+00, -.31111100E-02, 0.24620900E+00, 0.28546500E+00, 0.15592800E-01, 0.33502000E-01, 0.24181400E-01, 0.14925800E-02, -.83817800E-01, -.26378700E-01, 0.22754400E-01, 0.26366900E+00, 0.73827100E-01, 0.39191300E-01, 0.10345900E+00, -.37980700E-01, 0.22088200E+00, -.15799700E+00, 0.27332300E-01, 0.59444600E-01, 0.49862700E+00, 0.58062300E-02, 0.32315300E-01, 0.22620600E+00, -.21758500E-01, -.67063300E-02, -.15407900E+00, 0.16391000E-02, -.46383700E-02, -.23531500E-03, 0.18756400E-01, -.33920900E-01, -.28527600E-01, -.57897800E-02, -.24079800E+00, -.24714700E-01, 0.24477700E+00, 0.11913400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19101800E+01, 0.67032900E+00, 0.70690800E+00, -.10007400E+01, 0.76509400E+00, 0.72544500E-01, -.84662000E+00, 0.99685100E+00, 0.55327700E+00, 0.25886200E+00, -.98074200E-01, -.47540800E+00, 0.12334400E+01, 0.43373700E-01, 0.11139100E+01, 0.28018700E+00, 0.26727100E+00, 0.64332900E+00, 0.22971200E+00, 0.14718300E+01, 0.52855300E+00, -.36197000E-01, -.81129900E+00, -.33999800E+00, 0.45604600E+00, 0.99963100E-01, 0.21076300E+00, -.81077000E+00, 0.74771300E+00, -.43151300E+00, -.39779200E+00, -.42211100E+01, 0.42636300E+00, -.53922300E-01, 0.59257500E-02, -.35773800E-02, 0.15135700E-01, 0.15135600E+00, 0.48154200E+00, -.27709700E+00, -.12216400E+00, 0.15445800E+00, 0.31922000E+00, 0.20270500E+00, 0.14842700E+00, -.17823900E+00, -.26549900E+00, -.34725500E+00, -.29860400E+00, -.21116800E+00, -.36781000E+01, 0.12179500E+01, -.51683600E+00, -.89966400E-02, -.24730000E+00, -.47947300E+00, 0.58736500E-02, 0.76782600E-02, -.39837000E-01, 0.10607300E+00, 0.38980700E-01, 0.72608900E+00, 0.28118600E-01, 0.26644600E-01, -.44783000E+00, 0.12578400E-02, -.36188300E+00, -.52032100E-02, -.22796800E+00, -.10424600E+00, -.59282700E-01, -.73604600E-01, 0.14145200E-01, -.34888500E-02, -.20035200E-01, 0.52670500E-02, -.11348100E+00, 0.13566000E-01, -.71623300E-01, 0.34371300E+00, 0.17302700E-02, 0.13670800E-02, 0.63752200E-03, 0.54709800E-03, -.12691700E-01, 0.48048200E-03, -.29622500E-02, -.26526200E-01, 0.63702200E-02, 0.13537500E-02, -.87359400E-03, 0.41792900E-02, -.39041100E-01, 0.18141800E-02, -.16164700E-01, -.93301300E-01, 0.26019100E-01, 0.32166000E-01, 0.35193800E-01, -.84775100E-02, 0.13382400E-01, -.44698900E-02, 0.56495900E-01, -.12890700E+00, -.12953200E-01, 0.85249400E+00, -.16431700E+01, 0.30536100E+00, -.10308100E+01, -.71682900E-01, 0.19945600E-02, 0.43538600E-01, 0.15612700E+00, 0.80032000E-01, 0.27910200E+00, 0.49683000E-01, 0.53992600E-01, -.35211400E-02, 0.19151700E+00, 0.41562100E-01, -.20071200E-03, -.38082900E-01, -.19358500E-01, -.20542100E-01, -.34944200E-01, 0.29921200E-01, -.21441000E-01, 0.13179900E+00, -.23636800E-01, 0.23289300E+00, -.35127500E-02, 0.15634800E+00, 0.80070200E-01, -.61232800E-01, 0.78007300E-01, -.37256600E-01, 0.83390800E-02, 0.12727500E-01, 0.50145200E-03, -.28859600E+00, -.22457600E+00, -.16006600E-01, 0.90624600E-01, -.21507600E+00, 0.10719700E+00, -.87243300E-01, -.55465700E-01, -.18678600E-01, -.18671300E-01, -.30490500E-01, -.86989500E-02, 0.14931300E-01, 0.41053900E-01, -.26723100E-01, -.87223300E-01, -.46780800E-01, 0.14761600E-01, -.21670100E-01, -.22274900E-01, -.22974800E-01, 0.62877400E-02, 0.49158600E-01, -.14024400E+00, 0.78053200E-02, -.18520300E-01, 0.54639600E-01, -.31388200E-01, 0.25622800E+00, 0.10881200E-01, -.15216300E+00, -.21518700E-01, -.15257900E-02, 0.64892800E-02, 0.84642400E-02, 0.27592600E-01, 0.22609500E-02, 0.21032100E-01, -.66745700E-01, 0.43266300E-01, 0.12024300E+00, -.38550000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23865700E+00, 0.21278600E+00, 0.92478100E-01, 0.76548800E-01, -.55323800E-01, 0.16463300E+00, -.27555100E+00, 0.31746100E+00, 0.11219300E+00, -.12927100E-01, -.46746400E-01, 0.74597800E-01, -.21751600E+00, -.17037800E-01, -.27372600E+00, 0.95488400E-01, -.42233500E-01, 0.13399900E+00, 0.33929000E-01, -.10391700E+00, -.50458000E-02, 0.22624400E-01, 0.32135900E+00, 0.75381900E-03, 0.66288200E-01, 0.34004200E-01, -.82708000E-01, -.86192200E-01, 0.17217800E+00, -.20419000E-01, -.57535200E-01, -.20888900E-01, -.31182900E+00, -.54033400E-01, 0.75686300E-03, -.21849700E-01, -.79392600E-01, 0.20955600E-01, 0.82899500E-01, 0.49912200E-01, 0.34071100E-01, 0.12598200E-01, 0.11531500E-01, 0.20059000E-01, -.35923500E-02, -.21854000E-01, -.62309200E-01, -.40452800E-01, -.76968000E-01, -.49698900E-01, -.48527800E+00, -.23745400E-01, -.55124600E-01, -.15817000E-02, -.95937900E-02, 0.13046600E-01, 0.12163400E-01, -.71399100E-04, 0.17162700E-01, -.21906000E-01, -.12635200E-01, -.14516300E-01, 0.52894200E-02, -.40735400E-01, -.37761500E-01, -.36844600E-01, -.13874300E+00, 0.16687600E-02, -.18874200E-01, -.81734900E-02, -.15577400E+00, -.99201200E-01, 0.37158900E-02, -.13070300E-02, 0.17436700E-01, 0.38652500E-02, -.18614500E-01, -.33113900E-01, -.24139000E-02, 0.13186000E+00, 0.97280300E-03, 0.15273400E-03, 0.15401500E-02, -.21651100E-02, -.41150300E-02, 0.46260000E-03, 0.12396900E-02, -.11539600E-01, 0.29417500E-02, -.69389100E-03, -.88941700E-03, -.19761900E-01, 0.62957300E-02, 0.21100500E-02, 0.13491400E-01, -.48639500E-01, 0.21643000E-01, 0.68533900E-02, -.86732000E-02, -.17985100E-01, 0.67114100E-02, -.14803400E-02, 0.13231900E-01, 0.47202400E-02, -.65290700E-03, 0.10665900E+00, -.30792300E-01, 0.43705400E-02, -.57256800E-01, -.17745700E-01, 0.23997300E-01, -.60474700E-01, -.19447300E-01, -.48996700E-02, -.22104600E-01, 0.97199600E-02, -.62310100E-02, -.69863200E-02, 0.40312100E-01, 0.24768900E-01, -.27627400E-02, -.11396100E-01, 0.19115300E-01, 0.22069500E-01, -.45765400E-02, -.32959600E-02, -.18803000E-01, 0.19185500E-01, -.47938800E-01, 0.24466300E-01, 0.27150800E-02, 0.90715800E-02, 0.79255300E-02, 0.48855600E-02, 0.51113200E-02, 0.10075200E-01, 0.20805900E-02, 0.14019600E-01, -.47771100E-01, -.67010900E-01, -.35611200E-01, -.73767500E-02, -.12921500E-01, -.28181000E-01, -.88322400E-02, 0.20086100E-01, 0.20691200E-01, 0.24812500E-02, -.23555100E-02, 0.35693600E-03, 0.44464100E-02, -.15715100E-02, -.65500300E-02, 0.18864700E-02, -.30858200E-01, -.27456700E-01, -.16844400E-01, -.55614000E-02, 0.87781500E-02, 0.75495400E-02, 0.33819800E-01, -.43578200E-01, 0.15372600E+00, -.77644200E-02, 0.13264100E-02, 0.89642900E-02, 0.49320800E-02, 0.37383500E-01, 0.68010600E-01, 0.45173400E-01, -.23315400E-01, 0.21468200E-02, 0.61497200E-02, 0.40890000E-02, 0.24921200E-01, 0.10550200E-01, 0.17313100E-01, 0.14362800E-01, 0.52287300E-01, -.58854100E-01, -.59526200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.25312100E+02, 0.81460900E+01, 0.29102800E+01, 0.50415400E+01, -.30326000E+01, 0.47933300E+01, -.73707700E+01, 0.88679400E+01, -.82988200E+01, -.10956200E+02, -.33645200E+01, 0.10207200E+02, -.34928900E+02, -.21762800E+01, -.33647900E+02, -.35813000E+01, -.75091800E+01, 0.45968300E+01, -.18176000E+00, 0.20597100E+02, 0.10996000E+01, -.54446600E+01, -.20004400E+01, 0.10507600E+01, 0.22124400E+01, 0.28156600E+00, -.18385400E+01, -.91412900E+00, 0.59969600E+01, 0.19378500E+01, -.13452800E+01, 0.14708400E+02, -.17987500E+02, -.17732900E+01, -.20864100E+00, -.48202700E+00, -.36363400E+01, -.14120000E+01, -.15999000E+01, 0.79356500E+00, 0.34724600E+01, -.82661200E+00, -.17827500E+01, 0.28673500E+01, 0.70651400E+01, 0.32433100E+00, -.71438800E+01, -.16960400E+01, -.17354000E+01, -.33084100E+01, -.38297000E+01, -.10006400E+02, 0.12618100E+01, -.30694800E+01, 0.23148400E+00, -.52499500E+01, -.52048100E+00, 0.51571900E-02, -.56727900E+00, 0.13840900E+01, 0.50263300E+00, 0.28577900E+01, -.78766100E+00, -.49241000E+00, -.29924400E+00, 0.32805400E+00, -.50676900E+01, 0.27734700E+00, 0.44116000E+01, 0.12276500E+01, -.86649500E+00, -.26291800E+01, 0.29660300E+00, -.12121100E-01, -.16909400E+01, -.66414400E+00, -.11137800E+01, 0.10676500E+01, -.20424700E+00, 0.98498000E+01, 0.37618300E-01, -.10764700E-01, -.27866500E-01, -.73730600E-01, -.43915400E-01, 0.65692100E-02, 0.16513500E+00, -.81748200E+00, 0.14795200E+00, -.67440500E-01, -.26831400E+00, -.44034800E-01, -.37175800E+00, 0.41386400E-01, 0.41602800E+00, -.27728100E+01, 0.43711600E+00, -.64905300E+00, 0.48045500E+01, 0.75587200E+00, -.93652000E+00, 0.40495600E+00, 0.20133900E+00, 0.24876000E+01, 0.14078600E+01, -.14857200E+01, -.37259900E+01, -.42873100E+01, -.61730900E+01, -.18346400E+01, -.69324300E+00, 0.69374600E+01, 0.48713500E+01, -.15063000E+00, 0.20513400E+01, 0.88865000E+00, -.12906700E+00, 0.34404000E+01, 0.48363100E+01, 0.64313600E+00, 0.18971700E+00, 0.73606000E+00, 0.10966200E+01, -.66815400E-02, 0.59731700E+00, 0.67672700E-01, -.89202200E+00, 0.20953000E+01, -.21978500E+01, 0.38531000E+01, 0.23247700E+00, -.22102700E+00, 0.85821400E+00, -.52338800E+00, 0.19133700E+01, -.18895200E+01, 0.92729100E-01, -.14315100E+01, -.42625500E+00, -.25711900E+01, -.60450600E+01, 0.30739900E+00, 0.83361000E+00, -.14045500E+01, -.56393300E+00, -.55015600E+01, -.22622500E+01, -.45160800E+00, -.77089900E-01, -.12533400E+00, 0.28119300E+00, 0.31025200E+00, 0.28813100E+00, 0.22372000E+01, 0.81888600E+01, 0.32907600E+01, -.46267700E+00, 0.20783900E+01, 0.82766400E+00, 0.23654400E+01, -.83577500E+00, -.37211400E+01, 0.85072100E+01, -.11268500E+00, -.57991500E+00, 0.46991700E+01, -.66008700E+01, -.33976700E+01, 0.24053100E+02, -.27180100E+02, -.25499300E+01, -.21970300E+00, 0.93243200E+00, 0.25660700E+01, 0.76620900E+00, 0.25442200E+01, 0.31275200E+01, -.26165500E+02, 0.43219600E+01, 0.31051200E+02, -.29662500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.19694800E+00, -.16898300E+00, -.88369700E-01, -.10695600E+00, 0.52382200E-01, -.13634200E+00, 0.20645100E+00, -.24576500E+00, -.79153800E-01, -.48850300E-02, 0.34956300E-01, -.62873900E-01, 0.12733000E+00, 0.10829000E-01, 0.17749400E+00, -.82674800E-01, 0.32693100E-01, -.10071800E+00, -.29555600E-01, -.86206200E-01, -.65583800E-02, -.29671400E-01, -.25798200E+00, 0.82971500E-03, -.49072200E-01, -.25596900E-01, 0.64656100E-01, 0.59053200E-01, -.12808400E+00, 0.15127700E-01, 0.46711600E-01, -.98884800E-02, 0.22097500E+00, 0.40942200E-01, -.16154000E-02, 0.16883200E-01, 0.61019000E-01, -.89220200E-02, -.45535400E-01, -.31399400E-01, -.93186500E-02, -.13344000E-01, -.61189500E-02, -.14439400E-01, 0.65067100E-02, 0.21180800E-01, 0.54336600E-01, 0.31864700E-01, 0.61743200E-01, 0.32539300E-01, 0.44192400E+00, -.66486700E-01, 0.46045700E-01, -.27254600E-02, -.16042500E-01, -.13888000E-01, -.96733900E-02, 0.90061600E-04, -.16123100E-01, 0.19282600E-01, 0.12414400E-01, 0.11339200E-01, -.46958900E-02, 0.27672700E-01, 0.33846100E-01, 0.25688100E-01, 0.10281500E+00, -.44375200E-02, 0.12590200E-01, 0.49618600E-02, 0.11714800E+00, 0.76631300E-01, -.22331400E-02, 0.51989300E-03, -.16584500E-01, -.70289200E-02, 0.17859300E-01, 0.23920800E-01, 0.37710600E-02, -.11298800E+00, -.62769800E-03, -.15174500E-03, -.12898700E-02, 0.11334900E-02, 0.31103100E-02, -.30654000E-03, -.98352500E-03, 0.95135500E-02, -.19281300E-02, 0.33810800E-03, 0.95342200E-04, 0.12918800E-01, -.40027900E-02, -.14298300E-02, -.97518400E-02, 0.39497100E-01, -.14632500E-01, -.44910600E-02, 0.58871100E-02, 0.15363800E-01, -.57795000E-02, 0.21804400E-02, -.13001500E-01, -.73993400E-02, -.47350600E-03, -.10140000E+00, 0.32574700E-01, 0.15772100E-02, 0.36389900E-01, 0.14763200E-01, -.20419500E-01, 0.38726700E-01, 0.11146600E-01, 0.52277100E-02, 0.15651600E-01, -.60078200E-02, 0.43157100E-02, 0.57305300E-02, -.40104500E-01, -.20018400E-01, 0.17931300E-02, 0.81414800E-02, -.17839500E-01, -.19427400E-01, 0.40639100E-02, 0.30327100E-02, 0.18139800E-01, -.11439100E-01, 0.37995000E-01, -.20621100E-01, -.16258100E-02, -.43413800E-02, -.49055800E-02, -.52011900E-02, -.34315900E-02, -.11835000E-01, -.20483000E-02, -.15776700E-01, 0.38664900E-01, 0.53927300E-01, 0.26538800E-01, 0.58671500E-02, 0.72477100E-02, 0.24890000E-01, 0.11547200E-01, -.13389000E-01, -.17447100E-01, -.20356300E-02, 0.18903900E-02, 0.24483800E-03, -.37218500E-02, 0.14582800E-02, 0.63528700E-02, -.21280900E-03, 0.25551000E-01, 0.23873900E-01, 0.13341300E-01, 0.51228700E-02, -.74271900E-02, -.68568500E-02, -.23870600E-01, 0.31640400E-01, -.10471500E+00, 0.24567600E-02, -.91938900E-03, -.26972900E-02, -.67956800E-02, -.27852700E-01, -.15671500E+00, 0.94529100E-03, 0.67473300E-01, -.62390700E-03, -.41613000E-02, -.44047100E-02, -.14360900E-01, -.68459500E-02, -.13504700E-01, 0.12294000E-01, -.10704300E-01, 0.49519200E-02, 0.34758500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10608400E+00, -.52467500E-01, -.34751700E-01, -.79793600E-01, 0.23350100E-01, -.15595400E-01, 0.27731700E-01, -.13125100E-01, 0.24091900E-01, -.22870900E-01, 0.15596600E-01, -.28232500E-01, -.62287900E-02, -.42294600E-03, -.36577100E-01, -.50862100E-02, 0.35551700E-02, -.26314100E-01, -.12336600E-01, -.38703100E+00, -.64600600E-02, -.88323700E-02, -.32914800E-01, 0.56378600E-02, -.65582800E-02, -.73739700E-02, 0.15980200E-01, 0.16868600E-01, -.23252700E-01, 0.43328900E-03, 0.49816600E-02, -.41671000E-01, 0.75407300E-01, 0.95669600E-02, -.22005800E-03, 0.61504400E-02, 0.28115900E-01, 0.41660800E-02, 0.51869100E-02, -.12600500E-01, -.19738300E-01, 0.39486100E-02, 0.22190200E-02, 0.49984200E-02, 0.11003800E-03, 0.32813700E-02, 0.51205800E-02, -.13108300E-02, 0.47848900E-02, 0.10809000E-03, 0.70933500E-02, -.11252600E+00, -.37757600E-02, -.49923700E-03, 0.60194600E-01, -.96753100E-03, 0.85126700E-04, 0.18277900E-03, -.19002500E-02, 0.32016000E-03, -.27778600E-03, 0.21912900E-02, 0.10268400E-02, 0.74338300E-02, -.24645700E-02, 0.58547700E-02, 0.50653800E-01, 0.67013800E-02, -.32336400E-02, 0.29205000E-03, 0.13829700E-01, 0.12752400E-01, -.17994600E-02, 0.86916000E-03, -.67915400E-03, 0.32587400E-02, 0.11615700E-02, 0.37779900E-03, -.47741800E-02, -.41078200E-01, -.40212900E-03, -.41115900E-04, 0.95086000E-04, 0.72807600E-03, 0.11827400E-02, -.25468900E-03, -.83349000E-04, 0.34300300E-02, -.12478100E-02, 0.31745300E-03, 0.10424500E-02, 0.35037500E-02, 0.73781300E-03, -.95516000E-03, -.19714100E-02, 0.12706000E-01, -.16251000E-02, -.43483500E-03, -.47187600E-02, -.30316400E-02, -.27449400E-03, 0.32517800E-02, 0.28654400E-02, -.10493800E-01, -.43339800E-02, 0.45521900E-03, -.28991300E-02, -.11745400E-02, 0.47688600E-01, 0.52388900E-02, -.64710500E-02, 0.88915100E-02, 0.32378500E-02, 0.25503900E-02, -.92672400E-02, -.17244300E-02, 0.24910100E-02, 0.81955100E-02, -.39182000E-01, -.69177400E-02, -.37668000E-03, 0.52668200E-02, -.34810800E-02, -.66957400E-02, -.26343400E-02, 0.31269800E-02, 0.11279200E-01, 0.50594600E-02, 0.24639800E-01, -.24260800E-02, -.18621400E-02, 0.20767200E-02, -.11784800E-02, 0.77817800E-03, -.89506500E-02, -.64762900E-02, -.11601200E-02, -.53289000E-02, -.60664000E-02, -.31834600E-02, 0.31908200E-01, 0.23940400E-03, -.39387100E-02, 0.49658200E-02, 0.39965300E-02, -.76420800E-02, -.10371000E-01, -.46883400E-03, -.78353800E-03, 0.79269400E-03, -.16844000E-03, 0.16312200E-02, -.10299300E-02, 0.20940400E-02, 0.20537000E-02, 0.35192900E-02, 0.90936200E-03, 0.19867300E-02, -.19688700E-03, 0.27680100E-02, 0.64313600E-03, -.40905200E-02, -.74207100E-03, -.12872400E-01, 0.41424200E-03, -.15225500E-02, -.58062500E-02, -.35370800E-02, -.71756900E-02, -.15030300E-03, 0.18523200E-01, 0.53142100E-01, -.45823900E-03, 0.96008000E-03, 0.24972300E-02, 0.73119500E-03, -.30895300E-02, -.27612900E-02, -.49919500E-02, 0.12613100E-02, 0.47325100E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.33784900E+00, 0.19038300E+00, 0.66025600E-01, 0.10162100E+00, -.59855600E-01, 0.11791300E+00, -.19614600E+00, 0.19798500E+00, 0.46661000E-01, -.33919700E-02, -.54742500E-01, 0.78226900E-01, -.18853300E+00, -.13980400E-01, -.17777800E+00, 0.55926900E-01, -.32223500E-01, 0.12013700E+00, 0.29554000E-01, 0.24561100E+00, -.15512200E-01, 0.80200100E-02, 0.22166900E+00, -.53108400E-02, 0.49371100E-01, 0.31888100E-01, -.71227900E-01, -.86558900E-01, 0.14534200E+00, -.13620900E-01, -.38864000E-01, 0.12985800E-01, -.32070100E+00, -.46837600E-01, -.15175100E-03, -.26541500E-01, -.87484200E-01, 0.20231300E-01, 0.76595000E-01, 0.55402600E-01, 0.69994600E-01, -.14374600E-02, 0.92582600E-02, 0.10489900E-01, 0.16832600E-02, -.11501100E-01, -.35347200E-01, -.14913100E-01, -.46707300E-01, -.40031100E-01, -.20974300E+00, 0.44449400E-01, -.25094100E-01, -.77367900E-02, -.13713000E+00, 0.33815800E-02, 0.72499100E-02, -.36251400E-03, 0.89575500E-02, -.11476500E-01, -.31095400E-02, -.11490000E-01, 0.18634900E-02, -.40937400E-01, -.17799500E-01, -.36578000E-01, -.14755700E+00, -.96662400E-02, -.12375200E-01, -.12594900E-01, -.12801800E+00, -.83197000E-01, 0.48793000E-02, -.23120300E-02, 0.11115400E-01, -.15317400E-02, -.12149500E-01, -.25912100E-01, 0.24482700E-02, 0.10885800E+00, 0.11899200E-02, 0.11675700E-03, 0.10288000E-02, -.26888400E-02, -.43636900E-02, 0.61157400E-03, 0.40604600E-03, -.97396400E-02, 0.35809400E-02, -.97464900E-03, -.14934300E-02, -.18937800E-01, 0.30580200E-02, 0.25469700E-02, 0.98677400E-02, -.40447100E-01, 0.18906000E-01, 0.56031400E-02, 0.15890100E-02, -.70675000E-02, 0.31494200E-02, -.40866800E-02, 0.23413300E-02, 0.93936000E-02, 0.28305400E-02, 0.38685800E-01, 0.22329500E-01, 0.12444400E-01, -.12257500E+00, -.17863600E-01, 0.23237900E-01, -.58895600E-01, -.20690700E-01, -.39422500E-02, -.50642000E-02, 0.96195700E-02, -.78334400E-02, -.18573300E-01, 0.87113600E-01, 0.24807300E-01, -.30744500E-02, -.12634300E-01, 0.12457300E-01, 0.19935800E-01, -.25233000E-02, -.44243600E-02, -.24782700E-01, 0.12382900E-01, -.58049700E-01, 0.25346500E-01, 0.40123800E-02, 0.11302500E-01, 0.10562000E-01, -.21185500E-02, 0.16111500E-01, 0.62889000E-02, 0.23657500E-02, 0.10824700E-01, -.14467000E-01, -.38403700E-01, -.66644800E-01, -.62741400E-02, -.39686900E-02, -.23157000E-01, -.58478300E-02, 0.17768400E-01, 0.22922700E-01, 0.16243400E-02, -.88624500E-03, -.15875200E-03, 0.30356600E-02, -.19315500E-02, -.11811900E-02, -.72632200E-03, -.25267400E-01, -.22468100E-01, -.12352100E-01, -.64997200E-02, 0.56242600E-02, -.24058700E-02, 0.24179900E-01, -.23308300E-01, 0.10392800E+00, 0.46906100E-02, 0.15539300E-03, 0.89847600E-02, 0.81127800E-02, 0.28718000E-01, 0.16321400E+00, -.88055100E-03, -.23860700E+00, 0.53964400E-02, 0.56326700E-01, 0.13188100E-02, 0.66944600E-02, 0.60080300E-02, 0.11553300E-01, -.92215900E-02, 0.40512500E-01, -.49986700E-02, -.32801500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20360100E+01, 0.98055500E+00, 0.76827200E+00, -.13428500E+01, 0.22874200E+00, -.44854100E+00, -.18953600E+01, 0.21880300E+01, 0.23264200E+00, 0.40708300E+00, -.53628100E+00, 0.68678700E+00, -.11375100E+00, -.25204400E-02, -.40746600E+00, 0.25515000E+00, -.19012300E+00, 0.95152600E+00, 0.44906800E+00, -.37604600E+01, 0.25484100E+00, 0.48329500E+00, 0.10144400E+01, -.15966800E+00, 0.37937200E+00, -.14495300E-02, -.17567100E+00, -.82714000E+00, 0.91838800E+00, -.10219200E+00, -.61436200E+00, -.36671600E+01, 0.17579600E+01, -.55633400E-02, 0.33026000E-02, -.28866000E+00, 0.12450400E+00, 0.44997800E-01, 0.35114500E+00, -.20370500E+00, -.37261100E+00, 0.22905800E+00, 0.81419700E-01, 0.16216600E+00, 0.24807400E+00, -.12496700E+00, -.24713900E+00, -.38128200E+00, -.59005500E+00, -.10609900E+00, -.37709800E+01, 0.76988900E+00, -.60192900E+00, 0.10712800E-01, 0.75723200E+00, -.15953800E+00, 0.71776900E-01, 0.14295000E-01, 0.21500400E-01, -.22370600E-01, -.38994200E-01, 0.10770700E+00, 0.43468000E-01, -.15166900E+00, 0.32911800E-01, 0.30480100E-02, -.92238200E+00, -.10537800E+00, -.21819400E-01, 0.63872400E-01, 0.23017700E+00, 0.10891700E+00, 0.17553800E-01, 0.43203300E-04, -.35279300E-01, -.19365200E-01, -.10484300E+00, 0.75257500E-01, 0.41426800E-01, 0.86846900E+00, 0.27422600E-02, 0.56492300E-03, -.82908500E-03, 0.76073600E-03, -.12039800E-01, 0.21706700E-02, 0.17367900E-01, -.67181100E-01, 0.10848100E-01, -.34460600E-02, -.22921000E-01, -.26606700E-02, -.14079400E-01, 0.90880500E-02, 0.68585400E-01, -.23722000E+00, 0.26525400E-02, -.30241100E-01, -.55199600E-01, 0.10231600E+00, 0.21589700E-01, 0.74585000E-01, -.64170800E-01, -.10329200E+00, 0.62728300E-01, -.26971600E+00, 0.22295500E+00, -.13397900E+00, -.30828000E-01, -.12468000E+00, 0.88353600E-01, -.30547500E+00, 0.59586200E-02, -.44132200E-01, -.23319100E+00, 0.10504700E-01, -.32125900E-01, 0.23764200E+00, 0.87894800E-01, 0.11699200E+00, -.16118800E-01, -.13451500E-01, 0.12393100E+00, 0.59354900E-01, 0.66519000E-01, -.48341000E-01, -.27242500E-02, 0.26727000E-02, -.34880500E+00, -.10004100E+00, 0.32789500E-01, -.11411100E+00, -.11092600E-01, 0.77861900E-02, 0.30633600E-01, 0.77149300E-01, 0.10724300E-01, 0.16715400E-02, -.39142300E+00, -.29727500E+00, -.17111500E+00, 0.21353600E-02, 0.64992900E-01, -.22519500E+00, -.63060200E-01, 0.12137200E+00, 0.71169200E-01, 0.26599400E-01, -.59518700E-02, 0.15412800E-01, -.37871700E-02, 0.60347100E-02, 0.72263700E-01, -.75683600E-01, -.22662000E+00, -.44316600E-01, 0.32691800E-01, -.85556000E-01, 0.18434500E-01, 0.58489600E-01, 0.86620200E-02, -.70219900E-03, 0.29746700E+00, -.87120700E-02, 0.51595200E-02, -.46479100E+00, 0.54714600E-01, 0.75976800E-01, 0.16267400E+00, -.92316200E-02, -.47222800E+00, 0.24442500E-01, 0.11037200E+00, 0.23831700E+00, 0.31846100E-01, 0.63714100E-02, 0.32795900E-01, -.15292400E-01, 0.79052100E-01, -.64690200E-02, -.18811200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.39039000E+01, 0.80358600E+00, 0.91394000E+00, 0.14884500E+01, -.94723800E+00, 0.13153400E+01, -.15431400E+01, 0.18855400E+01, 0.22090300E-02, -.22779600E+00, -.10275700E+01, 0.22513900E+01, -.31985400E+01, -.25315000E+00, -.72908100E+00, 0.17060200E+01, -.19478800E+00, 0.13446800E+00, -.55045800E+00, 0.11567600E+02, -.15538000E+01, -.14026000E+01, 0.28392400E+00, -.22141300E+00, 0.84583000E+00, 0.33805800E+00, -.50396400E+00, -.17518700E+01, 0.11087300E+01, -.68201200E-01, 0.61670900E+00, 0.30412200E-01, -.72672100E+01, -.69526900E+00, -.11578900E+00, -.74724200E+00, -.13563700E+01, 0.41208800E+00, 0.10742100E+01, 0.13100300E+01, 0.23132400E+01, -.43098800E+00, 0.31620200E+00, 0.50961500E-02, 0.52205700E+00, 0.54300100E-01, -.23576800E+01, -.81304800E-01, -.27528200E+00, -.75335200E+00, 0.54583700E+01, -.10236400E+01, 0.17579300E+01, -.68630700E+00, -.21282100E+00, -.42957400E+00, -.97833200E-01, -.86429600E-02, 0.23049300E-01, 0.19885900E+00, 0.67151500E-02, -.46862900E+00, -.18027200E+00, -.26165100E+00, 0.31822900E+00, 0.42416500E-01, -.24055100E+01, -.21877300E+00, 0.91178800E+00, -.93195500E-02, 0.35607700E+00, 0.43619500E+00, 0.79826200E-01, -.17464900E-01, -.22711200E+00, -.66741300E+00, 0.40743600E+00, 0.15827300E-02, 0.51467200E+00, 0.90744700E+00, 0.11362700E-01, -.34255600E-02, 0.59283300E-02, -.48282300E-01, 0.14660200E-01, 0.78392300E-02, 0.82020100E-01, -.98340700E-01, 0.32563600E-01, -.20633800E-01, -.26495100E-01, -.24493600E+00, 0.20491300E+00, 0.29025600E-01, 0.36284600E+00, -.40698100E+00, -.44379200E-01, -.13738400E+00, 0.39064400E+00, -.61618100E+00, 0.42414500E-01, 0.92529800E-01, 0.16105400E+00, 0.10892300E+01, -.50805300E+00, -.60107400E+00, 0.57839100E+01, -.27483900E+00, -.21324100E+01, -.14202300E+00, -.38431200E+00, -.94350900E+00, -.59465800E+00, 0.67901000E+00, 0.96729300E+00, 0.86727600E+00, 0.14960300E-01, 0.41304900E+00, -.39135700E+00, -.35160300E-02, -.25578900E-01, 0.71719400E-01, -.48883500E+00, -.20922700E+00, 0.42446000E-01, 0.10918800E+00, 0.15446700E-01, 0.42601500E+00, -.25173000E+00, 0.78221600E+00, 0.29801500E-01, 0.30375300E+00, 0.22954100E+00, -.30102300E+00, 0.69273700E+00, -.75849800E+00, -.24901100E-01, -.18025300E+00, 0.54109300E+00, -.22350300E+00, -.48500000E+00, -.12208500E+00, 0.30754500E+00, -.43633100E+00, 0.20531500E+00, -.66186900E+00, -.26187300E+00, -.75197900E-01, -.44110300E-02, -.39757500E-01, -.24164600E+00, 0.86485500E-01, 0.42131100E+00, 0.54199400E-01, 0.59104200E+00, 0.11729600E+00, 0.14880600E+00, 0.64200300E-01, -.20910300E+00, -.44402300E+00, -.18309700E+00, 0.51285000E+00, -.68196600E+00, 0.28593100E+00, -.10460300E+00, 0.41142400E+00, -.35614400E+00, -.29550900E+00, 0.93292300E+00, 0.31175400E-01, -.54621700E+00, -.12039300E+00, 0.18339900E+00, 0.52109800E-01, -.57138200E+00, 0.16773000E-01, 0.11959700E-01, -.40610200E+00, 0.16788600E+00, 0.22914800E+00, -.31638000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14352500E+01, 0.96870300E+00, 0.30441700E+00, -.56246500E-01, -.28396600E+00, 0.27121400E+00, -.23244300E+00, -.54406000E-02, 0.29493200E+00, 0.30222400E+00, -.10165300E+00, 0.30295300E+00, 0.14880900E+00, -.65250000E-02, 0.37032500E+00, -.35733300E+00, 0.12468600E+00, 0.25539900E+00, 0.62140900E+00, -.48732900E+01, 0.11403800E+00, 0.15295900E+00, 0.42096000E+00, -.83870500E-01, -.27020200E-01, 0.10684300E+00, -.17942600E+00, 0.11659400E-01, 0.58930600E-01, -.53532800E-01, 0.60626400E-01, 0.32225800E+00, -.11013900E+01, -.86115400E-01, -.79774800E-02, -.33683100E-01, -.30524000E+00, -.10785500E+00, -.76742200E-01, 0.22653000E+00, 0.27638100E+00, -.83042700E-01, -.11434400E-01, -.47099500E-01, -.43613300E-01, -.82722700E-01, -.90230000E-01, -.17326100E-01, -.62773500E-01, -.22136200E+00, -.15929700E+00, -.16976000E+01, 0.16282000E-01, 0.44383500E-02, 0.35127000E-02, -.18268700E-01, -.12484400E-01, -.32222300E-02, 0.61704000E-02, -.16185700E-01, -.27137700E-02, -.95951400E-01, -.21040700E-01, -.47320100E-01, 0.10851800E+00, 0.22304800E-01, -.50345500E+00, -.10999600E+00, 0.70584400E-01, 0.41026700E-01, -.12417400E+00, -.11177100E+00, -.17346300E-01, 0.95253200E-02, 0.15738700E+00, 0.99857300E-01, -.21780800E-01, -.15759100E-01, -.31590200E-01, 0.43084700E+00, -.19128300E-02, 0.17522100E-03, 0.55786500E-02, 0.70779000E-02, 0.27331600E-02, -.35152400E-03, -.29643600E-02, -.29552700E-01, -.64460000E-02, 0.33080200E-02, 0.27723400E-01, 0.22646600E-01, 0.10748000E-01, -.11940800E-02, -.16087600E-01, -.10996700E+00, -.43764700E-01, -.15682300E-01, 0.10314400E-01, -.71401200E-02, 0.40452000E-01, -.65789700E-01, -.70236300E-01, 0.21977400E+00, -.40386500E-02, 0.32135900E-01, 0.94430900E+00, 0.82958900E-02, -.41580000E-01, -.10338200E-01, 0.69504200E-01, -.15541300E+00, -.13854400E+00, -.98426900E-01, 0.77332400E-01, 0.22490600E-01, -.28062500E-01, 0.51959900E-01, 0.56855500E+00, 0.20220300E+00, -.25973400E-01, -.44225600E-01, -.27389100E-01, 0.66985400E-01, 0.86963300E-02, -.42910500E-01, -.28680500E+00, -.12005500E+00, -.32396200E+00, 0.12110100E+00, 0.20271200E-01, 0.29531900E-01, 0.44295600E-01, -.52229600E-02, 0.95520900E-01, 0.12306500E+00, 0.18665000E-01, 0.87771300E-01, -.44457800E-01, -.78289400E-01, -.32550900E+00, -.17016400E-01, -.19955300E-01, -.11984900E+00, 0.25698000E-01, -.15595400E+00, -.82173900E-02, -.25131700E-02, 0.77146200E-02, 0.28207500E-02, 0.19706600E-01, -.67598700E-02, -.24481700E-01, -.26734700E-01, -.58618800E-01, -.22423000E-01, -.26438900E-01, -.29685500E-01, 0.29659300E-01, -.93497900E-02, 0.72098500E-01, -.11987700E+00, 0.54041800E+00, -.85887900E-01, 0.60368200E-02, 0.89114600E-01, -.17444900E+00, 0.17052000E-01, 0.76325900E+00, 0.77228800E-02, -.70426100E+00, 0.47521500E-01, 0.19245700E+00, 0.18957400E-01, -.58870200E-01, 0.15232800E+00, 0.40240400E-01, -.50684600E-01, 0.13675200E+00, 0.77287100E-03, -.79187600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.34538100E+01, 0.16447300E+01, 0.74355600E+00, 0.77805900E+00, -.71002400E+00, 0.85411300E+00, -.16977300E+01, 0.17673300E+01, 0.25507300E+00, 0.14939600E+00, -.44198800E+00, 0.65599400E+00, -.10989400E+01, -.78815900E-01, -.10818400E+01, 0.35818900E+00, -.26072300E+00, 0.10829100E+01, 0.51752900E+00, 0.19842500E+00, 0.61349900E-01, 0.16334300E+00, 0.27042800E+01, 0.10876900E+00, 0.34120200E+00, 0.17336700E+00, -.60430000E+00, -.32823100E+00, 0.14229900E+01, -.50806200E-01, -.30482200E+00, 0.21494700E+01, -.19340500E+01, -.33425700E+00, 0.33323600E-01, -.77697900E-01, -.40584000E+00, -.34164500E-01, 0.29317600E+00, 0.26979700E+00, 0.82554800E-03, 0.15679800E+00, -.35525300E-01, 0.24496400E+00, 0.21631000E-01, -.15791300E+00, -.78570100E+00, -.21252600E+00, -.48767000E+00, -.25859600E+00, -.52542500E+01, 0.20553400E+01, -.40113000E+00, 0.25142100E-01, -.56595500E+00, 0.62041700E-03, 0.78255500E-01, -.22735400E-02, 0.18133500E+00, -.15185300E+00, -.11374100E+00, -.24181700E+00, 0.52035100E-01, -.30717100E+00, -.22690700E+00, -.22413200E+00, -.81286100E+00, 0.17984100E-01, -.19241600E+00, -.81817800E-01, -.73536800E+00, -.38561100E+00, -.59232700E-02, 0.93106600E-02, 0.14651300E+00, 0.12276300E+00, -.18355500E+00, -.20766400E+00, -.38903300E-01, 0.64457400E+00, -.33608000E-03, 0.20165000E-02, 0.12518700E-01, 0.45973500E-02, -.19298500E-01, 0.22738200E-03, 0.69645800E-02, -.50070500E-01, -.65490500E-03, 0.37931700E-02, 0.77206700E-02, -.46346800E-01, 0.56866600E-03, 0.18966300E-02, 0.53131900E-01, -.22067000E+00, 0.64186600E-01, -.35397600E-03, -.44364300E-01, -.28426500E+00, 0.50950000E-02, 0.13660300E-02, 0.25725000E+00, 0.26991800E-01, -.44550800E-01, 0.75399600E+00, -.46762400E+00, -.70406600E-02, -.51409700E+00, -.11664000E+00, 0.10855100E+00, -.21630300E+00, -.41752600E-01, 0.12683300E-01, 0.54199200E-01, 0.70903200E-01, -.20715900E-01, -.28263600E-02, 0.23993500E-01, 0.11771800E+00, 0.93787300E-02, -.81469800E-01, 0.35278400E-01, 0.10811300E+00, 0.22102000E-01, -.24313700E-01, -.92395400E-01, 0.16698300E+00, -.38679100E+00, 0.14962000E+00, 0.27489000E-01, 0.27239500E-01, 0.44703100E-01, 0.25993000E-02, 0.73185000E-01, 0.75208200E-01, 0.14152000E-01, 0.65265900E-01, -.23250000E+00, -.20126300E+00, -.31154200E+00, -.63077900E-01, -.42472300E-03, -.19029300E+00, -.15738000E+00, -.19507800E-01, 0.86226500E-01, 0.10660400E-01, -.84627400E-02, -.50801600E-02, 0.27782100E-01, -.87389600E-02, -.23436700E-01, -.37081400E-02, -.11929300E+00, -.13318800E+00, -.72699100E-01, -.49344800E-01, 0.32830200E-01, -.26039100E-01, 0.20139200E+00, -.15295300E+00, 0.52626500E+00, 0.38227300E-01, -.22770100E-02, -.13642100E-01, 0.10137700E+00, 0.19819200E+00, 0.87597500E+00, -.11396900E-01, -.14684100E+01, 0.16629100E-01, 0.42428400E+00, 0.86995400E-01, -.68753200E-01, 0.31192600E+00, 0.21180900E+00, 0.52786800E-02, 0.22374000E+00, -.41829700E-01, -.18517000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18989600E+01, -.45391000E+00, -.34788400E+00, -.77899500E+00, 0.63883100E+00, -.61167200E+00, 0.42666800E+00, -.92573400E+00, -.73532600E+00, -.10736200E+01, 0.67942900E+00, -.10974700E+01, -.13370100E+01, -.41709200E-01, -.10192400E+01, -.57417600E+00, -.86686000E-01, -.83717500E+00, -.77656100E+00, 0.17586200E+01, 0.78727300E-01, -.24172800E+00, -.13223100E+00, 0.19205300E+00, -.29455000E+00, 0.30458000E-01, 0.18113900E-01, 0.41617500E+00, -.60925000E-01, -.46921000E+00, 0.50276700E+00, 0.70767800E+01, -.16175900E+01, -.10257900E+00, -.13900400E-01, 0.30753400E+00, 0.47832200E+00, -.16943900E+00, -.39835700E+00, 0.19134600E+00, -.23540200E-01, -.21133000E+00, -.84824500E-01, -.44278700E-01, 0.22215900E+00, 0.10519900E+00, -.69126600E-01, 0.10949600E+00, 0.56517600E+00, 0.13827500E+00, 0.27811400E+01, -.51411500E+01, 0.22274700E+00, 0.35106600E-01, 0.38251700E+01, 0.61014200E-01, -.57138800E-01, 0.13144900E-01, -.11954500E+00, 0.15573100E+00, -.20513500E-01, -.14634200E+00, -.15500600E+00, 0.30062600E+00, 0.48625000E+00, 0.10664400E+00, 0.42393300E+00, 0.31194300E+00, 0.84706400E+00, 0.45016800E+00, -.21470500E-02, 0.18331600E+00, -.22984000E-01, 0.94508700E-02, 0.68283700E-01, 0.14919500E+00, 0.15481200E-01, -.12172200E+00, -.21543500E-01, 0.31675000E+00, -.26986600E-02, -.15614000E-02, 0.23156400E-02, 0.45195400E-02, 0.21177100E-01, -.20726100E-02, 0.13421300E-01, -.24492300E-01, -.80959600E-02, -.14743000E-02, 0.45282600E-02, 0.19339700E-01, 0.53250700E-01, -.74891300E-02, 0.29397800E-01, -.84893700E-01, 0.26294900E-01, 0.34113100E-01, -.34962300E-01, 0.16580300E+00, -.41609600E-01, 0.10159300E+00, 0.75597500E-01, 0.16205300E+00, 0.71436900E-01, 0.30575000E+00, 0.15193000E+01, -.52497600E-01, 0.15410500E-01, 0.39789200E-02, -.26310900E-01, 0.56785200E+00, 0.11509400E+00, -.67991700E-01, 0.55256400E-01, -.12572800E-01, 0.19681300E-01, 0.47022300E+00, 0.66999700E-01, 0.50253200E-01, -.21336400E-01, -.72139500E-01, 0.11142800E-01, 0.15172300E-02, -.97833700E-01, 0.67872900E-01, -.28599100E-01, 0.32575600E+00, 0.56374700E-01, 0.20747300E+00, -.67848700E-03, 0.18464600E+00, 0.89424800E-01, -.50937200E-01, 0.17923000E+00, -.47494100E+00, -.13360400E-01, -.75719500E-01, 0.64212100E-01, -.20970800E+00, 0.46758600E-01, 0.40695600E-01, 0.46457800E-01, -.37919700E-01, 0.19341700E+00, 0.28446000E+00, 0.19231300E+00, 0.13215900E-01, -.14612300E-01, -.29421200E-01, -.31084000E-01, 0.88181100E-01, -.58241800E-01, -.10979800E+00, -.10230300E+01, -.22795900E+00, -.10230800E+00, -.15232000E-01, -.23660000E-01, -.11552300E+00, 0.99976300E-01, 0.47165000E-01, -.54549800E+00, 0.71320900E-01, -.16770200E-01, 0.14045400E+00, 0.25635400E+00, -.10851000E+00, -.38767000E+00, 0.23128600E-01, 0.13768300E+01, 0.10193800E+00, -.49885700E+00, -.59156000E+00, 0.26367000E-01, -.44863400E+00, -.11454800E+00, 0.12352600E+01, -.47865300E-01, -.12023300E+01, -.20865700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19274900E+02, -.76234400E+01, -.29961900E+01, -.49088300E+01, 0.11817400E+01, -.39562500E+01, 0.50342200E+01, -.45904000E+01, -.50663100E+00, -.81679700E+00, 0.28423200E+01, -.25728500E+01, 0.44328100E+01, 0.23773800E+00, 0.52824700E+01, 0.11028800E+01, 0.15090900E+01, -.77090900E+01, -.28328900E+01, -.21915100E+02, -.33083800E+01, 0.10233800E+01, -.16445500E+01, 0.10463400E+01, -.23176400E+01, -.11317200E+01, 0.19135200E+01, 0.42835700E+01, -.50860200E+01, 0.16121000E+01, 0.19402100E+01, 0.28103300E+01, 0.14053100E+02, 0.19318100E+01, 0.22285000E+00, 0.97344300E+00, 0.45954700E+01, -.64013200E+00, 0.75465900E-01, -.29383600E+01, -.60760100E+01, 0.10202000E+01, -.91000000E+00, 0.27773600E+01, -.26185000E+01, 0.77796000E-01, 0.46704400E+00, 0.30596400E+01, 0.25261300E+01, 0.14733700E+01, -.13629700E+02, 0.32953400E+02, -.12666500E+01, 0.86115800E+00, -.25132800E+02, 0.31246100E+00, 0.24908100E+00, -.94641100E-01, 0.60481300E+00, -.94029800E+00, 0.28528300E+00, -.28557700E+01, 0.11188600E+01, -.24413100E+01, -.23796000E+01, 0.13927300E+00, 0.39371700E+00, 0.53618800E-01, -.32191200E+01, -.25619700E+01, 0.30233800E+01, 0.17767400E+01, -.18902100E+00, 0.74180900E-01, 0.27646700E+00, -.14885200E+00, 0.12569200E+01, 0.72059700E+00, 0.78808200E+00, -.16733100E+01, -.31561000E-01, -.89245100E-02, -.28676100E-01, 0.73347200E-01, 0.19672300E+00, -.13951200E-01, 0.78939800E-01, 0.16646000E+00, -.10496800E+00, 0.15796600E-01, 0.79599200E-01, 0.44387300E+00, 0.42454800E+00, -.60840700E-01, 0.18445700E+00, 0.70956900E+00, -.85720500E+00, -.15480800E+00, 0.37477200E-01, -.60484400E-01, 0.44046800E+00, -.15253200E-01, -.63555400E+00, 0.57765400E+00, -.93057300E+00, -.67041000E-01, -.52796600E+00, 0.28236700E+00, -.89037100E+00, -.37790900E-01, 0.17671600E+00, 0.78398900E+00, -.36394700E+00, -.38038300E-01, 0.65664100E+00, -.18982600E+00, 0.14297200E+00, -.15637600E+01, 0.13319600E+01, -.87811500E-01, 0.12857400E+00, -.39662200E+00, 0.31462800E+00, 0.20426300E+00, -.60710100E+00, 0.13305000E+00, -.65606000E+00, -.84068400E+00, 0.14385200E+01, 0.36542300E+00, -.21049200E+00, 0.44751400E+00, -.60048500E-01, -.35846200E+00, 0.51636600E+00, -.13003000E+01, -.22227100E-01, 0.70920700E+00, 0.10640900E+01, 0.14375500E+01, 0.20623400E+01, -.20857300E+00, 0.49941800E-02, 0.48885700E+00, 0.60131700E-01, -.14104900E+00, 0.20850800E-02, -.17327100E+00, 0.10852700E+00, 0.62344100E-01, 0.38372200E-01, 0.24417200E-01, 0.23205800E+00, -.10816700E+00, 0.10977200E+01, -.48495000E+00, -.85503200E-01, 0.60475700E+00, -.20098100E+00, -.10684300E+00, -.72393300E+00, -.50440800E-01, 0.11918500E+00, -.76109200E-02, -.22688000E+00, 0.14510500E+01, 0.12908600E+01, -.44620700E-01, 0.60102600E+01, 0.17773200E+00, -.43289900E+01, -.26609200E+00, -.25558100E-01, 0.12028300E+01, 0.20024800E+00, -.16635500E+01, -.15884700E+01, 0.10895700E-01, 0.19414100E+01, -.47508800E-01, 0.27533800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14480300E+02, 0.55364800E+01, 0.17950300E+01, 0.45837800E+01, -.30033100E+01, 0.39352000E+01, -.35559100E+01, 0.64056000E+01, 0.16430900E+01, 0.11817200E+01, -.23649100E+01, 0.30481800E+01, -.25524100E+00, -.15045200E+00, -.42450800E+01, 0.25233400E+01, -.12206300E+01, 0.40439000E+01, 0.18759300E+01, 0.26291000E+02, 0.20643700E+01, -.19130800E+01, -.20921000E+01, -.28295700E+00, 0.19625800E+01, 0.16759800E+00, -.13665700E+00, -.74316300E+00, 0.15155400E+01, 0.21717300E+01, -.19919800E+01, 0.44462400E+01, 0.86845700E+00, -.17972300E+00, -.19546300E-01, 0.17137900E+00, -.15642700E+01, -.54478200E-01, 0.54004700E-01, 0.94608600E+00, 0.28284000E+01, 0.32209200E+00, -.23829400E+00, -.28934000E+01, -.25367400E+01, 0.85347100E-01, 0.32205600E+01, -.13516400E+01, -.28615100E+01, 0.15615100E+00, 0.20333600E+01, -.90731200E+01, 0.13200800E+01, -.16535000E+00, 0.47436500E+01, -.21083200E+00, -.13377500E+00, -.58968100E-02, 0.52565300E-01, 0.27557000E+00, -.15690800E+00, 0.67092800E+00, -.33159400E+00, 0.65326900E+00, 0.34626600E+00, 0.32131600E-01, 0.25574900E+01, 0.30708300E+00, 0.11241700E+01, 0.88971300E+00, -.11653800E+01, -.68809900E+00, 0.70379100E-01, -.36565700E-02, -.58043800E+00, -.16884100E+00, -.51822200E-01, -.27650200E+00, -.45512100E+00, -.16946300E+01, 0.29942800E-02, -.70304700E-02, 0.10795700E-01, -.25380800E-01, 0.25033500E-01, -.54069200E-02, 0.28394300E-01, 0.10647400E+00, 0.70524100E-02, -.20182100E-01, -.18598900E-01, -.14553900E+00, 0.12373300E+00, -.15176500E-01, 0.52961500E-01, 0.33053500E+00, 0.29400400E+00, 0.12358700E-01, 0.45789000E+00, -.82216400E+00, -.50328500E+00, 0.30391200E+00, 0.13053400E+01, 0.10134900E+01, 0.34106000E+00, 0.13538100E+01, 0.25277100E+00, -.20621300E+01, 0.19133400E+01, 0.16206300E+00, -.33321700E+00, 0.35136000E+01, 0.21030700E+01, -.15761700E-01, -.11374700E+01, 0.34983800E+00, 0.66872800E-01, 0.23531900E+01, 0.13557000E+01, -.73632300E+00, -.18396900E+00, 0.13869400E+01, 0.21712400E+00, 0.77650500E-01, 0.72906300E-01, -.10088600E+00, 0.14183200E+00, -.30458600E-01, -.39831700E+00, 0.22922100E+00, 0.11299700E+00, -.59388900E+00, -.11836600E+00, 0.18569200E+01, 0.38450500E-01, 0.10672300E+01, -.11256100E-01, -.12704200E+00, 0.10432500E+01, 0.24189000E+01, -.26908100E+01, 0.41310600E-01, -.47883900E+00, 0.18863900E+01, -.87306200E+00, -.92725300E+00, -.32092400E+00, -.50795000E-02, 0.89659800E-02, -.42377200E+00, -.81563100E+00, -.20404700E+00, 0.22527300E-01, 0.76765500E+00, 0.48243100E+01, 0.23248500E+01, 0.31085600E+00, 0.11557100E+01, 0.17593300E+00, 0.18064000E+01, -.91061500E+00, -.15115900E+01, 0.94334900E+01, -.47978800E+00, 0.13943400E+00, 0.18145900E+01, -.28838200E+01, 0.76970600E-01, 0.11717200E+02, 0.22869400E+00, -.86592200E+01, -.71477500E-01, 0.29347600E+01, 0.24297700E+01, 0.16278900E+00, 0.27386500E+01, 0.24308900E+00, -.56596700E+01, 0.15130500E+00, -.44787000E+01, -.80577600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.51756500E+01, 0.19793100E+01, 0.77701200E+00, 0.11395700E+01, -.30391500E+00, 0.12973300E+01, -.22837200E+01, 0.21634300E+01, 0.49474400E+00, -.97613500E-01, -.50197600E+00, 0.71671700E+00, -.21041500E+01, -.14865200E+00, -.19100400E+01, 0.55822700E+00, -.32334600E+00, 0.11648900E+01, 0.17454900E+00, 0.28970100E+01, -.27961100E+00, 0.10617300E+00, 0.24460200E+01, -.81274700E-01, 0.49521400E+00, 0.37094100E+00, -.78479500E+00, -.97059600E+00, 0.15182100E+01, -.13054900E+00, -.35055400E+00, 0.82248200E-01, -.36537200E+01, -.51085500E+00, -.12871000E-02, -.30686000E+00, -.96510700E+00, 0.21780200E+00, 0.87191400E+00, 0.60750200E+00, 0.84509400E+00, -.43250300E-01, 0.11341900E+00, 0.95994200E-01, 0.54696300E-01, -.12637100E+00, -.56662500E+00, -.21542400E+00, -.52954700E+00, -.45331400E+00, -.13035500E+01, -.26995300E+00, -.10758700E+00, -.12540200E+00, -.37545000E+00, 0.38033900E-02, 0.63949400E-01, -.32991500E-02, 0.64500200E-01, -.10085200E+00, -.40323100E-01, -.10297300E+00, -.10046500E-01, -.35555100E+00, -.11877400E+00, -.35669900E+00, -.16320800E+01, -.16078500E+00, -.14267000E+00, -.10976300E+00, -.13312200E+01, -.83401400E+00, 0.39875800E-01, -.20454700E-01, 0.12283700E+00, -.45782700E-01, -.76898000E-01, -.28793500E+00, 0.44199600E-01, 0.10567000E+01, 0.10351800E-01, 0.12317000E-02, 0.10035300E-01, -.25981700E-01, -.40476400E-01, 0.57848600E-02, 0.23657500E-02, -.95303400E-01, 0.30447900E-01, -.77407200E-02, -.16256600E-01, -.19670200E+00, 0.45207600E-01, 0.24243600E-01, 0.10136000E+00, -.40386400E+00, 0.17842200E+00, 0.58598000E-01, -.80574700E-01, -.10818800E+00, 0.40823000E-01, -.52757600E-01, -.25637100E-01, 0.88425800E-01, -.22823500E-01, 0.22202900E+00, 0.21271700E-01, 0.22862600E+00, -.13093400E+01, -.17554400E+00, 0.21353500E+00, -.81722500E+00, -.31733500E+00, -.34661900E-01, -.97141000E-01, 0.11520500E+00, -.99546500E-01, -.23469200E+00, 0.84482400E+00, 0.28906200E+00, -.33326000E-01, -.17034700E+00, 0.17042000E+00, 0.23279600E+00, -.25229600E-01, -.51642600E-01, -.26228200E+00, 0.12364400E+00, -.58110500E+00, 0.24122200E+00, 0.41264000E-01, 0.10347900E+00, 0.10028600E+00, -.31830900E-01, 0.18189500E+00, 0.14773500E-01, 0.20824900E-01, 0.10025800E+00, -.15547400E+00, -.38648700E+00, -.63565400E+00, -.61621600E-01, -.75051900E-01, -.20796700E+00, -.45844400E-01, 0.31537000E+00, 0.27891600E+00, 0.21324500E-01, -.37475400E-02, 0.40314900E-02, 0.29084600E-01, -.21442600E-01, -.38002100E-02, 0.99167300E-02, -.20246200E+00, -.19959100E+00, -.12963400E+00, -.65278100E-01, 0.64013100E-01, -.31546000E-01, 0.30673400E+00, -.31331200E+00, 0.13594600E+01, 0.10944200E+00, 0.37585700E-02, 0.21574600E+00, 0.12268400E+00, 0.35598500E+00, 0.22351800E+01, -.84608700E-02, -.32444500E+01, 0.11604900E+00, 0.82458800E+00, 0.52989300E-01, -.14945100E+00, 0.42060000E+00, 0.35704600E+00, -.17498200E+00, 0.26288200E+00, 0.42830500E-01, -.10076700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 } },
        { { 0.21993200E+05, -.29956200E+04, 0.17025100E+04, 0.32077500E+04, -.84392000E+04, 0.26096400E+04, -.11316900E+05, 0.35605400E+04, 0.24354600E+05, 0.31742000E+04, 0.10435700E+05, 0.14920200E+05, -.20521500E+05, -.45850300E+04, -.30069500E+05, 0.15985200E+05, -.26654300E+05, -.20316000E+04, -.68632300E+04, -.96797800E+04, 0.16951800E+05, 0.20509300E+04, 0.25063500E+05, -.10502400E+05, -.14727800E+03, -.41967600E+04, -.44825900E+04, -.66709100E+04, 0.59458100E+04, 0.56515000E+04, 0.12681800E+05, -.68292100E+04, 0.56729300E+04, 0.16139100E+04, 0.30341500E+04, 0.44229900E+04, -.54860500E+04, -.21015000E+04, -.95037100E+04, 0.46288300E+04, -.12711300E+05, -.34302200E+04, -.95894100E+04, -.13519500E+05, 0.16206600E+05, 0.81070900E+04, 0.28655600E+05, -.14019800E+05, 0.11850800E+05, -.97894600E+04, -.58776600E+04, -.78337100E+04, 0.47158500E+04, 0.99328600E+04, 0.14788500E+05, -.78929200E+04, 0.23639900E+04, 0.14951500E+05, 0.83887800E+04, 0.12320000E+05, -.12547300E+05, -.10638900E+05, -.27968300E+05, 0.12757700E+05, -.96370500E+04, 0.12982400E+05, 0.50010600E+04, 0.71334500E+04, -.45882600E+04, -.97459400E+04, -.15493000E+05, 0.71065400E+04, -.10442000E+05, -.32480500E+04, -.61813200E+04, -.89404800E+04, 0.10910900E+05, 0.45815700E+04, 0.18905800E+05, -.93338700E+04, 0.10084700E+05, 0.33638100E+04, 0.37591500E+04, 0.57813900E+04, -.80038800E+04, -.19732000E+04, -.14111700E+05, 0.61476800E+04, -.10397900E+05, -.61088500E+02, -.27731500E+04, -.41360000E+04, 0.64274500E+04, 0.68647000E+03, 0.10236100E+05, -.44269000E+04, -.37133200E+04, -.67630500E+03, -.16758000E+04, -.24583500E+04, 0.32135300E+04, 0.11080800E+04, 0.55759900E+04, -.25767700E+04, -.33737600E+05, 0.47108700E+04, -.63310000E+04, -.91320400E+04, 0.17558500E+05, -.11927700E+04, 0.21506100E+05, -.10048000E+05, -.53253100E+04, 0.92951700E+04, 0.49874600E+04, 0.68210300E+04, -.58351100E+04, -.76435900E+04, -.14301100E+05, 0.70393100E+04, -.19575200E+04, 0.13444800E+05, 0.75599900E+04, 0.10368600E+05, -.98214600E+04, -.10178000E+05, -.22985200E+05, 0.10676400E+05, -.44582800E+04, 0.96763600E+02, -.35945400E+04, 0.35051600E+04, -.50896200E+04, -.13917500E+04, 0.18652800E+04, -.73005900E+04, -.84310200E+04, 0.10822300E+05, -.12456300E+04, 0.85168000E+04, 0.57264300E+04, 0.11099500E+04, -.80559200E+04, -.48308400E+04, -.61374200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16633100E+00, 0.15425600E+05, 0.41477100E+04, 0.33127200E+04, -.31783500E+04, 0.53338400E+03, -.21685900E+03, 0.36590900E+04, 0.33742400E+04, 0.39433300E+05, 0.96733900E+04, 0.71506400E+04, -.58268300E+04, 0.73389900E+03, -.26453000E+04, 0.84578300E+04, 0.42991400E+03, -.37776700E+05, -.94037500E+04, -.70137100E+04, 0.53461800E+04, -.55418100E+03, 0.17615000E+04, -.80470200E+04, 0.64937600E+04, -.16051700E+05, -.57131400E+04, -.48906100E+04, 0.31289000E+04, 0.15643900E+04, -.21251900E+03, -.52102800E+04, 0.25147500E+04, 0.10624400E+05, 0.33010800E+04, 0.23863000E+04, -.29056400E+04, 0.93865100E+03, -.36370900E+03, 0.27663700E+04, 0.32135200E+04, -.27610800E+05, -.98692500E+04, -.74193900E+04, 0.49650600E+04, 0.45206200E+03, 0.43526900E+03, -.83484000E+04, 0.57263800E+03, -.17375600E+05, -.58872900E+04, -.44338700E+04, 0.41857400E+04, -.27125700E+03, -.29607600E+03, -.49657400E+04, -.13982200E+04, 0.41649300E+05, 0.11916700E+05, 0.92209300E+04, -.82853300E+04, 0.67251000E+03, -.44906800E+02, 0.10382900E+05, -.74278400E+04, 0.27927500E+05, 0.79564500E+04, 0.67103100E+04, -.45381700E+04, -.15962200E+04, 0.53549300E+03, 0.72770000E+04, -.92921000E+03, -.19615000E+05, -.63623600E+04, -.49131000E+04, 0.46761300E+04, -.59286100E+03, 0.73256800E+03, -.55406700E+04, 0.31284300E+04, 0.18003800E+05, 0.50811800E+04, 0.34796600E+04, -.36338500E+04, 0.94228700E+03, -.31807600E+03, 0.41315300E+04, -.91227100E+03, -.12873600E+05, -.41132100E+04, -.31541700E+04, 0.32296400E+04, -.31988300E+03, 0.45695400E+03, -.35368700E+04, -.57497700E+03, -.63874000E+04, -.20475200E+04, -.15416100E+04, 0.15691200E+04, -.30934800E+03, 0.13143200E+03, -.17530200E+04, -.60921100E+04, -.31892400E+05, -.71355700E+04, -.49180900E+04, 0.49209800E+04, -.23477500E+04, 0.22649200E+04, -.59786300E+04, -.82716000E+04, 0.24156600E+05, 0.60526000E+04, 0.51004800E+04, -.18245000E+04, -.24562600E+04, 0.13692800E+02, 0.55515800E+04, 0.47175200E+04, 0.32425100E+05, 0.91200200E+04, 0.69061200E+04, -.78132400E+04, 0.24888200E+04, -.57644600E+03, 0.80156000E+04, -.59396300E+03, -.10726400E+04, 0.42674300E+04, -.50105600E+04, -.35522400E+04, 0.28084000E+04, 0.48907800E+04, -.28145400E+04, -.13970600E+04, 0.32393600E+04, 0.82642600E+04, 0.81027800E+03, -.14189300E+04, 0.77385500E+03, 0.28742700E+04, -.62776600E+04, 0.12279100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.43397600E+00, -.73621800E+00, 0.12314300E+05, 0.13619700E+05, -.14555000E+05, -.10262300E+05, -.13291400E+05, 0.13750000E+05, -.35424200E+05, 0.19059500E+05, 0.34656000E+05, 0.38931700E+05, -.28591700E+05, -.37902200E+05, -.42270000E+05, 0.39774400E+05, 0.35256600E+05, -.15650300E+05, -.31495800E+05, -.34224400E+05, 0.26498700E+05, 0.34757200E+05, 0.34615700E+05, -.34561000E+05, 0.40847600E+05, -.17129300E+05, -.20031300E+05, -.22892300E+05, 0.13785400E+05, 0.25813600E+05, 0.17060400E+05, -.22549700E+05, -.14597800E+05, 0.68448900E+04, 0.12380200E+05, 0.13831400E+05, -.10683800E+05, -.12689800E+05, -.12750800E+05, 0.13899600E+05, 0.44298400E+05, -.18410200E+05, -.35293600E+05, -.39485600E+05, 0.28625900E+05, 0.39843600E+05, 0.39850500E+05, -.39749700E+05, 0.59978800E+05, -.24937200E+05, -.24316400E+05, -.27297600E+05, 0.13753000E+05, 0.33510000E+05, 0.20782000E+05, -.27117300E+05, -.84493200E+05, 0.41607800E+05, 0.41004300E+05, 0.45590400E+05, -.27220600E+05, -.52715900E+05, -.36215900E+05, 0.45230100E+05, -.74125100E+05, 0.33207700E+05, 0.26967900E+05, 0.30120400E+05, -.13705200E+05, -.39525500E+05, -.20169000E+05, 0.29379600E+05, 0.29782400E+05, -.12487500E+05, -.24122300E+05, -.27135500E+05, 0.20569300E+05, 0.26220800E+05, 0.25702000E+05, -.27222100E+05, -.20933000E+05, 0.12502400E+05, 0.16640600E+05, 0.18404600E+05, -.13234000E+05, -.16528600E+05, -.17722300E+05, 0.18669900E+05, 0.12522400E+05, -.58654000E+04, -.13545600E+05, -.14916300E+05, 0.12573500E+05, 0.12460000E+05, 0.13295500E+05, -.15044200E+05, 0.82201200E+04, -.38313900E+04, -.71775400E+04, -.79882300E+04, 0.62624600E+04, 0.74655700E+04, 0.74059500E+04, -.80227400E+04, 0.47868100E+04, -.39685400E+04, -.23868800E+05, -.26106800E+05, 0.24363100E+05, 0.21612400E+05, 0.30726000E+05, -.26792800E+05, -.57289700E+05, 0.25373900E+05, 0.20958700E+05, 0.23587300E+05, -.94853700E+04, -.31528100E+05, -.19825300E+05, 0.23323300E+05, -.68787500E+05, 0.32504100E+05, 0.34086700E+05, 0.37568900E+05, -.22642500E+05, -.44223200E+05, -.31179100E+05, 0.37442900E+05, 0.10645800E+05, 0.12676700E+05, 0.35167600E+04, -.12943900E+04, -.15313500E+04, 0.27963700E+04, 0.40696200E+04, -.73107500E+04, -.15710800E+05, 0.16539300E+05, 0.49374000E+04, 0.22812900E+05, 0.95916700E+04, 0.36938800E+04, -.23284100E+04, -.15314500E+05, -.83695800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.25797600E+01, 0.52207000E+01, -.87841500E+00, 0.96830700E+04, -.94192800E+04, -.14761100E+05, -.33769900E+05, 0.80927500E+04, -.17997200E+06, 0.53382700E+05, 0.32485300E+05, 0.65874300E+05, -.19679000E+05, -.10355100E+06, -.94553700E+05, 0.60430800E+05, 0.13906600E+06, -.46056000E+05, -.20786500E+05, -.48297400E+05, 0.14244300E+05, 0.88727700E+05, 0.80932500E+05, -.42150900E+05, 0.10074000E+06, -.39172900E+05, -.14764700E+05, -.29974000E+05, 0.19618300E+04, 0.57340900E+05, 0.47611200E+05, -.26684900E+05, -.75064900E+05, 0.27500600E+05, 0.97772900E+04, 0.21132200E+05, -.49877800E+03, -.40269100E+05, -.32262500E+05, 0.18509800E+05, 0.22361500E+06, -.91148600E+05, -.31775200E+05, -.64648300E+05, 0.64841500E+04, 0.12283700E+06, 0.98980100E+05, -.56773000E+05, 0.19540500E+06, -.71263800E+05, -.25203400E+05, -.45819400E+05, -.63262800E+04, 0.93758200E+05, 0.61498700E+05, -.40571700E+05, -.26611400E+06, 0.10262900E+06, 0.31751600E+05, 0.68465600E+05, 0.30151300E+04, -.14092800E+06, -.10943800E+06, 0.59337000E+05, -.16332500E+06, 0.59625500E+05, 0.19493400E+05, 0.40149700E+05, 0.35641000E+04, -.87020700E+05, -.67626700E+05, 0.34931900E+05, 0.14265900E+06, -.61695900E+05, -.20812600E+05, -.42398800E+05, 0.33893600E+04, 0.78328300E+05, 0.64284500E+05, -.37496600E+05, -.11694500E+06, 0.46122300E+05, 0.13077300E+05, 0.31362500E+05, 0.28110700E+03, -.60723900E+05, -.49693000E+05, 0.26953000E+05, 0.63259600E+05, -.21803000E+05, -.73324400E+04, -.18907500E+05, 0.13509600E+04, 0.35920000E+05, 0.32704500E+05, -.16359200E+05, 0.40125800E+05, -.14648200E+05, -.51328200E+04, -.11564600E+05, 0.62520000E+03, 0.22384500E+05, 0.18971500E+05, -.10070200E+05, 0.93412200E+05, -.10329400E+05, -.16589400E+05, -.39503000E+05, 0.16580200E+05, 0.65261500E+05, 0.59597700E+05, -.34965200E+05, -.12063700E+06, 0.42007400E+05, 0.19508200E+05, 0.36342400E+05, -.64507400E+04, -.67638900E+05, -.58539400E+05, 0.33321900E+05, -.23389300E+06, 0.85109700E+05, 0.28447300E+05, 0.57671100E+05, 0.43813900E+04, -.12106200E+06, -.89485500E+05, 0.50248900E+05, 0.50136900E+05, 0.54411500E+05, -.51836200E+05, 0.54571900E+05, 0.26090000E+05, 0.14761500E+04, -.18788500E+05, 0.13858200E+05, -.73957100E+04, -.15469900E+04, -.26097700E+05, 0.27723700E+05, 0.39035500E+05, 0.72171900E+04, -.67280500E+05, 0.34834300E+05, 0.57048700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27703700E+01, -.29507900E+00, 0.52620800E+00, 0.40093300E+00, 0.86525600E+04, 0.26692300E+04, -.46625200E+04, 0.43893100E+03, -.26300000E+05, 0.16494200E+05, 0.12722800E+05, 0.12419100E+05, 0.93185400E+04, -.54184000E+04, -.57728000E+04, 0.13116900E+05, 0.27028200E+05, -.20010400E+05, -.62086200E+04, -.43506000E+04, -.18524500E+05, 0.20851000E+04, 0.29588300E+04, -.54605000E+04, -.54058500E+04, 0.61627600E+03, 0.46021300E+04, 0.58266300E+04, -.15349400E+05, -.58325900E+04, 0.25166000E+04, 0.50625600E+04, 0.32065600E+04, 0.45646100E+03, -.56546100E+03, -.12574500E+04, 0.70733400E+04, 0.20032800E+04, -.28072600E+04, -.79424900E+03, 0.45407000E+04, -.11303000E+05, -.45112000E+04, -.33144700E+04, -.14455000E+05, -.35201800E+04, 0.57624700E+04, -.45894300E+04, -.13885600E+05, -.25554900E+04, 0.65020700E+04, 0.90483200E+04, -.15278000E+05, -.99372900E+04, 0.20299200E+03, 0.80369100E+04, -.17536800E+05, 0.14118300E+05, -.50253900E+04, -.86440100E+04, 0.35676900E+05, 0.32600300E+04, -.27365000E+04, -.72950100E+04, -.18963800E+05, 0.11846800E+05, -.57050800E+04, -.81616900E+04, 0.28184800E+05, 0.87980000E+03, 0.48685800E+03, -.74019000E+04, 0.11352000E+04, -.28911900E+04, -.68839700E+02, 0.88265100E+03, -.14202000E+05, -.22439800E+04, 0.51117000E+04, 0.91481200E+02, -.12846400E+05, 0.82753700E+04, 0.29785500E+04, 0.21955500E+04, 0.10447800E+05, -.43222000E+04, -.36415300E+04, 0.26141200E+04, -.24091400E+04, -.10753800E+04, 0.72108000E+03, 0.14249100E+04, -.87830300E+04, -.15174600E+04, 0.37959700E+04, 0.88483200E+03, -.62963500E+03, -.81960900E+03, 0.20962400E+03, 0.57000800E+03, -.43860100E+04, -.10525500E+04, 0.16039000E+04, 0.30029500E+03, 0.17113300E+05, -.13380200E+05, -.10432000E+05, -.10119700E+05, -.57555300E+04, 0.20014800E+04, 0.49909500E+04, -.11039400E+05, -.29236300E+05, 0.16079300E+05, 0.20881700E+04, 0.64471900E+03, 0.16460700E+05, -.48243100E+04, 0.22504800E+04, 0.97493600E+03, -.32333500E+04, 0.75872700E+04, -.47708800E+04, -.79484800E+04, 0.25176300E+05, 0.77760900E+04, -.13242500E+04, -.66528700E+04, -.12894500E+04, -.36431800E+04, -.11278600E+05, 0.81932200E+04, 0.17677400E+04, 0.19629100E+04, -.11964700E+05, 0.13233200E+05, 0.16168100E+03, 0.28786100E+04, 0.30780600E+04, -.76588100E+04, -.42212600E+03, -.22579400E+04, -.13449600E+05, 0.77459100E+04, 0.80574000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16201900E+01, 0.69931500E-01, 0.12287200E+01, 0.52698400E+00, 0.55618500E+00, 0.89344000E+04, 0.14761000E+05, 0.10640700E+04, 0.88815700E+05, -.29929200E+05, -.21533500E+05, -.26688400E+05, 0.50062500E+04, 0.53674400E+05, 0.42725700E+05, -.23475100E+05, -.61823300E+05, 0.27270800E+05, 0.14205800E+05, 0.17963800E+05, -.23161800E+04, -.43945600E+05, -.38818900E+05, 0.14247200E+05, -.45866200E+05, 0.19210300E+05, 0.68257900E+04, 0.94837400E+04, 0.42855100E+04, -.28258200E+05, -.21921400E+05, 0.77174400E+04, 0.29597700E+05, -.12483500E+05, -.50274800E+04, -.68639900E+04, -.16299600E+04, 0.17860700E+05, 0.15244000E+05, -.55558700E+04, -.86584100E+05, 0.44041700E+05, 0.18288700E+05, 0.24405300E+05, -.16833900E+04, -.54967800E+05, -.47790000E+05, 0.20509900E+05, -.66168900E+05, 0.32657100E+05, 0.10947000E+05, 0.15847600E+05, 0.28845100E+04, -.37667100E+05, -.30402000E+05, 0.13422600E+05, 0.11566900E+06, -.50848300E+05, -.16445200E+05, -.23436900E+05, -.10065700E+05, 0.66976900E+05, 0.51349500E+05, -.18496600E+05, 0.72609700E+05, -.30950500E+05, -.95449400E+04, -.14022500E+05, -.78556100E+04, 0.42318300E+05, 0.32460000E+05, -.11070700E+05, -.58453400E+05, 0.27142400E+05, 0.10819600E+05, 0.14390800E+05, 0.21563500E+04, -.36230000E+05, -.30492700E+05, 0.11832900E+05, 0.52325900E+05, -.23816300E+05, -.80920700E+04, -.11142400E+05, -.32878700E+04, 0.27819900E+05, 0.22827200E+05, -.88357800E+04, -.23730100E+05, 0.99074300E+04, 0.39016900E+04, 0.53799900E+04, 0.17286600E+04, -.15927100E+05, -.15569300E+05, 0.40919400E+04, -.15800900E+05, 0.67064400E+04, 0.27116100E+04, 0.37167200E+04, 0.81323500E+03, -.10128900E+05, -.90012800E+04, 0.29655400E+04, -.44779400E+05, 0.10903200E+05, 0.12469300E+05, 0.14706100E+05, -.48165700E+04, -.33040100E+05, -.27706500E+05, 0.11901300E+05, 0.60863700E+05, -.25229300E+05, -.11928400E+05, -.15730000E+05, -.65516500E+03, 0.34757900E+05, 0.27604200E+05, -.13681700E+05, 0.88076300E+05, -.37831400E+05, -.14160400E+05, -.20101400E+05, -.49066100E+04, 0.53597900E+05, 0.43627500E+05, -.16391500E+05, -.19659700E+05, -.22271800E+05, 0.26881500E+05, -.25357100E+05, -.97801700E+04, -.59883000E+03, 0.12092700E+05, -.10780500E+05, 0.54290700E+04, 0.44686400E+03, 0.64451800E+04, -.15127800E+05, -.19148800E+05, -.27275900E+04, 0.32317200E+05, -.17057400E+05, -.79425600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.58341500E+00, -.38294400E+00, 0.61656100E-01, -.62947500E-01, 0.16983500E+00, 0.26976500E+00, 0.23745100E+04, -.40304300E+03, 0.13382000E+05, -.78665800E+04, -.55358000E+04, -.68646300E+04, 0.32380500E+04, 0.75356000E+04, 0.12290900E+05, -.82853200E+04, -.28936600E+04, 0.13051500E+04, 0.34200900E+04, 0.42288600E+04, -.28325500E+04, -.37435000E+04, -.94046800E+04, 0.55599100E+04, -.76271700E+04, 0.34966600E+04, 0.27745900E+04, 0.34852400E+04, -.90479800E+03, -.44439100E+04, -.59232200E+04, 0.41819500E+04, 0.33409300E+04, -.16361200E+04, -.14043200E+04, -.17406800E+04, 0.63091400E+03, 0.20514700E+04, 0.35204200E+04, -.22232100E+04, -.10968500E+05, 0.47270600E+04, 0.49465800E+04, 0.61217600E+04, -.29268700E+04, -.70266200E+04, -.12008400E+05, 0.75854000E+04, -.11641400E+05, 0.47186200E+04, 0.49164700E+04, 0.61755100E+04, -.23801100E+04, -.70879200E+04, -.94673300E+04, 0.71383100E+04, 0.99256800E+04, -.51285400E+04, -.60878600E+04, -.77410700E+04, 0.36758400E+04, 0.76687800E+04, 0.13797300E+05, -.94504900E+04, 0.10821200E+05, -.50350700E+04, -.46196800E+04, -.59565000E+04, 0.19503800E+04, 0.70430000E+04, 0.93475700E+04, -.68384700E+04, -.75467300E+04, 0.34902300E+04, 0.30347100E+04, 0.37642600E+04, -.12845500E+04, -.44560100E+04, -.72210800E+04, 0.47113700E+04, 0.91866700E+03, -.75236900E+03, -.20273100E+04, -.24782300E+04, 0.19062300E+04, 0.18484500E+04, 0.57172700E+04, -.32829900E+04, -.17202800E+04, 0.82881400E+03, 0.99303700E+03, 0.12363200E+04, -.51333200E+03, -.13184500E+04, -.33599500E+04, 0.17458200E+04, -.17576300E+04, 0.84969900E+03, 0.78072200E+03, 0.97079100E+03, -.38452900E+03, -.11251500E+04, -.20878200E+04, 0.12457400E+04, -.46801500E+03, 0.73162400E+03, 0.17527100E+04, 0.20050400E+04, -.19105700E+04, -.15899600E+04, -.56685500E+04, 0.30433000E+04, 0.11001600E+05, -.53430500E+04, -.47749900E+04, -.61500400E+04, 0.26716900E+04, 0.73340400E+04, 0.10199400E+05, -.69221800E+04, 0.13375600E+05, -.63548400E+04, -.60495600E+04, -.76219100E+04, 0.30327800E+04, 0.84927200E+04, 0.12416900E+05, -.89278500E+04, -.22292700E+04, -.22091300E+04, 0.25205900E+04, -.46480100E+04, 0.22263700E+02, -.20427500E+03, 0.15467900E+04, 0.19021500E+03, 0.29669600E+04, -.57299600E+04, 0.62179900E+03, -.26296200E+04, -.28082600E+04, -.42436600E+03, 0.58630800E+04, 0.13039700E+04, 0.15446500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.73362200E+00, 0.64649200E-01, 0.87580000E-01, 0.10328100E+00, 0.62504200E-01, -.91000200E-01, 0.59927700E+00, 0.39150200E+03, -.45047700E+04, 0.60735000E+04, 0.32718300E+04, 0.38805700E+04, -.27136900E+04, -.28655000E+04, -.56238100E+04, 0.54308400E+04, -.46733300E+04, 0.10758300E+04, -.15874400E+04, -.15738600E+04, 0.27167300E+04, 0.24346700E+03, 0.32503700E+04, -.30014600E+04, 0.18272500E+04, -.17673400E+04, -.21823900E+04, -.25398000E+04, 0.20409900E+04, 0.23552600E+04, 0.38255500E+04, -.32927600E+04, -.10392200E+03, 0.71429000E+03, 0.89995700E+03, 0.97504700E+03, -.97333700E+03, -.50871600E+03, -.14871100E+04, 0.15199200E+04, 0.23225700E+04, -.14600000E+04, -.32569800E+04, -.36031400E+04, 0.31459700E+04, 0.30798400E+04, 0.55534700E+04, -.52438700E+04, 0.41681200E+04, -.26333400E+04, -.38386800E+04, -.43094300E+04, 0.31201700E+04, 0.37611500E+04, 0.58124700E+04, -.54091700E+04, 0.47562100E+04, -.25993200E+02, 0.41220200E+04, 0.44847800E+04, -.55592300E+04, -.14781700E+04, -.72502200E+04, 0.64307200E+04, -.22156700E+03, 0.17810800E+04, 0.33713500E+04, 0.37794500E+04, -.36414400E+04, -.28836900E+04, -.54421000E+04, 0.48293300E+04, 0.10267900E+04, -.10827300E+04, -.19507500E+04, -.21555900E+04, 0.19183500E+04, 0.14567100E+04, 0.32159600E+04, -.32153800E+04, 0.50155200E+04, -.15765100E+04, 0.10638700E+04, 0.10201300E+04, -.22632500E+04, 0.12544700E+04, -.20432000E+04, 0.19751000E+04, -.10683600E+04, -.82039800E+02, -.52372300E+03, -.51394700E+03, 0.79489500E+03, -.19693400E+03, 0.96010000E+03, -.10748800E+04, -.17881100E+02, -.33843500E+03, -.50168000E+03, -.54187500E+03, 0.56485300E+03, 0.31028400E+03, 0.86323300E+03, -.84968000E+03, -.58570000E+04, -.48020200E+02, -.31955500E+01, 0.19105700E+03, 0.14539500E+04, -.11386500E+04, 0.12474800E+04, -.89670100E+03, -.44505600E+04, 0.37480700E+04, 0.36398800E+04, 0.43340600E+04, -.30900600E+04, -.43889700E+04, -.61398800E+04, 0.52276400E+04, -.25861000E+04, 0.31883700E+04, 0.44345800E+04, 0.49312100E+04, -.41538700E+04, -.39799400E+04, -.68822400E+04, 0.64242900E+04, 0.42305900E+02, 0.30695600E+03, 0.83620400E+03, 0.88023800E+03, -.83010000E+03, 0.11222000E+03, 0.41305600E+03, -.15207900E+04, -.19929500E+04, 0.46591300E+04, 0.34212000E+03, 0.12294200E+04, 0.64479400E+03, 0.23252600E+03, -.10232500E+04, -.34014000E+04, -.18541200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25781000E+00, 0.28000000E+00, 0.77769800E-01, 0.78733800E-01, -.61764100E-01, -.22755000E+00, -.14652700E+01, -.75652700E+00, -.61276600E+04, 0.46464600E+04, 0.25598300E+04, 0.31531900E+04, -.20948200E+04, -.29817000E+04, -.24932000E+04, 0.34498900E+04, 0.61912000E+03, -.13251300E+04, -.12282800E+04, -.13086900E+04, 0.19453600E+04, 0.11595000E+04, 0.12079400E+04, -.14881900E+04, 0.30578500E+04, -.25977200E+04, -.11797900E+04, -.17090000E+04, 0.13676300E+04, 0.22704700E+04, 0.30168100E+04, -.17475100E+04, -.14298100E+04, 0.14363900E+04, 0.69256200E+03, 0.93680100E+03, -.83140800E+03, -.10431800E+04, -.14405200E+04, 0.98980300E+03, 0.67677600E+04, -.50192700E+04, -.27785500E+04, -.36959700E+04, 0.26235700E+04, 0.45520600E+04, 0.47460700E+04, -.38871500E+04, 0.66972900E+04, -.54605900E+04, -.21425800E+04, -.29578300E+04, 0.17344800E+04, 0.40902500E+04, 0.46633600E+04, -.30339000E+04, -.44345900E+04, 0.45959500E+04, 0.18357600E+04, 0.26449000E+04, -.26024500E+04, -.34710500E+04, -.51932900E+04, 0.27361400E+04, -.27498200E+04, 0.39888800E+04, 0.10649700E+04, 0.16329200E+04, -.17916800E+04, -.24354100E+04, -.34595700E+04, 0.16679600E+04, 0.30653900E+04, -.24774200E+04, -.14678600E+04, -.19559700E+04, 0.17300700E+04, 0.21698700E+04, 0.28259100E+04, -.20631500E+04, 0.12314100E+03, 0.66798600E+03, 0.50392100E+03, 0.72510100E+03, -.11036800E+04, -.42190800E+03, -.14172000E+04, 0.85282800E+03, -.45171500E+02, -.65593600E+03, -.38903500E+03, -.50059700E+03, 0.77035300E+03, 0.24951300E+03, 0.90741500E+03, -.57260300E+03, 0.70285900E+03, -.75199800E+03, -.35996100E+03, -.48945100E+03, 0.45004000E+03, 0.55895900E+03, 0.78062800E+03, -.52020800E+03, -.19546400E+04, -.44506700E+03, -.70186100E+03, -.61528300E+03, 0.15335700E+04, 0.21789000E+02, 0.34896400E+03, -.83593800E+03, -.51453700E+04, 0.42256900E+04, 0.17699500E+04, 0.23021400E+04, -.15993300E+04, -.29908200E+04, -.21842800E+04, 0.24648800E+04, -.60074000E+04, 0.58729800E+04, 0.21517300E+04, 0.29363600E+04, -.21868100E+04, -.40790600E+04, -.49279800E+04, 0.30397100E+04, 0.94667600E+03, 0.10294300E+04, -.39303900E+02, 0.73251800E+03, -.19621500E+03, 0.45811800E+02, 0.38402400E+03, -.88447900E+03, -.89236100E+03, 0.86094000E+03, -.25129200E+03, 0.13642400E+04, 0.10965700E+04, 0.35892800E+03, -.53198900E+03, -.31579500E+03, -.57300200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.33684200E+01, -.42984200E+00, -.20786200E+01, -.10778500E+01, -.12476100E+01, -.13077500E+01, -.12503300E+01, -.35904200E+01, -.32583300E+01, 0.16100000E+05, 0.52985000E+04, 0.64486600E+04, -.80472500E+04, -.29556900E+04, -.20161100E+05, 0.87143800E+04, -.33458700E+05, 0.48398100E+04, 0.16590800E+04, 0.41884400E+04, 0.79273100E+04, -.52274800E+04, 0.96666600E+04, 0.27785300E+04, 0.13838400E+05, -.14266800E+05, -.79838800E+04, -.10333300E+05, 0.88165400E+04, 0.13037000E+05, 0.20040300E+05, -.10987000E+05, -.59668200E+04, 0.79109400E+04, 0.35414300E+04, 0.43613400E+04, -.38829500E+04, -.50271800E+04, -.87124900E+04, 0.49092500E+04, 0.16953900E+05, -.19861400E+05, -.10842200E+05, -.13542600E+05, 0.11910600E+05, 0.18724000E+05, 0.29576900E+05, -.15484300E+05, 0.20161600E+05, -.25032300E+05, -.11238200E+05, -.13607900E+05, 0.11147300E+05, 0.16870300E+05, 0.28520700E+05, -.14899100E+05, -.70004700E+04, 0.19393500E+05, 0.11498500E+05, 0.13500500E+05, -.16448600E+05, -.15292500E+05, -.34499300E+05, 0.15159200E+05, -.69994000E+04, 0.17930600E+05, 0.83881000E+04, 0.98048400E+04, -.12280700E+05, -.13372600E+05, -.24105400E+05, 0.10537000E+05, 0.12837600E+05, -.12868600E+05, -.72778400E+04, -.89068100E+04, 0.76954000E+04, 0.10696800E+05, 0.17958600E+05, -.99623500E+04, 0.97109700E+04, 0.15558600E+03, 0.21063200E+04, 0.23054500E+04, -.57390100E+04, 0.95003500E+03, -.95360000E+04, 0.34989000E+04, -.36174600E+04, -.31004200E+04, -.13027800E+04, -.13118800E+04, 0.33730500E+04, -.34696100E+03, 0.51334700E+04, -.18812400E+04, 0.26899400E+04, -.40369600E+04, -.18561300E+04, -.22693600E+04, 0.21730800E+04, 0.27598000E+04, 0.48199200E+04, -.25655300E+04, -.52969900E+05, 0.10369900E+05, 0.75527400E+04, 0.10607800E+05, 0.51550300E+04, -.14499900E+05, 0.28384300E+04, 0.93136700E+04, -.12525200E+05, 0.18019700E+05, 0.86823200E+04, 0.10166300E+05, -.96328600E+04, -.14147800E+05, -.20550100E+05, 0.11486400E+05, -.20056700E+05, 0.26538300E+05, 0.12486200E+05, 0.14604700E+05, -.13386300E+05, -.19747300E+05, -.32121200E+05, 0.16049800E+05, 0.37726200E+04, 0.48911200E+04, -.46524600E+04, 0.62312200E+04, -.26097100E+04, 0.32874300E+02, 0.50629100E+03, -.45882300E+04, -.66365700E+04, 0.87113800E+04, -.96961300E+03, 0.71635800E+04, 0.62993100E+04, 0.17545100E+04, -.77091500E+04, -.19670200E+04, -.30999700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.65673600E+01, -.10749800E+02, 0.13694100E+01, -.23540000E+01, -.62542100E+00, 0.74626700E+00, -.60150500E+01, -.89213500E+01, -.34057100E+01, -.18514500E+00, 0.99944700E+04, 0.10895200E+05, -.12063700E+05, -.18084600E+04, -.27139600E+05, 0.15562400E+05, -.68750000E+05, 0.30751800E+05, 0.19557800E+04, 0.66058300E+04, 0.16185600E+05, -.12051900E+05, 0.16255300E+05, 0.31704300E+04, 0.14235200E+05, -.14578900E+05, -.12875900E+05, -.15682800E+05, 0.15624700E+05, 0.18403400E+05, 0.32104100E+05, -.17025500E+05, -.36336400E+04, 0.52272400E+04, 0.55360600E+04, 0.62547900E+04, -.70468600E+04, -.57410500E+04, -.13355200E+05, 0.74608500E+04, 0.22046700E+03, -.12474900E+05, -.16833500E+05, -.18704400E+05, 0.22523300E+05, 0.20507000E+05, 0.43508300E+05, -.23161200E+05, 0.19974700E+05, -.26055900E+05, -.17975800E+05, -.20658100E+05, 0.19416700E+05, 0.21899000E+05, 0.42918200E+05, -.23381200E+05, 0.88836700E+04, 0.80176600E+04, 0.17629200E+05, 0.19273400E+05, -.28999800E+05, -.17492300E+05, -.54725900E+05, 0.22624600E+05, -.52264100E+04, 0.20359100E+05, 0.13134800E+05, 0.14707200E+05, -.20384600E+05, -.20145500E+05, -.38540100E+05, 0.15728300E+05, 0.25358700E+04, -.73107000E+04, -.10861900E+05, -.12017600E+05, 0.14986300E+05, 0.10455400E+05, 0.28261200E+05, -.14456900E+05, 0.27060800E+05, -.11792300E+05, 0.30067600E+04, 0.22516200E+04, -.10292700E+05, 0.64748600E+04, -.13381500E+05, 0.48669200E+04, -.11071800E+05, 0.23856200E+04, -.22422900E+04, -.17460300E+04, 0.63758500E+04, -.29259700E+04, 0.75670700E+04, -.30421200E+04, 0.11806500E+04, -.25635400E+04, -.29801300E+04, -.33073800E+04, 0.39278200E+04, 0.32771000E+04, 0.72523300E+04, -.39617200E+04, -.85856100E+05, 0.45010200E+05, 0.10168600E+05, 0.15324400E+05, 0.94048600E+04, -.22160600E+05, 0.43211200E+04, 0.11971100E+05, -.22620900E+05, 0.21553000E+05, 0.15256800E+05, 0.17352700E+05, -.15077300E+05, -.24021700E+05, -.29176400E+05, 0.19604600E+05, -.17598900E+05, 0.24070200E+05, 0.19073700E+05, 0.21352100E+05, -.22934100E+05, -.26808300E+05, -.50151700E+05, 0.24028200E+05, 0.21315800E+04, 0.46532500E+04, -.17999400E+04, 0.59894100E+04, -.67121000E+04, -.82065900E+03, 0.14883400E+04, -.94365200E+04, -.13274200E+05, 0.17663400E+05, -.97891000E+03, 0.11888400E+05, 0.79911100E+04, 0.22568800E+04, -.65033900E+04, -.88789800E+04, -.79189200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15719300E+01, 0.10471100E+01, -.35935800E+00, 0.32992400E+00, 0.10158300E+00, -.33465600E+00, 0.17255500E+01, 0.23581100E+01, -.92711500E+00, 0.49856800E-01, -.13679100E+00, 0.38330500E+03, -.34776500E+03, -.78727700E+03, -.90982300E+03, 0.62350500E+03, 0.20728700E+03, -.36674900E+03, 0.36057200E+03, 0.67710200E+02, 0.68850800E+02, 0.40896900E+01, 0.47291600E+03, -.10373200E+03, 0.25539500E+04, -.23329100E+04, -.20195800E+03, -.73658300E+03, 0.38447400E+03, 0.12019800E+04, 0.12633200E+04, -.69683800E+03, -.19797000E+04, 0.15432900E+04, 0.30839700E+03, 0.65207400E+03, -.20750700E+03, -.10931500E+04, -.96077000E+03, 0.62027900E+03, 0.53738500E+04, -.45956500E+04, -.93307700E+03, -.20897100E+04, 0.58318100E+03, 0.32026300E+04, 0.32933800E+04, -.20926700E+04, 0.48476500E+04, -.48223500E+04, -.41363500E+03, -.13853100E+04, 0.28603900E+03, 0.25922100E+04, 0.25960200E+04, -.13586100E+04, -.92580800E+04, 0.63528200E+04, 0.33148100E+02, 0.12952400E+04, 0.58161100E+03, -.37516700E+04, -.22665200E+04, 0.11055400E+04, -.42309600E+04, 0.51613000E+04, -.31905400E+03, 0.53011300E+03, 0.29369700E+02, -.15703900E+04, -.11845200E+04, 0.44956700E+03, 0.37311300E+04, -.27751500E+04, -.57410800E+03, -.12423800E+04, 0.41537800E+03, 0.20639200E+04, 0.18633000E+04, -.11943200E+04, -.38050400E+04, 0.21217400E+04, -.21980600E+02, 0.48440400E+03, 0.48656700E+03, -.17901100E+04, -.92329300E+03, 0.42091500E+03, 0.97116300E+03, -.96245600E+03, -.18419700E+03, -.43631100E+03, 0.26870300E+03, 0.66504700E+03, 0.72706700E+03, -.43296400E+03, 0.10668200E+04, -.85295200E+03, -.15301600E+03, -.34331600E+03, 0.96316100E+02, 0.57172800E+03, 0.49739400E+03, -.32980100E+03, -.29870100E+04, 0.22890900E+04, 0.23738200E+03, 0.27986000E+03, 0.40878100E+03, -.97001300E+03, 0.22749600E+03, -.16422800E+02, -.22216200E+04, 0.27875300E+04, -.28154600E+03, 0.21509900E+03, 0.93591800E+02, -.67565600E+03, 0.55595600E+00, 0.33018500E+03, -.56651500E+04, 0.57229100E+04, 0.14460000E+03, 0.11962300E+04, -.43024500E+02, -.25977900E+04, -.22929900E+04, 0.11330900E+04, 0.13758900E+04, 0.12189400E+04, -.93628100E+03, 0.12265900E+04, 0.57400000E+03, 0.11850400E+03, -.91027600E+02, -.21475900E+03, 0.31237000E+03, -.10153300E+04, -.57584700E+03, 0.45499400E+03, 0.97368600E+03, 0.26298300E+03, -.11970000E+04, 0.12370800E+04, 0.19219900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26852900E+01, -.11055100E+00, -.19836800E+00, -.82270300E-01, 0.85142200E-02, -.18053100E+00, -.43476100E-01, -.48073200E+00, -.36098500E+00, 0.19022300E-01, 0.35664000E-01, -.39232500E-01, 0.54477200E+03, 0.10178800E+04, 0.29816200E+04, 0.46222000E+02, 0.25969100E+04, -.22535300E+03, -.10174000E+04, -.11838300E+04, 0.46661900E+03, 0.76143100E+03, -.12205700E+04, -.12719200E+04, -.35739600E+03, 0.36945900E+02, -.34433900E+02, -.16505800E+03, 0.22353300E+03, 0.13340000E+03, 0.34182800E+03, -.55481600E+02, 0.44386600E+03, -.32265500E+02, 0.20196800E+03, 0.29813000E+03, -.35256200E+03, 0.91653600E+02, -.32514000E+03, 0.28222700E+03, -.28937200E+03, 0.36237300E+03, -.56878900E+03, -.86149900E+03, 0.59472800E+03, 0.16755900E+03, 0.52049400E+03, -.80250400E+03, 0.42740000E+03, -.15475700E+01, -.14646700E+02, -.21141700E+03, -.82321200E+02, 0.45260000E+03, 0.62661700E+03, -.73605500E+02, 0.42488500E+03, 0.86156300E+03, 0.14889600E+03, 0.44802900E+03, -.42428100E+03, -.57498600E+03, -.14061500E+04, 0.28014800E+03, -.75910300E+03, 0.20503600E+04, 0.98240000E+02, 0.33549300E+03, -.98037100E+02, -.86852500E+03, -.96961900E+03, 0.14220600E+03, -.35500800E+03, 0.14186400E+03, -.39804800E+03, -.62248600E+03, 0.62015700E+03, 0.36533200E+02, 0.43202900E+03, -.57921500E+03, 0.76551300E+03, 0.81234000E+02, 0.27749500E+03, 0.48367600E+03, -.42076900E+03, 0.20068200E+03, -.83613400E+03, 0.50639500E+03, -.34568300E+03, 0.12342400E+03, -.30926800E+03, -.39415900E+03, 0.44415500E+03, -.13750400E+03, 0.25701900E+03, -.41255200E+03, -.30169700E+03, 0.40493200E+02, -.89258200E+02, -.13811900E+03, 0.17892200E+03, -.43479100E+02, 0.20485100E+03, -.12950400E+03, 0.11780000E+04, 0.17982100E+03, -.73196700E+03, -.83403800E+03, 0.16071700E+03, -.67328700E+02, -.20309500E+04, -.10541400E+04, -.13093600E+04, 0.12445000E+04, 0.22910400E+03, 0.40309700E+03, 0.87534000E+02, -.40091900E+03, 0.68714700E+03, 0.29639300E+03, 0.77073900E+03, 0.93540900E+03, -.14654900E+03, 0.48209000E+01, -.35666600E+02, -.24639600E+03, -.62644700E+03, -.15351700E+03, -.36368300E+03, -.15231400E+03, 0.66110100E+03, -.56669400E+03, -.28880800E+03, -.23876400E+02, 0.17535000E+03, -.45245900E+03, -.41671900E+03, 0.30755500E+03, 0.26185300E+02, 0.25374400E+03, 0.53442500E+01, 0.28759000E+02, 0.11735400E+04, -.32968500E+03, -.25770700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12195900E+01, -.61351700E+00, 0.12162800E+00, -.69592200E-01, 0.16836100E+00, 0.46392100E+00, 0.80024700E+00, -.36704400E+00, 0.17504500E+00, 0.45611400E-01, -.27881400E-01, -.64054100E+00, 0.39953500E+00, -.13947700E+04, -.26019300E+04, 0.12394200E+03, -.36776700E+03, -.12329800E+04, 0.67904300E+03, 0.89094200E+03, -.94941100E+03, -.48043500E+03, 0.12668700E+04, 0.84545100E+03, 0.17191800E+04, -.19883500E+04, -.57118800E+03, -.61677400E+03, 0.94166600E+02, 0.48886200E+03, 0.22399100E+03, -.74999300E+03, -.94667300E+03, 0.88509300E+03, 0.12989000E+03, 0.12529300E+03, 0.18197700E+03, -.39715500E+03, -.15470900E+03, 0.15109300E+03, 0.81657200E+03, -.26386500E+04, -.29256200E+03, -.30166900E+03, -.13699900E+03, 0.40067900E+03, 0.14842400E+04, -.48719400E+03, -.52262500E+02, -.30191900E+04, -.39465600E+03, -.27408700E+03, 0.37345500E+03, 0.11487500E+03, 0.55936500E+03, -.49089000E+03, -.51102200E+04, 0.38036200E+04, 0.69479400E+03, 0.54079100E+03, 0.83527800E+03, -.14285100E+04, 0.22245100E+03, 0.69086800E+03, -.21786400E+04, 0.34441000E+04, 0.54467200E+03, 0.39611600E+03, 0.13894900E+03, -.25637700E+03, 0.19519300E+03, 0.58261500E+03, 0.17532000E+04, -.18820000E+04, -.28869700E+03, -.28319900E+03, -.33279000E+03, 0.79661100E+03, 0.61233500E+03, -.35166500E+03, -.20427200E+04, 0.91706200E+03, 0.12147600E+03, 0.84471800E+02, 0.49568300E+03, -.99262900E+03, -.20618100E+03, 0.58873900E+02, 0.70433800E+03, -.78346500E+03, -.56211300E+02, -.49340000E+02, -.17338800E+03, 0.44596500E+03, 0.24403500E+03, -.51404600E+02, 0.58155600E+03, -.53176500E+03, -.96737000E+02, -.97954500E+02, -.84370300E+02, 0.21188300E+03, 0.83829800E+02, -.11609600E+03, -.92024500E+03, 0.66080400E+03, 0.63743800E+03, 0.73148600E+03, -.56854900E+03, -.52914400E+03, 0.13128200E+04, 0.74641900E+03, -.40314200E+03, 0.20842800E+04, 0.11969200E+03, 0.12812500E+01, 0.88415800E+02, -.11664900E+03, -.11621900E+04, 0.16651200E+03, -.28389900E+04, 0.32955200E+04, 0.48946400E+03, 0.34330600E+03, 0.32986800E+03, -.59945200E+03, -.32238300E+02, 0.54042700E+03, 0.74438500E+03, 0.47329400E+03, -.97464900E+03, 0.95230500E+03, 0.25223100E+03, 0.21700000E+03, -.20559200E+03, 0.31673700E+03, 0.26571500E+03, -.36950500E+03, 0.18238900E+03, 0.78175700E+02, 0.32058600E+03, 0.69071300E+02, -.14802300E+04, 0.62788600E+03, 0.46097400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12044000E+01, -.19377700E+00, 0.85234600E-01, -.49339600E-01, 0.40271300E-01, -.22268500E-01, 0.44129900E+00, 0.22635100E+00, 0.22228000E+00, -.36707400E-01, -.29827800E-01, 0.10148800E+00, 0.99979000E-01, -.25457800E+00, -.14538000E+04, 0.18671900E+03, -.34090200E+04, 0.13429900E+04, 0.85129600E+03, 0.10132700E+04, -.19534900E+03, -.64633200E+03, 0.39209700E+03, 0.88242700E+03, -.11239900E+04, 0.11523900E+03, -.16137200E+03, -.25907500E+02, 0.38303300E+03, -.26112200E+03, 0.22404500E+03, -.22776400E+03, 0.52372400E+03, -.24889900E+03, -.75925000E+02, -.17624300E+03, 0.37474300E+02, 0.24456300E+03, 0.20836200E+03, -.73832300E+02, -.26553700E+04, 0.10240000E+04, 0.16983900E+03, 0.49994900E+03, 0.18415500E+03, -.64508200E+03, -.64565400E+01, 0.17417200E+03, -.19984400E+04, 0.41780300E+03, -.19645500E+03, -.58396900E+01, 0.53739400E+03, -.85168200E+03, 0.64613900E+02, -.32511200E+03, 0.37918100E+04, -.17500100E+04, -.35594500E+03, -.70833300E+03, -.26489300E+03, 0.18166300E+04, 0.93145800E+03, -.25738400E+03, 0.38068300E+04, -.12623100E+04, -.90966700E+02, -.31586200E+03, -.72861800E+03, 0.13357300E+04, 0.19554500E+03, 0.13551700E+02, -.13545200E+04, 0.35094300E+03, 0.13517800E+03, 0.32273000E+03, 0.13924900E+02, -.54005000E+03, -.11774700E+03, 0.11776900E+03, 0.82635200E+03, -.69854800E+03, -.41822600E+03, -.65898100E+03, 0.42134900E+03, 0.76782000E+03, 0.10861900E+04, -.50107800E+03, -.32962400E+03, 0.12559800E+03, 0.16013100E+03, 0.24259600E+03, -.17610300E+03, -.26098700E+03, -.27335800E+03, 0.17361200E+03, -.27929700E+03, 0.12901300E+03, 0.27746700E+02, 0.80750900E+02, -.63756900E+01, -.11225700E+03, -.10986900E+03, 0.26590700E+02, -.22510000E+04, 0.13450000E+04, 0.83903100E+03, 0.10041700E+04, -.30936700E+03, -.41763700E+02, 0.58243300E+03, 0.10119300E+04, 0.17040500E+04, -.18661100E+03, 0.65414100E+02, 0.41954600E+01, -.47061900E+03, 0.11415100E+03, -.86415500E+03, 0.23844900E+03, 0.22937900E+04, -.10820500E+04, 0.80262200E+02, -.75112600E+02, -.51616900E+03, 0.83583100E+03, 0.95744500E+01, 0.27278200E+03, -.34391300E+03, -.25086600E+03, 0.42503000E+02, -.15783100E+02, -.26537300E+03, -.20228000E+02, 0.10581100E+03, -.23390400E+03, 0.48814800E+02, 0.51275600E+03, 0.18287700E+03, -.40954400E+03, -.23757200E+03, -.48908400E+02, -.23208800E+03, -.56280200E+03, -.23654300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16514400E+01, 0.66191200E-01, 0.11582600E+00, 0.26662200E-01, 0.17161700E-01, 0.39340800E-01, -.91921700E+00, -.58758300E+00, 0.57915200E+00, -.74085300E-02, 0.25994600E-01, 0.43743900E+00, -.50411400E+00, 0.30267500E-01, -.92592100E+00, -.24225900E+03, 0.59933000E+03, -.31608300E+03, -.22254100E+03, -.46876600E+03, 0.14921600E+03, 0.41757000E+03, 0.64864200E+03, -.28305700E+03, -.42428900E+03, 0.35302500E+03, 0.10317100E+03, 0.31099500E+03, -.51462300E+03, -.31081000E+03, -.45866500E+03, 0.34023100E+03, 0.40163300E+03, -.46631900E+03, -.13146700E+01, -.76285200E+02, 0.15357200E+03, 0.20124600E+03, 0.21289500E+03, -.10738400E+03, -.87274100E+03, 0.13017000E+04, -.16019200E+03, 0.10806700E+03, -.27979500E+03, -.57979900E+03, -.95279100E+03, 0.25022300E+03, -.36702400E+03, 0.11093100E+04, 0.79527100E+02, 0.33343000E+03, -.69982200E+03, -.45968400E+03, -.13025700E+04, 0.43366300E+03, 0.76848300E+03, -.11075100E+04, 0.41429900E+02, -.11051400E+03, 0.68289600E+03, 0.28137700E+03, 0.68949200E+03, -.19029500E+03, -.26164500E+03, -.76238300E+03, 0.19726900E+03, 0.10493900E+03, 0.64936100E+03, -.11996100E+03, 0.31076600E+03, 0.56951300E+02, -.73510500E+03, 0.53618400E+03, -.14773200E+02, 0.96734900E+02, -.25379000E+03, -.35030200E+03, -.29288200E+03, 0.15471600E+03, -.37109600E+03, -.15949900E+03, 0.22394800E+03, 0.20697400E+03, 0.87529700E+02, -.14755500E+03, 0.14260300E+03, 0.13438700E+03, -.12748700E+03, 0.27678200E+03, -.52682400E+02, -.39787500E+02, -.91238300E+02, 0.21468200E+01, 0.35065200E+02, 0.11198700E+00, -.18107800E+03, 0.24140400E+03, -.16750700E+02, 0.19594000E+02, -.73141200E+02, -.83805600E+02, -.10191800E+03, 0.38099200E+02, 0.53216100E+03, -.49875000E+03, -.23922800E+02, -.21132800E+03, 0.30012300E+03, 0.17239500E+03, 0.64926700E+03, 0.60535800E+01, -.24394800E+03, -.16150500E+03, 0.18697000E+03, 0.22114500E+03, 0.25585700E+03, -.23941900E+03, -.10925000E+03, 0.84901300E+02, 0.66338800E+02, -.13614600E+04, 0.79507800E+01, -.11470400E+03, 0.77216500E+03, 0.18362900E+03, 0.10016800E+04, -.22831900E+03, -.25420000E+03, -.24495600E+03, -.34309900E+01, -.24720600E+03, -.13283400E+02, 0.46530200E+02, -.17273100E+03, 0.35789200E+03, -.89877100E+02, 0.31368500E+03, 0.24424300E+03, -.57690100E+02, -.22148500E+03, -.91672500E+02, 0.72311800E+02, -.23962300E+03, 0.12359100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.52350600E+01, -.64266200E+01, -.13587700E+00, -.19035400E+01, -.56335400E+00, -.10533000E+00, -.24269600E+01, -.20022000E+01, -.55940300E+01, -.19737200E+00, 0.69746200E+00, -.12984300E+01, -.47370500E+01, -.39927300E+01, -.89239500E+01, -.53672500E+01, 0.97255200E+04, 0.24720200E+04, 0.17887100E+03, -.10274500E+04, -.16003900E+04, 0.48521700E+04, -.63217700E+03, -.85720200E+03, -.57286700E+04, -.10022900E+04, 0.31795500E+03, 0.13857800E+04, -.60666100E+02, -.26862800E+04, -.10693300E+04, 0.77361200E+03, 0.26765700E+04, -.26357100E+04, 0.28849600E+03, -.97521800E+02, 0.28153900E+00, 0.11596400E+04, 0.11876700E+04, 0.77074200E+02, -.55428700E+04, 0.13284300E+05, -.33647800E+04, -.13193500E+04, 0.48271700E+03, -.54380300E+03, -.10505800E+04, -.18130500E+04, -.86332900E+04, 0.12525800E+05, 0.63322600E+03, 0.15774700E+04, -.45174600E+03, -.45306900E+04, -.25138200E+04, 0.61085900E+03, 0.86422700E+04, -.42071200E+04, -.61791100E+04, -.71058700E+04, 0.66310700E+04, 0.80169800E+04, 0.10989100E+05, -.59905400E+04, 0.23893000E+05, -.93804700E+03, -.41187900E+04, -.44774000E+04, -.84934100E+03, 0.10471100E+05, 0.41651900E+04, -.31228800E+04, -.68659000E+04, 0.15778600E+04, -.68648200E+03, -.56993100E+02, 0.85563800E+03, -.24471800E+04, -.82106000E+03, -.48172200E+03, -.56684300E+04, -.69332400E+03, -.27023000E+04, -.36572000E+04, 0.59346900E+04, 0.10590600E+04, 0.73499700E+04, -.36253900E+04, -.10204800E+03, 0.17814800E+04, -.30469200E+03, -.14345600E+03, -.41642900E+03, -.14833900E+03, -.41586700E+03, -.16009200E+03, -.14015500E+04, 0.13910200E+04, -.18573500E+03, 0.43876600E+02, -.42496400E+02, -.52106700E+03, -.55700100E+03, -.41732500E+02, 0.66818600E+04, 0.37746500E+04, 0.25923300E+03, -.22643800E+03, -.65578700E+03, 0.47685500E+04, 0.35027500E+03, 0.38345300E+03, 0.10950000E+05, 0.30603100E+04, -.14360600E+04, -.10664400E+04, -.15322400E+04, 0.34787100E+04, 0.26478600E+03, -.23878700E+03, 0.16882400E+05, -.94112200E+04, -.39981800E+04, -.40333800E+04, 0.13688700E+04, 0.78858600E+04, 0.53990400E+04, -.30075400E+04, -.17867500E+04, -.15033900E+04, 0.17432700E+04, -.15594500E+04, -.11316400E+04, 0.18828400E+03, -.52437500E+03, -.16427000E+03, 0.11655800E+04, 0.34746400E+03, 0.16178000E+04, -.23362200E+04, -.14110500E+04, -.39005900E+03, 0.20117700E+04, -.19865800E+04, -.89291400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20730900E+01, -.95116200E-01, 0.21987700E+00, 0.23935200E-01, -.32726900E-01, -.14856400E+00, -.37773700E+00, -.21999400E+00, 0.43446700E+00, 0.95442300E-01, -.75242900E-01, 0.22469100E+00, 0.80763300E+00, 0.30720100E+00, 0.20332800E+01, 0.56325300E+00, -.64068600E-02, -.33621300E+03, -.10706600E+03, 0.47205500E+02, -.10575400E+03, -.35847300E+03, -.75897500E+02, 0.45026200E+02, 0.19261100E+04, -.92680600E+03, -.21837800E+03, -.49960700E+03, 0.11864000E+03, 0.95378400E+03, 0.41729300E+03, -.35984300E+03, -.78321700E+03, 0.65564000E+03, 0.96495700E+02, 0.23224600E+03, -.15474500E+03, -.44263000E+03, -.54591500E+03, 0.17761200E+03, 0.19385200E+04, -.20524500E+04, 0.29115700E+02, -.43926300E+03, 0.41474000E+03, 0.92480300E+03, 0.19072500E+04, -.28671700E+03, 0.25000800E+04, -.21673800E+04, -.26558800E+03, -.63044400E+03, 0.40793700E+03, 0.14680800E+04, 0.13319700E+04, -.42693000E+03, -.52680400E+04, 0.28516500E+04, 0.12491000E+04, 0.17381300E+04, -.92192800E+03, -.29132800E+04, -.22595100E+04, 0.13951800E+04, -.55292100E+04, 0.22692700E+04, 0.62882600E+03, 0.94447200E+03, 0.15776600E+03, -.23753500E+04, -.74832200E+03, 0.65062800E+03, 0.15559700E+04, -.77192500E+03, -.12005200E+03, -.33518500E+03, 0.15979700E+03, 0.81686300E+03, 0.79155200E+03, -.22032000E+03, -.23637600E+03, 0.45735700E+03, 0.59208600E+03, 0.82766600E+03, -.98485900E+03, -.64305300E+03, -.16405200E+04, 0.76142400E+03, 0.11876900E+03, -.26703600E+03, -.79421500E+02, -.14196800E+03, 0.20656600E+03, 0.15461100E+03, 0.29837600E+03, -.12797800E+03, 0.39059900E+03, -.34015300E+03, -.46098600E+02, -.11813600E+03, 0.96891000E+02, 0.21330600E+03, 0.29744300E+03, -.90853200E+02, -.16839700E+03, -.56174400E+03, -.32810700E+03, -.25936400E+03, -.65472500E+02, -.62997000E+03, -.51231300E+03, -.39579600E+03, -.15627500E+04, 0.17739400E+03, -.89302400E+02, -.69938200E+02, 0.26215900E+03, -.37861900E+03, -.15715200E+03, -.20922400E+03, -.36439700E+04, 0.26243100E+04, 0.61456300E+03, 0.90223100E+03, -.51042700E+03, -.18569400E+04, -.14333200E+04, 0.66077400E+03, 0.50814500E+03, 0.47598100E+03, -.52868600E+03, 0.53815000E+03, 0.22889400E+03, -.39268200E+02, -.19811200E+02, -.17700500E+03, -.24730200E+03, -.36534500E+03, -.37401400E+03, 0.75183600E+03, 0.50442600E+03, 0.13720600E+03, -.51487800E+03, 0.74759100E+03, 0.56756000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25744700E+01, 0.17995800E+00, -.11134400E+00, -.79487000E-01, -.24034500E+00, -.32455600E+00, 0.43302400E+00, 0.12769400E+01, -.11485800E+01, -.83880700E-01, 0.44420400E-01, 0.82550800E+00, -.31306100E+00, -.91847000E+00, 0.71645600E-01, 0.91387700E+00, -.23359800E-01, 0.38558100E+00, -.40792700E+03, -.64882200E+03, 0.40687500E+03, 0.86159300E+03, 0.11875900E+04, -.62724200E+03, -.16263000E+04, 0.44463700E+03, 0.49173300E+03, 0.64798100E+03, -.19512200E+03, -.99462400E+03, -.13261700E+04, 0.64878500E+03, 0.41927500E+03, -.62100000E+02, -.37566400E+03, -.47315300E+03, 0.32167700E+03, 0.38038100E+03, 0.88634800E+03, -.48751200E+03, -.10253500E+04, 0.18655400E+03, 0.72797000E+03, 0.97021400E+03, -.69948900E+03, -.65429200E+03, -.19730700E+04, 0.10252300E+04, -.18702100E+04, 0.30478400E+03, 0.42058400E+03, 0.55408900E+03, -.21466100E+03, -.12353300E+04, -.17365100E+04, 0.59496500E+03, 0.14095200E+04, 0.95241200E+01, -.81478000E+03, -.96540700E+03, 0.92372500E+03, 0.17148100E+04, 0.31999100E+04, -.10169000E+04, 0.24720800E+04, 0.21316900E+03, -.56773600E+03, -.73390100E+03, 0.35173900E+03, 0.16857300E+04, 0.23231700E+04, -.70720000E+03, -.11641100E+04, 0.18810100E+03, 0.63713500E+03, 0.83314300E+03, -.47992600E+03, -.80952400E+03, -.14203100E+04, 0.85965000E+03, -.88700800E+03, 0.49951900E+03, -.48457000E+03, -.62600100E+03, 0.88737100E+03, 0.16939400E+03, 0.16274900E+04, -.65089600E+03, 0.49529800E+03, -.36407600E+03, 0.21095300E+03, 0.23596300E+03, -.36275500E+03, 0.30841500E+02, -.49926200E+03, 0.24669500E+03, -.16561300E+03, -.25231000E+01, 0.17758000E+03, 0.22413500E+03, -.17162200E+03, -.18162000E+03, -.48495600E+03, 0.23117800E+03, 0.13256900E+04, -.13022900E+03, -.52544100E+03, -.67276600E+03, 0.49515000E+03, 0.16756100E+04, 0.18447100E+04, -.66485100E+03, 0.27584400E+04, -.48533500E+03, -.50219500E+03, -.71000700E+03, 0.22983600E+03, 0.13205000E+04, 0.16862300E+04, -.67554800E+03, 0.25022500E+04, -.31916800E+03, -.75283200E+03, -.93099300E+03, 0.50321800E+03, 0.18074900E+04, 0.26249700E+04, -.97639400E+03, -.22201200E+03, -.26127900E+03, 0.30220400E+03, -.38171400E+03, 0.17097500E+03, 0.32754200E+02, 0.21981900E+03, 0.92288300E+02, 0.79346100E+03, -.82227900E+03, 0.18340100E+03, -.91521500E+03, -.47785000E+03, -.93405900E+02, 0.50913900E+02, -.33242200E+03, 0.35277300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26592400E+01, 0.37463400E-01, 0.21895300E+00, 0.19958100E+00, 0.39675300E+00, -.10648000E+00, -.21379300E+01, -.20473300E+01, 0.10737000E+01, 0.61472600E-01, 0.67248200E-01, -.10379000E+01, -.31854100E-02, 0.97112000E-01, -.11520100E+01, -.89236200E+00, 0.51798300E-01, 0.13493200E+01, -.10795100E+01, -.78417200E+03, 0.56595000E+03, 0.21345700E+04, 0.19113600E+04, -.77590300E+03, -.59954800E+04, 0.21656600E+04, 0.12763400E+04, 0.20983600E+04, -.75777500E+03, -.32854700E+04, -.32031400E+04, 0.18495100E+04, 0.19451500E+04, -.11525100E+04, -.72131500E+03, -.11094700E+04, 0.86043600E+03, 0.12971200E+04, 0.24911200E+04, -.10377500E+04, -.58055800E+04, 0.34373700E+04, 0.11621000E+04, 0.22607700E+04, -.18403100E+04, -.27487700E+04, -.69452900E+04, 0.20746600E+04, -.70220300E+04, 0.32870300E+04, 0.13501900E+04, 0.21990600E+04, -.15531800E+04, -.46645600E+04, -.62527700E+04, 0.18452800E+04, 0.10176000E+05, -.44503100E+04, -.35932400E+04, -.46574200E+04, 0.35019100E+04, 0.72824000E+04, 0.97133700E+04, -.40998500E+04, 0.13080700E+05, -.37039300E+04, -.20849000E+04, -.28939800E+04, 0.50565600E+03, 0.65374500E+04, 0.53602600E+04, -.22779800E+04, -.39549200E+04, 0.13046900E+04, 0.11513600E+04, 0.17694800E+04, -.12476900E+04, -.24375000E+04, -.38724100E+04, 0.16270000E+04, -.22463900E+04, 0.44620400E+03, -.16483800E+04, -.21903700E+04, 0.32004200E+04, 0.84089700E+03, 0.55870200E+04, -.21277300E+04, 0.75971000E+03, -.29428200E+03, 0.39796300E+03, 0.49178300E+03, -.93279800E+03, -.61752200E+02, -.13264900E+04, 0.48950400E+03, -.89069400E+03, 0.53483600E+03, 0.33624300E+03, 0.52600400E+03, -.46870500E+03, -.60410700E+03, -.13569400E+04, 0.49165700E+03, 0.23941000E+04, 0.81334500E+03, -.19024700E+03, -.63239700E+03, 0.99607000E+03, 0.39521300E+04, 0.41330600E+04, -.38770500E+03, 0.71488600E+04, -.12129900E+04, -.84949400E+03, -.11673400E+04, 0.29697700E+02, 0.26073500E+04, 0.31928400E+04, -.84150800E+03, 0.93437900E+04, -.46374700E+04, -.23214000E+04, -.30407500E+04, 0.21107700E+04, 0.57430000E+04, 0.74488600E+04, -.26488300E+04, -.11798900E+04, -.11722200E+04, 0.14081400E+04, -.15421400E+04, 0.51127000E+02, 0.19971300E+03, 0.46913000E+03, 0.57669400E+03, 0.19263200E+04, -.10009600E+04, 0.10531300E+04, -.27837600E+04, -.17158000E+04, -.39478400E+03, 0.92972400E+03, -.17327400E+04, 0.62510500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.39987900E+01, 0.82171400E+00, 0.17445600E+01, 0.92276300E+00, 0.79877500E+00, 0.78061000E+00, -.60404000E+00, 0.10705100E+01, 0.27975000E+01, -.53881900E+00, 0.73434800E-01, 0.10675500E+01, 0.16207000E+01, 0.78668100E+00, 0.84254000E+00, 0.34356300E+01, -.21504600E+00, -.23222800E+01, 0.54792900E+00, -.40210800E+00, -.92165100E+03, -.94471900E+03, -.15572100E+04, 0.20833600E+02, -.57418100E+03, 0.18762200E+04, 0.90212400E+03, 0.89510300E+03, -.53029900E+03, -.11464300E+04, -.26213300E+04, 0.94539200E+03, 0.15651800E+03, -.43073300E+03, -.68124000E+03, -.73171600E+03, 0.40912400E+03, 0.48646700E+03, 0.11814300E+04, -.73897000E+03, -.74256200E+03, 0.17735600E+04, 0.25308900E+04, 0.26472500E+04, -.14729200E+04, -.21745200E+04, -.29089100E+04, 0.26808500E+04, -.14105000E+04, 0.33135500E+04, 0.10109700E+04, 0.78686300E+03, 0.25182000E+02, -.13243000E+04, -.21854900E+04, 0.87471700E+03, -.13396800E+01, -.27047600E+04, 0.24137300E+03, 0.55447600E+03, -.97272900E+03, 0.13564000E+04, 0.34085400E+04, 0.49882400E+03, -.31845300E+04, -.47293300E+04, 0.14172400E+02, 0.37515700E+03, 0.41068500E+03, 0.25944000E+03, 0.34240300E+04, 0.26764600E+03, -.21282600E+03, 0.14222200E+04, 0.12476300E+04, 0.14560500E+04, -.94066200E+03, -.10896700E+04, -.28422900E+04, 0.14798800E+04, 0.67882900E+03, -.29103600E+03, -.66234500E+02, -.15382500E+03, -.54879200E+03, 0.47247600E+03, 0.71120800E+03, -.13332700E+03, 0.74634100E+03, -.28059700E+02, 0.47284600E+03, 0.50895200E+03, -.55753800E+03, -.55216000E+02, -.11908100E+04, 0.52526800E+03, -.62515100E+02, 0.25723700E+03, 0.37833500E+03, 0.40256600E+03, -.22216300E+03, -.32756200E+03, -.66118000E+03, 0.40495400E+03, 0.31791400E+04, -.45401100E+04, -.71068800E+03, -.67176500E+03, -.91772200E+03, 0.72231500E+03, -.16992700E+03, -.67689500E+03, 0.32168000E+03, -.46416300E+04, -.68120600E+03, -.68101800E+03, 0.57103300E+03, 0.14554500E+04, 0.18794300E+04, -.77725200E+03, 0.11799000E+04, -.36974700E+04, -.23544900E+03, 0.28804900E+02, -.79513100E+03, 0.17246200E+04, 0.25857700E+04, 0.78938000E+01, -.10622300E+03, -.36142200E+03, 0.40839700E+03, -.58720800E+03, 0.55809100E+03, -.13661700E+03, 0.22040300E+03, -.11367500E+03, 0.82148100E+03, -.89937800E+03, -.32771500E+03, -.71469500E+03, -.67738700E+03, -.11313200E+03, 0.35172900E+03, 0.35307200E+01, -.18780700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.53651900E+00, -.56745000E+00, 0.16039700E+00, -.11054400E+00, 0.13658500E+00, 0.43595600E+00, 0.44543400E+00, -.55911000E+00, 0.25327700E+00, 0.32668200E-01, -.40928500E-01, -.34471100E+00, 0.32733900E-01, 0.47475700E+00, 0.55368900E+00, 0.77593700E-01, 0.28879700E-01, 0.68539400E+00, -.24777400E+00, 0.11308200E+00, -.68351200E-01, -.26868800E+03, -.27058300E+03, 0.39291000E+02, 0.71795700E+02, 0.14854900E+01, 0.43089600E+02, -.21244300E+02, 0.90891100E+02, -.61387600E+02, 0.78429000E+02, -.98501600E+01, -.27207000E+02, 0.51701400E+02, -.30465200E+02, -.76521500E+01, -.43855700E+02, 0.34433000E+02, -.44699900E+02, -.15663300E+02, 0.38828000E+03, -.23748100E+03, 0.90757300E+02, 0.21709300E+02, -.19240700E+02, -.55911900E+02, 0.10641400E+03, 0.45643700E+02, -.51511300E+01, -.36005500E+02, 0.86641400E+02, 0.21546500E+02, 0.76841100E+02, -.42987700E+02, 0.33638400E+03, 0.59708700E+02, 0.25503800E+03, -.84547500E+02, -.25547300E+03, -.18426000E+03, -.11492700E+02, 0.37966100E+03, 0.14517800E+03, -.23635700E+03, 0.52820800E+03, -.38563600E+03, -.29064800E+03, -.27205700E+03, 0.44575300E+02, 0.53918300E+03, 0.34797300E+03, -.28989700E+03, 0.54658800E+02, -.10173100E+02, 0.53171000E+02, 0.16250700E+02, 0.85544900E+02, -.82397400E+02, 0.37388400E+02, 0.29907900E+02, 0.11257000E+03, 0.15252600E+02, -.14013000E+03, -.12336600E+03, 0.62939400E+02, 0.14431800E+03, 0.61607400E+02, -.14612700E+03, -.15751500E+02, -.29405200E+02, 0.47563300E+02, 0.40831200E+02, 0.13115300E+02, -.55094100E+02, -.16988500E+02, 0.54168600E+02, 0.61759400E+01, -.23397500E+02, 0.23766200E+02, 0.12685400E+02, 0.14192500E+02, -.29506500E+02, 0.17510500E+02, 0.16310700E+02, -.27081800E+02, -.11402100E+03, 0.17349100E+02, 0.51367000E+02, -.11368700E+03, -.21878900E+03, -.27035200E+03, 0.75331400E+02, -.27919300E+03, -.40982200E+02, -.19083800E+01, 0.17258600E+02, 0.13299900E+02, 0.13516700E+03, 0.92133000E+02, 0.19188900E+02, 0.11747800E+03, 0.37334200E+02, -.12236200E+03, -.68930600E+02, -.71008100E+02, 0.20497900E+03, -.17477500E+03, -.94959700E+02, 0.13182600E+02, 0.58005700E+00, -.26521600E+00, -.11859000E+02, -.45058800E+02, -.27762000E+02, 0.25149300E+02, -.80435000E+02, 0.33923900E+02, -.10376400E+03, -.96409700E+02, -.63992500E+02, 0.27259700E+02, 0.11330100E+02, 0.52321900E+02, 0.90153000E+02, -.60225100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16131900E+01, -.12019500E+01, 0.37502300E+00, -.45994900E+00, -.29313200E+00, 0.90986500E+00, -.20636500E+01, -.18295800E+01, 0.22785100E+01, -.41896700E+00, 0.10532100E+00, -.10754700E+01, -.15508300E+01, -.79303800E+00, -.11827600E+01, -.13444100E+01, -.17145600E+00, -.17702700E+01, -.10203700E+00, 0.94729300E-01, -.22468000E+00, 0.12893300E+01, 0.60901000E+03, -.57236400E+02, 0.41414200E+04, -.42469500E+04, -.85533500E+03, -.11492400E+04, -.29358200E+02, 0.23409600E+04, 0.19241200E+04, -.10038900E+04, -.15721800E+04, 0.13155800E+04, 0.72489300E+03, 0.95172600E+03, -.42555200E+03, -.12003100E+04, -.16321300E+04, 0.89314500E+03, 0.39060200E+04, -.30763700E+04, -.23973600E+04, -.30690600E+04, 0.17772300E+04, 0.33587700E+04, 0.56805900E+04, -.29690500E+04, 0.55912800E+04, -.52151800E+04, -.91121700E+03, -.14357000E+04, 0.24738100E+02, 0.31688900E+04, 0.25266000E+04, -.12628400E+04, -.15189900E+05, 0.92277700E+04, 0.22161100E+04, 0.31602000E+04, 0.78927800E+03, -.75928800E+04, -.46383600E+04, 0.26510900E+04, -.11765000E+05, 0.10279100E+05, 0.12545200E+04, 0.19715400E+04, 0.12277200E+04, -.54966800E+04, -.24584500E+04, 0.15775500E+04, 0.28062400E+04, -.28002600E+04, -.13963000E+04, -.18513200E+04, 0.91224700E+03, 0.23249700E+04, 0.33157200E+04, -.17577300E+04, -.45346100E+04, 0.18334200E+04, 0.14506200E+04, 0.18705400E+04, -.62512900E+03, -.26366600E+04, -.27788600E+04, 0.17452900E+04, -.24365700E+02, -.27035900E+03, -.60334400E+03, -.73248500E+03, 0.61787400E+03, 0.51948700E+03, 0.12697700E+04, -.73936000E+03, 0.84402700E+03, -.73621200E+03, -.41623000E+03, -.54039400E+03, 0.26240200E+03, 0.66812000E+03, 0.92408300E+03, -.51208600E+03, -.44666400E+04, 0.29228300E+04, 0.26980700E+03, 0.44524100E+03, 0.64226100E+03, -.23157400E+04, -.86525000E+03, 0.19758100E+03, -.51344900E+04, 0.57642000E+04, 0.26043900E+03, 0.62334000E+03, 0.75365500E+03, -.22084500E+04, -.88960700E+03, 0.46527800E+03, -.87137600E+04, 0.73352100E+04, 0.94247500E+03, 0.16521000E+04, 0.55269900E+03, -.44818400E+04, -.26224000E+04, 0.13230100E+04, 0.10893900E+04, 0.11117500E+04, -.11691500E+04, 0.12339400E+04, 0.23513000E+03, 0.13950400E+03, -.43207700E+03, 0.21417700E+02, -.66749700E+03, -.45581300E+03, -.13514100E+03, 0.17539800E+04, 0.12259100E+04, 0.28419000E+03, -.10611200E+04, 0.14227300E+04, 0.33918900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.45358800E+01, 0.70185400E+01, -.12655300E+00, 0.18256000E+01, 0.78491100E+00, -.15684600E+00, 0.50427200E+01, 0.75280300E+01, 0.28194700E+01, -.43225700E+00, -.53715500E+00, 0.25661000E+01, 0.32750700E+01, 0.24888500E+01, 0.58213600E+01, 0.46447000E+01, -.65720100E+00, -.54663900E+01, 0.34606900E+01, -.25720700E+01, 0.11907100E+00, 0.14837100E+01, -.41171300E+00, -.23021800E+03, 0.40943800E+04, -.34464600E+04, -.59386000E+03, -.93790000E+03, -.39682400E+02, 0.20633300E+04, 0.92574900E+03, -.77655400E+03, -.16505000E+04, 0.45575300E+03, 0.71017000E+03, 0.96458200E+03, -.52971700E+03, -.12751000E+04, -.12532700E+04, 0.92560900E+03, 0.25945300E+04, -.74389400E+03, -.24088200E+04, -.30978100E+04, 0.21732100E+04, 0.29718500E+04, 0.44775700E+04, -.31578800E+04, 0.57131600E+04, -.35068100E+04, -.52083300E+03, -.13279800E+04, -.97107200E+02, 0.30107000E+04, 0.11384500E+04, -.12708900E+04, -.19374100E+05, 0.80100000E+04, 0.25339000E+04, 0.38989500E+04, 0.46684700E+03, -.88137800E+04, -.33215500E+04, 0.33701200E+04, -.14865300E+05, 0.10442500E+05, 0.11974100E+04, 0.23932500E+04, 0.11125100E+04, -.64762900E+04, -.16946000E+04, 0.19755100E+04, 0.22566500E+04, -.18156000E+04, -.15848000E+04, -.20292500E+04, 0.14730400E+04, 0.21274900E+04, 0.24495000E+04, -.20210000E+04, -.56219000E+04, 0.10840900E+04, 0.17058200E+04, 0.21359400E+04, -.89094900E+03, -.31953100E+04, -.24695800E+04, 0.20461600E+04, 0.39490000E+03, 0.35067000E+03, -.73261700E+03, -.91290700E+03, 0.78135300E+03, 0.76696300E+03, 0.99147000E+03, -.94043900E+03, 0.93720200E+03, -.29041800E+03, -.40840300E+03, -.55122200E+03, 0.30420900E+03, 0.69993200E+03, 0.69400400E+03, -.53076000E+03, -.41851600E+04, 0.34744800E+04, 0.10077800E+03, 0.34468200E+03, 0.52969500E+03, -.18909800E+04, -.35963700E+03, 0.48740300E+02, -.58979000E+04, 0.71612200E+04, -.13112000E+03, 0.39788800E+03, 0.89865600E+03, -.22011200E+04, 0.32303100E+03, 0.23009700E+03, -.95010500E+04, 0.52492200E+04, 0.63256800E+03, 0.17755500E+04, 0.25007200E+03, -.45750800E+04, -.15638600E+04, 0.14967200E+04, 0.12036600E+04, 0.11001300E+04, -.53768400E+03, 0.70278100E+03, 0.52384400E+03, 0.83825600E+02, -.17985000E+03, -.28055500E+03, -.46590700E+03, -.10574300E+04, -.16826900E+03, 0.19971000E+04, 0.96507200E+03, 0.27221300E+03, -.51655700E+03, 0.12904500E+04, -.46019300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49215300E+01, 0.68529500E+01, -.38618100E+00, 0.17341700E+01, 0.52516800E+00, -.75814000E+00, 0.56762000E+01, 0.72807300E+01, -.28237100E+01, 0.46702700E+00, -.52019300E+00, 0.35907300E+01, 0.66272500E+00, -.88411500E+00, 0.79592600E+00, 0.14027500E+01, 0.11032100E+00, 0.68307800E+00, 0.13737600E+00, 0.48773500E-01, 0.71294200E+00, 0.40529600E+00, 0.13066500E+01, -.23607600E+00, -.52494800E+04, 0.59029400E+04, 0.91355200E+03, 0.13241500E+04, -.39345400E+03, -.30362600E+04, -.26601100E+04, 0.99620500E+03, 0.20568900E+04, -.14699900E+04, -.88578500E+03, -.12046600E+04, 0.78061400E+03, 0.15926100E+04, 0.22619900E+04, -.10665500E+04, -.48988300E+04, 0.27852600E+04, 0.28747700E+04, 0.35713500E+04, -.26135500E+04, -.44710100E+04, -.79686500E+04, 0.32819000E+04, -.70107400E+04, 0.51940000E+04, 0.75336200E+03, 0.15912500E+04, -.41813600E+03, -.41106900E+04, -.41581400E+04, 0.11550700E+04, 0.20938200E+05, -.10324600E+05, -.23052400E+04, -.39612300E+04, -.63390400E+03, 0.10118800E+05, 0.59607700E+04, -.29781000E+04, 0.16219100E+05, -.11100100E+05, -.10364700E+04, -.23771500E+04, -.14717700E+04, 0.71252600E+04, 0.25040600E+04, -.16715400E+04, -.28056800E+04, 0.32949900E+04, 0.16382200E+04, 0.21520800E+04, -.16881400E+04, -.26849200E+04, -.42356700E+04, 0.19443900E+04, 0.56386300E+04, -.81177600E+03, -.14076300E+04, -.19080700E+04, 0.65664700E+03, 0.30872800E+04, 0.33569500E+04, -.16860300E+04, 0.25623700E+03, -.45190200E+02, 0.70158700E+03, 0.82869400E+03, -.95037500E+03, -.51716300E+03, -.15763900E+04, 0.79359200E+03, -.10298100E+04, 0.76416700E+03, 0.48180300E+03, 0.64565900E+03, -.44572100E+03, -.85387600E+03, -.12745300E+04, 0.57606100E+03, 0.52103500E+04, -.23217900E+04, -.13853200E+03, -.45897900E+03, -.49229200E+03, 0.25080700E+04, 0.14700400E+04, -.15966900E+03, 0.64172100E+04, -.56351600E+04, 0.19157700E+03, -.41325300E+03, -.10303800E+04, 0.23958300E+04, 0.33806600E+03, -.17590800E+03, 0.11105300E+05, -.72618300E+04, -.85212100E+03, -.22076600E+04, -.59383700E+00, 0.59188600E+04, 0.40456600E+04, -.15688200E+04, -.13620100E+04, -.14624800E+04, 0.14930700E+04, -.14825700E+04, -.10207400E+03, 0.17231700E+02, 0.50602000E+03, 0.36755200E+03, 0.89688600E+03, 0.10659000E+04, 0.46084200E+03, -.25029000E+04, -.17497800E+04, -.42250100E+03, 0.12566200E+04, -.21031000E+04, -.38981900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27244400E+01, -.48751100E-01, 0.66271600E+00, 0.39629900E+00, 0.74991800E+00, 0.13828400E+00, 0.46236600E-01, -.32218500E+00, -.34398600E+00, -.17107300E-01, -.11435600E-01, 0.47437700E+00, 0.13621200E+01, 0.76796400E+00, 0.26273600E+01, 0.96523300E+00, -.11031800E+00, -.68822500E+00, 0.10762800E+01, -.80461300E+00, -.28140300E+00, 0.51712000E+00, -.65844500E+00, 0.23609800E+00, -.22905700E+00, 0.92121400E+03, 0.14875000E+03, 0.17928300E+03, -.11964400E+03, -.95862800E+01, -.23475900E+03, 0.23767300E+03, -.20874600E+02, -.44937400E+02, -.30206300E+02, -.44930800E+02, 0.91060400E+01, 0.17922700E+02, 0.12749200E+03, -.57715800E+02, -.10075400E+03, 0.29805900E+03, 0.64326500E+03, 0.64750700E+03, -.41428900E+03, -.31066100E+03, -.86971400E+03, 0.69950100E+03, -.14561900E+03, 0.11433600E+04, 0.27956300E+03, 0.28871100E+03, -.17718200E+03, -.55497500E+02, -.52447200E+03, 0.34276100E+03, 0.16953600E+04, -.12143200E+04, 0.28516900E+03, 0.22692100E+03, -.84602300E+03, 0.21848600E+03, -.49417400E+03, 0.22920300E+03, -.87261500E+03, -.23535900E+04, 0.32887500E+03, 0.33342700E+03, -.19269100E+03, -.61243400E+03, -.32149900E+03, 0.25918400E+03, 0.66372000E+03, 0.32218100E+03, 0.99901800E+02, 0.11916500E+03, -.21352100E+03, 0.12870600E+03, -.49422600E+03, 0.16779500E+03, 0.11870700E+04, -.48854300E+02, 0.11259500E+03, 0.10324700E+03, -.50364900E+03, 0.25611800E+03, -.29473500E+03, 0.13758900E+03, -.49201900E+02, -.92311100E+01, 0.29091000E+02, 0.33852100E+02, 0.23659700E+02, -.30275200E+02, -.93444300E+02, 0.36142700E+02, -.13250500E+02, 0.48981300E+02, 0.32516500E+02, 0.40192500E+02, -.85758000E+01, -.23977700E+02, -.78419800E+02, 0.47158500E+02, 0.12705600E+03, -.13393700E+04, -.10400800E+03, -.12783500E+03, 0.62803800E+02, 0.35822600E+02, 0.29801700E+03, -.15882800E+03, -.39371100E+03, -.22673800E+04, -.49532900E+01, -.38125400E+01, 0.11496300E+03, -.19283200E+03, 0.10325200E+03, -.64785900E+02, 0.34121700E+03, -.12928000E+04, 0.18029100E+03, 0.13144500E+03, -.29967600E+03, -.31201600E+02, 0.23612600E+00, 0.99499100E+02, -.23253100E+02, -.37002700E+02, 0.79939000E+02, -.81011400E+02, 0.72503900E+02, -.16249900E+02, 0.58686000E+02, 0.36357200E+02, -.85318800E+02, 0.16900800E+03, -.40433600E+02, 0.65845200E+02, -.69558800E+02, -.64790600E+01, -.72134500E+01, -.11634300E+03, -.65036900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.88239700E+01, 0.13476800E+02, -.12385300E+01, 0.32061900E+01, 0.98200300E+00, -.75690100E+00, 0.71441700E+01, 0.12393800E+02, 0.42904400E+01, 0.83668100E-02, -.12664000E+01, 0.16278500E+01, 0.35180600E+00, -.18365900E+01, 0.43259700E+01, 0.11425000E+01, -.53248200E+00, -.85863800E+01, 0.31804100E+01, -.24673300E+01, -.10064300E+00, -.24155600E+01, 0.28737000E+01, -.28971000E+00, 0.43565200E+00, 0.13488800E+01, 0.12181300E+04, 0.68829100E+03, 0.17563800E+03, -.86619600E+03, -.29359400E+04, 0.10056500E+04, -.68203500E+03, 0.37303100E+03, -.65312800E+03, -.41657500E+03, 0.39086500E+02, -.10953500E+02, 0.88956600E+03, -.55516300E+03, 0.46358900E+03, -.23324900E+04, 0.20971600E+04, 0.12496000E+04, -.13446400E+03, -.47924900E+03, -.11525000E+04, 0.16475800E+04, 0.68268900E+03, -.23660900E+04, 0.13872100E+04, 0.48431000E+03, 0.36120800E+03, -.27550900E+03, -.13833600E+04, 0.86121100E+03, -.10523300E+05, 0.26757400E+04, -.90424400E+03, 0.36461400E+03, 0.23360500E+03, -.21737300E+04, 0.47843900E+04, -.59224100E+03, -.17290400E+04, 0.29828700E+03, -.25518400E+04, -.20250500E+04, 0.84484300E+03, 0.16567000E+04, 0.61568400E+04, -.24820300E+04, 0.44641000E+03, 0.91691800E+02, 0.12348000E+04, 0.94700200E+03, 0.32025400E+02, -.52713800E+03, -.20485700E+04, 0.12153200E+04, -.39024300E+04, 0.71212300E+03, -.13750800E+03, 0.36873700E+03, -.11692700E+03, -.14467300E+04, 0.30805500E+03, 0.41872700E+02, 0.16474700E+04, -.69281500E+03, 0.21960700E+03, -.88172700E+01, 0.33475000E+02, 0.51384300E+03, -.54884800E+03, 0.10489300E+03, 0.34899900E+03, -.19298200E+03, 0.37423900E+03, 0.24399100E+03, -.24906000E+02, -.52565700E+02, -.52834300E+03, 0.32217400E+03, 0.34061300E+04, 0.69672400E+03, -.17477300E+04, -.17741900E+04, 0.63995800E+02, 0.22089400E+04, 0.20911100E+04, -.19514100E+04, 0.37086100E+04, -.16932200E+04, -.23236400E+04, -.26205700E+04, 0.66360000E+03, 0.32282400E+04, 0.45556400E+04, -.27547300E+04, -.83968600E+03, 0.16314400E+04, -.16914700E+04, -.10085700E+04, -.52643200E+03, 0.89463500E+03, 0.29694500E+04, -.14902300E+04, 0.46739400E+03, 0.33658300E+03, 0.22719700E+03, -.16785200E+03, 0.90378800E+03, -.19926000E+03, 0.85896200E+03, -.82766100E+03, 0.16296000E+04, -.38920900E+04, -.86690100E+03, -.26979800E+03, -.11475700E+03, 0.97037800E+02, -.91714700E+02, 0.12371600E+04, 0.18455900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.44551300E+01, 0.23673400E+00, -.18231800E+01, -.63109900E+00, -.70911200E+00, 0.22202000E+00, -.29977100E+01, -.47160900E+01, 0.27129200E+01, 0.72181500E-01, 0.88179300E-01, -.27229600E+01, -.11683000E+01, 0.49275200E+00, -.14360000E+01, -.13301400E+01, -.86633700E-01, -.22332600E+01, -.37675400E+00, 0.64710200E-01, -.59623900E-01, -.13662300E+01, 0.72759600E+00, -.32830800E+00, -.57808900E+00, 0.12394000E+01, 0.81864200E-01, -.26685000E+03, 0.15400500E+03, -.11714300E+03, -.10663100E+03, -.35092400E+03, -.33503300E+03, 0.41038200E+03, -.15889100E+03, -.95035500E+02, 0.14516200E+03, -.86522600E+02, 0.14077600E+03, -.74414100E+02, 0.14069700E+04, -.23106700E+04, 0.18068700E+02, -.38680800E+03, -.45388000E+02, 0.52110000E+03, 0.47296800E+02, -.41432800E+03, 0.10306200E+04, -.27008600E+04, -.51471700E+03, -.78681700E+03, 0.37465600E+03, 0.37235800E+03, 0.59846800E+03, -.87388800E+03, 0.28066600E+01, 0.14176800E+04, -.33131600E+03, -.20142000E+03, 0.21115800E+03, 0.61552100E+03, 0.10304300E+04, -.15060400E+03, 0.38011300E+04, 0.17474000E+04, -.66846700E+03, -.76478000E+03, -.34094100E+03, 0.19391500E+04, 0.71832600E+03, -.60073900E+03, 0.59999700E+03, -.47030700E+03, 0.17942100E+03, 0.33716800E+02, -.14797700E+03, 0.14951400E+03, 0.27074700E+02, 0.70808000E+01, -.82858100E+03, 0.10245700E+04, -.20427400E+03, -.11994800E+03, 0.28589600E+03, -.22914300E+03, 0.55679000E+03, -.16298400E+03, 0.57965600E+03, -.46151700E+03, 0.15322900E+03, 0.98928600E+02, -.21665900E+03, 0.17704100E+03, -.21859100E+03, 0.96634200E+02, 0.23603100E+03, -.27424400E+03, 0.69691000E+02, 0.26972300E+02, -.75361800E+02, 0.51918900E+02, -.97271600E+02, 0.16675900E+02, 0.11146600E+04, 0.16578800E+04, -.67225300E+02, -.71098900E+02, -.25322100E+03, 0.47315800E+03, -.34307400E+03, -.41812100E+02, 0.12216700E+04, 0.21977900E+04, 0.80949100E+01, -.71448400E+02, -.34646700E+03, 0.55849900E+03, -.10069800E+03, 0.18927500E+02, -.12398600E+02, 0.26291100E+04, 0.94328100E+01, 0.42804200E+02, -.10579100E+03, 0.31654900E+03, -.10238200E+03, 0.13611600E+03, 0.29464400E+03, 0.20960600E+03, -.11099200E+03, 0.13714700E+03, 0.28645700E+03, 0.40284100E+02, 0.13505900E+03, -.75306900E+02, 0.43643200E+03, -.37561400E+03, -.16352800E+03, -.37101100E+03, 0.66480900E+01, 0.22197200E+02, -.20952500E+02, 0.12541200E+03, 0.21241500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26502800E+01, 0.53960500E+00, 0.14163600E+01, 0.77663800E+00, 0.74004600E+00, 0.78591000E+00, 0.11397500E+01, 0.27861400E+01, 0.20945200E+00, -.29862900E+00, -.61514300E-01, 0.17108000E+01, 0.57710200E+00, -.13679200E+00, 0.13407700E+01, 0.23411700E+01, -.92321600E-01, -.12527800E+00, 0.10438500E+01, -.66935200E+00, -.79428500E-01, -.24235400E+00, -.66503200E+00, 0.17320300E+00, -.18884700E+00, 0.76271200E-01, 0.12291400E+00, -.16440800E+00, -.27183900E+03, -.68345600E+02, -.29950600E+02, -.71157600E+02, 0.55593400E+02, 0.46544700E+00, 0.92531300E+02, 0.92194100E+02, 0.40911700E+02, 0.17209000E+02, 0.40912100E+01, 0.13055500E+03, 0.71555000E+02, 0.17342700E+03, -.32715200E+03, -.31951500E+03, -.11233400E+03, 0.94860400E+01, -.17672500E+03, -.42802300E+03, -.11813600E+03, 0.66361800E+02, -.50226700E+02, -.49380100E+02, -.30549300E+03, -.93087600E+02, -.27721300E+03, -.16026000E+03, -.44008200E+03, 0.63266500E+03, 0.26223900E+03, 0.25881800E+03, 0.43323700E+03, -.14635100E+03, 0.79227400E+02, 0.43222900E+03, -.50193300E+03, 0.60239500E+03, 0.25864000E+03, 0.31327100E+03, 0.25740000E+03, -.30356000E+03, -.24351000E+03, 0.42085700E+03, 0.31709400E+03, -.17649200E+03, -.23940900E+03, -.28911300E+03, -.60965600E+02, 0.16645100E+03, 0.10801000E+03, -.35238800E+03, -.98248000E+03, 0.73722800E+03, 0.37619400E+03, 0.41765800E+03, 0.49507500E+02, -.42803000E+03, -.75204300E+01, 0.46435500E+03, 0.81479000E+02, -.95179500E+02, -.98401400E+02, -.11869900E+03, -.23767600E+02, 0.65139700E+02, 0.61702700E+02, -.14084100E+03, 0.65048800E+00, -.19398100E+02, -.60485700E+02, -.62578700E+02, -.20881800E+02, 0.74089900E+01, 0.57338200E+01, -.83258300E+02, -.11973600E+04, 0.41945700E+03, 0.29501000E+03, 0.39136000E+03, 0.14670600E+03, -.53598700E+03, -.14093700E+03, 0.42898200E+03, -.13291600E+04, 0.86432600E+03, 0.39025700E+03, 0.52281500E+03, 0.50129200E+02, -.69068000E+03, -.41187200E+03, 0.54915400E+03, -.10882400E+03, 0.26812600E+03, 0.10172100E+03, 0.88501600E+02, 0.39762900E+03, 0.14921900E+02, 0.19799900E+03, 0.22087600E+03, -.14579100E+02, -.39009100E+02, 0.65237600E+02, -.72680000E+02, 0.56034500E+02, 0.95902600E+02, -.80386000E+02, 0.13395500E+03, -.39273100E+02, 0.35049100E+03, 0.17493800E+03, -.50696100E+02, -.84535000E+02, -.27436000E+02, 0.11416100E+03, -.21686700E+03, 0.39106000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14831400E+01, 0.77960500E-01, 0.88762900E-01, 0.52610600E-01, 0.15827500E-01, -.51818900E-01, 0.17716400E+00, 0.34587300E+00, -.91556100E-02, -.14396100E-01, -.10551000E-01, 0.42262200E+00, -.12170400E+00, -.23434600E+00, 0.74965700E+00, 0.35169100E+00, -.21009800E-01, -.15799900E+00, 0.33157600E+00, -.29131200E+00, -.58007600E-01, 0.79702000E-01, 0.18415500E+00, -.24004600E-01, 0.66067300E-01, -.63826300E-01, -.36101500E-01, -.86373200E-01, -.14450500E-01, -.47267300E+02, -.15755500E+03, 0.10334700E+01, -.60348900E+02, 0.84280900E+01, -.47667600E+02, -.42494200E+02, 0.40647800E+02, -.14850300E+01, 0.95114900E+02, -.44879000E+02, 0.10602700E+03, -.12053900E+03, 0.13291600E+03, 0.12647500E+03, -.12194800E+03, -.44810200E+02, -.26684700E+03, 0.13155700E+03, -.79244600E+02, -.82122800E+02, 0.29542000E+02, 0.43640700E+02, -.37898300E+02, -.66520300E+02, -.18074800E+03, 0.35146600E+02, -.22776700E+03, 0.71509200E+02, 0.74632000E+02, 0.60973800E+02, -.39830400E+02, -.21360100E+01, 0.30633700E+03, 0.50989900E+02, 0.31328400E+03, -.22214500E+02, -.48268000E+01, -.40953600E+02, -.67299500E+02, 0.18157800E+03, 0.24276100E+03, -.26957900E+02, -.26653900E+02, 0.55942400E+02, 0.49792200E+01, -.14329400E+02, 0.43246300E+02, -.17838600E+00, -.44270200E+02, -.82328800E+01, -.13999500E+03, 0.13348100E+02, 0.20486200E+02, 0.20592400E+02, -.11597600E+02, -.70451100E+02, 0.68427600E+02, 0.88012500E+01, 0.15175600E+03, -.27654700E+02, 0.35391300E+02, 0.21240500E+02, -.38843800E+02, 0.45081400E+02, -.79884600E+02, 0.27152200E+02, 0.40314600E+02, -.84244700E+01, 0.23959900E+02, 0.21723400E+02, -.22381800E+02, -.10671400E+01, -.54399100E+02, 0.23316700E+02, 0.29647000E+03, 0.11969100E+03, -.30947500E+01, -.21329500E+02, -.75029700E+02, 0.10662700E+03, 0.67700500E+01, -.14316300E+02, 0.15775100E+03, 0.95293500E+02, 0.43572900E+02, 0.12648000E+02, -.68546800E+02, 0.80894000E+02, 0.42024100E+02, 0.18986600E+02, -.71536800E+02, -.23355000E+02, -.16472800E+02, -.25910300E+02, 0.24221500E+02, 0.59223800E+02, 0.20989700E+03, -.22826600E+02, 0.49457000E+02, 0.20202900E+02, 0.24649600E+02, -.20625500E+02, 0.62847900E+02, 0.18364700E+01, 0.24124400E+02, 0.38711900E+02, 0.82766600E+02, -.92378900E+02, -.23171300E+02, -.39161300E+02, -.32080100E+02, -.27320400E+01, 0.21179100E+02, -.28596400E+02, 0.42199500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.21521700E+01, -.17529800E+00, -.67900500E-01, -.21240600E+00, -.48076700E+00, 0.24830300E+00, 0.94008000E+00, 0.67145600E+00, -.12050800E-01, -.92975600E-01, 0.62975400E-02, 0.42267400E+00, 0.95440200E+00, 0.80440100E+00, 0.17759000E+01, 0.13036600E+01, -.10425000E+00, -.25453500E+00, 0.84256700E+00, -.60332300E+00, -.13558200E+00, 0.71742200E+00, -.75539400E+00, 0.25828900E+00, -.19941100E+00, 0.19978100E+00, -.85261900E-01, 0.15108500E-01, -.85020600E-01, 0.10618600E+00, -.16180600E+03, -.34896100E+01, 0.10486800E+03, -.65208300E+02, 0.41306600E+02, 0.52041700E+02, -.46413600E+02, 0.35402000E+02, -.15327800E+02, 0.58782300E+02, -.66956600E+03, 0.44732400E+03, -.72145500E+01, 0.27222700E+02, 0.10941500E+03, -.23831700E+03, 0.75046700E+02, 0.34038800E+01, -.35291400E+03, 0.39335200E+03, 0.91177700E+02, 0.11273100E+03, 0.72957100E+01, -.11926400E+03, -.13955700E+03, 0.11252600E+03, -.53462800E+03, 0.13757200E+03, 0.13558500E+03, 0.20868800E+03, 0.81440000E+01, -.31685400E+03, 0.31861500E+02, 0.22330400E+03, -.11289900E+04, 0.44813800E+02, 0.11570100E+03, 0.19617600E+03, 0.17095700E+03, -.49237800E+03, 0.79895500E+02, 0.17313400E+03, -.10319300E+03, 0.54559700E+02, -.43888300E+02, -.65875800E+02, 0.45487900E+02, -.35967600E+02, -.26279900E+02, -.77475700E+02, -.10642100E+03, 0.30249900E+02, 0.12656400E+03, 0.16882800E+03, -.69067700E+02, -.70047400E+02, -.17320200E+03, 0.18064200E+03, -.10326400E+02, 0.44769400E+01, -.75152500E+02, -.94112600E+02, 0.65580500E+02, 0.15737900E+02, 0.62945400E+02, -.96518200E+02, -.70145900E+02, 0.43914400E+02, -.19961900E+02, -.24576800E+02, 0.27777000E+02, -.17326900E+02, 0.17599900E+02, -.28058300E+02, -.10791500E+03, -.19316500E+03, -.55496000E+02, -.49423000E+02, 0.68499800E+02, -.73915400E+02, 0.67087600E+02, -.50515600E+02, -.16479400E+03, -.30895100E+03, -.47924700E+02, -.19032200E+02, 0.47536300E+02, -.96771100E+02, -.70286000E+01, -.46110900E+02, 0.11735700E+03, -.30455300E+03, -.27758900E+02, -.93074400E+01, 0.80043000E-01, -.31273500E+02, 0.13971600E+03, -.61628700E+01, -.86227900E+02, -.51434100E+02, 0.57135500E+02, -.60645000E+02, -.18983500E+02, 0.60775400E+01, 0.23737000E+02, -.84174500E+02, -.48929900E+02, 0.29384800E+02, 0.34397400E+02, 0.52778300E+02, -.27490800E+02, -.46462500E+01, 0.46533900E+02, -.41693800E+02, -.72326100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17275200E+01, -.70554300E+00, 0.21172600E+00, -.14343900E+00, 0.16131200E+00, 0.40555900E+00, 0.43466700E+00, -.96552200E+00, 0.73771300E+00, -.29071800E-02, -.50063300E-01, -.62319200E+00, 0.63885200E+00, 0.10311700E+01, 0.14606800E+01, 0.93182500E-01, 0.57534500E-01, 0.35192400E+00, -.25776300E+00, -.11236800E+00, -.97783200E-01, 0.29106800E+00, -.16662000E+00, 0.13668100E+00, 0.12165100E+00, 0.12817600E+00, 0.84279000E-01, 0.74226500E-01, 0.26897800E-01, -.88274900E+00, 0.87569400E-02, 0.84664400E+01, -.81084700E+02, 0.55049700E+02, -.37206500E+02, -.17658100E+02, 0.36902000E+02, -.17936800E+02, 0.14134400E+02, -.23276000E+02, 0.43894900E+03, -.49232600E+02, 0.12722200E+03, 0.10525100E+03, -.18416900E+03, 0.10199400E+03, -.53321500E+02, 0.13078400E+03, 0.15375800E+03, 0.14795600E+03, -.11023700E+02, -.29819800E+02, -.16693100E+02, 0.10268000E+03, 0.12013900E+03, -.38938500E+01, 0.27752800E+03, -.14497300E+03, -.14731100E+02, 0.31484900E+02, -.73445900E+02, 0.10118800E+03, -.18967800E+02, 0.39808500E+02, 0.65983400E+02, -.45818800E+03, 0.65928600E+02, 0.12685900E+03, -.97130900E+02, -.17212000E+02, -.68523000E+02, 0.13017900E+03, 0.17774600E+02, 0.30739800E+02, 0.35552700E+02, -.58939900E+01, -.10150600E+02, 0.27997000E+02, 0.46311100E+02, 0.71037600E+01, 0.10599400E+03, -.49507600E+02, -.58190900E+02, -.37513400E+02, 0.95042900E+01, 0.50011900E+02, 0.14246300E+02, -.32339600E+02, 0.92478100E+02, -.37386200E+02, 0.51139500E+02, 0.34452900E+02, -.55736700E+02, 0.10226900E+02, -.40440300E+02, 0.37461300E+02, 0.39991200E+02, -.24291100E+02, 0.21903300E+02, 0.13059900E+02, -.21209500E+02, 0.58397200E+01, -.67639300E+01, 0.15557700E+02, 0.28458300E+02, -.40179500E+03, 0.28257600E+02, 0.48559500E+02, -.55546600E+02, -.11534700E+02, -.72154200E+02, 0.39932000E+02, 0.16089700E+03, -.52761500E+03, 0.42510100E+02, 0.57322600E+02, -.71199400E+02, 0.39277100E+02, -.10109800E+03, 0.52977400E+02, -.18794000E+03, -.17689500E+03, 0.56887300E+02, 0.12214300E+03, -.43100900E+02, -.10394300E+03, -.14198100E+03, 0.10792200E+03, 0.48852700E+02, 0.35071800E+02, -.61225800E+02, 0.57588900E+02, 0.37666000E+02, -.49526400E+01, -.42796400E+02, 0.43813100E+02, 0.30710700E+02, 0.46723600E+02, -.63611800E+02, -.57520600E+02, 0.14239700E+02, 0.33020800E+00, -.64666500E+02, 0.40786100E+00, 0.66010800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.42598800E+01, -.25565400E+00, 0.68484900E+00, 0.64360200E+00, 0.11279900E+01, 0.14157700E+00, -.70462200E+00, -.12821200E+01, 0.49124000E+00, 0.14029000E+00, -.31009200E-02, -.11328800E+01, 0.11340000E+01, 0.12340500E+01, 0.18438000E+00, -.73980800E+00, -.62657300E-01, 0.17317500E+00, -.74728200E+00, 0.61153000E+00, -.51412800E-02, 0.32396000E+00, 0.37448400E-01, 0.61641400E-01, -.24601700E-01, 0.57987300E+00, 0.85448900E-01, 0.45299300E-01, 0.10957800E+00, -.14972900E+01, -.17282300E+00, -.63738600E+00, -.31323700E+03, 0.46653300E+02, -.14968400E+03, -.96713900E+02, 0.15247000E+03, -.98431800E+02, 0.47855400E+02, -.11882600E+03, 0.13955000E+04, -.31214400E+03, 0.26105700E+03, 0.25293500E+03, -.55289600E+03, 0.42132700E+03, -.17949200E+03, 0.32066100E+03, 0.36600400E+03, 0.20942400E+03, 0.23309100E+02, 0.57332500E+02, -.22103000E+03, 0.24172400E+03, 0.26631300E+03, 0.91960100E+02, 0.31091200E+03, -.42550300E+03, -.14001600E+03, -.54457100E+02, -.38938300E+02, 0.15892000E+03, 0.20113800E+02, -.66110600E+02, 0.11077200E+04, -.74336300E+03, -.12447400E+02, 0.11040000E+02, -.32394000E+03, 0.33114500E+03, -.14878000E+03, 0.38629000E+02, -.19693200E+03, 0.13466700E+03, 0.16310400E+03, 0.81373400E+02, 0.65182400E+01, 0.17088000E+02, 0.15623700E+03, 0.11383900E+03, -.40316800E+02, -.22928900E+03, -.22308400E+03, -.18156700E+03, 0.14445000E+03, 0.22744000E+02, 0.13135300E+03, -.20811000E+03, 0.32129900E+03, 0.95670900E+01, 0.18007600E+03, 0.13527900E+03, -.19091200E+03, 0.67881900E+02, -.12110400E+03, 0.15389000E+03, 0.17608600E+03, -.19863900E+02, 0.78932600E+02, 0.55188600E+02, -.85347800E+02, 0.45016200E+02, -.30339900E+02, 0.66547500E+02, 0.79276700E+03, -.42901500E+03, -.26934900E+01, -.24623500E+02, -.23399100E+03, 0.27331700E+03, -.17224400E+03, -.16794800E+02, 0.11901900E+04, -.59171000E+03, 0.43840700E+02, -.25242600E+02, -.32374000E+03, 0.41581000E+03, -.21075800E+03, -.68373000E+01, -.67787200E+03, -.46174400E+03, -.10462600E+02, 0.89564600E+02, 0.15652900E+03, -.26275700E+03, -.25943500E+03, 0.56132200E+02, 0.21592400E+03, 0.15265900E+03, -.21621400E+03, 0.21082000E+03, 0.16212100E+03, -.40944300E+02, -.17405300E+03, 0.26838300E+03, 0.14362300E+03, -.36811200E+02, -.23746400E+03, -.14703900E+03, 0.77783800E+02, -.90295300E+00, -.21032700E+03, 0.96794800E+02, 0.11079100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.45078000E+01, -.54193500E+01, -.51008700E-01, -.14458800E+01, -.31147800E+00, -.18519100E+00, 0.17461800E+00, 0.32151000E+00, -.12737100E+01, -.44107300E+00, 0.25270300E+00, 0.81913300E+00, -.12398100E+01, -.20388100E+01, 0.53653300E+00, -.17487200E+00, 0.15833700E+00, 0.37952700E+00, 0.12525400E+01, -.11113400E+01, -.62469800E+00, -.13513500E+01, -.90079300E+00, -.80421500E-01, -.32437600E-01, 0.81621700E+00, 0.36994900E-02, -.69706300E-01, 0.12030200E+01, 0.14087700E+01, 0.95528200E+00, -.72808700E+00, -.31269500E+00, -.28677100E+03, -.47751200E+02, -.28453100E+02, 0.19184600E+02, -.44366600E+02, -.55314500E+02, -.55904800E+02, 0.85339400E+03, 0.10109100E+04, -.52217800E+03, -.63434700E+03, 0.23709600E+03, 0.50948100E+03, 0.70427700E+03, -.60768000E+03, 0.65996500E+03, 0.13101600E+03, -.11869800E+03, -.13487800E+03, 0.56069400E+02, 0.22830500E+03, 0.15256200E+03, -.54256000E+02, -.10637000E+04, 0.12726600E+03, -.72510400E+03, -.72169500E+03, 0.76975500E+03, -.14600800E+03, 0.70069400E+03, -.87393900E+03, 0.41477000E+03, 0.15738800E+04, -.46155000E+03, -.48631200E+03, 0.29299500E+03, 0.49226200E+03, 0.82494800E+03, -.52189600E+03, -.69104200E+03, 0.23290400E+03, 0.47429600E+02, 0.33242900E+02, 0.11135100E+03, -.19982600E+03, 0.14688600E+03, 0.26213200E+02, 0.34176700E+02, -.30958700E+03, -.37206800E+03, -.40261700E+03, 0.29185400E+03, 0.44528500E+02, 0.11759000E+03, -.46232600E+03, 0.11696900E+02, 0.35853000E+03, 0.29820900E+02, 0.20848600E+02, -.64453700E+02, 0.58719700E+02, 0.43654400E+02, 0.35970800E+02, 0.30850300E+02, 0.13518300E+03, 0.17450900E+02, 0.36149300E+01, -.18109900E+02, 0.30822700E+02, 0.32443800E+02, 0.14970900E+02, -.32064200E+03, 0.21156800E+03, 0.11385200E+03, 0.12860900E+03, -.96604500E+02, -.20162400E+03, -.96653700E+02, 0.12689600E+03, 0.10875800E+04, 0.16935200E+04, -.21413300E+03, -.28895100E+03, -.66901500E+02, 0.55381100E+03, 0.32030800E+03, -.26956900E+03, -.74082700E+03, 0.27259200E+03, -.38690400E+03, -.31958400E+03, 0.31013800E+03, -.15573800E+03, 0.38431600E+03, -.43830700E+03, 0.34618100E+02, 0.41756400E+02, -.11156900E+03, 0.99583500E+02, 0.45447600E+02, -.62800900E+02, -.17511400E+03, 0.47490500E+02, 0.15906500E+03, -.54329500E+03, -.11514100E+03, 0.12216000E+01, 0.65317000E+02, -.91135100E+01, -.97169400E+02, 0.27538100E+03, 0.75394800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.76227000E+00, -.47132000E-01, -.34507800E-01, -.28458500E-01, -.12903600E-01, 0.15247400E-01, -.74418100E-01, -.16122700E+00, 0.16517800E-01, 0.14589200E-02, 0.52356100E-02, -.14478100E+00, 0.14868400E+00, 0.12815400E+00, -.12267800E+00, -.33291300E-01, 0.14516100E-02, -.66031700E-01, 0.13674800E-01, 0.49735700E-01, 0.21545300E-01, -.15511900E+00, -.66737600E-01, 0.82403400E-02, -.29075900E-01, 0.19704500E-01, 0.25530500E-01, -.38354800E-04, 0.49053600E-01, -.21176300E+00, 0.40087700E-01, 0.17745000E+00, 0.38262900E-01, -.54088000E-01, -.88846900E+01, -.12662500E+02, 0.51466100E+01, -.52091700E+00, 0.81785800E+01, -.13613400E+02, 0.47997100E+02, -.44630700E+02, -.14998000E+02, -.34647500E+02, 0.31300500E+02, 0.27867600E+02, 0.20437500E+02, -.34123600E+02, 0.98535100E+02, -.13939200E+03, -.20968800E+02, -.24169500E+02, 0.14509800E+02, 0.16131200E+02, -.28553100E+02, -.22262300E+02, -.70167200E+02, 0.66187500E+02, -.22108000E+02, -.38602100E+02, 0.27035700E+02, -.12870500E+02, 0.34165800E+02, -.51489800E+02, 0.30350000E+02, 0.17993700E+03, -.35620900E+02, -.61845500E+02, 0.33976400E+02, 0.53610100E+02, 0.82687900E+02, -.63882800E+02, -.11464900E+02, 0.28877600E+01, 0.13438300E+02, 0.19401800E+02, -.96496000E+01, -.10179800E+02, -.95747200E+01, 0.19016500E+02, 0.14723800E+02, 0.15385300E+02, -.99001000E+01, -.14973300E+02, -.73968000E+01, -.62018100E+01, -.60765900E+01, -.19723800E+02, -.52685800E+01, 0.67573900E+01, 0.47327700E+01, 0.85266600E+01, -.28691600E+01, 0.26248900E+01, -.31027700E+01, 0.84381900E+01, 0.29658400E+01, -.30595400E+01, 0.37931600E+01, 0.50183900E+01, -.23001700E+01, 0.89619100E+00, -.47848000E+01, 0.53512600E+01, -.45710500E+01, 0.75640000E+02, -.15148700E+01, -.70730900E+01, 0.26740500E+01, 0.90339700E+00, 0.18591300E+01, -.67808300E+01, 0.39314600E+02, 0.17842300E+03, -.20596800E+02, -.36777500E+02, 0.17021600E+02, 0.33936400E+02, 0.50380700E+02, -.32833400E+02, -.57733600E+02, 0.14444100E+03, -.13758400E+02, -.25016200E+02, 0.91960800E+01, 0.10366500E+01, 0.49432700E+02, -.30659500E+02, 0.35519400E+01, 0.36599400E+01, -.38423400E+01, 0.42009100E+01, 0.40942300E+01, -.34038100E+01, 0.70127500E+01, 0.45743200E+00, 0.15803800E+02, -.54356200E+02, -.36269500E+01, 0.38287800E+01, 0.26518900E+01, 0.45653600E+00, -.21000900E+01, 0.23936900E+02, 0.18103300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.32212100E+01, 0.11880100E+01, -.18624300E+00, 0.60454200E+00, 0.34278700E+00, -.37776400E+00, -.14715400E+01, -.35055700E+01, 0.83301900E+00, 0.57888000E+00, -.10400100E+00, -.22245600E+01, 0.95395000E+00, 0.14404500E+01, 0.12969600E+00, -.17900000E+01, 0.61379400E-01, 0.16553800E+01, -.16510900E+01, 0.10840200E+01, -.85874500E-02, -.17020400E+00, 0.51212900E+00, -.32057700E-01, 0.44676500E+00, -.90962800E-01, 0.52909200E-01, -.89842200E-01, -.62355400E+00, -.88214500E+00, -.96097300E+00, 0.15894000E+00, 0.29885600E+00, -.42719300E+00, -.72312300E+01, -.41696500E+02, 0.27340300E+02, -.25101400E+02, 0.27150800E+02, -.36451400E+02, 0.35785600E+03, 0.13786800E+03, -.35020100E+03, -.45113200E+03, 0.27068500E+03, 0.29663300E+03, 0.38157000E+03, -.48657500E+03, 0.65425900E+03, -.69253800E+03, -.22364400E+03, -.23357200E+03, 0.15980100E+03, 0.91857600E+02, -.15879200E+03, -.21111900E+03, -.11086400E+04, 0.86406900E+03, -.29319100E+03, -.38402500E+03, 0.51291200E+03, -.22653900E+03, 0.47885700E+03, -.49222800E+03, -.64614500E+03, 0.18894400E+04, -.39430200E+03, -.47776000E+03, 0.52138300E+03, 0.17951400E+03, 0.89461600E+03, -.54596500E+03, 0.26757800E+03, -.25168700E+03, -.76467700E+02, -.50714300E+01, -.11544000E+03, 0.70409200E+02, -.24988900E+02, -.33510300E+02, 0.44417000E+02, 0.21176100E+03, -.10265100E+03, -.15629600E+03, 0.81132300E+02, -.56863800E+02, 0.10174900E+02, -.16520600E+03, -.44498700E+01, 0.52079500E+02, -.16516100E+02, 0.18526900E+02, -.35365700E+02, 0.50819000E+02, 0.70561500E+01, 0.73465800E+01, 0.26535100E+02, -.25207300E+02, -.20786200E+01, 0.12307200E+02, -.18032100E+02, 0.18630900E+02, -.16253500E+02, 0.79602200E+01, -.84034200E+03, 0.60368900E+03, 0.78878600E+02, 0.75958900E+02, 0.12550900E+03, -.27405000E+03, 0.24137000E+02, 0.50300100E+02, -.42453900E+03, 0.17768400E+04, -.21364200E+03, -.24071400E+03, 0.25445800E+03, 0.37901100E+02, 0.50313000E+03, -.25450900E+03, -.38130000E+03, 0.10812800E+04, -.14053400E+03, -.20160800E+03, 0.96697600E+02, 0.63826800E+02, 0.45699600E+03, -.25104000E+03, 0.31072900E+02, 0.24656400E+02, -.23095500E+02, 0.23094700E+02, 0.22901000E+02, 0.67638500E+01, -.18256500E+02, 0.32645400E+01, 0.13589100E+03, -.55300200E+03, 0.74174200E+02, 0.49017200E+00, 0.13411300E+02, -.12896300E+01, -.12465100E+02, 0.28277200E+03, 0.12714800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.62316100E+01, -.40101800E+00, -.97425000E+00, -.82722300E+00, -.11566000E+01, -.10193100E+00, 0.15388800E+01, 0.24561000E+01, -.14414700E+00, -.25025100E+00, -.11756500E-01, 0.10662700E+01, -.23722100E+01, -.23139300E+01, -.19428000E+01, 0.81305400E+00, -.19698000E+00, -.26642900E+01, 0.10818100E+01, -.46398100E+00, 0.27482000E+00, 0.82815900E+00, 0.11863900E+01, -.90547800E-01, 0.14697600E+00, -.12133700E+01, -.30982700E-01, 0.34357600E-01, -.68812700E-01, -.24576000E+00, 0.10119500E+01, -.17908900E+01, 0.66557600E+00, -.83658800E+00, 0.88881200E+01, -.85389400E+00, 0.20921300E+02, -.15334300E+02, -.29362400E+02, -.14477600E+01, 0.60999800E+03, 0.91234500E+03, -.26317100E+03, -.32196100E+03, 0.20023200E+02, 0.32978500E+03, 0.60357200E+03, -.32204800E+03, 0.17001300E+03, 0.52365800E+03, -.12735000E+03, -.18725900E+03, 0.23432300E+03, 0.89584400E+02, 0.27818800E+03, -.11477600E+03, 0.31229400E+02, 0.41999000E+03, -.60162200E+03, -.60791600E+03, 0.49848000E+03, 0.31305500E+03, 0.71216200E+03, -.64301500E+03, 0.11733000E+03, 0.76099300E+03, -.25898400E+03, -.14658700E+03, 0.12148100E+03, 0.29853700E+03, 0.64731100E+03, -.17909200E+03, 0.95976800E+02, -.20271000E+03, -.78101300E+02, -.82259000E+02, -.51707200E+02, 0.58708600E+02, 0.83278400E+02, -.10156700E+03, 0.30832200E+03, 0.67977800E+02, -.33946500E+03, -.40137400E+03, 0.27418500E+03, 0.22744700E+03, 0.24059900E+03, -.38496900E+03, 0.33385600E+02, 0.60326900E+02, 0.33290500E+02, 0.34480600E+02, -.10224000E+03, 0.13510100E+02, -.15253100E+02, 0.25950100E+02, 0.10458400E+02, -.66915500E+01, 0.34539500E+01, 0.59436800E+00, -.20570500E+02, 0.80155700E+01, 0.20392400E+02, -.17318000E+01, -.10688200E+04, -.49494300E+03, 0.15884500E+03, 0.24148000E+03, 0.49708300E+02, -.41290900E+03, -.12323600E+03, 0.19136400E+03, 0.46395200E+02, 0.52542100E+03, -.10152400E+03, -.36575100E+02, 0.29657100E+02, 0.13884500E+03, 0.13274600E+03, -.67107800E+02, 0.52047500E+02, 0.18759200E+03, -.19292000E+03, -.10028000E+03, -.22330500E+02, 0.11325200E+03, 0.20802100E+03, -.16598600E+03, 0.94361200E+01, 0.12441500E+02, -.10400200E+03, 0.89782900E+02, 0.19168300E+02, 0.42499100E+00, -.14814500E+03, -.44132400E+02, 0.16327200E+03, -.33831600E+03, 0.13340600E+02, -.13976400E+03, 0.16974600E+02, -.69890400E+01, -.10175600E+03, 0.21388100E+03, 0.23047100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.33312200E+01, -.42551100E+00, -.18108300E+01, -.69220400E+00, -.93354900E+00, -.67719100E+00, 0.32728500E+00, -.47461400E+00, -.32074100E+01, 0.56363900E+00, -.24188200E-01, 0.14564700E+01, -.17677200E-01, -.40782700E-01, 0.42965200E+00, 0.10271200E+01, -.78288000E-01, -.75124500E+00, 0.95378100E+00, -.68245900E+00, -.78621700E-01, -.12805600E+00, -.42026500E+00, 0.61533400E-01, -.22722900E+00, -.79070800E-02, -.10999000E+00, -.29056900E+00, 0.68902100E-01, 0.19960300E+01, -.31620700E+00, -.72155700E+00, -.71399500E+00, 0.31907100E+00, -.67895400E+00, 0.52972600E+00, -.12874100E-01, 0.26622800E+02, -.19770700E+02, -.38811900E+01, -.14828100E+03, -.18573400E+03, 0.20627500E+03, 0.40849600E+03, -.24072300E+03, -.21028900E+03, -.29109200E+03, 0.44203200E+03, -.48574800E+03, 0.61324700E+03, 0.45940700E+02, 0.13978900E+03, -.69386100E+02, -.69567800E+02, 0.26214900E+03, 0.12637500E+03, 0.96172500E+03, -.83406200E+03, 0.19605300E+03, 0.23215100E+03, -.34456500E+03, 0.25404400E+03, -.26676500E+03, 0.29760800E+03, 0.84657500E+03, -.17916800E+04, 0.15803800E+03, 0.20780400E+03, -.35163300E+03, 0.69503500E+02, -.54376100E+03, 0.25008800E+03, -.94362400E+02, 0.10591300E+03, 0.53046700E+02, 0.77737300E+02, 0.14244100E+02, -.46713000E+02, 0.29649700E+02, 0.10379900E+03, -.30361800E+02, -.20773000E+03, 0.65640500E+02, 0.73789900E+02, -.29149000E+02, 0.53888600E+02, 0.50621100E+02, 0.71293600E+02, 0.17041300E+02, -.28861800E+02, 0.21453700E+02, 0.25587200E+02, -.41814200E+01, -.43501800E+02, -.32562000E+02, 0.34058400E+02, -.22987300E+02, 0.22552800E+02, 0.24271800E+01, 0.93575500E+01, 0.38786700E+01, -.20816500E+02, 0.12135800E+02, 0.12825800E+02, 0.85645300E+03, -.60435700E+03, -.33952300E+02, -.10363300E+03, -.14737500E+03, 0.28296000E+03, -.83537300E+02, -.96861900E+02, 0.62694400E+03, -.15941900E+04, 0.91865700E+02, 0.87153100E+02, -.22810700E+03, 0.10696700E+03, -.39658400E+03, 0.88847800E+02, 0.39152100E+03, -.97352400E+03, 0.21250100E+03, 0.19561000E+03, -.15413000E+03, -.63903200E-01, -.49559300E+03, 0.23191900E+03, -.27647900E+02, -.32412900E+02, 0.55976600E+01, -.24988200E+01, -.34893000E+02, -.74683500E+01, -.22744000E+02, 0.68909900E+02, -.12148100E+03, 0.42109900E+03, -.18384000E+02, 0.13125700E+02, -.59094900E+00, -.24143000E+01, -.57777400E+01, -.19598500E+03, -.86769000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.33532800E+01, 0.22934300E+00, 0.49752900E+00, 0.42300200E+00, 0.57646900E+00, -.25960600E+00, -.54206900E-01, -.98433200E-01, -.14268400E+01, 0.26745000E+00, -.21863800E-01, 0.38198000E+00, 0.99535400E+00, 0.20839300E+00, -.11307600E+00, -.97042400E+00, 0.89929700E-01, 0.15899700E+01, -.11011400E+01, 0.97841400E+00, 0.38351100E+00, 0.78203900E-01, -.14084800E+00, -.44364400E-01, 0.15580300E+00, -.67028100E+00, -.11640600E+00, -.43351300E+00, -.31562000E+00, 0.13928000E+00, -.69042500E+00, -.88499500E+00, 0.33450400E+00, 0.10122100E+00, -.52765800E+01, 0.50507700E+00, -.45483500E+00, -.32212900E+00, -.20118500E+02, -.18066600E+01, 0.19836800E+02, -.69357200E+01, 0.24373300E+02, 0.24758900E+02, 0.94597700E+01, -.23068900E+02, -.32504300E+01, 0.25023300E+02, 0.37678700E+02, 0.77740200E+02, -.42974300E+02, -.37541500E+02, 0.75407400E+02, 0.38076900E+02, 0.70050700E+02, -.28730700E+02, 0.10180800E+03, -.17497900E+03, -.81032100E+02, -.10441500E+03, 0.11541300E+03, 0.51355900E+02, 0.12939800E+03, -.10377100E+03, 0.16845200E+03, -.42753300E+03, -.62757100E+02, -.61228600E+02, 0.46071500E+02, 0.91269300E+02, 0.92547700E+02, -.52413600E+02, -.72375800E+02, 0.78953900E+02, 0.31673500E+02, 0.30702800E+02, -.16899400E+02, -.22587400E+02, 0.45074100E+02, 0.36076300E+02, -.34796100E+02, -.19399900E+02, -.40083400E+02, -.35927900E+02, 0.80244600E+02, -.10911500E+02, 0.14022100E+02, -.45783000E+02, 0.50901900E+01, -.71880900E+01, 0.20792800E+00, 0.35161200E+01, -.15879300E+01, 0.65409100E+01, 0.84379600E+01, 0.62711400E+01, -.44585000E+01, 0.12096200E+01, 0.61206500E+00, 0.20369800E+01, -.78177800E-01, -.57568500E+00, 0.11747100E+02, 0.27470000E+01, 0.11756600E+03, -.31582200E+03, -.44055900E+02, -.76828300E+02, 0.24493200E+02, 0.11115400E+02, 0.21821100E+02, -.77773200E+02, 0.17820500E+03, -.38349700E+03, -.53321400E+02, -.64724600E+02, 0.31264700E+02, 0.77837500E+02, -.23148100E+02, -.68613900E+02, 0.51144300E+02, -.73960300E+02, 0.17444900E+02, 0.71050200E+01, -.54502800E+02, -.41638700E+01, -.84673000E+02, 0.32008600E+01, -.48264800E+01, 0.15900900E+00, -.17595300E+02, 0.16581800E+02, -.57902900E+01, -.48703700E+01, -.53704800E+01, -.29829300E+00, -.27522700E+01, 0.10319000E+02, -.15587600E+02, -.52665400E+01, 0.16744100E+02, 0.36284600E+00, -.26549200E+02, 0.15767900E+02, -.10113900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.26588900E+01, -.19990700E+00, 0.10344500E+00, -.78537100E-01, -.53442800E-01, -.57729200E-01, 0.17663500E+01, 0.20916300E+01, -.10748400E+01, -.32390900E-01, -.59916000E-02, 0.10423700E+01, -.60246900E+00, -.74686300E+00, 0.26092000E+00, 0.12840200E+01, 0.51351700E-01, 0.11034000E+01, 0.85643800E+00, -.13501800E+00, -.11584700E+00, -.77580200E+00, -.54631400E+00, 0.52912500E-01, 0.24491700E-01, -.92188500E-01, 0.67281000E-01, -.11808400E+00, 0.42265400E+00, -.17853100E+00, 0.38853100E+00, -.77606900E+00, 0.25124400E+00, 0.44706700E-01, 0.20863900E+00, -.28537800E+00, 0.10167600E+00, -.12019400E+00, -.22414700E-01, 0.33596100E+01, 0.11269800E+03, 0.11786600E+03, -.66043000E+01, -.29905800E+02, 0.13826000E+02, 0.38170800E+02, 0.32613700E+02, -.35401400E+02, 0.19603100E+03, 0.45216600E+02, -.49755000E+02, -.57823200E+02, 0.40762500E+02, 0.57357600E+02, -.12988600E+01, -.48907600E+02, -.12307500E+03, -.14785100E+02, -.11301700E+02, -.68632200E+01, 0.49646900E+02, -.46790300E+02, 0.72574800E+02, -.15610700E+02, -.29203600E+03, 0.74197900E+02, -.69022100E+01, 0.15709300E+02, 0.90314900E+02, -.61783800E+02, 0.13730600E+03, 0.47683400E+01, 0.78890600E+01, 0.47594000E+01, -.12949800E+02, -.14078600E+02, -.14314400E+02, -.17325400E+01, 0.94231200E+01, -.21164300E+02, 0.47692100E+02, -.36396400E+02, -.67913800E+01, 0.31811800E+01, -.12604200E+01, 0.10113300E+01, -.25532800E+02, 0.39232500E+01, 0.22601000E+02, -.55205100E+01, -.37440800E+01, -.44202700E+01, -.60207900E+01, 0.14860100E+02, 0.17158900E+01, -.67849800E+01, -.26801300E+00, -.42946400E+00, 0.17986500E+01, 0.11856200E+01, -.15267600E+01, 0.78457800E+00, 0.18772200E+01, -.64365100E+00, -.18147300E+03, -.13511100E+03, -.15404800E+02, -.38753500E+02, 0.89606100E+02, -.53059100E+02, 0.91577500E+02, -.50774500E+02, -.23242900E+03, 0.25312500E+02, 0.43745000E+01, 0.23810400E+02, 0.51603000E+02, -.85868400E+02, 0.95349000E+01, 0.13513700E+02, -.62165100E+02, 0.44445400E+02, 0.15706000E+02, 0.29541700E+02, -.49632600E+02, -.36704000E+02, -.80112500E+00, 0.18892700E+02, -.66100100E+00, 0.53195500E+01, -.14997000E+01, 0.54872000E+01, 0.26967300E+01, -.10302600E+01, -.66212700E+01, -.45422100E+01, 0.56308100E+01, -.35034400E+02, 0.75779300E+00, -.77794000E+00, 0.40904800E+01, -.39630400E+00, -.16477400E+02, 0.20270500E+02, -.32482000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.70779800E+01, 0.10423500E+01, 0.27443300E+01, 0.15856900E+01, 0.11134600E+01, 0.28737100E+00, 0.32696900E+01, 0.66946500E+01, 0.34826500E+00, -.35708900E+00, -.26751100E+00, 0.45078500E+01, 0.28963100E+00, -.10776000E+01, 0.10285600E+01, 0.45044900E+01, 0.88860100E-01, -.40106900E+00, 0.15922800E+01, -.11682300E+01, 0.59682100E+00, -.15501000E+01, -.56378400E-02, -.72242300E-01, 0.60015700E+00, -.59828900E+00, -.10374100E+00, -.49875700E+00, 0.72878400E-01, 0.29228400E+01, -.38377800E+00, 0.23387800E+01, -.58366100E+00, 0.24378800E+00, -.14242700E+02, 0.17189400E+01, -.14967000E+01, -.10549300E+01, 0.10913000E+01, -.46395700E+01, 0.11672100E+04, 0.22555000E+03, -.35891300E+03, -.57195900E+03, 0.38549200E+03, 0.48830000E+03, 0.50146300E+03, -.52984700E+03, 0.19352900E+04, -.52008300E+03, -.51311300E+03, -.61332900E+03, 0.39959900E+03, 0.75030600E+03, 0.11937600E+03, -.49300300E+03, -.89886000E+02, -.45329500E+03, -.44436500E+03, -.46687000E+03, 0.28344300E+03, 0.14326600E+03, 0.66612300E+03, -.58518400E+03, 0.35238600E+03, 0.13990500E+03, -.38091100E+03, -.45233900E+03, 0.33933400E+03, 0.49681000E+03, 0.10782600E+04, -.50518200E+03, 0.10519900E+03, -.49227100E+02, 0.14362600E+03, 0.20183300E+03, -.30736100E+03, -.10650400E+03, -.26058900E+03, 0.18062800E+03, 0.59985400E+03, -.40554600E+03, -.26480100E+03, -.18693500E+03, -.85617300E+02, 0.19561100E+03, -.15775400E+02, -.22668300E+03, 0.89187400E+02, 0.32571900E+02, -.25901900E+02, -.23822700E+02, -.53007300E+02, 0.57919900E+02, -.16130600E+02, -.31431800E+02, 0.11497900E+02, -.99134900E+01, -.99881600E+00, -.75163200E+01, 0.24104000E+01, 0.19305500E+01, 0.79097200E+01, -.89951700E+01, -.10055900E+04, -.53433000E+03, -.31323500E+02, -.14316900E+03, 0.38708300E+03, -.26312400E+03, 0.45373600E+03, -.21190200E+03, 0.21569300E+03, 0.16894200E+03, -.17641300E+03, -.23497000E+03, 0.19680700E+03, 0.21839800E+03, 0.31414600E+03, -.26083300E+03, -.96853800E+03, 0.10407800E+04, 0.17176200E+03, 0.18520500E+03, -.25731800E+03, -.33895200E+03, 0.15458500E+03, 0.60307900E+02, 0.10507200E+02, 0.14285000E+02, -.11084200E+02, 0.19644700E+02, 0.13271400E+02, 0.17915500E+01, 0.29781500E+01, -.61050700E+02, 0.10109900E+03, -.38611900E+03, 0.56285500E+01, -.12834700E+02, -.11183900E+01, 0.70432300E+00, -.81229100E+02, 0.16079700E+03, 0.42248900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.38020700E+01, -.70821100E+00, -.18694400E+01, -.91022100E+00, -.61760100E+00, -.10341200E+01, 0.14097100E+01, -.77196700E+00, -.21679300E+01, 0.39266700E+00, 0.34436100E-01, -.16823100E+01, -.10889600E+00, 0.56822900E+00, -.26766100E+00, -.18629100E+01, 0.11389700E+00, 0.10146200E+01, -.30264300E+00, 0.12873300E+00, -.57039100E+00, 0.98767800E+00, -.47905800E+00, 0.11787300E+00, -.21173400E+00, 0.45243300E+00, 0.60902500E-01, 0.37763900E+00, -.36216200E+00, -.14879200E+01, 0.12603700E+01, 0.71388100E+00, 0.22053300E+00, -.10399600E+00, 0.62386800E+01, -.75585300E+00, -.60918200E+00, 0.28665500E-01, -.43110200E+00, -.10105200E+01, 0.34853400E+00, 0.13987200E+04, 0.10676200E+03, 0.28414700E+03, -.46813800E+03, 0.21001300E+02, 0.18457900E+03, 0.26830600E+03, -.13226400E+04, 0.17466700E+04, 0.36691700E+03, 0.43833500E+03, -.15757200E+03, -.49058700E+03, 0.18370000E+03, 0.46215500E+03, 0.50273600E+03, 0.52969500E+03, -.22275900E+03, -.19251200E+03, 0.13102100E+03, 0.31972500E+03, 0.27899900E+03, -.11251500E+03, -.34035700E+03, 0.49554600E+03, 0.28284200E+03, 0.48390600E+03, -.29019400E+03, -.21795800E+03, -.18379800E+03, 0.48887600E+03, 0.37675200E+01, -.23427500E+03, -.22381300E+03, -.24534100E+03, 0.21382400E+03, 0.10056200E+03, 0.19081500E+03, -.25745600E+03, -.15177500E+03, 0.35247200E+03, -.14194900E+03, -.24116800E+03, 0.34325900E+03, 0.10092800E+03, 0.26938700E+03, -.17804300E+03, 0.62509400E+02, -.99978300E+01, 0.42699300E+02, 0.39825400E+02, -.60800800E+02, -.27133200E+01, -.17896900E+02, 0.40486300E+02, -.49217400E+01, 0.11172200E+02, 0.86836700E+01, 0.12992000E+02, -.18529100E+02, 0.43344700E+00, 0.10154800E+02, 0.11073500E+02, -.10005000E+04, -.55387600E+03, 0.28797800E+03, 0.36786700E+03, -.29006700E+02, -.40178900E+03, -.24703200E+03, 0.32528700E+03, -.84565600E+03, 0.25560600E+03, 0.34118800E+03, 0.49539600E+03, -.19310700E+03, -.40099800E+03, -.33850800E+03, 0.46679300E+03, 0.92217000E+03, -.10105400E+04, -.28756100E+03, -.19628500E+03, 0.46905700E+02, 0.35419400E+03, 0.67504000E+02, -.19793300E+03, -.76510300E+01, 0.47041100E+01, -.70935100E+02, 0.61228700E+02, 0.11283000E+01, -.64397900E+01, -.20223500E+03, 0.40568900E+02, 0.77970200E+02, 0.59813600E+02, 0.28881100E+02, -.14802000E+03, 0.18338900E+02, -.64835200E+01, -.62658600E+02, -.16890000E+02, -.48095900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.54213300E+01, 0.92551300E+00, 0.28537200E+01, 0.15947200E+01, 0.16905000E+01, 0.15737800E+01, 0.11812800E+01, 0.23700100E+01, 0.67578300E+01, -.10269500E+01, -.98524400E-02, -.38525900E-01, 0.26014500E+01, 0.18417000E+01, 0.42877800E+01, 0.42768800E+01, -.20373700E+00, -.38114200E+01, 0.14444200E+01, -.17424200E+01, 0.79254200E+00, -.37311700E+01, 0.11766800E+00, -.39422400E+00, 0.16276500E+00, 0.12676100E+01, 0.49717300E+00, 0.11885400E+00, 0.10369300E+01, -.30438500E+00, 0.14553000E+01, 0.31778700E+00, 0.31864300E+00, 0.57122000E+00, 0.44425100E+01, 0.67685500E+00, -.28799000E+00, 0.58410100E+00, -.23834000E+00, -.23350200E+00, -.61291400E-01, 0.30988200E+00, 0.12012000E+03, 0.14152000E+03, 0.16804500E+02, -.53691300E+02, -.10771700E+03, 0.18026900E+03, 0.26715300E+03, 0.28879800E+03, -.15088500E+03, -.23775200E+03, 0.19615200E+03, 0.19510200E+03, 0.18377600E+03, -.22974000E+03, 0.11505400E+04, -.96964900E+03, -.56482000E+02, -.57523400E+01, -.32469100E+03, 0.38026800E+03, -.10899700E+03, 0.22938400E+02, 0.13281500E+04, -.16346100E+04, -.66659400E+02, -.20058400E+02, -.33933400E+03, 0.40809400E+03, -.22259800E+03, 0.19220000E+02, 0.23800100E+02, 0.14241700E+03, 0.90253100E+02, 0.11957000E+03, -.99929400E+02, -.39412000E+02, -.12891000E+03, 0.12763900E+03, 0.41738900E+03, -.39614000E+03, -.14296300E+03, -.14290600E+03, -.39748300E+02, 0.19968000E+03, 0.65830500E+02, -.15531300E+03, -.35070800E+02, 0.54410500E+02, 0.22386200E+02, 0.39334900E+02, -.16374400E+02, -.22099100E+02, -.44484400E+02, 0.37553200E+02, -.16594300E+02, 0.15060500E+02, 0.41226900E+01, 0.57359200E+01, 0.54104000E+01, -.77498000E+01, -.18137400E+01, 0.65748600E+01, 0.49550900E+03, -.76594200E+03, -.75304900E+02, -.66320900E+02, -.55337100E+02, 0.13598000E+03, 0.52662000E+01, -.57509900E+02, 0.95219900E+03, -.12869800E+04, -.14412500E+03, -.13135800E+03, -.78128300E+02, 0.30577600E+03, -.18501200E+03, -.12619700E+03, 0.17971200E+03, -.58093400E+03, 0.22598900E+03, 0.33469600E+03, -.37115700E+03, -.73290400E+02, -.37702500E+03, 0.34661600E+03, -.20643200E+02, -.20929300E+02, 0.10662900E+02, -.88361100E+01, -.78241500E+01, -.63470800E+01, 0.26030200E+02, -.79470500E+02, -.47344600E+02, 0.23771400E+03, -.16551600E+02, -.15661800E+01, -.77675000E+01, -.25287400E-01, -.11206400E+02, -.93666300E+02, -.11306700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.32193500E+01, -.56965500E+00, -.18981500E+01, -.95521800E+00, -.84370000E+00, -.12168500E+01, 0.33223200E-01, -.11731500E+01, -.12517800E+01, 0.20300200E+00, 0.64812200E-01, -.84949700E+00, -.10215500E+01, -.61555700E+00, -.78001800E+00, -.13665200E+01, 0.10651500E+00, 0.10810000E+01, -.31696900E+00, 0.13565400E+00, -.27212200E+00, -.76089200E+00, 0.78902300E-01, -.21694500E+00, 0.87485900E-01, -.97401000E+00, 0.65053200E-01, -.21633300E+00, -.95962800E-01, -.55888700E+00, -.64456800E-01, 0.32130100E+00, 0.55051400E-01, -.26568000E+00, 0.65470300E+01, -.10343300E+00, -.44135000E+00, -.14482700E-01, 0.53034600E+00, -.13289000E+01, 0.33925900E+00, 0.59997900E+00, 0.70367700E-01, 0.49235300E+02, -.50835000E+02, 0.21181000E+02, -.65325000E+02, 0.47714400E+02, -.14008400E+03, 0.23557000E+03, 0.15343700E+02, -.20452800E+01, -.16539600E+02, -.11826700E+02, 0.43150500E+02, -.17194500E+02, 0.20880900E+03, 0.72886500E+02, 0.63327400E+02, 0.95269600E+02, -.91222400E+02, 0.79507200E+02, -.70148400E+02, 0.13913200E+03, 0.10667800E+03, -.11966300E+03, 0.15535800E+03, 0.20328500E+03, -.16428700E+03, -.49875900E+02, -.23458500E+03, 0.23919900E+03, -.86244300E+02, -.16889900E+02, 0.49261500E+02, 0.68562100E+02, -.49042100E+01, -.25541000E+02, -.17442300E+02, 0.71936500E+02, -.15198200E+03, 0.12880700E+03, 0.16333500E+02, 0.20442800E+02, 0.29455400E+02, -.29309500E+02, 0.52327900E+02, 0.34552700E+02, 0.63698500E+01, -.30562100E+02, -.30319800E+01, 0.83615600E+00, 0.34197800E+01, -.47132900E+01, -.27876300E+01, 0.18815900E+01, 0.15211000E+01, -.13187900E+01, -.39919400E+01, -.20483600E+01, 0.56009300E+00, 0.12755300E+01, -.28407600E+00, -.21629800E+01, 0.20787000E+03, -.61634400E+02, 0.41942600E+01, 0.28334300E+02, -.57431800E+02, 0.78163600E+02, -.40585000E+02, 0.34084700E+02, -.20874000E+03, -.99210500E+02, 0.14916300E+03, 0.20432800E+03, -.90693400E+02, -.13393200E+03, -.15364300E+03, 0.22198600E+03, 0.26377800E+03, -.15900100E+03, 0.18761900E+02, 0.35293700E+02, -.23270900E+02, 0.88964800E+02, -.72100100E+02, 0.59914100E+02, 0.16506600E+01, -.48672600E+01, 0.89580700E+01, -.60975200E+01, -.18929400E+01, 0.25479000E+01, -.56732600E+01, 0.23393900E+00, -.89714700E+01, 0.14250900E+03, 0.26049100E+01, -.18790100E+02, -.22655100E+01, -.68189000E-01, 0.12569100E+02, -.91193900E+02, -.21067700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19923900E+01, -.17840200E+00, -.15575100E+00, -.41937400E+00, -.63211100E+00, -.35559000E-02, -.88094300E+00, -.95931600E+00, 0.57903900E+00, -.92306800E-01, 0.49152100E-01, -.47197000E-01, -.22656000E+00, -.22373800E-01, 0.39107100E+00, -.52695500E-01, -.27669400E-01, 0.65520500E+00, 0.27348400E+00, -.14372700E+00, -.19573800E+00, 0.36800800E-01, -.37243900E+00, 0.93692300E-01, 0.28860200E-01, -.80844100E+00, -.13462000E+00, -.33183500E+00, 0.11432000E-01, 0.67913400E+00, 0.78018600E+00, -.17493100E+00, -.30398100E+00, -.18934000E+00, 0.22278200E+01, 0.41583000E+00, -.80193300E-01, 0.15070600E+00, 0.17517700E+00, -.43783100E+00, 0.67908700E-02, 0.73065900E-01, 0.78700300E-01, -.37248200E+00, 0.68678600E+02, 0.16816000E+02, -.24815100E+02, 0.73657700E+01, -.40440100E+01, 0.75783800E+02, -.11152500E+03, -.14508000E+03, 0.19023900E+03, 0.91378400E+02, 0.69602200E+02, -.14637400E+03, 0.29614200E+03, -.47158100E+02, -.25562600E+02, -.33803800E+02, -.36060200E+02, 0.15371000E+03, 0.12147800E+03, -.81712300E+01, 0.42275400E+03, -.33683100E+03, 0.65313300E+02, 0.90706000E+02, -.16090400E+03, 0.11136200E+03, -.38472600E+02, 0.12667100E+03, -.42120300E+02, 0.65544700E+02, 0.14132800E+02, 0.12493600E+02, -.17073000E+01, 0.12696800E+02, 0.19085300E+02, 0.15702800E+02, 0.20919300E+02, 0.10279200E+02, -.34108300E+02, -.40060500E+02, 0.18940400E+02, 0.51466500E+02, 0.10438400E+03, -.38824500E+02, 0.10463300E+01, -.20934200E+01, 0.10373800E+02, 0.15691500E+02, -.19092800E+02, -.13271700E+02, -.32758300E+02, 0.13854600E+02, 0.24343500E+01, -.32525500E+01, -.26216100E+01, -.12510300E+01, 0.68873900E+00, -.11381900E+01, -.34424900E+01, -.14609800E+01, 0.16315500E+03, -.15294700E+03, -.26294600E+00, 0.21808600E+02, -.64141700E+02, 0.42643400E+02, -.76847500E+01, 0.23455000E+02, -.77976800E+02, -.20405900E+03, 0.95550500E+02, 0.14430700E+03, -.57304800E+02, -.51698500E+02, -.10470400E+03, 0.15379000E+03, 0.17310700E+03, -.91901200E+02, 0.52954700E+02, 0.63718700E+02, -.11739200E+03, 0.46185600E+02, -.57136800E+02, 0.71416600E+02, 0.32000700E+01, -.88851500E+01, 0.79206900E+01, -.71649400E+01, -.86103400E+00, 0.31247700E+01, 0.19670100E+02, -.47517200E+02, 0.10358100E+02, 0.79708000E+02, -.33283700E+00, -.25310000E+02, -.12411100E+02, -.77673300E-01, 0.30853200E+01, -.65351900E+02, -.17966300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13201300E+02, -.97569900E+00, -.46905900E+01, -.23893800E+01, -.23288700E+01, 0.17555400E+00, -.53502400E+01, -.10019300E+02, -.44450600E+01, 0.15765000E+01, 0.33407600E+00, -.34752300E+01, -.45713200E+01, -.29351700E+01, -.88285800E+01, -.43000300E+01, 0.61739700E+00, 0.79592400E+01, -.41860900E+01, 0.37937000E+01, 0.46061000E-01, 0.64785500E+00, 0.67595500E+00, -.30254900E+00, -.17418100E-01, -.25483300E+01, -.47717700E+00, 0.44284800E+00, -.33323300E+00, 0.95558300E+00, -.27394800E+01, -.14532400E+01, -.28589900E+00, -.49061300E+00, -.11110900E+02, 0.15463900E-01, -.24082700E+00, -.11907500E+01, 0.18945300E+01, 0.57760400E+00, 0.51985000E-02, -.30789200E+00, -.31849700E+00, 0.16480600E+01, -.10516900E+01, -.45039800E+02, 0.33497400E+02, -.94655000E+01, -.30403500E+03, -.18415300E+03, 0.22169700E+02, 0.86408000E+02, 0.41203300E+02, -.11119900E+03, 0.75010900E+02, 0.91741000E+02, -.19927200E+03, -.69213800E+01, -.36651500E+02, -.95597700E+02, 0.13610000E+03, -.36148000E+02, 0.16252100E+03, -.12477300E+03, -.29610000E+03, 0.28403700E+03, -.25732900E+01, -.14622700E+02, 0.16635800E+03, -.63820100E+02, 0.18640300E+03, -.28482400E+02, 0.69194300E+02, -.39120600E+02, -.14820000E+03, -.18842300E+03, 0.99112600E+02, 0.87430100E+02, 0.12607700E+03, -.19878000E+03, 0.13862100E+03, -.19398500E+03, -.10384200E+02, -.59364600E+02, -.29131000E+01, 0.62656700E+02, 0.60755600E+02, -.67541400E+02, 0.18005000E+01, 0.33124700E+02, 0.27556200E+02, 0.19854600E+02, -.26981200E+02, -.14942600E+02, -.23350200E+02, 0.18792600E+02, 0.61184800E+01, -.25660900E+01, 0.36835500E+01, 0.18474600E+01, -.58919100E+01, -.12145400E+01, -.17379000E+01, 0.13366400E+01, -.42556200E+03, 0.37180900E+03, 0.15417500E+03, 0.16433800E+03, -.24541700E+02, -.17590700E+03, -.83776500E+02, 0.16161400E+03, -.80407900E+03, 0.44303000E+03, 0.13710000E+03, 0.14706300E+03, 0.14452300E+03, -.23618200E+03, 0.83610800E+02, 0.13920600E+03, -.20051400E+03, 0.12529500E+03, -.52161000E+02, -.10364500E+03, 0.13715700E+03, -.32050700E+02, 0.12491300E+03, -.12677900E+03, 0.76987900E+01, 0.26576100E+01, -.79832600E+01, 0.88295700E+01, 0.59959500E+01, 0.82013900E+00, -.10484300E+02, 0.24346700E+02, 0.18307600E+02, -.73767600E+02, 0.12763500E+02, 0.11073000E+01, -.54537700E+01, -.15705400E+01, 0.51770600E+01, 0.23981100E+02, 0.48476400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.32605800E+01, 0.65232900E+00, 0.14841000E+01, 0.63702400E+00, 0.63314400E+00, 0.52349000E+00, -.89176200E+00, 0.19134400E+00, 0.21814300E+01, -.35033500E+00, 0.78946800E-01, -.26060100E+00, 0.84780200E+00, 0.64006800E+00, -.34850900E+00, 0.96050500E+00, -.16840200E+00, -.16661300E+01, -.19888800E+00, 0.24843000E+00, 0.66314400E+00, 0.65791000E+00, 0.52624500E+00, 0.12241000E-01, 0.15793600E+00, 0.48289100E-01, 0.16005100E-01, 0.19183300E+00, -.25212900E+00, -.15957300E+01, 0.78565200E+00, 0.15588400E+01, 0.28296600E+00, 0.94970800E-01, 0.41247400E+01, -.36746300E+00, -.58395700E+00, -.26046600E+00, 0.39427700E+00, 0.29586100E+00, 0.28424100E-01, 0.29548400E+00, -.21227400E+00, -.89527400E-01, 0.34148800E+00, -.27806300E-01, 0.50883800E+02, 0.15720400E+02, -.30227000E+02, 0.30379900E+02, 0.39824600E+02, 0.10999100E+02, 0.51885000E+01, -.94025900E+00, 0.39969400E+02, 0.18155100E+02, 0.27695000E+03, -.20173100E+03, -.82469400E+02, -.10121000E+03, -.64724600E+02, 0.15261700E+03, 0.46083400E+02, -.11570100E+03, 0.65328700E+03, -.18237100E+03, -.12140000E+03, -.19733700E+03, -.82706300E+02, 0.27448600E+03, 0.71864400E+02, -.20934400E+03, 0.45976500E+02, -.90155300E+02, 0.25714700E+02, 0.62479400E+02, -.45463500E+02, -.16249000E+02, -.89191700E+02, 0.57757800E+02, 0.13364000E+03, -.13520300E+03, -.64496200E+02, -.69242000E+02, -.24565300E+02, 0.87834100E+02, 0.61997200E+02, -.74406000E+02, -.19438300E+02, 0.20128300E+02, 0.13735300E+02, 0.13310900E+02, -.86755300E+01, -.15556200E+02, -.10658300E+02, 0.12347500E+02, -.35354000E+00, 0.27080600E+01, 0.86814100E+00, 0.61623300E+00, 0.11665700E+01, -.21678600E+01, -.17012400E+01, 0.13623200E+01, -.10577800E+03, 0.16698100E+03, 0.26081800E+02, 0.12931500E+02, 0.76941900E+01, -.36539400E+01, -.10475500E+02, 0.40723000E+01, 0.14670100E+03, 0.41828000E+02, -.26326900E+02, -.87449000E+02, 0.15495400E+01, 0.10377200E+03, 0.61682300E+02, -.93061000E+02, 0.13503000E+03, 0.37778700E+01, -.47991400E+02, -.60692900E+02, -.82020600E+01, 0.77772300E+02, 0.38598300E+02, -.70210500E+02, -.10510000E+01, -.41072800E+01, -.41466100E+01, 0.54706300E+01, -.45944300E+00, -.66628400E+00, -.33588200E+01, -.17273100E+02, 0.13883500E+02, -.60003500E+02, 0.93423600E+01, -.10012700E+02, -.46851100E+01, 0.40970400E-01, -.15874600E+01, 0.36729100E+02, 0.58493400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.51393300E+01, -.73345000E+00, -.27729100E+01, -.13484500E+01, -.13481600E+01, -.16191100E+01, 0.31508800E+00, -.29343500E+01, -.24039000E+01, 0.72642800E+00, 0.16375500E-01, -.72995400E+00, -.84867900E-01, 0.69736800E+00, 0.21748900E+01, -.57980300E+00, 0.75409300E-01, 0.18353800E+01, -.11270700E+00, -.54078700E+00, -.85246500E+00, -.16018600E+01, -.53600600E+00, -.17621600E+00, 0.73112000E-01, 0.18721600E+00, 0.22587600E+00, -.18861300E+00, 0.61680900E+00, 0.52344200E+00, 0.20679700E+00, -.19620900E+00, -.21164500E+00, 0.56146000E+00, -.11209100E+01, 0.22139500E+00, -.49308400E+00, 0.34325800E+00, -.51578700E+00, 0.95446900E+00, -.15450600E-01, 0.58070900E+00, 0.18691200E+00, 0.48181000E+00, 0.93958200E+00, 0.12490300E+00, 0.12211000E+01, -.24491700E+02, 0.37995900E+03, -.21742900E+02, -.31970700E+02, -.28656600E+02, -.10745900E+03, 0.58511200E+02, -.43161400E+02, -.29403400E+02, -.28525200E+03, 0.40251500E+02, 0.64921200E+02, 0.14602300E+03, 0.57898900E+02, -.19154700E+03, -.21179600E+03, 0.15020900E+03, -.10176600E+04, 0.68466000E+02, 0.57933600E+02, 0.18692800E+03, 0.21138700E+03, -.35153100E+03, -.90310700E+02, 0.17934900E+03, -.89754000E+02, 0.84868400E+02, 0.34714600E+02, 0.11113700E+02, -.69612500E+01, -.55041500E+02, 0.40879000E+00, 0.12886100E+02, -.17931500E+03, 0.14791500E+03, 0.55910200E+02, 0.74593400E+02, 0.40270800E+02, -.13707500E+03, -.16135900E+03, 0.80558900E+02, 0.66367600E+01, -.15025300E+02, -.30986000E+02, -.25429600E+02, 0.32581300E+02, 0.30968800E+02, 0.43045800E+02, -.24588700E+02, -.66484200E+01, 0.24900700E+01, 0.29111100E+00, -.75552400E+00, 0.27324200E+01, 0.30380800E+01, 0.72385500E+01, -.20838500E+01, 0.31626600E+03, -.52511000E+03, -.10707800E+03, -.10418300E+03, 0.43628900E+02, 0.72235600E+02, -.37995800E+01, -.90702100E+02, 0.18491100E+03, -.31438400E+03, -.14365400E+03, -.87099200E+02, 0.70493200E+02, 0.35522700E+02, 0.33521700E+01, -.77244700E+02, -.33763900E+03, 0.10728400E+02, 0.92995200E+02, 0.18256700E+03, -.21633500E+02, -.16732700E+03, -.12173500E+03, 0.19030200E+03, -.75800200E+01, 0.91885700E+01, -.16190900E+01, 0.58313100E+00, -.10736800E+01, -.35740300E+01, 0.74296500E+00, 0.17173800E+02, -.35946600E+02, 0.78299000E+02, -.16565600E+02, 0.28566500E+02, 0.18382800E+02, 0.11025200E+01, -.45970400E+01, -.90079300E+01, -.38402400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.58567100E+01, -.44615600E+00, -.81870900E+00, -.65558100E+00, -.70117400E+00, -.37808000E-01, 0.31244800E+01, 0.38329700E+01, -.56006500E+00, -.11327100E+00, -.50580900E-01, 0.16238500E+01, -.27457200E+01, -.24169800E+01, -.25557000E+01, 0.15107700E+01, 0.91156500E-01, -.72790300E+00, 0.58591500E+00, -.36110000E+00, 0.53443100E+00, -.14384000E+01, 0.11997800E+01, -.32472300E+00, 0.52867200E+00, -.15311200E+01, 0.17238800E-01, 0.18809100E+00, 0.15376500E+00, -.29887600E+00, 0.58883100E+00, 0.10933700E+01, -.27560800E+00, -.18411800E+00, 0.19172600E+01, -.30474800E+00, 0.71819900E-02, -.99903800E-01, 0.60965800E+00, 0.11637600E+01, -.16545100E+00, 0.94782500E-01, -.12506700E+00, -.44160900E+00, -.40064600E+00, -.28704100E+00, 0.12010700E+01, 0.55249600E+00, -.30333900E+03, -.69974700E+02, -.75763600E+00, 0.18252100E+02, 0.75794300E+02, -.48372500E+02, 0.29464900E+02, 0.12414000E+02, 0.21245300E+03, -.53204500E+01, -.67296800E+02, -.13460900E+03, 0.66398300E+01, 0.14721600E+03, 0.18855300E+03, -.14534700E+03, 0.85324700E+03, 0.52407000E+02, -.55788500E+00, -.64278000E+02, -.13720900E+03, 0.30955600E+03, 0.11913800E+03, -.33782400E+02, 0.77433100E+02, -.60987100E+02, -.40856700E+02, -.46833900E+02, 0.74052500E+01, 0.57488100E+02, 0.25194500E+02, -.53293000E+02, 0.89688300E+02, -.12025200E+03, -.49173400E+02, -.69677200E+02, -.48213400E+01, 0.76105800E+02, 0.81077600E+02, -.78669700E+02, 0.60035200E+01, 0.11987900E+01, 0.15249600E+02, 0.10740000E+02, -.18671200E+02, -.10399100E+02, -.76580100E+01, 0.10808200E+02, 0.10065400E+02, -.56015600E+01, -.14716700E+01, -.18342200E+01, -.42465200E+01, 0.20370500E-01, -.29198300E+01, -.19892200E+01, -.53728700E+03, 0.46265300E+03, 0.11999000E+03, 0.15044900E+03, 0.52350100E+02, -.15564500E+03, 0.46262800E+01, 0.14855600E+03, -.74585800E+03, 0.51003300E+03, 0.24640600E+03, 0.28872200E+03, 0.23242400E+02, -.25402000E+03, -.51455400E+02, 0.30180200E+03, 0.10082500E+03, 0.13071200E+03, -.44062900E+02, -.11175100E+03, 0.88278500E+02, 0.83060900E+02, 0.13507400E+03, -.11831900E+03, 0.12065900E+02, -.47198500E+00, -.57600700E+01, 0.77995500E+01, 0.45802000E+01, 0.48267000E+01, -.47352700E+01, 0.54667500E+01, 0.31674300E+02, -.14522700E+02, 0.11044900E+02, -.20187200E+02, -.53757200E+01, -.12417400E+01, 0.68527600E+01, -.32807700E+02, 0.46402300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.65379200E+01, 0.11122400E+02, -.68103600E+00, 0.28274400E+01, 0.66030600E+00, 0.12852400E+00, 0.43061700E+01, 0.51980800E+01, 0.33357300E+01, 0.42849900E+00, -.82301700E+00, 0.18078600E+01, 0.32738300E+01, 0.31624500E+01, 0.46770900E+01, 0.35922500E+01, -.58916500E+00, -.14660200E+01, 0.13152000E+00, 0.75323400E-01, 0.54738800E+00, 0.20294900E+01, 0.22629300E+01, 0.12665200E+00, 0.10284400E+01, 0.76075700E+00, -.20205400E-01, 0.61731500E+00, -.13125600E+01, -.15483400E+01, -.28650000E+00, 0.51455200E+01, -.59094300E+00, 0.51958000E-01, -.66074700E+01, 0.10176700E+01, -.11710100E+01, -.24047500E-01, -.22779000E+00, -.23477400E+00, 0.58859600E-01, -.64830200E-01, -.40914900E+00, -.16860200E+01, -.57995600E+00, -.36144500E+00, -.71768600E+00, -.14627200E+00, 0.10823100E+01, 0.43434000E+03, 0.16373000E+02, -.11960300E+03, 0.90647500E+02, 0.43033000E+02, 0.15104300E+03, -.12317700E+03, 0.49889500E+03, -.62159200E+03, 0.41636800E+02, 0.14788300E+02, -.15437800E+03, 0.26514200E+03, -.21025200E+02, 0.81466900E+02, 0.30176100E+03, -.63265100E+03, 0.17578900E+03, 0.19821000E+03, -.27231500E+03, 0.28368800E+02, -.30822600E+03, 0.23598200E+03, -.13934100E+03, -.77029300E+02, 0.22426900E+03, 0.31289000E+03, -.17262300E+03, -.14501500E+03, -.26451000E+03, 0.32051800E+03, 0.93582400E+02, -.23425700E+03, -.85646200E+02, -.12831200E+03, 0.64248000E+02, 0.13232400E+03, 0.21183600E+03, -.96782300E+02, -.19854600E+02, -.21267800E+02, 0.15834900E+02, 0.23167500E+02, -.14934000E+02, -.35024000E+02, -.48061600E+02, 0.19439700E+02, 0.16083400E+01, -.10260200E+01, -.69413800E+01, -.61664900E+01, 0.60200600E+01, -.25253600E+00, -.79655500E+00, -.66696200E+01, 0.65476800E+03, -.57080100E+03, -.10134400E+03, -.12436400E+03, -.56699700E+02, 0.27297200E+03, -.86045000E+01, -.12360600E+03, 0.47794200E+03, -.74098100E+03, 0.51145200E+01, -.15122800E+02, -.94423400E+02, 0.15699500E+03, -.11592500E+03, 0.36193000E+01, 0.67303600E+03, 0.37407600E+02, 0.78285000E+01, 0.23518200E+02, -.16562100E+03, 0.28045300E+03, -.87860900E+02, 0.50600000E+02, 0.13952400E+01, -.10730500E+02, 0.11935900E+02, -.65714000E+01, -.54881500E+00, 0.41400000E+01, 0.10023300E+02, -.87288500E+02, -.17411000E+02, 0.16886500E+03, 0.47980100E+01, -.39964500E+02, -.19686000E+02, 0.12841200E+01, -.53607500E+00, -.78079600E+02, -.45698100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.55590400E+01, -.11601800E+01, -.39684000E+00, -.83851800E+00, -.87328400E+00, 0.16049100E+00, 0.72668000E+00, 0.39988000E+00, 0.21774900E+01, -.41816200E+00, -.14664600E-01, 0.43263200E+00, -.25578200E+00, -.27122600E+00, 0.29791000E+01, 0.21649700E+01, -.18648900E+00, -.10366800E+01, 0.16230000E+01, -.14433200E+01, -.45383300E+00, -.19169700E+00, -.42014200E+00, 0.17634200E+00, -.81137900E-01, -.54435000E+00, 0.25426500E-02, -.19650200E+00, 0.43259000E+00, 0.15634600E+01, 0.11658300E+01, -.25991900E+00, -.50223200E+00, -.15417500E+00, 0.51324100E+01, -.12166800E+00, 0.15778900E+00, 0.24617100E+00, -.61802000E+00, -.15001500E+01, 0.26141900E+00, 0.18476500E+00, 0.33405700E+00, 0.63801800E-01, 0.10852400E+01, 0.22197800E+00, 0.66704700E-02, 0.69130600E+00, 0.19423200E+00, 0.75788500E-01, 0.47230300E+02, 0.66069700E+02, -.50184000E+02, -.32728000E+02, -.53648100E+02, 0.73284400E+02, -.14752600E+03, 0.78627800E+02, 0.28197700E+02, 0.30595400E+02, -.40215900E+01, -.10303600E+03, -.48149300E+02, 0.16150400E+02, -.33138100E+03, 0.98644900E+02, -.14481600E+02, -.37811600E+02, 0.65868000E+02, -.10951900E+03, 0.46025800E+02, -.70397300E+02, 0.58199900E+01, -.17843000E+02, -.20315400E+02, -.11305400E+02, 0.19077900E+02, -.28210500E+01, 0.14104100E+02, -.12043600E+02, -.44213100E+01, 0.27441300E+02, 0.42399800E+02, 0.51140900E+02, -.31425500E+02, -.40155000E+02, -.55337100E+02, 0.51540300E+02, 0.22602100E+01, 0.15525800E+02, -.22643400E+01, -.27866300E+01, -.14099100E+01, 0.53233700E+01, -.18857800E+01, -.24954600E+01, -.35929100E+01, 0.22099200E+01, 0.18141200E+01, 0.22142900E+01, -.29343100E+00, -.51274100E+00, -.32176900E+00, 0.26034900E+01, -.68134500E+02, 0.35565900E+02, 0.17634800E+02, -.11093800E+02, -.13768800E+02, -.43785000E+02, 0.17244900E+01, -.22918800E+02, -.21831600E+02, 0.37750900E+02, -.24753000E+02, -.64768000E+02, 0.40175500E-01, -.74612800E+01, 0.42586900E+02, -.86001700E+02, -.62735400E+02, -.45254600E+02, -.33147100E+02, -.41466600E+02, 0.24788100E+02, -.24220100E+02, 0.22780100E+02, -.53508400E+02, -.41991000E+01, 0.29607400E+00, -.18587400E+01, 0.50348500E+00, -.15944400E+01, -.20213000E+01, -.41034700E+00, 0.14667800E+02, -.43759200E+01, -.64785800E+02, 0.29161000E+01, 0.18946000E+02, 0.56813300E+00, -.91243000E-01, -.75023700E+01, 0.43109900E+02, 0.71070100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.31502800E+01, -.64692000E+00, -.15748300E+01, -.66297900E+00, -.45103500E+00, -.73339000E+00, 0.14617700E+01, 0.64346300E+00, -.19396400E+01, 0.15649300E+00, -.25875300E-01, -.68148900E-01, -.26670200E+00, -.87454900E-01, 0.53082800E+00, -.10576100E+01, 0.22983500E-01, 0.34943700E+00, 0.27227300E+00, -.28384000E+00, -.59643500E+00, 0.98947300E+00, -.58596100E+00, 0.16914600E+00, -.29363000E+00, 0.41304600E+00, 0.16164100E-01, 0.90716700E-01, 0.64573200E-01, 0.13675800E+00, 0.69686900E+00, 0.60693700E-01, -.10870900E+00, 0.29634800E-01, 0.60084900E+01, -.11165400E+01, -.32445100E+00, -.15931900E+00, -.44352000E+00, 0.32027000E+00, 0.94030200E-01, 0.69729700E+00, -.26724700E+00, -.68668500E+00, 0.34678700E+00, 0.22486800E-02, 0.57221200E+00, 0.31068300E+00, -.40621800E-01, 0.24450700E+00, 0.19905600E-01, -.25802800E+02, -.16896100E+01, 0.17771300E+01, 0.59031200E+01, -.35603200E+02, 0.57795100E+02, -.48558900E+02, 0.10662000E+01, 0.19252200E+02, -.34437300E+02, -.70161000E+01, 0.55927800E+01, 0.13050700E+02, 0.10975100E+03, -.13729500E+03, -.34517000E+02, -.16439500E+02, 0.50527800E+01, 0.52906600E+02, 0.43697300E+02, -.12915200E+02, 0.21408100E+02, -.14297100E+02, 0.10395900E+02, 0.23198100E+02, -.12305700E+02, -.14158800E+02, -.18443000E+02, 0.23420900E+02, 0.21506600E+02, 0.56606900E+00, 0.13476100E+02, 0.20883800E+02, -.40702400E+02, -.18275200E+02, -.19001400E+02, 0.13217200E+02, -.33746500E+01, 0.10136700E+02, 0.68249500E+00, 0.24231100E+01, -.32267300E+01, 0.47210100E+00, -.81322700E+01, 0.27449800E+01, -.71216800E+00, 0.10353600E+01, -.49773600E+00, -.64265000E+00, 0.49293200E+00, -.20570800E+00, 0.11000300E+00, -.55979200E+00, 0.32516600E+02, -.43212000E+02, 0.28770500E+02, 0.30930900E+02, -.43115500E+02, -.15053200E+02, -.36579200E+02, 0.29802200E+02, 0.41897600E+02, -.58688800E+02, 0.92291600E+01, 0.22922500E+02, -.34252800E+02, -.11089300E+01, -.31591200E+02, 0.20714500E+02, 0.11861000E+02, -.73715400E+02, 0.11250500E+02, 0.37394700E+02, -.16856500E+02, -.52353200E+01, -.32619900E+02, 0.44179400E+02, -.99372400E+00, -.19468400E+01, -.42088200E+00, -.33201900E+00, -.27401700E+00, 0.80609900E-01, -.20659500E+00, -.10231200E+02, -.31083200E+01, 0.13489000E+02, 0.71811700E+00, 0.17472500E+02, -.25001400E+01, -.85675700E-01, 0.19138600E+00, -.13571300E+02, -.13075500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.59085600E+01, 0.10551400E+01, 0.28300900E+01, 0.14007200E+01, 0.10313200E+01, 0.15888500E+01, -.22428900E+01, -.10338200E+01, 0.28937600E+01, -.23101600E+00, 0.94275600E-02, 0.14832100E+01, 0.15647000E+01, 0.40255100E+00, 0.12262700E+01, 0.41126100E+01, -.16216500E+00, -.33214900E+00, 0.11547100E+00, 0.11255100E+00, 0.10530800E+01, -.39712200E+00, 0.59137600E-02, -.53557600E-02, 0.18135900E+00, -.43559400E+00, -.17127600E+00, -.28107800E+00, -.26210300E+00, 0.19165100E+01, -.12259000E+01, -.52757100E+00, -.20053900E+00, -.13121900E+00, -.10683500E+02, 0.93196300E+00, 0.32893500E+00, -.78197400E-01, 0.22556600E+00, -.24111600E+01, 0.19827100E+00, -.47395700E+00, 0.21601900E+00, -.56135300E+00, -.45006600E+00, 0.58035900E-01, -.12818700E+01, 0.24616200E-01, -.46169000E+00, -.10200700E+00, 0.60781000E+00, 0.16866200E+01, 0.49479800E+02, 0.11076300E+02, 0.16355000E+02, 0.23097500E+02, 0.12631600E+03, 0.13315200E+02, -.71248000E+02, -.10365900E+03, 0.34140200E+02, 0.18440400E+03, 0.12208700E+03, -.97285600E+02, 0.41484600E+03, 0.18829200E+03, 0.43665600E+02, -.37043400E+02, -.85174800E+02, 0.17191100E+03, 0.53716900E+02, -.21956200E+02, -.40413100E+02, -.64659700E+02, 0.48587300E+02, 0.63915700E+02, -.62423500E+02, -.54608700E+01, -.71495000E+02, 0.54376100E+02, -.42352000E+02, -.55338800E+02, -.92671000E+02, -.82449100E+02, 0.71681600E+02, 0.78680200E+02, 0.99440400E+02, -.71662700E+02, 0.89430200E+01, -.66040100E+02, -.56876000E+01, -.11186100E+02, 0.15954100E+02, 0.31170900E+00, 0.36173700E+02, -.11590100E+02, 0.92520200E+01, -.63021100E+01, -.24533500E+01, -.26400200E+01, -.64264000E+00, 0.20684600E+01, 0.64806200E+00, -.29068900E+01, -.30700400E+03, 0.29289500E+03, -.71854600E+02, -.69549900E+02, 0.22536300E+03, 0.44811300E+02, 0.19699300E+03, -.67179200E+02, -.54911700E+03, 0.29708000E+03, 0.12810700E+03, 0.11774800E+03, 0.10590900E+03, -.14115500E+03, 0.45335700E+02, 0.14107700E+03, 0.62452800E+02, 0.28470000E+03, -.23387700E+02, -.78417100E+02, 0.35264400E+02, 0.86251100E+02, 0.13723100E+03, -.10147800E+03, 0.10737600E+02, 0.64641700E+01, 0.42400400E+01, 0.24507400E+01, 0.37277200E+01, 0.35067300E+01, 0.22420000E+00, -.15405500E+01, 0.30186100E+02, -.24931800E+02, 0.96120700E+01, -.59068100E+02, 0.86355300E+01, 0.44159500E+00, 0.17746300E+01, -.61762700E+01, 0.35674500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.38759400E+01, -.44102700E+00, -.30376300E+00, -.48530500E+00, -.66749500E+00, 0.25444300E+00, 0.86704600E+00, 0.65349600E+00, 0.10712900E+01, -.30829400E+00, -.66388700E-02, 0.39487200E+00, -.40034300E-01, 0.74206500E-01, 0.20617800E+01, 0.16266700E+01, -.16555100E+00, -.19139300E+01, 0.17254900E+01, -.13934900E+01, -.39383700E+00, 0.11205500E+01, -.39665800E+00, 0.32294900E+00, -.21270500E+00, 0.27216300E+00, -.60840400E-02, 0.24846000E-01, 0.14140200E+00, 0.11374100E+01, 0.89265900E+00, -.34754200E+00, -.18232500E-01, -.17341900E+00, 0.48929400E+01, -.95501300E+00, 0.12336800E+00, -.17254800E+00, -.77157200E+00, -.73211900E+00, 0.27145700E+00, 0.35239700E+00, -.75596500E-01, -.45633800E+00, 0.70650800E+00, 0.88909600E-01, 0.71957800E-01, 0.46441700E+00, -.24979500E+00, 0.88406700E-01, 0.44916300E+00, 0.85079800E+00, 0.13550400E+00, -.10857000E+02, 0.33187200E+01, 0.69830900E+00, 0.15231600E+02, -.28192400E+02, -.39783500E+02, -.40516900E+02, 0.39831300E+02, 0.22983900E+02, 0.20913900E+02, -.42333600E+02, 0.10261200E+03, -.48583700E+02, -.55318300E+02, -.56898500E+02, 0.32718700E+02, 0.57525700E+02, 0.27418700E+02, -.57621600E+02, -.85166400E+01, -.23346200E+02, -.18713700E+02, -.15419900E+02, 0.13541900E+02, -.10392200E+01, 0.59109000E+01, -.15654200E+02, -.59781100E+01, -.18039700E+02, -.21779900E+02, -.23399700E+02, 0.26180900E+02, 0.12228100E+02, 0.21330300E+02, -.24017100E+02, -.39005000E+00, 0.39797300E+01, 0.27188100E+01, 0.14770400E+01, -.33333500E+00, 0.16280000E+00, 0.30891700E+01, 0.16064100E+01, 0.11840400E+01, -.80529600E+00, 0.59293200E+00, 0.20329800E+00, -.69110300E+00, 0.57086900E+00, -.52786900E+00, 0.21094400E+00, -.12368200E+03, 0.78260200E+02, 0.28353300E+02, 0.29926400E+02, 0.88946200E+01, -.47548800E+02, -.18150000E+02, 0.29616700E+02, 0.19083400E+02, 0.30156400E+01, -.25138000E+02, -.27052800E+02, 0.27238600E+02, 0.22301100E+02, 0.37282600E+02, -.25796800E+02, 0.27918200E+02, 0.54805400E+01, -.17829700E+02, -.15669200E+02, 0.83742400E+01, 0.18757000E+02, 0.85009000E+01, -.16285800E+02, 0.13296700E+01, 0.27814900E+01, 0.57502900E+00, 0.52088000E-01, 0.17985800E+01, 0.77920800E-01, -.18326800E+00, 0.52830500E+00, 0.66396500E+01, -.14495100E+02, 0.56697600E+01, -.10620000E+02, 0.15158500E+01, -.27047400E-02, 0.35272600E+01, 0.96912900E+01, 0.22598500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16943300E+01, 0.88762000E-01, 0.10945200E+01, 0.32933200E+00, 0.38605600E+00, 0.62153500E+00, -.83013800E+00, -.13021500E+01, 0.17813300E+00, 0.11455200E+00, -.38429000E-02, -.55690400E-01, 0.18934800E+00, -.21686900E+00, 0.52129800E+00, -.13961400E+00, 0.28198300E-03, 0.68724100E+00, -.26333400E+00, 0.21963500E+00, 0.27149000E-01, 0.68254100E-01, 0.16635000E+00, -.39751900E-01, 0.26923500E+00, -.40670200E+00, -.44239800E-01, -.32832900E+00, -.98008000E-01, 0.52961300E+00, -.10453900E+00, 0.11805200E+00, 0.14274100E+00, -.40615100E-01, -.70784900E+00, 0.69016800E-01, -.29111400E+00, -.33283500E+00, 0.23032200E+00, -.23894900E+00, 0.10923600E+00, 0.12980900E+00, -.13608100E+00, -.23958600E+00, 0.23239400E+00, 0.39022000E-01, 0.25923900E+00, 0.12256600E+00, -.30876700E-01, 0.11559600E+00, 0.14789800E+00, 0.12272700E+00, -.49182600E-01, -.67586400E-01, -.12427300E+02, -.16062300E+01, 0.32517900E+02, -.39212700E+02, -.20481000E+02, -.25456900E+02, 0.56949800E+01, 0.82491600E+01, 0.31162900E+02, -.29737400E+02, 0.15354100E+03, -.25600800E+02, -.30844400E+02, -.46008400E+02, 0.71085800E+01, 0.69958700E+02, 0.54155100E+02, -.42392900E+02, 0.19161700E+02, -.21979900E+02, 0.15786600E+02, 0.22550600E+02, -.22778800E+02, -.92216700E+01, -.32615100E+02, 0.21504400E+02, -.74238600E+01, -.99746600E+01, -.13834000E+01, 0.69945600E+01, -.13194600E+02, -.96275200E+01, -.83572900E+01, 0.32203600E+01, 0.33838600E+01, -.58890800E+01, -.35765300E+01, -.42337300E+01, 0.29168500E+01, 0.46811900E+01, 0.46747900E+01, -.39204400E+01, 0.11172000E+01, -.42105600E+00, -.57357700E+00, -.87631500E+00, 0.22421900E+00, 0.89844400E+00, 0.49465400E+00, -.84382900E+00, -.53185100E+02, 0.24932900E+02, 0.64888800E+01, -.48118700E+01, 0.22148200E+02, -.16704200E+02, 0.17121100E+02, -.53155800E+01, -.60151700E+00, 0.34175800E+02, 0.95356100E+01, 0.74244700E+01, -.10097300E+01, -.42280800E+00, 0.86049500E+00, 0.96714700E+01, 0.23030200E+02, 0.27856400E+02, -.19817200E+01, -.13121000E+02, 0.28902800E+01, 0.85046700E+01, 0.19848000E+02, -.12983700E+02, 0.11486900E+01, 0.23955000E+01, 0.81776500E+00, -.42144200E+00, 0.12765000E+01, 0.37389800E+00, -.92646000E-01, 0.27567000E+01, 0.42390800E+01, -.11311500E+02, 0.11910400E+01, 0.50195500E+01, 0.14102600E+01, 0.14623700E+00, 0.63488900E-02, -.31887100E+01, 0.65189000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.55544900E+01, -.11138400E+01, -.28422200E+01, -.15459100E+01, -.14019200E+01, -.15642900E+01, -.52611200E+00, -.17382500E+01, -.37440200E+01, 0.35194100E+00, 0.12649400E+00, -.12934500E+01, -.12355300E+01, -.65447600E+00, -.14656200E+01, -.38607400E+01, -.79409500E-02, 0.11965100E+01, -.57417000E+00, 0.71151400E+00, -.70077200E+00, 0.16975300E+01, -.19303500E+00, 0.68708000E-01, -.40137000E+00, -.36289800E+00, -.65581700E-01, -.11919100E+00, -.32408000E+00, -.16725800E+01, 0.32967900E+00, -.17876600E+01, 0.62501000E+00, -.50764200E+00, 0.92034700E+01, -.96098000E+00, 0.14152200E+00, 0.29034200E+00, 0.53700800E+00, 0.12063900E+01, -.25078900E+00, 0.65083700E+00, -.47190900E+00, -.11940700E+00, 0.97855200E+00, -.13906600E+00, 0.14033000E+01, 0.48628300E+00, -.49588300E+00, -.51574800E+00, -.11720300E+01, 0.74700200E+00, -.16190800E-01, -.87425600E+00, -.23871000E+00, 0.10703800E+02, 0.15939100E+03, -.13613200E+03, -.70494700E+02, -.11418900E+03, 0.39701400E+02, 0.12757600E+03, 0.13203900E+03, -.11686700E+03, 0.43770000E+03, 0.40941800E+02, -.32827800E+02, -.72708200E+02, -.34228100E+02, 0.17141400E+03, 0.72856000E+02, -.69329400E+02, 0.46025700E+02, -.11216500E+03, -.30066200E+02, -.55915500E+01, -.83389400E+01, 0.14096100E+02, -.31135400E+02, -.10981900E+02, 0.78459900E+02, -.15500400E+03, -.65077600E+02, -.68945600E+02, 0.23470400E+02, 0.86177500E+02, 0.10558500E+03, -.65319400E+02, 0.10999100E+02, -.48928600E+01, 0.13712500E+02, 0.44335200E+01, -.10201000E+02, -.72942200E+01, -.66016400E+01, 0.40580600E+01, 0.71632700E+01, -.35758000E+01, -.77479000E-02, -.14792400E+01, -.20067600E+01, 0.17542800E+01, -.20130000E+01, -.15237000E+01, -.41834600E+03, 0.29115300E+03, 0.79341600E+02, 0.71561600E+02, 0.60080100E+02, -.10826100E+03, 0.33852100E+02, 0.64836500E+02, -.30011300E+03, 0.24435600E+03, 0.10046400E+03, 0.10055200E+03, 0.19700600E+02, -.99298600E+02, 0.12128500E+02, 0.10440600E+03, 0.10387300E+03, 0.18334600E+03, -.35553400E+02, -.74301400E+02, 0.42942500E+02, 0.65724100E+02, 0.96835400E+02, -.83930100E+02, 0.80480600E+01, 0.75101100E+01, 0.26172500E+01, -.73461100E+00, 0.66162500E+01, 0.22627100E+01, -.34109300E+00, 0.52559700E+01, 0.22697700E+02, -.29950600E+02, 0.19791700E+02, -.33643900E+02, -.33393600E+01, -.19129000E+00, 0.41205000E+01, -.64494300E+01, 0.30994400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.46567200E+00, 0.10526500E-01, 0.14225300E-01, 0.95553900E-02, 0.74352000E-03, -.22639100E-01, 0.38949500E-01, 0.84977100E-01, -.44075700E-01, 0.12634100E-01, -.81372800E-02, 0.38697000E-01, 0.12113100E-01, -.65789800E-01, 0.13170700E+00, -.29179500E-01, -.19379800E-02, 0.11331000E+00, -.41148800E-01, 0.18908600E-01, 0.19461900E-02, 0.49638300E-01, 0.21864500E-01, -.70906700E-02, 0.43199700E-02, -.40930900E-01, -.10403700E-01, -.12917900E-01, -.49159200E-02, 0.46866200E-01, -.27720300E-01, -.65824200E-01, -.80549300E-02, 0.27545700E-01, -.45241000E+00, 0.13630400E-01, -.20310900E-01, -.49536800E-02, 0.57788100E-01, 0.40274900E-01, -.77034500E-02, -.19589400E-02, -.30985800E-02, 0.28247800E-01, -.43891200E-01, 0.53698000E-02, -.12728400E-01, -.33280800E-01, 0.80603400E-03, 0.17792000E-02, -.54678500E-02, -.15042200E-01, 0.44575400E-02, 0.14579900E-01, -.42165200E-01, -.10779200E-01, 0.11004100E+02, -.31972300E+00, -.73507400E+01, -.86783800E+01, 0.42861300E+01, 0.67382000E+01, 0.89541900E+01, -.97754500E+01, 0.33872400E+02, -.37248500E+01, -.93712100E+01, -.10983700E+02, 0.88545200E+00, 0.15925400E+02, 0.89640100E+01, -.10824300E+02, 0.83822100E+00, -.16622600E+01, -.51949000E+00, -.11582100E+00, -.35884200E+00, -.46381000E+00, -.84789400E+00, -.51175600E+00, 0.15249900E+00, 0.26355100E+01, -.29256300E+01, -.29979700E+01, 0.21624500E+01, 0.15433300E+01, 0.28174900E+01, -.38320000E+01, 0.15930000E+00, -.80195200E+00, 0.64669900E-01, 0.92348600E-01, -.33483400E-02, 0.28726500E+00, 0.26986300E+00, 0.17959000E+00, 0.71009600E-01, -.50556200E-01, 0.32487800E-01, 0.37481500E-02, -.31586700E-01, 0.52453400E-01, 0.45057200E+00, 0.17179400E-01, -.92058500E+01, 0.71252100E+01, 0.13345200E+01, 0.81685700E+00, 0.19837300E+01, -.32104200E+01, 0.14658100E+01, 0.85461800E+00, 0.17547000E+01, 0.10162800E+02, -.12692200E+01, -.14491400E+01, 0.11391700E+01, 0.20540100E+01, 0.24644900E+01, -.14597200E+01, 0.26841000E+01, 0.22404400E+01, -.22420200E+01, -.24538900E+01, 0.11800300E+01, 0.19844100E+01, 0.22204600E+01, -.24534200E+01, 0.71855400E-01, 0.26519100E+00, -.16681300E+00, 0.16906600E+00, 0.92631900E-01, -.35833100E-01, -.10783300E+00, 0.33320800E+00, 0.14099100E+01, -.34219200E+01, 0.25118200E+00, -.96444400E+00, 0.31640100E+00, 0.74170700E-02, -.16175000E+00, 0.14981000E+01, 0.66542300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10652000E+02, -.11562900E+02, 0.18399600E+00, -.33244700E+01, -.11605900E+01, 0.39919400E+00, -.45327300E+01, -.57676400E+01, -.37878600E+01, -.28774400E+00, 0.80404200E+00, -.12584900E+01, -.29878000E+01, -.33266800E+01, -.39542000E+01, -.22353600E+01, 0.66592500E+00, 0.23056800E+01, 0.56269300E+00, -.27565700E+00, -.44227200E+00, -.82661900E+00, -.17044100E+01, 0.26805900E+00, -.55125800E+00, -.10490700E+01, -.15133500E+00, -.37841300E+00, 0.10059200E+01, 0.13142100E+01, -.31909000E-01, 0.41865600E+00, -.81540500E+00, 0.49084200E+00, -.19016600E+00, 0.40280800E+00, -.45303100E+00, 0.31526100E-01, 0.59825500E+00, -.20640900E+00, -.59764900E-01, 0.33705900E+00, 0.11633200E+00, -.97812500E+00, -.26659600E+00, -.19607700E+00, -.10672600E+01, -.90315900E+00, -.92922000E+00, -.39209500E+00, -.66347800E+00, 0.32051400E+01, 0.12000500E+01, -.35256100E+01, -.69675500E+01, -.80841700E+00, 0.38705600E+02, -.55119300E+03, 0.22759000E+02, -.91687400E+01, -.30735100E+02, -.16104000E+02, -.11381300E+03, 0.27076600E+02, 0.32819200E+03, -.28949400E+03, 0.92859700E+02, 0.29740500E+02, -.32784200E+02, 0.53055100E+02, -.10026600E+03, 0.63090400E+02, 0.25906300E+02, -.23399500E+03, 0.71299200E+02, 0.13322500E+03, -.10852400E+03, -.61035900E+02, -.22186800E+03, 0.13919600E+03, -.11851700E+02, -.41113000E+03, -.14138600E+02, 0.32181900E+01, -.44119400E+02, -.25512800E+01, -.70533100E+00, 0.27532000E+02, 0.11091700E+02, 0.14209600E+02, -.43120200E+01, -.16263400E+02, 0.66484500E+01, -.56255300E+01, 0.93767100E+01, -.18764100E+02, 0.15669800E+02, -.65360800E+01, -.52406400E+01, -.81826500E+01, -.19349400E+00, 0.63844400E+01, -.18569600E+02, -.87153200E+01, -.36178500E+03, 0.26458400E+03, 0.13399900E+03, 0.86840900E+02, 0.68977800E+02, -.85535300E+02, -.43608500E+02, 0.89171200E+02, -.14375100E+03, -.23569000E+03, 0.13339600E+03, 0.11142000E+03, 0.55294300E+02, -.50104700E+02, 0.35222800E+02, 0.14813600E+03, 0.24703800E+03, 0.32805400E+03, 0.47260700E+01, -.10577900E+03, 0.44920300E+02, 0.11005300E+03, 0.12477500E+03, -.10632200E+03, 0.17566200E+02, 0.12883800E+02, 0.21105000E+02, -.13230500E+02, 0.14906100E+02, 0.77549800E+01, 0.43646500E+01, 0.84445600E+01, -.29142800E+01, 0.72527500E+02, 0.33700500E+02, 0.83508900E+01, -.99513400E+01, 0.55938600E+00, 0.32833000E+02, -.92962200E+02, 0.47857300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25052500E+01, -.58056900E+00, -.14618900E+01, -.71628600E+00, -.51101400E+00, -.10133500E+01, 0.90575100E+00, 0.59610200E+00, -.12446400E+01, 0.11471000E+00, -.31458000E-01, 0.28729800E+00, -.97924300E+00, -.12382000E+01, -.39583700E+00, -.49400100E+00, 0.10322700E+00, 0.34512100E+00, 0.72647000E-01, -.13640600E+00, -.15842000E+00, -.97169300E+00, 0.42763200E-01, -.24320600E+00, -.82319300E-01, -.34696700E+00, 0.80744100E-01, -.10776100E+00, 0.17678800E+00, 0.69817400E+00, -.63499000E+00, 0.35301400E+00, -.38249900E+00, 0.12835900E-01, -.59188400E+00, 0.70212600E-01, -.33986100E+00, -.24876500E+00, 0.22134000E+00, -.45918200E+00, 0.18026900E+00, 0.18169200E+00, -.12084700E+00, 0.64399200E+00, -.31147800E+00, 0.53181700E-01, 0.48320700E-01, -.14953900E+00, 0.87338400E-01, -.31734300E-02, -.57233000E+00, -.80468600E+00, -.44379800E+00, 0.21505000E+00, 0.77714300E-01, 0.53594000E-01, 0.38394700E+01, -.14003400E+00, 0.45974000E+02, 0.50972900E+02, -.57020800E+02, -.38624400E+02, -.59181700E+02, 0.63861200E+02, -.61326600E+02, 0.35682700E+02, 0.77898500E+02, 0.72507700E+02, -.54219100E+02, -.59943400E+02, -.60402700E+02, 0.81976800E+02, 0.25535900E+00, -.11977200E+02, 0.15390700E+02, 0.21680300E+02, -.12868400E+02, -.10738700E+02, -.24774800E+02, 0.22488200E+02, 0.16035600E+02, -.12449000E+02, 0.25339000E+02, 0.30971200E+02, -.37765800E+02, -.19398100E+02, -.37291500E+02, 0.39086600E+02, 0.21444600E+01, 0.39662700E+01, -.53736700E+01, -.57210700E+01, 0.32142200E+01, 0.30687400E+01, 0.81878200E+00, -.65499900E+01, 0.36589500E+00, 0.27120900E+00, -.89650300E+00, -.10703900E+01, 0.66253100E+00, 0.51634700E+00, -.39146300E+01, -.12984700E+01, 0.11189300E+03, -.68701500E+02, -.12274600E+02, -.30373800E+02, -.33097500E+01, 0.36860100E+02, 0.38081500E+00, -.27911200E+02, 0.76691600E+02, -.47516000E+02, 0.34030300E+02, 0.22297700E+02, -.41274200E+02, -.45633600E+01, -.60903100E+02, 0.28965900E+02, -.65504900E+01, 0.22115300E+02, 0.22015600E+02, 0.14351700E+02, -.11722000E+02, -.13671700E+02, -.80158800E+01, 0.15570500E+02, 0.49567400E+00, -.66763600E-02, 0.28295600E+01, -.36176000E+01, 0.44695200E+00, 0.74870900E+00, 0.13132600E+01, -.14877800E+01, -.67265400E+01, 0.30205600E+02, 0.12466000E+01, 0.13281000E+02, -.23251900E+01, 0.95828000E-01, 0.27547800E+01, -.27986700E+02, -.34972600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.25060000E+01, 0.50451800E+00, 0.12371300E+01, 0.52877300E+00, 0.55601000E+00, 0.45848100E+00, 0.29210500E-01, 0.59836200E+00, 0.41914500E+00, -.75222800E-01, -.14960800E-01, 0.31934200E+00, 0.37268600E+00, 0.20117400E-01, 0.32602300E+00, 0.94693200E+00, -.11597700E-01, 0.31094100E+00, 0.16809500E+00, -.33975800E-01, 0.47620200E-01, -.26497500E+00, -.16031000E+00, 0.35212000E-01, -.96536900E-02, 0.69441800E-03, 0.12031400E+00, -.34360100E-01, 0.60063600E+00, -.47486600E+00, -.10701000E+00, -.15369100E+00, 0.12316000E+00, -.10287200E+00, 0.21650700E+01, -.25476200E+00, 0.27633000E+00, 0.14825800E+00, -.41554400E+00, 0.82007000E+00, -.16766700E+00, -.78693500E-01, -.11562100E-01, -.24824400E+00, 0.10187400E+00, -.84708300E-01, -.15513100E+00, 0.52680100E-02, 0.75600500E-01, 0.83096500E-01, 0.16224400E+00, -.38577200E-01, 0.38575300E-01, -.50439000E-01, -.81376200E+00, -.27955700E+00, 0.36721300E+01, 0.16625800E+00, -.22192900E+00, -.13415300E+02, 0.33180800E+01, -.27499400E+01, 0.34995100E+02, -.21028800E+02, 0.87944000E+02, 0.34855200E+02, -.16714000E+02, -.20510100E+02, -.76046200E+00, 0.45966700E+02, 0.43873700E+02, -.19732400E+02, 0.89848000E+01, -.38170300E+01, -.54736400E+01, -.65328800E+01, 0.15593000E+01, 0.98240800E+00, -.88131800E-01, -.92348400E+01, -.14602500E+01, -.77390900E+01, 0.11510000E+02, 0.28795000E+01, -.11304500E+02, -.84928900E+01, -.26177000E+01, -.20977000E+01, 0.22596400E+01, -.90250300E+00, 0.20059700E+00, 0.67292200E+00, -.15298700E+01, 0.24475500E+01, -.59594500E+00, 0.96716900E+00, 0.38719700E+00, -.80348100E-01, 0.71712300E-01, -.10586500E+00, -.30929000E+00, 0.19214400E+00, 0.53880000E+00, -.79353600E-01, -.84050100E+02, 0.26576600E+02, 0.19801900E+02, 0.16914400E+02, 0.67406700E+01, -.37619200E+02, 0.25890100E+01, 0.14583800E+02, -.11731100E+03, 0.12251500E+03, 0.31405800E+02, 0.36986400E+02, -.60962100E+00, -.45305100E+02, -.14022100E+02, 0.35175800E+02, 0.74284400E+00, 0.90689900E+01, -.51576000E+01, -.34617500E+01, 0.29777600E+01, 0.49690900E+01, 0.81204400E+01, -.37767800E+01, 0.41952800E+00, 0.81112800E+00, -.11656800E+01, 0.13239600E+01, 0.39674400E+00, 0.16162700E-01, -.89480300E+00, 0.19999300E+01, 0.12952600E+01, -.93788100E+01, 0.68687600E+00, 0.97566200E+01, 0.65877500E+00, -.97240500E-01, -.17520300E+01, 0.79399800E+00, 0.21279600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.50983400E+01, 0.82649500E+01, -.94169700E-01, 0.21252300E+01, 0.65155300E+00, 0.23163400E+00, 0.29837000E+01, 0.37263500E+01, 0.85844300E+00, 0.22727800E+00, -.44181500E+00, 0.18737300E+01, 0.42727100E+01, 0.38062300E+01, 0.38798700E+01, 0.36187500E+01, -.50413800E+00, -.15948700E+01, 0.17250700E+01, -.50294400E+00, 0.58853300E+00, 0.26293600E+01, 0.13818700E+00, 0.88576500E+00, 0.22145300E+00, -.21051700E+00, -.30586500E+00, 0.30610300E+00, -.11316600E+01, -.18341200E+01, 0.23282300E+00, 0.12674000E+01, -.15500200E+00, -.40262500E+00, 0.31009600E+01, -.28663800E+00, 0.63222700E+00, 0.32469500E+00, -.33251300E+00, 0.25215400E+01, -.53842500E+00, -.54286300E+00, -.78239200E-01, 0.26094700E+00, -.19878200E+01, -.35340400E+00, -.14610800E+01, -.62726800E+00, 0.67479000E+00, 0.25608900E-02, -.10445200E+01, 0.13295100E+00, 0.85505600E+00, -.13227100E+01, -.18175100E+01, -.92915200E+00, -.19469400E+01, -.19356300E-01, -.27282900E+00, 0.10962400E+01, -.49309500E+02, -.66333500E+02, 0.98188000E+02, 0.13162100E+02, -.19511200E+03, 0.25252500E+03, 0.25487900E+02, 0.47330200E+02, -.58239900E+02, -.12115900E+03, 0.26521800E+02, 0.23970100E+02, 0.76278500E+02, -.11117700E+03, -.78608000E+02, -.38896800E+02, 0.48128000E+02, 0.50951700E+00, 0.91006900E+01, -.35982700E+02, 0.14926300E+03, -.18403500E+03, 0.28027100E+02, 0.49705500E+02, -.92480400E+02, 0.32751400E+02, 0.81982200E+02, 0.66325000E+02, 0.17285600E+02, 0.55131400E+02, 0.23858400E+02, 0.10682300E+02, -.35017500E+02, -.13929500E+02, -.68885700E+02, 0.69371800E+01, 0.16678000E+01, 0.19089500E+01, 0.14363100E+01, -.28416500E-01, -.64096700E-01, 0.70291700E+00, -.78477000E+01, 0.17204400E+00, 0.32905000E+03, -.19582600E+03, 0.57520400E+02, -.40774400E+02, -.18312800E+03, 0.30698800E+02, -.11608400E+03, -.55231300E+02, 0.76694100E+03, -.32535700E+03, -.55300800E+02, -.13223600E+03, -.18551100E+03, 0.21456500E+03, -.39903600E+02, -.15690100E+03, 0.31975900E+02, -.12337600E+02, -.60482100E+01, -.12530700E+02, -.57183500E+02, -.39733000E+02, -.31106300E+02, -.17117700E+02, 0.15902700E+01, 0.28230300E+01, 0.92432700E+01, -.13767300E+02, 0.61229500E+01, 0.46280000E+00, 0.55543200E+01, -.75334900E+01, 0.17020700E+02, -.67009600E+02, 0.25184200E+02, 0.85262400E+01, -.26050900E+02, 0.27638200E-01, 0.10897700E+01, -.81284700E+01, 0.52058200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.28985300E+01, 0.41559700E+01, -.32434400E+00, 0.10304700E+01, 0.18521400E+00, -.23114500E+00, 0.18609000E+01, 0.24258100E+01, -.71326000E+00, 0.37070400E+00, -.26597400E+00, 0.89804300E+00, 0.56592700E+00, 0.47391400E+00, -.48016400E+00, 0.21426800E+00, -.27178700E-01, 0.28628000E+00, -.66229500E+00, 0.63948700E+00, 0.46041200E+00, 0.33928000E+00, 0.67009500E+00, -.15055700E+00, 0.23824800E+00, -.26943100E-01, -.61182800E-01, 0.18745200E+00, -.59450300E+00, -.30851700E+00, -.11283100E+00, 0.50506900E+00, -.57794900E-02, -.22967700E+00, -.29451200E+01, 0.11095300E+00, -.21723800E+00, -.31756900E+00, 0.43584900E+00, 0.28945300E+00, -.33956100E-02, -.44258200E-01, -.27304900E+00, 0.23282400E-02, -.86727100E-01, 0.16895200E+00, 0.33655100E+00, -.29579100E+00, -.41572700E+00, -.16866400E-01, -.53810500E+00, -.15453600E+00, -.36220100E+00, -.36454800E+00, 0.49755800E+00, 0.27386800E+00, 0.49860700E+01, 0.14096200E+00, 0.82284400E+00, -.18161600E+00, 0.23038200E+00, 0.45403800E+02, -.21884400E+02, -.20479400E+02, 0.11117100E+03, -.58994300E+02, -.42894200E+02, -.41080900E+02, 0.10535100E+00, 0.79967200E+02, 0.96229200E+01, -.44980800E+02, -.28799200E+02, 0.96074100E+02, 0.18841700E+02, -.95657900E+01, 0.19370400E+01, 0.15941200E+02, 0.40482900E+02, -.10248500E+02, 0.45886500E+01, 0.17052700E+02, -.27042400E+02, -.46008900E+02, 0.43258300E+02, 0.27192600E+02, -.13749200E+02, -.57849900E+02, -.11940900E+02, -.47767400E+01, -.14407400E+01, 0.43492000E+01, 0.60773100E+01, 0.89717400E+00, 0.20933800E+02, 0.55640200E+01, -.32712300E+01, 0.36715100E+01, 0.89009000E+00, 0.20196700E+01, -.41019600E+00, -.25102500E+01, 0.55530400E+01, 0.20921300E+01, -.15590900E+03, 0.58215000E+02, -.48470200E+02, 0.58315100E+01, 0.79880200E+02, -.15047000E+02, 0.57578600E+02, 0.68975600E+01, -.29706000E+03, 0.17107900E+03, -.15014100E+02, 0.22507900E+02, 0.78339400E+02, -.64799600E+02, 0.27663200E+02, 0.22066700E+02, -.63373000E+02, -.65154600E+02, 0.14111900E+01, 0.27126300E+02, 0.97633700E+01, -.17808400E+01, -.14796300E+02, 0.23868400E+02, -.35875500E+01, -.51816100E+01, -.91182900E+01, 0.11007700E+02, -.51442600E+01, -.19749600E+01, -.37283700E+01, 0.25837200E+00, -.95192600E+01, 0.52645300E+01, -.18407200E+02, -.63825100E+01, 0.96222100E+01, -.58852700E+00, -.82572200E+01, 0.31560100E+02, -.13766000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.45602100E+01, 0.77548800E+00, 0.23746300E+01, 0.97775200E+00, 0.12319100E+01, 0.85823700E+00, -.52888500E+00, 0.46301900E+00, 0.51868300E+01, -.71976400E+00, 0.24883400E-01, -.12943400E+01, 0.93490300E+00, 0.71851000E+00, 0.14728700E+01, 0.57546300E+00, -.14041200E+00, -.21853500E+01, -.43723200E+00, -.64696400E-02, 0.50555100E+00, -.96494300E+00, 0.11657500E+01, -.28396700E+00, 0.38739700E+00, 0.10617400E+01, 0.38433500E+00, 0.45012800E+00, 0.29680800E+00, -.32044900E+01, 0.16625200E+01, 0.27538900E+01, 0.77997300E+00, 0.56083100E+00, 0.51478000E+01, 0.19377200E+00, -.94498200E+00, -.12649800E+00, -.17843000E+00, 0.10174100E+01, -.24762100E+00, 0.39653100E+00, 0.40889600E+00, -.55124000E+00, 0.48119500E+00, -.12311400E+00, 0.76452100E+00, -.54510900E-01, 0.27823100E+00, 0.20265700E+00, 0.12442800E+00, -.49237600E-01, 0.29318800E-01, -.11724800E+00, -.24474500E+00, 0.48131200E-01, -.22092700E+01, -.18342500E-01, -.64801900E+00, 0.32525000E+00, 0.14309800E+00, -.34241600E+00, -.68276800E+02, -.49189800E+01, 0.14312300E+03, -.73599000E+02, -.19965200E+02, -.30318600E+02, -.10466800E+02, 0.55470700E+02, -.43310000E+02, -.23904400E+02, -.26506100E+02, 0.40017400E+02, 0.40785800E+02, 0.27557800E+02, -.25274400E+02, -.12846100E+02, -.27578500E+02, 0.27952800E+02, -.48492000E+02, 0.63368300E+02, -.91688200E+00, -.36218900E+01, 0.18538900E+02, -.25401800E+02, -.61494200E+02, -.95099200E+01, -.76345800E+01, -.14197800E+02, -.13818500E+02, -.78347100E+01, 0.16529500E+02, 0.90565600E+01, 0.29039100E+02, -.66910800E+01, -.15006600E+01, 0.12370700E+01, -.27291900E+00, 0.24043300E+00, 0.59350400E+00, -.26769900E+00, 0.19016000E+01, 0.25163600E+00, -.91522000E+02, 0.38557700E+02, -.38103400E+02, -.20572000E+02, 0.77206300E+02, -.17508000E+01, 0.58941900E+02, -.16934300E+02, -.37829200E+02, 0.48674400E+02, -.39250100E+02, -.22516700E+02, 0.50200800E+02, 0.75702800E+01, 0.16319300E+02, -.16071500E+02, -.14605200E+01, -.25924400E+01, 0.62764900E+01, 0.38522000E+01, 0.53618300E+01, 0.12037300E+02, 0.61725400E+01, 0.38804300E+01, -.17159700E+01, -.71387100E+00, -.13854000E+01, 0.18437400E+01, -.25546600E+01, -.85419700E+00, -.12711500E+01, 0.18566700E+01, -.84617700E+01, 0.16972600E+02, -.10818400E+02, 0.65101600E+01, 0.10184300E+02, 0.84357500E-01, -.93821900E+00, 0.14223800E+02, -.27352000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.81435200E+01, -.12958500E+02, 0.12485400E+01, -.31062900E+01, -.97102400E+00, 0.58482100E+00, -.71810100E+01, -.87044200E+01, -.32720300E+01, -.50033500E-01, 0.86342000E+00, -.52868200E+00, -.32448400E+01, -.34177600E+01, -.36151500E+01, -.24382500E+01, 0.17973200E+00, -.40184600E+01, 0.74849300E+00, -.45071200E+00, 0.39322200E+00, -.10103100E+01, 0.27061600E+01, -.70789800E+00, 0.34169600E+00, 0.73341300E+00, 0.29410600E+00, 0.15628800E+00, -.35530700E+00, 0.32280700E-01, 0.12526100E+00, -.74225600E+00, 0.37982700E+00, -.33891900E+00, 0.77626600E+01, -.74468800E+00, 0.11743400E+01, 0.18401300E-01, 0.44816600E+00, -.15494500E+01, -.28844200E+00, -.51513300E+00, 0.45727200E+00, -.44328300E+00, -.86396500E+00, -.25239200E+00, -.10663700E+01, 0.13425300E+01, 0.11899800E+01, 0.83630000E-02, 0.91077600E+00, -.13119300E+00, 0.13620700E+01, -.27488100E+01, 0.30338200E+01, -.31942500E+00, -.23134400E+01, 0.13077800E+00, 0.10693100E+01, 0.21038300E+01, -.41457400E+00, -.17436500E+01, -.18187100E+01, -.52629100E+02, -.50761200E+03, -.10929200E+03, -.12898000E+03, -.89647800E+02, 0.63596600E+02, -.13547100E+03, 0.50161800E+01, -.17238200E+03, -.51008600E+02, 0.16610700E+03, -.82264100E+02, -.10860500E+03, 0.12067200E+03, 0.36895400E+02, 0.18235800E+03, -.10606300E+03, 0.22340700E+03, 0.24482500E+02, -.37645600E+02, -.68401100E+02, 0.57393900E+02, 0.11359400E+03, 0.48967000E+02, -.91299600E+02, -.10283600E+02, 0.43281100E+02, 0.27289200E+02, 0.36435400E+02, -.28302200E+02, -.95789600E+01, -.37457900E+02, 0.40281900E+02, -.17162300E+02, 0.15874000E+02, 0.81873600E+01, 0.11134300E+02, -.13740900E+01, -.75655000E+01, 0.95653700E+01, 0.12442200E+02, 0.89813800E+02, -.26345600E+03, -.53772500E+02, -.36612500E+02, -.90156100E+02, -.30992300E+02, -.79019500E+00, -.56963000E+02, 0.12513300E+03, 0.47572400E+02, -.21197700E+03, -.20849500E+03, -.11894800E+02, 0.70193100E+02, 0.67368300E+02, -.28193900E+03, -.14856100E+03, -.43884700E+03, -.37534900E+02, 0.39293700E+02, -.41493400E+02, -.73298200E+02, -.11796200E+03, 0.22681200E+02, -.19640700E+02, -.14031100E+02, -.17896400E+02, 0.11074900E+02, -.13389400E+02, -.99862000E+01, -.51487100E+01, -.61705000E+01, -.20076600E+02, -.10632000E+03, -.21072700E+02, -.14991700E+02, 0.12416700E+01, -.15075700E+01, -.35444500E+02, 0.15367800E+03, -.41667500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23903100E+01, -.53618200E+00, -.12985900E+01, -.50502500E+00, -.35698800E+00, -.66859300E+00, 0.14403300E+01, 0.17811400E+01, -.99104900E+00, -.50870500E-01, -.47142400E-01, 0.81370400E+00, -.89413000E+00, -.96549500E+00, -.90710200E-01, 0.13160800E+00, 0.40416100E-01, -.62902000E+00, 0.63312800E+00, -.58994800E+00, -.20177200E+00, -.89469400E+00, -.16325800E+00, -.14301100E+00, -.27018400E+00, 0.19389900E+00, 0.11298500E+00, 0.13860200E+00, 0.52120100E+00, 0.28008100E+00, -.91484900E-01, -.55295300E+00, -.23822500E+00, 0.83489300E-01, 0.23285000E+01, -.12703900E+00, 0.71817300E-02, 0.18973100E+00, -.14089400E+00, -.28536000E+00, 0.70987400E-01, 0.15861900E+00, 0.20061800E+00, 0.11775200E+00, -.28529700E+00, -.47638000E-01, -.52086700E+00, -.88312700E-01, 0.27159400E+00, 0.16555200E-01, -.27815200E+00, -.37868700E+00, -.21980200E+00, -.10476500E+00, -.20834700E+00, 0.36716600E-01, -.25132300E+01, -.95408800E-01, 0.32514900E+00, 0.32518700E+00, 0.22676400E-01, 0.45364300E-01, 0.15601300E+00, -.70090500E-01, -.10899400E+03, 0.76869500E+01, 0.52627100E+01, 0.27882000E+01, 0.12606100E+02, -.42276200E+02, -.19673100E+01, -.71998100E+01, -.34103800E+01, -.13988300E+02, -.19484300E+02, -.12984000E+02, 0.17251500E+02, 0.48520100E+01, 0.17740500E+02, -.12893400E+02, 0.28606900E+02, -.12741300E+02, -.55302700E+01, -.43756900E+01, -.13130700E+01, 0.15337200E+02, 0.16491600E+02, -.29120800E+01, -.14962600E+00, 0.80309200E+01, 0.58275600E+01, 0.44471400E+01, -.44021600E+01, -.44878800E+01, -.86495500E+01, 0.47382300E+01, -.46489100E+00, 0.58707100E+00, 0.64858600E+00, 0.72450400E+00, -.24215900E+00, -.38294400E+00, 0.21078400E+00, 0.88886900E+00, 0.60239800E+02, 0.44094900E+01, 0.11525800E+02, 0.61666100E+01, -.39444200E+02, 0.72995900E+01, -.32132000E+02, 0.42396000E+01, -.25998800E+01, -.14480100E+02, 0.20961700E+01, -.85638900E+01, -.99158700E+01, -.24552400E+01, 0.12545400E+02, -.14894900E+02, 0.13570000E+02, -.22510700E+02, -.11368300E+02, -.13157100E+02, 0.16892300E+01, 0.40279000E+01, 0.30113000E+01, -.15487300E+02, -.57706900E+00, -.67963100E+00, 0.50351900E+00, -.57925900E+00, -.16954400E+00, -.36918900E+00, 0.35069500E+00, -.48920800E+00, 0.94537200E+00, -.13386500E+02, 0.42933800E+01, -.46921100E+01, -.25041700E+01, -.91767400E-01, 0.11534500E+01, 0.61573100E+01, 0.10389900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.70099500E+01, 0.45105800E+00, 0.10532500E+01, 0.77736400E+00, 0.88926100E+00, 0.31575400E-01, -.36020100E+01, -.46268800E+01, 0.77068300E-01, 0.25830600E+00, 0.35574100E-01, -.14333600E+01, 0.40141700E+01, 0.21091900E+01, 0.47053900E+01, -.89247100E+00, -.26333200E+00, 0.57047600E+00, 0.29752100E+00, 0.20572700E+00, -.72936600E+00, 0.14052300E+01, -.13838300E+01, 0.47402900E+00, -.60320500E+00, 0.20418600E+01, 0.12782100E+00, -.44821700E+00, 0.52529200E+00, -.47534400E+00, -.30387200E+00, -.30492400E+01, 0.12039500E+01, -.18795900E+00, 0.21336300E+01, -.12774600E+00, 0.92652800E+00, 0.24990900E+00, -.21926400E-01, 0.23247700E+00, -.48596900E-01, -.33019300E+00, 0.14992800E-01, 0.48616000E+00, -.82966900E-01, 0.36309400E-01, -.11484700E+01, -.56892400E+00, -.82858400E+00, -.81982500E-01, -.91405100E-02, -.45862800E+00, -.11825100E+00, 0.73021800E+00, 0.14894300E+01, 0.21434200E+00, -.97448000E+00, -.86071500E-01, 0.92881100E+00, 0.59635200E-01, -.40074100E+00, -.97686300E-01, -.57319900E+00, 0.17439600E+00, 0.41678300E+00, 0.12391000E+03, 0.12441600E+02, 0.18922300E+02, 0.82853700E+01, -.77544700E+01, -.50464000E+01, 0.20051700E+02, 0.12957100E+02, -.94571600E+01, 0.80056800E+01, 0.10056400E+02, -.17284700E+02, -.55677700E+01, -.22095500E+02, 0.96054900E+01, 0.28687600E+02, -.46334200E+02, -.78466300E+01, -.64094500E+01, -.98710100E+01, 0.14619400E+02, 0.91377400E+01, -.61520600E+01, 0.22875100E+01, -.32665700E+01, -.61041500E+00, -.32633900E+01, -.39715400E+00, -.75284200E+00, -.79221500E+00, -.40479600E+01, 0.19220100E+01, -.11278400E+01, -.62829400E+00, -.11872300E+01, 0.15265700E+00, 0.81669900E+00, -.41084500E+00, -.12679700E+01, 0.55423700E+01, 0.27513100E+02, -.68626900E+01, -.12052100E+02, 0.16029100E+02, 0.97990500E+01, 0.13555600E+01, -.10570700E+02, 0.13389000E+03, -.32858300E+02, -.65937600E+01, -.93950100E+01, -.13375700E+02, 0.44619200E+02, 0.16127300E+01, -.28832100E+01, 0.31799700E+02, 0.53300000E+02, 0.16712600E+01, -.65436100E+01, -.86562000E+00, 0.72853700E+01, 0.13656700E+02, -.67947900E+01, 0.21976800E+01, 0.21272900E+01, 0.19311100E+01, -.10159000E+01, 0.20042600E+01, 0.84160300E+00, 0.56240600E+00, -.74295200E-01, 0.15697100E+01, 0.53888800E+01, 0.15584800E+01, -.62198400E+00, -.16973900E+01, 0.17717500E+00, 0.40168000E+01, -.13986500E+02, 0.49284600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49166000E+01, 0.10108500E+01, 0.22755500E+01, 0.11116300E+01, 0.75085000E+00, 0.12537200E+01, -.21598100E+01, -.12627300E+01, 0.12511000E+01, -.10157500E+00, 0.77446800E-01, 0.10819900E+01, 0.22229600E+01, 0.11055000E+01, 0.74689300E+00, 0.33450700E+01, -.20073700E+00, 0.10624600E+00, 0.22089400E+00, 0.39699900E+00, 0.89623000E+00, 0.99136100E+00, -.75170200E+00, 0.34716900E+00, -.16885300E+00, -.29073400E+00, -.24424000E+00, -.20472700E+00, -.16360600E+00, -.37584900E+00, -.16441200E+00, -.54655300E+00, 0.27191000E+00, -.25533300E+00, -.14066200E+01, 0.17205500E+00, 0.39430900E+00, 0.85413200E-01, 0.48234200E+00, 0.17233500E+00, -.17611700E+00, -.34517100E+00, -.85506400E-01, -.22884800E+00, -.59264600E+00, -.87040400E-01, -.10863900E+01, -.41280400E+00, -.35101800E-01, 0.66986600E-01, -.46577600E-01, 0.71894400E+00, 0.46013700E+00, 0.15492700E+00, -.90793300E+00, 0.81061000E-01, -.37930300E+01, -.20938500E-01, 0.39384200E+00, -.85476900E+00, 0.17615400E+00, 0.88763000E-01, -.63633800E+00, 0.23323400E+00, -.86950000E+00, 0.28727600E+00, 0.28032100E+02, 0.13669300E+02, 0.88830000E+01, 0.14609200E+02, 0.33989700E+02, 0.22026500E+02, 0.68633500E+01, -.15797900E+02, 0.29283800E+02, 0.30252400E+02, -.36920100E+02, -.12127700E+02, -.48922700E+02, 0.24700500E+02, -.43698400E+02, 0.64916800E+02, 0.71979300E+01, 0.15282000E+02, -.18404700E+02, -.31306000E+02, -.50355200E+02, 0.91706800E+01, -.16098000E+01, -.26090800E+02, -.12875200E+02, -.11779400E+02, 0.16794000E+02, 0.10692900E+02, 0.26439500E+02, -.10656900E+02, 0.11063500E+01, -.19278500E+01, -.94397100E+00, -.14777500E+01, 0.86709500E+00, 0.12607700E+01, 0.35071200E+01, -.14354200E+01, -.20618700E+02, 0.76366200E+02, -.22874600E+02, -.22859900E+02, 0.53071100E+02, 0.15494900E+02, 0.39097800E+02, -.18068400E+02, -.18415100E+03, 0.12589200E+03, 0.42950700E+02, 0.49536400E+02, 0.30298200E+02, -.60264700E+02, -.20555500E+02, 0.57470200E+02, 0.12633700E+02, 0.49957300E+02, 0.85195400E+01, -.74470600E+01, 0.10930100E+02, 0.12217200E+02, 0.34867600E+02, -.67996200E+01, 0.11161300E+01, 0.39431000E+01, -.10324800E+01, 0.52681300E+00, 0.50282200E+00, 0.34096700E+00, -.20237600E+00, 0.22470000E+01, 0.39717900E+00, 0.10951900E+02, -.10763000E+01, 0.10499800E+02, 0.86235200E+01, 0.47177100E+00, 0.21213000E+01, -.85657900E+01, 0.68886300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.47890800E+01, -.65880100E+00, -.24502100E+01, -.92394300E+00, -.10510800E+01, -.96740000E+00, 0.14418400E+01, 0.40707800E+00, -.26011700E+01, 0.27610400E+00, -.33285700E-01, 0.13330500E+01, -.34593600E+00, 0.69542400E-01, 0.22674900E+01, 0.74051300E+00, -.59346100E-01, 0.33172800E+00, 0.83076700E+00, -.10458500E+01, -.74197600E+00, -.64866800E+00, -.69504600E+00, -.97694700E-02, -.25879800E+00, 0.35860500E+00, 0.41438600E-01, -.25180900E+00, 0.36827600E+00, 0.20415800E+01, -.18660300E+00, -.41540400E+00, -.92553900E+00, 0.69959000E+00, -.23227100E+01, 0.60997500E+00, -.23387100E+00, 0.11255900E+01, -.61689600E+00, 0.25956800E+00, -.36236600E-01, 0.29011900E+00, 0.19310200E+00, 0.73592100E-01, 0.25468500E+00, -.33097100E-01, 0.33029100E-01, 0.42178500E+00, 0.15047800E+00, 0.11011500E+00, -.14505500E+00, 0.54758000E-01, 0.23051800E+00, -.23770100E+00, -.77792800E+00, -.13514700E+00, -.10492100E+02, -.81613800E-01, -.91960400E+00, 0.55407400E+00, 0.38183000E+00, -.21872100E+00, 0.96146500E+00, 0.14408600E+00, -.15058000E+01, -.37050800E+00, 0.46104300E+00, -.26136900E+02, 0.43571000E+02, 0.48340500E+01, 0.52961400E+02, -.30529500E+02, -.38854300E+01, -.62589700E+02, -.16817600E+02, 0.47277100E+01, 0.10923800E+01, -.34546000E+01, -.54511300E+01, 0.31234600E+01, 0.15576000E+02, -.40537600E+02, 0.12873500E+01, 0.61738300E+01, -.18874000E+02, 0.44751200E+01, 0.17065800E+02, 0.10745400E+02, 0.30245800E+01, 0.49531800E+01, 0.50168000E+01, 0.14443800E+01, -.36191800E+01, -.65859400E+01, -.10740500E+02, 0.15806100E+01, 0.32417100E+01, -.20768300E+01, -.84194800E+00, -.12259600E+01, -.44503700E+00, 0.10918500E+01, -.97366000E+00, -.12347100E+01, 0.97523700E+02, 0.79246800E+02, 0.35756200E+02, 0.33162300E+02, -.49956900E+02, 0.19042600E+02, -.67244000E+02, 0.39204400E+02, -.10305400E+03, 0.14929400E+01, 0.73017700E+02, 0.52837200E+02, -.10382800E+02, -.47254700E+02, 0.20359700E+02, 0.59299600E+02, 0.61564100E+02, 0.54285800E+02, -.21545500E+02, -.42825400E+02, 0.26892800E+02, 0.30588900E+02, 0.41729000E+02, -.44869700E+02, 0.38518300E+01, 0.12436400E+01, 0.41860400E+01, -.21076000E+01, 0.25339300E+01, 0.16577100E+01, 0.67876800E+00, 0.27935600E+01, 0.44507300E+01, -.10068900E+02, 0.13933800E+02, -.17338400E+01, -.54776700E+01, 0.52956700E-01, 0.12406700E+02, -.28282000E+02, 0.13181500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15972500E+01, 0.26038300E+00, 0.97257500E+00, 0.47335200E+00, 0.41162400E+00, 0.61904000E+00, 0.25376600E-01, 0.58968700E+00, 0.44939200E+00, -.11190400E+00, -.18682900E-01, 0.56123600E+00, 0.39212200E+00, 0.20852900E+00, 0.47606400E+00, 0.74498400E+00, -.33500100E-01, -.30515500E+00, 0.21099300E+00, -.15169200E+00, 0.67648400E-01, 0.22923200E+00, -.11804900E+00, 0.93982500E-01, -.14252300E-01, 0.33244100E+00, -.29596100E-01, 0.29570400E-01, 0.57806200E-01, 0.36082300E+00, 0.63010500E-01, 0.13442100E+00, -.12950300E+00, 0.15424700E+00, -.38132700E+01, 0.16351600E+00, -.74402300E-02, -.92191400E-01, -.15182300E-01, 0.22800000E+00, -.38969300E-01, -.20632600E+00, -.49605500E-01, -.15666100E+00, -.34096200E-01, 0.55073800E-01, 0.18859400E+00, 0.21113900E-01, 0.14577000E-01, 0.36972200E-01, -.50965900E-02, -.16554200E+00, -.74360900E-01, 0.10108000E+00, 0.52373800E+00, -.16187900E-01, -.11109100E+01, -.42444200E-01, 0.24600700E+00, -.98766100E-01, 0.57971200E-01, 0.11294900E+00, 0.15540300E+00, 0.40807700E-01, -.80370100E-02, -.12017000E+00, 0.18626800E-01, -.64775400E-01, 0.76076000E+01, 0.25657600E+00, 0.95727000E+01, -.42912300E+00, 0.16717700E+01, -.52277500E+01, -.11545900E+00, 0.17698600E+01, -.29961900E+00, 0.42576600E+00, 0.15123800E+01, 0.29461200E+01, 0.88344900E+01, -.15625600E+02, -.56383800E+00, -.19917000E+01, -.39241100E+01, 0.25266500E+01, 0.41565200E+01, -.13816100E+01, -.48314700E+00, 0.27240300E+01, 0.15899300E+01, 0.90343000E+00, -.16238500E+01, -.25423000E+01, -.35394300E+01, 0.87896500E+00, 0.50979400E+00, -.11173300E+01, -.31401400E+00, -.33594500E+00, -.78361100E-01, 0.60238400E-01, -.32269100E+00, -.28209600E+00, 0.30279500E+02, 0.56084600E+00, 0.66359700E+01, 0.89662000E+01, -.16686700E+02, 0.53298700E+01, -.19400000E+02, 0.98405400E+01, 0.18058300E+02, -.33303000E+02, 0.85603500E+01, 0.63635500E+01, -.70518700E+01, 0.44117400E+01, 0.40696900E+01, 0.81615100E+01, 0.11181700E+02, 0.11871900E+02, -.15955900E+01, -.34840300E+01, 0.20219900E+01, 0.37436700E+01, 0.33347500E+01, -.34243700E+01, 0.61888600E+00, -.32121600E+00, 0.42771600E+00, -.32504600E-01, 0.34118700E+00, 0.57850500E+00, 0.28215100E+00, -.15672700E+00, 0.73804900E+00, 0.50268300E+00, 0.11912600E+01, 0.53213700E+00, -.17313300E+01, 0.25142800E-01, 0.20112300E+01, -.79485000E+01, 0.16216700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12739800E+02, 0.76810500E+00, 0.47087300E+01, 0.23153300E+01, 0.22572300E+01, -.72904500E-01, 0.58772500E+01, 0.98104600E+01, -.76115900E+00, -.44910000E+00, -.33332200E+00, 0.29560400E+01, 0.40153900E+01, 0.23338200E+00, 0.31026000E+01, 0.22552100E+01, 0.38696600E+00, 0.35022100E+01, 0.62308100E+00, 0.11622300E+00, 0.48060800E+00, -.33925900E+01, -.25187500E+01, -.76992400E-02, -.41051700E+00, 0.57767600E+00, 0.40266400E-01, -.41149500E-01, 0.14272100E+01, 0.77502800E+00, 0.12166800E-01, 0.34559000E+01, -.11125200E+01, 0.79258100E+00, -.71698700E+01, 0.52675500E+00, -.31065900E+00, -.77694300E+00, 0.85158600E+00, 0.11319400E+01, -.41147200E+00, -.10864900E+01, -.24287600E+00, 0.58142000E+00, -.12482100E+01, -.82624200E-01, 0.18324600E+00, -.59770000E+00, 0.50761800E+00, -.28869600E+00, 0.10359100E+01, -.10780500E+01, -.30932400E+00, -.24358500E+01, 0.34848400E-02, 0.24198800E+00, 0.24861200E+02, 0.33364900E+00, 0.42536000E+00, -.20343400E+01, -.60154300E+00, -.57419300E+00, -.83419700E-01, 0.11302200E+00, 0.22058200E+01, 0.19743500E+01, -.11939800E+01, -.12442000E+01, 0.13238200E+01, 0.33996800E+02, 0.20760700E+02, 0.26577500E+02, 0.11071900E+02, -.40939500E+01, -.95893000E+01, -.12457300E+02, 0.48281100E+01, 0.30760500E+01, -.34234800E+01, -.21609200E+02, 0.81374500E+01, 0.64153600E+02, 0.41673600E+00, -.12687300E+02, 0.77512500E+01, -.10286000E+02, -.55679000E+02, -.19050100E+02, -.56071100E+01, 0.98894100E+01, -.37425900E+01, 0.24753800E+01, 0.42529200E+01, 0.99707600E+01, 0.16749100E+02, 0.31331400E+01, -.27366600E+00, -.11930600E+00, 0.70134300E+00, 0.24187100E+00, -.96451000E+00, -.50099800E+00, -.16340500E+01, -.33761000E+00, -.22199300E+03, 0.42725000E+02, 0.49243400E+02, 0.59994700E+02, 0.29567700E+02, -.94702300E+02, 0.68450800E+00, 0.66541600E+02, -.49150000E+03, 0.42604600E+03, 0.66308000E+02, 0.82822600E+02, 0.83783400E+02, -.16510200E+03, -.34683300E+02, 0.90113600E+02, -.13968000E+03, 0.11178300E+02, 0.21270700E+02, 0.45248100E+02, 0.15419900E+02, -.41912300E+02, -.31271000E+02, 0.54766400E+02, -.10218500E+00, 0.56702200E+00, -.73320300E+01, 0.42425800E+01, -.60392800E-01, 0.99982700E-02, -.18135400E+01, 0.33377100E+01, -.21395300E+01, 0.16881100E+02, 0.56919100E+00, 0.58078900E+01, 0.68033900E+01, -.49113700E+00, -.42611700E+01, 0.11919000E+02, -.58171900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.57620200E+01, -.79150400E-01, 0.88078400E+00, 0.76036700E+00, 0.14532000E+01, -.18035000E+00, -.80709100E+00, -.14319600E+01, -.40678400E+00, 0.33748800E+00, -.14418200E-01, -.82062100E+00, 0.67071100E+00, 0.59530600E+00, -.93409400E+00, -.19566000E+01, 0.20572400E+00, 0.21137500E+01, -.18403800E+01, 0.12424800E+01, 0.27498700E+00, -.18359200E+01, 0.56660000E-02, -.25839200E+00, 0.17906800E+00, -.60023200E+00, 0.82084100E-01, -.36157500E+00, 0.36491000E+00, -.51366900E+00, -.14916800E+01, -.77908900E+00, 0.53751600E+00, 0.18654600E+00, -.57363900E+01, 0.66016600E+00, -.42419000E+00, -.38473500E+00, 0.11686000E+01, 0.27137300E+00, -.31733100E-01, -.98341200E-01, 0.24182300E-01, 0.28542800E+00, 0.10537600E+00, 0.11625600E+00, 0.10012900E+00, -.17473800E+00, -.30234800E+00, -.91536900E-01, -.29045500E+00, -.23823100E+00, -.33053000E+00, 0.29126000E+00, 0.52582800E-01, 0.23966000E+00, 0.71198600E+00, -.67087100E-01, 0.21962400E+00, 0.46750900E+00, -.13754400E+00, 0.58213000E-01, 0.10239200E+00, -.21125800E+00, 0.38524100E+00, 0.15470800E+00, -.25800000E-01, -.22119600E+00, -.21416200E+01, 0.65040700E-02, 0.32767200E+02, -.45645000E+01, 0.15719400E+01, -.13526500E+02, -.16965600E+02, -.72472000E+01, 0.15939200E+02, 0.61733500E+01, 0.26702700E+02, -.40744700E+01, 0.58392800E+02, -.55100300E+02, -.87063400E+01, -.76345200E+01, -.10278300E+02, 0.24228000E+02, 0.18833200E+02, -.33915400E+01, -.48334400E-01, 0.17234500E+02, 0.83549100E+01, 0.59492700E+01, -.91783100E+01, -.95507900E+01, -.15107400E+02, 0.58141500E+01, 0.91475500E+00, -.12477900E+01, -.31745500E+00, -.30574200E+00, -.62767200E+00, -.28066000E+00, -.47722800E+00, -.16826800E+00, 0.11445300E+03, -.34507100E+02, 0.18387200E+02, 0.13880900E+02, -.56517400E+02, 0.20982200E+02, -.62859200E+02, 0.13682600E+02, 0.35178100E+02, -.72769000E+02, 0.27352600E+02, 0.22358800E+02, -.28559500E+02, -.16012500E+00, 0.14977100E+01, 0.24705700E+02, 0.24859900E+02, 0.36096100E+01, -.44267400E+01, -.42754700E+01, -.49027000E+01, 0.35570100E+00, -.78967300E+01, -.50164700E+01, 0.11738100E+01, -.17033800E+01, 0.27446700E+00, 0.99308400E+00, 0.50932200E+00, 0.10712500E+01, 0.26070200E+00, -.89291500E+00, 0.18340400E+01, -.62177100E+01, 0.51652500E+01, -.51159200E+01, -.62427200E+01, -.22286100E+00, 0.35549400E+01, -.19260600E+02, 0.19462300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.30105800E+01, -.11710400E+01, 0.70455300E-01, -.50288200E+00, -.15715300E+00, 0.59161700E+00, -.20047700E+01, -.11616400E+01, 0.75388600E+00, -.35587200E+00, 0.18418800E+00, -.15421000E-02, -.88071300E+00, -.96548200E+00, -.55678700E+00, 0.39762800E+00, -.74220200E-01, -.18755500E+01, 0.82329800E+00, -.57149100E+00, 0.39272600E-01, 0.80625700E-01, 0.86395900E-01, -.39431000E-01, -.32218800E+00, 0.26336700E+00, -.36901200E-01, 0.19658000E+00, 0.13356900E+00, 0.54512700E+00, 0.26074200E+00, -.43876700E+00, -.55026600E-01, 0.22640300E-01, 0.52100100E+01, -.65919400E+00, 0.18502100E+00, 0.67554100E-01, -.15172100E+00, -.30135800E+00, 0.22326500E-01, -.27998200E-02, -.68070300E-01, -.42285200E+00, 0.28046500E+00, -.88798400E-01, -.14711400E+00, -.20920900E-01, -.21168400E+00, -.11735800E-01, 0.99171200E-02, 0.45560400E+00, 0.41072400E-01, -.24542000E+00, -.63376100E+00, 0.10959000E-01, -.59619300E+00, 0.10310300E+00, -.21439400E+00, 0.12780400E+00, -.97500700E-02, 0.23175000E+00, -.17101300E+00, -.70091900E-01, -.57313200E+00, 0.14808700E+00, 0.19873800E+00, 0.14516800E+00, -.11251800E+00, 0.77525300E-02, -.26932400E+00, -.29643800E+01, -.60985800E+01, -.16088500E+02, -.10636900E+02, -.27632900E+01, 0.10715300E+02, 0.67666900E+00, 0.10069200E+02, -.17395700E+01, 0.13833600E+02, -.21775500E+02, -.31991400E+01, -.38531700E+00, -.21426500E+01, 0.63620700E+01, 0.10480800E+02, 0.56803600E+00, 0.76376900E+00, 0.75287100E+01, 0.37292800E+01, 0.29643700E+01, -.48151700E+01, -.39396100E+01, -.72226400E+01, 0.31016400E+01, 0.27929400E+00, 0.10908400E+00, -.69869300E-02, 0.17796100E-01, -.33276200E+00, -.24235200E+00, 0.10284100E+01, 0.12042800E+00, -.71519600E+00, -.17338100E+02, 0.17506600E+02, 0.88881500E+01, -.18778000E+02, -.54512800E+01, -.14120200E+02, 0.62122200E+01, -.43169100E+01, -.19389400E+02, 0.70118100E+01, 0.43786700E+01, -.39695100E+01, 0.40062400E+00, 0.91219500E+01, 0.16223700E+01, 0.17623600E+02, -.11709100E+02, -.69072500E+01, -.74700600E+01, -.96543900E+00, 0.84812700E+01, -.37626200E+00, -.94749300E+01, 0.34417500E+00, -.10378800E+01, 0.34492800E-01, 0.21362000E+00, -.13350200E+00, 0.19817700E+00, -.32349100E+00, 0.77295100E-01, 0.76718000E+00, -.26851400E+01, 0.40454200E+01, -.21207500E+01, -.25202900E+01, -.15619100E+00, -.10637600E+01, -.36521800E+00, 0.59527900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.40027300E+01, 0.80711600E+00, 0.19496600E+01, 0.77001300E+00, 0.57267500E+00, 0.90110300E+00, -.21600900E+01, -.17296800E+01, 0.83188900E+00, 0.16560400E-01, 0.66930900E-01, -.14094700E+00, 0.14016200E+01, 0.86135100E+00, -.87843300E-01, 0.80418500E+00, -.17408500E+00, 0.49570100E+00, -.37280700E+00, 0.82301600E+00, 0.52211700E+00, 0.13129200E+01, -.11110600E+00, 0.23027800E+00, 0.59747300E-01, -.42579800E+00, -.22735000E+00, -.25593900E+00, -.41110700E+00, -.87618100E+00, 0.30201600E+00, 0.40524900E+00, 0.43103100E+00, -.15923700E+00, 0.13337900E+01, 0.69465100E-01, -.34825800E+00, -.21870000E+00, 0.10235000E+01, -.27844300E+00, 0.52723000E-01, 0.73435900E-01, -.23385400E+00, -.96951000E-01, -.34024500E+00, -.87177000E-01, -.31481500E+00, -.48929500E+00, 0.73994200E-03, 0.79560800E-01, -.18706500E+00, 0.34398900E+00, 0.25346400E+00, 0.16705400E+00, 0.22671600E-01, 0.39430100E-01, -.50424000E+01, -.61564800E-01, 0.27754800E+00, -.45659500E+00, -.57598300E-02, 0.42744500E-01, -.63702200E+00, 0.86629700E-01, 0.18875900E+00, 0.68374300E-01, 0.32965700E+00, 0.24540400E+00, -.11836000E+01, 0.20068400E+00, 0.15355500E+00, 0.84354900E+00, 0.15625500E+02, 0.41602200E+02, 0.32175800E+02, 0.16641300E+02, -.28590000E+02, -.47401900E+01, -.26094400E+02, 0.17919900E+02, -.18646800E+02, 0.30484200E+02, 0.15338400E+01, 0.32784800E+01, -.15414200E+01, -.81587100E+01, -.18568900E+02, 0.73875700E+00, -.20951500E+01, -.18726500E+02, -.83049900E+01, -.78171200E+01, 0.10080400E+02, 0.67184300E+01, 0.14089700E+02, -.81015500E+01, -.12420800E+01, -.20940400E+00, -.15162500E+00, -.11644800E+00, 0.11376700E+01, 0.24469200E+00, 0.59028700E+00, -.16274900E-01, 0.53644600E+02, -.16003300E+02, -.61387200E+02, -.51217200E+02, 0.42356100E+02, 0.39375700E+02, 0.46442300E+02, -.48518800E+02, 0.22226000E+03, -.10702500E+03, -.63097900E+02, -.60789500E+02, -.82432700E+01, 0.83283100E+02, -.61732500E+01, -.59157800E+02, -.78430700E+00, 0.62185700E+01, 0.14529900E+02, 0.11427500E+02, -.13209200E+02, -.93881400E+01, 0.16301300E+01, 0.12464100E+02, -.15718700E+01, 0.15493600E+01, -.75575700E+00, -.50675300E+00, -.60000100E+00, -.60972300E+00, 0.87977100E+00, -.22354700E+01, -.19987600E+01, 0.25958700E+01, -.10885000E+02, 0.40870500E+01, 0.48762200E+01, 0.46690500E+00, -.15349000E+01, 0.57551700E+01, -.21543100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.63012100E+01, -.81601300E+01, 0.50552600E+00, -.21908000E+01, -.51434500E+00, 0.28113400E+00, -.31636000E+01, -.40309700E+01, 0.40543400E+00, -.56281400E+00, 0.45190300E+00, -.11192500E+01, -.19641200E+01, -.19118500E+01, 0.23354000E+00, -.87350500E+00, 0.80925200E-01, -.75751500E+00, 0.13200600E+01, -.12070400E+01, -.87691200E+00, -.41434000E+00, -.48498200E+00, 0.88273600E-01, -.15707200E+00, -.16661400E+00, 0.11685000E+00, -.25268000E+00, 0.71089200E+00, 0.41249600E+00, 0.96092300E+00, 0.14361200E+01, -.14219900E+00, 0.26968200E+00, 0.11257100E+02, -.11425400E+01, -.29185300E+00, -.58654600E+00, 0.25899800E-01, -.14837000E+01, 0.31098100E+00, 0.40332900E+00, 0.13591800E+00, 0.36385900E+00, 0.42124700E+00, 0.12211600E-01, -.23010900E-01, 0.30000800E+00, 0.19629900E+00, 0.44899500E-01, 0.10719300E+01, -.24238400E-01, 0.21232300E+00, 0.60683800E+00, 0.37929700E+00, -.25409500E+00, 0.69253700E+01, 0.22951400E-01, 0.11264400E+01, 0.84718800E+00, -.41894600E+00, -.28828200E+00, -.53707000E+00, 0.98461400E-01, 0.15776700E+01, 0.40565900E-01, -.35946900E+00, -.10099500E+01, 0.30830500E+01, -.16272700E+00, -.33949800E-02, 0.55184800E+00, -.12827000E+01, 0.13221700E+03, 0.73219100E+02, 0.37994400E+02, -.65929800E+02, -.30029600E+02, -.87531700E+02, 0.34270000E+02, -.11951900E+03, 0.12843900E+03, 0.26554900E+02, 0.27777700E+02, -.98493500E+00, -.48035800E+02, -.44387100E+02, 0.23324500E+02, -.18310400E+01, -.55729700E+02, -.24189700E+02, -.20075100E+02, 0.26818900E+02, 0.18743800E+02, 0.34413600E+02, -.20347300E+02, -.21474900E+01, 0.22060300E+01, -.73883300E+00, -.53329900E+00, 0.31896600E+01, 0.12801700E+01, 0.11980500E+01, -.64458000E+00, 0.16352400E+03, -.16412800E+02, -.13662400E+03, -.10774900E+03, 0.92491400E+02, 0.11021700E+03, 0.11393300E+03, -.97579300E+02, 0.31809100E+03, -.11806500E+03, -.10112300E+03, -.86234700E+02, -.99565900E+01, 0.11860000E+03, -.17687200E+02, -.83072300E+02, -.37625500E+02, 0.13889100E+02, 0.30197800E+02, 0.25639600E+02, -.11393800E+02, -.20111900E+02, 0.20466000E+02, 0.29088700E+02, -.28979800E+01, 0.33142000E+01, 0.23010000E+01, -.45574100E+01, -.11301600E+01, -.19677300E+01, 0.17178500E+01, -.28545700E+01, -.60234200E+01, 0.87168600E+01, -.22565000E+02, 0.14017400E+02, 0.11991700E+02, 0.11183200E+01, 0.17400600E+01, 0.84007700E+01, -.62464500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.30291100E+01, -.50686300E+00, -.16582300E+01, -.65068900E+00, -.61061200E+00, -.75896100E+00, 0.10332900E+01, 0.94959200E+00, -.11754400E+01, -.39535300E-01, 0.11272400E-01, 0.42210600E+00, -.89261500E+00, -.64205100E+00, 0.68864600E-01, -.19521800E+00, 0.11782700E-01, -.96026600E-01, 0.56142700E+00, -.54673000E+00, -.34883100E+00, -.56280700E+00, -.19787700E+00, -.82140000E-01, -.11605700E+00, -.46203800E+00, 0.48039800E-01, -.90015600E-01, 0.14832300E+00, -.28156300E-01, 0.37405600E+00, 0.57568800E+00, -.19472600E+00, -.31401000E-01, 0.65096400E+01, -.33163100E+00, -.23810500E+00, 0.59668700E-01, 0.15590000E+00, -.85792600E+00, 0.19596900E+00, 0.36790100E+00, 0.55473600E-01, 0.65631800E+00, 0.18327800E-01, 0.10747300E-01, 0.34729200E-01, 0.85596400E-01, 0.11540700E+00, 0.63901700E-01, 0.21175700E+00, -.18885800E+00, 0.65049200E-01, -.18697800E-01, 0.45409400E+00, -.20148600E+00, 0.45612900E+00, 0.49480300E-01, 0.79210300E-01, 0.64464500E+00, 0.81078400E-01, 0.13358300E+00, 0.19112900E+00, 0.42373600E-01, 0.52445300E+00, -.33213300E+00, -.41458600E-01, -.24237900E+00, 0.16844000E+01, -.56178100E-01, -.90726100E-01, 0.18395200E+00, -.19315900E+00, 0.14371100E+00, 0.96416800E+01, 0.33212000E+01, -.67876600E+01, -.29129900E+01, -.91808500E+01, 0.17473300E+01, -.45125300E+01, 0.92504200E+01, 0.10365100E+01, 0.16277900E+00, 0.18240200E+01, -.74831000E+00, 0.11386300E+00, 0.36257100E+00, 0.42697600E+00, -.55784300E+01, -.18216900E+01, -.12966200E+01, 0.99940600E+00, 0.12296800E+01, 0.60910500E+00, -.15838200E+01, 0.10225700E+00, -.33670700E+00, -.98025600E-01, -.14136100E+00, 0.21910800E+00, 0.28064800E+00, -.60522500E+00, -.24846400E+00, 0.45845900E+01, 0.63869700E+01, -.10089000E+02, -.91772800E+01, 0.11814500E+02, 0.68882700E+01, 0.15574000E+02, -.77837300E+01, 0.24039300E+02, -.67056300E+01, -.52514500E+01, -.56554100E+01, -.18319300E+01, 0.69867400E+01, -.15525100E+01, -.50718600E+01, -.11573500E+01, 0.82717200E+01, 0.10366800E+01, -.23436000E-01, 0.51736800E+00, -.12094200E+01, 0.31611200E+01, 0.10502300E+01, 0.99857700E-01, 0.74020100E+00, 0.76473900E+00, -.75021100E+00, 0.52155400E+00, 0.46348200E-01, 0.40584300E+00, -.58030800E-01, 0.74065300E-01, -.98643200E-01, -.24471300E+01, -.10050300E+00, 0.23402200E+00, 0.13825900E+00, 0.17897900E+00, -.12063700E+00, 0.34468500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18284500E+01, 0.29516000E+00, 0.10167600E+01, 0.51444800E+00, 0.42677200E+00, 0.60941400E+00, -.39513700E-01, 0.89797600E-02, 0.64505700E+00, -.25967400E-01, -.62479100E-02, 0.29781800E+00, 0.76049100E+00, 0.54840400E+00, 0.56262700E+00, 0.11280500E+01, 0.16191000E-01, 0.14024600E+00, 0.45751600E-01, -.63353000E-01, 0.19723200E+00, -.97585500E-01, -.21104300E+00, 0.60086000E-01, 0.53059900E-01, 0.31909500E+00, -.28043400E-01, 0.85110600E-01, 0.12143500E-02, 0.33124500E+00, 0.45630300E-01, 0.43535700E+00, -.19433800E+00, 0.18950000E+00, -.47157100E+01, 0.27065800E+00, -.11688800E+00, -.10936200E+00, -.87866500E-01, -.51026700E-01, 0.93659300E-03, -.16835000E+00, 0.21097800E-01, -.23048800E+00, -.37279700E-01, 0.55148500E-01, 0.78212000E-01, 0.80694000E-01, 0.84697400E-01, 0.58358000E-01, 0.10764700E+00, -.37115600E-01, 0.15936300E-01, 0.13957500E+00, 0.42913400E+00, -.18844600E+00, -.16524400E+01, -.18806200E-01, 0.89948200E-01, 0.30868300E+00, 0.44846800E-01, 0.16049100E+00, 0.11961500E+00, -.67706100E-01, 0.63499800E+00, -.57019600E-01, -.25169500E+00, 0.55079000E-01, -.24581800E+00, 0.23936600E-01, 0.62704000E-01, -.13352400E+00, 0.33231900E+00, -.10699700E+00, 0.36294000E+00, 0.44969300E+01, -.17148400E+01, -.11350100E+01, -.18974400E+01, 0.47169400E+01, 0.63930700E+01, 0.32056800E+01, -.82281900E+00, 0.13830300E+01, -.26004200E+01, 0.77578600E+00, -.38784700E+01, 0.85703400E+00, 0.19423600E+00, -.71488000E+00, -.30222600E+00, -.22516200E+00, 0.24858200E+00, 0.14020000E+00, 0.45603900E+00, -.76075100E-01, -.15134100E+00, -.21335200E+00, 0.93618900E-02, 0.13315000E+00, -.36738900E-01, -.75528400E-01, 0.97439100E+00, 0.88280700E-01, -.42500700E+00, 0.31952400E+01, -.92339800E+00, -.48512400E+01, 0.25298500E+01, 0.41660100E+01, 0.83387500E+01, -.54392900E+01, -.74046700E+01, 0.13180700E+02, -.39067400E+00, 0.37091800E-02, 0.12233000E+01, -.20441900E+01, -.14362900E+01, -.99078600E+00, 0.10392500E+02, 0.33966900E+01, -.13476600E+00, -.34777400E+01, -.95047800E+00, 0.37707400E+01, -.18487800E+00, -.34112800E+01, -.15664700E+00, -.10899800E+00, -.17191300E+00, -.38647600E-01, -.40644100E+00, -.74708600E-01, -.18890300E+00, 0.19191300E+00, -.11796000E+00, -.21065300E+00, 0.10742000E+01, -.10373900E+00, 0.39506200E+00, 0.56266700E-02, -.99308800E+00, 0.22111500E+01, 0.83099200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.19347200E+01, 0.13442600E+00, 0.15167800E+00, 0.23087100E+00, 0.33516400E+00, -.15978800E+00, -.37505400E+00, -.22051500E+00, -.44571100E+00, 0.10948000E+00, 0.12767700E-01, -.17379500E+00, 0.30692000E-01, -.19351000E-01, -.91715500E+00, -.70787700E+00, 0.65257500E-01, 0.83945100E+00, -.70695200E+00, 0.60823700E+00, 0.15529700E+00, -.39876000E+00, 0.84947400E-01, -.86931100E-01, 0.80745500E-01, -.26549200E+00, -.58576200E-02, -.81391100E-01, -.12021300E-01, -.33741500E+00, -.30563900E+00, -.16954700E+00, 0.25311500E+00, -.41428700E-01, -.39639000E+00, 0.15168200E+00, 0.60587400E-01, -.93584700E-02, 0.18751000E+00, 0.19446500E+00, -.98658600E-01, -.97724400E-01, -.93495100E-02, -.26922700E-01, 0.76061000E-01, -.10713300E-01, 0.27545600E-01, -.37648300E-01, -.94827000E-01, -.37182500E-01, 0.15210400E+00, 0.16945700E+00, 0.12806700E+00, -.23650300E+00, -.36130300E+00, -.56106300E-01, 0.39512100E+01, 0.96045700E-01, -.59110000E-02, 0.30109400E+00, -.13238500E+00, -.13928600E-01, -.23597100E+00, -.29485700E-01, 0.11846100E+00, 0.18214600E+00, -.70344400E-01, -.10218600E+00, -.66106900E+00, -.29287400E-01, -.29273300E-02, 0.50363400E-01, -.10920100E+00, 0.52231300E-01, 0.13748300E+00, 0.14659400E+00, 0.28645100E+01, 0.96172100E+00, 0.27491200E+01, 0.12882300E+01, 0.39079500E+01, -.26270600E+01, -.13409600E+01, -.51038300E+00, -.58652100E+00, 0.11064100E+01, -.93517600E-01, -.68054700E+00, -.55025700E+00, 0.17245000E+01, 0.48716700E+00, 0.20374800E+00, 0.24249800E+00, -.52754800E+00, -.38458000E+00, 0.35876100E+00, -.66350800E-01, -.27338600E+00, -.41252200E-01, -.87332900E-02, 0.11281000E+00, -.76865300E-01, -.22622600E+00, 0.86046600E-01, 0.43515400E+01, -.69345200E+01, 0.15487600E+01, 0.21520300E+01, -.53257000E+01, -.12533500E+01, -.60741200E+01, 0.19855300E+01, 0.16617300E+02, -.13969500E+02, -.30704200E+01, -.35661000E+01, -.11549300E+01, 0.62538700E+01, 0.15990400E+01, -.34783900E+01, 0.54124000E+01, 0.21822000E+01, -.17559700E-01, -.68053200E+00, -.20575200E+01, 0.11925800E+01, -.17021200E+01, -.88423100E+00, -.61705700E-01, -.13724800E+00, 0.22462800E+00, -.25914400E+00, -.20902200E+00, 0.24532900E-01, 0.32748400E+00, -.51564000E+00, -.13131500E+00, 0.87426500E-01, -.34351400E+00, 0.36017800E-01, -.16437100E+00, 0.66041000E-01, 0.36343100E+00, -.91850300E+00, 0.68843700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.40947200E+01, -.81120400E+00, -.19094000E+01, -.97790900E+00, -.62485300E+00, -.10224600E+01, 0.14808200E+01, 0.23248400E+00, -.26081800E+01, 0.24912300E+00, 0.19318100E-01, -.13345700E+01, -.67525800E+00, 0.13114800E+00, -.56378100E+00, -.30185000E+01, 0.40883700E-01, 0.41628600E+00, -.24931800E+00, 0.15752900E+00, -.77184900E+00, 0.15961300E+01, -.25819900E+00, 0.18321800E+00, -.29145900E+00, 0.54345600E+00, 0.65562500E-01, 0.20734600E+00, -.10973300E+00, -.19203200E+01, 0.12293600E+01, -.26671200E+00, 0.55129500E+00, -.58366700E-01, 0.86338700E+01, -.95447200E+00, -.37442100E+00, 0.17777600E+00, -.55836800E-01, 0.40219300E+00, 0.82316100E-01, 0.80472900E+00, -.56675500E-01, 0.27137300E+00, -.33336400E-01, 0.85132000E-01, 0.56895800E+00, 0.12242700E+00, 0.12464600E+00, -.63671600E-01, -.52168000E+00, -.34321500E+00, -.28782300E+00, -.33356800E-02, 0.77314000E+00, -.53169300E-01, 0.13344300E+01, -.17201000E-01, 0.47542100E+00, -.29945600E-01, 0.78705700E-01, 0.60401800E+00, -.38756800E+00, -.10904600E+00, 0.97256200E+00, -.38571600E+00, -.19525000E+00, -.14550300E+00, 0.72993900E-01, -.11802600E+00, 0.16720300E+00, 0.13517600E+00, 0.10387100E+01, -.31970700E+00, -.20085700E+00, -.94433600E-01, -.19787800E+01, -.38668100E+01, -.21693300E+02, -.14165900E+01, -.27491100E+02, 0.34173300E+02, 0.93867800E+01, 0.96789800E+01, -.26027200E+01, -.11183300E+02, -.59912600E+01, 0.96912200E+01, -.43761200E+00, -.75795400E+01, -.26030200E+01, -.15118100E+01, 0.34398100E+01, 0.16699300E+01, 0.23768700E+01, -.12252000E+01, 0.32376000E+00, -.61984700E+00, -.66245500E-01, -.19309300E+00, 0.53518400E+00, 0.26769300E+00, -.20978800E+01, -.18382400E+00, -.35447000E+02, 0.40253300E+02, 0.98979500E+01, 0.15163300E+02, -.11009100E+01, -.10038800E+02, 0.84343100E+01, 0.15061200E+02, -.71492100E+02, 0.66867800E+02, 0.12684600E+02, 0.18847600E+02, 0.11282800E+01, -.27277000E+02, -.28577100E+01, 0.17938800E+02, -.48858800E+01, 0.15895200E+02, 0.34018400E+01, 0.51856800E+00, 0.18099300E+01, 0.36307700E+01, 0.13577300E+02, 0.10955000E+01, 0.24652900E+00, 0.65149900E+00, 0.37506400E+01, -.38348700E+01, 0.26065300E+00, 0.32369400E-01, 0.13404900E+01, -.37147300E+00, -.26903000E+00, 0.51621000E+00, 0.17483500E+01, 0.18163000E+01, 0.63692600E+00, 0.27938200E+00, 0.34154100E+01, -.12657100E+01, 0.51280000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.42023600E+01, -.40269100E+00, -.14992300E+01, -.80402900E+00, -.65699400E+00, -.42620100E-01, -.13397500E+01, -.24067700E+01, 0.10644900E+01, -.59701000E-01, 0.96387200E-01, -.14099200E+01, -.60031000E+00, -.38201500E-01, 0.93994600E-01, -.42826700E+00, -.58837500E-01, -.78486500E+00, 0.25430100E+00, -.32280400E+00, -.29766500E+00, 0.50899800E-01, 0.15855500E+00, -.18095200E-01, -.14718000E+00, 0.81938100E-01, 0.10118000E+00, 0.13425100E+00, 0.10282900E+00, -.37419100E+00, 0.88980000E-01, -.25977500E+00, -.52993300E-01, -.17830400E+00, 0.57646400E+01, -.57526100E+00, 0.42423700E+00, 0.33031900E+00, -.60384500E+00, 0.44142200E+00, -.41490400E-01, 0.90056300E-01, 0.21399000E-01, 0.12851800E+00, 0.52034500E-01, -.12613400E+00, -.19128300E+00, 0.10782300E+00, 0.18881500E+00, 0.11416100E-02, 0.19147800E+00, -.98251400E-01, 0.73423400E-02, 0.16943700E+00, -.84248100E+00, -.22711400E+00, 0.17642700E+01, 0.73023500E-01, -.29621600E+00, 0.31623700E+00, 0.40793100E-01, -.25266600E+00, 0.64161500E-01, 0.63899300E-01, -.27129800E+00, 0.18813800E+00, 0.13039600E+00, 0.17676500E+00, -.19263500E+00, 0.56433800E-01, -.49535600E-01, -.21283900E+00, -.29710900E-01, 0.15644200E-01, -.70736500E+00, -.12620500E+01, 0.14521900E+00, -.82893200E+00, -.14207400E+02, -.18797700E+01, -.18161000E+02, 0.25362900E+02, 0.59587700E+01, 0.57721200E+01, -.20973300E+01, -.90223400E+01, -.23976400E+01, 0.59288800E+01, -.14464000E+01, -.47585600E+01, -.13650900E+01, 0.27743700E+00, 0.18792100E+01, 0.66149100E+00, -.14219200E+00, 0.48125200E+00, 0.12965600E+00, -.45825700E+00, 0.33345200E-01, 0.11441500E+00, 0.32092200E+00, 0.49785700E+00, -.10535800E+01, 0.15968500E-01, -.18441700E+02, 0.38609400E+02, 0.75928400E+01, 0.11512600E+02, -.27766200E+01, -.15232500E+01, 0.16527400E+02, 0.11548600E+02, -.95345100E+02, 0.82597800E+02, 0.16099400E+02, 0.23032300E+02, 0.34827500E+01, -.36298100E+02, -.27957400E+01, 0.21802900E+02, -.28669400E+00, 0.12891100E+02, 0.23605000E+01, -.11503900E+01, 0.84323100E+00, 0.36472000E+01, 0.11669300E+02, -.34014500E+00, 0.53381400E-01, 0.19656700E+00, 0.33097400E+01, -.30497800E+01, 0.45203200E+00, -.26476500E+00, 0.94354500E+00, 0.28408000E-01, 0.34933400E-01, 0.12495900E+00, 0.10976300E+01, 0.21407600E+01, 0.56869100E+00, 0.25349100E+00, 0.17950000E+01, 0.35073700E-01, 0.79918500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26326500E+02, 0.38714500E+01, 0.77457500E+01, 0.48317000E+01, 0.38861000E+01, 0.28130800E+01, -.91647100E+01, -.92555000E+01, 0.41928000E+01, 0.15038600E+01, -.28165200E+00, -.55193100E+01, 0.35510100E+01, 0.32650000E+01, -.78104900E+01, -.70797000E+01, 0.11740900E+00, 0.46352000E+01, -.91691900E+01, 0.81312800E+01, 0.26829600E+01, 0.32967200E+01, 0.44134400E+01, -.57269700E+00, 0.15533000E+01, 0.16017800E+01, -.22811700E+00, 0.54010300E+00, -.26036000E+01, -.50625000E+01, -.44687900E+01, -.16414900E+01, 0.12758600E+01, -.36286500E+00, -.45365800E+02, 0.48058800E+01, 0.37285400E+00, 0.87657500E-01, 0.21886200E+01, 0.40398500E+01, -.12007600E+01, -.22834900E+01, -.34661900E+00, -.75939300E+00, -.24220600E+01, 0.17923000E+00, -.49094400E+00, -.22778800E+01, -.68521500E+00, -.64685500E+00, -.41593400E+01, -.19489300E+01, -.13025200E+01, -.44839100E+01, 0.11654300E+01, 0.16872200E+01, -.19630900E+02, -.31025000E+00, 0.88099100E+00, -.34593100E+01, 0.27714100E+00, 0.11546600E+01, -.47236200E-01, -.30495000E+00, -.87719400E+00, 0.49600900E+00, -.72708500E+00, 0.11374400E+01, -.41664500E+01, 0.59105600E+00, 0.39361600E+00, 0.53893700E+00, 0.42737100E+01, -.14589400E+01, -.35232800E+01, -.35366300E+00, 0.47864100E+01, 0.78688700E+00, 0.52605500E+00, -.10271400E+02, 0.23228800E+02, 0.11857200E+02, 0.42458400E+01, 0.36339300E+01, 0.51571000E+01, 0.11076500E+02, -.40774000E+00, 0.71404400E+01, 0.59071500E+01, -.60129600E+01, -.99756400E-01, -.34731500E+00, -.83683400E+01, 0.31335700E+01, 0.37633900E+00, -.22528700E+01, 0.28965000E+00, -.77018600E-01, -.52422000E-01, -.54169300E-01, -.16458600E+01, 0.14073500E+00, 0.91024600E+01, -.12558700E+01, -.15373200E+03, 0.45173100E+02, 0.12580500E+02, -.13519200E+02, 0.65240800E+02, -.38576700E+02, 0.31832200E+02, -.16551100E+02, -.22987500E+03, 0.18446100E+03, 0.52456900E+02, 0.43817000E+02, 0.31738300E+02, -.81162700E+02, -.15456000E+02, 0.42469800E+02, -.10880700E+02, -.20866600E+02, -.19606000E+02, -.14709600E+02, 0.20816400E+02, 0.32823900E+01, 0.48004400E+01, -.14568900E+02, 0.41284500E+00, 0.76809300E+00, -.76351400E+01, 0.78229200E+01, 0.10341200E+01, 0.60910100E+00, -.42658100E+01, 0.60374100E+01, 0.30078600E+01, -.53251300E+01, 0.13177000E+01, -.97929000E+01, 0.29499900E+00, -.77763600E+00, -.74948700E+01, 0.14207500E+02, 0.33507200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.93343300E+01, 0.14066500E+02, -.49917300E+00, 0.36060500E+01, 0.10025700E+01, -.15422700E+00, 0.58113900E+01, 0.61614100E+01, -.27661700E+00, 0.10672000E+01, -.82939000E+00, 0.22271200E+01, 0.31913100E+01, 0.30794300E+01, 0.10104200E+01, 0.27299100E+01, -.93971000E-01, 0.61109100E+00, -.85773400E+00, 0.10400500E+01, 0.14248400E+01, 0.79754800E+00, 0.17397800E+01, -.16731400E+00, 0.76578700E+00, 0.40536300E+00, -.11728200E+00, 0.82249300E+00, -.12744800E+01, -.82847200E+00, 0.84223400E-01, 0.10395900E+01, -.19304200E+00, -.42118100E+00, -.54407300E+01, 0.40064800E+00, 0.18338600E-01, 0.10597200E+00, -.38437600E+00, 0.23291100E+01, -.31633400E+00, -.41066000E+00, -.32747600E+00, 0.10320300E+01, -.48833900E+00, -.13408300E-01, 0.38516200E+00, -.78507400E+00, -.62146700E+00, -.35252400E+00, -.20280300E+01, -.24603000E+00, 0.53503500E-01, -.40728200E+00, -.41829700E+01, -.52376200E+00, 0.17786200E+02, 0.87628300E-01, 0.44008300E+00, -.71125700E+00, 0.12579900E+01, 0.10805300E+01, 0.56184500E+00, -.18880200E+00, -.35903600E+01, -.15105400E+01, -.54823900E-01, 0.48843900E+00, 0.32459500E+01, 0.63290600E-02, -.90108100E+00, -.25605200E+00, -.33494000E+00, -.12858800E+00, -.13313900E+01, -.11129900E+01, -.23547200E+01, -.26548700E-01, -.30200000E+00, 0.32386200E-01, 0.12008500E+03, -.71498400E+02, -.26995100E+02, -.22478400E+02, -.15108600E+02, 0.40192100E+02, -.46019600E+01, -.23061700E+02, -.43175300E+01, 0.61694600E+01, 0.35391500E+01, 0.27925800E+01, -.20673000E+01, -.13215400E+01, -.17719000E+00, 0.22464400E+01, -.18494700E+00, -.15737800E+01, 0.67726400E+00, 0.62335900E+00, -.28561400E+00, -.20968000E+00, -.98031700E+00, 0.55512100E+00, -.67877900E+02, 0.10336200E+00, -.10612800E+02, -.18545500E+02, 0.25386600E+02, -.25969000E+02, 0.44219300E+01, -.22738800E+02, 0.91796500E+02, 0.87865500E+01, -.30642300E+02, -.26908800E+02, -.74045600E+01, 0.25094600E+02, -.20616900E+02, -.29023600E+02, 0.43283900E+02, -.13507000E+02, 0.54336300E+01, -.21588100E+01, -.26216100E+02, 0.18633200E+01, -.72620300E+01, -.19205900E+01, 0.21951000E-01, 0.62546800E+00, -.20699400E+01, 0.10710200E+01, 0.38332500E+00, -.14142400E+00, 0.46042300E+00, -.13588100E+01, 0.22940500E+00, -.19363000E+01, -.19343800E+00, -.32985700E+01, 0.76717300E+00, 0.17793400E+00, -.13654600E+01, 0.84889600E+01, 0.11717100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16051500E+02, -.56096000E+00, -.50563000E+01, -.22550300E+01, -.22700600E+01, -.25433800E+01, 0.12133400E+02, 0.14390400E+02, -.52120300E+01, -.78011300E+00, -.22167700E+00, 0.60766400E+01, -.20053000E+01, -.12822900E+01, 0.27794100E+01, 0.51187700E+01, 0.10712600E+00, -.49093300E+01, 0.57173300E+01, -.52304700E+01, -.72100000E+00, -.15004700E+01, -.18642300E+01, 0.23581000E+00, -.80904900E+00, 0.93327300E+00, 0.16789600E-01, 0.97754200E+00, 0.73128500E+00, 0.24430500E+01, 0.26723400E+01, 0.32399900E+01, -.16544600E+01, 0.64654800E+00, 0.11304400E+02, -.66551000E+00, -.65661300E+00, 0.90066700E+00, -.21162600E+01, -.34937500E+01, 0.42414200E+00, 0.88569700E+00, 0.71798900E+00, -.19624200E+01, 0.51229600E+00, -.48722800E+00, -.13281800E+01, 0.54698700E+00, 0.93068300E+00, 0.48127200E+00, 0.12444700E+01, 0.16429300E+01, 0.78789400E+00, -.53276700E+00, -.11547200E+01, -.53923800E+00, 0.44467400E+00, 0.25240200E+00, -.22952700E+00, 0.15020800E+01, -.81777400E+00, -.67378900E+00, -.49898300E+00, -.20902800E+00, 0.47238300E+01, 0.44820800E+00, 0.79460700E+00, -.23019500E+01, -.25255600E+00, -.75597800E+00, -.63591200E-01, -.20914300E+00, -.21303200E+01, 0.58536800E+00, 0.22850800E+01, 0.16294100E+01, 0.37230200E+01, 0.41614000E+00, -.14786800E+01, -.30649600E-01, -.50496300E+00, -.77018600E+02, -.71174500E+01, -.18868500E+02, 0.29354000E+02, 0.10365000E+02, 0.33867600E+02, -.13553700E+02, 0.68970400E+00, 0.13346700E+02, 0.70134400E+01, 0.95022600E+01, -.12404700E+02, -.51602900E+01, -.17535100E+02, 0.94455100E+01, -.31177900E+00, 0.17756500E+01, 0.45434000E+00, 0.80636700E+00, -.85975900E+00, 0.11053500E+00, -.20586800E+01, 0.72484600E+00, -.15963100E+02, -.57249500E-01, 0.13757800E+02, 0.35797500E+02, -.20391600E+02, -.12174300E+02, 0.10132900E+00, 0.39034800E+02, -.14139800E+03, 0.32939000E+02, 0.36801800E+02, 0.47420300E+02, -.64343600E+01, -.61538700E+02, -.46080800E+01, 0.43488600E+02, -.45624100E+02, -.11604500E+02, -.19923500E+01, 0.65213500E+01, 0.90504200E+01, -.13123400E+02, -.17036400E+01, 0.75772300E+01, -.13663800E+00, -.22521800E+01, 0.21949500E+00, 0.55281600E+00, 0.10245700E+01, -.38626100E+00, -.74410700E+00, 0.10325200E+01, 0.12162300E+01, -.98884000E+00, -.29486600E+00, -.60255800E+01, -.43797600E+01, -.29953200E+00, -.88350500E+00, -.20292600E+01, -.17610400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.33737000E+02, 0.28118100E+01, 0.96667500E+01, 0.55485100E+01, 0.53156000E+01, 0.32541600E+01, -.12677400E+02, -.12285000E+02, 0.20480500E+02, -.20297900E+01, -.60038100E-01, -.13605400E+02, 0.69879900E+01, 0.77026600E+01, 0.57945900E+01, -.10047000E+02, -.28882100E+00, 0.24194000E+01, -.53810000E+01, 0.38010500E+01, -.15689900E+01, 0.33447300E+01, 0.45648400E+00, 0.35611300E+00, 0.24948600E-01, 0.32075200E+01, 0.30790100E+00, -.27170100E+00, -.17447900E+01, -.22627700E+01, -.34458900E+01, 0.59411100E+00, 0.13270100E+01, -.11182300E+01, -.27454900E+02, 0.36794900E+01, -.12247900E+01, -.14149800E+01, -.16844500E+01, -.55133800E+01, 0.10836700E+01, 0.22050100E+00, 0.35447100E+00, 0.35216300E+00, 0.10442800E+01, 0.51852400E+00, -.30452200E+01, -.17688200E+01, -.33747100E+01, -.59552300E+00, -.24268200E+01, 0.21478700E+01, -.11722700E-01, -.50731800E+01, -.78486500E+01, -.14090500E+01, 0.39255600E+02, 0.98599100E+00, -.62494800E+00, -.86344800E-01, 0.12724100E+00, 0.56437400E+00, 0.65482800E+00, -.80618600E+00, -.20259500E+01, 0.10461300E+01, -.52518900E+00, 0.17981100E+01, -.84436000E+01, 0.32711300E+00, 0.15720300E+01, 0.57963200E+00, -.10848600E+01, -.33229800E+00, -.34302000E+01, -.30713600E+01, -.17848900E+01, -.13122600E-01, -.28182000E+00, 0.52107300E+00, 0.21690700E+00, -.64141400E-01, -.16279100E+02, -.91781900E+01, 0.92645700E+01, 0.68482300E+01, -.67520700E+00, -.12804500E+02, 0.29557200E+01, -.17001000E+01, -.29722900E+01, -.24201600E+01, 0.44886900E+01, 0.27664500E+01, -.30578400E+01, -.92121300E+00, -.47771600E+00, -.24133200E+01, 0.57032200E+00, 0.85312400E+00, 0.10774900E+01, -.51510600E-04, -.28294100E+01, 0.16551100E+01, 0.20420200E+03, 0.79122700E+02, -.16010500E+02, -.12947400E+02, -.36135000E+02, 0.80886300E+02, 0.42991800E+02, 0.37003800E+01, 0.34577300E+03, -.75891000E+02, -.77633200E+02, -.84146300E+02, -.21839900E+02, 0.13330500E+03, 0.24778400E+02, -.78179100E+02, 0.67211400E+01, -.10800500E+02, 0.20183800E+02, 0.13204300E+02, -.34859400E+02, -.10455000E+02, -.72415500E+01, 0.14915900E+02, -.54980100E+00, 0.10668600E+01, 0.82067000E+01, -.10510000E+02, -.84071500E+00, -.60089500E+00, 0.33537500E+01, -.47949300E+01, -.45565800E+00, 0.11555600E+01, -.23565400E+00, -.17182000E+01, 0.18702600E+00, 0.95540100E+00, 0.62126500E+01, -.60079500E+01, -.26692800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13238900E+02, -.15616400E+01, -.40015000E+01, -.23761000E+01, -.18967600E+01, -.13843200E+01, 0.45831100E+01, 0.47265500E+01, -.18623900E+01, -.56319500E+00, 0.60048500E-01, 0.20113800E+01, -.16428800E+01, -.14313300E+01, 0.26358700E+01, 0.27206500E+01, -.79413400E-02, -.24931100E+01, 0.36243100E+01, -.32876200E+01, -.99027000E+00, -.13863100E+01, -.14137800E+01, 0.85922200E-01, -.75466000E+00, 0.38473900E+00, 0.19266400E+00, 0.43744600E+00, 0.11350800E+01, 0.92931800E+00, 0.20076700E+01, 0.10939400E+01, -.10778500E+01, 0.43385200E+00, 0.17825800E+02, -.16226500E+01, 0.34844200E+00, 0.68198800E+00, -.15499300E+01, -.17672900E+00, -.11766100E-01, 0.49262100E+00, 0.72785900E+00, 0.64990800E+00, -.36440100E+00, -.67188600E-01, -.58381800E+00, 0.42019000E+00, 0.93996700E+00, 0.15342000E+00, 0.96448000E+00, -.73814900E+00, 0.21380100E+00, -.49619600E+00, 0.43752300E+00, -.57537900E+00, -.74477500E+01, -.11713400E-01, -.18809600E+01, 0.14837900E+01, 0.52883600E-01, -.83305300E+00, 0.66408000E+00, -.10139600E+00, 0.16554500E+01, -.75127700E+00, 0.33147000E-01, -.44199000E+00, -.60083100E+00, -.32268600E+00, 0.22544500E+00, -.11190000E+01, -.11856500E+01, 0.27793400E+00, 0.10638700E+01, 0.97375900E+00, 0.99711600E+00, 0.13817700E+01, -.22743000E+01, 0.19241000E-01, -.77386200E-01, 0.13221300E+00, 0.20714300E+00, -.83149300E+01, 0.57311700E+01, -.37386800E+00, 0.10338200E+02, -.80433300E+01, 0.49088900E+00, 0.44375200E+01, 0.14630100E+01, 0.26941600E+01, -.26037800E+01, -.11733900E+01, -.54492100E+01, 0.28058700E+01, 0.14577500E+01, 0.14716400E+01, -.30749400E-01, 0.68303500E-01, -.52680300E-01, 0.59527800E+00, -.91418600E+00, -.92041600E-01, 0.35036600E+02, -.16011300E+01, -.84807300E+01, -.12202200E+02, -.16277800E+01, 0.17317100E+02, 0.12274300E+02, -.13545300E+02, 0.48188100E+01, 0.22128500E+02, 0.12164000E+02, 0.96839500E+01, -.21549900E+02, -.88256600E+01, -.16653700E+02, 0.85828900E+01, -.14944800E+02, 0.92693600E+01, -.19545000E+01, -.48031700E-01, 0.10944800E+02, -.22832700E+01, 0.33734700E+01, 0.11886900E+01, 0.19878500E+01, 0.18390900E+00, -.66366500E+00, 0.75305000E+00, 0.98630600E+00, -.42978800E+00, -.45757400E+00, 0.93639000E+00, 0.31171100E-01, 0.97074400E+00, -.85268200E+00, 0.22307400E+01, -.79324200E+00, 0.11098800E+00, -.23414000E+01, -.80254700E+00, -.21361100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.74300100E+01, -.69957000E+00, -.29376900E+01, -.14376300E+01, -.14295200E+01, -.19855300E+00, -.25113200E+01, -.54605500E+01, -.14520900E+01, 0.72504100E+00, 0.66780300E-01, -.30207200E+01, -.31930000E+01, -.88114500E+00, -.46803400E+01, -.46766300E+01, 0.35718900E+00, 0.27361000E+01, -.20404400E+01, 0.14920900E+01, -.54446800E+00, 0.16322400E+01, 0.13255700E+01, -.83977700E-01, 0.54434400E+00, -.11563100E+01, -.16091500E+00, -.27092300E-01, -.11591400E+01, 0.30131500E+00, -.11954600E+01, -.57404000E+00, 0.27018000E+00, -.56491000E+00, -.83842900E+00, 0.12863400E+00, -.16194700E+00, 0.44530100E-01, -.63877300E+00, -.28288100E+01, 0.46128600E+00, 0.38140100E+00, 0.83048300E-01, -.15603100E+01, 0.82935300E+00, -.71032900E-01, -.14598300E+01, -.29190200E+00, -.96738900E+00, 0.98897200E-01, -.27265100E+00, 0.19254200E+01, 0.28747400E+00, -.56097700E+00, -.22523900E+01, -.17108200E+00, -.29680200E+01, 0.34829500E+00, -.52477900E+00, 0.53527200E+00, -.27143300E+00, 0.40045700E+00, -.10507900E+01, -.19665700E+00, -.25584900E+01, 0.81854000E+00, 0.11938100E+01, 0.43812600E+00, -.36496700E+01, -.47233100E+00, -.45055600E+00, 0.27551000E+01, -.40975200E+00, -.48547100E-01, -.13419800E+01, -.14166800E+01, 0.17940300E+01, -.64824200E+00, 0.38349900E+00, 0.23860000E+00, 0.29991300E-01, 0.66196600E-01, 0.24656100E-01, -.13607600E+00, 0.96055800E+01, 0.49983500E+01, 0.59077500E+01, 0.11044300E+01, 0.37027000E+01, 0.93772300E-01, 0.30936100E-01, -.10663900E+01, -.19061700E+01, 0.10780400E+01, -.32217900E+01, -.11133900E+01, 0.48899300E+00, -.76521300E+00, -.58534000E-01, 0.72735900E-01, -.94853000E-01, 0.21116300E+00, -.22047700E+01, 0.91772800E-01, 0.27876000E+01, 0.30583600E+02, 0.49302000E+01, 0.10584200E+02, -.74102100E+01, 0.96052400E+00, 0.68840700E-01, 0.14373100E+02, 0.45710800E+02, -.12141500E+02, 0.22853200E+01, -.31919000E+01, -.72155500E+01, 0.18620500E+02, -.16483000E+01, -.30417300E+01, -.11539400E+02, 0.21162000E+02, -.10622200E+00, -.92380500E+00, 0.50625600E+01, -.46971600E+01, -.54508300E+01, 0.19469400E+00, 0.72610200E+00, 0.11582100E+01, 0.69617300E+00, -.14328100E+01, 0.31933200E+00, 0.23587700E+00, 0.39997800E+00, -.34126100E+00, 0.34084300E+00, -.86823100E+00, 0.38982800E+00, -.43878900E+01, -.11658800E+01, 0.13392600E+00, 0.18170500E+01, -.27378100E+01, 0.15551700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.55095900E+01, 0.76163700E+00, 0.21136300E+01, 0.10303600E+01, 0.77243400E+00, -.16721200E+00, 0.23800800E+01, 0.41218500E+01, -.16687300E+01, 0.37065900E-01, -.13103800E+00, 0.19625800E+01, 0.10720800E+01, -.76311800E-01, 0.57757500E+00, 0.94291200E+00, 0.88674600E-01, 0.24035400E+01, -.26488800E+00, 0.51217100E+00, 0.23198700E+00, 0.10042400E+01, -.25747600E+00, 0.20585700E+00, 0.52845700E+00, -.66434600E+00, -.11371300E+00, -.54436300E+00, -.18402900E+00, -.16470000E+00, 0.11932400E+00, 0.51632100E+00, -.45975500E-01, 0.19567600E+00, -.42654600E+01, 0.50788100E+00, -.25116100E+00, 0.12687800E+00, 0.13594300E+00, 0.14166900E+00, -.52622600E-01, -.90078300E-01, -.21509000E-01, -.82714400E-01, -.27780300E+00, -.37140100E-01, -.21410200E+00, -.29207400E+00, -.36886400E-01, 0.33577200E-01, -.12188700E+00, 0.45695900E+00, 0.20890000E+00, 0.71117300E+00, -.72444300E+00, -.61240100E-01, 0.11260000E+02, 0.17763200E-01, 0.15371200E+00, -.43375400E+00, -.16370400E+00, 0.13027400E+00, -.25563500E+00, -.15901100E+00, 0.11811300E+01, 0.64229900E-01, 0.12746000E-01, -.62063900E+00, -.29283700E+00, 0.74654200E-01, 0.25797900E+00, 0.78208700E+00, 0.15929200E+00, 0.13122900E+00, -.30294300E+00, -.96758300E+00, -.26543900E+00, -.47281600E+00, 0.52962900E+00, -.76518200E-01, -.65407900E-01, 0.17230000E+00, -.10275700E+00, -.28931000E+00, 0.46614300E+00, -.48389000E+01, -.63004700E+01, -.21417800E+00, 0.58819700E+00, 0.18164800E+01, -.49899100E+00, -.79503200E-01, 0.96842600E+00, 0.17631200E+01, 0.58971700E+00, 0.67812600E-01, 0.93467300E-01, 0.69274300E-02, 0.23804700E+00, 0.28304700E+00, -.30671500E-01, -.12526900E+00, -.35721800E+01, 0.14208800E+00, 0.28932200E+02, -.28282000E+02, -.13626900E+02, -.19690600E+02, 0.11099800E+02, 0.12309300E+02, 0.84526700E+01, -.19361300E+02, 0.21595500E+02, 0.84808300E+01, -.65127800E+01, -.77845400E+01, -.35473900E+01, 0.25306100E+01, -.82013600E+01, -.71170800E+01, 0.10354800E+02, -.85269000E+01, -.68223700E+00, -.25452200E+01, -.27818400E+01, 0.39806800E+01, 0.32285900E+01, -.20976700E+01, 0.24833900E+00, 0.32433200E+00, 0.66425800E+00, -.11254200E+01, 0.88914400E-01, 0.83536600E-01, 0.50646800E+00, -.18964300E+00, 0.43151900E+00, -.46390000E+00, 0.23987000E+00, 0.87632000E+00, -.19737400E+00, 0.27898200E-01, 0.69935200E+00, 0.12066300E+01, -.40361600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.30461000E+01, 0.60434100E+00, 0.14845800E+01, 0.84767700E+00, 0.77226800E+00, 0.76507400E+00, 0.10537700E+01, 0.18642700E+01, 0.55881700E+00, -.15787600E+00, -.45516000E-01, 0.12597500E+01, 0.11069100E+01, 0.43324700E+00, 0.13807000E+01, 0.29160800E+01, -.67471500E-02, 0.41166100E+00, 0.79185000E+00, -.56469700E+00, 0.15425900E+00, -.78447200E+00, -.71909300E+00, 0.10744500E+00, -.48957900E-01, 0.40591900E-01, 0.13770600E+00, -.56156400E-01, 0.89822700E+00, -.19197800E+00, -.35448300E-02, 0.56631400E-01, 0.44943900E-01, -.26125500E-01, -.10125800E+01, 0.82148300E-01, -.13267100E+00, -.75476700E-01, -.26871600E-01, -.21928300E+00, 0.74243400E-01, 0.55806900E-01, 0.14020500E+00, -.89241500E-01, 0.55401200E-01, 0.45032100E-01, 0.15613500E-01, 0.58571300E-01, 0.37989800E-02, -.19318400E-01, -.26181400E-01, 0.14871000E+00, -.35532400E-01, 0.60367300E-01, -.92544100E-01, -.60791600E-01, -.46901800E+01, -.14681800E-01, -.38223000E+00, 0.12992400E+00, 0.17996800E+00, 0.17164500E+00, 0.28967000E+00, -.50973300E-01, -.85419700E-01, 0.13960900E+00, 0.41819800E+00, 0.63823700E-01, -.85836600E+00, -.20893400E+00, 0.14971200E-01, -.11003700E+01, -.29772900E+00, -.24294400E+00, -.71507200E+00, -.22884900E+00, 0.27814100E+00, 0.48435900E+00, -.47601700E+00, 0.58149100E-01, 0.13756600E-02, 0.94115700E-01, -.12298500E-01, -.26920800E+00, -.33241000E-01, -.44325300E-01, 0.70348000E+01, -.82800300E+00, 0.54169200E+00, 0.16193900E+01, 0.93918800E+00, 0.12786900E+01, -.19571800E+01, -.17662300E+01, -.54244900E+01, 0.13660400E+01, 0.50676200E+00, -.26166000E+00, -.60890500E-01, 0.70187300E-01, 0.18228300E-01, 0.30712100E+00, -.58923000E+00, 0.80866400E-02, 0.49482400E+02, -.11352700E+02, -.27891200E+01, -.59638800E+01, -.11747300E+02, 0.21036600E+02, 0.89645300E+01, -.52142100E+01, 0.31037900E+02, -.10338600E+02, -.88208800E+00, -.15466700E+01, -.10222000E+02, 0.84029000E+01, 0.58969100E+00, -.23105000E+01, 0.34483700E+01, 0.13723400E+02, -.32278100E+00, -.17487200E+01, 0.46953900E+00, 0.46158400E+00, -.13969900E+01, -.57857200E+00, 0.65404900E+00, -.17842200E+00, 0.12457000E+01, -.12188300E+01, 0.57697300E+00, -.78639900E-02, 0.43077600E+00, -.25885400E+00, 0.40551400E+00, -.30903600E-01, 0.16876900E+00, 0.46209900E+00, -.15035000E+01, 0.12555600E+00, -.74540600E+00, -.22084300E+01, 0.58511700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.47016100E+01, 0.92870500E+00, 0.26932500E+01, 0.14891900E+01, 0.16214900E+01, 0.15745100E+01, 0.15506400E+01, 0.44098900E+01, 0.56055700E+01, -.12478800E+01, -.36328600E-01, 0.10274300E+01, 0.14640900E+01, 0.81001300E+00, 0.34754300E+01, 0.28233100E+01, -.31028900E+00, -.38504400E+01, 0.14365800E+01, -.14941400E+01, 0.43726600E+00, -.23952000E+01, 0.18554900E+00, -.37153800E+00, -.13254100E+00, 0.12627100E+01, 0.36905700E+00, -.16582800E+00, 0.13546100E+01, 0.59594800E+00, 0.12318000E+01, -.60675900E+00, 0.28989900E+00, 0.10366400E+01, 0.44527000E+01, 0.62867600E+00, -.39511500E+00, 0.82040700E+00, -.25764600E-01, 0.62717800E+00, -.29451300E+00, 0.20174600E+00, 0.76089900E+00, -.23549100E+00, 0.44278800E+00, -.81851700E-01, 0.25758000E+00, -.12641500E+00, -.42680300E+00, -.57988200E-01, -.43720100E-01, 0.39885000E+00, 0.12163500E+00, -.46123900E+00, -.10616600E+01, 0.39684400E+00, 0.74880000E+01, 0.15937900E+00, 0.14849000E+00, -.64344600E+00, -.17415100E+00, -.67171700E-01, -.54336400E+00, 0.14891300E+00, -.67683300E+00, 0.33267900E+00, 0.35198900E+00, -.55416700E+00, 0.16645500E+01, 0.26284800E-01, -.65987800E+00, -.43513600E-01, -.88156400E+00, 0.28152800E+00, 0.43624000E+00, 0.67055700E+00, 0.16141000E+01, -.48340700E+00, -.15814900E+00, -.50369200E-02, -.51741900E-03, 0.63802800E-01, -.13865900E+00, -.19562200E+00, -.94583400E-01, 0.22551200E+00, 0.35374200E+00, 0.17898500E+01, -.41177400E+00, -.71075000E-01, 0.39822300E+00, 0.65399100E+00, -.65504800E+00, 0.51418000E+00, 0.36804400E-01, 0.36017400E+00, 0.40994500E+00, -.27827400E+00, -.60054900E-01, -.18200400E-01, -.16663000E+00, 0.74006600E-01, -.74071000E+00, 0.81754600E-01, -.43103400E+02, 0.26984400E+02, 0.79915700E+01, 0.16778300E+02, 0.19710000E+01, -.19048300E+02, -.11806800E+02, 0.17848200E+02, -.46873500E+02, 0.14736300E+02, 0.69985700E+01, 0.12126700E+02, 0.46450200E+01, -.14997800E+02, 0.46077300E+00, 0.11994800E+02, -.13331400E+02, -.49769900E+00, 0.28710800E+01, 0.49396000E+01, -.18370100E+01, -.50977600E+01, -.19572500E+01, 0.43978200E+01, 0.51875700E+00, 0.11516700E+00, -.19727500E+01, 0.14352500E+01, 0.12671500E+00, 0.14874200E+00, -.36950100E+00, 0.45407800E+00, 0.23830800E-01, -.38104900E+00, 0.57188000E-01, -.39072600E+00, 0.32955100E+00, -.44420700E-03, 0.76811600E+00, 0.14847000E+01, 0.73913700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15223300E+02, 0.18617000E+01, 0.46028000E+01, 0.27025900E+01, 0.22229400E+01, 0.16343100E+01, -.47160200E+01, -.49760600E+01, 0.19383600E+01, 0.54075600E+00, -.67011900E-01, -.21377900E+01, 0.33814200E+01, 0.17888400E+01, -.79254800E+00, -.25262100E+01, 0.59848000E-02, 0.36782900E+01, -.36114100E+01, 0.34792300E+01, 0.10628300E+01, 0.11077900E+01, 0.76182200E+00, 0.32014400E-01, 0.79412200E+00, -.69865800E+00, -.16443500E+00, -.83765200E+00, -.67508600E+00, -.87702100E+00, -.19779100E+01, -.11989100E+01, 0.11640100E+01, -.36464100E+00, -.18396900E+02, 0.16747800E+01, -.23393900E+00, -.80549500E+00, 0.17202000E+01, 0.71867900E+00, -.55326700E-01, -.71111900E+00, -.58840200E+00, -.21508400E+00, -.78966600E-01, 0.10658700E+00, 0.34273600E+00, -.44746900E+00, -.65022600E+00, -.14991400E+00, -.27984800E+00, 0.16807600E+00, -.17336500E+00, 0.18695400E+00, 0.37259800E+00, 0.16615500E+00, 0.11054500E+02, 0.11605300E+00, 0.13070500E+01, -.82776400E+00, -.22167300E+00, 0.61370800E+00, -.76698300E+00, 0.74743900E-02, -.33336400E+00, 0.96003800E+00, -.75896400E+00, 0.42209600E+00, -.62008300E+00, 0.45507400E+00, -.15441800E+00, 0.77839600E+00, 0.12307600E+01, -.23441800E+00, -.96010200E+00, -.36115300E+00, -.60543500E+00, -.62786400E+00, 0.96663900E+00, 0.67959100E-01, 0.19359700E+00, -.35526400E+00, -.16255400E-01, -.43246800E+00, -.73984100E-01, 0.14943200E+00, 0.37935300E+00, 0.24148600E+00, 0.61023200E+01, -.36384500E+00, -.46538300E+00, -.66192900E+00, 0.14105500E+00, 0.89427100E+00, 0.67616400E-02, -.38029700E+00, 0.60016900E+00, -.99756300E-01, -.39928700E-01, -.10568100E+00, -.72946800E-01, 0.13152600E+00, 0.10420100E+00, -.36011500E-01, 0.11964900E+02, -.92403100E+01, 0.14697200E+01, 0.72865100E+01, -.94508000E+01, 0.39706100E+00, -.68479800E+01, 0.87358300E+01, -.40021400E+01, 0.58360200E+01, 0.50559500E+00, -.45029400E+00, 0.43033000E+01, -.10768000E+01, 0.21760000E+01, -.24250500E+00, -.66312100E+01, 0.42654300E+00, -.26344300E-01, -.20225700E+00, 0.28146900E+01, -.23270000E+00, 0.11887400E+01, -.36586000E+00, 0.76166700E+00, 0.57907400E+00, 0.79441300E-01, -.34884900E+00, 0.24058500E+00, 0.13842100E+00, -.12561500E+00, 0.22149700E+00, -.17822400E+00, 0.28783800E+00, -.82008100E-01, 0.57622200E-01, 0.99449000E-01, 0.31857800E-01, 0.70358600E+00, -.64042700E+00, 0.26997200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.33792700E+01, -.47699300E+01, 0.34736400E+00, -.11743500E+01, -.23829900E+00, 0.23791600E+00, -.22956100E+01, -.28441600E+01, 0.86640500E+00, -.32743000E+00, 0.28219800E+00, -.10793600E+01, -.13306500E+01, -.62053000E+00, -.74365200E+00, -.56660200E+00, 0.57210800E-01, -.12267700E+01, 0.57505500E+00, -.64990000E+00, -.36573200E+00, -.40404700E+00, -.40901000E-01, 0.11551800E-01, -.20528200E+00, 0.27095900E+00, 0.81857500E-01, 0.49583600E-01, 0.27185700E+00, 0.38215400E+00, 0.15099300E-01, -.48295000E+00, 0.44603600E-01, 0.58775800E-01, 0.31349200E+01, -.11222000E+00, 0.17368800E+00, 0.16878400E+00, -.32297700E+00, -.96560800E+00, 0.11811300E+00, 0.99144000E-01, 0.40435100E+00, 0.20161700E+00, 0.19687100E+00, 0.11423600E+00, -.17914600E+00, 0.36723800E+00, 0.10651700E+00, -.75325500E-01, 0.37599500E+00, 0.16279900E+00, 0.10546800E+00, -.32003300E+00, 0.52710700E+00, 0.10171300E+00, -.10940000E+02, -.13828000E+00, -.48380100E+00, -.51276700E-01, 0.75645100E-02, -.32355800E+00, 0.31894900E+00, -.10863800E+00, 0.49760100E+00, -.98505200E-01, -.22571800E-01, -.41909400E-01, -.91249400E+00, -.74370500E-01, 0.26658100E+00, -.35583100E+00, -.14379800E+00, -.25890200E-01, -.85267100E-01, 0.34169200E+00, 0.38446700E+00, 0.30320700E+00, -.36569900E+00, 0.42844800E-01, -.69378800E-01, 0.57777600E-01, 0.52637900E-01, 0.18008200E+00, 0.76849600E-01, -.22069000E+00, -.14496300E+00, -.19981800E+00, -.17047000E+00, 0.75324300E+01, 0.14872700E+00, 0.11214500E+00, -.39143200E+00, 0.48323800E-01, 0.49280700E+00, 0.14159000E-01, -.17265100E+00, 0.50699800E+00, 0.12071800E-01, -.21664900E-01, 0.17604500E-01, -.39771500E-01, 0.13786600E+01, -.26235000E-01, -.13797000E+01, -.46482700E+01, -.31752700E+01, -.36128100E+01, 0.27253300E+01, -.18749200E+01, -.53824300E+00, -.38306700E+01, 0.96809100E+01, 0.27215600E+01, -.16978400E+01, -.90137400E+00, -.33756100E+01, 0.14413700E+01, -.32417700E+01, -.98251100E+00, 0.18440900E+01, -.10532900E+01, 0.55904400E+00, -.19833500E-01, -.80437400E+00, -.14725400E+00, -.11566900E+00, 0.43344600E+00, -.20493800E+00, -.18649100E+00, -.90163200E+00, 0.71317200E+00, -.92940800E-01, -.18951200E+00, -.24078600E+00, 0.21298700E+00, -.38613100E+00, 0.38553700E+00, -.28696400E+00, 0.32235300E+00, 0.15083000E+00, -.45106500E-01, -.71262100E+00, 0.60533700E+00, -.12282600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17498200E+01, -.29247900E+00, -.98914800E+00, -.36252200E+00, -.33693500E+00, -.46806600E+00, 0.58544900E+00, 0.65551100E+00, -.39831100E+00, -.14184100E-01, -.68731900E-02, 0.36463200E-01, -.66209700E+00, -.26944300E+00, -.39476000E+00, -.25314100E+00, 0.71422100E-02, -.42333900E+00, 0.22664900E+00, -.24277900E+00, -.13908100E+00, -.14715400E+00, 0.87610000E-01, -.44277900E-01, -.71219400E-01, -.13870600E-01, 0.29932300E-01, 0.99652300E-01, 0.63537800E-02, -.92591900E-01, 0.95420500E-01, -.29425500E-02, -.15463000E-01, -.70325900E-01, 0.28826300E+01, -.21893600E+00, 0.88964500E-01, 0.13637000E+00, -.20112100E+00, 0.51627000E-01, -.23292900E-01, 0.11692300E+00, 0.21543500E-01, -.60462600E-01, 0.11318800E+00, -.51714200E-01, 0.71407100E-01, 0.76907600E-01, 0.21688700E-01, -.94194700E-02, -.31676900E-01, 0.14652000E+00, 0.16382100E-01, -.79759900E-01, -.30889500E+00, 0.10588600E+00, -.17672200E+01, 0.40744500E-03, -.31510800E+00, -.74851800E-02, -.42781600E-03, -.84610100E-01, 0.47867300E-02, -.14512100E-01, -.17185500E+00, -.19131600E-01, 0.14452400E+00, -.10050200E-01, -.34883200E+00, -.34688800E-01, 0.15351000E-01, -.13436700E+00, -.21455200E+00, 0.21234400E-01, 0.93688700E-01, 0.21197900E+00, 0.21324700E+00, 0.12501500E+00, -.18512600E+00, -.24268600E-01, -.45822300E-01, 0.65056300E-01, 0.58647600E-02, 0.54014400E-01, -.79801800E-01, -.42795100E-01, -.36655000E-01, -.23090800E-01, -.91111700E-01, 0.34374100E-01, 0.38576100E+00, 0.14530500E+00, -.12791000E+00, -.11606100E+00, -.36062000E-02, 0.11504700E+00, 0.35417100E-01, -.82243800E-01, -.21312900E-01, -.16476400E-01, -.15447100E-01, 0.68338100E-02, -.45323000E-01, -.10974300E-01, -.72061400E+00, -.28439900E+01, 0.59302700E+00, -.11239000E+00, -.20302000E+00, -.10557500E+01, -.20635100E+01, -.29498400E+00, 0.39952800E+01, -.36452700E+01, -.26448600E+00, -.74824400E+00, -.12773600E+00, 0.19968200E+01, 0.33568900E+00, -.62910000E+00, 0.11662600E+00, -.73150100E+00, 0.78020600E-01, 0.43541700E+00, -.52639300E+00, -.23226900E+00, -.54272900E+00, 0.44539600E+00, 0.39786000E-01, 0.23616400E-01, -.24561200E+00, 0.21280700E+00, 0.27222400E-01, 0.46490600E-01, -.21770000E-01, -.25302900E-01, 0.28683000E-01, -.53474200E-01, 0.10736900E+00, -.15367300E-01, -.31969200E-01, -.15817600E-02, -.12888800E+00, -.13569800E+00, -.59270700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.21003200E+01, -.34423800E+00, -.11763700E+01, -.58172800E+00, -.48774700E+00, -.72331800E+00, 0.10257500E-01, 0.33622000E-01, -.58400200E+00, 0.33460000E-01, 0.21918400E-02, -.35187200E+00, -.12047400E+01, -.66116000E+00, -.97452900E+00, -.13458400E+01, -.55690000E-02, -.43883900E+00, -.78304100E-01, 0.18347500E-01, -.23829400E+00, 0.10444500E+00, 0.41344100E+00, -.10045400E+00, -.37950100E-01, -.21531500E+00, 0.35629000E-01, 0.18283700E-01, -.10171100E+00, -.35547000E+00, -.54117800E-01, -.20481600E+00, 0.11961300E+00, -.16827600E+00, 0.42564900E+01, -.25567200E+00, 0.59523300E-01, 0.10188600E+00, -.48686500E-01, 0.21552000E-01, -.85800600E-02, 0.20414300E+00, -.12826700E-02, 0.12037500E+00, 0.12747500E+00, -.58353900E-01, 0.50108000E-01, 0.35666100E-01, 0.14079400E-01, -.32056900E-01, -.10906000E+00, 0.37792700E-01, -.15578300E-01, -.14471000E+00, -.25095900E+00, 0.18200800E+00, -.90676800E+00, -.20686900E-01, -.26309200E+00, -.11078900E+00, -.42347300E-03, -.11565400E+00, -.12958200E-01, -.57824800E-02, -.21251700E+00, -.13977500E+00, 0.73323400E-01, -.23901800E-01, 0.80375800E-01, -.29167500E-02, -.22903200E-01, 0.86282600E-01, -.24865300E+00, 0.11065600E+00, 0.22401500E+00, -.29044300E-01, 0.20917200E+00, 0.73567500E-01, -.95670200E-01, -.26291600E-01, -.31526900E-01, 0.41251400E-01, 0.15430000E-01, 0.12351900E+00, -.14391200E+00, -.73299600E-01, -.21627700E+00, -.11116900E+00, -.12424600E+00, 0.41810300E-01, 0.56373200E+00, 0.50237400E+00, -.24571400E+00, -.21879000E-01, 0.19402000E-01, 0.21789100E+00, 0.61642900E-01, -.82560600E-01, -.20019000E-02, 0.42862700E-01, -.48629300E-01, -.25309400E-01, -.42009500E+00, 0.35590700E-01, -.34459500E+01, -.10819900E+01, 0.28863900E+00, 0.13017800E+00, 0.87995000E+00, -.16427300E+01, -.16296100E+01, 0.39101700E-01, 0.32687200E+01, -.30031000E+01, -.96703300E+00, -.13256400E+01, 0.78071500E+00, 0.20163800E+01, 0.47186000E+00, -.11752300E+01, -.28648700E+00, -.16747800E+01, 0.21797300E+00, 0.72238300E+00, -.10586300E+01, -.18546700E+00, -.52310700E+00, 0.50313500E+00, 0.79368400E-01, -.94142800E-02, -.24665000E+00, 0.18362300E+00, 0.15455600E-01, 0.60249600E-01, -.36978000E-01, -.42510600E-01, 0.92394300E-01, -.15781900E+00, 0.95366100E-01, -.15515800E+00, -.26813200E-01, -.87909100E-02, 0.43003300E-02, 0.29043500E+00, -.13465700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22433800E+01, -.17463000E+00, -.16535000E+00, -.27009900E+00, -.41078600E+00, 0.20535600E+00, 0.27182700E+00, -.21090400E-02, 0.37899300E+00, -.87414300E-01, -.61739200E-02, 0.14374800E+00, -.49963100E-01, 0.10008500E+00, 0.68608200E+00, 0.70343900E+00, -.88158400E-01, -.93016200E+00, 0.60995900E+00, -.52718700E+00, -.11708600E+00, 0.49896000E+00, -.28797900E-01, 0.86913100E-01, -.90618200E-01, 0.20764600E+00, -.22424200E-02, 0.63878600E-01, -.30063200E-01, 0.22002800E+00, 0.20832100E+00, -.55619700E-01, -.13937000E+00, -.34695300E-01, 0.69918500E+00, -.12164800E+00, 0.14012700E-01, 0.42400100E-01, -.82631500E-01, -.24352100E+00, 0.74331200E-01, 0.83901000E-01, 0.34307800E-02, 0.73922600E-01, -.63490900E-01, 0.39780300E-01, -.69099900E-01, 0.84577200E-02, -.40716600E-01, 0.17140600E-01, -.21562700E+00, -.35201900E-01, -.47225600E-01, 0.26383800E+00, 0.20940200E+00, 0.81447000E-01, -.28023900E+01, -.77650000E-01, 0.76425800E-01, -.26481100E+00, 0.92599200E-01, 0.28612000E-01, 0.68758400E-01, 0.54763400E-01, -.34668200E+00, -.17616600E+00, 0.12179400E+00, 0.18696800E+00, 0.39117800E+00, -.45142400E-02, -.10274400E-01, 0.20305100E-01, 0.28467800E-01, -.83367000E-03, 0.10623500E-01, -.52049000E-01, -.45891400E+00, -.11458300E+00, 0.11944400E+00, -.35480600E-01, 0.15192200E-02, -.18582600E-02, -.11880300E-01, 0.93274500E-02, -.63301600E-02, 0.38661900E-01, -.18927200E+00, -.13523600E+00, 0.27862700E-01, -.15343000E-01, 0.18931800E+00, 0.13615200E+00, 0.51479600E+00, -.65979000E-02, -.94358100E+00, 0.70877800E-01, 0.75476700E-02, -.92386700E-01, 0.39057200E-01, 0.40480700E-01, 0.61028800E-01, 0.13270300E-01, -.84298400E-01, 0.37983400E-01, 0.30014900E+01, 0.10215100E+01, -.61806800E+00, -.18221800E+01, 0.12779500E+01, 0.27349700E+01, 0.39845700E+01, -.16111600E+01, 0.23327600E+01, -.10940900E+01, -.22727700E+00, -.22741500E+00, -.10891400E+01, 0.58591000E+00, -.47029600E+00, -.36941100E+00, -.18447600E+01, 0.69919500E+00, 0.43583600E+00, 0.77646300E+00, -.55629000E+00, -.12437700E+01, -.63240100E+00, 0.91354600E+00, 0.33113700E-01, 0.75387700E-01, 0.34473000E+00, -.45551900E+00, 0.23458100E-01, -.28039500E-01, 0.21538200E+00, -.18156400E+00, 0.12229500E+00, -.14371500E+00, 0.73917800E-03, -.66562100E-01, -.13709900E+00, 0.52020800E-01, 0.76341600E-01, -.85630300E-01, -.12754900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.47891000E+01, 0.46595300E+00, 0.17095700E+01, 0.90128300E+00, 0.76513800E+00, 0.83433500E-01, 0.16879100E+01, 0.29002400E+01, -.12475100E+01, 0.36627100E-02, -.10211100E+00, 0.16373800E+01, 0.11429100E+01, 0.29709500E+00, 0.28266400E+00, 0.67360400E+00, 0.60137200E-01, 0.75395200E+00, -.10754800E+00, 0.23189900E+00, 0.37268800E+00, 0.38928800E-01, -.39150300E+00, 0.87532900E-01, 0.16100100E+00, -.13959700E+00, -.11111300E+00, -.19775000E+00, -.97556100E-01, 0.41755900E+00, -.57018300E-01, 0.44129400E+00, -.53925200E-01, 0.21993200E+00, -.50021700E+01, 0.37867300E+00, -.22540900E+00, -.21481500E+00, 0.26852800E+00, -.16877800E-01, -.28532600E-01, -.23138300E+00, -.10733100E+00, -.32480500E+00, 0.64195900E-01, -.20343700E-01, 0.17132600E+00, 0.57551100E-01, 0.44281500E-01, 0.32127700E-01, 0.36074900E+00, 0.13964400E+00, 0.13505000E+00, -.14827900E+00, 0.44829000E+00, -.57869000E-01, 0.35102600E+01, 0.72792900E-01, 0.33012400E+00, -.23501100E+00, -.21458400E+00, -.88614700E-01, -.25869600E+00, 0.43474300E-01, 0.55283000E+00, 0.24868900E+00, -.38166200E+00, -.27634000E+00, 0.16610600E+00, 0.10080700E+00, -.14960700E+00, 0.40074900E+00, 0.33461500E+00, 0.24945900E-01, 0.69727700E-01, 0.19711000E+00, 0.73987300E-01, -.23327200E+00, 0.17086000E+00, 0.12217000E-01, 0.17720300E-01, -.58403900E-01, -.46303200E-01, -.10185600E+00, 0.83499500E-01, 0.22210900E-01, 0.15018200E-01, 0.12536800E+00, 0.18748300E+00, -.24511200E-01, -.44348300E+00, -.67596200E+00, 0.46292900E+00, 0.12820900E+01, 0.38783900E+00, -.15818700E+00, 0.16297600E+00, -.16672800E+00, -.44586700E-01, -.35892300E-01, -.26703600E-01, 0.80328000E-01, -.30304000E-03, -.14299000E-01, 0.83381200E+01, 0.63382000E+01, 0.12395900E+01, 0.45245700E+01, -.50175900E+01, -.25193700E+00, -.73212300E+01, 0.57518400E+01, 0.78393400E+01, -.23447800E+01, 0.53125600E+00, -.74286900E+00, -.69561500E+00, 0.30866600E+01, 0.11722500E+01, -.40050400E-02, 0.53012100E+00, 0.37379900E+01, 0.86457600E-01, -.86044900E+00, 0.78834100E+00, 0.84061800E+00, 0.63966100E+00, -.60678600E+00, 0.19303900E+00, 0.18015600E+00, 0.49328900E-01, 0.37893700E-02, 0.77567500E-01, 0.67569800E-01, -.87977200E-02, 0.12537200E+00, -.17458100E-01, 0.88672500E-01, 0.10553500E+00, -.51328600E-01, 0.96680800E-01, 0.15397300E-01, 0.10337100E+01, -.11724200E+01, 0.48089200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15101800E+01, 0.24536800E+00, 0.84985800E+00, 0.31896900E+00, 0.29364600E+00, 0.38934100E+00, -.53315200E+00, -.53243500E+00, 0.46549300E+00, 0.13433500E-01, 0.34111400E-02, -.85909500E-01, 0.36353500E+00, 0.23371800E+00, 0.86584400E-01, 0.14748500E+00, 0.35462500E-02, 0.20072800E+00, -.25860700E+00, 0.21658900E+00, 0.12300000E+00, 0.18312900E+00, 0.67336700E-01, 0.19086400E-01, 0.82455100E-01, 0.15183000E+00, -.27356900E-01, -.11771900E-02, -.98705200E-01, 0.97489400E-01, -.14189100E+00, 0.13548600E+00, -.60218000E-01, 0.85306200E-01, -.37504700E+01, 0.28541600E+00, -.70560200E-01, -.77285100E-01, 0.94509200E-01, 0.39225200E-01, -.12911900E-01, -.13861300E+00, -.24843400E-01, -.53618000E-01, -.10240200E+00, 0.33153600E-01, 0.60382200E-01, -.30805600E-01, 0.26073300E-01, 0.55935200E-02, -.86374400E-01, -.12413700E+00, -.49379100E-01, -.37594500E-01, 0.24569300E+00, -.22618400E-01, -.13183300E+01, -.37483900E-01, 0.14357200E+00, -.90074500E-01, 0.39286900E-01, 0.86506600E-01, 0.61224800E-01, -.12428000E-01, 0.10042600E+00, -.25659000E-01, -.11607500E+00, 0.55964800E-01, 0.12169100E+00, 0.37449500E-01, 0.99123900E-02, 0.77354700E-02, 0.26688800E-01, 0.24132700E-01, 0.22142300E+00, 0.13755100E+00, 0.73563700E+00, -.24207300E+00, 0.25561300E+00, 0.96496400E-02, 0.35244400E-01, -.28619600E-01, -.47705200E-01, -.42548900E-01, 0.35801600E-01, -.13877000E+00, -.27084600E+00, -.22326500E+00, 0.10155100E+00, 0.46891400E-01, 0.82017500E+00, 0.37909400E+00, -.83732600E+00, 0.13603800E+00, -.17996100E+01, 0.20604000E+00, 0.89508100E-01, -.72962600E-01, 0.20027000E+00, 0.10990000E+00, -.13402200E-01, -.64445200E-03, -.46016200E+00, 0.10957900E+00, 0.89513700E+01, 0.10561100E+02, -.27470700E+01, -.45915800E+01, 0.26565500E+01, 0.79108900E+01, 0.12181900E+02, -.38899700E+01, 0.47824400E+01, 0.82887900E+01, -.11312600E+01, 0.26746300E+00, -.46685900E+01, 0.31205000E-01, -.25115500E+01, -.26786500E+00, -.37061700E+01, 0.21640100E+00, 0.94085000E+00, 0.13308900E+01, -.99589500E+00, -.23360500E+01, 0.19166800E+00, 0.15722200E+01, 0.15453300E+00, 0.14778000E+00, 0.36111200E+00, -.71437300E+00, 0.20007600E+00, -.11343300E+00, 0.22147500E+00, -.15123600E+00, 0.45775300E+00, -.42421300E+00, -.42303100E+00, -.31300700E+00, -.33464300E+00, 0.49307200E-01, -.38150900E+00, 0.86277300E+00, -.16697700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18385700E+01, -.30346100E+00, -.11264300E+01, -.53594000E+00, -.47093200E+00, -.72938800E+00, -.83508800E-01, -.65900000E+00, -.31556400E+00, 0.12799600E+00, 0.17190100E-01, -.67237500E+00, -.74815400E+00, -.23815700E+00, -.82724700E+00, -.91346900E+00, 0.45057300E-01, -.81870300E-01, -.25005700E+00, 0.88118200E-01, -.67075500E-01, -.29319700E+00, 0.34363900E+00, -.14390600E+00, 0.49657900E-01, -.21586300E+00, 0.44473100E-01, 0.90384500E-01, -.17783500E+00, -.46076100E+00, -.13954400E-01, 0.69936300E-01, 0.81925500E-01, -.13914000E+00, 0.32049800E+01, -.14526600E+00, -.80445100E-01, 0.48951200E-01, -.58984300E-01, -.37923200E-01, 0.26981100E-01, 0.23835400E+00, 0.59682400E-01, 0.12597100E+00, 0.92049200E-01, -.37783800E-01, 0.10325500E+00, 0.59098600E-01, 0.54015300E-01, -.27941700E-01, -.16340900E+00, 0.33734400E-01, -.29412500E-01, -.83523200E-01, -.28796200E+00, 0.11428300E+00, -.21534100E+01, -.36461200E-01, -.35387800E+00, -.86772000E-01, 0.89444600E-01, -.83191400E-01, 0.14888300E+00, -.41726300E-01, -.12651300E+00, -.18470100E+00, 0.14972300E+00, -.28371600E-01, -.77015200E-01, -.49050000E-01, 0.25550100E-01, -.27255200E+00, -.36465000E+00, 0.58784300E-01, 0.20683800E-02, -.10898400E+00, 0.59749800E-01, 0.85750500E-01, -.15302300E+00, -.26611200E-01, -.16679900E-01, 0.49871400E-01, 0.15621400E-01, 0.45538500E-01, -.11110500E+00, -.40385900E-01, -.68882600E-01, -.48079800E-01, -.72645400E-01, 0.21537600E-01, 0.54507900E+00, 0.70809500E+00, -.15967800E+00, -.38122800E-01, 0.21267600E+00, 0.40330000E+00, -.57474400E-01, 0.58446800E-01, -.11730500E-01, 0.23257000E-01, 0.15143800E-01, -.24352200E-02, 0.34257300E+00, 0.16361700E-01, -.19067800E+01, -.22149400E+01, -.57575100E+00, -.11689600E+01, 0.12120900E+01, 0.15634800E-01, 0.18209300E+01, -.14869300E+01, -.24386000E+01, 0.10797800E+01, 0.41233100E+00, 0.65882700E+00, -.88328100E-01, -.11894900E+01, -.46155100E+00, 0.49942400E+00, 0.72775500E+00, 0.31630400E+00, -.19208900E+00, -.23886900E+00, 0.14368400E+00, 0.31520100E+00, -.17382500E+00, -.18470300E+00, -.67433500E-01, -.66592300E-01, 0.90697500E-01, -.25824400E-01, -.52761000E-01, -.33822400E-01, -.16635000E-01, 0.26118200E-01, -.50928000E-01, 0.49193300E-01, 0.64257600E-01, 0.48237500E-01, 0.67644100E-01, 0.13860700E-02, -.20445500E+00, 0.99664600E-01, -.12875500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.77996100E+01, 0.10448900E+01, 0.23385500E+01, 0.14140300E+01, 0.11463500E+01, 0.88318500E+00, -.28032800E+01, -.29445000E+01, 0.12598400E+01, 0.30012100E+00, -.20334500E-01, -.12066200E+01, 0.92983700E+00, 0.87685900E+00, -.14767000E+01, -.14575800E+01, -.17921400E-02, 0.13698300E+01, -.20291800E+01, 0.18407500E+01, 0.56409300E+00, 0.77141800E+00, 0.79118800E+00, -.35852000E-01, 0.43283600E+00, -.19984100E+00, -.11694700E+00, -.23719100E+00, -.62295200E+00, -.50783500E+00, -.11656700E+01, -.61575800E+00, 0.63806500E+00, -.23084500E+00, -.10101400E+02, 0.92761200E+00, -.19277100E+00, -.40440000E+00, 0.82716900E+00, -.50780900E-01, 0.19917200E-01, -.27208100E+00, -.33537500E+00, -.39036400E+00, 0.15020600E+00, 0.36750400E-01, 0.15991500E+00, -.25810900E+00, -.52969400E+00, -.71446700E-01, -.43856400E+00, 0.49328000E+00, -.33634000E-01, 0.18335000E+00, -.16452800E+00, 0.19913900E+00, 0.30981500E+01, 0.37494300E-01, 0.66216300E+00, -.48265500E+00, -.64953000E-01, 0.44145900E+00, -.43906100E+00, -.35967600E-01, -.77624900E+00, 0.29736300E+00, -.11703500E+00, 0.31462200E+00, -.88431500E+00, 0.91800800E-01, 0.65592800E-02, 0.37051900E+00, 0.50175900E+00, -.13387000E+00, -.42241200E+00, 0.47201900E-01, 0.11992700E+00, -.23044800E+00, 0.36449300E+00, 0.51322300E-01, 0.97144100E-01, -.12084400E+00, 0.67000300E-04, -.20168400E+00, -.62586300E-01, 0.75631600E-01, 0.74457000E-01, 0.11297100E+00, 0.62422100E-01, 0.70675500E-02, 0.44212900E+00, 0.17916800E+00, -.25963700E+00, -.11758500E+00, 0.18504500E+00, 0.13208500E+00, 0.34226700E+01, -.16038200E+00, -.69398000E-01, -.76054900E-01, -.57094800E-01, 0.84078700E-01, 0.47143500E+00, -.44732100E-01, -.33122700E+01, -.17607200E+01, 0.32616800E+01, 0.58180700E+01, -.52021600E+01, -.28706900E+01, -.41619300E+01, 0.57079800E+01, -.78760100E+01, -.88717300E+00, 0.20890600E+01, 0.17028200E+01, 0.15459900E+01, -.18815300E+01, 0.13724700E+01, 0.14823900E+01, -.11795000E+01, 0.12065400E+01, -.56773700E+00, -.53884300E+00, 0.16910700E+01, 0.98411900E+00, 0.32362500E+00, -.56041300E+00, 0.40854800E+00, 0.15760500E+00, -.17964500E-01, 0.71071400E-01, 0.10030600E+00, 0.95908800E-01, -.14825800E+00, 0.11802700E+00, -.63629900E-01, 0.88650000E-01, 0.21660700E-01, -.39360200E-02, 0.97430500E-01, 0.12054400E-01, 0.44628300E-02, -.25189800E+00, 0.19545300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17952300E+01, -.24314600E+01, 0.14895800E+00, -.61825100E+00, -.13952700E+00, 0.82824700E-01, -.93287500E+00, -.12009500E+01, 0.26577900E+00, -.18701300E+00, 0.13789600E+00, -.45054300E+00, -.35937200E+00, -.34678800E+00, 0.19087500E+00, -.16915400E+00, 0.20887000E-01, -.13361500E+00, 0.34805900E+00, -.33391600E+00, -.24997100E+00, -.21283000E+00, -.35795100E+00, 0.68098300E-01, -.13815900E+00, -.23409900E-01, 0.37279600E-01, -.11346400E+00, 0.31371200E+00, 0.20661900E+00, 0.61863500E-01, -.28981600E+00, -.30532500E-01, 0.10486400E+00, 0.17246700E+01, -.99072700E-01, 0.14996900E+00, 0.15796100E+00, -.18296700E+00, -.13836700E+00, -.49271300E-02, 0.19038200E-01, 0.12818400E+00, 0.92958700E-01, 0.37045600E-01, -.27902900E-01, -.15481900E+00, 0.11072700E+00, 0.70209900E-01, -.33806700E-01, 0.24603900E+00, 0.68646400E-01, 0.14106700E+00, -.80753600E-01, -.20774000E+00, -.71547900E-01, -.27085000E+00, -.28606400E-01, -.28862700E+00, -.39741500E-01, -.54574800E-01, -.32933100E+00, 0.73614800E-01, 0.11656600E-01, -.79980100E-01, 0.60673100E-01, 0.78614600E-01, 0.37137100E-01, -.36832900E+00, -.26367200E-01, 0.56806400E-01, -.16906100E+00, -.18295300E+00, 0.16487300E-01, -.24242800E+00, -.30277500E+00, 0.22938000E-01, 0.61844800E-02, -.51401500E-01, -.78661500E-02, -.16836800E-01, 0.25306700E-01, 0.15669800E-01, 0.42097600E-01, 0.24968300E-01, -.95169600E-01, -.77377200E-01, -.12344900E+00, 0.31666800E-02, 0.46461600E-01, 0.87992000E-01, 0.36812100E+00, -.26376000E-01, 0.10973800E+00, 0.71213500E-01, 0.27489800E+00, -.11842400E-01, 0.58914900E+01, 0.28022100E-01, 0.58167100E-01, -.20448000E-02, -.10590400E-01, -.56185400E+00, 0.36166600E-01, -.56472900E+01, 0.54319100E+01, -.42509300E+00, -.29031500E+00, 0.21499000E+01, -.49006700E+00, 0.29682500E+01, -.49132000E+00, -.77193100E+01, 0.40212600E+01, 0.52378400E+00, 0.18638100E+01, -.22154800E+00, -.34382200E+01, -.12142600E+01, 0.14929400E+01, 0.88945000E+00, 0.25415400E+00, -.24117800E+00, -.85439400E+00, 0.51297300E+00, 0.27854300E+00, 0.30705100E+00, -.80085600E+00, -.39370700E-01, -.27967300E-01, -.30554700E-02, -.60032600E-02, -.29976000E-01, -.94331900E-01, -.45405000E-01, 0.64454500E-01, -.69292600E-01, 0.96385100E-01, -.51248600E-01, 0.91530300E-01, -.19311700E-01, -.33416000E-01, -.92101200E-01, 0.56628100E+00, 0.27941800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.90266600E+00, -.16143500E+00, -.50023400E+00, -.19025500E+00, -.17656900E+00, -.23414400E+00, 0.31636400E+00, 0.31876400E+00, -.27906200E+00, -.11612200E-02, -.36879200E-02, 0.25983900E-01, -.21355000E+00, -.12783700E+00, -.12099600E+00, -.13993000E+00, 0.26921800E-02, -.13161500E+00, 0.10800800E+00, -.10145400E+00, -.61777900E-01, -.99046800E-01, -.23253200E-01, -.16249000E-01, -.48617300E-01, -.52610800E-01, 0.17296900E-01, 0.18674100E-01, 0.34973900E-01, -.65735700E-01, 0.77151400E-01, -.64368100E-01, 0.56681900E-02, -.38689200E-01, 0.18726300E+01, -.15576100E+00, 0.60912500E-01, 0.54365300E-01, -.80126500E-01, 0.10592600E+00, -.15793500E-01, 0.52113100E-01, 0.14119000E-01, 0.35921200E-01, 0.25357400E-01, -.22781100E-01, 0.89428600E-02, 0.32045400E-01, 0.35900100E-01, -.44703700E-02, 0.35017800E-01, -.20127800E-02, 0.32643800E-02, 0.76472200E-02, -.13379300E+00, 0.22058100E-01, 0.87683500E-01, 0.14652400E-02, -.11369800E+00, 0.13947400E-01, -.13610000E-01, -.88456500E-01, -.14379700E-01, 0.83675100E-02, -.60007000E-01, 0.10717300E-01, 0.45861400E-01, -.16504700E-01, -.10117000E+00, -.10602900E-01, -.18797000E-01, -.47013300E-01, -.12250300E+00, 0.27426200E-01, -.13674400E-01, -.31993300E-01, -.87293700E-01, 0.31494700E-01, -.82885800E-01, -.21240700E-01, -.15564700E-01, 0.13611100E-01, 0.61131200E-03, 0.25540800E-01, -.29086500E-01, 0.81063300E-02, 0.42095500E-01, 0.39207100E-01, -.14787100E-01, -.74925300E-02, -.16164600E+00, -.14059500E+00, 0.17487100E+00, 0.20522300E-01, -.16121500E+00, -.70265100E-01, -.87410900E-02, -.78165600E-02, 0.20072900E+00, 0.18525400E-01, -.19108200E-03, -.11768800E-01, -.64413000E-01, 0.21167700E-01, 0.23673000E+01, 0.14222900E+00, -.48581900E+00, -.67891000E+00, 0.51396600E-01, 0.68731600E+00, -.21522400E+00, -.55669700E+00, 0.45808600E+01, -.71611500E+00, -.93242100E+00, -.10976500E+01, -.29760700E+00, 0.17045500E+01, -.92105700E-03, -.94353800E+00, 0.85864500E-01, -.41189100E+00, 0.28180700E+00, 0.29659900E+00, -.55492400E+00, -.20574100E+00, -.32188400E-01, 0.28728500E+00, -.32523500E-01, 0.11548600E-01, 0.41292000E-01, -.61109700E-01, 0.36714200E-02, -.37962400E-02, 0.43324000E-01, -.52016700E-01, 0.32433300E-01, -.42880300E-01, 0.24354200E-01, -.31400200E-01, -.18586800E-01, 0.41095700E-02, 0.12463500E+00, -.73223600E-01, -.42676200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10905500E+01, -.19364100E+00, -.59670900E+00, -.30414600E+00, -.25414600E+00, -.36530000E+00, 0.50375200E-01, 0.29588200E-01, -.39757700E+00, 0.21056000E-01, 0.17226800E-02, -.18233900E+00, -.45610000E+00, -.31963500E+00, -.39902800E+00, -.70663300E+00, -.11148800E-02, -.81930500E-01, -.53773300E-01, 0.47049100E-01, -.11306500E+00, 0.61411700E-01, 0.12729400E+00, -.36380700E-01, -.26375400E-01, -.16870400E+00, 0.17625900E-01, -.42861200E-01, -.19751000E-01, -.17242300E+00, -.90412800E-02, -.19430800E+00, 0.82534500E-01, -.10503300E+00, 0.24810300E+01, -.14850900E+00, 0.61924600E-01, 0.53818900E-01, 0.31504100E-01, 0.54436900E-01, -.49215800E-02, 0.89463700E-01, -.84528900E-02, 0.13990600E+00, 0.15287700E-01, -.20602400E-01, -.74035500E-03, -.14233500E-01, -.96634000E-02, -.34003300E-01, -.48806100E-01, -.25856800E-01, -.17015400E-01, -.77157100E-01, -.10319700E+00, 0.95375500E-01, 0.22224600E+00, -.42745100E-02, -.56521800E-01, -.73378600E-01, -.24248700E-01, -.74875300E-01, -.47131700E-01, 0.10523800E-01, -.58551100E-01, -.19450500E-02, 0.19618000E-01, -.40289200E-01, 0.57908900E-01, 0.24001200E-02, -.39755100E-01, 0.53266000E-01, -.12211300E+00, 0.62167400E-01, 0.33388900E-01, -.11611100E+00, 0.38841000E-01, 0.98286300E-02, -.28051500E-01, -.10375300E-01, -.10029700E-01, 0.78068200E-02, -.71058900E-02, 0.28430600E-01, -.11367900E-01, -.35735700E-02, 0.74137800E-03, 0.79218900E-02, -.13624300E-01, 0.12305300E-02, -.11302400E+00, -.47972300E-01, 0.70308400E-01, 0.38865400E-01, -.81272800E-01, -.63569300E-01, -.92912200E-02, -.64523600E-02, 0.64249800E-01, 0.22843800E+00, 0.10133700E-02, -.15974200E-01, -.13573900E-01, 0.24730400E-01, 0.27543100E+01, -.15572100E+01, -.54028800E+00, -.89367600E+00, 0.23130300E+00, 0.51286300E+00, -.10163000E+01, -.73996500E+00, 0.61342600E+01, -.17875600E+01, -.13114400E+01, -.16276900E+01, -.49537500E-01, 0.23383300E+01, 0.21069500E+00, -.13928300E+01, -.26635900E-02, -.12647300E+01, 0.33164400E+00, 0.46445200E+00, -.83306000E+00, -.28854400E+00, -.16852100E+00, 0.40597100E+00, -.31050600E-01, -.22620500E-02, -.51922600E-01, 0.11135800E-01, -.13960600E-01, 0.36277200E-02, 0.21446600E-01, -.49702100E-01, 0.16890600E-01, -.21935600E-01, 0.26212000E-01, -.29813900E-01, -.10062900E-01, 0.34639400E-02, 0.13156000E+00, -.77396500E-01, -.10339100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11396100E+01, -.10114800E+00, -.87716200E-01, -.14074300E+00, -.20439000E+00, 0.78042600E-01, 0.25148900E+00, 0.17083500E+00, 0.21819600E+00, -.60679700E-01, -.10713000E-01, 0.12836100E+00, 0.95697500E-02, 0.13944100E-02, 0.60520100E+00, 0.43743700E+00, -.42116400E-01, -.43647100E+00, 0.40610200E+00, -.34585100E+00, -.89376200E-01, 0.18286000E+00, -.48205500E-01, 0.42590900E-01, -.45913300E-01, 0.11605400E+00, 0.95013600E-02, 0.27416700E-01, 0.33919800E-01, 0.14236900E+00, 0.14761100E+00, 0.46172600E-01, -.11708900E+00, 0.10935000E-01, 0.43626800E+00, -.90008000E-01, 0.12566600E-01, 0.28460200E-01, -.10721000E+00, -.70363200E-01, 0.34720900E-01, 0.32782800E-01, 0.16347500E-01, 0.50372800E-01, -.38839600E-01, 0.55140500E-02, -.19287600E-01, 0.34855200E-01, 0.62461200E-01, 0.15747900E-01, -.15489700E-01, -.10801200E+00, -.50070200E-01, 0.13277400E+00, 0.16323600E+00, 0.80681000E-02, -.16090500E+01, -.46478700E-01, -.42954500E-01, -.95270400E-01, 0.47718000E-01, -.14210500E-01, 0.85229800E-01, 0.10049900E-01, -.18803800E-01, -.49072600E-01, 0.29900600E-01, 0.59730800E-01, 0.16664100E+00, 0.19091700E-01, 0.10468800E-01, -.38999700E-01, 0.33514700E-02, -.51258000E-02, -.13382700E-01, -.38801000E-01, -.18499100E+00, -.31463000E-01, 0.20793600E-01, -.69911200E-02, -.37598700E-02, 0.62315900E-02, 0.36797800E-02, 0.16227000E-01, 0.26710200E-02, 0.30163500E-02, -.52183000E-01, -.56636000E-01, -.46903100E-02, -.37320400E-02, 0.11228000E-02, -.21290800E-02, 0.70576800E-01, 0.16287000E-01, -.41684000E-02, -.38305300E-02, -.48210200E-02, 0.28109800E-02, 0.21122000E-01, -.58553200E-02, 0.35432000E+00, -.10563300E-01, -.15840700E+00, -.45169800E-02, -.28504300E+00, -.96034800E+00, -.69220600E+00, -.10713900E+01, 0.10312700E+01, 0.36189800E+00, 0.98863400E+00, -.11422900E+01, 0.14036300E+01, -.40757800E-01, -.44910400E+00, -.34047300E+00, -.25138400E+00, 0.42246800E+00, -.39148500E+00, -.38116600E+00, -.44911700E+00, -.19480300E+00, 0.81613300E-01, 0.26159900E+00, -.18239500E+00, -.29681800E+00, 0.33954000E-01, 0.23240700E+00, -.10841200E-01, 0.53164300E-02, -.61204600E-01, 0.59998400E-02, -.11529000E-01, -.14495900E-01, 0.66155000E-01, -.81079300E-01, 0.18894700E-01, -.32354600E-01, -.91344100E-02, -.46214700E-03, -.13902900E-01, 0.13052500E-01, -.10675200E+00, 0.18151600E+00, -.93344400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.24424700E+01, 0.26165900E+00, 0.87063600E+00, 0.46719800E+00, 0.38616700E+00, -.14677000E-01, 0.10594200E+01, 0.17831200E+01, -.79688000E+00, 0.15791000E-01, -.58845700E-01, 0.10314200E+01, 0.43031000E+00, -.31371600E-01, 0.16920000E+00, 0.46546700E+00, 0.34256900E-01, 0.56046400E+00, -.23213700E-01, 0.10647100E+00, 0.15525200E+00, -.81320500E-01, -.20897200E+00, 0.24582600E-01, 0.73498900E-01, -.92426200E-01, -.53159900E-01, -.11484700E+00, 0.26493100E-01, 0.23188600E+00, -.11169200E-01, 0.93157700E-01, 0.13231900E-01, 0.13482400E+00, -.27228900E+01, 0.24214600E+00, -.19368400E+00, -.14927200E+00, 0.29786300E+00, -.10480000E+00, 0.26864200E-02, -.63404200E-01, -.28888100E-01, -.73910800E-01, -.26810800E-01, 0.19252200E-01, 0.95581600E-01, -.33386200E-01, -.30011300E-01, 0.34282600E-02, -.15854100E-01, 0.72853100E-01, 0.26334700E-01, 0.26036400E-01, 0.18203100E+00, 0.46762100E-01, 0.93454500E+00, 0.72815900E-03, 0.15318600E+00, -.15418700E+00, -.45730400E-01, 0.42163900E-01, -.75348500E-01, 0.85597700E-02, 0.81788800E-01, 0.21324000E-01, -.58159800E-01, -.64509600E-01, -.22111600E-02, 0.13329400E-01, 0.20392600E-01, 0.86253000E-01, 0.16129000E+00, -.18244100E-01, 0.71140400E-01, 0.19497100E+00, 0.14764200E-01, -.16607000E-01, 0.78711200E-01, -.10127100E-01, 0.90804200E-02, -.15163300E-01, -.29278400E-01, -.48484800E-01, 0.44319300E-01, -.12752400E-01, -.54701400E-01, -.44089900E-01, 0.41676700E-01, 0.15431100E-01, 0.22814300E+00, 0.61208700E-01, -.20408700E-01, -.36908600E-01, 0.21797500E+00, -.13094300E-01, 0.21053000E-01, 0.64408400E-02, -.21576100E+00, -.12004700E+00, -.92489500E-02, 0.94711000E+00, -.83117400E-01, -.22232400E-01, 0.71454400E+01, -.25785100E+01, 0.34855800E+00, 0.38712000E+00, -.22500400E+01, 0.16677900E+01, -.23169800E+01, 0.70719700E+00, 0.44680400E+01, -.54329600E+01, 0.25385400E+00, -.57634500E+00, -.40879300E+00, 0.17649100E+01, 0.10711400E+01, -.35996500E+00, 0.50603800E+00, 0.50614800E+00, -.20394300E+00, -.26575000E+00, 0.34959100E+00, 0.18552000E+00, -.23560600E+00, -.18389800E+00, 0.66572100E-01, 0.27180400E-01, 0.11135000E+00, -.51356400E-01, 0.20825000E-01, 0.25088800E-01, -.26253500E-01, 0.11165700E-01, -.52767900E-01, 0.75205800E-01, 0.62316100E-01, 0.14746000E-01, -.25470400E-01, -.17256100E-03, 0.22989700E+00, -.73998900E+00, 0.76096600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18674000E+01, 0.74210000E-01, 0.12852100E+01, 0.55869600E+00, 0.57252700E+00, 0.99332800E+00, -.16974300E+00, -.81788200E+00, 0.40873600E+00, 0.75576600E-01, 0.22586700E-01, -.35821900E+00, 0.67250700E+00, 0.51590100E+00, 0.52469500E+00, 0.44381900E+00, 0.25359400E-01, 0.13284800E+00, -.46156900E-01, -.18747200E-01, 0.17883000E+00, -.51394100E+00, -.46498600E-01, -.26433500E-01, 0.11735000E+00, 0.98448300E-01, 0.36296600E-01, 0.18550100E-01, 0.57601800E-01, -.42875300E+00, 0.24010500E+00, 0.16932800E+00, 0.10003400E+00, 0.52201600E-01, 0.43031200E+00, 0.13017900E+00, -.70159500E-01, 0.69810100E-01, 0.14964800E+00, 0.55215400E+00, -.80457000E-01, -.29567400E-01, 0.99785600E-01, 0.19455200E+00, -.32711300E-01, 0.70675100E-01, 0.47202200E+00, 0.11242100E+00, 0.10154100E+00, -.52699100E-01, -.28711000E+00, -.25144900E+00, -.14512100E+00, 0.50077900E-01, 0.47471600E+00, 0.72227400E-01, -.30194400E+01, -.74028300E-01, 0.19918600E+00, -.16819100E+00, 0.16405700E+00, 0.14781500E+00, 0.13737400E+00, -.10957200E-01, -.67546900E-01, -.34515500E+00, 0.72181800E-01, -.78340400E-01, 0.60846700E+00, -.99191500E-01, 0.12808800E+00, -.35661000E+00, -.17881500E+00, -.39594300E-02, -.27137400E+00, -.33679200E+00, -.82133800E+00, 0.15581200E+00, -.25896500E-01, -.93242200E-02, 0.31806100E-01, -.29988400E-01, 0.13536400E-01, 0.15562500E-01, 0.35343800E-01, -.10856400E-01, -.11404300E+00, -.17429300E+00, -.23549600E-01, -.68489900E-02, 0.51902600E+00, 0.80184300E+00, -.68239100E-01, -.54819000E-01, 0.56718200E+00, 0.23037900E+00, -.50226800E-01, -.18490200E-03, -.22313000E+00, 0.21230200E-01, 0.24570600E+00, 0.26752000E-01, 0.13919200E+01, -.54014100E-02, 0.14961800E+02, 0.78167100E+01, -.17165400E+01, 0.16193200E+01, -.62360800E+01, 0.26839200E+01, -.54124500E+01, 0.18055000E+01, -.82219100E+01, 0.41794200E+01, 0.72194200E+00, 0.34129700E+01, -.69128000E+00, -.39664500E+01, -.66046200E+00, 0.31478600E+01, 0.33247100E+01, 0.11077000E+01, 0.62966900E+00, -.69230600E+00, -.45441000E+00, 0.10429800E+01, 0.24744700E+00, -.19030700E+00, -.20841400E+00, -.12943300E+00, 0.26498900E+00, 0.16993500E+00, -.17640900E+00, -.89942400E-01, 0.33205600E-01, 0.13764200E-01, -.40113700E+00, 0.58586300E+00, 0.17727000E-01, 0.40319100E+00, 0.26625300E+00, 0.31225400E-01, 0.72983700E+00, -.49841400E+00, -.39179900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.95805900E+00, -.17227500E+00, -.57173600E+00, -.28052400E+00, -.24558700E+00, -.37192400E+00, 0.17101600E-01, -.30280200E+00, -.28957200E+00, 0.72062600E-01, 0.88180500E-02, -.33513300E+00, -.23952100E+00, -.12930300E+00, -.34354100E+00, -.48543200E+00, 0.28252500E-01, 0.17484700E+00, -.15002800E+00, 0.98054800E-01, -.35050600E-01, -.14320700E+00, 0.77641900E-01, -.57014100E-01, 0.16034500E-01, -.18236200E+00, 0.20669500E-01, -.11756200E-01, -.51172000E-01, -.20847700E+00, -.15190800E-01, -.16639600E-01, 0.47127900E-01, -.86127100E-01, 0.19265500E+01, -.79847100E-01, -.11595000E-01, 0.37932400E-01, 0.14439800E-01, 0.33539100E-02, 0.10426800E-01, 0.10736700E+00, 0.19041200E-01, 0.13949200E+00, 0.10616200E-01, -.71286100E-02, 0.93886300E-02, -.11555000E-01, -.76126300E-02, -.32820600E-01, -.53053300E-01, -.59344700E-02, -.13468600E-01, -.82419400E-01, -.16690000E+00, 0.67367200E-01, 0.16748400E+00, -.57888900E-03, -.83502700E-01, -.77464800E-01, -.90541100E-02, -.76053500E-01, -.11944300E-01, -.37692900E-02, -.45816400E-01, 0.14640100E-01, 0.47035400E-01, -.47025600E-01, -.11908700E+00, -.13055600E-01, -.17995200E-01, -.73240600E-01, -.17577000E+00, 0.44340800E-01, -.46548600E-01, -.12688900E+00, 0.51359200E-01, -.17645600E-03, -.60574000E-01, -.94104800E-02, -.37801600E-02, 0.17083900E-01, -.67241800E-02, 0.50085900E-02, 0.13483500E-01, 0.16298300E-01, 0.41643400E-01, 0.45308500E-01, -.11306700E-01, -.53327300E-02, -.12064200E+00, -.22090400E-02, 0.75840100E-01, 0.43022100E-02, -.38957600E-01, 0.58147200E-02, -.15187300E-01, -.59287400E-02, 0.60965000E-01, 0.76459500E-01, 0.18626400E-01, -.12098300E-01, 0.16414700E+00, 0.24873300E+00, 0.46524300E+00, -.26622400E+01, -.38315500E+00, -.11530900E+01, 0.10101200E+01, 0.33316500E+00, 0.54555200E+00, -.11009900E+01, 0.60825700E+01, -.13382300E+01, -.12831800E+01, -.18812100E+01, 0.67015600E-02, 0.22956300E+01, 0.18914400E+00, -.16827000E+01, -.18333100E+00, -.86294900E+00, 0.15654700E+00, 0.30731400E+00, -.45539700E+00, -.16103700E+00, 0.50803200E-01, 0.20340100E+00, -.18685600E-01, 0.17799100E-02, -.22397400E-01, -.52560000E-01, 0.60212200E-02, 0.38768500E-02, 0.66865800E-02, -.26832000E-01, 0.53661000E-01, -.67674400E-01, 0.21811100E-01, -.56291700E-01, -.26023100E-01, -.64332700E-03, -.50831500E-01, 0.55947400E-01, -.43557300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12084200E+02, 0.21447400E+01, 0.40733000E+01, 0.25148300E+01, 0.19938000E+01, -.24863300E+00, 0.71915400E+01, 0.12177600E+02, -.24529100E+01, -.68385300E-01, -.53784000E+00, 0.57604500E+01, 0.85821300E+00, -.17096700E+01, 0.67635700E+00, 0.28978100E+01, 0.23950800E+00, -.14180600E+00, 0.12044800E+01, -.63785200E+00, 0.83523900E+00, -.26565700E+01, 0.14827700E+00, -.30149000E+00, 0.53696800E+00, -.30266100E-01, 0.81492300E-01, -.36828100E+00, 0.63587000E+00, 0.15428000E+01, 0.13909700E-01, 0.24134000E+01, -.86782900E-01, 0.54365900E+00, -.10184600E+02, 0.14915900E+01, -.14334500E+01, -.11743000E+01, 0.17249200E+01, -.22008900E+01, 0.66600700E+00, -.31930900E+00, 0.26525500E+00, 0.16351500E+01, -.18292300E+01, 0.10602900E+00, -.30988500E+00, -.74433600E+00, 0.10012100E+01, 0.19093500E+00, 0.21536100E+00, -.20627300E+01, -.74624900E+00, 0.21596600E+01, 0.26605500E+01, -.26491800E+00, -.51408100E+01, -.30000800E+00, 0.11164000E+01, -.41216000E+00, -.98797500E-01, 0.45159900E+00, -.22922000E+00, -.14453100E+00, 0.32228000E+01, -.46681800E-01, -.72777300E+00, -.86125900E+00, 0.97561500E+00, 0.25199800E+00, 0.27140200E+00, 0.26299100E-02, 0.76756900E+00, 0.17687300E+00, 0.17679800E+01, 0.25143600E+01, -.13047000E+01, 0.49690200E+00, -.82170700E-01, -.26936300E+00, -.10192300E+00, 0.10955700E+00, -.22862400E+00, -.12685000E+00, -.25254500E+00, -.27164900E+00, 0.44268400E-01, -.22927600E+00, 0.19037000E+00, 0.27420700E+00, -.42237200E+00, -.20278300E+01, 0.56561800E+00, -.60202000E+00, 0.12673600E+01, -.22510000E+01, 0.29797900E-01, -.88211900E-01, -.22222100E+01, -.16327300E+01, 0.10885700E+01, -.72161700E-01, 0.30033200E+00, -.74409700E+00, 0.16074300E+03, -.95131700E+02, -.16762100E+02, -.26336400E+02, -.22304200E+02, 0.41087600E+02, -.34760800E+02, -.20841200E+02, 0.21155900E+03, -.92653700E+02, -.28062000E+02, -.46644300E+02, -.11210300E+02, 0.81605000E+02, 0.12730600E+02, -.39945000E+02, 0.41800400E+01, -.13169400E+02, 0.41289300E+01, 0.60510200E+01, -.10387000E+02, -.18972600E+01, -.30844700E+01, 0.62817200E+01, 0.84111800E-01, -.17270600E+00, 0.11284600E+00, -.85933100E+00, -.25213400E+00, 0.50320000E+00, 0.57105500E+00, -.12488500E+01, -.50784600E+00, 0.46436500E+00, 0.11934400E+01, 0.64020500E-01, -.10765200E+01, 0.12337100E+00, 0.28263300E+01, -.92145600E+01, -.14159100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.21907500E+02, -.27625200E+01, -.65740300E+01, -.39842300E+01, -.35667300E+01, -.14197900E+01, 0.13638600E+01, 0.20345700E+00, -.22640800E+00, -.71907000E+00, 0.43483100E+00, -.13026900E+01, -.41866900E+01, -.99269600E+00, -.21319500E+01, 0.17055900E+00, 0.47201100E-01, -.51962100E+01, 0.35138200E+01, -.34107600E+01, -.12142900E+01, -.94174700E+00, -.71450400E+00, -.12087800E+00, -.10944800E+01, 0.27907100E+01, -.17886500E+00, 0.20651400E+01, -.69378900E+00, 0.19666800E+01, 0.41625200E+01, 0.42833100E+01, -.25237000E+01, 0.14519700E+01, 0.14727000E+02, -.22616100E+01, 0.10760000E+01, 0.74903700E+00, -.29980700E+01, 0.25130600E+01, -.56935300E+00, -.57539900E+00, -.24004500E+00, 0.57061300E+00, -.58204900E+00, -.73250900E-01, 0.66467600E+00, 0.16828300E+00, 0.89599600E+00, 0.21107900E+00, 0.80592000E+00, -.15199700E+01, 0.22030400E+00, -.10962200E+01, 0.50096500E+00, -.25239300E+00, 0.18336500E+02, -.40670600E-01, 0.69041500E+00, -.12214000E+01, -.32943200E+00, -.16750000E+01, 0.86461300E-01, 0.46114300E+00, -.28726900E+00, -.86214100E+00, -.18240900E+01, -.74408200E+00, 0.25242600E+01, 0.59223100E+00, -.33750900E+00, 0.15576000E+01, 0.96314500E+00, 0.42497500E+00, 0.12226400E+01, -.10591100E+00, 0.13238900E+00, -.16777900E+01, 0.14373300E+01, 0.15367400E-03, 0.37075600E+00, -.55165200E+00, -.45008900E+00, 0.78051200E+00, 0.15864700E+01, -.53124500E-01, -.13248200E+01, 0.87499400E+00, -.21294900E+00, -.90557100E+00, -.44520600E+01, -.35512000E+01, 0.46438300E+01, 0.63956200E-01, -.69082500E+01, 0.23166900E+00, 0.74780800E-01, -.10878600E+00, 0.47393000E+01, 0.11445200E+01, -.85398700E+00, -.27606900E+00, -.10327600E+01, 0.21866500E+01, 0.29508500E+00, 0.18803200E+03, 0.45374300E+01, 0.20679000E+02, -.45035600E+01, 0.11426700E+02, 0.28732700E+02, 0.25944100E+02, -.93339400E+02, 0.10400500E+03, 0.10799200E+02, 0.32632400E+02, -.19586700E+02, -.42078400E+02, -.45731400E+01, 0.31547500E+02, 0.21816600E+01, -.22001600E+01, 0.45646400E+01, -.41792400E+00, -.38434300E+01, 0.87606900E+00, 0.13658000E+02, 0.94754300E+00, 0.28617700E+00, -.16855500E+00, 0.11274500E+01, -.36378400E+00, 0.25733600E+00, -.64715500E+00, -.16106100E+00, 0.90318700E+00, 0.21083000E+01, -.39080300E+00, -.28090800E+01, -.10416800E+01, 0.69738900E+00, 0.23500400E-01, 0.21413000E+01, 0.35239800E+01, 0.65367700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.72172700E+01, 0.15010700E+01, 0.34329700E+01, 0.17855400E+01, 0.13015400E+01, 0.19624600E+01, -.19826700E+01, -.94366100E+00, 0.20467100E+01, -.80830900E-01, 0.34613800E-01, 0.97919300E+00, 0.24590400E+01, 0.13531800E+01, 0.64713500E+00, 0.42633300E+01, -.12639700E+00, 0.33473100E-01, 0.34788600E+00, 0.33893100E+00, 0.10853600E+01, 0.51470200E+00, -.57414800E+00, 0.26865500E+00, -.16701400E+00, 0.15515700E+00, -.14274300E+00, 0.20249800E+00, -.37931800E-01, -.11535900E+00, -.75697700E-01, -.40811200E+00, 0.22773200E+00, -.30732300E+00, -.65223000E+01, 0.58466400E+00, -.34164900E-01, -.90650700E-01, 0.33279600E+00, -.76471600E-03, -.62832400E-01, -.33602000E+00, -.13233500E-01, -.75633100E+00, -.40209300E+00, -.12585800E+00, -.75372300E+00, -.65101500E+00, -.41282400E+00, -.17864600E-01, -.67847400E+00, 0.12124100E+01, 0.37526200E+00, -.41675200E+00, -.26730900E+01, -.21109000E+00, 0.53799700E+00, 0.27174400E+00, -.30860700E-01, -.10334100E+01, 0.53284300E+00, 0.95777900E+00, -.34493000E+00, 0.11029100E+00, -.25921900E+01, -.19667100E+00, 0.82056700E+00, 0.80952500E+00, -.70753500E+00, -.17403200E+00, -.63369800E+00, -.71204900E+00, 0.48246200E+00, -.50419300E+00, -.11189100E+01, 0.26436700E+00, -.22048800E+00, 0.87967300E+00, -.76076000E+00, 0.14071900E+00, 0.32931600E+00, -.15423700E+00, 0.22428200E-01, 0.43609000E+00, -.69731100E+00, -.14415100E+00, 0.38877300E+00, 0.38208200E+00, -.11016600E+00, -.74396500E-01, 0.20967800E+01, 0.65991000E+00, 0.10898500E+00, -.13697400E+01, 0.13718800E+01, -.12689800E+00, -.82930900E-01, -.34889100E+00, -.25276000E+01, -.10360600E+01, -.17945900E+00, 0.70026000E-01, 0.41889300E+00, -.27463900E+00, 0.12169400E+00, -.24233200E-02, 0.27266300E+02, 0.43881300E+02, -.38826500E+02, -.15754400E+02, -.36286600E+02, 0.46238200E+02, -.33879300E+02, -.22029200E+02, 0.15240900E+02, 0.11119400E+02, 0.82943700E+01, -.57392900E+01, 0.16988000E+02, 0.12201100E+02, 0.78166000E+01, 0.22018600E+02, -.25903000E+01, -.51962200E+01, 0.43274800E+01, 0.63401000E+01, -.13770400E+01, -.42277500E+01, -.55995900E+00, -.41553500E+00, 0.28774100E+01, -.17018300E+01, -.71123700E-01, 0.69570200E+00, 0.42697400E+00, -.19923300E-01, 0.38563500E+00, -.20475300E+00, 0.15299200E+01, -.46258700E+00, -.57474000E+00, -.23519800E-01, 0.40903800E+01, -.81445200E+01, 0.24576100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.36673400E+01, -.65878000E+00, -.19781100E+01, -.10357400E+01, -.87327500E+00, -.11909600E+01, 0.14039400E+00, -.53751600E-01, -.15928500E+01, 0.17181900E-01, 0.44175600E-01, -.29041000E+00, -.17122900E+01, -.12385800E+01, -.84674300E+00, -.20482800E+01, -.45148600E-02, 0.80249800E-01, 0.95800900E-01, -.11275400E+00, -.53729700E+00, -.14113400E+00, 0.21000500E+00, -.13344200E+00, -.60986100E-01, -.96154900E+00, 0.56547500E-01, -.35874900E+00, 0.28777600E-01, -.41517500E+00, -.22881300E-02, -.33570200E+00, 0.20401900E+00, -.31065100E+00, 0.88043200E+01, -.37051700E+00, -.19076300E+00, 0.48121600E-01, 0.60971200E+00, -.11840500E+01, 0.28110300E+00, 0.55006300E+00, -.16612900E-01, 0.95238300E+00, 0.97941200E-01, -.42480200E-01, 0.90766200E-02, 0.42380500E-01, -.54565600E-01, -.24207100E-01, 0.13416900E+00, 0.13839100E+00, 0.10308900E+00, -.27773000E-01, 0.41691500E-01, 0.86443700E-01, 0.16766000E+01, 0.13355900E-01, 0.52096900E-01, 0.17736500E+00, -.10152100E+00, -.12106000E+00, -.17785800E+00, 0.79891800E-01, -.55152500E-01, -.38749800E-02, -.26329600E-01, -.46785100E-01, 0.59288600E+00, 0.45662700E-01, -.40611600E-01, 0.47557700E+00, -.13792800E+00, 0.16580700E+00, 0.44530400E+00, 0.76556300E-01, -.80625800E-01, -.90167400E-01, 0.21274700E-01, 0.63571900E-01, -.49704900E-01, 0.27404900E-01, 0.76538300E-01, 0.68654700E-02, -.24702200E+00, 0.37478300E-01, -.31302200E-01, 0.45092500E-01, -.82279700E-01, 0.81191400E-01, -.39316300E+00, -.11284600E+01, 0.11112000E+01, 0.15501300E+00, -.11116500E+01, -.55860200E+00, 0.11010900E+00, -.16466400E-01, 0.47971400E+00, 0.77108300E-01, 0.21111400E-01, 0.11602000E-01, -.18535200E+01, 0.17600400E+00, 0.18910700E+00, 0.17352700E+00, -.13102300E+00, 0.90633000E+01, -.12058400E+02, -.64826400E+01, -.16409900E+02, 0.77972100E+01, -.14635000E+02, -.11458500E+02, 0.10907400E+01, 0.51717000E+01, 0.16352000E+01, -.55624000E+01, -.22568800E+01, 0.38564200E+01, 0.21336800E+01, 0.11473100E+02, 0.60251600E+00, -.74432700E+00, 0.12208500E+01, 0.75495800E+00, -.22260100E+01, 0.19857300E-01, -.47606400E-01, 0.16078000E+00, 0.42863200E+00, 0.19829600E+00, -.57179500E-01, -.10729700E-01, 0.38318200E+00, -.43987700E+00, -.73570900E+00, 0.74754000E+00, 0.88487800E-01, 0.67129400E+00, 0.27251500E+00, 0.80396100E-01, 0.14355800E+01, -.73010300E+00, 0.18205100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.27961200E+01, -.63608500E+00, -.15272800E+01, -.76683300E+00, -.52422000E+00, -.10003200E+01, 0.10072000E+01, 0.13911400E+01, -.14437600E+01, -.15801900E-01, -.46835300E-01, 0.67425700E+00, -.14496200E+01, -.15986300E+01, -.45902400E+00, -.97603600E+00, 0.32510900E-01, -.41711400E+00, 0.33971000E+00, -.31561500E+00, -.31776600E+00, -.56679300E+00, 0.16710800E+00, -.20272700E+00, -.17932000E+00, -.25139900E+00, 0.70828400E-01, -.15409300E+00, 0.28062600E+00, 0.65919700E+00, -.44112600E+00, -.58405600E+00, -.77440100E-01, -.63879000E-01, 0.18514300E+01, -.23567700E+00, -.12552700E+00, -.23467900E+00, 0.31033400E+00, -.61759600E+00, 0.21525600E+00, 0.18715800E+00, -.89378700E-01, 0.46317100E+00, -.28562000E+00, 0.28143500E-01, -.20216300E+00, -.15835000E+00, 0.61249900E-01, 0.74640300E-02, -.49181200E+00, -.52850300E+00, -.34018100E+00, 0.34492900E+00, 0.24488800E+00, 0.11045700E+00, -.39927500E+01, -.20052600E+00, 0.40159500E+00, 0.47395400E+00, 0.18347300E+00, 0.72577000E-01, 0.40238800E+00, -.18280900E-01, 0.15033600E-01, -.12669400E+00, 0.54811000E-01, 0.34233400E+00, -.29677100E+00, 0.38896900E-01, 0.11296200E+00, 0.10593000E+00, 0.42467100E+00, -.12717400E+00, 0.12182800E+00, 0.12093700E+00, -.31564500E+00, 0.16869400E+00, 0.10159500E+00, 0.21816200E-02, -.70785400E-01, -.27673500E-01, -.51263300E-01, -.11505300E+00, -.72276800E-01, -.82747800E-01, 0.25938200E+00, 0.38752100E+00, 0.11606300E+00, -.32844100E-01, -.38048700E+00, -.72753500E+00, 0.63297300E+00, -.18150300E-01, -.80156600E+00, -.19436900E+00, 0.42163500E-01, -.39024000E-02, 0.40391900E+00, 0.19408100E+00, -.22517900E-01, -.11713200E-02, -.53988300E+00, 0.76332300E-01, 0.88455500E-01, 0.10835300E+00, 0.32002600E-01, -.50061000E+00, -.42445200E+01, -.27867200E+01, -.75301700E+01, -.20610200E+01, -.15217100E+02, 0.49620900E+01, 0.42666000E+01, 0.65403900E+01, -.19367400E+01, -.74064400E+01, -.51538000E+01, 0.55820600E+01, 0.91498600E+01, 0.97940600E+01, -.10934500E+01, -.32552400E+01, 0.99772300E+00, 0.26833800E+01, -.20959400E+01, -.23833900E+01, 0.55455300E-01, 0.21560400E+00, 0.44944000E+00, 0.30443600E+00, -.22682800E-02, -.97401500E-01, 0.21635300E+00, -.11169300E+00, -.45918700E+00, 0.42274700E+00, -.73999300E-01, 0.44570600E+00, 0.26412900E+00, 0.66845300E-01, 0.50303200E+00, -.72849600E+00, 0.43924400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10202400E+02, 0.42360100E+00, 0.36005300E+01, 0.17800300E+01, 0.17721500E+01, -.19898600E+00, 0.42413700E+01, 0.71412200E+01, 0.19418400E+01, -.97845800E+00, -.26401600E+00, 0.80300600E+00, 0.35798300E+01, 0.60382700E+00, 0.65468800E+01, 0.11325800E+00, 0.35639800E-01, 0.27509100E+01, 0.10626100E+01, -.53615400E+00, -.85111300E+00, -.24667700E+01, -.26811100E+01, 0.13086200E+00, -.70924900E+00, 0.67046400E+00, 0.18370700E+00, -.48693700E+00, 0.15406000E+01, 0.13050600E+01, 0.26043300E+00, 0.55986900E+00, -.33322900E+00, 0.39539800E+00, -.32166800E+01, 0.57505500E+00, -.37640100E+00, -.34882000E+00, 0.27044100E+00, -.73334700E+00, 0.88834900E-01, -.41045300E-01, -.18696900E+00, 0.11580700E+00, -.40294300E-01, -.28923700E+00, -.21996600E+00, -.57254700E+00, -.80243000E+00, -.42348100E+00, -.67441200E+00, 0.66521500E+00, -.18665900E+00, -.23883200E+01, -.31225300E+01, 0.11449800E+00, 0.25050900E+02, 0.39676500E+00, 0.62477900E+00, -.16630400E+01, -.17298400E+00, 0.58835900E+00, 0.20020800E-01, -.25008800E+00, 0.11828000E+01, 0.15345800E+01, 0.63554500E+00, -.65129000E+00, 0.71724300E+00, 0.35545900E+00, 0.34721400E+00, -.60127400E+00, -.14673100E+01, 0.65909100E-01, -.67707600E+00, -.21091800E+00, -.19293700E+00, 0.73619800E+00, -.89656300E+00, 0.53353100E-01, -.13760500E+00, 0.39421700E+00, 0.21216200E+00, -.66095600E+00, -.33899400E+00, 0.78100100E+00, 0.11897400E+01, 0.56343000E+00, 0.23398400E+00, -.13127900E+00, -.10095900E+01, 0.26244300E+00, 0.77792700E-01, -.36948700E+00, -.19099300E+00, 0.54068600E+00, -.20699200E-01, 0.27612000E+00, 0.69569100E+00, 0.41553200E+00, 0.15345600E-01, 0.14089200E+00, 0.82485000E+00, -.91773100E-01, 0.11383700E-01, -.24014600E+00, -.19401500E+00, -.93971400E+00, 0.11210700E+01, 0.17148000E+02, 0.25933100E+02, -.48689600E+00, -.25474600E+02, -.16347100E+02, 0.95925300E+00, 0.63151500E+01, -.11500600E+01, -.56100900E+01, 0.23746300E+01, 0.33952900E+01, -.17094400E+02, -.67893000E+01, -.77441800E+00, 0.41991900E+01, 0.42278200E+01, -.54834000E+01, 0.41469100E+00, 0.34202500E+01, 0.85280200E-02, -.24351000E+00, 0.91276200E+00, -.11084400E+01, 0.26995400E+00, -.36418100E+00, -.33646800E+00, -.26967200E+00, 0.53570700E+00, -.70318200E+00, -.11763700E+01, -.36806600E+00, 0.14104800E-01, -.11040400E+00, -.25254800E+01, 0.22567600E+01, -.10140200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.82726600E+01, 0.10112600E+01, 0.29019900E+01, 0.16005900E+01, 0.13136500E+01, -.10134300E+00, 0.36415100E+01, 0.62619900E+01, -.26044000E+01, 0.20088500E+00, -.27795800E+00, 0.30894200E+01, 0.15166100E+01, 0.84809800E-01, -.48482800E+00, 0.88680800E+00, 0.15934900E+00, 0.16945700E+01, -.73353000E+00, 0.88816900E+00, 0.79374400E+00, 0.28693800E+00, -.22366300E-01, -.18135100E-01, 0.39254300E+00, 0.28654100E+00, -.16712400E+00, -.88747900E-01, -.24649700E+00, 0.17245600E+00, -.39985200E+00, 0.40109500E+00, -.98753200E-01, 0.36996700E+00, -.14694500E+02, 0.15788600E+01, -.46707300E+00, -.22558800E+00, 0.10086500E+01, -.11672300E+00, -.18470300E+00, -.55064700E+00, 0.31569100E-01, -.28562500E+00, -.74370100E+00, 0.16393900E+00, -.16194900E-01, -.71299900E+00, -.24373700E+00, -.19536900E+00, -.13566400E+01, -.68710200E+00, -.41435800E+00, -.16034700E+01, 0.14814200E+01, 0.84314800E+00, -.12335300E+02, -.20172200E+00, 0.19449600E+00, -.14664000E+01, 0.12071300E+00, 0.60855600E+00, 0.15458300E+00, -.10274600E+00, 0.17158200E+00, -.20175900E+00, -.70429900E-01, -.18575900E-01, 0.14047000E+00, 0.11811200E+00, 0.67467300E-01, 0.72434800E+00, 0.15993400E+01, -.50445400E+00, -.23184700E+00, 0.64290700E+00, 0.12857300E+01, -.26661600E+00, 0.16815600E+01, 0.55170500E-01, -.28447700E-01, 0.51900400E-01, -.26803800E+00, -.18969600E+00, 0.89983500E+00, -.39125600E+00, -.11036000E+01, -.11813200E+01, 0.38445100E+00, 0.14407000E+00, 0.10629000E+01, 0.40382700E+00, -.30017100E+01, 0.27492000E+00, 0.27090200E+01, -.12584000E+01, 0.51433600E-01, 0.99166900E-01, -.20616800E+01, -.85686900E+00, 0.20451700E+00, -.12555400E+00, 0.61898400E+00, -.10737900E+01, 0.13228000E-01, -.30654000E+00, -.14417800E+00, -.12832200E+01, -.42708200E+00, -.49305900E+00, -.14720600E+02, -.13126500E+01, -.20683800E+01, -.56937100E+02, -.40154200E-01, 0.68416300E+01, -.56947000E+01, -.17515200E+01, -.18477500E+00, 0.52517700E+01, -.11684400E+01, 0.40165100E+01, 0.80674900E-01, 0.27602700E+01, -.11439700E+01, -.34563400E+01, -.73042600E+01, 0.33878600E+01, 0.26266400E+00, -.98789400E-01, -.34522200E+00, 0.11489300E+01, -.53511300E-01, 0.11020700E+00, -.13700800E-01, -.39183300E+00, -.51875500E-01, 0.36836800E+00, -.40355000E-01, 0.11978500E+00, 0.45534300E-01, -.88409200E-02, 0.10282700E+01, -.16226300E+01, -.77766900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17660100E+02, 0.29974800E+01, 0.57010600E+01, 0.31568800E+01, 0.23735800E+01, 0.24717500E+01, -.10994900E+02, -.12849200E+02, 0.58919600E+01, 0.84667800E+00, 0.43343100E-01, -.63221400E+01, 0.12569300E+01, 0.26212400E+01, -.53584700E+01, -.58961000E+01, -.10405200E+00, 0.30594600E+01, -.65262000E+01, 0.56336600E+01, 0.13411900E+01, 0.50441800E+01, 0.38571900E+01, -.15963300E-01, 0.16564000E+01, -.58969900E+00, -.29898500E+00, -.35737100E+00, -.29307800E+01, -.22740400E+01, -.37941700E+01, -.16846200E+01, 0.10782700E+01, -.95699900E+00, -.19480200E+02, 0.80476600E+00, 0.15431400E+01, 0.50199100E-01, -.49037800E+00, 0.27962500E+01, -.61403900E+00, -.12696800E+01, -.82320700E+00, -.64845500E+00, 0.24581200E+00, -.19681100E+00, 0.94330000E-01, -.12203800E+00, -.93920400E+00, -.32904300E+00, 0.43245000E+00, 0.85012900E+00, 0.62031100E+00, -.72799500E+00, -.14263300E+01, -.21551400E+00, 0.96015900E+01, 0.51275300E+00, -.11524800E+01, -.10653500E+01, -.73558300E+00, -.11787100E+01, -.15387600E+01, 0.27103600E+00, -.46667700E+01, 0.12423800E+01, -.11298400E+01, 0.17236100E+01, -.74264700E+01, 0.73591400E+00, 0.48848800E+00, 0.12014500E+01, 0.12311400E+01, 0.47515600E-01, -.20529900E+01, -.10584600E+01, 0.33448000E+01, -.31175900E+01, 0.20251800E+01, 0.21080000E+00, 0.31977700E+00, -.39814000E+00, 0.12747300E+00, 0.27472000E+00, 0.78591400E-01, -.41195700E+00, -.27130200E+01, -.15321900E+01, 0.45300300E-01, 0.40385000E+00, 0.42859400E+01, 0.15895100E+01, -.20667600E+01, -.28862100E+00, 0.27805000E+01, 0.72960600E+00, 0.36449600E+00, -.32479000E+00, -.26834700E+01, -.44818200E+00, -.40626700E-01, 0.46694300E-01, -.95113200E+00, 0.56334200E+00, -.11231100E+00, 0.42115100E+00, 0.63519100E+00, 0.13464800E+01, 0.43376400E+00, -.16416500E+00, 0.49890400E+00, 0.33185700E+01, 0.86602700E+02, 0.17198200E+02, -.70958700E+01, -.23787100E+02, -.65354600E+01, 0.32453400E+02, -.59518200E+01, -.21713300E+02, -.23318200E+02, 0.73363900E+01, 0.33738700E+01, 0.35175200E+01, 0.63630400E+01, -.22227600E+01, 0.65897900E+01, 0.22199600E+01, 0.12174400E+01, 0.18747700E+00, -.35471800E+01, 0.28862900E+00, -.35552600E+00, 0.34240900E+00, -.52239400E+00, 0.31913600E+00, -.13873600E+01, 0.11057100E+01, 0.16122700E+01, 0.10702700E+01, 0.10008300E+00, 0.11193100E+00, -.14449000E+01, 0.27225100E+01, 0.78227700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.45464700E+01, 0.98295200E+00, 0.21769600E+01, 0.10529400E+01, 0.73207800E+00, 0.12683100E+01, -.19391600E+01, -.70281700E-03, 0.88932500E+00, -.25232800E+00, 0.32380300E-01, 0.15282000E+01, 0.13688000E+01, 0.47072400E+00, 0.35434200E+00, 0.22925100E+01, -.26726200E+00, -.55821900E+00, 0.31460000E+00, 0.35108700E+00, 0.62341700E+00, 0.14856900E+01, -.56703400E+00, 0.34678500E+00, -.34776000E+00, -.19568100E+00, -.24805400E+00, -.26699200E+00, 0.46168900E-01, -.27168100E+00, -.14156000E+00, -.10474100E+01, 0.41736200E+00, -.20272400E+00, 0.12063400E+01, -.39608100E-01, 0.37719300E+00, 0.11620100E+00, 0.56773300E+00, 0.37204100E+00, -.19644600E+00, -.32641400E+00, -.19544900E+00, -.33555100E+00, -.40231200E+00, -.10197300E+00, -.11742600E+01, -.65309500E+00, -.34324200E+00, 0.58211900E-01, -.35782100E+00, 0.95707700E+00, 0.36177700E+00, -.19854300E+00, -.17013200E+01, 0.17207800E+00, 0.12144000E+01, 0.70856200E-01, 0.35964800E+00, -.98691700E+00, 0.73701200E-01, 0.20771600E+00, -.84469600E+00, 0.11469500E+00, -.10681200E+01, 0.40091100E+00, 0.84092600E+00, 0.72035500E-01, -.64108100E+00, 0.19751200E+00, -.13064800E-01, 0.38139900E+00, -.78320900E-01, 0.77077400E-01, 0.25071700E+00, 0.41398800E+00, 0.76110600E+00, -.19781500E+00, 0.11150300E-01, -.28224000E-01, 0.22715200E-01, 0.79655300E-01, 0.69968900E-02, -.12797300E+00, -.42027700E-01, -.75944900E-01, 0.16300000E+00, 0.30744400E+00, -.69046500E-01, -.70329800E-01, -.52627000E+00, -.79282700E+00, -.61417500E+00, 0.25300700E+00, -.51510100E+00, -.59009100E+00, 0.32094800E-01, 0.38040600E-01, 0.51366000E+00, 0.93703600E-01, -.57497400E-02, -.11907500E+00, -.19261400E-01, -.44632600E-01, -.47888700E-01, -.10422700E+00, -.29553300E+00, -.21831400E+00, 0.35343800E+00, -.18153100E-01, 0.68351000E-01, -.34687700E-01, 0.34991500E+02, -.16332800E+02, -.54920200E+01, -.82375200E+01, -.39749800E+01, 0.14673900E+02, 0.24493800E+01, -.75739100E+01, 0.33001700E+01, -.10330200E+02, -.42079900E+00, 0.43179000E+00, -.22792700E+01, 0.27954300E+01, 0.46502100E+01, -.30703600E+00, 0.50387400E-01, -.46635100E-01, -.21679600E+00, -.64272100E-01, 0.10181500E-02, 0.17913600E+00, -.32618600E-01, -.26516200E+00, 0.64819800E+00, -.76462700E+00, 0.16870100E+00, -.62710700E+00, -.18008400E+00, -.58212500E-02, -.16710800E+00, 0.41028100E+00, -.44080500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.64596700E+01, 0.13970100E+01, 0.32742700E+01, 0.16560800E+01, 0.12540900E+01, 0.19975000E+01, -.16952600E+01, 0.11558600E+01, 0.13392300E+01, -.37805400E+00, -.12133400E-01, 0.19219400E+01, 0.11506700E+01, 0.22449100E+00, 0.23993100E+00, 0.28385800E+01, -.28748400E+00, -.15421900E+01, 0.81278400E+00, 0.65608900E-01, 0.65953100E+00, 0.16284500E+01, -.20889100E+00, 0.37176600E+00, -.36699200E+00, 0.25759200E+00, -.15725600E+00, 0.41693800E-01, 0.96499600E-01, -.18817300E+00, 0.13887300E+00, -.11306100E+01, 0.47415400E+00, -.37628400E+00, -.22209400E+01, 0.15339000E+00, 0.20112800E+00, -.27483800E-01, 0.52864600E+00, 0.16401600E+00, -.84451200E-01, -.33688100E+00, -.16966600E+00, -.78309300E+00, -.42142000E+00, -.20481300E+00, -.85862900E+00, -.86427100E+00, -.49229000E+00, 0.12027800E-01, -.85735000E+00, 0.10915300E+01, 0.27512100E+00, -.10654800E+00, -.23670200E+01, -.88528400E-01, -.26881900E+01, 0.19077800E+00, -.11326200E+00, -.68308600E+00, 0.50236800E+00, 0.10308900E+01, -.38165400E+00, 0.12101500E-01, -.20956400E+01, -.54850000E+00, 0.48128500E+00, 0.10047200E+01, -.15733800E+00, 0.15669200E+00, -.40567100E+00, 0.14046100E+01, 0.12377600E+01, -.25096200E+00, 0.21432300E+00, 0.81751800E+00, -.11254600E+01, 0.13932100E+00, 0.22300400E+00, -.46100600E-01, 0.20437400E+00, -.22779700E+00, 0.29225400E-01, 0.56898300E+00, -.47829100E+00, 0.64994600E-01, -.86943900E+00, -.43079400E+00, -.75015100E-01, -.22076500E+00, 0.26649400E+01, 0.78886400E+00, -.43153700E+00, -.67517100E+00, 0.58808900E+00, 0.34695000E+00, 0.33118300E-01, -.28983400E+00, -.18285200E+01, -.11965500E+01, -.49121300E+00, 0.82696400E-01, 0.42264600E+00, -.37499900E+00, -.22300000E+00, -.81330200E-01, 0.83494000E+00, -.21312000E+00, -.10491300E+01, -.37843400E+00, 0.52875600E+00, -.14160100E+00, -.72180500E+00, 0.29212800E+02, 0.49506900E+01, 0.46419200E+01, -.66485200E+01, 0.66344700E+00, -.54564700E+01, 0.48388700E+01, -.81529200E+01, -.23013000E+01, 0.13830100E+01, 0.30929700E+01, -.46481700E+00, -.10190200E+01, 0.51891200E+01, 0.22545100E+01, 0.62459600E+00, 0.29879600E+00, -.14316900E+01, 0.65236100E+00, 0.23050900E+00, -.22670600E-01, -.14548500E+00, 0.11425000E+00, 0.26679300E+00, -.83653200E+00, -.42705600E+00, -.35839500E+00, 0.34677600E+00, 0.95353400E-01, -.94379600E+00, 0.81681300E+00, -.13625200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.25907200E+01, 0.82634600E+00, 0.13367800E+00, 0.56143100E+00, 0.38479000E+00, -.29910300E+00, -.12460400E+01, -.49877900E+00, -.49980200E+00, 0.18899600E+00, -.88213100E-01, -.62146900E+00, -.43328600E+00, -.21756300E+00, -.11345800E+01, -.28740800E+01, -.37463100E-01, 0.11845700E+01, -.13679600E+01, 0.12929300E+01, -.21119500E+00, 0.85332800E+00, 0.65661300E+00, -.33576800E-01, 0.12429100E+00, -.20271800E+00, -.44129700E-01, -.33207300E+00, -.30857900E+00, -.30069500E+00, -.11030400E+01, -.35312400E+00, 0.26370500E+00, -.68449300E-01, -.40537000E+01, 0.59289300E+00, -.14199000E+00, 0.11181000E+00, 0.49551000E+00, 0.25157900E+00, -.87345000E-01, -.30983100E-01, -.29456900E+00, -.18559600E+00, 0.16531100E+00, -.85009700E-01, 0.70881300E-01, -.19150500E+00, -.27798200E+00, -.41514000E-01, -.19469200E+00, 0.33267000E+00, 0.83358800E-02, -.23760900E+00, -.57032300E+00, 0.33716200E+00, 0.22158100E+01, 0.34219200E-01, -.30591600E-01, -.26900800E+00, -.18196700E+00, 0.26467500E-01, -.39825000E+00, 0.57720900E-01, -.10904600E+01, 0.35869900E+00, 0.17935500E-02, 0.42133200E+00, -.59175300E+00, 0.19069700E+00, -.75758500E-01, 0.10763800E+01, 0.19838800E+00, 0.10375800E+00, 0.32241400E+00, 0.71611700E-01, 0.94472800E+00, -.12800900E+00, 0.22862500E+00, 0.24084800E-01, -.51988100E-01, 0.52568600E-02, 0.30923000E-01, 0.22596400E-01, -.11762500E+00, 0.36151600E-01, -.20823400E+00, -.19020300E+00, -.14693500E+00, 0.99524100E-01, 0.67082600E+00, 0.23110800E+00, -.74007100E+00, 0.22200700E+00, -.47166400E-01, -.11371400E+00, 0.69603900E-01, -.10181500E-01, 0.67856200E-02, -.11534400E+00, -.17723200E+00, -.11966000E-01, -.89398500E+00, -.55329300E-01, 0.15046100E-01, 0.35058900E-01, -.18806000E-01, 0.29335300E+00, -.16692000E-01, -.16322400E+00, 0.21928700E+00, -.10674700E-01, -.28330800E+00, 0.22921000E+00, -.50842700E+01, -.57923200E+01, 0.72899100E+01, 0.28753800E+01, 0.37860100E+01, -.55347200E+01, -.26753500E+01, -.11803100E+02, 0.39702300E+00, 0.14814300E+01, -.15132900E+01, -.30395600E+00, 0.21316800E+01, 0.48941100E+00, -.10571800E+00, -.46123100E-01, -.37134000E+00, 0.27562600E+00, 0.20669700E-02, 0.61248000E-01, -.14956100E+00, -.85497500E-01, 0.89374400E-01, -.13753000E+00, 0.72486400E-01, -.17376300E+00, -.18968500E-01, -.45884600E-01, -.27816500E+00, 0.18602900E+01, -.65295300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.59058700E+01, 0.12066400E+01, 0.29198700E+01, 0.11765600E+01, 0.95732400E+00, 0.13185200E+01, -.26498100E+01, -.21222800E+01, 0.14357200E+01, 0.60722900E-01, 0.46319900E-01, -.63701000E+00, 0.12668100E+01, 0.81260900E+00, -.59956700E+00, 0.56060400E+00, -.11051100E+00, 0.62816100E+00, -.62875600E+00, 0.10591800E+01, 0.58907200E+00, 0.11370400E+01, 0.28016300E+00, 0.15498400E+00, 0.13750700E+00, -.19507400E+00, -.11299500E+00, -.79212700E-01, -.28072000E+00, -.87180000E+00, -.13682000E+00, 0.58195100E-01, 0.55069000E+00, -.33950600E+00, -.29390500E+01, 0.32340400E+00, -.18022400E+00, -.24179200E+00, 0.62260200E+00, 0.68107200E+00, -.13492400E+00, -.18798000E+00, -.34139100E+00, -.66262300E+00, -.17894600E+00, -.19841800E+00, -.31978300E+00, -.71351000E+00, -.39349700E+00, 0.88132000E-01, -.66430400E+00, 0.80019800E+00, 0.12967500E+00, -.13153700E+00, -.18930800E+01, -.50445100E-01, 0.78723500E+01, 0.30509500E+00, 0.47590200E+00, 0.42840800E+00, -.11304200E+00, 0.59342700E+00, -.81719000E+00, -.26764100E-01, -.21149200E+00, -.10211300E-01, -.18047600E+00, 0.17382200E+00, -.72818400E+00, 0.26680600E+00, -.45329900E-01, 0.18196800E+01, 0.13987400E+01, -.77222100E-01, 0.50758700E+00, 0.95175300E+00, -.58312600E+00, -.47615200E-01, 0.16875500E+00, 0.21771800E-01, 0.71084300E-01, -.71778300E-01, 0.16055200E+00, -.72426600E-02, -.17076500E+00, 0.52380000E+00, -.18290500E+00, 0.49368200E+00, -.16097400E+00, -.45007500E-01, 0.89295800E+00, -.15375100E+01, 0.96083100E+00, -.41381100E+00, -.19610900E+01, -.48526100E+00, 0.17732400E+00, -.60429400E-01, 0.19564400E+00, -.10475600E+01, -.59746300E+00, 0.18149500E+00, 0.36731700E+00, -.96064100E+00, -.12082300E+00, -.14258800E+00, 0.20083100E+00, -.31618000E+00, -.11891500E+00, -.69969700E-01, 0.29777300E+00, -.77802400E-01, -.29575900E+00, 0.50250200E+00, -.67008300E+00, -.41866600E+01, 0.31270300E+01, 0.14404700E+01, 0.20921000E+01, -.39324800E+01, -.11412800E+02, -.39209200E+01, -.19677400E+01, 0.15493100E+01, 0.39998900E+01, -.17163900E+01, 0.43796100E+01, 0.76446500E+00, 0.49018400E+00, 0.38704700E+00, -.71955400E+00, 0.58035600E+00, 0.69134800E+00, 0.47946600E-01, -.19503800E+00, 0.17696800E+00, 0.14900600E+01, -.12385500E+01, -.80120200E+00, -.11873700E+01, -.10680400E+00, -.61713300E-01, -.74239500E+00, 0.18478800E+01, -.62615900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.25965200E+02, -.22266100E+01, -.99887000E+01, -.49573900E+01, -.47339400E+01, -.45832200E+01, 0.11357400E+02, 0.12007300E+02, -.68230000E+01, -.29021600E+00, -.17404900E+00, 0.20921700E+01, -.72976100E+01, -.59104000E+01, -.15965400E+01, -.35030200E+01, 0.92012800E+00, -.34670600E+01, 0.34923800E+01, -.44563000E+01, -.19503700E+01, -.74644500E+01, 0.90731000E+00, -.15938100E+01, -.33299700E+00, 0.16300500E+01, 0.78630300E+00, 0.17684100E+01, 0.16237300E+01, 0.48418500E+01, 0.16694100E+01, 0.32931600E+01, -.24707700E+01, 0.18649900E+01, 0.15982200E+02, -.22856900E+01, -.19018300E+01, -.28744000E+00, -.25748700E+01, -.32307400E+01, 0.90430400E+00, 0.14403300E+01, 0.63427500E+00, -.11890900E+01, 0.26921900E+01, -.93518600E-01, 0.25862800E+01, 0.18195900E+01, 0.11073800E-01, -.19038300E+00, 0.67230600E+00, -.88016200E-01, -.12339500E+01, -.18596700E+01, -.13921500E+00, -.33401200E+00, 0.26127000E+02, 0.54238600E+00, -.14964600E+01, 0.34612400E+01, -.93924000E+00, 0.23279000E+00, 0.19235300E+01, -.11669500E+01, 0.20604100E+01, 0.12436400E+01, -.15170300E+01, -.13478100E+01, -.12371800E+00, -.11331800E+01, -.13355800E+01, 0.19733700E+01, -.24126500E+01, -.17049500E+00, -.45840200E+01, -.49140000E+01, 0.14000100E+01, 0.14146500E+01, -.19498400E+01, 0.89900300E+00, 0.11377300E+00, 0.16443300E-02, 0.45391600E+00, -.65485000E-01, 0.12021800E+01, 0.11828200E+01, 0.23714100E+01, 0.14161400E+01, -.77997500E+00, 0.81009700E+00, 0.13312500E+01, 0.55111700E+01, 0.44249100E+01, -.22636800E+01, -.67757200E+00, 0.45263600E+01, -.55863800E+00, 0.36091600E+00, 0.22172400E+01, 0.49542400E+00, 0.26255900E+00, 0.29936100E+00, -.36744400E+00, 0.72520100E-01, 0.72403100E+00, 0.16724700E+00, 0.46849000E+00, 0.31292700E+01, -.39468100E+00, 0.13138400E+01, -.24777800E+01, -.54737200E+00, -.37609000E+01, -.13091800E+01, -.30617900E-01, 0.13573200E+01, -.15423500E+02, -.11504800E+02, -.38240400E+01, -.16499000E+01, 0.32883600E+01, -.25080000E+02, -.20425200E+01, -.22561400E+01, 0.49091600E+00, 0.64880100E+01, 0.73841600E+01, -.33807000E+01, -.40786400E+00, -.14231100E+01, -.22607900E+01, 0.14642600E+01, -.83790400E+00, -.93111900E-01, -.10126200E+01, 0.58368700E+00, -.15222600E+01, 0.77344300E-01, -.26843600E+00, 0.78248500E+00, 0.44125800E-01, -.19926500E+00, -.20362800E+01, 0.48887400E+01, -.15880400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.39321000E+01, -.44786700E+00, -.21866000E+01, -.11594900E+01, -.12917300E+01, -.12512000E+01, -.12025300E+01, -.22091200E+01, -.41841800E+01, 0.82745200E+00, -.98947000E-02, 0.73930700E+00, -.10772000E+01, -.95747300E+00, -.97900000E+00, -.13828600E+01, -.10003400E+00, -.18835600E+00, -.13072600E+00, 0.30610900E+00, -.26389100E+00, 0.12051700E+01, 0.32169700E+00, 0.77192400E-01, -.10470200E+00, -.17442500E+00, -.91162000E-01, -.20628300E+00, -.45263500E-01, 0.21879200E+00, -.33654600E+00, -.98080300E-01, -.13228200E+00, 0.19675200E+00, 0.49458900E+00, -.12084500E+00, -.10741000E-01, 0.25715900E+00, 0.24869400E+00, 0.43510500E+00, -.10025900E+00, -.17334100E-01, -.27624900E+00, -.11022800E+00, 0.76114000E-01, -.12144800E+00, 0.21914500E+00, 0.69193000E-02, 0.10911600E+00, 0.59182400E-01, 0.16471300E+00, -.97346100E-01, -.52772400E-01, 0.67464500E+00, 0.66406400E+00, 0.32907400E+00, -.57823200E+01, -.17035000E+00, -.26337600E-01, -.17714600E+00, -.52222900E-01, 0.46608300E-01, -.55674000E-01, 0.59352500E-01, -.21019100E+00, 0.10551800E-01, 0.99065100E-01, 0.15688800E+00, 0.51767900E+00, 0.50967700E-01, -.10532400E+00, 0.54293300E+00, 0.39389000E+00, 0.59419400E-01, 0.52858800E+00, 0.29332500E+00, 0.44546900E+00, 0.15251000E+00, 0.11245100E+00, -.50813000E-01, -.91964300E-01, 0.40941400E-01, -.84638400E-01, 0.23312600E-01, -.15637700E+00, 0.19333500E-01, -.16115700E+00, -.29232500E+00, -.43889000E-01, 0.17684000E-01, 0.18951000E+00, 0.69789300E-01, -.21738300E+00, 0.15890200E+00, -.19661700E+00, 0.30737500E-01, 0.55337600E-01, -.52452800E-03, 0.17872100E+00, 0.13793200E+00, -.16259200E+00, 0.18119900E-01, -.73206900E+00, 0.10525700E+00, 0.34464200E-01, 0.67941700E-01, -.80717600E-02, 0.20591400E+00, 0.60203000E-01, 0.60587200E-02, 0.84604400E-01, -.24771700E+00, 0.32705000E+00, 0.57795500E+00, 0.72255400E+00, 0.47574000E+00, -.78041200E-01, -.27716000E+01, -.29159500E+01, -.44429300E+00, 0.35112400E+01, 0.11656400E+02, 0.93885900E+00, -.23287700E+01, 0.14862200E+01, 0.25038800E+00, -.55608400E+01, -.13578800E+01, -.23342400E+00, -.33096100E+00, 0.77194000E-01, -.41588600E+00, -.62414100E+00, -.28969600E-01, 0.96768400E-02, 0.11998200E+00, -.17320100E+01, 0.17144800E+01, 0.97744800E+00, 0.14815700E+01, 0.48244900E-01, 0.16847400E-01, 0.38377800E+00, -.50686700E+00, 0.49183800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.58003800E+01, -.81055600E+00, -.28951100E+01, -.14523400E+01, -.13940300E+01, -.15561100E+01, 0.41228400E+00, -.11726400E+01, -.33810500E+01, 0.49657100E+00, -.14579600E-01, 0.11633600E+00, -.14363400E+01, -.46250200E+00, 0.12779200E+01, -.22434000E+01, -.67983600E-01, 0.11500600E+01, -.25456900E-01, -.40228400E+00, -.12721000E+01, -.20203000E+00, -.21297000E+00, -.18249200E-01, -.90322100E-01, 0.83074300E-02, 0.15399600E+00, -.44798100E+00, 0.61752500E+00, 0.65037600E+00, -.89042100E-01, -.53119200E+00, -.21038600E+00, 0.61924900E+00, 0.87724300E+00, -.16948900E-01, -.35369600E+00, 0.58148900E+00, -.20724900E+00, 0.77489700E+00, -.65380100E-01, 0.58325200E+00, -.30169700E-01, 0.24039500E+00, 0.91151100E+00, -.18775000E-01, 0.99429500E+00, 0.93386400E+00, 0.67092800E-01, 0.61864400E-01, 0.16369700E+00, 0.10638700E+00, 0.60697600E-01, 0.56910700E+00, 0.72759600E+00, 0.35518300E+00, -.65554300E+01, -.17981500E+00, -.70948900E-01, 0.10322500E+00, -.18584500E+00, -.13361400E+00, -.20440200E+00, 0.11389500E+00, -.42342300E+00, 0.83224800E-01, 0.18539900E+00, 0.45683200E+00, -.14583600E+00, 0.11819100E+00, 0.10426200E+00, 0.12901700E+01, 0.32472500E+00, 0.19182900E+00, 0.10056300E+01, 0.29668400E+00, 0.74904600E+00, -.18754900E+00, 0.37685400E+00, -.12114800E+00, -.17395500E+00, 0.12820500E+00, -.22668600E-01, -.46951700E-01, 0.45943700E-01, 0.13392900E+00, -.49422600E+00, -.77069000E+00, -.82828900E-01, 0.60970100E-01, 0.40518300E+00, 0.64580700E-01, -.75210200E+00, 0.57023500E+00, -.36391900E+00, 0.13477800E-01, 0.11478100E+00, 0.42192800E-01, 0.63057900E+00, 0.16494600E+00, -.33561900E+00, 0.22161200E-01, -.10236500E+01, -.57517100E-01, 0.15054100E-01, 0.67890700E-01, -.20531000E+00, -.74033300E-01, 0.29670500E+00, -.10299400E+00, 0.36080500E+00, 0.96006500E-01, -.89105300E+00, -.17101400E+00, 0.94918300E+00, -.34212500E-01, 0.88663900E-02, -.10741200E+01, -.29635200E+01, -.64279500E+00, 0.14895600E+01, 0.78609700E+01, 0.84332400E+00, -.94410300E+00, 0.64149600E+00, 0.12511900E+01, -.11635300E+01, -.92506800E+00, -.55659400E-01, -.17191300E+00, -.56518800E+00, -.53811000E+00, -.39236400E+00, 0.99087200E-01, 0.39002300E-01, -.10991800E+00, -.10769200E+01, 0.66167300E+00, 0.97373600E+00, 0.80708000E+00, 0.76633700E-01, 0.44883700E-01, 0.18425000E+00, 0.69895600E+00, 0.39995100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.36972400E+01, 0.81567100E+00, 0.16663400E+01, 0.88098200E+00, 0.77603100E+00, 0.80028400E+00, -.48086100E+00, 0.20778900E+01, 0.23358800E+01, -.65066200E+00, 0.41760200E-01, 0.14821800E+01, 0.90625200E+00, 0.22695800E+00, 0.43184200E+00, 0.23581100E+01, -.26346100E+00, -.22325000E+01, 0.44726100E+00, -.22081400E+00, 0.73187900E+00, 0.65215600E+00, 0.45171500E-01, 0.34652100E-02, -.17179500E+00, -.15889600E-01, -.54977100E-01, -.18788800E+00, 0.26475300E+00, 0.52271600E+00, -.23664700E+00, -.52344500E+00, 0.15228600E-01, 0.23182000E+00, 0.62350100E+00, -.13222700E-01, -.12924100E+00, 0.11450200E+00, 0.16976400E+00, 0.36077900E+00, -.85433500E-01, -.20922400E-01, -.14906000E+00, -.89289000E-01, 0.31731000E+00, -.40469300E-03, 0.14036400E+00, -.84940300E-01, -.36311100E+00, -.61891200E-01, -.21257900E+00, 0.37431200E+00, -.44992700E-02, -.62087100E+00, -.91259300E+00, 0.24415100E+00, 0.64157300E+01, 0.13665500E+00, 0.11597300E+00, -.54355500E+00, -.17720200E+00, 0.72139500E-02, -.38422900E+00, 0.46180200E-02, -.69876300E+00, 0.37153200E+00, 0.45307900E-02, -.61834900E-01, -.33065700E+00, 0.77063400E-01, -.16241300E+00, -.10648100E+00, -.53673200E+00, 0.13436100E+00, -.73942500E-01, 0.13006800E+00, 0.12591800E+01, -.10842700E+00, -.27068700E+00, 0.83455700E-01, 0.50081500E-01, 0.29706300E-01, 0.44547100E-01, 0.36786100E-01, -.18539300E+00, -.85452300E-02, 0.12612800E+00, 0.46382300E+00, -.16230900E+00, 0.46484600E-01, 0.19218500E+00, 0.21863700E+00, -.47755400E+00, -.19963400E-01, 0.25550400E+00, -.15926400E+00, -.24336000E-01, -.32906700E-01, -.15312900E+00, -.26342800E-01, 0.48945700E-01, -.51592600E-01, 0.18397700E+00, 0.98363100E-01, -.38647000E-01, -.68515000E-01, -.40313500E-02, 0.20118000E+00, 0.50445600E-01, -.39748700E-02, -.71057400E-01, 0.20918900E-01, 0.68228300E+00, -.28426600E-01, 0.43845100E+00, -.15523000E+00, 0.33318900E-01, 0.15443300E+00, -.74114300E-01, 0.89247100E+00, -.21370200E+01, 0.20843000E+01, 0.31898500E+00, 0.93890400E+00, -.14108000E+00, -.15434500E+01, -.13250700E+01, 0.11572600E+01, 0.84814000E-01, 0.11793000E+00, 0.16327800E+00, -.90377600E-01, 0.16347600E+00, -.49405800E-01, 0.68534800E-01, -.21960800E-01, 0.24052100E+00, -.55162400E-01, -.35327900E+00, -.12450800E+00, 0.79760700E-02, 0.69611800E-02, 0.89117900E-01, -.31783200E+00, -.17159600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14429000E+02, -.13251400E+01, -.54273800E+01, -.27459000E+01, -.23549800E+01, -.15278800E-01, -.56868600E+01, -.99258000E+01, 0.40268000E+01, -.53829200E-01, 0.34116600E+00, -.58173400E+01, -.32819400E+01, -.48634400E+00, -.18305500E+01, -.41644800E+01, -.11184700E+00, -.40536700E+01, -.36041300E+00, -.47376600E+00, -.70308000E+00, 0.91378500E+00, 0.22073500E+01, -.32113600E+00, 0.14165100E+00, 0.88089000E+00, 0.12102600E+00, 0.84004300E+00, -.11587100E+01, 0.85052800E-02, 0.12000700E-01, 0.48136500E+00, -.39788200E+00, -.58656800E+00, 0.13302900E+02, -.16820700E+01, 0.13814100E+01, 0.52802700E+00, -.19038300E+01, -.38456800E+00, 0.25841500E-01, 0.17881600E+00, -.20531300E+00, 0.39697400E-01, 0.12541000E+01, 0.16222900E-01, 0.12548400E+01, 0.13869700E+01, -.51751000E-01, -.18444700E+00, 0.13172900E+01, -.37722000E+00, 0.76709200E-01, -.92072600E+00, 0.25413900E+01, 0.24591100E+00, -.14063300E+02, 0.43015200E-01, -.71545500E+00, 0.39441700E+00, -.31914900E+00, -.68729100E+00, -.27199300E+00, 0.28376800E+00, -.15585900E+01, 0.33770600E+00, -.37231800E+00, 0.45559500E+00, 0.19339200E+01, 0.25813900E-01, -.78099900E+00, 0.76501800E+00, -.94468500E+00, 0.36000100E+00, 0.77031000E+00, 0.51036200E+00, 0.87634900E+00, -.39744500E+00, -.15633900E+00, -.29518700E-01, -.12416000E+00, -.69614000E-01, -.21113300E-01, -.70708900E-01, -.19900300E-01, -.75895300E-01, -.29411300E+00, -.77805800E+00, 0.41172500E-01, 0.24480800E+00, -.14052100E+01, -.19423800E+00, -.85753900E+00, 0.96508400E+00, 0.10812800E+01, -.21299200E+00, -.50338700E-01, 0.15087200E+00, 0.23713900E+00, 0.51553700E+00, 0.62096700E+00, 0.17041300E+00, 0.22958600E+01, 0.89987900E+00, -.32464200E+00, -.10572800E+00, -.22893000E+00, -.79182300E+00, 0.77324200E+00, -.84483800E-01, -.47353600E-01, 0.77518100E+00, 0.12560000E+01, -.16286300E+01, 0.62373300E+00, -.20542900E+01, -.76893600E-01, -.16019400E+01, 0.18844200E+01, 0.57594000E-01, -.45547700E+02, -.56347100E+01, 0.25815000E+01, 0.14330300E+02, 0.27941900E+01, -.22218800E+02, -.58571200E+01, 0.13525400E+02, 0.98682300E+00, 0.12786900E+01, -.11733200E+01, 0.18616400E+01, 0.16449300E+01, -.75173800E+00, -.26706800E+00, 0.10955700E+00, 0.21620700E+01, -.21011400E+01, -.42839200E+01, -.10970800E+01, 0.50223400E+00, -.18046000E-01, -.19579600E+01, 0.84514900E+00, -.13545300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.49575600E+01, -.93493100E+00, -.27648500E+01, -.14238300E+01, -.13673300E+01, -.16251300E+01, -.49403400E+00, -.31476500E+01, -.32287400E+01, 0.61624100E+00, 0.14236800E+00, -.20120500E+01, -.39664500E+00, 0.78604500E-01, -.13365800E+01, -.26167000E+01, 0.16376200E+00, 0.23604800E+01, -.97245500E+00, 0.86710200E+00, -.33309300E+00, 0.53662600E+00, -.35176000E+00, -.80552200E-01, -.18100800E+00, -.45974200E+00, -.24385200E-01, 0.14107400E+00, -.57958600E+00, -.17914800E+01, 0.32039200E+00, -.43570500E+00, 0.31156400E+00, -.53731700E+00, 0.64670500E+01, -.65732100E+00, -.27975200E+00, 0.80027100E-01, 0.23846100E+00, 0.60345000E+00, -.35802600E-01, 0.81553000E+00, -.34522400E+00, -.53767800E-01, 0.83462100E+00, -.12392400E+00, 0.13069500E+01, 0.14311500E+00, -.67025800E+00, -.52061400E+00, -.13406500E+01, 0.57324900E+00, -.21561400E+00, -.60424900E+00, -.10484300E+01, 0.85127700E+00, -.93676600E+00, -.29505200E-02, -.20362700E+00, 0.11756400E+00, 0.76482200E-02, -.82827300E-01, 0.28469800E+00, -.13895800E+00, -.12575900E+00, 0.33879800E+00, 0.50061800E+00, -.24611600E+00, -.81658000E+00, -.10773000E+00, 0.19401500E+00, -.65342800E+00, -.12177300E+01, 0.13792200E+00, 0.29685200E+00, 0.66011200E+00, 0.13014900E+01, -.47455400E+00, -.31594900E+00, -.37659300E-01, -.98603200E-01, 0.25533000E+00, 0.28064200E-01, -.26374500E+00, 0.11993800E+00, 0.36007600E+00, 0.16225300E+00, 0.47030000E+00, 0.18810000E-01, -.33035000E-01, -.99399600E+00, -.11139500E+01, 0.29131800E+00, -.95492300E-01, -.88192700E+00, -.50293800E+00, 0.59051300E-01, 0.37716300E-01, 0.41828700E+00, -.25205100E+00, 0.46162000E-01, 0.53787600E-01, 0.95085600E+00, -.53673800E+00, -.53573600E-01, -.19134900E+00, -.30545700E+00, -.38901000E+00, 0.22775900E+00, 0.21624300E+00, -.18958400E+00, -.43128300E-01, 0.84496700E+00, -.38313800E-01, -.28812800E-01, -.55419400E+00, 0.79321500E-01, 0.45180000E-01, -.19560000E+00, -.61055000E-02, 0.33716400E+00, 0.23961200E+02, -.27371700E+00, -.20281200E+01, 0.43413000E+01, 0.27750400E+01, 0.25675800E+01, -.14700100E+01, 0.36818200E+00, 0.27013600E-01, 0.13266400E+00, -.55093400E+00, 0.17971800E+00, 0.35217100E+00, 0.30386100E+00, 0.39179400E-01, 0.49569500E+00, -.10601600E-01, 0.10408800E+01, -.42351800E+00, -.27240200E+00, 0.39184200E-01, 0.32150400E+00, -.77061900E-01, 0.15957800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20882200E+02, 0.34086400E+01, 0.73653500E+01, 0.46922500E+01, 0.34467900E+01, 0.36552600E+01, -.48194100E+01, -.27886200E+01, 0.93285600E+01, -.79287400E-01, -.39737200E+00, 0.66800900E+00, 0.77476200E+00, -.32400000E+00, -.75144600E+00, 0.42549100E+01, -.13118600E+00, -.24890300E+01, -.15874300E+01, 0.11077000E+01, 0.21921300E+01, -.33904200E+01, 0.38723000E+01, -.87227300E+00, 0.17986400E+01, -.99400100E+00, -.53829500E-02, -.51985700E+00, -.15385700E+01, 0.51781300E+01, -.50891800E+01, 0.30675300E+01, -.11394100E+01, -.39263800E+00, -.34994400E+02, 0.31374900E+01, -.26405800E+00, -.13555500E+01, 0.62861600E+00, -.47427600E+01, 0.11173500E+01, -.14869200E+01, -.60865600E+00, 0.58688600E-01, -.71719600E+00, -.29768300E+00, -.53469800E+00, 0.24120800E+00, -.49812300E+00, -.67568900E-01, 0.19481600E+01, 0.66686400E+00, 0.83921500E+00, 0.84631200E+00, -.31856800E+01, -.85575500E+00, 0.23687700E+02, 0.39997400E+00, 0.13366600E+01, 0.12964900E+01, -.84425000E+00, -.10194600E+01, -.13835700E+01, 0.15327200E+00, -.18911700E+01, 0.18472600E+01, -.60092300E+00, 0.20536700E-01, -.12973400E+01, 0.11051000E+00, -.50320900E+00, -.14779900E+01, -.12672500E+01, 0.79232400E-01, -.19919500E+01, -.73691100E+00, 0.53638800E+00, -.74638400E+00, -.35826400E+00, 0.25456500E+00, 0.21910100E+00, -.32557200E+00, 0.69238400E-01, -.76125700E+00, -.47644200E+00, -.16152800E+00, 0.16691000E+01, 0.17979400E+01, 0.61280000E-01, 0.69006000E+00, 0.31579600E+00, 0.10509700E+01, 0.21032000E+01, -.87938700E+00, 0.74720100E-01, 0.24548900E+01, 0.21632000E+00, 0.42814300E+00, -.10948400E+01, -.13793500E+01, 0.78536300E+00, 0.26483500E+00, 0.12053700E+01, -.37025200E+00, 0.55913200E+00, 0.35172200E+00, 0.31890000E+00, 0.19492200E+01, -.35418000E+00, 0.37064100E+00, -.78202800E+00, 0.34499700E+00, -.10429600E+01, 0.58112100E+00, 0.15175500E+01, -.12228800E+01, 0.34112300E+00, 0.69455200E+00, -.22739600E+00, -.68813400E+00, -.65514300E-01, -.25064700E+00, -.12872200E+02, -.13614800E+02, 0.25424400E+02, 0.60251300E+01, 0.14342900E+02, -.12965400E+02, 0.18546100E+01, 0.15750500E+01, 0.38980900E+00, 0.78532800E-01, 0.16954100E+01, -.46216600E+00, -.68412500E+00, 0.10580300E+01, 0.29591100E+01, -.13635900E+01, -.29302100E+01, -.18671700E+01, -.58014100E+00, -.25812600E+00, 0.81718700E-01, 0.59837000E+00, 0.24345500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.46969700E+01, 0.81323000E+00, 0.23944200E+01, 0.92212100E+00, 0.76313700E+00, 0.11011600E+01, -.24563900E+01, -.17493600E+01, 0.21276700E+01, -.76934800E-01, 0.30799700E-01, -.16079200E+00, 0.70614400E+00, 0.28563300E+00, -.22994600E+00, 0.96498000E+00, -.12856900E+00, 0.32686900E+00, -.78990000E+00, 0.87109900E+00, 0.66444000E+00, 0.41664900E+00, 0.64655300E+00, -.47749600E-01, 0.34823300E+00, -.38715000E+00, -.11928300E+00, -.20232600E+00, -.40265300E+00, -.26828100E+00, -.73603700E+00, 0.12686100E+00, 0.26055800E+00, -.61869600E-01, -.78117300E+01, 0.11053600E+01, -.15792100E+00, -.98230400E-02, 0.94366900E+00, -.17275200E+01, 0.14904300E+00, -.24254000E+00, 0.20757200E+00, 0.19072800E+00, -.73142700E+00, 0.21101300E-01, -.78556400E+00, -.34725800E+00, -.11166900E+00, -.22739800E+00, -.18927300E+00, 0.16254900E+00, 0.37416700E+00, -.22881800E+00, 0.11452500E+01, 0.26711200E+00, -.80862100E+01, -.12867900E+00, -.23670000E+00, -.51851100E+00, 0.53954900E-01, 0.15647500E+00, 0.11522400E+00, -.88437200E-01, 0.43966900E+00, -.19369300E+00, -.16188400E+00, 0.19310100E+00, -.10272500E+01, 0.54530800E-01, 0.29147800E+00, 0.14157300E+00, 0.60765600E+00, -.96747000E-01, 0.18108500E+00, 0.39103500E+00, -.56667700E+00, 0.91386400E-01, 0.33141200E+00, -.11533800E+00, 0.23091700E-01, -.23534400E-01, -.74774000E-01, 0.19618400E+00, 0.23350000E+00, -.34236400E+00, -.64835000E+00, -.75692000E+00, 0.75516400E-01, -.11898200E+00, 0.41864800E+00, 0.17922500E+00, -.10910900E+01, 0.24138300E+00, 0.81218700E+00, -.35508400E+00, -.17444000E-01, -.78952900E-01, -.50963700E+00, -.93153200E-01, -.13405400E-01, -.49815500E-01, 0.56341300E+00, 0.10856500E+00, -.24634700E-01, -.54432500E-01, -.17609500E-01, -.38017100E+00, -.32027300E+00, -.21379400E+00, 0.23477200E+00, 0.11909700E+00, -.13341500E+00, -.15528700E+00, -.62898600E-01, -.54040700E+00, 0.19312500E-01, -.64969600E+00, 0.32963400E+00, -.23798700E-02, 0.27678200E-01, 0.44077100E-03, -.13226400E+00, -.15874500E+01, 0.16587400E+01, -.43382100E+00, 0.86189400E+00, -.14507300E+01, 0.29740000E+00, 0.33176700E+00, -.40671300E+00, 0.32850200E+00, 0.34880700E+00, -.10320200E-01, -.16133100E+00, 0.38186600E+00, 0.67318200E+00, -.20802200E+00, -.37126200E+00, -.42719300E+00, -.13325100E-01, -.28478900E-01, -.34564100E+00, 0.21338200E+00, 0.63022600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.44897900E+01, -.91464900E+00, -.23518500E+01, -.98149800E+00, -.10086700E+01, -.97129100E+00, 0.70926200E+00, -.20694100E+00, -.28119200E+01, 0.24030500E+00, 0.38752600E-01, 0.78119700E-01, -.14806500E+00, -.39452700E-01, 0.28120100E+00, -.10046500E+01, -.25913800E-01, 0.86557700E+00, 0.21303700E+00, -.65551800E-01, -.46687000E+00, 0.69667300E+00, -.67752300E+00, 0.58564500E-01, -.37483500E+00, 0.59015300E-01, -.83652200E-01, 0.26677800E-01, -.12700400E+00, -.14178200E+00, 0.38378900E+00, -.44488900E+00, -.20078200E+00, -.86460900E-01, 0.59556900E+01, -.89492600E+00, -.59997300E-01, 0.13418200E+00, -.54761400E-01, 0.15016400E+01, -.25828400E+00, 0.46873400E+00, -.48389900E+00, -.11281900E+01, 0.75038900E+00, -.37339400E+00, 0.98857200E+00, 0.34712600E+00, -.27371400E-01, -.32016200E-01, -.72549700E+00, 0.73036900E+00, -.84416100E-01, -.25696900E+00, -.12362700E+01, 0.45163900E+00, 0.29035500E+01, -.76382200E-02, -.32766800E+00, -.20622500E+00, 0.19340000E-01, -.31417800E+00, -.17339100E+00, 0.10684000E+00, -.14132400E+01, 0.29062600E+00, 0.66683300E+00, 0.34821500E+00, -.37349700E+00, -.97105100E-01, -.26652900E+00, -.41336000E+00, -.10073900E+01, 0.94104200E-01, -.18088000E-01, 0.76673600E-01, 0.11338200E+01, -.28180600E+00, -.11269600E+00, -.68814100E-01, -.11463100E+00, 0.14789900E+00, -.10550500E-01, -.41542000E-01, -.51687200E+00, 0.65835100E-02, -.94319000E-02, 0.27637200E-02, 0.17340600E+00, -.69708900E-01, -.70476400E+00, -.11392100E+00, -.34600000E+00, 0.46283700E+00, -.14088900E+00, 0.12319200E+00, 0.69758200E-01, -.11656500E-01, 0.37972700E+00, 0.86738700E+00, -.43159300E+00, -.65355700E-01, -.21363300E+01, 0.57773400E+00, -.16087300E-01, 0.22502500E+00, -.61186100E-01, 0.21941200E+00, 0.98630200E+00, 0.15316500E+00, -.65927700E-01, 0.71433900E-03, 0.19612800E+00, -.16367300E+00, 0.22255600E+00, -.25563000E+00, -.13149000E+00, -.56139000E+00, 0.32963800E+00, -.19840400E+00, 0.26979500E+00, -.85784800E-01, -.13487000E+00, 0.66777300E+00, 0.17529500E+01, 0.25628500E+01, -.12602300E+01, 0.31571100E+00, -.31997500E+00, -.89808100E+00, 0.64669300E+00, -.84432800E+00, -.91300100E+00, 0.33307400E+00, -.10902700E+00, 0.48345200E-01, -.14242500E+01, 0.11593800E+01, 0.22339900E+01, 0.90511200E+00, -.30982700E+00, -.58613400E-01, 0.83274800E+00, -.37960600E+00, -.42925400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.34766100E+02, -.25699900E+01, -.12329700E+02, -.67157300E+01, -.59143800E+01, -.58888000E+01, 0.14631400E+02, 0.15988900E+02, -.15010200E+02, -.31571500E+00, 0.20104000E+00, 0.56018000E+01, -.67335500E+01, -.63758200E+01, -.32550900E+01, -.11639600E+01, 0.10825200E+01, -.17051700E+01, 0.56726900E+01, -.52419000E+01, -.18717200E+01, -.40313700E+01, -.30030400E+01, -.46272300E+00, -.17411900E+01, 0.10987000E+01, 0.36682100E+00, 0.19390100E+01, 0.21764900E+01, 0.68632400E+00, 0.52606700E+01, 0.20883700E+01, -.28249700E+01, 0.11847600E+01, 0.46189400E+02, -.53199000E+01, 0.86773300E+00, 0.73155600E+00, -.32308200E+01, 0.10100400E+02, -.16468100E+01, 0.27786200E+00, -.24716400E+00, 0.74711000E+00, 0.16710800E+01, -.83555100E-01, 0.35784200E+01, 0.81075600E+00, 0.16670500E+01, 0.65218700E+00, -.42417900E+00, -.43332400E+01, -.25369400E+01, -.21525800E+01, -.69994200E+00, 0.16722200E+00, -.13402300E+02, 0.32501000E+00, -.20767700E+01, 0.14762700E+01, 0.49274000E+00, -.52270200E+00, 0.17742700E+01, 0.24091400E+00, -.12283700E+01, -.30431900E+00, 0.36396400E+00, -.44513700E+00, 0.32997900E+01, 0.35305200E-01, -.10703400E+01, 0.92695200E-02, -.16675700E+01, 0.33314100E+00, 0.29749700E+01, 0.37505400E+01, 0.34859000E+01, -.71634700E+00, -.64372700E+00, -.15407500E+00, -.11661900E+00, 0.73586700E-01, -.27007800E+00, 0.39011900E+00, -.37977300E+00, -.44979300E+00, -.48910500E+00, 0.44868400E+00, 0.31020700E-02, 0.12268500E+00, 0.16245200E+00, -.15075700E+01, 0.25109800E+00, -.11870000E+01, 0.17562700E+01, -.21393600E+01, -.62902400E-01, -.30855900E+00, -.25128300E+01, -.11225000E+01, 0.31109700E+00, 0.31849200E-01, 0.11171300E+01, -.53008400E+00, 0.17562400E+00, -.10064000E+00, 0.58770700E+00, -.15901000E+01, 0.72281700E+00, -.15169200E+00, 0.54765200E+00, 0.11007800E-01, 0.17321800E+01, 0.30464800E+00, -.52446500E+00, 0.13406700E+01, -.29029900E+00, 0.14922000E+01, -.61525200E+00, 0.11607800E+01, -.49496100E+00, 0.12663800E+00, -.23625800E+00, -.34214300E+01, 0.46562600E+01, -.19321500E+02, 0.57251700E+01, -.16932500E+01, 0.23595000E+01, 0.56750200E+01, -.24634300E+01, 0.44216400E+01, 0.59088600E+01, -.21386700E+01, 0.22136800E+00, 0.17329500E+00, 0.88622300E+01, -.70038700E+01, -.13869700E+02, -.53198500E+01, 0.15405600E+01, 0.18714700E+00, -.41797400E+01, 0.59867500E+00, 0.36040300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.85786300E+01, -.63489800E+00, -.35553800E+01, -.16357300E+01, -.14808400E+01, -.16468800E+00, -.31501300E+01, -.63344400E+01, 0.24571400E+01, 0.21390800E+00, 0.10686800E+00, -.47787300E+01, -.32310600E+01, -.18932900E+00, -.33940800E+01, -.50867800E+01, 0.17150500E+00, -.30190100E+01, -.14348300E+01, 0.17344000E+00, -.40613300E+00, -.54991200E+00, 0.24739000E+01, -.70502700E+00, 0.15253000E+00, 0.10122400E+01, 0.25471000E+00, 0.11610300E+01, -.10203900E+01, 0.63151300E+00, -.10427300E+01, 0.29106700E+00, -.52047700E+00, -.16657400E+00, 0.60905700E+01, -.12880200E+01, 0.58866900E+00, 0.25027700E+00, -.22917000E+01, 0.20552400E+00, 0.16302300E-01, 0.13134600E+00, -.17840200E+00, -.12016700E+01, 0.19703000E+01, -.19061100E+00, 0.11949300E+01, 0.11048900E+01, -.58130200E+00, -.14175100E+00, 0.70476800E+00, 0.45836500E+00, -.21124900E+00, -.18312800E+01, -.98808700E+00, -.20941800E+00, 0.23728900E+01, 0.55929600E+00, -.15138000E+01, 0.13128900E+01, -.35216100E+00, -.17090400E+00, 0.58186400E-01, -.14914700E+00, -.35147100E+01, 0.62116500E+00, -.63631800E+00, 0.87108300E+00, -.17867900E+01, -.23622000E-01, -.12046900E+01, 0.36870000E+01, -.17851600E+00, -.61742400E-01, -.20035100E+01, -.21076100E+01, 0.51394700E+00, -.63647900E+00, -.14712300E+00, 0.31856300E+00, 0.30014800E+00, -.44501100E+00, -.25453900E-01, 0.45966500E+00, 0.80081000E+00, -.29912500E-01, 0.16371300E+00, 0.36413200E+00, -.22699700E+00, 0.15356000E+00, 0.24018600E+00, 0.11843100E+01, 0.32082000E+01, -.92939800E+00, -.69314800E-01, 0.12383500E+01, -.27940400E+00, -.16167200E+00, 0.43409900E+00, 0.32376200E+00, 0.41694100E+00, 0.96330600E-01, 0.95814800E+00, 0.10317900E+01, 0.38694000E+00, 0.41645500E+00, 0.64948100E+00, 0.77537200E+00, 0.65465900E-01, 0.57453400E-01, -.62170000E+00, 0.12171900E+00, -.73219800E+00, -.79148700E+00, 0.10488000E+00, 0.36532500E+00, 0.29903500E+00, 0.13970000E+01, 0.61877600E+00, 0.17280800E+01, 0.12172100E+00, -.82694300E+00, 0.86657200E-01, -.81496100E+00, 0.23765500E+00, -.69339700E-01, 0.14450100E+02, -.18730100E+01, 0.45852000E+00, 0.13686800E+01, 0.61859200E+00, 0.11356500E+00, 0.17143700E+01, 0.19719000E-03, 0.43648000E+00, -.96846100E-01, 0.35085500E+01, -.35380200E+01, -.19799200E+01, -.30869800E+01, 0.13223900E-02, 0.70569700E-01, 0.25655700E-01, -.85030900E+00, 0.16837500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.53652300E+01, 0.10107000E+01, 0.27116200E+01, 0.13059500E+01, 0.10000300E+01, 0.16060800E+01, -.20116000E+01, 0.64070400E+00, 0.22029600E+01, -.43220400E+00, -.29591700E-01, 0.21367800E+01, 0.43414500E+00, -.47491100E+00, 0.50320700E+00, 0.26507500E+01, -.25203000E+00, -.11324700E+01, 0.21943700E+00, 0.11054400E+00, 0.73549500E+00, 0.41469200E+00, 0.26247300E+00, 0.27750600E-01, -.13151500E-01, -.41990900E+00, -.19003900E+00, -.45351500E+00, -.95516700E-02, 0.20158800E+01, -.14089000E+01, -.15427100E+01, -.12019900E-01, -.11105000E+00, -.87046900E+01, 0.64096600E+00, 0.59219100E+00, -.36200700E-01, 0.47639100E+00, -.14615000E+01, 0.11316500E-01, -.64490500E+00, 0.32145500E-01, -.40407000E+00, -.41672100E+00, 0.45376600E-01, -.10340600E+01, -.13741700E+00, -.68946600E+00, -.17482400E+00, 0.18269600E+00, 0.14868400E+01, 0.72970700E+00, -.37317000E-01, -.18398200E+00, 0.16798800E+00, 0.52054200E+01, 0.59935500E-01, 0.39191000E+00, -.76708400E-01, -.12837000E+00, 0.29891100E+00, -.56118900E+00, -.47183000E-01, 0.20345100E+00, -.38654900E-01, -.41384700E-01, -.26960400E+00, 0.52164600E+00, 0.92676200E-01, 0.28631200E-01, 0.57438000E+00, 0.19179400E+00, 0.47556200E-01, 0.81746900E+00, 0.89544400E+00, -.16934000E+00, 0.21684000E-01, 0.11434400E+00, -.56124600E-01, -.93677500E-01, 0.11864200E+00, 0.68941500E-02, -.16128100E+00, -.15659000E+00, 0.17185800E+00, -.11042900E+00, 0.29684800E+00, -.14381600E-02, 0.35370400E-01, -.43704500E+00, -.15867900E+01, 0.38489200E+00, 0.28005500E+00, -.11462100E+01, -.82925000E+00, 0.13754400E+00, 0.41643600E-01, 0.49541700E+00, -.13502400E+00, -.93045900E-01, 0.68110300E-02, -.73968900E+00, -.35623900E+00, 0.18810100E-01, -.30477400E-01, -.28816200E+00, -.32778900E-01, 0.26116100E+00, 0.12178700E-01, 0.11853000E+00, -.15614600E-01, 0.39175300E+00, 0.50836200E-01, -.30381600E+00, 0.10856400E+00, -.49379400E-01, -.21505600E+00, 0.61808700E-01, -.55845300E-01, 0.68435900E-01, 0.17610000E+00, -.16672500E-01, 0.17150200E+00, -.42216700E-01, -.23090600E-02, -.71474600E-01, 0.11829100E+01, -.60826600E-01, -.11601600E+00, 0.29421200E-01, -.12255300E-01, -.12508500E+00, 0.28521200E-01, 0.10172600E-01, 0.32113800E-01, -.22634400E+00, 0.12359200E+00, 0.25424800E+00, 0.13106500E+00, -.20261000E-01, -.82206400E-03, 0.22026000E-01, -.11169100E+00, -.16195700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11213400E+02, -.60770900E+00, -.44422100E+01, -.21772900E+01, -.18456400E+01, -.11864900E+00, -.49658900E+01, -.92346100E+01, 0.14022700E+01, 0.40253500E+00, 0.31059000E+00, -.59569000E+01, -.28867800E+01, 0.79370400E-01, -.45413200E+01, -.57788500E+01, 0.20238600E+00, -.15601800E+01, -.16737100E+01, 0.84067300E+00, -.39528100E+00, 0.42431000E+00, 0.17133500E+01, -.37410000E+00, -.17511200E+00, 0.77591700E+00, 0.15857400E+00, 0.10686900E+01, -.71824400E+00, -.15545700E+01, -.30595200E+00, -.47375100E+00, 0.85910900E-01, -.67388800E+00, 0.95157700E+01, -.91296200E+00, 0.65859300E+00, 0.39681900E+00, -.13946500E+01, 0.31920300E+01, -.49079100E+00, 0.83709600E-01, -.39365700E+00, -.75508200E+00, 0.12007800E+01, -.10978800E+00, 0.50678700E+00, -.45109300E-01, -.31136100E+00, 0.34380900E+00, -.54442700E+00, -.81109900E-01, -.75110500E+00, -.19491300E+00, -.23841200E+01, -.20201400E+00, 0.31800000E+01, 0.32167700E+00, 0.47805400E+00, 0.12984900E+01, -.14545100E-01, 0.67607600E+00, -.32860600E+00, -.15219000E+00, -.98415500E+00, 0.54958300E+00, 0.58573300E+00, -.14717700E+00, 0.33620000E+00, -.26845500E+00, -.82220500E+00, 0.10705300E+01, -.11983100E+01, 0.13155000E+00, 0.26631400E+00, 0.32402500E+00, 0.16063400E+01, -.28994700E+00, -.43592100E+00, 0.92532000E-01, 0.60166300E-01, 0.58564400E-01, 0.25771800E-01, -.25064500E+00, -.15324400E+00, 0.43267500E+00, 0.79441300E+00, 0.10545200E+01, -.89660500E-01, -.96537200E-01, -.58584700E+00, -.40514600E+00, 0.63902900E+00, -.52754400E+00, -.66394200E+00, 0.13717300E+00, 0.43883600E-01, -.92355300E-01, 0.36882800E-02, -.35906200E+00, -.32041300E+00, 0.19609600E-01, 0.19000100E+01, -.81676300E-01, -.25233000E+00, -.21194600E+00, 0.19714300E+00, -.39777800E+00, -.35496400E+00, 0.47980900E-01, -.15102300E+00, -.11530000E+00, 0.98572100E+00, 0.53415300E+00, 0.20833500E+00, 0.10620600E+00, -.42364600E-02, 0.94157100E+00, -.39645300E+00, 0.55485000E+00, -.60835700E-01, 0.28165300E+00, 0.14223000E+00, -.15968800E+01, 0.32724400E+00, -.18090300E-01, -.49647700E-01, -.25921600E+00, 0.90966700E+00, 0.10982900E+01, 0.78772400E-01, 0.53640800E+00, 0.13537700E+01, -.20763000E+00, -.43045300E-01, 0.30899600E+00, 0.21127800E+01, -.16625400E+01, -.25282600E+01, -.15227500E+01, 0.15719900E+00, 0.16696100E-01, -.43418400E+00, -.43247800E+00, 0.60625200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.96624700E+01, 0.13121500E+01, 0.29053100E+01, 0.17554400E+01, 0.14092500E+01, 0.11048600E+01, -.35106200E+01, -.37145600E+01, 0.15932000E+01, 0.37738100E+00, -.25965300E-01, -.15162500E+01, 0.11992100E+01, 0.11470300E+01, -.17981100E+01, -.17972100E+01, -.87883500E-02, 0.17026600E+01, -.25265300E+01, 0.22957800E+01, 0.69879000E+00, 0.10144800E+01, 0.96273000E+00, -.34944000E-01, 0.52655000E+00, -.24178800E+00, -.15161800E+00, -.29288800E+00, -.80014900E+00, -.62711500E+00, -.14179700E+01, -.78533800E+00, 0.79617500E+00, -.29730600E+00, -.12599500E+02, 0.11522600E+01, -.25666000E+00, -.51286700E+00, 0.10431300E+01, -.77537500E-01, 0.32866500E-01, -.32696600E+00, -.43211200E+00, -.49478200E+00, 0.21368000E+00, 0.49874000E-01, 0.22435900E+00, -.31624000E+00, -.67137200E+00, -.88543100E-01, -.58389000E+00, 0.60951000E+00, -.59375700E-01, 0.23922400E+00, -.20026300E+00, 0.27222800E+00, 0.35990400E+01, 0.37289400E-01, 0.85062900E+00, -.64653700E+00, -.58687400E-01, 0.57381200E+00, -.53528700E+00, -.37792600E-01, -.10703200E+01, 0.34057800E+00, -.13741400E+00, 0.43028800E+00, -.10110500E+01, 0.12093500E+00, -.13832600E-01, 0.50339100E+00, 0.65072900E+00, -.17115700E+00, -.53532500E+00, 0.45601300E-01, 0.10204300E+00, -.30682500E+00, 0.48816500E+00, 0.64199900E-01, 0.12772000E+00, -.16168500E+00, -.63426500E-02, -.25467800E+00, -.75680300E-01, 0.96239200E-01, 0.87747100E-01, 0.14979800E+00, 0.84044000E-01, 0.32131600E-02, 0.52978100E+00, 0.22929500E+00, -.28960800E+00, -.14019000E+00, 0.21170300E+00, 0.16945400E+00, 0.12353000E+00, -.33390000E-01, -.35559900E+00, -.31529800E+00, -.18109200E+00, 0.84125800E-01, 0.31587400E+00, -.97982500E-01, -.47290800E-01, -.46233100E-01, 0.11766400E+00, -.25793500E-01, 0.42915600E-01, 0.28953700E-01, -.14575200E-01, 0.46659400E-01, 0.10988500E+00, 0.25919100E-01, 0.16243000E+00, -.11279900E+00, 0.28090500E-01, -.68370800E-01, 0.55051400E-01, 0.56616400E-01, 0.57298100E-01, 0.22242500E-01, 0.19467600E-01, 0.11440600E-01, -.42091300E-01, -.22629900E-01, -.26990600E-01, 0.15308500E-02, 0.62024000E+00, -.34766300E+00, -.11510700E+00, -.22667500E+00, -.59551300E+00, 0.15567400E+00, -.29515400E-01, -.13191700E+00, -.10505400E+01, 0.90662700E+00, 0.12428100E+01, 0.70176100E+00, -.37151900E-01, 0.18374200E-01, 0.17852100E+00, 0.22029000E+00, -.29044600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.42616900E+02, -.43047400E+01, -.12586600E+02, -.72550700E+01, -.69038000E+01, -.40753700E+01, 0.15990000E+02, 0.15832100E+02, -.29148200E+02, 0.22660000E+01, 0.25382500E+00, 0.12352300E+02, -.13837300E+02, -.89726800E+01, -.21651500E+02, 0.20435100E+01, 0.19966700E+01, 0.12693200E+02, -.64091300E+00, 0.67438400E+00, 0.45001900E+00, 0.28074200E+01, -.37237400E+01, 0.31315400E+00, -.66509700E+00, -.75651100E+01, -.20042600E+01, 0.15345100E+01, -.20026000E+01, 0.62883600E+01, -.56808100E+00, 0.38662600E+01, -.46790400E+01, 0.75335000E-01, 0.71736600E+01, -.43466100E+01, -.29213100E+00, -.11457900E+01, -.15777800E+01, 0.19644200E+01, -.27030800E+00, -.53030400E+00, -.20508100E+01, -.11562900E+01, 0.15351700E+01, 0.12357500E+01, 0.20000300E+01, 0.19965100E+01, 0.10943200E+01, 0.76115800E+00, 0.19714700E+01, 0.23183400E+01, 0.12732600E+01, -.46932200E+01, -.33436300E+01, -.23542500E+00, 0.10099700E+02, 0.83138600E+00, -.27955900E+01, -.19946600E+01, 0.39837900E+00, -.10991900E+01, 0.37745200E+00, 0.47466100E+00, -.29709400E+01, -.28494900E+01, -.53068400E+00, -.15533500E+01, 0.66289100E+01, 0.39671500E-01, -.20079400E+01, 0.20302400E+01, -.17410600E+01, 0.11333900E+01, 0.18653300E+01, -.47001200E+00, 0.35828400E+01, -.87185000E+00, -.78011400E+00, 0.29740100E+00, 0.10594600E+00, -.47557000E-01, -.22269700E+00, 0.15497700E+01, 0.13750600E+00, 0.76209000E+00, -.13043500E+01, 0.98771300E+00, -.11568700E+01, 0.17070600E+00, 0.13357200E+01, 0.26670900E+01, 0.13548300E+01, -.42689400E+00, 0.16601100E+01, 0.12810400E+00, -.41113100E+00, -.70376800E+00, -.16438800E+01, -.54581700E+00, 0.63468200E+00, -.35052600E+00, 0.35535700E+01, 0.16052100E+01, -.58088600E+00, -.29655300E-02, 0.14237800E+01, 0.15397300E+01, -.50612600E+01, -.15460600E+01, 0.13942700E+01, -.25730700E+00, 0.12463200E+01, 0.40573600E+01, 0.59316600E+01, 0.69414200E+00, 0.12432500E+00, 0.63963600E+01, -.69352500E+00, 0.30372100E+01, -.56216000E+00, 0.55227500E+00, 0.28085200E+00, -.35134300E+01, -.28165200E+01, 0.15568800E+00, -.31479100E+00, 0.15160900E+01, -.14418000E+01, -.40860500E+01, 0.10683100E+02, -.55173500E+01, 0.64287200E+00, 0.30433100E+00, 0.14456700E+01, -.32188900E+00, 0.23385200E+01, -.16363900E+01, 0.96467300E+00, -.24433500E+01, -.15024500E+01, -.85566700E-03, 0.73904700E+01, -.61996900E+01, 0.50540700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.40792200E+02, 0.36889400E+01, 0.12950500E+02, 0.72103500E+01, 0.70423700E+01, 0.50179500E+01, -.12562700E+02, -.13126900E+02, 0.17353500E+02, -.20890700E+00, -.18693400E+00, -.12113500E+02, 0.85182400E+01, 0.83853200E+01, -.32289600E+01, -.69321800E+01, 0.67920400E+00, 0.60670600E+01, -.88263600E+01, 0.68701900E+01, 0.18566400E+01, 0.52918700E+00, 0.13249600E+01, 0.92644600E-01, 0.13287600E+01, 0.23047900E+01, 0.26814000E-01, 0.48649700E+00, -.21639200E+01, -.48447300E+01, -.45812200E+01, 0.89504300E+01, 0.17699200E+00, -.11935100E+01, -.38129100E+02, 0.50099800E+01, -.15682800E+01, -.20909000E+01, 0.93047000E-01, -.14967100E+01, -.55314800E-01, -.18281900E+01, -.46297300E+00, -.11113000E+01, -.63415100E+00, 0.55672400E+00, -.16142900E+01, -.22967900E+01, -.14613200E+01, -.38143100E+00, 0.43931300E+00, 0.91089700E+00, -.34013800E+00, -.80401300E+01, -.36567400E+01, 0.45812900E+00, 0.46767700E+02, 0.14533100E+01, -.30693200E+00, -.38044200E+01, -.11402000E+01, -.64930300E+00, -.15310400E+01, 0.11606500E+00, -.30655000E+01, 0.31616100E+01, -.25959100E+01, -.44143400E+00, -.33351100E+01, 0.14803200E+01, -.25930900E+00, 0.23184000E+01, -.16295400E+01, 0.40794500E+00, -.66889600E+00, -.11593900E+01, 0.49748400E+01, -.61964200E+00, -.54042400E+00, 0.69957300E+00, 0.50940200E+00, -.43347200E+00, 0.64870500E+00, 0.19556600E+01, 0.17575200E+00, -.15299200E+00, -.18666700E+01, -.85879200E+00, -.16424600E+01, 0.74051400E+00, 0.49634000E+01, 0.46216700E+01, -.60282700E+01, -.11874400E+01, 0.60592100E+01, -.10393900E+01, -.48972900E+00, -.68309100E+00, -.57312200E+01, -.33754700E+01, 0.85678000E+00, -.42894200E+00, 0.59714400E+01, -.33954200E+00, -.95945100E+00, -.89618200E+00, 0.14333200E+01, 0.62225800E+00, -.39553500E+01, -.18045800E+01, 0.16467500E+01, 0.50276100E+00, 0.23320500E+01, 0.24824700E+01, 0.82091700E+01, -.19274200E+01, 0.52129700E-01, 0.44069500E+01, -.55007000E+01, 0.12469600E+01, 0.28397500E+00, 0.20237300E+01, -.27883300E+00, -.16697600E+01, -.65154500E+00, 0.32023100E+00, -.33805800E+00, 0.34586200E+00, -.11842200E+01, -.24413500E+01, 0.34993800E+00, -.43298300E+01, 0.12554400E+00, -.12140100E+00, 0.47848300E+00, -.56404400E+00, -.38213000E+00, -.49424400E+00, -.65550300E+00, -.36966100E-01, -.61112000E+00, 0.99665100E-02, 0.26558500E+01, -.10681900E+01, -.69530600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.66149500E+01, 0.11416500E+01, 0.19926300E+01, 0.13175500E+01, 0.95427900E+00, 0.16486300E+00, 0.13787800E+01, 0.25437400E+01, -.12094700E+01, 0.13775300E+00, -.12102100E+00, 0.13154900E+01, 0.14352300E+01, 0.43296600E+00, 0.16610000E+00, 0.39380900E+00, 0.45338900E-01, 0.16653200E+01, -.70309500E+00, 0.82010000E+00, 0.45686300E+00, 0.58733900E+00, -.15299100E+00, 0.10898000E+00, 0.35374500E+00, -.42436200E+00, -.10044400E+00, -.40620500E+00, -.20941000E+00, -.31665900E+00, -.46798900E+00, -.34492300E+00, 0.25126000E+00, 0.32630500E-01, -.63693700E+01, 0.51868100E+00, -.64701400E-01, -.15019600E+00, 0.52176300E+00, 0.50434800E+00, -.10743600E+00, -.27864600E+00, -.16403100E+00, -.94533200E-01, -.75670500E-01, 0.12456200E-01, 0.20191800E+00, -.14272900E+00, -.18457600E+00, -.71132800E-01, -.26026900E+00, 0.91067400E-01, -.29347000E-01, 0.26245500E+00, -.22013000E+00, 0.14119500E+00, 0.32129400E+01, 0.70868900E-02, 0.41614800E+00, -.44481000E+00, -.54542200E-01, 0.17295700E+00, -.24827000E+00, 0.19936200E-01, -.38498800E+00, 0.20583000E+00, -.11327200E+00, 0.13659400E+00, -.50881400E+00, 0.10410600E+00, 0.34055100E-01, 0.16969600E+00, 0.46622900E+00, -.11551900E+00, -.39008800E+00, -.85048500E-01, -.32738900E+00, -.26383200E+00, 0.40098200E+00, -.10801200E-01, 0.54774800E-01, -.97405500E-01, -.47367100E-01, -.19371800E+00, 0.48226500E-01, 0.75131600E-01, -.23453800E-01, 0.92570200E-02, 0.12148700E+00, 0.28194500E-01, 0.53371200E+00, 0.19053300E+00, 0.33767000E-01, -.61971600E-01, 0.43393800E+00, 0.87880600E-01, 0.65595800E-01, -.10468200E-01, -.39404300E+00, -.18072900E+00, 0.12005500E-01, 0.90960900E-01, 0.32472100E-02, -.99007500E-01, 0.56168100E-01, 0.28239400E-01, 0.82108500E-01, 0.59370300E-01, 0.82499000E-01, 0.21525300E-01, 0.33895100E-02, 0.33112800E-01, -.13677200E+00, -.32709100E-01, -.78777800E-01, 0.12644100E+00, 0.37138500E-02, -.10518500E-01, 0.34243200E-01, 0.58726800E-02, -.48096100E-01, -.89379900E-01, 0.20268500E-01, 0.85106600E-01, 0.84610200E-01, 0.20829400E-02, 0.28503500E-01, -.47118500E-01, 0.21182100E+00, -.16916600E+00, -.12661500E-01, 0.25668800E-01, -.33950400E+00, 0.69793400E-01, -.14655300E-01, -.88588600E-01, -.72372900E+00, 0.60033900E+00, 0.77528600E+00, 0.53497400E+00, 0.57345200E-01, 0.25513000E-01, 0.51469000E-01, 0.11990100E+00, -.20884700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.38243600E+02, 0.77603500E+01, 0.10692200E+02, 0.75909900E+01, 0.59297900E+01, 0.40117900E+01, -.78451900E+01, -.42873000E+01, 0.97558100E+01, 0.89011200E+00, -.71345600E+00, -.42756300E+01, -.60861700E+00, 0.34739100E+00, -.11118800E+02, -.63536400E+01, 0.19266300E+00, -.40675500E+01, -.65806100E+01, 0.54802300E+01, 0.32545600E+01, -.55199500E+00, 0.84452900E+01, -.13875800E+01, 0.29700600E+01, 0.42517900E+00, 0.27357200E+00, -.14837200E-01, -.32211600E+01, -.16561600E+01, -.66021800E+01, 0.41023400E+01, 0.13404900E+01, -.92913500E+00, -.42670600E+02, 0.42463400E+01, -.11769700E+01, -.24063900E+01, 0.26612500E+01, -.25776500E+01, 0.11460500E+01, -.18611800E+01, -.33275900E+00, 0.23895000E+01, -.47263600E+01, -.43339300E-01, -.18919600E+01, -.25790500E+01, 0.88969600E+00, 0.25689600E+00, -.62545700E-01, -.34590500E+01, -.14719800E+01, 0.48613700E+01, 0.47932800E+01, -.89322200E+00, -.15106100E+02, -.77447800E+00, 0.21758800E+01, -.12509800E+01, -.77983400E+00, 0.59018700E+00, -.15225100E+01, -.92346900E+00, 0.51130400E+01, 0.12963600E+01, -.21939400E+01, -.10385600E+01, -.62797800E+01, 0.56338900E+00, 0.11213600E+01, 0.17518300E+00, -.16396900E+00, 0.57476300E+00, 0.19175700E+01, 0.39781800E+01, -.33783000E+00, -.74201600E+00, 0.84831800E-01, -.41082000E+00, -.56463400E-01, 0.16753300E+00, -.15572200E+00, -.39623000E-01, -.25214700E+00, -.92200700E+00, -.63369700E+00, -.36970100E+00, 0.19777300E+00, -.15341600E+00, -.37197500E+01, -.77427300E+01, 0.82708600E+00, 0.85564900E+00, -.20174200E+01, -.49248400E+01, 0.34825400E+00, -.49810200E+00, -.12143100E+01, -.21771800E+01, 0.11725500E+01, -.28697400E-01, 0.39896400E+00, -.32867400E+00, 0.14877700E+01, 0.10090800E+00, -.99657700E+00, 0.17221200E+01, -.17211000E+01, -.33236000E+00, -.14058100E+00, 0.74505400E+00, 0.13427900E+00, 0.70650200E+00, 0.11521900E+01, -.39247400E+01, 0.28953000E+00, -.11292900E+01, -.64856600E+00, -.11705400E+01, 0.46122600E-01, 0.12552700E+01, 0.71069200E+00, -.51174100E+01, -.40206200E+01, 0.90608400E-01, -.12300000E+01, 0.13223900E+01, 0.57850700E+00, -.21079400E+00, -.30948600E-01, 0.31729900E+00, -.14652500E+01, 0.22219500E+01, -.54309900E-01, 0.66363800E+00, 0.40024900E+01, -.21648600E+01, 0.79666900E+01, -.37252700E+01, -.12941700E+01, -.15406100E+00, 0.29822800E+00, 0.11430400E+01, 0.18483900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.29792700E+01, 0.47211700E+00, -.82109400E+00, -.35418200E+00, -.65175000E+00, -.56233200E-01, 0.18560600E+01, 0.19723300E+01, 0.23980400E+00, -.20536900E+00, -.87323100E-01, 0.98207100E+00, -.19828600E-01, 0.13162700E-01, 0.18075700E+01, 0.15773900E+01, -.15379000E+00, -.13998500E+01, 0.13946700E+01, -.11611800E+01, -.29670500E+00, 0.29521700E+00, -.30080600E+00, 0.12284500E+00, -.17629100E+00, 0.21679300E+00, 0.20454500E-01, 0.75758400E-01, 0.17587100E+00, 0.58593400E+00, 0.76406100E+00, 0.85305900E-01, -.35722200E+00, -.26602500E-01, 0.38941800E+01, -.43336300E+00, 0.11438400E+00, 0.12895600E+00, -.45550300E+00, -.17520100E+00, 0.70261400E-01, 0.11665700E+00, 0.60170400E-01, -.23174100E-03, 0.23539600E+00, 0.18991100E-01, 0.94332300E-01, 0.30247300E+00, 0.26095600E+00, 0.10029300E+00, 0.20692300E+00, -.31537300E+00, -.15725200E+00, 0.35099100E+00, 0.54789500E+00, 0.66735500E-01, -.46771900E+01, -.10949700E+00, -.14291200E+00, -.10488400E+00, 0.96949900E-01, -.48354900E-01, 0.13973300E+00, 0.49753900E-01, -.92154100E-01, -.11551900E+00, 0.10094200E+00, 0.99917800E-01, 0.49663500E+00, 0.25358400E-01, -.43515700E-01, -.63054700E-01, -.25237000E-01, -.38091900E-02, 0.71701100E-01, -.11163000E-01, -.41289600E+00, 0.15868800E-03, -.10738500E-02, -.34543000E-01, -.29504100E-01, 0.19859000E-01, -.56647100E-02, 0.48373700E-01, -.67590500E-01, 0.14489800E-01, -.70931000E-01, -.10181400E+00, 0.38207000E-03, -.16646100E-01, -.13018200E+00, -.15384700E+00, 0.22156700E+00, 0.65326300E-01, -.72422500E-01, -.10800200E+00, -.10231600E-01, -.14017200E-01, 0.81952300E-01, 0.82368000E-01, 0.13460000E+00, -.28571300E-01, -.26668700E+00, 0.49458400E-01, 0.14855600E-01, 0.28794400E-01, -.22533100E-01, 0.18808900E-01, 0.67586700E-01, 0.67349100E-03, 0.25092600E-01, 0.11686000E-02, 0.70122800E-02, -.57041100E-03, 0.50829100E-03, 0.16973100E-01, -.31124200E-01, -.30238300E-01, 0.51734300E-01, -.75590900E-02, 0.19027600E-01, -.31125200E-01, -.19360900E-01, -.38831800E-01, 0.69254600E-01, 0.74559500E-02, 0.36382000E-02, 0.30577100E-01, -.93005300E-01, -.16377100E+00, 0.70355100E-02, 0.10658600E-01, 0.11964600E+00, 0.27548600E-02, 0.17808100E+00, -.95415800E-01, 0.66742700E-01, -.60002700E-01, -.18612700E-01, -.40931900E-01, -.27493800E-01, 0.17771900E-01, 0.20883400E-03, 0.54252900E-02, -.24084600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.56201300E+01, 0.49166300E+00, 0.12710200E+01, 0.82596000E+00, 0.98934300E+00, 0.12399800E+00, -.16919400E+01, -.17010000E+01, 0.54328700E-01, 0.28378500E+00, 0.50583700E-02, -.16305000E+01, -.23115300E+00, 0.14929700E+00, -.26273400E+01, -.29279600E+01, 0.89083500E-01, 0.88494800E+00, -.19575900E+01, 0.16406700E+01, 0.30831700E+00, 0.52961400E-01, 0.10846100E+01, -.19865700E+00, 0.37340700E+00, -.12595400E+00, 0.38180200E-01, -.86370700E-01, -.40384700E+00, -.16394500E+01, -.97238200E+00, -.16183300E+00, 0.83083600E+00, -.94575800E-01, -.49991600E+01, 0.70204200E+00, -.21931000E+00, -.12729100E+00, 0.90660900E+00, 0.41211700E-01, 0.94925500E-02, -.14259900E+00, -.35160900E-01, 0.72949900E+00, -.52826400E+00, 0.46637700E-01, 0.17194000E+00, -.27368800E+00, -.94103400E-01, -.26280300E+00, -.43931900E+00, -.55793700E+00, -.12388000E+00, 0.40016400E-01, 0.59460800E+00, 0.26828200E-01, 0.29602300E+01, 0.17470400E-02, 0.58850400E+00, 0.93383600E-01, -.16305500E+00, 0.31357900E+00, -.43308000E+00, -.14834200E+00, 0.10163600E+01, 0.25464800E-01, -.43532300E+00, -.24208000E+00, -.10041700E+01, -.25806000E-01, 0.30580700E+00, 0.18751700E+00, 0.67116000E+00, -.11985400E+00, -.18569800E+00, -.55231500E-01, -.74088900E+00, 0.44990300E+00, 0.21824400E-01, 0.33139800E-01, 0.30897300E-01, -.35781000E-01, 0.25859800E-01, -.24631100E-01, 0.75143700E-01, -.29778000E-01, 0.22233400E-01, 0.40556300E-01, -.21676100E-01, 0.17849300E-01, 0.11178200E+00, -.11637700E+00, 0.24306900E-01, -.51066000E-01, -.15017200E+00, 0.41950500E-02, 0.23393100E-01, -.92579200E-02, -.63196400E-01, -.19753700E+00, -.54519000E-01, 0.31456500E-01, 0.44669400E+00, -.50055000E-01, 0.63111200E-01, 0.14350400E-02, -.35849700E-02, 0.15953200E+00, -.19125300E+00, -.13525700E-01, -.73712300E-01, 0.35937600E-01, -.12331600E+00, 0.28736700E-01, -.16067200E-01, -.10215300E+00, 0.50853400E-01, -.30939000E-01, -.50516500E-01, -.51884500E-01, -.29441700E-01, 0.43091200E-01, 0.48019600E-01, 0.94400800E-01, -.39767400E+00, -.42220900E-01, -.44464600E-01, 0.38756500E-01, 0.96929700E-01, 0.11389100E+00, -.75154000E-02, -.50440400E-02, -.16433700E+00, 0.25715400E-01, -.59702600E+00, 0.23875000E+00, -.55621300E-01, 0.60996400E-02, -.17228900E-01, 0.14792800E-01, 0.61506100E-02, -.74817400E-02, -.45955200E-02, -.65854600E-02, 0.50769100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.52217500E+01, 0.41344000E+00, 0.14214400E+01, 0.94171800E+00, 0.86857300E+00, 0.95950100E-01, 0.14710800E+01, 0.27875900E+01, -.10612500E+01, 0.31908000E-02, -.84561400E-01, 0.15691100E+01, 0.66537900E+00, 0.65301700E-01, -.21973600E+00, 0.81149000E+00, 0.85719600E-01, 0.10026900E+01, -.17125400E+00, 0.27995800E+00, 0.30376000E+00, -.29689700E+00, -.31644200E+00, 0.43224300E-01, 0.15117800E+00, -.36070800E-01, -.46386000E-01, -.10513300E+00, 0.16522700E+00, 0.45841400E-01, -.57326200E-01, 0.42288600E-01, 0.22086300E-01, 0.23772000E+00, -.35304500E+01, 0.36938600E+00, -.12803000E+00, 0.21693600E-01, 0.17096400E+00, 0.74345900E-01, -.78739900E-01, -.14843500E+00, 0.68289500E-01, -.36000400E+00, -.37669800E-01, -.34744300E-01, -.67495100E-01, -.46031600E-01, 0.17301900E-01, 0.14917100E-01, 0.79860800E-01, 0.34524100E+00, 0.14345900E+00, 0.58434900E-01, -.22388900E+00, -.50192700E-02, 0.24641800E+01, 0.53556800E-01, 0.11345000E+00, -.99889100E-01, -.13209300E+00, 0.92489600E-01, -.21098000E+00, -.49270600E-01, 0.61395100E+00, 0.13338600E+00, -.22842900E-01, -.25543600E+00, -.28533100E+00, -.19600000E-01, 0.63172300E-01, 0.90344400E-01, 0.64656800E-01, 0.40071100E-02, -.13508500E-01, 0.12263500E+00, 0.80414500E-01, -.45469000E-01, 0.41633100E-01, -.24864000E-01, -.50316500E-02, 0.34705200E-01, -.16250900E-01, -.83457300E-01, 0.63612800E-01, 0.14494300E+00, -.18511800E-01, -.48353100E-01, 0.17295300E-01, 0.27524100E-01, 0.41370200E+00, 0.23743700E+00, -.13149300E+00, -.90082800E-01, 0.32428200E+00, 0.92518800E-01, 0.22635300E-01, -.12466400E-03, -.29536100E+00, -.18849700E+00, -.67820100E-01, 0.57088100E-01, 0.13294600E+00, -.14482200E+00, 0.25100500E-01, -.14128900E-01, 0.52546800E-01, 0.67364100E-01, -.10818000E+00, 0.35582500E-01, 0.43211400E-02, 0.16606400E-03, -.15988400E+00, -.32684400E-01, -.10265600E+00, 0.14725600E+00, 0.89649900E-02, -.84640100E-01, 0.41853300E-01, 0.29046500E-02, -.41762500E-01, -.45514400E-01, -.46585300E-02, 0.13955700E+00, 0.82237200E-01, -.45842600E-02, 0.11835700E-01, -.38022800E-01, 0.10739000E+00, 0.37550500E-01, -.47082300E-02, -.11375000E-02, -.19146900E+00, 0.13178000E-02, -.17382500E+00, -.17344700E+00, -.41091000E+00, 0.27871100E+00, 0.23832000E+00, 0.29183900E+00, 0.38217700E-01, 0.94218600E-02, 0.23326500E-01, 0.32095700E-01, -.96926600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.44549500E+02, -.46570800E+01, -.15138400E+02, -.82645700E+01, -.73678100E+01, -.60572300E+01, 0.16807700E+02, 0.20026500E+02, -.10407900E+02, -.17636700E+01, 0.23569900E+00, 0.81163500E+01, -.83470800E+01, -.78796100E+01, 0.26344300E+01, 0.47214100E+01, 0.23464400E+00, -.99116600E+01, 0.10829500E+02, -.98766500E+01, -.26677000E+01, -.34890700E+01, -.20950300E+01, -.49634700E+00, -.13616300E+01, 0.22291700E+01, 0.16122700E+00, 0.18840000E+01, 0.11690800E+01, 0.47387800E+01, 0.80562300E+01, 0.57092600E+01, -.40896600E+01, 0.21219400E+01, 0.53501000E+02, -.59277000E+01, 0.74132900E+00, 0.11838700E+01, -.43993100E+01, -.13209900E+01, 0.15556200E+00, 0.12059700E+01, 0.73540500E+00, 0.15892300E+01, 0.11097100E+01, 0.19181400E+00, 0.34689700E+01, 0.36078400E+01, 0.32482100E+01, 0.21476100E+00, 0.42466500E+01, -.33380400E+01, 0.22870000E+00, 0.26724100E+00, 0.93697200E+01, -.59730800E+00, -.77533000E+01, -.74161100E+00, -.66275200E+00, 0.24592000E+01, -.67670200E+00, -.30983200E+01, 0.19316100E+01, 0.33012900E+00, 0.89783700E+01, -.76861700E+00, -.20030200E+01, -.37061700E+01, 0.10851800E+02, -.60908000E+00, -.14668300E+01, -.14468200E+01, -.19779700E+01, 0.77769500E+00, 0.28012200E+01, -.37171400E+00, -.18328500E+01, -.11409700E+00, 0.38897900E+00, -.46674700E+00, -.10280300E+01, 0.84535600E+00, -.53619200E+00, -.15995500E+01, 0.31735500E+00, -.60720700E+00, 0.80030800E+00, 0.10617100E-01, 0.11374700E+01, 0.19620900E+00, -.98350800E+01, -.66790700E+01, 0.37750500E+01, 0.34134400E+01, -.28547400E+01, -.37060000E+01, 0.50849600E+00, 0.55677700E+00, 0.44026100E+01, 0.45548700E+01, 0.88578000E+00, -.12959600E+00, -.62282800E+01, 0.15403900E+01, 0.90316200E+00, 0.11827800E+01, -.26146400E+01, 0.11925900E+01, 0.20461100E+01, 0.79309300E+00, 0.66769400E-01, 0.71125100E+00, -.88392100E-01, -.13185000E+01, -.18442000E+01, 0.21171400E+01, -.12516500E+01, 0.10918800E+00, -.28667700E+01, -.22991200E+01, -.15534800E+01, 0.53198100E+00, -.16347300E+00, 0.87414000E+00, -.16772600E+01, 0.15784400E-01, -.14768600E+01, -.12201400E+01, -.84685300E+00, -.11650000E+01, 0.20449000E+00, 0.82845300E-01, 0.75168400E+00, -.37974200E-01, -.28596400E+00, 0.11450400E+00, 0.22431900E+01, -.47964200E+01, -.25680200E+00, -.52132000E+00, 0.97761400E-01, 0.12100400E-01, -.33115400E+00, 0.35868600E+00, 0.91364100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20584100E+01, 0.71995500E+00, 0.57187300E+00, 0.42934500E+00, 0.35185000E+00, 0.36568100E+00, -.70571200E+00, -.79969400E+00, 0.53179500E+00, 0.67717800E-01, -.16216200E-02, -.28688500E+00, 0.38860400E+00, 0.39341800E+00, -.25456500E+00, 0.11639100E-01, 0.62834100E-02, 0.29176600E+00, -.45656700E+00, 0.39076600E+00, 0.18455800E+00, 0.41179200E-01, 0.14491800E+00, -.13203200E-01, 0.94956000E-01, 0.95789300E-01, -.19542600E-01, 0.33756000E-01, -.12993900E+00, -.11533000E+00, -.20344600E+00, 0.11798300E+00, 0.55218500E-01, -.45503500E-02, -.28732600E+01, 0.22899000E+00, -.32869800E-01, -.83670700E-01, 0.84051100E-01, 0.75220500E-01, -.22348500E-01, -.12632800E+00, -.56914000E-01, -.12439700E+00, 0.46060600E-02, 0.31081600E-01, 0.58084900E-01, -.46102300E-01, -.81387700E-01, 0.67231200E-02, -.62476100E-01, 0.15153800E-01, -.17024600E-01, -.30366900E-01, 0.10090600E+00, -.44775100E-01, 0.33511200E+00, 0.25409500E-01, 0.20062200E+00, 0.10027600E+00, 0.24059900E-01, 0.18485800E+00, -.84256400E-02, -.15876800E-01, 0.36760700E-01, 0.10461100E-01, -.79612500E-01, 0.29515300E-01, 0.90003400E-01, 0.11306000E-01, 0.11695800E-02, 0.53634100E-01, 0.16856800E+00, -.50815700E-01, 0.37374000E-01, 0.12232700E+00, 0.14959600E+00, -.24290600E-01, 0.87239200E-01, 0.27032200E-01, 0.20802400E-01, -.24860000E-01, -.26646600E-03, -.53816700E-01, -.29519100E-02, 0.12988300E-01, 0.32640500E-01, 0.32903400E-01, 0.22164900E-01, -.65134100E-02, 0.85530300E-01, 0.35735800E-01, -.21351800E+00, -.30534000E-01, 0.12301300E+00, 0.14896700E-01, 0.12559200E-01, -.88136000E-02, -.92241900E-01, -.89240700E-01, -.50679000E-01, 0.52671000E-02, 0.22481200E+00, -.67331300E-01, -.40946400E-01, -.27243900E-01, 0.19001600E-01, -.94185800E-01, 0.19957600E-01, 0.11759700E-02, 0.36078700E-02, 0.15682500E-01, 0.48104600E-01, -.45593200E-02, 0.22603200E-01, -.25673400E-01, -.83517600E-03, -.26452400E-01, 0.50175500E-03, 0.39092400E-02, 0.12380000E-01, 0.32147300E-01, 0.18968500E-03, -.23767600E-01, -.92825900E-02, 0.87839300E-03, -.18591400E-01, -.52972600E-02, 0.79913600E-01, 0.13550300E+00, 0.18574500E-02, 0.66352400E-03, -.50763700E-01, 0.32553400E-01, -.13770200E-01, -.54550700E-01, 0.35181500E+00, 0.83399800E-02, -.35464200E+00, 0.26896800E-01, 0.26819600E-02, -.18185200E-02, -.19001300E-01, -.54732500E-01, -.20805100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.72644400E+01, -.93568800E+00, -.24100600E+01, -.14310000E+01, -.12694800E+01, -.23364300E+00, -.18128800E+01, -.32645200E+01, 0.12269300E+01, -.12018400E+00, 0.19302600E+00, -.20579800E+01, -.10861000E+01, -.34910300E+00, -.62507400E-01, -.91883900E+00, -.10346300E-01, -.25345000E+00, 0.28768100E+00, -.32807800E+00, -.49843100E+00, 0.12483900E+01, 0.30668200E+00, 0.98213800E-01, 0.12140500E+00, 0.18679100E+00, -.59143200E-01, 0.13875800E+00, -.61383400E+00, -.10143300E+00, 0.82244700E+00, 0.10504700E+01, -.50534900E+00, 0.92677800E-01, 0.35940100E+01, -.39013200E+00, 0.36002100E+00, 0.40472800E+00, -.11029200E+01, 0.67593100E+00, -.10173600E+00, -.57529600E-01, -.71214000E-01, 0.20333200E+00, -.26555200E+00, -.39847600E-01, -.23939000E+00, -.19266900E+00, 0.19727100E+00, 0.88988100E-01, -.85086600E-01, -.41610800E+00, 0.61980700E-02, 0.18397400E+00, -.42941600E+00, -.15343700E+00, 0.78013000E+01, -.15647200E-01, -.43826500E-02, -.20973600E+00, -.36087900E-01, -.37765400E+00, 0.48291000E-01, 0.43342500E-01, -.98810300E-01, -.22371300E+00, -.36105300E+00, 0.23595000E-01, -.42146400E-01, 0.22840900E+00, 0.10488400E+00, 0.63248600E+00, 0.45353300E+00, 0.10259900E+00, -.12481400E+00, -.70743100E+00, -.36618200E+00, -.74401800E+00, 0.80888300E+00, -.28107500E-01, 0.76881900E-01, -.12041700E+00, -.53349500E-01, 0.17422600E+00, 0.60917000E+00, -.22108700E+00, -.10295900E+01, -.10251700E+00, -.10876200E-01, 0.68578000E-01, 0.62242300E+00, 0.10588600E+01, 0.28374200E+00, -.54969100E-01, 0.30014100E+00, 0.66587100E+00, -.88767000E-02, 0.27614700E-01, 0.32726000E-01, 0.40473300E-01, 0.14865500E+00, -.41788600E-01, -.11514400E+01, -.10950200E+00, 0.23976700E+00, 0.14534400E+00, -.60812300E-01, 0.58163400E+00, -.31316300E+00, -.54257900E-01, -.84276900E-01, -.34845600E+00, -.68074600E+00, 0.63056200E+00, 0.80228400E-01, 0.73968800E+00, 0.18796700E+00, 0.10439900E+01, -.53159300E+00, 0.37624000E+00, -.40137200E+00, -.15800100E+00, 0.48635600E-01, -.11596000E+00, 0.21832700E+00, 0.12708000E-01, 0.27076700E+00, 0.13235700E+00, 0.18879400E-01, 0.17669300E+00, -.49622500E-02, -.24453600E-01, -.10616500E+00, -.21483000E-01, 0.21286300E+00, 0.10394100E+00, -.49841400E+00, -.10847400E+00, -.98462300E+00, 0.99615800E+00, 0.65258400E-01, 0.26390600E-01, 0.97986000E-02, -.66584500E-01, -.18586700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11167400E+01, 0.32958900E+00, 0.32186100E+00, 0.25843200E+00, 0.10500700E+00, -.34800200E+00, 0.56250800E+00, 0.10215500E+01, -.83254500E+00, 0.12137500E+00, -.77124600E-01, 0.37994200E+00, 0.41735500E-01, -.20310900E+00, -.35570300E+00, -.71839700E+00, 0.62642300E-02, 0.51665000E+00, -.43866000E+00, 0.44316000E+00, 0.10362500E+00, 0.32371100E+00, 0.21826300E+00, -.33267100E-01, 0.13008500E+00, -.33901600E+00, -.53227300E-01, -.17793500E+00, -.20928100E+00, -.99219700E-01, -.23976200E+00, -.22584300E+00, 0.18134600E+00, -.70263900E-01, -.14437800E+01, 0.18217000E+00, -.16242900E+00, -.14096700E+00, 0.43944900E+00, 0.22782600E-02, 0.12793700E-01, 0.32097200E-01, -.11534900E+00, 0.52613000E-01, -.67467400E-02, -.31926800E-02, 0.12623700E+00, -.98232900E-01, -.99720000E-01, -.36603700E-01, -.17199800E+00, 0.67296100E-01, -.35195600E-01, 0.36484800E-01, 0.36571500E-01, 0.20193900E+00, 0.17688100E+01, -.17742500E-01, 0.15344200E+00, -.41172300E+00, -.55914600E-01, 0.24354600E-01, -.17844600E+00, 0.17821900E-01, -.17974800E+00, 0.49747000E-01, -.65326100E-01, -.82772400E-02, -.12331900E-01, 0.59853000E-01, -.57068800E-01, 0.21222800E+00, 0.90244100E-01, 0.34908000E-01, 0.11684700E-01, 0.10993100E-01, -.59970600E-01, -.81690000E-01, 0.12154600E+00, -.20918100E-01, 0.16024400E-01, -.29028500E-01, -.32281900E-01, -.35433700E-01, -.22075700E-01, -.41149400E-02, -.65873800E-01, -.13587600E-01, 0.32430200E-01, 0.72485200E-02, 0.17056000E+00, 0.62858900E-01, 0.10839400E+00, 0.32120600E-01, 0.17156000E+00, -.59858500E-01, 0.23568500E-01, -.16194800E-01, -.20107200E+00, -.53780200E-01, 0.18031900E-01, 0.28146400E-01, -.23722600E+00, 0.11555000E-01, 0.74284800E-01, 0.21878000E-01, 0.25203900E-01, 0.10170200E+00, -.38298000E-01, -.34944600E-01, 0.41635700E-01, -.88260800E-02, -.72636100E-01, 0.44320800E-01, 0.83136800E-01, 0.72960400E-01, -.51097700E-02, 0.61357900E-01, -.36518000E-01, 0.21422700E-01, -.34273800E-01, -.61365400E-01, 0.33027700E-02, 0.12050800E-01, 0.44883500E-01, -.15601200E-02, 0.18159500E-01, -.20714300E-01, 0.57429600E-01, -.21561000E-01, -.35960600E-02, 0.83735600E-03, 0.20531000E+00, -.14607700E-01, -.11202600E+00, 0.31119000E-01, -.17903800E+00, -.13805900E-02, -.37380900E+00, -.15503100E-02, 0.13675100E+00, 0.94354400E-02, -.77973000E-02, 0.30014600E-01, 0.10469500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.43045600E+00, 0.25020800E+00, 0.15856800E+00, 0.12252700E+00, 0.19044100E-01, 0.30530000E-01, 0.13560000E+00, 0.18774400E+00, -.47177500E-02, 0.25218600E-01, -.27642600E-01, 0.10805800E+00, 0.12115900E+00, 0.64238000E-01, 0.10889200E+00, 0.52823200E-01, -.16060700E-01, 0.13439200E-01, -.33109500E-01, 0.52884700E-01, 0.35952300E-01, 0.16652300E+00, 0.59235700E-01, 0.81772900E-02, 0.33777900E-01, -.81979500E-02, -.14614400E-01, -.20971600E-01, -.71031800E-01, 0.64340000E-02, -.36288700E-01, -.28076800E-01, 0.18201000E-01, -.22699500E-01, -.81092800E+00, 0.56045500E-01, -.49623100E-01, -.50919300E-01, 0.89827400E-01, -.26758900E-01, 0.19459100E-01, 0.20315600E-02, -.39406600E-01, -.65875100E-02, -.84740700E-02, 0.76333400E-02, 0.37056800E-01, -.22680600E-01, -.28977300E-01, -.95402200E-03, -.85968700E-01, -.48775500E-02, -.41079100E-01, 0.81840900E-01, 0.75916500E-01, 0.55347000E-01, -.31767400E+00, -.19171800E-01, 0.70325800E-01, -.13546100E+00, 0.15925600E-01, 0.52797200E-01, -.19157900E-01, 0.45240100E-02, -.95998600E-01, -.17280700E-02, -.68977600E-03, 0.45805400E-01, 0.33995400E-01, 0.22292700E-01, -.68275400E-02, 0.45578700E-01, 0.59721100E-01, -.94402700E-02, -.22310400E-01, 0.10967600E-01, -.89926300E-01, -.40291600E-01, 0.53542900E-01, -.25443600E-02, 0.90689700E-02, -.12142300E-01, -.61120800E-02, -.17299900E-01, -.76917600E-03, 0.16804200E-01, -.13681100E-01, -.44152400E-02, 0.71766900E-02, -.50125900E-02, 0.30700500E-01, -.18343700E-01, 0.39756300E-01, -.10290600E-01, 0.11531500E-01, -.21387700E-01, 0.82825400E-02, -.81737000E-02, -.31514000E-01, -.38457900E-01, 0.31641700E-01, 0.58553200E-02, -.10223600E-01, -.12658000E-01, 0.11644800E-01, -.15270700E-02, 0.29442300E-02, 0.56987000E-02, -.27520800E-02, 0.73231100E-03, 0.89918400E-03, -.11174500E-02, 0.57011400E-02, 0.67444100E-02, 0.13570200E-01, -.53113000E-02, 0.21807300E-02, 0.35975100E-02, 0.44924000E-02, 0.62675000E-02, 0.67122700E-02, 0.17068900E-02, -.48754400E-03, -.22460300E-01, 0.13472300E-02, -.39579800E-03, 0.43852600E-02, 0.62943100E-02, 0.36332700E-01, 0.37334700E-01, -.48178700E-03, 0.25310000E-02, 0.55310300E-01, 0.43785700E-03, 0.11328800E+00, -.28867300E-01, -.40472700E-01, -.26276400E-02, -.37801100E-01, 0.50308800E-03, 0.70303300E-01, 0.51578900E-01, 0.42542300E-03, 0.45264600E-02, -.16597900E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17535500E+01, -.15684400E+01, 0.29409500E+00, -.61138600E+00, -.36867300E+00, 0.56822800E+00, -.39987200E+00, -.11019400E+01, 0.16784900E+01, -.28384900E+00, 0.12113600E+00, -.50035200E+00, -.38819300E+00, -.12227900E+00, -.19336900E+00, 0.94561500E+00, -.99561000E-02, -.17034800E+01, 0.49531100E+00, -.69116600E+00, 0.14803800E+00, -.12222800E+00, 0.31841700E+00, -.24015900E-01, 0.79265600E-01, -.62419700E-01, 0.50361100E-01, 0.29349800E+00, 0.23856300E-01, -.18197700E+00, 0.70503100E+00, 0.86162900E+00, -.16318500E+00, -.17522400E+00, 0.28069700E+01, -.35352700E+00, 0.14407700E+00, -.19548400E+00, -.38793700E+00, -.42978900E+00, 0.69750300E-01, 0.15498100E-01, 0.16200900E+00, -.15962100E-01, -.11346700E+00, 0.23196800E-01, 0.16490300E-01, 0.21489100E+00, 0.29089200E+00, 0.29561500E-01, 0.18172500E+00, -.16789500E+00, 0.14097500E-01, -.26717300E+00, 0.31827900E+00, -.25661900E+00, -.33935000E+00, 0.30412800E-01, -.53631400E-01, 0.12336000E+00, 0.56083100E-01, -.11508100E+00, 0.21427300E+00, -.17611600E-01, 0.48372600E+00, -.10951200E+00, -.10232400E+00, -.15097200E+00, -.10567700E-01, -.53898300E-01, 0.14130300E+00, -.37165900E+00, -.16941500E+00, -.36704600E-01, -.25377600E+00, -.31302900E+00, -.52246200E+00, 0.64584200E-01, -.11335000E+00, 0.13949100E-01, 0.37714200E-01, -.12521100E-01, 0.51083800E-01, 0.96703900E-01, 0.13010700E+00, 0.11596000E-01, -.78086700E-01, -.16922900E+00, 0.97596600E-02, -.25821200E-01, -.15133200E+00, 0.26432300E+00, 0.10923700E+00, -.11400400E+00, 0.29323600E+00, 0.18992900E+00, -.64160300E-01, -.77278300E-02, -.12501300E+00, -.16090800E-01, 0.10183000E+00, -.86553200E-04, 0.83799600E+00, 0.51709900E-01, -.90251900E-01, -.74204700E-01, 0.64839600E-01, -.16893800E+00, -.20226200E+00, 0.23832200E-01, -.30716600E-01, 0.20995200E-01, 0.18858500E+00, -.15611000E-01, -.11327300E+00, -.88593300E-01, 0.15448900E-01, 0.15024000E+00, -.82604500E-01, 0.10190300E+00, 0.40185700E-01, 0.80987500E-01, -.12856900E-01, -.86977800E-01, -.19877100E-01, 0.12124300E-01, 0.67963400E-02, 0.33149300E-01, -.45549500E-01, -.98044800E-01, 0.20813500E-01, 0.37312000E-01, -.19302800E-01, -.43217200E-02, 0.20741700E-01, -.21370400E-01, 0.16791600E-02, -.14569500E-01, -.29007500E-01, 0.44819000E-02, -.49964800E-01, 0.99137400E-02, 0.15871800E+00, 0.99600000E-02, -.87336700E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22162000E+02, -.21632600E+01, -.81587400E+01, -.42084200E+01, -.44098000E+01, -.30610800E+01, 0.48717100E+01, 0.27817400E+01, -.11970300E+02, 0.14996400E+01, -.88565800E-01, 0.55817500E+00, -.76482900E+01, -.56623300E+01, -.82987800E+01, -.68108400E+01, 0.11421600E+01, 0.82333500E+01, -.11443000E+01, 0.11613400E+01, -.17199900E+01, -.35408000E+01, -.50946400E+00, -.73641100E+00, -.36176200E+00, -.21286900E+01, -.17070600E+00, 0.38685000E+00, 0.72856800E+00, 0.35376700E+01, -.28438800E-01, -.13406100E+01, -.87798100E+00, 0.81626700E+00, 0.92071900E+01, -.16928900E+01, -.18388400E+00, 0.18666000E-01, -.57295200E+00, -.27184700E+01, 0.45810200E+00, 0.19291500E+00, 0.33137000E+00, -.13528500E+01, 0.13515100E+00, -.24872200E+00, -.23599900E+01, -.32611300E+00, -.48010900E+00, 0.13131000E+00, 0.12809500E+00, 0.15351000E+01, 0.13567200E+00, 0.10536300E+00, -.26136600E+01, -.37299700E+00, 0.86163900E+01, 0.28186500E+00, -.24453900E+00, 0.60317500E+00, -.70392500E+00, -.27729400E+00, -.10824500E+01, -.23563900E+00, -.21357700E+01, 0.19178600E+01, 0.12675200E+01, 0.34355200E+00, -.56000900E+01, -.53048300E+00, 0.19303900E-01, 0.26024900E+01, -.83143300E+00, 0.42665000E-01, -.33140400E+01, -.41199200E+01, 0.27957900E+01, -.12848300E+01, 0.85681400E+00, 0.48606400E+00, 0.14586000E-01, 0.52971800E-02, 0.24628900E+00, -.53578800E+00, 0.17092600E+01, 0.32287300E+00, 0.32593800E+00, -.40891600E+00, 0.38789100E-01, 0.23043800E+00, 0.18285500E+00, 0.19769300E+01, -.87664400E-01, 0.36935500E+00, -.64575200E+00, 0.24428700E+01, -.41453000E-01, 0.33181300E+00, 0.18085200E+01, 0.60553100E+00, -.10877900E+00, 0.10172200E+00, -.19813200E+01, -.71717600E-01, 0.17861100E+00, 0.14492900E+00, -.35846300E+00, 0.15674600E+01, 0.15832300E-01, 0.42427400E+00, -.91959200E+00, -.18487900E+00, -.18806900E+01, -.56635900E+00, -.87082600E+00, 0.76241500E-02, 0.99537400E-01, 0.12610200E+01, -.20855800E+01, -.26852200E+01, 0.46545200E+00, -.70232400E+00, 0.18006500E+00, -.45513100E+00, -.44725600E+00, -.55271600E+00, 0.11004700E+01, -.90619100E+00, 0.92567000E+00, 0.19178400E+01, -.46356100E+00, 0.11815800E+00, -.17648700E+01, 0.53636400E-01, 0.20935700E+00, -.78542200E+00, -.64358600E+00, -.10894400E+00, -.51197100E+00, 0.29322100E+00, 0.11913300E+01, 0.98494300E-03, -.49196400E+00, 0.41245500E+01, -.36888700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.31353100E+01, 0.12681400E+01, 0.15536600E+00, 0.49672200E+00, 0.41829300E+00, -.63151100E+00, 0.15896800E+01, 0.17934800E+01, -.12842000E+01, 0.25115100E+00, -.11048100E+00, 0.34820000E+00, 0.52580700E+00, 0.31760400E+00, -.40693900E+00, -.49162900E+00, 0.85283600E-01, 0.13129500E+01, -.64051700E+00, 0.57994200E+00, 0.14591900E+00, -.38695200E+00, 0.57579700E-01, -.83606700E-01, 0.23115200E+00, -.18511700E+00, 0.70343700E-02, -.31721600E-01, -.84046200E-01, -.85076300E+00, 0.75883000E-01, 0.79976500E+00, 0.21334900E+00, 0.13137900E+00, -.95118800E+00, 0.28950600E+00, -.47595800E+00, -.15643700E+00, 0.49295500E+00, 0.20158800E-01, 0.62026600E-02, 0.97590200E-01, 0.13034500E-01, 0.22707700E+00, -.15058000E+00, 0.11490400E-02, 0.25581000E+00, -.10229300E+00, 0.19183700E+00, -.95841200E-02, -.13486400E+00, -.40095200E+00, -.11864600E+00, -.13383700E+00, 0.64140400E+00, 0.12804700E+00, -.13078800E+01, -.35833300E-01, -.50457100E-01, -.60299500E-01, -.79763600E-01, -.10594500E+00, 0.76156500E-01, -.33579400E-01, 0.62280900E+00, 0.14969100E-01, -.21198800E+00, -.15228600E+00, -.70774700E+00, 0.32030900E-01, 0.22834100E+00, -.59077800E-01, 0.24260400E+00, 0.25598100E-02, 0.10677900E+00, 0.15874400E+00, 0.24302400E+00, -.20609600E-01, 0.52913800E-01, -.36790100E-02, -.60010200E-02, -.31224800E-02, -.17617100E-01, 0.36183600E-01, 0.13078300E+00, -.88056500E-01, -.13565000E+00, -.14512200E+00, 0.20196200E-01, -.11971100E-01, 0.10608000E+00, -.46190500E-01, -.10488000E+00, -.17751000E-01, 0.10432200E+00, -.10411800E+00, -.35184600E-02, -.26380200E-01, -.94583100E-01, -.48249800E-01, -.60939600E-01, 0.17268000E-01, 0.98923700E-01, 0.13651100E-01, 0.60112400E-01, 0.16186900E-01, 0.66827400E-02, -.91961500E-01, 0.28102700E-01, -.18654500E-01, 0.19884200E-01, 0.41049200E-01, -.17018900E+00, -.12981700E+00, -.18359200E+00, 0.41783800E-01, 0.14433200E-01, -.19095100E+00, 0.71595000E-01, -.31126500E-02, -.28716800E-01, -.33477600E-01, -.48318700E-01, 0.17796800E+00, 0.58297500E-01, 0.20727700E-01, 0.52295000E-02, -.10288900E+00, -.14232100E-01, 0.82801300E-01, -.74277100E-02, -.70499700E-02, -.69464300E-01, 0.90574400E-02, -.27347700E+00, 0.23296100E+00, 0.11152000E+00, 0.40698200E-02, 0.11466300E+00, -.13466100E-01, 0.93053300E-01, -.24415400E-01, -.48276300E-01, -.23126800E-02, 0.14730600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 } },
        { { -.45693700E+06, 0.15170700E+06, 0.29602900E+05, 0.46162500E+05, 0.89289000E+05, -.16647600E+06, 0.11280900E+04, 0.29952900E+05, 0.12327700E+06, -.45819000E+05, -.61141100E+04, -.10351700E+05, -.28713000E+05, 0.47969300E+05, 0.68630700E+04, -.56629700E+04, 0.12711100E+06, -.30218400E+05, -.38945600E+04, -.60123600E+04, -.29328300E+05, 0.43192400E+05, -.10902100E+05, -.13333200E+04, -.17356800E+06, 0.53507900E+05, 0.57024400E+04, 0.99234600E+04, 0.40730800E+05, -.59453300E+05, 0.69605700E+04, 0.38757500E+04, -.31995700E+06, 0.88283200E+05, 0.10401400E+05, 0.15421200E+05, 0.74592600E+05, -.10427300E+06, 0.27430900E+05, 0.47450400E+04, 0.37231400E+06, -.12034000E+06, -.14100600E+05, -.23037500E+05, -.85831400E+05, 0.12705000E+06, -.20056300E+05, -.10209200E+05, -.23544500E+06, 0.65176700E+05, 0.10872700E+05, 0.17232800E+05, 0.49484400E+05, -.80479400E+05, 0.11503900E+05, 0.85940200E+04, -.16630800E+06, 0.59147600E+05, 0.10772800E+05, 0.17500100E+05, 0.31639200E+05, -.64475400E+05, -.26547800E+04, 0.10964400E+05, 0.15140800E+06, -.31245900E+05, -.52911200E+04, -.97030400E+04, -.36209600E+05, 0.55872100E+05, 0.44121700E+04, -.35722300E+04, 0.33213600E+06, -.91878600E+05, -.11916100E+05, -.17394600E+05, -.75992400E+05, 0.10784900E+06, -.27062700E+05, -.67369700E+04, 0.14431700E+06, -.41087700E+05, -.38496900E+04, -.68536300E+04, -.35019100E+05, 0.49484400E+05, -.67823600E+04, -.18356700E+04, 0.13295500E+06, -.40390400E+05, -.35178600E+04, -.64249900E+04, -.32477100E+05, 0.45761300E+05, -.55086400E+04, -.17955300E+04, -.32577200E+06, 0.97014900E+05, 0.87027500E+04, 0.15358600E+05, 0.80568700E+05, -.10824000E+06, 0.16891300E+05, 0.42828100E+04, 0.38329600E+06, -.11356700E+06, -.17200200E+05, -.27459100E+05, -.84930600E+05, 0.12994500E+06, -.15944900E+05, -.14257000E+05, 0.19914900E+06, -.66647100E+05, -.80467300E+04, -.12951300E+05, -.43806100E+05, 0.68831000E+05, -.79660500E+04, -.62350900E+04, -.32921600E+06, 0.12440800E+06, 0.11508900E+05, 0.19121400E+05, 0.74191400E+05, -.11229500E+06, 0.16485400E+05, 0.77496000E+04, 0.19098200E+06, -.76831100E+05, -.30652500E+04, -.82488600E+04, -.49299400E+05, 0.66252000E+05, -.84450700E+04, -.17414600E+04, -.13737400E+06, 0.51032400E+05, 0.11219200E+05, 0.16707300E+05, 0.25716500E+05, -.52623300E+05, -.29103500E+04, 0.11978300E+05, -.23168100E+06, 0.97607600E+05, 0.13752700E+05, 0.21846100E+05, 0.47574200E+05, -.84081700E+05, -.59755600E+03, 0.13693000E+05, 0.70318400E+05, -.23738700E+05, 0.58623600E+05, -.38604600E+05, 0.36226100E+03, 0.28050300E+05, 0.26056900E+05, -.16056800E+05, -.63634500E+05, -.54568100E+05, 0.27779700E+05, -.23606400E+05, -.91789700E+03, 0.69951100E+04, 0.26091100E+03, 0.11937300E+05, 0.25096400E+05, 0.38025400E+05, 0.65516700E+05, 0.30249700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12652000E+01, -.44051500E+06, -.65561100E+05, -.75874000E+05, 0.80198500E+05, 0.20748200E+05, 0.75329200E+05, -.80040500E+05, -.21623800E+06, 0.23680800E+06, 0.75430400E+05, 0.91004900E+05, -.39523200E+05, -.94899200E+05, -.49245300E+05, 0.90677300E+05, 0.10011400E+06, 0.58087500E+05, 0.42227100E+04, 0.61386800E+04, -.32307900E+05, 0.32699300E+05, -.20993200E+05, 0.10063100E+05, 0.44755600E+04, -.17443000E+06, -.38403400E+05, -.45735200E+05, 0.48080500E+05, 0.16910300E+05, 0.42487000E+05, -.48248100E+05, -.88001900E+05, -.27461900E+06, -.51153100E+05, -.60678400E+05, 0.81160800E+05, -.73564000E+04, 0.63740600E+05, -.68484800E+05, -.27791000E+05, 0.37180300E+06, 0.80744800E+05, 0.97164200E+05, -.93207300E+05, -.41920000E+05, -.98357800E+05, 0.10262600E+06, -.11806500E+06, -.12946500E+06, -.15070800E+05, -.18402000E+05, 0.52784400E+05, -.28273200E+05, 0.36592200E+05, -.23261300E+05, 0.18720700E+06, -.33508600E+06, -.72327300E+05, -.86934800E+05, 0.36458200E+05, 0.83842700E+05, 0.72378600E+05, -.87931200E+05, -.70495000E+05, 0.30055300E+06, 0.63424500E+05, 0.75813700E+05, -.68360700E+05, -.47574600E+05, -.58928200E+05, 0.78108400E+05, 0.36770700E+05, 0.29290100E+06, 0.64528100E+05, 0.77730600E+05, -.82940600E+05, -.15680600E+05, -.75064400E+05, 0.86143800E+05, 0.99279700E+04, 0.15235400E+06, 0.31758500E+05, 0.38195500E+05, -.43752400E+05, -.78424200E+04, -.36050000E+05, 0.40692900E+05, -.16620300E+05, 0.14230400E+06, 0.34315800E+05, 0.41296900E+05, -.40106100E+05, -.17521100E+05, -.34187800E+05, 0.43204300E+05, -.11502200E+05, -.33013300E+06, -.73828100E+05, -.87943100E+05, 0.98145700E+05, 0.28025500E+05, 0.75940700E+05, -.93238000E+05, 0.99056900E+05, 0.33393200E+06, 0.52394600E+05, 0.60563700E+05, -.90059100E+05, 0.74473600E+04, -.67095600E+05, 0.67229300E+05, -.36391700E+05, 0.16400900E+06, 0.44006900E+05, 0.54097700E+05, -.44273300E+05, -.30067900E+05, -.49735400E+05, 0.56862500E+05, 0.11669600E+06, -.28226700E+06, -.82019000E+05, -.10048400E+06, 0.68443000E+05, 0.71410300E+05, 0.85203500E+05, -.10353000E+06, -.14801300E+06, 0.17788000E+06, 0.70547500E+05, 0.84186700E+05, -.50657500E+05, -.67190200E+05, -.45309800E+05, 0.84540400E+05, 0.18656700E+06, -.29247400E+06, -.64946700E+05, -.78335900E+05, 0.26667400E+05, 0.83615200E+05, 0.63837100E+05, -.79065800E+05, 0.12803200E+06, -.21295800E+06, -.54912000E+05, -.65588000E+05, 0.33472300E+05, 0.59989600E+05, 0.38289500E+05, -.64980700E+05, -.92366600E+04, -.70526000E+05, 0.51006100E+05, 0.38588100E+05, 0.33970500E+05, -.39962300E+05, 0.19817100E+05, 0.49420100E+05, -.40473400E+05, -.10611200E+05, -.39129300E+05, 0.20997700E+05, -.28036500E+04, -.18835700E+05, -.47199500E+05, 0.16585200E+04, 0.36946400E+05, 0.23652100E+05, 0.51645600E+05, 0.98703500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12813700E-01, -.48207100E-01, 0.25033300E+05, 0.30878500E+05, -.32520300E+05, -.20389000E+05, -.34475300E+05, 0.34415200E+05, 0.61383200E+05, -.23578100E+05, -.22607600E+05, -.28274500E+05, 0.13268200E+05, 0.33455900E+05, 0.19109700E+05, -.28922300E+05, -.50331200E+05, 0.10307100E+05, -.13475100E+04, -.15377500E+04, 0.15515100E+05, -.99080500E+04, 0.11165200E+05, -.32104700E+04, 0.61087600E+04, 0.88817400E+03, 0.14134300E+05, 0.17888100E+05, -.19800900E+05, -.88551300E+04, -.19571300E+05, 0.19542300E+05, 0.51161100E+05, -.12818100E+05, 0.19974300E+05, 0.26069500E+05, -.37886500E+05, -.32287300E+04, -.35190600E+05, 0.29600400E+05, -.13655900E+05, 0.33970700E+03, -.30258600E+05, -.38241600E+05, 0.42034800E+05, 0.21065500E+05, 0.43154000E+05, -.42106200E+05, 0.56030500E+05, -.93099300E+04, 0.50517200E+04, 0.60304700E+04, -.22183000E+05, 0.11471800E+05, -.17332400E+05, 0.84304700E+04, -.68335800E+05, 0.19704900E+05, 0.26834000E+05, 0.33567900E+05, -.15666200E+05, -.43581000E+05, -.27858800E+05, 0.35209100E+05, 0.57072000E+05, -.26403400E+05, -.24310800E+05, -.30660300E+05, 0.16864200E+05, 0.31009100E+05, 0.20545800E+05, -.31946800E+05, -.42026900E+05, 0.55751600E+04, -.22187800E+05, -.29029600E+05, 0.37929200E+05, 0.64702400E+04, 0.37407600E+05, -.32636500E+05, -.80190700E+04, -.32062800E+03, -.12128100E+05, -.15556000E+05, 0.17792800E+05, 0.76794500E+04, 0.17091400E+05, -.16965500E+05, -.30268300E+04, -.18102600E+04, -.12015700E+05, -.15332200E+05, 0.16389000E+05, 0.83818300E+04, 0.15917300E+05, -.16593300E+05, 0.12194300E+05, 0.32837300E+04, 0.27429800E+05, 0.35040500E+05, -.37792600E+05, -.12822700E+05, -.34057600E+05, 0.38565300E+05, -.36105800E+05, 0.45795200E+04, -.20674800E+05, -.25788600E+05, 0.35124100E+05, 0.17510400E+04, 0.31011400E+05, -.29790600E+05, -.13368300E+05, -.14871400E+03, -.14118900E+05, -.18291100E+05, 0.21328300E+05, 0.84881200E+04, 0.22852000E+05, -.20080500E+05, 0.18570200E+05, -.49983500E+04, 0.26379300E+05, 0.33987600E+05, -.37894900E+05, -.17118600E+05, -.40156900E+05, 0.37065700E+05, -.52340700E+04, 0.79157900E+03, -.18711700E+05, -.23030900E+05, 0.25872300E+05, 0.13350500E+05, 0.23801900E+05, -.24683500E+05, -.69338900E+05, 0.20999000E+05, 0.23622300E+05, 0.29793200E+05, -.11208700E+05, -.39702900E+05, -.23546800E+05, 0.31050700E+05, -.15916800E+05, -.40954700E+03, 0.17418400E+05, 0.21866300E+05, -.18322900E+05, -.17378700E+05, -.20043300E+05, 0.23450100E+05, -.15726800E+04, 0.27837200E+05, -.15207900E+05, -.15741000E+05, -.74532200E+04, 0.37666200E+04, -.37362500E+04, -.19710500E+05, 0.16841300E+05, 0.14692200E+05, 0.20905300E+04, -.27706200E+04, 0.22803200E+03, 0.11261900E+05, 0.22116000E+05, 0.45409300E+04, -.95227900E+03, 0.18722300E+03, -.20409500E+05, -.22409500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.46472600E-01, 0.99173400E-03, 0.13435900E+00, -.11969500E+04, 0.23394600E+04, 0.51168700E+04, 0.89824800E+04, -.78505800E+03, -.46359700E+04, 0.18730700E+04, 0.74094500E+03, 0.15039100E+04, -.34357800E+03, -.44456500E+04, -.46739100E+04, 0.13547000E+04, 0.29788800E+04, -.11153200E+04, 0.21973100E+01, 0.16370800E+03, -.12177500E+04, -.84152100E+03, -.16434200E+04, 0.14896900E+03, -.14021900E+03, -.15008500E+03, -.22713200E+03, -.75787000E+03, 0.10754200E+04, 0.20639200E+04, 0.38358700E+04, -.67595700E+03, -.57929500E+04, 0.38598300E+04, -.96044000E+02, -.68631400E+03, 0.29855300E+04, 0.16834000E+04, 0.48753900E+04, -.65118400E+03, 0.22429500E+04, -.17059800E+03, 0.72190200E+03, 0.17804800E+04, -.30855900E+04, -.43115300E+04, -.75421200E+04, 0.16808500E+04, 0.28859400E+03, -.27677400E+03, -.41919400E+03, -.97258000E+03, 0.11830000E+04, 0.17757900E+04, 0.30887100E+04, -.86799100E+03, 0.52354200E+03, -.78305100E+03, -.73618400E+03, -.15319400E+04, 0.23208100E+04, 0.50419900E+04, 0.69240900E+04, -.13735200E+04, -.69038200E+04, 0.30592100E+04, 0.95192100E+03, 0.18672400E+04, 0.27766000E+02, -.45891600E+04, -.47711300E+04, 0.17286300E+04, 0.34304200E+04, -.28187500E+04, 0.47480500E+03, 0.12021700E+04, -.28557800E+04, -.21578600E+04, -.51369300E+04, 0.12236000E+04, 0.90335500E+03, -.22393900E+03, 0.88309600E+02, 0.49561400E+03, -.99830700E+03, -.18061100E+04, -.32701800E+04, 0.42805600E+03, 0.40235700E+03, -.20124500E+02, 0.11176800E+03, 0.51365300E+03, -.82955500E+03, -.17372300E+04, -.31039700E+04, 0.45210300E+03, -.10164600E+04, -.12961100E+03, -.17374200E+02, -.86156100E+03, 0.13392800E+04, 0.21215500E+04, 0.59149800E+04, -.83800200E+03, 0.36563300E+04, -.97544800E+03, -.48796900E+03, 0.27151900E+03, -.18999800E+04, -.10549200E+04, -.62290600E+04, 0.15144200E+03, -.17524600E+04, 0.73417400E+03, 0.75514700E+03, 0.14098300E+04, -.12667300E+04, -.32362800E+04, -.40584700E+04, 0.13004700E+04, -.14650000E+04, -.13380500E+03, -.58278600E+03, -.15510100E+04, 0.27402200E+04, 0.40700100E+04, 0.73903400E+04, -.13802800E+04, 0.34665600E+04, -.13593400E+04, -.33101900E+03, 0.14169500E+03, -.14129400E+04, -.20578500E+04, -.49428000E+04, 0.70001300E+02, -.15514100E+03, -.57832200E+03, -.56167100E+03, -.12182700E+04, 0.20835500E+04, 0.35993300E+04, 0.59024600E+04, -.11401300E+04, 0.13168400E+04, -.64369600E+02, -.18639400E+03, -.92032300E+03, 0.97284500E+03, 0.31796900E+04, 0.48889800E+04, -.69490800E+03, 0.25706000E+03, -.21920800E+04, 0.48078300E+03, 0.69722600E+03, -.16275400E+03, -.41278100E+04, -.26511300E+04, 0.11576300E+03, 0.61288500E+03, -.12614600E+04, -.40108600E+04, 0.29733300E+03, 0.52739100E+03, -.33278900E+04, -.32587500E+04, 0.11838900E+04, -.11947500E+04, -.98797200E+03, -.12716500E+04, 0.15865000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15319300E+00, 0.65523000E-03, 0.27626900E+00, -.23739200E+01, -.71424600E+04, -.41527700E+04, -.50520900E+04, -.28482800E+04, 0.10015700E+05, -.51058500E+04, -.40299600E+04, -.46883300E+04, 0.59372200E+04, 0.51828200E+04, 0.23602500E+04, -.35443400E+04, 0.35386500E+04, 0.80071700E+03, -.16777400E+03, -.34181100E+03, 0.11435200E+03, 0.25894200E+04, 0.79566800E+03, 0.15746500E+03, -.37545700E+04, 0.11514900E+04, 0.19451100E+04, 0.23353300E+04, -.41789200E+04, -.32597500E+04, -.25775000E+04, 0.12753300E+04, 0.43611800E+04, -.57737900E+04, 0.49414500E+03, 0.73786100E+03, -.59091400E+04, -.17616900E+04, -.45468000E+04, -.89421300E+03, 0.31383000E+03, 0.43628700E+03, -.26870200E+04, -.31334400E+04, 0.90158100E+04, 0.45654800E+04, 0.58156800E+04, -.98436400E+03, -.12542600E+05, 0.24137400E+04, 0.14559200E+04, 0.21241700E+04, -.48649200E+03, -.60408500E+04, -.18859400E+04, 0.91509100E+03, 0.79244500E+03, 0.20358800E+04, 0.10509000E+04, 0.10349200E+04, -.52110500E+04, -.29888000E+04, -.42638100E+04, -.46655200E+03, 0.19323400E+05, -.85393700E+04, -.52831300E+04, -.61942000E+04, 0.48861400E+04, 0.85406300E+04, 0.22438100E+04, -.47224500E+04, -.47139200E+04, 0.69421800E+04, -.62513300E+03, -.89113800E+03, 0.62769000E+04, 0.26509900E+04, 0.48665000E+04, 0.62314200E+03, 0.24149700E+04, -.48770800E+03, -.16434400E+04, -.19325000E+04, 0.37570400E+04, 0.26282100E+04, 0.21301600E+04, -.10557700E+04, 0.34286500E+04, -.11168500E+04, -.18766200E+04, -.22070200E+04, 0.37420600E+04, 0.28121000E+04, 0.19817600E+04, -.13640500E+04, -.60646100E+04, 0.17477100E+04, 0.34345200E+04, 0.38766000E+04, -.77387300E+04, -.47084300E+04, -.33210600E+04, 0.19945500E+04, -.88993100E+03, 0.19672000E+04, 0.16954500E+02, 0.96877900E+02, 0.55733300E+04, 0.19639500E+04, 0.32588500E+04, 0.22301400E+04, 0.33092900E+04, -.18829200E+03, -.15101000E+04, -.19422100E+04, 0.36110100E+04, 0.35771500E+04, 0.29539400E+04, -.90553600E+03, -.38718700E+04, 0.84048500E+03, 0.26714700E+04, 0.34167500E+04, -.69965300E+04, -.55379700E+04, -.58486700E+04, 0.15090700E+04, 0.35246100E+04, -.18810000E+04, -.36471800E+04, -.42191200E+04, 0.77227700E+04, 0.41168100E+04, 0.32811200E+04, -.29622400E+04, 0.10092600E+05, -.20040900E+04, -.37569300E+03, -.80828000E+03, -.58347700E+04, 0.88627500E+03, -.37569700E+04, -.19195400E+04, -.16770800E+04, 0.14254500E+04, 0.13404600E+04, 0.16307400E+04, -.53704600E+04, -.26677200E+04, -.30785500E+04, 0.85731800E+02, 0.18383700E+04, 0.28686800E+04, -.18678300E+04, -.22666800E+04, -.28547400E+03, 0.48910800E+03, 0.98297700E+03, 0.17330000E+03, 0.24120000E+04, 0.34004800E+04, 0.86139200E+03, -.14108900E+04, -.17691700E+03, 0.62795400E+04, 0.58174900E+04, 0.76953300E+03, -.25690300E+04, 0.12620600E+04, -.45569600E+03, -.23222900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.28452000E+00, 0.56215400E-01, -.49353000E+00, 0.69246800E+00, 0.55584300E+00, -.14762100E+05, -.18810100E+05, -.72437700E+03, 0.29330700E+04, -.12730300E+04, 0.12211200E+04, 0.94232900E+03, -.34343800E+04, 0.89291400E+04, 0.98174400E+04, 0.12373600E+04, -.61292600E+04, 0.41705900E+04, -.13123600E+03, 0.34622100E+03, 0.19160800E+04, 0.42034100E+04, 0.31142600E+04, 0.42542800E+03, 0.97233400E+03, -.40015300E+03, -.97372800E+03, -.13002000E+04, 0.14104800E+04, -.47841200E+04, -.69392500E+04, -.14188800E+04, 0.72487300E+04, -.67677000E+04, -.71453200E+03, -.22207200E+04, -.82005300E+03, -.68606700E+04, -.75109800E+04, -.23554500E+04, -.55285800E+04, 0.15764800E+04, 0.94690100E+03, 0.17674500E+04, -.59305400E+03, 0.11505000E+05, 0.13259700E+05, 0.19717500E+04, -.22500600E+04, -.73086200E+03, 0.10638000E+04, 0.10465300E+04, -.43629800E+03, -.47242400E+04, -.56765100E+04, 0.89973700E+03, 0.10134800E+05, -.19247200E+04, -.63547600E+03, -.73001800E+03, -.31185700E+04, -.11644300E+05, -.14205200E+05, -.11259400E+04, 0.65169600E+04, -.26764200E+04, 0.14709100E+04, 0.11732300E+04, -.49466700E+04, 0.70885900E+04, 0.90902500E+04, 0.13535100E+04, -.48723000E+03, 0.39182800E+04, -.11090100E+03, 0.12117900E+04, -.22104900E+02, 0.72949400E+04, 0.69062900E+04, 0.11147900E+04, -.31776900E+04, 0.15837700E+04, 0.13037800E+04, 0.18383000E+04, -.11085400E+04, 0.46022600E+04, 0.58793200E+04, 0.19530200E+04, -.24304000E+04, 0.11902400E+04, 0.13208600E+04, 0.17601600E+04, -.14500800E+04, 0.40258400E+04, 0.56174800E+04, 0.18417500E+04, 0.84374300E+02, 0.87665300E+02, -.27136600E+04, -.37286000E+04, 0.52502100E+04, -.41243600E+04, -.99273000E+04, -.36479100E+04, -.97483000E+03, 0.36320100E+03, 0.10198600E+04, 0.16941500E+04, -.19654700E+04, 0.39348600E+04, 0.11669300E+05, 0.18369300E+04, 0.38672900E+04, -.10671700E+04, -.50228600E+03, -.22348600E+03, -.63232700E+03, 0.81082000E+04, 0.70664400E+04, -.27282600E+02, 0.41234500E+04, -.26528600E+03, -.10491500E+04, -.19818400E+04, -.58074900E+01, -.10192800E+05, -.12972700E+05, -.22898800E+04, -.13387700E+05, 0.58914400E+04, 0.38174400E+04, 0.47395500E+04, -.20467100E+04, 0.45947900E+04, 0.95092500E+04, 0.47082700E+04, 0.47972000E+04, 0.48514600E+03, 0.30021500E+02, 0.11032000E+03, -.20214000E+04, -.91753500E+04, -.11834200E+05, -.13763900E+03, -.19427300E+04, 0.76116300E+03, -.49713200E+03, -.43003300E+03, 0.16885700E+04, -.78499700E+04, -.10167900E+05, -.82923200E+03, -.14282100E+04, 0.17769200E+04, 0.24353500E+04, 0.10874900E+04, 0.25299900E+04, 0.10205300E+05, 0.73021900E+04, 0.26499900E+04, -.53980000E+04, 0.53685400E+03, 0.10490900E+05, -.36199200E+03, -.13715100E+04, 0.55407500E+04, 0.41493300E+04, -.37226100E+04, 0.45537200E+04, 0.32224500E+04, 0.71609800E+04, 0.15495500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.28315800E-01, 0.11077800E+00, -.63656100E+00, 0.57825500E+01, -.12617700E-02, 0.40872800E-01, 0.48093900E+05, 0.34658800E+04, -.18915100E+05, 0.71692600E+04, 0.65978700E+03, 0.13045500E+04, 0.62305600E+04, -.67134400E+04, -.14133800E+05, -.10940700E+03, -.98244500E+04, 0.34342400E+03, 0.14222700E+04, 0.14320700E+04, 0.16900400E+04, 0.21763700E+04, -.39678300E+04, 0.11952900E+04, 0.16106800E+04, -.29812000E+03, 0.15271000E+04, 0.23166600E+04, -.27312000E+04, -.48124800E+03, 0.13680600E+05, 0.33499900E+04, -.56139800E+04, 0.16538100E+05, 0.20681900E+04, 0.50894000E+04, -.25219600E+04, -.67478700E+04, 0.11619000E+05, 0.55423500E+04, -.22687400E+04, 0.33921000E+04, -.16713400E+04, -.35078600E+04, 0.48844700E+04, 0.48646000E+04, -.23199700E+05, -.51940000E+04, 0.81329300E+04, 0.37136800E+04, -.18637300E+04, -.17514100E+04, -.48807300E+03, 0.38315700E+04, 0.12421100E+05, -.10037100E+04, -.21145900E+05, 0.37185400E+03, 0.45501300E+04, 0.52051000E+04, 0.10371800E+04, -.15020400E+05, 0.26528200E+05, 0.70219200E+04, -.17645300E+05, 0.53237800E+04, -.30767800E+03, 0.87328600E+02, 0.67285500E+04, -.74890300E+04, -.15969000E+05, -.17818400E+04, -.23075800E+04, -.14990800E+05, -.11777100E+04, -.36457300E+04, 0.35560600E+04, 0.57640300E+04, -.14826700E+05, -.45143900E+04, -.31873700E+04, 0.94669200E+03, -.14782000E+04, -.22591100E+04, 0.31442400E+04, 0.17600700E+04, -.10824600E+05, -.31390700E+04, -.17652400E+04, 0.40106200E+03, -.15153300E+04, -.22451500E+04, 0.28524300E+04, 0.13235500E+04, -.10498300E+05, -.30516700E+04, -.74471500E+04, 0.43714800E+04, 0.36084400E+04, 0.61484700E+04, -.45716700E+04, -.32214500E+03, 0.23319500E+05, 0.75484300E+04, 0.24149500E+05, -.11274800E+05, -.33693300E+04, -.58803600E+04, -.16938300E+04, 0.28525000E+04, -.32924900E+05, -.76190900E+04, -.15983300E+05, 0.40192300E+04, 0.87273500E+03, 0.43406400E+03, 0.41833300E+04, -.26273600E+04, -.12102500E+05, -.69583500E+03, -.88353000E+04, -.67452200E+03, 0.41329900E+04, 0.64893100E+04, -.26245100E+04, -.73413900E+04, 0.23904600E+05, 0.80006600E+04, 0.12188800E+05, -.35895300E+04, -.46281100E+04, -.60780900E+04, 0.31462000E+04, 0.93201000E+04, -.17402100E+05, -.68436500E+04, -.20717200E+05, 0.35993700E+03, 0.37113600E+04, 0.44246900E+04, 0.15786000E+04, -.11398500E+05, 0.24233000E+05, 0.60905300E+04, 0.50442600E+04, -.50964400E+03, -.71483300E+02, 0.44541800E+02, -.20857000E+04, 0.41554300E+04, 0.21877900E+05, 0.15870600E+04, -.75806300E+03, -.65371900E+03, 0.46824400E+04, -.49833900E+04, -.21299100E+04, -.21362200E+05, -.15285100E+05, -.35746400E+04, 0.75635600E+04, -.77308100E+03, -.17867300E+05, -.15254200E+04, 0.19134700E+04, -.71994400E+04, -.28321900E+04, 0.61747200E+04, -.10067800E+05, -.40596900E+04, -.86697500E+04, 0.69855200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10343800E+00, 0.78275100E-01, -.55487400E+00, 0.24085700E+01, -.30682100E+00, -.88660800E-01, 0.62932300E+00, -.21380200E+04, -.24130500E+05, 0.12416900E+05, 0.82549200E+04, 0.10509500E+05, -.34760100E+04, -.13873600E+05, -.11305400E+05, 0.12199800E+05, -.12209000E+05, 0.68093000E+03, -.12564300E+04, -.15712000E+04, 0.47735600E+04, -.31982600E+04, 0.47153100E+04, -.19321400E+04, 0.18939500E+05, -.69349000E+04, -.22617200E+04, -.29485400E+04, -.21768200E+04, 0.73626200E+04, 0.17661300E+04, -.36194900E+04, 0.46238900E+05, -.15466300E+05, -.26680000E+04, -.34658700E+04, -.88475800E+04, 0.16970100E+05, -.32703000E+04, -.34052000E+04, -.54799700E+05, 0.20052600E+05, 0.70320000E+04, 0.92127700E+04, 0.59188000E+04, -.22137500E+05, -.41347400E+04, 0.10193300E+05, 0.10319000E+05, 0.93340500E+03, 0.19714100E+04, 0.25831800E+04, -.56350800E+04, 0.94611200E+03, -.70364500E+04, 0.23153100E+04, 0.41350200E+05, -.21058600E+05, -.12438000E+05, -.16016700E+05, 0.51920500E+04, 0.23089400E+05, 0.18925600E+05, -.17741100E+05, -.27934800E+05, 0.12534800E+05, 0.82523300E+04, 0.10362200E+05, -.22889000E+04, -.13743900E+05, -.10433400E+05, 0.12152600E+05, -.55614600E+05, 0.21549500E+05, 0.54385600E+04, 0.69630100E+04, 0.79127500E+04, -.19730600E+05, 0.36991400E+03, 0.72370000E+04, -.16545900E+05, 0.56897100E+04, 0.17948200E+04, 0.23287200E+04, 0.20914000E+04, -.66555600E+04, -.15038600E+04, 0.28155800E+04, -.16111700E+05, 0.59047100E+04, 0.20687200E+04, 0.26781200E+04, 0.17013400E+04, -.66021600E+04, -.19998700E+04, 0.32194200E+04, 0.41470800E+05, -.13892900E+05, -.38694900E+04, -.52348800E+04, -.62729000E+04, 0.14675300E+05, 0.11670700E+04, -.60401500E+04, -.24654600E+05, 0.61589500E+04, -.37112400E+02, 0.37748800E+03, 0.61430900E+04, -.69657500E+04, 0.30155000E+04, 0.99008500E+03, -.24441200E+05, 0.92753200E+04, 0.34724700E+04, 0.43926900E+04, 0.20983500E+04, -.95905000E+04, -.20857100E+04, 0.51836800E+04, 0.41654100E+05, -.16686300E+05, -.54857100E+04, -.69764000E+04, -.39155700E+04, 0.16994400E+05, 0.42017700E+04, -.81650300E+04, -.23297100E+05, 0.99744400E+04, 0.24822300E+04, 0.35081300E+04, 0.30999800E+04, -.98749600E+04, -.32994200E+04, 0.42766300E+04, 0.39271100E+05, -.20869900E+05, -.11863700E+05, -.15434100E+05, 0.50993100E+04, 0.21421700E+05, 0.18436800E+05, -.16896700E+05, 0.29981200E+04, -.19329700E+04, -.11966600E+04, -.14131500E+04, 0.34836400E+03, 0.18755100E+04, 0.61810500E+03, -.28308800E+04, -.84741800E+04, -.13469700E+04, -.19853000E+04, 0.39605600E+04, 0.13145200E+04, -.42999100E+04, -.32730000E+04, 0.30680200E+04, 0.42020200E+04, 0.37875400E+04, -.35151700E+04, 0.33311000E+04, 0.26750500E+03, -.12672500E+04, -.18654000E+04, -.19369400E+04, -.36950900E+04, -.48597600E+04, -.24867100E+04, 0.11727800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12138900E-01, -.11052900E+00, 0.96925300E+00, -.40670600E+01, -.46720000E+00, 0.15907900E+00, -.52307200E+00, 0.63954100E+00, 0.14846000E+05, -.92313000E+04, -.64654200E+04, -.82726100E+04, 0.38268000E+04, 0.10374000E+05, 0.11785600E+05, -.92755400E+04, 0.35960500E+04, 0.40276700E+04, -.12649700E+04, -.17630600E+04, 0.47969800E+03, 0.24604900E+04, 0.17206300E+04, -.12876700E+04, -.21475800E+04, -.46409400E+03, 0.44900200E+04, 0.61499700E+04, -.43854500E+04, -.55678200E+04, -.80541700E+04, 0.62869100E+04, 0.12326400E+04, -.94383900E+04, 0.76756600E+04, 0.11054200E+05, -.10051000E+05, -.10858900E+05, -.16790600E+05, 0.10308700E+05, 0.85261200E+04, -.16766600E+04, -.11006000E+05, -.14972300E+05, 0.11128100E+05, 0.14711600E+05, 0.22060900E+05, -.14913000E+05, -.36647200E+04, -.60657800E+04, 0.72573100E+03, 0.99597600E+03, 0.43479100E+03, -.25681300E+04, 0.51851600E+02, 0.74671700E+03, -.34893000E+05, 0.23404400E+05, 0.11653000E+05, 0.14600800E+05, -.52376400E+04, -.18516400E+05, -.15418300E+05, 0.15189600E+05, 0.22762900E+05, -.10904100E+05, -.68194500E+04, -.85901400E+04, 0.17128000E+04, 0.11923400E+05, 0.11085700E+05, -.94280500E+04, 0.10405600E+05, 0.39947200E+04, -.11231100E+05, -.15694700E+05, 0.11150000E+05, 0.13939600E+05, 0.19857700E+05, -.15285900E+05, 0.94154400E+03, 0.11882600E+04, -.38760100E+04, -.54540000E+04, 0.40032900E+04, 0.45665600E+04, 0.74805700E+04, -.55018800E+04, 0.23508800E+04, 0.14124400E+03, -.38051800E+04, -.53159400E+04, 0.35413200E+04, 0.48027400E+04, 0.70584300E+04, -.54412900E+04, -.82845800E+04, 0.10651400E+03, 0.63862800E+04, 0.94508200E+04, -.49675200E+04, -.10481500E+05, -.13324900E+05, 0.92612300E+04, 0.71682300E+04, 0.20204600E+04, -.16105500E+04, -.28563600E+04, 0.24752700E+03, 0.61112200E+04, 0.33823100E+04, -.21155600E+04, 0.43690600E+04, 0.86299400E+03, -.64238600E+04, -.88266500E+04, 0.63548800E+04, 0.72104700E+04, 0.10633500E+05, -.90755500E+04, -.32888400E+04, 0.23617300E+03, 0.11121100E+05, 0.15377000E+05, -.12048400E+05, -.12692000E+05, -.18821800E+05, 0.15677700E+05, -.90682300E+03, 0.62168300E+03, -.58592400E+04, -.82814400E+04, 0.62876100E+04, 0.65338400E+04, 0.11662000E+05, -.85650700E+04, -.30011300E+05, 0.20974100E+05, 0.10153700E+05, 0.12808500E+05, -.51366600E+04, -.16058100E+05, -.14569100E+05, 0.13343300E+05, 0.90584900E+04, -.20611200E+04, 0.87436300E+03, 0.13006600E+04, -.34392200E+04, 0.14424700E+03, -.41212700E+04, 0.16791600E+04, 0.12246300E+04, 0.57496700E+04, -.43803200E+04, -.76384700E+04, -.20203600E+04, 0.63664700E+04, 0.22023500E+04, -.65924000E+04, 0.17595300E+04, 0.23744900E+04, 0.56794900E+04, -.12054100E+04, -.20540500E+03, 0.51549900E+04, 0.64317700E+04, 0.16059200E+04, 0.29107400E+04, 0.18755800E+04, -.32391200E+04, -.57351000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.69217400E+00, 0.36581600E+00, 0.67409200E+00, 0.21283300E+01, 0.76393700E+00, 0.12304700E+01, -.17809400E-01, 0.49460200E-01, 0.10621200E+01, -.13159400E+05, 0.17652200E+04, 0.25082900E+04, -.18177200E+04, -.32650900E+04, -.74010900E+04, 0.35293800E+04, 0.46396100E+04, 0.29368300E+05, 0.21508400E+04, 0.33598900E+04, -.35181700E+04, -.20635000E+03, -.49167900E+04, 0.31218800E+04, -.87240200E+04, -.50706000E+04, -.42695000E+04, -.62557500E+04, 0.65458400E+04, 0.25383000E+04, 0.90368200E+04, -.66549500E+04, -.31214000E+05, -.12128700E+05, -.74655100E+04, -.12027400E+05, 0.17663000E+05, 0.25607700E+04, 0.21219500E+05, -.11872600E+05, 0.11193900E+05, 0.11168700E+05, 0.10553400E+05, 0.15119400E+05, -.15360000E+05, -.85660700E+04, -.22292000E+05, 0.15672800E+05, -.68139100E+04, -.35344500E+05, -.12080400E+04, -.18283600E+04, 0.24185300E+04, 0.53817000E+03, 0.31908100E+04, -.17020100E+04, 0.22349800E+05, 0.15377600E+05, -.95437200E+04, -.11803600E+05, 0.63469000E+04, 0.11410300E+05, 0.10768500E+05, -.13037400E+05, 0.21343700E+03, -.30948200E+04, 0.57031900E+04, 0.78903600E+04, -.59169300E+04, -.43710900E+04, -.10726400E+05, 0.98831800E+04, 0.32308700E+05, 0.16260200E+05, 0.84586700E+04, 0.13249500E+05, -.18870000E+05, -.46138500E+02, -.23380400E+05, 0.13186200E+05, 0.12065600E+05, 0.41678100E+04, 0.40400700E+04, 0.61903100E+04, -.72736000E+04, -.85773900E+03, -.93751500E+04, 0.66562200E+04, 0.93119500E+04, 0.33040400E+04, 0.32489800E+04, 0.50807800E+04, -.55862200E+04, -.12174900E+04, -.80638100E+04, 0.54590400E+04, -.18249700E+05, -.12785400E+05, -.61392300E+04, -.10466400E+05, 0.10939400E+05, 0.43976600E+04, 0.17200500E+05, -.11086800E+05, 0.13530500E+05, 0.21223900E+05, 0.21493500E+04, 0.43310800E+04, -.61638600E+04, -.24040900E+04, -.82907700E+04, 0.42202300E+04, 0.11718300E+05, 0.95448800E+04, 0.44985300E+04, 0.68789200E+04, -.77478200E+04, -.14110900E+04, -.10561100E+05, 0.70467800E+04, -.11573000E+05, -.50094400E+04, -.84867100E+04, -.12875200E+05, 0.11977900E+05, 0.72208800E+04, 0.17178200E+05, -.12709400E+05, 0.10974200E+05, -.33370200E+03, 0.13787900E+04, 0.29687300E+04, -.28368300E+04, -.14444700E+04, -.96145100E+04, 0.26744400E+04, 0.14391900E+05, 0.19210200E+05, -.70419300E+04, -.86374600E+04, 0.61373100E+04, 0.81873600E+04, 0.99173400E+04, -.96254100E+04, 0.29087100E+04, 0.13211600E+05, 0.79878600E+03, 0.67434700E+03, -.18231200E+04, 0.32939000E+04, 0.10047700E+04, 0.10113000E+04, 0.49966300E+04, -.72667800E+04, 0.69043300E+04, 0.60789500E+04, 0.29619100E+04, -.77243300E+04, 0.53134000E+03, 0.59072200E+04, -.61655200E+04, -.65410300E+04, -.81738000E+04, -.21520200E+03, 0.98670100E+02, -.42273300E+04, -.70481100E+04, 0.14446100E+04, -.10541200E+03, 0.25213200E+04, 0.76477900E+04, 0.52993500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23143500E+00, -.88059800E-01, 0.61080000E+00, -.24271900E+01, -.18726500E+00, -.27859000E+00, -.41326300E+00, -.54048400E+00, -.25546800E-03, -.63640100E-01, 0.16500200E+04, 0.15714000E+04, -.18144100E+04, -.26267300E+03, 0.48736900E+04, 0.16939000E+04, -.30262000E+04, -.40207200E+03, -.28258500E+03, -.39526600E+03, 0.11874600E+04, -.18725300E+04, 0.50478700E+03, -.68584200E+03, 0.61655600E+03, 0.93985400E+03, -.26934500E+03, -.20334400E+03, 0.22471600E+03, 0.22272000E+03, -.13791700E+04, -.11450300E+03, 0.11031100E+05, -.36474000E+04, -.11087100E+04, -.15042600E+04, -.20351400E+04, 0.69097100E+04, 0.22648000E+03, -.10449500E+04, -.10666300E+05, 0.45873100E+03, 0.10879500E+04, 0.14592800E+04, 0.21463100E+04, -.53744200E+04, 0.18055800E+04, 0.10324600E+04, 0.14879100E+04, 0.60417700E+03, 0.90813300E+03, 0.12374700E+04, -.18109200E+04, -.80781100E+02, -.25738700E+04, 0.13554400E+04, -.12089200E+05, 0.82060800E+04, 0.20106300E+04, 0.24882100E+04, 0.91431600E+03, -.26542700E+04, 0.10211800E+04, 0.25433700E+04, -.42882500E+03, -.82945600E+03, 0.13701700E+04, 0.10548800E+04, -.12805100E+04, 0.18748300E+04, 0.73020000E+04, 0.12880200E+04, -.10606500E+05, 0.48644500E+04, 0.73401800E+03, 0.11319700E+04, 0.26521500E+04, -.37191800E+04, 0.69413900E+03, 0.76684800E+03, -.89632500E+03, -.80942700E+03, 0.42572900E+03, 0.38933800E+03, -.38942300E+03, -.72411600E+03, 0.96545000E+03, 0.27128300E+03, -.10003700E+04, -.59253000E+03, 0.49320700E+03, 0.47278600E+03, -.46480400E+03, -.53754300E+03, 0.11235100E+04, 0.37494000E+03, 0.19371900E+05, -.54387300E+04, -.37778600E+04, -.45637500E+04, -.42853400E+03, 0.60761200E+04, -.31666700E+04, -.42604800E+04, -.15143100E+05, 0.40926700E+04, 0.22027000E+04, 0.27695700E+04, 0.10463800E+04, -.49202800E+04, 0.32118900E+03, 0.24381700E+04, 0.51756600E+03, -.96754400E+03, -.48942500E+03, -.65075000E+03, 0.85417000E+03, 0.21964000E+03, 0.20928200E+04, -.76782100E+03, -.14931300E+04, 0.38928600E+04, 0.55764200E+03, 0.71963300E+03, -.30026500E+03, 0.87222500E+03, -.70671600E+03, 0.99376300E+03, -.26952200E+04, 0.21310100E+03, 0.16375400E+04, 0.19117600E+04, -.20787200E+04, -.20098000E+04, -.20172600E+03, 0.16509000E+04, -.80252000E+04, 0.55801500E+04, 0.13499200E+04, 0.15616700E+04, 0.43083700E+03, -.19455200E+04, 0.16718700E+04, 0.16433800E+04, 0.42554600E+04, -.21395100E+04, -.16869700E+04, -.19873500E+04, 0.90831800E+03, 0.23539900E+04, -.13457900E+04, -.20415800E+04, -.49570400E+03, -.13700600E+03, -.86126500E+03, 0.21729100E+02, 0.60213600E+02, 0.13160400E+04, 0.11035000E+04, -.38652700E+03, -.99205100E+03, 0.41067700E+03, 0.98389400E+03, 0.32564700E+03, -.23132300E+03, 0.44147800E+03, -.36452000E+03, -.94846500E+03, 0.67381200E+03, -.25591600E+03, 0.64543500E+03, -.57591200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.28910200E-01, -.33042900E-01, 0.48419200E+00, -.25371300E+01, -.15544500E+00, 0.14448700E+00, -.44900600E+00, 0.15512700E+00, 0.25835700E+00, 0.21313600E+00, -.41803600E+00, -.52404900E+03, -.20646000E+01, 0.19056300E+04, 0.61707300E+04, -.82811400E+03, -.31717400E+04, -.27510400E+04, -.14693600E+04, -.18762000E+04, 0.23081900E+04, 0.22151500E+03, 0.24608200E+04, -.17826100E+04, 0.63161100E+04, -.18177800E+04, 0.25413600E+04, 0.37282000E+04, -.40989100E+04, -.12185500E+04, -.61177800E+04, 0.38501800E+04, 0.22552000E+05, -.35279300E+04, 0.54579200E+04, 0.79911300E+04, -.11760000E+05, 0.64861900E+03, -.11003900E+05, 0.79508200E+04, -.96581800E+04, 0.29677400E+04, -.66940400E+04, -.91502200E+04, 0.10027200E+05, 0.36757200E+04, 0.12076600E+05, -.93089800E+04, 0.16165700E+04, 0.48767800E+04, 0.15030900E+04, 0.18726400E+04, -.20009100E+04, -.12486700E+04, -.23227200E+04, 0.17336100E+04, -.16545400E+05, 0.39786200E+04, 0.49805100E+04, 0.62327400E+04, -.20276100E+04, -.75004000E+04, -.52787700E+04, 0.66037400E+04, 0.21189000E+04, -.24161200E+04, -.10096900E+04, -.18378700E+04, 0.26514900E+03, 0.30074900E+04, 0.67748200E+04, -.22668900E+04, -.21224200E+05, 0.22695900E+04, -.65582100E+04, -.94900500E+04, 0.12777700E+05, 0.60112500E+02, 0.12687500E+05, -.95473000E+04, -.72745600E+04, 0.22101200E+04, -.22874800E+04, -.35194200E+04, 0.40298900E+04, 0.53566400E+03, 0.57864600E+04, -.36478200E+04, -.59903200E+04, 0.18425400E+04, -.19223000E+04, -.30275200E+04, 0.33270400E+04, 0.71198800E+03, 0.54058700E+04, -.31409800E+04, 0.17537700E+05, -.56772900E+04, 0.24772000E+04, 0.46026200E+04, -.61787600E+04, 0.34496800E+03, -.10339500E+05, 0.47194500E+04, -.10526100E+05, 0.26797000E+04, -.86580800E+03, -.17599000E+04, 0.29536200E+04, -.68240400E+03, 0.39436600E+04, -.16915900E+04, -.71522100E+04, 0.60783300E+03, -.37801600E+04, -.55367600E+04, 0.61218200E+04, 0.16763500E+04, 0.78208600E+04, -.56356300E+04, 0.95302100E+04, -.46760200E+04, 0.72184300E+04, 0.10513600E+05, -.10164500E+05, -.44012800E+04, -.13217500E+05, 0.10561400E+05, -.11014000E+05, 0.54254200E+04, -.19957300E+04, -.33644000E+04, 0.41517500E+04, 0.55601700E+03, 0.89203200E+04, -.33979100E+04, -.13421900E+05, 0.19412000E+04, 0.39763200E+04, 0.49228700E+04, -.18929400E+04, -.59466100E+04, -.39884300E+04, 0.52986600E+04, 0.67884200E+04, -.32493800E+04, -.90531100E+03, -.72270400E+03, -.56684800E+03, 0.86921000E+03, -.29021100E+04, -.78898600E+03, -.32245800E+04, 0.41481900E+04, -.43416000E+04, -.45270800E+04, -.13064500E+04, 0.25650200E+04, -.65628000E+02, -.41964500E+04, 0.26977100E+04, 0.36166300E+04, 0.29643100E+04, 0.62523300E+03, -.15007000E+03, 0.28441700E+04, 0.38673200E+04, -.17147500E+03, 0.13962900E+04, -.63407100E+03, -.33245300E+04, -.41449700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.46068700E+00, 0.51941700E-02, -.12548200E-01, -.15629200E+01, 0.12966800E+01, -.23535200E+00, 0.16516300E+00, -.49902300E+00, -.26001200E+00, 0.47810700E-01, -.78773600E+00, -.28359600E-01, 0.14795300E+04, 0.10750400E+04, 0.27988900E+04, 0.32937200E+03, -.21208200E+04, -.45943200E+03, -.95284300E+02, -.72304500E+02, 0.39628500E+03, -.91155200E+03, 0.77791000E+03, -.27512400E+03, -.18535900E+04, 0.20760000E+04, 0.30299900E+02, -.15689100E+03, 0.21957500E+03, -.34794400E+03, 0.18992100E+03, -.14176000E+03, 0.12757500E+05, -.55314600E+04, -.31306500E+04, -.45794200E+04, 0.15604900E+03, 0.58288900E+04, 0.11840300E+04, -.41098400E+04, -.10066400E+05, 0.53214000E+03, 0.22982100E+04, 0.33957300E+04, 0.71115200E+03, -.48478400E+04, -.61183100E+02, 0.31413400E+04, -.23188500E+03, 0.92003600E+03, 0.79416600E+03, 0.94819900E+03, -.71438900E+03, -.45251200E+03, -.20317200E+04, 0.11558300E+04, 0.80904300E+03, 0.24770900E+04, -.39827400E+03, -.58407100E+03, -.16881800E+02, 0.18009700E+03, 0.93730100E+03, -.72411100E+03, 0.20478700E+04, -.22916200E+04, -.75412800E+03, -.10255400E+04, 0.16762600E+04, 0.16368700E+04, 0.43623900E+04, -.71794000E+03, -.79617500E+04, 0.44232600E+04, 0.26217000E+04, 0.39026600E+04, -.78644900E+03, -.53946900E+04, -.13388600E+04, 0.35035500E+04, 0.14543800E+04, -.18576100E+04, 0.93241600E+02, 0.30945900E+03, -.27491000E+03, 0.13402200E+03, -.26143300E+03, 0.30542600E+03, 0.14654000E+04, -.17410500E+04, -.12163600E+02, 0.17639700E+03, -.12338700E+03, 0.22882900E+03, -.19850700E+03, 0.17669500E+03, 0.10037900E+05, -.10543900E+04, -.20191300E+04, -.31570900E+04, -.76014300E+03, 0.47532700E+04, 0.63906800E+03, -.28558100E+04, -.10667100E+05, 0.19935700E+04, 0.15906800E+04, 0.23926800E+04, 0.58463200E+03, -.44915200E+04, -.17411800E+04, 0.18956900E+04, 0.18473100E+04, -.13885900E+04, 0.93068200E+02, 0.38680000E+03, -.21429800E+03, 0.28365700E+03, 0.57138200E+03, 0.36273700E+03, -.19637200E+03, 0.37522400E+04, -.89339600E+03, -.17259500E+04, 0.87176000E+03, 0.75093000E+03, 0.14831900E+04, -.15393500E+04, 0.27807300E+04, -.25602200E+04, -.17361900E+02, 0.36937500E+03, -.52998700E+03, 0.21168500E+02, -.22506800E+04, 0.31224500E+03, 0.15723600E+04, 0.11681600E+04, -.90376000E+03, -.11863300E+04, 0.28401200E+03, 0.10631500E+04, 0.20977300E+04, -.12811300E+04, 0.28140800E+04, -.14227300E+04, -.86165900E+03, -.12253600E+04, -.25219100E+03, 0.74752700E+03, -.35672000E+03, -.12919000E+04, 0.84320200E+03, -.11876300E+03, -.23040000E+03, 0.16638600E+03, -.13371700E+02, 0.28069500E+03, 0.43236200E+03, -.36273300E+03, -.31229100E+03, 0.49204300E+03, -.60623100E+01, -.38569700E+03, -.36146900E+02, -.56553000E+02, -.50233100E+03, -.25686600E+03, -.56626100E+03, 0.72244000E+01, 0.63130100E+03, 0.21924800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.28725800E-01, 0.95668200E-01, -.68194000E+00, 0.37456300E+01, 0.71845400E+00, 0.79532900E-01, 0.57111500E+00, -.41298700E+00, -.66244400E+00, 0.21892000E-01, -.48420300E+00, -.55923900E-02, 0.31047500E+00, 0.16883000E+04, 0.13622700E+04, -.48817700E+02, 0.54953600E+03, 0.13109400E+04, 0.20907100E+03, 0.24008500E+03, -.17620700E+03, 0.63047000E+03, 0.29923300E+03, 0.40461200E+03, -.35623400E+04, 0.10512000E+04, -.10028400E+04, -.17697000E+04, 0.18481200E+04, -.10204300E+04, 0.98866200E+03, -.17680400E+04, -.58406900E+04, 0.11019400E+04, -.30195100E+04, -.56755100E+04, 0.43171600E+04, -.20101600E+04, 0.32117700E+04, -.57461400E+04, 0.25971300E+04, 0.53531900E+03, 0.20089600E+04, 0.33729000E+04, -.26285100E+04, 0.13917900E+04, -.43314100E+03, 0.34214200E+04, 0.12940300E+03, -.16874600E+04, -.26799300E+03, -.23567400E+03, 0.10193400E+03, -.24317900E+03, -.23665000E+03, -.30306800E+03, -.29952000E+04, 0.15111700E+04, 0.94575600E+03, 0.13321800E+04, -.51679800E+03, -.29100800E+04, -.19190600E+04, 0.12021500E+04, 0.34002100E+04, -.11251200E+04, 0.88253900E+02, 0.15930700E+03, -.99138500E+03, 0.11250600E+04, 0.59109000E+03, 0.85211200E+02, 0.11481900E+05, -.40943800E+04, 0.27141000E+04, 0.53952700E+04, -.54585500E+04, 0.72642600E+03, -.39456700E+04, 0.54447100E+04, 0.40519400E+04, -.12796400E+04, 0.11368800E+04, 0.20975300E+04, -.21182100E+04, 0.11036200E+04, -.11969300E+04, 0.21278300E+04, 0.36495700E+04, -.11984800E+04, 0.10334000E+04, 0.18917100E+04, -.19719400E+04, 0.95834600E+03, -.10904600E+04, 0.18967100E+04, -.10183400E+05, 0.32546400E+04, -.31086500E+04, -.56683100E+04, 0.58758200E+04, -.76115200E+03, 0.50665100E+04, -.55405300E+04, 0.68258600E+04, -.18730100E+04, 0.17524500E+04, 0.31867100E+04, -.34870000E+04, 0.54959900E+03, -.41267200E+04, 0.30982000E+04, 0.54090000E+04, -.18173200E+04, 0.12210100E+04, 0.24320800E+04, -.23714800E+04, 0.12941900E+04, -.11553300E+04, 0.24784000E+04, -.10136600E+05, 0.38190300E+04, -.24284500E+04, -.48297000E+04, 0.45191100E+04, -.31525600E+04, 0.28809400E+04, -.49075600E+04, 0.34221200E+04, -.12348900E+04, 0.14438200E+04, 0.23834900E+04, -.24749300E+04, 0.11994000E+04, -.11231600E+04, 0.23697400E+04, -.26135100E+04, 0.17047900E+04, 0.83626800E+03, 0.11765900E+04, -.30453600E+03, -.18192400E+04, -.14241400E+04, 0.11350300E+04, 0.83958800E+03, -.45104400E+03, -.36533200E+03, -.77232400E+03, 0.90227000E+02, -.62322100E+03, 0.16016700E+03, -.70482100E+03, 0.19578800E+04, -.17355500E+04, 0.22261400E+04, 0.19500300E+04, 0.12468700E+04, 0.16152800E+04, 0.22072500E+04, 0.21829500E+04, -.24115500E+04, -.19894200E+04, 0.13711900E+04, -.66587900E+03, -.31199100E+03, 0.23255900E+01, -.13291900E+04, -.84418600E+03, 0.53814600E+03, 0.16640500E+04, 0.23805400E+04, 0.20318400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.84344000E+00, -.56617900E-01, -.24013500E+01, -.85388900E+01, -.14947800E+01, -.11847800E+00, 0.35896300E+00, 0.15314500E+01, 0.14975700E+01, -.13335500E+00, 0.94278400E+00, -.88856300E+00, 0.15019100E+00, -.10847300E+01, -.70781600E+04, 0.29395200E+03, 0.92526600E+04, 0.14176500E+02, 0.17513600E+04, 0.27046700E+04, -.48445600E+04, 0.32978800E+04, -.55192200E+04, 0.31887500E+04, -.96062100E+04, 0.12352600E+04, -.18764000E+04, -.29038700E+04, 0.44169000E+04, -.43374900E+03, 0.63028700E+04, -.32983800E+04, -.43344200E+05, 0.19942300E+05, -.23365600E+04, -.44415400E+04, 0.16388800E+05, -.11063400E+05, 0.17714800E+05, -.55008700E+04, 0.40466100E+05, -.68875600E+04, 0.25950400E+04, 0.42194600E+04, -.15256600E+05, 0.93797800E+04, -.18836200E+05, 0.54764500E+04, -.89798900E+04, 0.10203600E+04, -.20888800E+04, -.30892800E+04, 0.53288600E+04, 0.11826200E+03, 0.81792800E+04, -.34636400E+04, 0.16752600E+05, -.15410800E+05, -.52469600E+04, -.56805300E+04, 0.73992100E+03, 0.29539300E+04, -.13516300E+04, -.63147800E+04, -.26240600E+04, 0.29865400E+04, 0.11766000E+04, 0.14720000E+04, -.20089900E+03, -.44527000E+04, -.10500100E+05, 0.16617500E+04, 0.39443700E+05, -.20256000E+05, 0.41771700E+04, 0.66443800E+04, -.17754200E+05, 0.55906000E+04, -.19829300E+05, 0.75891700E+04, 0.95408000E+04, -.12826200E+04, 0.15159600E+04, 0.25815800E+04, -.39591300E+04, 0.15818800E+04, -.56087000E+04, 0.29807800E+04, 0.81157400E+04, -.10909800E+04, 0.13308200E+04, 0.22734400E+04, -.33118600E+04, 0.92016200E+03, -.51263100E+04, 0.26349300E+04, -.38139700E+05, 0.93118100E+04, 0.37488500E+03, -.95686400E+03, 0.99332100E+04, -.55813600E+04, 0.15053300E+05, -.16831600E+04, 0.26684000E+05, -.64619100E+04, -.79215400E+03, -.19656300E+03, -.66768900E+04, 0.37411100E+04, -.65438300E+04, 0.20128900E+03, 0.10267100E+05, -.32128000E+04, 0.30732000E+04, 0.46355200E+04, -.66970100E+04, 0.50656000E+03, -.90012900E+04, 0.50241400E+04, -.20471500E+05, 0.97761800E+03, -.54283900E+04, -.82535500E+04, 0.11804200E+05, -.25878900E+04, 0.11966400E+05, -.91932400E+04, 0.14468000E+05, -.34230500E+04, 0.11957400E+04, 0.23401100E+04, -.38373400E+04, 0.32297400E+04, -.47230900E+04, 0.30406500E+04, 0.71522300E+04, -.89867500E+04, -.29249300E+04, -.27936600E+04, 0.14116900E+04, 0.10842800E+04, -.19319300E+04, -.33142300E+04, -.10872100E+05, 0.54907900E+04, 0.15463000E+04, 0.15767700E+04, 0.15190100E+04, -.33516100E+04, 0.38319700E+04, 0.15368100E+04, 0.41981800E+04, -.40198400E+04, 0.58697800E+04, 0.34106000E+04, 0.13857300E+04, -.51545800E+04, -.68948100E+03, 0.43490000E+04, -.37175100E+04, -.42562000E+04, -.37071900E+04, -.11486700E+04, 0.16958000E+03, -.31610700E+04, -.39493100E+04, 0.10072600E+04, -.26053700E+03, 0.24319400E+04, 0.49065800E+04, 0.49788700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16726500E+00, 0.50479900E-02, -.28390900E+00, -.23680600E+01, -.18681300E+00, -.24686300E+00, 0.17819300E+00, 0.10395100E+00, 0.38392000E+00, -.35838700E-01, 0.23488500E+00, -.97240000E+00, -.95987500E-01, 0.15881500E+00, -.66011200E-01, 0.11215900E+03, 0.27713700E+04, -.35742700E+04, 0.50373400E+03, 0.36610100E+03, -.12965500E+04, 0.75867400E+03, -.14137000E+04, 0.50691600E+03, -.10130800E+04, 0.43646600E+03, 0.45517200E+03, 0.87688100E+03, -.16576800E+03, -.32657100E+03, 0.23704700E+00, 0.75119600E+03, 0.19961000E+03, 0.61553900E+04, 0.96421000E+03, 0.20743500E+04, -.33174900E+03, 0.14676500E+03, 0.18671400E+04, 0.19055600E+04, 0.92374500E+04, -.24068700E+04, -.15118600E+04, -.22730300E+04, -.11134200E+04, 0.27346600E+04, -.31622400E+04, -.19627800E+04, -.33867700E+04, 0.54432500E+04, -.53338800E+03, -.38140300E+03, 0.14019100E+04, -.48488200E+03, 0.17159100E+04, -.57761700E+03, -.48386700E+03, -.53952700E+04, 0.26289600E+03, 0.13370500E+03, -.26955000E+03, -.50524700E+03, -.46522600E+03, 0.14067100E+03, -.14546900E+04, -.27620200E+03, -.28593000E+03, -.49415900E+03, 0.75514500E+03, -.49657200E+03, -.33383200E+03, -.49014100E+03, -.35741300E+04, -.52789600E+04, -.62797800E+03, -.17034500E+04, 0.76531000E+03, -.10748800E+04, -.16055100E+04, -.15639500E+04, -.15681800E+02, -.68452800E+02, -.51410700E+03, -.10136100E+04, 0.47623200E+03, 0.20443700E+03, 0.18683900E+03, -.92137100E+03, 0.94266000E+00, -.34842500E+02, -.44100600E+03, -.87628900E+03, 0.45159200E+03, 0.15603500E+03, 0.30151600E+03, -.77157100E+03, -.10215700E+00, -.11855400E+03, 0.13041100E+04, 0.25340500E+04, -.93450700E+03, -.21394400E+03, -.26679400E+03, 0.22989800E+04, -.39078100E+02, -.31170400E+03, -.54052800E+03, -.12608100E+04, 0.84840300E+02, -.23037100E+03, 0.32686300E+03, -.11477000E+04, -.17333100E+03, -.16678400E+04, -.32993100E+03, -.94083700E+03, 0.28370700E+03, 0.14280500E+03, -.13685100E+03, -.78333300E+03, -.29208700E+04, -.11671600E+04, 0.13158100E+04, 0.25146700E+04, -.26263600E+03, -.14456900E+04, -.65054000E+03, 0.21706400E+04, 0.14327700E+04, 0.54479700E+03, -.26444000E+03, -.64153500E+03, 0.25669100E+02, 0.65300300E+03, 0.10924500E+04, -.33573600E+03, -.10339500E+04, -.50400000E+04, 0.46487400E+03, 0.31406200E+03, -.22515200E+03, -.47341400E+03, -.20888800E+03, 0.34119600E+03, -.10574200E+04, 0.60355400E+03, -.11533500E+03, -.32188300E+02, 0.60185800E+03, -.28948700E+03, -.17369100E+03, -.17384400E+03, -.48453800E+02, 0.42442400E+03, -.30590500E+03, -.85451300E+03, -.52124100E+03, -.14682700E+04, -.10919900E+04, -.55196600E+03, 0.38558300E+03, 0.39092900E+03, -.73449300E+03, -.93139000E+01, 0.12627400E+03, -.28487800E+03, 0.16127700E+03, 0.40001000E+03, 0.15229600E+03, 0.59141400E+01, -.37670200E+03, -.34880700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16383000E+00, 0.15584400E-01, -.25358100E+00, 0.16348200E+00, 0.37178900E+00, 0.49704700E+00, 0.11016000E+00, -.22248400E+00, -.24294200E-01, -.28357000E-01, 0.60346400E-01, -.18997600E+00, 0.42216000E-01, -.21608500E+00, 0.12093900E+00, 0.33448300E+00, 0.16457300E+04, 0.16500200E+04, 0.14593200E+03, 0.26183600E+03, -.50219500E+03, 0.15901400E+03, 0.33872700E+02, 0.35322100E+03, -.73814800E+03, -.30367400E+03, -.33630700E+03, -.47510100E+03, 0.50060100E+03, -.54443200E+02, 0.49275700E+03, -.49290400E+03, 0.16356900E+04, -.44548000E+04, -.10116200E+04, -.14622000E+04, 0.16148500E+03, 0.91396400E+03, -.51574200E+03, -.13532200E+04, -.31172600E+04, 0.21964700E+04, 0.10968000E+04, 0.14486000E+04, -.56256300E+02, -.14958200E+04, 0.67162500E+03, 0.13758500E+04, -.19454200E+03, -.25554700E+04, -.25863200E+03, -.42481300E+03, 0.22544600E+03, -.12214900E+03, -.47585800E+03, -.49854500E+03, -.18120200E+03, 0.20726500E+04, 0.12225100E+03, 0.15130600E+03, 0.24244800E+03, 0.43423500E+03, 0.12746600E+04, 0.21249000E+03, 0.13892600E+04, 0.28221800E+03, 0.13091600E+03, 0.29051200E+03, -.54630100E+03, 0.38997200E+03, -.14588400E+03, 0.37176800E+03, -.51967100E+03, 0.40313500E+04, 0.89531800E+03, 0.13066700E+04, -.34619100E+03, -.80631700E+03, 0.36139500E+03, 0.12341400E+04, 0.10991400E+04, 0.23672700E+03, 0.31446500E+03, 0.46797900E+03, -.57422300E+03, 0.55541200E+02, -.50789200E+03, 0.49249000E+03, 0.92682600E+03, 0.18546900E+03, 0.25342500E+03, 0.38099300E+03, -.48711800E+03, 0.74154900E+02, -.48841400E+03, 0.39682000E+03, -.47599700E+03, -.13299100E+04, -.77924000E+03, -.12163700E+04, 0.68955200E+03, 0.36740600E+02, 0.44961700E+03, -.11978000E+04, 0.70275600E+03, 0.13456000E+04, 0.46648100E+03, 0.80176200E+03, -.47976100E+03, 0.34414800E+03, -.64072500E+03, 0.80081400E+03, 0.95770000E+03, 0.96623000E+03, 0.41001300E+03, 0.58272600E+03, -.57801900E+03, -.35943100E+02, -.30792500E+03, 0.63508000E+03, -.43257400E+03, -.62155600E+02, -.73205700E+03, -.10050900E+04, 0.66796500E+03, 0.32748200E+03, 0.91747800E+03, -.98014600E+03, 0.70607300E+03, -.37163400E+03, 0.19751900E+03, 0.23830100E+03, -.38585800E+03, -.18683400E+03, -.10105600E+04, 0.18078100E+03, 0.13408100E+04, 0.15940000E+04, -.85714100E+02, -.76641400E+02, -.15530000E+01, 0.80156700E+03, 0.10794600E+04, 0.76517500E+01, 0.64676600E+03, -.38136200E+03, 0.90180200E+01, 0.63557000E+02, -.34632100E+03, -.65212800E+01, -.36255800E+03, 0.10346800E+03, 0.52145700E+03, -.52444900E+03, 0.48951900E+03, 0.69097700E+03, 0.24771800E+03, 0.32515200E+03, 0.47337100E+03, 0.73664400E+03, -.34698100E+03, -.53193000E+03, -.27572500E+02, -.74153900E+02, -.18618500E+02, -.19402600E+02, -.30220100E+03, -.27894900E+00, 0.49309600E+02, 0.18808700E+03, 0.12772500E+03, 0.48513600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.70804800E-01, 0.42954900E-01, -.34829900E+00, 0.24687400E+01, 0.27538500E+00, 0.13108100E+00, 0.23227800E+00, -.53437600E+00, -.40063000E-01, -.75120500E-01, 0.68004900E-01, -.25023100E+00, -.14537600E+00, -.74213900E-01, 0.15294200E+00, 0.11002700E+01, -.16246700E+00, 0.60050300E+04, -.35739300E+03, -.14238100E+03, 0.21486500E+03, -.43837800E+03, 0.60538600E+03, -.20392500E+03, 0.72897300E+03, -.17915200E+04, -.27944900E+03, -.45472600E+03, 0.17629000E+03, 0.25187500E+03, 0.28326800E+03, -.42650100E+03, 0.68411200E+03, -.11822300E+05, -.25568600E+02, -.29041200E+03, -.10159600E+04, -.22038700E+03, -.29299700E+04, -.66274600E+02, -.89944800E+04, 0.53142600E+04, 0.10868200E+04, 0.14570900E+04, 0.15721300E+04, -.28935100E+04, 0.31585600E+04, 0.12382300E+04, 0.27084500E+03, -.84251100E+04, 0.39416500E+03, 0.11470700E+03, -.19990600E+03, -.62634400E+02, -.79953200E+03, 0.24119500E+03, 0.22187300E+03, 0.75073400E+04, -.32628500E+03, -.29781300E+03, 0.75214300E+03, 0.10067300E+04, 0.24244200E+04, -.38808700E+03, 0.18792100E+04, 0.10139200E+04, 0.50544600E+03, 0.80088400E+03, -.12403300E+04, 0.51694400E+03, 0.12684700E+03, 0.98999100E+03, 0.30792200E+04, 0.10779700E+05, -.40690100E+03, -.27898400E+03, 0.45246800E+03, 0.12512500E+04, 0.24610200E+04, -.40564700E+03, 0.16640400E+03, 0.15553900E+04, 0.31869000E+03, 0.50402500E+03, -.40794100E+03, -.18566700E+03, -.31799400E+03, 0.51320500E+03, 0.71061600E+02, 0.12693700E+04, 0.21005300E+03, 0.35934700E+03, -.31097500E+03, -.11814100E+03, -.41569200E+03, 0.34269400E+03, 0.13070900E+04, -.38522500E+04, -.68518600E+03, -.11765500E+04, 0.42279000E+02, 0.92540500E+02, -.73965600E+03, -.10547600E+04, -.13322300E+04, 0.37801700E+04, 0.50593100E+03, 0.96128000E+03, 0.14222900E+03, 0.75381100E+02, -.13138500E+03, 0.88155000E+03, -.23013400E+03, 0.41403500E+04, 0.78825200E+01, 0.19359800E+03, -.60101700E+01, -.24380700E+03, 0.23061500E+02, 0.13474800E+03, 0.51972200E+04, -.12854200E+04, -.54905300E+03, -.88010300E+03, -.86403200E+03, 0.18888400E+04, 0.51221400E+03, -.59819700E+03, -.15685800E+04, 0.19168200E+03, -.28835200E+03, -.31151600E+03, 0.51223300E+03, -.74482400E+03, -.14170200E+04, -.55533800E+03, 0.18995600E+04, 0.70268900E+04, -.71851000E+03, -.70183700E+03, 0.43543700E+03, 0.12472800E+04, 0.20430500E+04, -.81818700E+03, 0.18508100E+04, -.10220400E+04, 0.42024200E+03, 0.55849600E+03, -.12145100E+04, 0.13982500E+03, -.73038300E+03, 0.75521700E+03, 0.86822500E+02, -.36868800E+03, 0.25626900E+03, 0.28384400E+03, 0.32015500E+03, 0.40407800E+03, 0.55307100E+03, -.10367500E+02, -.13174200E+03, -.31141600E+03, -.43459800E+03, 0.14390200E+03, 0.17517700E+01, 0.12745800E+03, -.13291200E+03, 0.30771800E+03, -.52217100E+02, -.11291800E+03, 0.71272400E+02, 0.26770900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.88006700E-02, -.43805900E-01, 0.31253600E+00, -.20417600E+01, -.19312000E+00, 0.13270100E-01, -.25948500E+00, 0.21789900E+00, 0.25039000E+00, -.67886100E-02, -.13956700E+00, 0.31445400E+00, 0.71969700E-01, -.61530100E-01, 0.10346000E-01, 0.13403200E+00, -.37761200E+00, 0.27540600E+00, 0.13962900E+03, 0.13550300E+03, -.40448600E+02, 0.14418600E+03, -.97938900E+02, 0.13836800E+03, 0.12603200E+03, 0.12703200E+03, -.78368400E+02, 0.25010100E+02, -.18221500E+02, 0.81497700E+02, -.70233300E+02, 0.24772500E+02, -.57071200E+03, -.80470700E+02, -.19902000E+03, 0.94094400E+02, 0.51975500E+03, 0.63883600E+02, 0.87598500E+03, 0.46793200E+02, -.14926100E+04, -.20063200E+03, 0.62192300E+03, 0.57732200E+03, -.32180400E+03, -.78607100E+03, -.73013900E+03, 0.57785300E+03, 0.48105300E+02, -.15382200E+03, -.12926400E+03, -.11130100E+03, -.18469300E+02, 0.53042600E+02, -.14524600E+02, -.10832300E+03, 0.92318900E+03, 0.40433700E+03, -.30248100E+03, -.35883700E+03, 0.43763900E+02, 0.14298800E+03, -.28995500E+03, -.37431200E+03, -.20453500E+03, 0.23915900E+03, 0.51800700E+02, 0.42108900E+01, 0.13721700E+03, -.35014400E+02, 0.35422600E+03, 0.25753400E+02, 0.33539300E+03, 0.53661700E+03, 0.22177000E+03, -.10322000E+03, -.46050800E+03, -.13507000E+03, -.81833100E+03, -.62964800E+02, -.21045500E+03, -.66645400E+02, 0.25786900E+02, -.10152600E+03, 0.86681000E+02, 0.42365300E+01, 0.12114500E+03, -.99853100E+02, -.23840600E+03, -.25457000E+02, 0.29301700E+02, -.82823500E+02, 0.81309300E+02, -.44417100E+02, 0.95608700E+02, -.84349700E+02, 0.13080400E+04, -.16511000E+03, -.68978200E+02, 0.19912300E+03, -.31068400E+03, 0.68460300E+03, 0.21585700E+03, 0.19336000E+03, 0.14785500E+03, -.41076000E+03, -.13016800E+03, -.31038700E+03, 0.11461600E+03, -.23249800E+03, -.15883100E+03, -.30698600E+03, -.14151700E+03, 0.17891600E+03, 0.53307700E+02, -.12100400E+03, 0.58370100E+02, 0.12090400E+02, 0.10510800E+03, -.12997200E+03, 0.10925800E+04, 0.73827600E+02, -.22221300E+03, 0.59953000E+02, -.95441700E+02, 0.45295900E+03, 0.93483700E+02, 0.66173700E+02, 0.34238500E+02, -.33720900E+03, 0.84312500E+02, -.24315900E+02, -.67043400E+02, -.47192700E+02, -.27139000E+03, -.40619900E+02, 0.22042400E+03, 0.75264700E+03, -.12335300E+03, -.15565000E+03, 0.12531100E+03, 0.16361900E+02, -.23035500E+03, -.15085500E+03, -.98808200E+02, 0.16069100E+02, 0.16878600E+02, 0.37470100E+02, 0.88727500E+02, 0.18161400E+03, 0.45469800E+03, 0.41767500E+02, -.12264800E+03, 0.73737100E+02, -.72914800E+02, -.24121200E+02, -.88767200E+02, -.25831600E+03, -.10418900E+03, 0.63328900E+02, -.70394400E+01, 0.15977500E+03, -.12492100E+03, 0.29743000E+02, -.36192700E+01, -.97883100E+02, -.55234700E+01, -.44537500E+02, -.74740700E+02, -.17942900E+03, 0.75890200E+02, -.33377700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10215000E+00, -.23358200E-01, 0.17409600E+00, -.14953300E+01, -.31582100E+00, 0.30228800E-01, -.45480200E-01, 0.66665600E+00, 0.28728000E+00, 0.19449900E-01, -.44935400E+00, 0.78160500E-01, 0.18975500E+00, 0.73041900E+00, -.19489700E+00, -.13389100E+00, -.92486500E+00, -.24449600E+00, 0.15335600E+01, 0.17454700E+03, -.14604400E+03, -.31399400E+03, -.16033100E+03, 0.14968600E+03, -.94636100E+03, 0.53207400E+03, 0.13321900E+02, -.10453900E+03, 0.27747000E+03, 0.81082000E+02, 0.55745800E+03, -.97866800E+02, -.28697400E+04, 0.99016300E+03, 0.40308600E+03, 0.33451100E+03, -.30253500E+02, -.65971600E+03, -.14542800E+03, 0.38922000E+03, 0.42391500E+04, -.22800200E+04, -.64270500E+03, -.57315800E+03, -.14673100E+03, 0.82416900E+03, -.39604100E+03, -.60275500E+03, -.90201800E+02, -.14508000E+03, 0.41250800E+01, -.24588900E+03, 0.24119100E+03, 0.36567400E+03, 0.56493100E+03, -.20897500E+03, -.11702600E+04, 0.94864000E+03, 0.35180000E+03, 0.47634600E+03, 0.34800700E+02, -.39558200E+03, 0.48670400E+03, 0.52410900E+03, -.12503800E+03, 0.22375200E+02, -.15382000E+02, 0.50571300E+02, -.12219300E+03, -.19804400E+03, -.17026600E+03, 0.42965800E+02, 0.34059100E+04, -.13566000E+04, -.50038800E+03, -.48363800E+03, -.10550600E+03, 0.68158400E+03, 0.59502500E+02, -.53969000E+03, 0.88815900E+03, -.48063000E+03, -.78095400E+01, 0.86365900E+02, -.25000800E+03, -.70526900E+02, -.43791300E+03, 0.86140700E+02, 0.83337100E+03, -.45227700E+03, -.52516200E+02, 0.19595600E+02, -.17126700E+03, -.19796800E+02, -.36839200E+03, 0.22594400E+02, -.17606100E+04, 0.10219600E+04, 0.41513500E+03, 0.47077900E+03, -.11395900E+03, -.63380800E+03, -.78426100E+03, 0.46268800E+03, -.36580900E+03, 0.82977400E+02, -.54404400E+02, -.71765300E+02, 0.21208300E+03, 0.16427000E+03, 0.87055500E+03, -.70777600E+02, 0.11391000E+04, -.54064400E+03, -.64674600E+02, 0.83877500E+02, -.35706600E+03, -.13191100E+03, -.76198300E+03, 0.65997300E+02, -.18906900E+04, 0.13005300E+04, 0.47862700E+02, -.14344900E+03, 0.58916400E+03, 0.93605800E+02, 0.10811900E+04, -.85006500E+02, 0.18300700E+04, -.10140300E+04, -.88651600E+02, 0.15558100E+02, -.28966800E+03, 0.59854300E+02, -.57155400E+03, 0.36817300E+02, -.10416100E+04, 0.79268600E+03, 0.32580100E+03, 0.51913800E+03, -.17329400E+03, -.46253300E+03, 0.27485900E+03, 0.53558700E+03, -.30118900E+03, 0.13510200E+03, -.13374100E+03, -.15566800E+03, 0.17524900E+03, -.10212700E+03, -.17648300E+03, -.14913400E+03, 0.42630700E+03, -.17994300E+03, 0.18334900E+03, 0.26538600E+03, -.37699900E+02, -.13019800E+03, -.13419500E+03, 0.87252300E+02, -.71293500E+02, -.27086400E+03, -.35631200E+03, -.10533300E+03, 0.51540200E+02, -.13599100E+03, -.13742100E+03, 0.24626600E+03, -.14377300E+03, 0.69200800E+02, -.50334600E+02, 0.12596000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.59359900E-01, -.43963000E-01, 0.58608600E+00, -.20130000E+01, -.22145600E+00, -.28926400E-01, -.31703300E+00, 0.24226700E+00, 0.35872400E+00, 0.13882000E+00, -.10747200E+00, 0.73692500E+00, 0.22042800E+00, -.35260900E+00, 0.11295800E+00, -.48483800E+00, 0.76003000E+00, -.62880500E+00, 0.28257900E+00, -.55752800E+00, -.10708200E+03, -.49908800E+03, -.91271600E+02, -.71493800E+02, -.51416600E+03, 0.36700300E+03, -.23384400E+03, -.22612700E+03, 0.43921900E+03, 0.15305300E+03, 0.56004200E+03, -.20243600E+03, 0.45799300E+04, -.27621100E+04, -.14511600E+04, -.15376200E+04, -.31523500E+02, 0.23552900E+04, 0.11790900E+03, -.14301700E+04, -.24952400E+04, 0.52150700E+03, 0.12410400E+04, 0.13585200E+04, -.66310700E+03, -.17634800E+04, -.27462400E+03, 0.12851600E+04, -.55682700E+03, -.31013600E+03, 0.45358500E+01, -.32244700E+02, 0.39697700E+03, 0.13304700E+03, 0.25157800E+03, 0.73941900E+02, 0.11994500E+04, 0.52550700E+03, -.59173600E+03, -.70500600E+03, 0.60131500E+03, 0.10515400E+04, 0.12323400E+04, -.72710400E+03, 0.12960700E+03, -.23570600E+03, -.73647100E+02, -.11239200E+03, -.14015300E+03, 0.38287900E+02, 0.11496300E+02, -.15078700E+03, -.29927300E+04, 0.22772900E+04, 0.12701200E+04, 0.12737800E+04, -.22699800E+03, -.19613300E+04, -.22613700E+03, 0.12229500E+04, 0.41275300E+03, -.32433200E+03, 0.21562400E+03, 0.17557500E+03, -.35550100E+03, -.22826900E+03, -.46642100E+03, 0.15948200E+03, 0.33257700E+03, -.28421600E+03, 0.16872100E+03, 0.13064600E+03, -.29772300E+03, -.17021400E+03, -.44304700E+03, 0.11316200E+03, 0.46743400E+03, 0.22081600E+03, -.19186000E+03, -.14927700E+01, -.13382900E+03, 0.19046200E+03, 0.24550700E+02, 0.57321500E+02, -.16296300E+04, 0.22678200E+03, 0.15863700E+03, 0.80106400E+02, 0.52713700E+03, -.34171400E+03, -.51317800E+02, 0.24438800E+02, 0.29694500E+03, 0.55943500E+01, 0.25913700E+03, 0.21780100E+03, -.43124500E+03, -.30221000E+03, -.24183800E+03, 0.18990800E+03, 0.12251700E+04, 0.30487100E+03, -.89020300E+03, -.91497100E+03, 0.69975200E+03, 0.12682800E+04, 0.12983900E+04, -.82266700E+03, 0.97986800E+03, -.70771200E+03, 0.27889200E+03, 0.29623300E+03, -.57265500E+03, -.36206600E+03, -.14022300E+04, 0.26563100E+03, 0.16165000E+04, 0.25138400E+03, -.63879800E+03, -.74361600E+03, 0.31933100E+03, 0.88522000E+03, 0.74742100E+03, -.82395300E+03, 0.30322300E+03, -.20812700E+03, -.23513800E+02, -.37523200E+02, -.21079100E+03, 0.24495500E+02, -.69233300E+02, -.10033200E+02, 0.20036700E+03, -.26740300E+03, 0.23222300E+03, 0.19932100E+03, -.47454600E+02, 0.65886600E+01, -.10256100E+02, -.82461400E+02, -.19778800E+03, -.39118000E+03, -.13545000E+03, 0.96292300E+00, 0.45313400E+02, -.35041700E+03, -.27639900E+03, -.41118800E+01, -.17117600E+03, -.20710400E+03, 0.25855100E+03, 0.22422700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.24540500E+00, -.52812200E-01, 0.68678600E+00, -.15671200E+01, -.57245700E-01, 0.10134800E+00, -.32237700E+00, -.45802700E+00, 0.19475800E+00, 0.96217500E-01, 0.59098900E+00, 0.19160700E+00, -.93156100E-02, 0.37060000E+00, -.43383600E-01, 0.11321400E+01, -.16784100E+00, 0.25850900E+00, 0.45588500E+00, 0.10695200E+01, -.18077300E+01, -.11738500E+04, 0.32182900E+03, -.14104900E+03, -.16241000E+04, 0.12187100E+04, -.11241100E+04, -.14364600E+04, 0.15952500E+04, 0.27717400E+03, 0.16662200E+04, -.13611700E+04, 0.13741600E+05, -.77784700E+04, -.59479900E+04, -.74553900E+04, 0.14258900E+04, 0.71897300E+04, 0.75483500E+03, -.71801100E+04, -.10249500E+05, 0.29766200E+04, 0.48455800E+04, 0.57835100E+04, -.23130900E+04, -.56993700E+04, 0.13132600E+03, 0.55620500E+04, 0.57839600E+03, -.12352300E+04, -.83744500E+02, -.15504500E+03, 0.23881200E+03, 0.35656000E+03, -.63195800E+03, 0.89353200E+02, 0.44320100E+04, 0.22604700E+03, -.18777100E+04, -.21411100E+04, 0.16345600E+04, 0.34573900E+04, 0.31741800E+04, -.21956500E+04, 0.14423800E+04, -.78147200E+03, -.13073200E+03, -.71052300E+02, -.63377700E+03, 0.40027900E+03, -.45679100E+03, -.14850800E+03, -.92558600E+04, 0.61493700E+04, 0.55862600E+04, 0.69805500E+04, -.22174100E+04, -.62236600E+04, -.11128000E+04, 0.68414900E+04, 0.19516200E+04, -.13530000E+04, 0.10779100E+04, 0.14103600E+04, -.15625900E+04, -.45958100E+03, -.16389600E+04, 0.13509400E+04, 0.16343900E+04, -.11521700E+04, 0.94501200E+03, 0.12360100E+04, -.14118500E+04, -.32711400E+03, -.15926600E+04, 0.11729600E+04, -.15163100E+04, 0.18810200E+04, -.20476400E+04, -.27874000E+04, 0.17347700E+04, 0.27670900E+03, 0.22095500E+04, -.25833500E+04, -.10227200E+04, -.49743300E+03, 0.11108400E+04, 0.15720800E+04, 0.99057100E+02, -.60610400E+02, -.17432600E+04, 0.14250700E+04, 0.17403000E+04, -.66704300E+03, 0.14579100E+04, 0.19034300E+04, -.19569200E+04, -.64703400E+03, -.77304000E+03, 0.18573300E+04, 0.12257100E+04, 0.12536500E+04, -.38662000E+04, -.49536800E+04, 0.34158000E+04, 0.29900700E+04, 0.41313400E+04, -.47429400E+04, 0.25858800E+04, -.19988100E+04, 0.14280600E+04, 0.17879300E+04, -.21363700E+04, -.10072500E+04, -.41114100E+04, 0.16335500E+04, 0.59808000E+04, -.61992000E+03, -.19915400E+04, -.22309400E+04, 0.93267900E+03, 0.30092300E+04, 0.17024600E+04, -.23978000E+04, 0.12700000E+04, -.70039500E+03, -.18667000E+03, -.32112400E+03, -.68142000E+03, 0.15053400E+03, -.14724400E+03, -.26004900E+03, 0.96243900E+03, -.13648400E+04, 0.12104900E+04, 0.15752500E+04, 0.41723200E+03, 0.11983900E+04, 0.99933300E+03, 0.10098000E+04, -.11579300E+04, -.16432900E+04, 0.67378200E+03, -.15882400E+03, -.20398300E+02, -.70895300E+03, -.10666100E+04, -.62462600E+03, -.37582100E+03, -.14594500E+03, 0.12540500E+04, 0.12304600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.85211600E-01, -.30164200E-01, 0.94748200E+00, -.27796600E+01, -.44746600E+00, -.18931100E+00, -.44572800E+00, 0.65676300E+00, 0.76513200E+00, 0.19091800E+00, -.46244000E+00, 0.43460100E+00, -.24070800E+00, 0.66240800E-02, -.33670200E+00, -.43878900E+00, 0.82093300E+00, -.12968000E+01, -.23421400E+01, 0.25292500E+00, 0.16824600E+01, -.45820700E+00, -.22044200E+03, -.40842700E+02, 0.29001200E+04, -.28548000E+03, 0.81019400E+02, 0.70640100E+03, -.73410000E+03, 0.49980300E+03, -.83107400E+03, 0.71812100E+03, -.16600100E+04, -.40588300E+03, 0.18829200E+04, 0.42240000E+04, -.11648500E+04, -.21912200E+04, -.32278700E+04, 0.40155200E+04, -.88081300E+04, -.18889300E+04, 0.10663900E+04, 0.33728000E+03, 0.60420400E+03, -.24943000E+04, 0.10871000E+04, 0.28274600E+03, -.38871400E+03, -.11337900E+04, 0.99200400E+02, 0.11743500E+03, -.10666700E+03, -.16461400E+03, -.33902900E+03, 0.16386000E+03, 0.11906700E+04, 0.53620900E+04, -.65352900E+03, -.80662300E+03, 0.22248100E+03, 0.29630500E+03, -.15306600E+03, -.91390800E+03, -.14645500E+04, 0.52853000E+03, 0.27587100E+03, 0.67059900E+02, 0.37636800E+03, -.16785700E+02, 0.15524800E+04, 0.19483100E+03, 0.30571300E+04, 0.24491600E+04, -.24891900E+04, -.51428600E+04, 0.16244600E+04, 0.34317500E+04, 0.37347800E+04, -.49398800E+04, -.33882700E+04, 0.64932600E+03, -.22367900E+03, -.99576700E+03, 0.10076000E+04, -.47013100E+03, 0.11075900E+04, -.10016700E+04, -.30565300E+04, 0.58905700E+03, -.18734000E+03, -.86769900E+03, 0.85315900E+03, -.45491200E+03, 0.85386400E+03, -.89474600E+03, 0.10046200E+05, -.74965600E+03, 0.41221400E+03, 0.20706300E+04, -.25750000E+04, 0.23201200E+04, -.16573200E+04, 0.21740600E+04, -.42951500E+04, -.15275900E+04, -.63509500E+03, -.15181500E+04, 0.14928500E+04, -.11464900E+04, 0.50387400E+03, -.16153400E+04, -.31891500E+04, 0.22844700E+04, -.61266300E+03, -.16484000E+04, 0.14471400E+04, -.22330900E+03, 0.12959000E+04, -.16924500E+04, 0.83130200E+04, 0.31576400E+03, 0.91656800E+03, 0.28622000E+04, -.29569700E+04, 0.14193600E+04, -.19994200E+04, 0.29823200E+04, -.30082100E+04, -.36112300E+03, -.18618600E+03, -.93131600E+03, 0.44743700E+03, -.50565200E+03, -.51642400E+03, -.11135500E+04, 0.96379200E+03, 0.49837900E+04, -.62773300E+03, -.84348300E+03, 0.45985200E+03, 0.27448900E+03, 0.10345400E+03, -.88975800E+03, 0.83909600E+03, -.53536200E+03, 0.30325900E+03, 0.51958800E+03, -.42345900E+03, 0.50572800E+03, 0.65760200E+03, 0.55301700E+03, -.16041400E+04, 0.90036000E+03, -.99303500E+03, -.10046800E+04, -.63718300E+03, 0.41722100E+03, -.81742300E+03, -.96323300E+03, 0.77669300E+03, 0.11327300E+04, 0.48443400E+03, 0.47015200E+03, 0.95408900E+02, -.33107400E+03, 0.47817100E+03, 0.10802900E+03, -.39565900E+03, -.14434900E+04, -.49637500E+03, -.86052500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.65764800E+00, 0.85590200E-02, 0.46892400E+00, 0.24800000E+01, -.17215600E+01, -.52480600E+00, -.65570900E-01, 0.81094600E+00, 0.78634700E+00, 0.13121000E+00, 0.61427000E-01, -.20828800E+00, 0.18052600E+00, -.51624400E+00, 0.71043400E-01, 0.31592100E+00, -.11141600E+01, -.11681900E+00, 0.93048100E+00, 0.54816900E+00, -.42335400E+01, 0.15955700E+01, 0.12764500E+01, 0.10416200E+03, -.50914100E+04, 0.10571500E+04, -.15904000E+03, -.10856900E+04, 0.11966600E+04, -.83594500E+03, 0.15995200E+04, -.11403900E+04, 0.94376000E+02, 0.51855800E+03, -.26796400E+04, -.60089900E+04, 0.20771200E+04, 0.25172200E+04, 0.52428700E+04, -.56933200E+04, 0.13194400E+05, 0.13901600E+04, -.16959300E+04, -.59350400E+03, -.66450700E+03, 0.35245600E+04, -.22308500E+04, -.51548700E+03, -.23211600E+03, 0.16867000E+04, -.10330000E+03, -.15405600E+03, 0.27320100E+03, 0.29687500E+03, 0.12233000E+04, -.29907200E+03, -.75333300E+03, -.62699300E+04, 0.26749200E+03, 0.44980000E+03, 0.65615100E+03, -.27454300E+02, 0.88493800E+03, 0.65576500E+03, 0.18937100E+04, -.10114400E+04, -.21810200E+03, -.30933300E+02, -.56302600E+03, -.13110400E+03, -.17294600E+04, -.19423800E+03, -.98074900E+03, -.35918500E+04, 0.35784700E+04, 0.74269900E+04, -.31924800E+04, -.42126400E+04, -.63170900E+04, 0.71750900E+04, 0.57265600E+04, -.15011100E+04, 0.39533800E+03, 0.15124400E+04, -.15788200E+04, 0.82143200E+03, -.19236600E+04, 0.15539900E+04, 0.52258800E+04, -.14353000E+04, 0.27832600E+03, 0.12677500E+04, -.12772000E+04, 0.79170400E+03, -.15501900E+04, 0.13424800E+04, -.14984300E+05, 0.21927500E+04, -.81961400E+03, -.33128400E+04, 0.36294400E+04, -.30758600E+04, 0.26160200E+04, -.34762600E+04, 0.57263100E+04, 0.12472100E+04, 0.13405300E+04, 0.27368200E+04, -.22922800E+04, 0.10415700E+04, -.10541900E+04, 0.28584600E+04, 0.54301400E+04, -.32100100E+04, 0.86118000E+03, 0.23951500E+04, -.21660700E+04, 0.48355200E+03, -.23925600E+04, 0.24952400E+04, -.11864200E+05, 0.16739100E+04, -.20560300E+04, -.51388600E+04, 0.49552800E+04, -.14656700E+04, 0.43760100E+04, -.53516200E+04, 0.62067700E+04, -.73166100E+03, 0.33166600E+02, 0.12170100E+04, -.52657700E+03, 0.11311400E+04, -.18497400E+03, 0.15878800E+04, -.16737300E+04, -.56443200E+04, 0.64116800E+03, 0.92276300E+03, 0.23107900E+03, -.28733900E+03, 0.58949900E+03, 0.10584600E+04, -.16235900E+04, 0.58872100E+03, -.39965900E+03, -.75697500E+03, 0.66072500E+03, -.86108500E+03, -.81682700E+03, -.78091100E+03, 0.27572000E+04, -.14242800E+04, 0.16190500E+04, 0.13847200E+04, 0.89243300E+03, -.99753800E+03, 0.98119300E+03, 0.14193900E+04, -.13754800E+04, -.18197500E+04, -.11237200E+04, -.85840700E+03, -.12167500E+03, 0.50812900E+03, -.82672600E+03, 0.20126400E+02, 0.12335400E+03, 0.21087200E+04, 0.86525600E+03, 0.14024600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10630500E+01, 0.29924400E-01, -.25194200E+01, -.55137900E+01, -.46324100E+00, 0.81891700E+00, 0.27231600E+00, 0.11093000E+01, 0.55486400E+00, -.11768400E+00, -.92145000E-01, -.19043000E-01, 0.25296000E+00, -.18136200E+00, 0.17672300E+00, 0.79081900E-01, 0.74012900E+00, -.16625300E+00, 0.50805600E+00, 0.11956000E+01, 0.21791900E+01, -.11206600E+01, 0.31840300E+01, 0.47026400E+00, -.69180800E+04, 0.43594100E+03, -.36653000E+03, -.18180100E+04, 0.19092300E+04, -.12828400E+04, 0.18228700E+04, -.18251800E+04, 0.57421700E+04, 0.11482100E+04, -.70894300E+04, -.12985400E+05, 0.56175700E+04, 0.68210800E+04, 0.10299300E+05, -.12830800E+05, 0.20949400E+05, 0.67090500E+04, -.54373100E+03, 0.12448600E+04, -.40997000E+04, 0.56955600E+04, -.35947200E+04, 0.16176000E+04, 0.93628400E+03, 0.29785000E+04, -.11482500E+03, -.86297700E+02, 0.20862100E+03, 0.31734000E+03, 0.10867000E+04, -.36618700E+02, 0.13206500E+04, -.16790300E+05, -.17172000E+03, 0.40496300E+02, -.40203800E+03, 0.59236400E+03, -.15724300E+04, 0.71893400E+01, 0.43862600E+04, -.12046000E+04, -.11273600E+04, -.56649800E+03, -.56443400E+03, 0.30955300E+03, -.43320800E+04, -.92828400E+03, -.10039400E+05, -.59888000E+04, 0.87354200E+04, 0.15378400E+05, -.65328800E+04, -.98213200E+04, -.11172200E+05, 0.15190200E+05, 0.80977700E+04, -.13722300E+04, 0.64029300E+03, 0.24911600E+04, -.25225000E+04, 0.12377000E+04, -.26063300E+04, 0.24892500E+04, 0.71985200E+04, -.11501500E+04, 0.61585000E+03, 0.22509500E+04, -.22109900E+04, 0.11169500E+04, -.20165300E+04, 0.22901200E+04, -.27476200E+05, 0.17810700E+04, -.11385300E+04, -.51338900E+04, 0.74378400E+04, -.60468400E+04, 0.65392500E+04, -.54235100E+04, 0.13620100E+05, 0.32930200E+04, 0.12457600E+04, 0.32820900E+04, -.40577200E+04, 0.33229600E+04, -.29284100E+04, 0.35768200E+04, 0.78424000E+04, -.60537300E+04, 0.17969800E+04, 0.42071300E+04, -.38771500E+04, 0.77783300E+03, -.26425500E+04, 0.42593500E+04, -.19136900E+05, -.31766300E+04, -.32537900E+04, -.78382400E+04, 0.76921800E+04, -.31687000E+04, 0.43238100E+04, -.82178700E+04, 0.64280100E+04, 0.15891800E+04, 0.10001300E+04, 0.27014500E+04, -.14690600E+04, 0.10537500E+04, 0.13114400E+04, 0.30673300E+04, 0.11835500E+03, -.14714900E+05, 0.92092500E+02, 0.55980800E+03, -.64854400E+03, -.27520900E+03, -.27934100E+04, 0.36095000E+03, -.15723200E+04, 0.14249000E+04, -.69690000E+03, -.11854400E+04, 0.89014200E+03, -.84095600E+03, -.84255400E+03, -.12480200E+04, 0.37895000E+04, -.22873000E+04, 0.25030200E+04, 0.22895600E+04, 0.16205900E+04, -.76570100E+03, 0.24349500E+04, 0.22308900E+04, -.24244400E+04, -.27870400E+04, -.47014400E+03, -.11020100E+04, -.27176000E+03, 0.53079100E+03, -.13047400E+04, -.57509300E+03, 0.12772000E+04, 0.35441400E+04, 0.24454400E+04, 0.22603300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14673800E-01, 0.80124800E-01, -.82563500E+00, 0.41575300E+01, 0.20711100E+00, -.88365400E-01, 0.58581000E+00, -.36870600E+00, -.65585000E+00, -.19021300E+00, 0.40686300E+00, -.88115500E+00, -.23053000E+00, 0.46801200E+00, -.12709600E+00, 0.30743900E+00, -.39312800E+00, 0.19021900E+00, 0.57881900E+00, 0.11118600E+01, -.96352900E+00, 0.21402800E+00, -.12152400E+00, -.26136000E-01, 0.15365200E+00, 0.59111400E+03, -.16391100E+03, -.26973400E+03, 0.16456900E+03, -.34145000E+02, 0.14366900E+03, -.28064300E+03, -.28164100E+04, 0.99414000E+03, -.53662700E+02, -.23374200E+03, 0.60943100E+03, -.12999200E+04, -.69914000E+03, -.36365800E+03, -.29749500E+04, -.23739700E+04, 0.60426400E+03, 0.90790500E+03, 0.11759600E+03, -.85837900E+03, 0.38980500E+03, 0.90526600E+03, 0.40661200E+03, -.82996700E+03, -.27217600E+00, 0.87142600E+01, -.10328900E+03, 0.94056400E+02, -.65671100E+02, 0.53100500E+02, 0.68707700E+03, 0.29130700E+04, -.21522700E+03, -.29386100E+03, 0.22473400E+03, 0.30334700E+03, 0.43740600E+03, -.34724300E+03, -.28496200E+03, 0.88529300E+02, 0.25829400E+03, 0.23171300E+03, -.77127500E+02, -.11280700E+03, 0.46071600E+03, 0.28833900E+03, 0.50888000E+04, -.42223000E+03, -.19870400E+03, -.71057900E+02, -.92900700E+03, 0.19561400E+04, 0.59703400E+03, 0.69723900E+02, 0.13359500E+03, -.61269000E+03, 0.18188200E+03, 0.30240600E+03, -.19347600E+03, 0.52158700E+02, -.97710500E+02, 0.32166500E+03, 0.18878900E+03, -.58939300E+03, 0.14692000E+03, 0.26155300E+03, -.19437800E+03, 0.51951500E+02, -.19047500E+03, 0.26941900E+03, -.34623700E+03, 0.26395700E+04, -.54395700E+03, -.93784200E+03, 0.61216000E+03, 0.81009700E+02, 0.47201600E+03, -.93710300E+03, 0.42639900E+03, -.23508900E+04, 0.30643900E+03, 0.55262500E+03, -.40068200E+03, 0.15937000E+02, -.51412300E+03, 0.53855500E+03, 0.59685000E+03, 0.14966400E+03, 0.10634800E+03, 0.25160500E+03, -.25672900E+03, 0.19271500E+03, -.17986500E+03, 0.24957400E+03, 0.42294500E+03, 0.21904000E+04, -.47350400E+03, -.92593700E+03, 0.48212000E+03, 0.27567700E+03, 0.10541200E+04, -.85720600E+03, 0.55787500E+03, -.12424900E+04, -.38400100E+02, 0.11637400E+03, -.19861900E+03, 0.20244300E+03, -.80454100E+03, 0.84098700E+02, 0.51907600E+03, 0.29183500E+04, -.14371200E+03, -.21663500E+03, 0.16269700E+03, 0.21028100E+03, 0.29946600E+03, -.26129800E+03, 0.16419700E+03, -.20696900E+03, 0.12838600E+02, -.80857800E+02, -.18696900E+02, 0.64700700E+02, 0.27841500E+03, -.61501500E+02, 0.11782900E+03, -.20757700E+03, 0.17881600E+03, 0.23225000E+03, 0.12687700E+03, 0.67082100E+03, 0.17223800E+03, 0.20259400E+03, -.21933400E+03, -.17762800E+03, 0.52051300E+03, -.96187900E+02, -.25909700E+02, 0.30887800E+02, -.15580400E+03, -.12177700E+03, -.31933000E+03, -.10496200E+03, 0.23626500E+03, 0.20460600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14959900E+00, -.97806000E-01, 0.45215200E+00, -.43315000E+01, -.46772300E+00, 0.33427000E-01, -.72557800E+00, 0.44829500E+00, 0.48478200E+00, -.82067300E-01, 0.39641200E+00, -.55877300E+00, -.31481300E+00, -.92674000E+00, -.56633000E-01, -.41771200E+00, -.38624900E+00, -.30509900E+00, -.13588300E+01, 0.25273600E+00, 0.13110200E+00, -.55530700E+00, -.59066600E+00, -.38811500E+00, 0.38751100E-01, 0.77712600E+00, -.19864300E+03, -.89063300E+02, 0.14780100E+03, 0.15253800E+03, 0.10622000E+03, -.73593300E+02, 0.63622800E+04, -.34755700E+04, -.17333900E+04, -.17313300E+04, 0.31111500E+03, 0.31063300E+04, 0.14834300E+04, -.16098600E+04, -.43058700E+04, 0.28039100E+04, 0.15329800E+04, 0.15586400E+04, -.71578200E+03, -.21723500E+04, -.88329400E+03, 0.14920200E+04, -.55352100E+03, 0.24117900E+03, -.16764200E+01, -.18573600E+02, 0.20515300E+03, -.55111500E+02, -.29568600E+02, -.31406600E+02, 0.26753800E+04, -.12249100E+04, -.10848600E+04, -.11820400E+04, 0.60049100E+03, 0.12003400E+04, 0.41074900E+03, -.11429900E+04, 0.36642600E+03, -.13971600E+03, -.16701900E+03, -.20926100E+03, 0.46089200E+02, 0.13256400E+03, 0.15003000E+03, -.28121800E+03, -.64702200E+04, 0.31153600E+04, 0.18398300E+04, 0.18680100E+04, -.40587100E+03, -.32683700E+04, -.15941700E+04, 0.18073100E+04, -.27728600E+02, 0.45111600E+02, 0.13480300E+03, -.17102700E+01, -.65861300E+02, -.91705200E+02, -.10598200E+03, -.21182100E+02, -.13609900E+03, 0.93293700E+02, 0.13053700E+03, 0.86611100E+01, -.40892600E+02, -.13076900E+03, -.10357600E+03, -.59106300E+01, 0.10915100E+04, -.11879100E+04, -.17107400E+03, 0.88478600E+02, -.27547000E+03, 0.85016400E+03, 0.81247700E+03, 0.14668500E+03, -.25867200E+03, 0.26294400E+03, -.12319300E+03, -.29146700E+03, 0.39170400E+03, -.44321600E+03, -.51811800E+03, -.32717800E+03, -.53102300E+03, 0.26209100E+03, 0.25598800E+03, 0.96696100E+02, -.67931100E+02, -.22627500E+03, 0.24631800E+03, 0.96993000E+02, 0.29274200E+04, -.93561700E+03, -.10949700E+04, -.86255900E+03, 0.22084400E+03, 0.14787000E+04, 0.44834100E+03, -.88160300E+03, -.29301900E+02, 0.29825900E+02, 0.31938900E+03, 0.17720300E+03, -.14119700E+03, -.33794300E+03, -.84043900E+03, 0.19129200E+03, 0.18877800E+04, -.10096900E+04, -.86188600E+03, -.93915200E+03, 0.59836400E+03, 0.90211700E+03, 0.22503400E+03, -.92067100E+03, 0.10005200E+03, -.26030500E+03, 0.10484500E+02, 0.63623200E+02, -.13733400E+03, 0.18819500E+03, 0.40126100E+03, 0.63736900E+02, -.47137800E+02, -.39608900E+02, 0.44383300E+02, 0.29648200E+02, -.74539200E+02, -.49984100E+03, -.46567000E+02, 0.21863400E+02, -.10616000E+03, -.59959500E+02, -.32713300E+03, 0.51010700E+02, 0.66467800E+01, -.28262800E+03, -.14551500E+03, -.11690600E+03, -.86003000E+02, -.20949000E+03, 0.22283100E+03, 0.10712000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.42408900E+01, -.20734400E+01, -.46741800E+00, -.25296700E-01, -.47746900E+01, -.16208700E+01, 0.57832300E+00, 0.26041000E+01, 0.71080200E-01, -.21595500E+01, 0.77918800E+00, -.14541100E+01, -.48735300E+00, -.88175400E+00, 0.87428900E+00, 0.69736000E+00, 0.16528800E+01, 0.93211600E+01, 0.18926500E+02, -.50982200E+01, 0.11068000E+02, -.65833000E+01, 0.49728000E+01, 0.45057300E+01, 0.97812800E+00, -.93939100E+01, 0.53203300E+01, -.26706600E+04, 0.78128000E+03, -.19898800E+04, 0.66489100E+01, -.28419700E+04, -.59668300E+05, 0.65790300E+05, 0.92080000E+04, 0.44014900E+04, 0.43037500E+04, -.31744500E+05, -.18894000E+05, 0.14524800E+04, 0.46370000E+05, -.38322500E+05, -.10138500E+05, -.75620700E+04, -.16390000E+04, 0.24739700E+05, 0.77723100E+04, -.59116000E+04, 0.12613200E+05, -.55131500E+04, -.61269700E+03, 0.15489000E+03, -.36649700E+04, 0.13670500E+04, -.11148200E+04, 0.68515700E+03, -.20688800E+05, 0.13777300E+04, 0.10099900E+05, 0.10140800E+05, -.82936800E+04, -.10313600E+05, -.81929900E+04, 0.92129400E+04, -.69989600E+04, 0.46557100E+04, 0.25821100E+04, 0.45872800E+04, -.74013700E+03, -.37866000E+04, -.71976200E+04, 0.52342400E+04, 0.71977300E+05, -.57357400E+05, -.11817900E+05, -.77852100E+04, -.36928700E+04, 0.37963400E+05, 0.21555400E+05, -.59927400E+04, 0.23008600E+04, -.17786700E+04, 0.70619300E+03, 0.42246300E+04, -.23713400E+04, 0.14269700E+04, -.75917800E+03, 0.45158300E+04, 0.31188000E+04, -.19021700E+04, 0.91864200E+03, 0.39767200E+04, -.27547100E+04, 0.17231600E+04, -.75316900E+03, 0.41366300E+04, -.36995700E+05, 0.32888100E+05, -.35986200E+04, -.10886300E+05, 0.17275000E+05, -.15204600E+05, 0.36372600E+04, -.11937900E+05, 0.24152800E+05, -.20347200E+05, 0.31334500E+04, 0.69541600E+04, -.12279900E+05, 0.11479500E+05, -.90727400E+03, 0.77447700E+04, 0.98691300E+04, -.92677000E+04, 0.27842000E+03, 0.40437600E+04, -.36672700E+04, 0.34941700E+04, -.30697900E+04, 0.39649100E+04, -.46545200E+05, 0.46737500E+04, 0.66533700E+04, 0.51337900E+03, 0.63081000E+04, -.21143900E+05, -.18073700E+04, 0.94286900E+03, -.13639400E+04, 0.14040900E+04, 0.81406100E+03, 0.31429700E+04, -.28526100E+04, 0.45192700E+04, 0.10176800E+05, 0.26776000E+04, -.14654100E+05, 0.58124200E+04, 0.85517800E+04, 0.87617900E+04, -.80134100E+04, -.97518800E+04, -.94733800E+04, 0.79212300E+04, 0.35644800E+04, 0.39818300E+04, -.16062800E+04, -.23595700E+04, 0.14750100E+04, -.69105000E+03, -.42650500E+04, -.26503000E+04, 0.14134300E+04, -.27769100E+04, 0.22639000E+04, 0.37210700E+04, 0.33858800E+04, 0.13646400E+05, 0.42855300E+04, 0.36327600E+04, -.21882300E+04, -.18943600E+04, 0.12176100E+05, -.87818600E+03, -.62682400E+03, 0.29177400E+04, -.59935200E+03, -.16485800E+04, 0.25758000E+04, 0.41663300E+04, 0.21169900E+04, 0.18252500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14880100E+01, -.63275200E-01, -.33856100E+00, -.43712700E+01, 0.13914800E+01, -.77715400E-01, -.64296500E-01, 0.92105900E-01, -.54193300E+00, -.42811200E-01, 0.10180900E+01, 0.50530500E+00, -.91264100E+00, 0.14412000E+01, 0.44843500E+00, -.60846700E+00, -.19113200E+01, 0.35704200E+00, 0.69120700E+00, 0.18618000E+01, 0.11827400E+01, 0.59066600E+00, 0.30667700E+00, -.53709000E+00, -.43759800E+00, -.33139600E+01, -.32537900E+01, 0.72152200E-01, 0.25133700E+03, 0.30468300E+03, 0.21264300E+02, 0.65934400E+02, 0.28564800E+05, -.16241300E+05, -.66724800E+04, -.84524200E+04, 0.72177700E+03, 0.13172400E+05, 0.48139200E+04, -.80058000E+04, -.17515900E+05, 0.10981500E+05, 0.45991800E+04, 0.55159300E+04, -.15660100E+04, -.78754000E+04, -.11471100E+04, 0.52876300E+04, -.12743900E+04, 0.19769000E+04, -.21235700E+02, -.12424100E+03, 0.64784400E+03, 0.19219900E+03, -.22370000E+02, -.10989900E+03, 0.10319000E+05, -.46249500E+04, -.39136300E+04, -.45503300E+04, 0.26057500E+04, 0.43556900E+04, 0.13114200E+04, -.45465000E+04, 0.37848000E+04, -.17587200E+04, -.13782200E+04, -.14494400E+04, 0.15002000E+03, 0.13343400E+04, 0.68136000E+03, -.17106100E+04, -.27741300E+05, 0.13680500E+05, 0.69295500E+04, 0.89242600E+04, -.15081000E+04, -.13955100E+05, -.54255400E+04, 0.87385800E+04, 0.19051500E+03, 0.42534600E+02, -.85458600E+02, -.88454600E+02, -.13984900E+03, -.13218300E+03, -.17291100E+03, -.16361600E+03, -.12565900E+03, 0.14658100E+03, -.47631900E+02, -.39263700E+02, -.70459200E+02, -.28062500E+03, -.20090400E+03, -.91472600E+02, 0.47896600E+04, -.51923800E+04, 0.60194300E+03, 0.13891600E+03, -.19337500E+04, 0.33056000E+04, 0.17506600E+04, 0.41756700E+03, -.44269900E+04, 0.33937700E+04, -.11066900E+04, -.76517400E+03, 0.26343900E+04, -.27640000E+04, -.12976200E+04, -.97861200E+03, -.14978600E+04, 0.68268200E+03, 0.54297300E+03, 0.48575300E+03, -.25351500E+03, -.58963500E+03, 0.13195500E+04, 0.52761600E+03, 0.11087300E+05, -.26141100E+04, -.29322700E+04, -.35101900E+04, 0.55458200E+03, 0.53302600E+04, 0.12762300E+04, -.36944000E+04, -.68230100E+03, 0.25627400E+03, -.15433100E+02, -.38308300E+01, 0.33019600E+03, -.95183400E+03, -.21702400E+04, 0.12945400E+03, 0.67454800E+04, -.43810400E+04, -.32059400E+04, -.37558000E+04, 0.29343800E+04, 0.34493200E+04, 0.10280600E+04, -.37754000E+04, -.91198800E+02, -.77826700E+03, -.12309300E+03, -.57968500E+02, -.30358700E+03, 0.40091700E+03, 0.13266300E+04, -.69571200E+02, 0.35030100E+02, 0.17952400E+02, 0.67603200E+02, -.84109700E+02, -.12579300E+03, -.14907300E+04, 0.79618700E+02, -.17470000E+03, -.43688300E+03, -.20596400E+03, -.10372800E+04, 0.42977000E+02, 0.78236600E+02, -.88732700E+03, -.45639500E+03, -.23665600E+03, -.20653500E+03, -.35752600E+03, 0.78696300E+03, 0.23309100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.30402100E+00, 0.22011700E+00, -.42962000E-01, 0.10398400E+01, 0.15262500E+00, 0.15831200E+00, 0.34338500E+00, 0.10399400E+00, 0.19013800E+00, -.26902100E-01, 0.94707400E-01, -.61273100E+00, -.10331600E+00, 0.39602800E+00, -.28833800E-01, 0.47549800E+00, 0.33156000E+00, -.50069400E+00, -.17786100E+01, 0.75788800E+00, -.36919000E+00, 0.49558200E-01, -.43202600E+00, -.40730800E+00, -.95131600E-02, 0.63892200E+00, 0.54910100E+00, -.36368800E-01, 0.14508400E+00, -.83041000E+02, -.68423700E+02, -.47345600E+01, -.59903400E+04, 0.29688300E+04, 0.15252500E+04, 0.18441100E+04, -.59155200E+02, -.25775200E+04, -.41758300E+03, 0.17725100E+04, 0.25652300E+04, -.19386300E+04, -.81554300E+03, -.89670000E+03, 0.29301200E+03, 0.11445800E+04, -.10069100E+03, -.89531100E+03, 0.45516400E+02, -.18234000E+03, 0.47738200E+01, 0.48974000E+02, -.11980000E+03, -.19638600E+03, -.12189200E+03, 0.50957300E+01, -.26294000E+04, 0.14309500E+04, 0.10194500E+04, 0.11094700E+04, -.55403400E+03, -.96434500E+03, -.30902300E+03, 0.11339100E+04, -.48681100E+03, 0.92354800E+02, 0.26944300E+03, 0.20591200E+03, -.41764300E+02, -.36694900E+02, 0.21176100E+03, 0.27509000E+03, 0.52905300E+04, -.22298700E+04, -.15031700E+04, -.18374300E+04, 0.30246000E+03, 0.25796400E+04, 0.57454700E+03, -.18090500E+04, -.79269300E+02, 0.17554100E+02, 0.21116600E+02, 0.15210300E+02, -.19242500E+02, 0.22813600E+02, 0.83188400E+02, 0.16293300E+02, -.27612300E+02, -.58094700E+01, 0.18832400E+02, 0.15274500E+02, -.34308000E+02, 0.53718300E+02, 0.92259400E+02, 0.16602300E+02, 0.78946900E+03, 0.30101400E+03, -.29322800E+03, -.25751800E+03, 0.18627400E+03, -.13061200E+03, -.39223600E+03, -.27708000E+03, -.27502600E+03, -.15486200E+03, 0.29136300E+03, 0.27823600E+03, -.34636300E+03, 0.15435500E+03, 0.18759000E+03, 0.27257200E+03, 0.26844100E+03, 0.20660000E+01, -.12690900E+03, -.12283200E+03, 0.67778700E+02, 0.15343000E+03, -.19288500E+03, -.12516100E+03, -.21689500E+04, 0.85575300E+03, 0.71122200E+03, 0.77420400E+03, -.11181300E+03, -.10190500E+04, -.19622300E+03, 0.80933200E+03, 0.17630100E+01, 0.70423400E+01, 0.12799200E+01, 0.64712900E+02, -.18847100E+03, 0.11186900E+03, 0.37852600E+03, 0.31897700E+02, -.13666700E+04, 0.10559600E+04, 0.74730500E+03, 0.79237600E+03, -.60742800E+03, -.53332000E+03, -.39948000E+02, 0.85801100E+03, -.18816500E+03, 0.12472600E+03, 0.81543000E+02, 0.51152500E+02, 0.94947300E+02, -.13472200E+03, -.11243000E+03, 0.36926800E+02, -.30226300E+02, -.65959900E+01, -.75513500E+01, 0.99785300E+01, 0.29429700E+02, 0.87474100E+02, -.44746900E+02, 0.64484300E+02, 0.56334300E+02, 0.29620500E+02, 0.57692500E+02, 0.81170400E+01, -.20447400E+02, 0.14004500E+03, 0.55055500E+02, 0.31971300E+02, 0.96168800E+02, 0.78589300E+02, -.20279100E+03, -.25088700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.95104900E-01, 0.28418200E-01, -.56137900E+00, 0.26896800E+01, 0.97412300E-01, -.73640400E-01, 0.42238400E+00, -.15721200E+00, -.35934800E+00, -.12273900E+00, -.27962600E+00, -.96691300E-01, 0.64969100E-01, 0.12467800E+00, -.98348500E-01, -.49902700E+00, -.70525000E+00, 0.18220700E+00, 0.64941000E+00, 0.18043900E+00, 0.88312800E-01, -.40116000E+00, -.18398300E+00, -.20227600E+00, 0.28622500E-01, 0.40000300E+00, -.14849100E+00, -.17666200E-01, 0.46276200E-01, -.39894100E+00, -.36984800E+02, -.62601400E+00, -.24599700E+03, 0.37693100E+03, 0.12148200E+03, 0.17187200E+03, 0.13660400E+02, -.42300500E+02, 0.16929700E+03, 0.15790700E+03, -.57971100E+02, -.30226900E+03, -.79031200E+02, -.28053900E+02, 0.36751200E+02, -.64615300E+02, -.19911000E+03, -.38146800E+02, -.80523700E+02, 0.15107200E+02, -.18632500E+02, -.31798700E+01, 0.71404700E+01, -.56377000E+02, -.20172900E+02, -.14501700E+02, -.44610800E+03, 0.25800200E+03, 0.23335300E+03, 0.20194300E+03, -.13318400E+03, -.14351300E+03, -.98840700E+02, 0.21112300E+03, -.15007200E+03, 0.15380300E+03, 0.69572400E+02, 0.22020700E+02, 0.26314800E+02, 0.45031400E+02, 0.14441100E+03, 0.43115800E+02, 0.31075000E+03, -.11325800E+03, -.18451300E+03, -.26452200E+03, 0.81040200E+02, 0.15684300E+03, -.45456300E+02, -.25880200E+03, -.40739400E+02, 0.14124700E+01, 0.37157800E+01, -.67277600E+01, 0.46512400E+01, -.13936800E+02, 0.36742800E+02, -.63877900E+01, -.43291300E+02, 0.13349300E+02, 0.40746700E+01, -.50899000E+01, 0.38274900E+01, -.10262100E+02, 0.41339700E+02, -.54205200E+01, 0.87823500E+03, -.21308700E+03, -.12842700E+03, -.85220000E+02, -.90102200E+02, 0.19330200E+03, -.94248000E+02, -.94717700E+02, -.40327100E+03, 0.11635500E+02, 0.99020300E+02, 0.64109600E+02, 0.26501400E+01, -.78145000E+02, 0.48928100E+02, 0.61096600E+02, 0.12835900E+02, 0.28707500E+02, -.32265000E+02, -.40917200E+02, 0.20313000E+02, 0.27493600E+01, 0.14767100E+02, -.44729800E+02, -.33337000E+03, 0.13952800E+02, 0.15277300E+03, 0.15299200E+03, 0.24201800E+01, -.97012600E+02, -.32965400E+01, 0.18272000E+03, -.49351800E+02, 0.10502300E+02, 0.15997300E+02, 0.57066900E+02, -.75623100E+02, -.65409700E+02, 0.29650200E+02, 0.39569600E+02, -.18720200E+03, 0.35727000E+03, 0.17992100E+03, 0.14486300E+03, -.15079600E+03, -.41588300E+02, -.22004200E+02, 0.16150300E+03, -.63653700E+02, 0.99585600E+01, 0.29454100E+01, -.29278100E+02, 0.82000300E+02, 0.49146300E+02, 0.17756600E+03, -.32062800E+02, -.23816100E+02, 0.73044500E+01, -.12258100E+02, 0.49089500E+01, -.15544700E+01, -.56964200E+02, -.31298800E+02, 0.19039200E+02, 0.12907600E+02, 0.42915500E+02, -.24856400E+02, 0.12250800E+02, -.51822600E+01, 0.24246400E+02, 0.12802300E+02, -.53984800E+01, 0.41506000E+02, 0.26339000E+01, -.48696300E+02, 0.40005100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43006500E+00, -.10566500E-01, 0.77819900E+00, 0.47587400E+01, 0.66111400E+00, 0.56632800E+00, -.22980800E+00, -.19730200E+00, -.68881900E+00, 0.50947500E-01, -.14156100E+00, 0.14207700E+01, 0.81931800E-01, -.57450100E-01, 0.12598100E+00, -.14228300E+01, -.22552000E+00, 0.55703700E-01, 0.15658200E+01, -.43180900E+00, 0.87740400E+00, 0.56700100E-01, -.41345100E+00, 0.12912700E+00, -.24032500E+00, -.61787500E+00, -.25095300E+00, 0.48230800E-01, -.16142600E+00, 0.32980000E-01, 0.13378300E+01, 0.22552000E+02, 0.24627400E+04, -.31026100E+04, -.95243200E+03, -.11847000E+04, 0.11475500E+03, 0.10067200E+04, -.14962800E+03, -.11131400E+04, -.55687600E+03, 0.19488700E+04, 0.36923600E+03, 0.18485300E+03, -.55263900E+02, -.50900900E+01, 0.10455500E+04, 0.16453800E+03, 0.21124400E+03, 0.55018900E+03, 0.16025400E+03, 0.77254800E+01, 0.61114000E+01, 0.24223500E+03, 0.10826200E+03, 0.25891000E+02, 0.15152100E+04, -.84251400E+03, -.77929100E+03, -.66544100E+03, 0.42572500E+03, 0.37816300E+03, -.79624300E+02, -.68540100E+03, 0.12223200E+04, -.79506300E+03, -.50175900E+03, -.37152800E+03, -.65219100E+02, 0.26751900E+03, -.23098200E+03, -.48695500E+03, -.25999700E+04, 0.16371200E+04, 0.10699900E+04, 0.14456700E+04, -.35889600E+03, -.13943200E+04, -.18059500E+03, 0.14345700E+04, 0.14459300E+03, 0.18516300E+02, 0.54715700E+01, 0.22573800E+02, -.21541700E+02, 0.41228500E+02, -.38907900E+02, -.48099800E+01, 0.13438900E+03, -.70329800E+01, -.61666100E+01, 0.15157000E+02, -.80604900E+01, 0.22791400E+02, -.53183400E+02, -.22313900E+01, -.26053100E+04, -.20080100E+03, 0.39471000E+03, 0.25891700E+03, 0.15849200E+03, -.48196200E+03, 0.19065400E+03, 0.33720300E+03, 0.99468500E+03, 0.56168800E+03, -.27008600E+03, -.16728400E+03, 0.17240400E+03, 0.64205800E+02, -.73056500E+02, -.18836400E+03, -.50275900E+02, -.99603600E+01, 0.75329800E+02, 0.11434600E+03, -.29984700E+02, -.37213200E+02, 0.99597400E+02, 0.12331600E+03, 0.19179800E+04, 0.12577100E+03, -.66555600E+03, -.74506300E+03, -.11617600E+03, 0.69772200E+03, -.20577100E+03, -.86775500E+03, -.87022200E+02, 0.66287900E+02, 0.30965100E+02, -.83839900E+02, 0.26872300E+03, 0.51405600E+02, -.12927600E+03, -.15527400E+02, 0.39945200E+03, -.13232300E+04, -.64951600E+03, -.48913900E+03, 0.59067700E+03, 0.79471400E+02, -.20293500E+03, -.52959700E+03, -.53775000E+02, -.23274600E+03, -.49485700E+02, 0.34601600E+02, -.16368100E+03, -.87996500E+02, -.12572800E+03, 0.27301600E+02, 0.76110100E+02, 0.73857900E+01, 0.33042000E+02, -.40814500E+01, -.22189400E+01, 0.18544500E+03, 0.22993500E+03, -.65189700E+02, -.87207300E+02, -.13167600E+03, 0.86387700E+02, -.29556000E+02, 0.23426700E+01, -.57839300E+02, -.14975900E+02, -.20455800E+02, -.10563200E+03, -.41079800E+01, 0.21954800E+03, 0.37189200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.35320400E+00, -.23900400E+00, -.58111500E+00, -.50235100E+01, -.91595100E+00, 0.10236600E+00, -.14745200E+00, 0.85617300E+00, 0.11617500E+01, -.25636700E+00, 0.43492100E+00, -.10242000E+01, 0.13469600E+00, -.51752700E+00, 0.31201100E+00, 0.38239500E+00, 0.49885000E-01, -.35890800E+00, -.32693800E+00, 0.25673100E+00, 0.42727100E-01, -.12892100E+00, -.44094800E+00, -.25947400E+00, 0.74596200E-01, 0.10133600E+01, 0.86949900E+00, -.13551300E-01, -.16589900E+00, 0.89058400E+00, 0.89447700E+00, 0.68618900E+00, 0.57718100E+04, 0.56161300E+03, -.11844500E+04, -.14269400E+04, 0.34010300E+02, 0.24093500E+04, 0.51204400E+03, -.13966200E+04, -.18745200E+04, 0.40635500E+03, 0.46759100E+03, 0.60987700E+03, -.32679300E+03, -.87400300E+03, -.66690100E+03, 0.61549000E+03, -.61885000E+02, 0.27685800E+03, -.79763900E+02, 0.73851300E+01, 0.12618000E+02, -.51142900E+02, -.21288400E+03, 0.21141100E+02, 0.14224200E+04, -.16224700E+04, -.35555200E+03, -.55976800E+03, 0.17607700E+03, 0.63536100E+03, 0.19079700E+03, -.56321700E+03, 0.47795700E+03, 0.30496200E+03, -.33197800E+03, -.17621600E+03, 0.18285500E+03, 0.29557400E+03, -.15138500E+03, -.17919600E+03, -.52539500E+04, -.20206600E+03, 0.11499100E+04, 0.13290700E+04, -.67999700E+02, -.21154300E+04, -.40059200E+03, 0.12899800E+04, 0.59336300E+02, -.47250700E+02, -.20541700E+02, -.53213700E+00, -.16766700E+02, 0.16183600E+02, -.69125200E+02, 0.38493600E+01, -.20971000E+01, 0.14794300E+02, 0.61442500E+01, 0.67208900E+01, -.99844700E+01, -.11674700E+01, -.19100800E+02, 0.98464900E+01, 0.10709200E+04, -.36086800E+03, -.34504400E+02, -.14824900E+03, -.19489700E+03, 0.47129600E+03, 0.56589700E+03, -.14649600E+03, -.78709200E+03, 0.31119900E+03, -.95372100E+01, 0.10999000E+03, 0.17916000E+03, -.43680000E+03, -.45229700E+03, 0.10152400E+03, -.33138500E+03, -.47911700E+03, 0.18380100E+03, 0.86250500E+02, -.42494100E+02, -.56441700E+02, 0.27590800E+03, 0.10273000E+03, -.39474000E+03, -.93474700E+03, -.22148800E+03, -.19466700E+02, 0.26852000E+03, -.54810400E+02, 0.34589900E+02, -.13418500E+02, 0.92460300E+01, 0.25338200E+02, 0.17814400E+03, 0.39440600E+02, -.10711200E+03, -.61221400E+02, 0.55092900E+02, 0.43279800E+02, 0.14016100E+04, -.10594100E+04, -.36929800E+03, -.59375000E+03, 0.30604000E+03, 0.68721400E+03, 0.28524300E+03, -.61282000E+03, 0.23322100E+03, 0.24051800E+03, -.17830500E+03, -.39466700E+02, 0.50347000E+02, 0.13883100E+03, -.26634800E+02, -.48956100E+02, 0.13561600E+02, -.58935800E+01, 0.18979300E+02, -.11822400E+01, 0.23350700E+01, -.69816400E+01, -.78052700E+02, 0.20987400E+01, -.27701600E+02, 0.69933600E+02, 0.16457100E+03, -.77512500E+01, 0.22471800E+01, -.75326100E+02, -.57509000E+02, -.12616400E+03, 0.84079600E+02, -.13397700E+02, 0.62704700E+02, -.31925900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.73598800E+00, 0.29565700E-01, 0.24738800E+00, 0.25716000E+01, 0.79164400E+00, 0.10579500E+01, 0.25900900E+00, -.31456700E+00, -.18891600E+00, -.55912600E-01, -.10761800E+01, 0.13103800E+00, 0.50000300E+00, -.94914000E+00, -.25263300E+00, 0.60515600E+00, 0.13541700E+01, 0.43512000E+00, -.41784200E-01, -.15025300E+01, -.49030300E+00, -.40660500E+00, -.11865700E+01, -.98309200E-01, -.20598900E-01, 0.17981800E+01, 0.11220400E+01, -.78953500E-01, -.13114700E+00, -.10010900E+01, -.33217800E+01, -.85292800E+00, -.16659900E+01, 0.66883300E+04, 0.16230000E+03, 0.46248300E+03, 0.36312100E+03, -.88684500E+02, -.22967400E+03, 0.33767700E+03, 0.16316400E+04, -.33018900E+04, -.38403600E+03, -.28768900E+03, -.49232600E+03, 0.40329200E+03, -.12847000E+04, -.27623800E+03, -.40355000E+03, 0.68833100E+02, -.12474100E+03, 0.55037800E+02, -.96860900E+02, -.46430200E+03, -.52803400E+03, -.24282700E+02, -.13781600E+04, -.80389000E+03, 0.88806400E+03, 0.73728300E+03, -.64393100E+03, -.56166400E+03, -.63373700E+03, 0.78790900E+03, -.50802700E+03, 0.10316100E+04, -.64704300E+02, 0.53650600E+02, 0.45647500E+03, 0.25124300E+03, 0.28105500E+02, 0.17070600E+03, 0.45571400E+03, -.46412500E+04, -.42186300E+03, -.95496200E+03, 0.75076600E+02, 0.90651700E+03, 0.95147500E+03, -.94931900E+03, -.75621400E+02, -.72082800E+02, -.29313200E+02, -.36067300E+02, -.11186000E+02, -.31235500E+02, -.37405300E+02, -.33599900E+02, -.11989400E+03, 0.35823500E+02, 0.83483800E+01, -.24073000E+02, -.21246500E+02, -.15997800E+02, 0.62856800E+02, -.26472900E+02, 0.36938100E+04, 0.71684500E+02, -.45323900E+03, -.35870100E+03, -.24407800E+03, 0.83592200E+03, 0.22751100E+03, -.35104600E+03, -.18119900E+04, -.26592500E+03, 0.33182400E+03, 0.27176200E+03, -.11165300E+03, -.41723700E+03, -.20343900E+03, 0.21431100E+03, -.26233900E+02, -.85786000E+03, 0.54288100E+02, -.10492300E+03, -.14059400E+02, 0.16424900E+02, 0.79820100E+02, -.88282000E+02, -.44827900E+04, -.59056700E+03, 0.86778100E+03, 0.14126300E+04, 0.33713500E+03, -.17341400E+04, -.36464800E+03, 0.15239000E+04, 0.16790400E+03, 0.45977200E+01, 0.28169200E+03, 0.17754300E+03, -.60488900E+03, -.56385400E+02, 0.52916400E+03, 0.70134500E+02, 0.51565800E+03, 0.14014200E+03, 0.48338000E+03, 0.25714800E+03, -.50181100E+03, 0.19624500E+03, -.13375500E+03, 0.36305500E+03, 0.18153400E+03, 0.52549400E+03, -.21722300E+03, -.10142200E+03, 0.35964000E+03, 0.24250500E+03, 0.10891400E+03, -.14654900E+03, -.67445400E+02, 0.60641000E+01, -.29975400E+02, 0.29411000E+02, -.10536900E+02, 0.41327000E+03, -.25150400E+03, 0.14404300E+03, 0.62267000E+02, 0.26544500E+03, 0.60860700E+03, 0.28422200E+02, -.25933000E+01, -.62288100E+02, -.31746300E+02, -.10054500E+03, 0.31730800E+03, 0.24546000E+02, -.20025300E+03, -.42921500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.44634500E+00, -.29168400E-01, 0.71818800E-01, -.20042100E+01, -.32887700E+00, 0.19939000E+00, 0.15324700E+00, 0.81323800E+00, 0.56086600E+00, -.27491300E-01, 0.59210400E+00, -.67371500E+00, -.32136100E+00, 0.82024100E+00, 0.61322900E-01, -.14839000E-01, -.24599700E+01, -.39607900E-01, 0.54359000E+00, 0.19179200E+01, -.24541800E+01, 0.91601100E+00, 0.11145100E+01, 0.25494300E+00, 0.12983200E-02, -.12113600E+01, -.65661400E+00, 0.14628400E-01, 0.17643900E+00, 0.24461600E+00, -.51967500E+00, 0.18614500E+00, 0.87501000E+00, -.27138900E+00, 0.52570600E+03, 0.61570100E+03, -.77508700E+03, -.15031600E+03, -.21886400E+03, 0.61629500E+03, -.37353000E+03, -.55231500E+03, -.30518700E+03, -.22451700E+03, 0.54659300E+03, -.11428100E+03, -.63520800E+02, -.25912800E+03, -.56395400E+01, -.26467300E+02, -.11187500E+02, -.10718600E+02, 0.44334800E+02, 0.13595700E+02, 0.79403000E+02, -.63848800E+01, -.12977300E+04, 0.10694100E+04, 0.68038700E+03, 0.57052900E+03, -.30405800E+03, -.36747600E+03, 0.35853800E+03, 0.60165600E+03, -.48236800E+03, 0.10018400E+03, 0.21190000E+03, 0.12058300E+03, -.80472800E+02, -.12069200E+03, 0.21270300E+03, 0.13431300E+03, 0.52832000E+03, 0.23710800E+03, -.66590000E+03, -.81164700E+03, 0.81532000E+03, 0.39050800E+03, 0.30574600E+03, -.80419700E+03, -.11091700E+03, 0.39183400E+02, 0.20795700E+02, -.57182700E+01, 0.20021100E+02, -.31397100E+02, 0.47252700E+02, -.36032800E+01, -.93324300E+02, 0.23682700E+02, 0.95081300E+01, -.91101800E+01, 0.17574300E+02, -.19093700E+02, 0.42892100E+02, -.77095300E+01, 0.99268800E+03, 0.98291800E+02, -.20538900E+03, -.80498800E+02, -.11916400E+03, 0.12117000E+03, -.49195300E+03, -.11227400E+03, -.44406800E+03, -.25707500E+03, 0.20785200E+03, 0.14163500E+03, -.43959100E+02, -.43569600E+02, 0.20687500E+03, 0.14852500E+03, -.84542800E+02, 0.26279300E+03, -.85275700E+02, -.10102000E+03, 0.10874700E+03, -.16682100E+02, -.95967500E+01, -.10728700E+03, -.22232900E+03, 0.26453500E+03, 0.36331800E+03, 0.27881100E+03, -.17666700E+03, -.68377100E+02, 0.22009800E+03, 0.34360300E+03, -.31919500E+02, 0.56977800E+01, -.44278300E+02, 0.58033500E+02, -.39280200E+02, -.30443800E+02, -.46977600E+01, 0.50522300E+02, -.36134700E+03, 0.81492700E+03, 0.46142000E+03, 0.35001000E+03, -.47941700E+03, -.30838000E+02, 0.38560900E+03, 0.37503900E+03, -.86958100E+02, -.71194600E+02, 0.13160800E+02, -.54793300E+02, 0.86278700E+02, -.74989400E+01, 0.63933300E+02, -.67547900E+02, -.51649300E+02, 0.48201000E+01, -.20239300E+02, -.47436400E+00, -.33475600E+01, -.15684400E+03, -.86995400E+02, -.14473000E+02, 0.11353200E+03, 0.13579500E+02, -.17457900E+03, 0.22315500E+02, -.51092700E+01, 0.86145600E+02, 0.31879300E+02, 0.27981100E+02, -.26231700E+02, -.11886800E+01, -.21525500E+03, -.31353000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.98586000E+00, -.27691600E-02, 0.23148900E+01, 0.10821000E+02, 0.37905400E+00, 0.77851600E+00, -.39362200E+00, -.73987900E+00, -.11910000E+01, 0.87656000E-02, -.32607900E+00, 0.12324900E+01, -.13189300E+01, 0.13383400E+01, -.69954800E+00, -.51502300E+00, -.12565800E+01, 0.13813500E+01, 0.87679400E-01, -.12762900E+00, 0.64897900E+00, -.10333600E+01, 0.32314400E+00, -.34450600E-01, -.18263800E+00, -.87347500E+00, -.69937300E+00, -.10741700E-01, 0.32695600E-01, -.43270200E+00, -.14480000E+01, -.11921200E+01, -.10238500E+01, -.23110600E-01, 0.11875900E+01, -.37654800E+03, 0.42950100E+03, 0.18579700E+03, 0.42323300E+03, -.31512100E+03, 0.39866100E+03, 0.15159100E+04, -.73466100E+01, -.10138000E+03, -.29183600E+03, 0.13644400E+03, 0.32834600E+02, -.61283400E+02, -.38770800E+02, 0.47821800E+03, 0.26689500E+02, -.90220700E+01, -.43898600E+02, 0.43512900E+02, -.48985700E+02, -.14676000E+02, 0.13874700E+04, -.17048500E+04, -.68724800E+03, -.69217000E+03, 0.59374700E+03, 0.47677800E+03, -.75973700E+02, -.73573500E+03, 0.97858700E+03, -.31615200E+03, -.38534000E+03, -.12089100E+03, -.60584600E+02, 0.23025700E+03, -.41832100E+03, -.17173200E+03, -.14796000E+04, -.65391600E+03, 0.51085800E+03, 0.10450700E+04, -.67704500E+03, -.97876700E+03, -.90439600E+03, 0.98416800E+03, 0.22965200E+03, -.46470000E+02, -.22096600E+02, 0.30629400E+02, -.53666500E+02, 0.53907800E+02, -.98412700E+02, 0.27992900E+02, 0.17574000E+03, -.21057600E+02, -.16904400E+01, 0.28069700E+02, -.28033200E+02, 0.32223400E+02, -.56769300E+02, 0.32955100E+02, -.10342500E+04, -.78955700E+03, 0.27327300E+03, -.52607000E+01, -.99571200E+01, -.83921100E+01, 0.44591400E+03, 0.61456900E+02, -.95348300E+02, 0.12138000E+04, -.21819100E+03, -.64341600E+01, 0.23946400E+03, -.23647400E+03, -.10185000E+03, -.35634700E+02, -.29244500E+03, -.45352600E+03, 0.15965000E+03, 0.15921200E+03, -.99834800E+01, -.84243400E+02, 0.70061100E+02, 0.17867600E+03, 0.29166000E+03, -.24029500E+03, -.56006900E+03, -.43793100E+03, 0.26398600E+03, 0.14523600E+03, -.27214400E+03, -.58326700E+03, 0.87572600E+02, -.30173000E+02, 0.15780700E+03, -.10059700E+03, 0.11229000E+03, 0.74902700E+02, 0.16868100E+03, -.22598500E+02, -.76340200E+02, -.18080200E+04, -.42092900E+03, -.39047700E+03, 0.87269100E+03, 0.65285400E+02, 0.51019000E+02, -.43312500E+03, 0.16656400E+03, 0.17823700E+03, -.12409700E+03, 0.87505300E+02, -.15816300E+03, -.55926300E+02, -.38123600E+03, 0.91742700E+02, 0.10042200E+03, -.10848800E+02, 0.42767600E+02, -.20186300E+02, 0.16914200E+02, -.88965200E+02, 0.58461200E+02, -.17333300E+01, -.14772600E+03, -.58347400E+02, -.48214500E+02, -.36519500E+02, -.42209800E+00, -.50081400E+02, -.40833500E+02, -.70611800E+02, 0.30888900E+02, 0.20280400E+02, 0.16574400E+03, -.14883600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11214300E+00, 0.87540500E-01, -.64210400E+00, 0.29512800E+01, -.37220900E+00, -.15541100E+00, 0.66330000E+00, 0.99196900E+00, 0.73632700E-01, 0.20024200E-02, 0.23915400E+00, -.24806100E+00, -.26696300E+00, -.50163400E+00, -.55459300E-01, 0.17979500E+00, 0.58000700E+00, -.14144400E+00, -.70590800E+00, -.15363400E+00, -.29116800E+00, 0.86466600E-01, 0.22339600E+00, -.12681500E-01, 0.26168300E+00, 0.86931000E+00, 0.57266800E+00, -.15067500E-02, -.75110400E-02, -.20155300E+00, 0.24500900E+00, -.35532600E+00, -.51033700E+00, 0.80394700E-01, -.52409000E+00, -.33402700E-01, -.17107500E+03, -.48498600E+02, -.10605200E+03, -.44753100E+02, 0.44034900E+03, -.12257000E+03, -.36619200E+02, -.84656800E+02, 0.51203100E+02, 0.17175300E+03, 0.89933600E+02, -.54220400E+02, 0.43940600E+02, 0.11696200E+02, -.24407300E+01, -.34788600E+02, 0.66015300E+02, 0.10438700E+03, 0.18541800E+03, -.62915400E+01, 0.11850500E+02, 0.20458700E+02, 0.17450300E+02, 0.11794700E+02, -.40035300E+02, -.16027200E+02, 0.82841100E+02, -.73236100E+01, -.52255600E+02, -.26777800E+02, -.28013900E+02, 0.25695400E+02, -.74769100E+02, -.99599800E+02, -.12655700E+03, -.88617500E+01, 0.47720700E+02, -.14492600E+03, -.11205300E+02, -.17047300E+02, 0.14879800E+03, -.35417100E+02, 0.80672600E+02, 0.37790600E+02, -.12156900E+02, 0.11670000E+02, 0.45306200E+01, 0.10609300E+01, 0.44742300E+01, 0.29587700E+01, 0.20289900E+02, 0.36200600E+01, -.17181500E+01, 0.31516900E+01, 0.40927600E+01, -.41247900E+00, 0.26323800E+01, 0.39162000E+01, 0.15511100E+02, 0.35914900E+01, -.10497800E+04, 0.39361600E+03, 0.10765600E+03, 0.16695200E+03, 0.14158300E+03, -.36634300E+03, -.11284700E+03, 0.12367200E+03, 0.75882700E+03, -.22863800E+03, -.73947200E+02, -.10804200E+03, -.91461300E+02, 0.28529600E+03, 0.98655000E+02, -.64522300E+02, 0.38779400E+02, -.62061300E+02, -.90150300E+01, -.19450600E+02, -.10454800E+01, -.74309900E+00, 0.22636800E+01, -.19813300E+02, 0.28096700E+03, -.43943400E+02, -.38704100E+02, -.43105500E+02, -.62876300E+02, 0.89179200E+02, 0.24902600E+02, -.57069400E+02, 0.16435000E+01, 0.25448400E+01, 0.27043600E+02, -.89173500E+01, 0.53436100E+02, 0.37970700E+02, 0.88708700E+02, 0.26867600E+02, -.53253700E+02, 0.50411400E+01, 0.29187200E+02, 0.61234400E+02, -.13798200E+03, -.85087800E+02, -.13311700E+03, 0.16181100E+02, 0.24736500E+02, -.13327100E+02, -.37593800E+02, -.24089700E+02, -.22040300E+01, -.20168400E+02, -.71149000E+02, -.29963500E+02, -.59386300E+01, -.11925000E+00, 0.47527000E+01, 0.45114600E+01, 0.24975000E+01, 0.29362400E+02, 0.29605500E+02, -.24252400E+02, 0.95847800E+01, -.34781700E+02, 0.24563500E+02, 0.25216900E+01, -.35073700E+01, 0.35539200E+02, 0.23779900E+02, -.54035500E+01, -.15808800E+02, 0.60341800E+01, 0.23278000E+02, 0.79483900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.24895700E+01, -.12871500E+01, -.29177100E+00, 0.51309700E+01, -.24357800E+01, -.51126400E+00, 0.62186100E+00, -.41250500E+00, -.18371400E+01, -.14134300E+01, 0.12963400E+01, -.16733000E+01, -.24639300E+01, 0.16925000E+01, -.44313800E+00, 0.56816000E+00, -.40632600E+01, 0.25232800E+01, 0.16635200E+01, 0.22760300E+01, -.22407500E+01, -.60604200E+00, 0.17663600E+01, 0.10448100E+00, 0.54304200E+00, 0.55530100E+00, -.30148800E+01, -.73405000E-01, -.10193100E+01, -.28824300E+01, 0.71842300E+01, 0.24850900E+01, 0.10941100E+01, 0.18791400E+01, 0.25092500E+01, 0.21802400E+01, 0.50968700E+01, 0.81271400E+03, 0.19206000E+04, 0.49075500E+03, -.46992000E+04, 0.19653000E+04, 0.65421400E+03, 0.95969900E+03, 0.26907800E+03, -.21223800E+04, -.15528600E+04, 0.70591100E+03, -.57197300E+02, -.74941300E+03, -.10137800E+03, 0.14411500E+03, -.19999500E+03, -.24631500E+03, -.58187000E+03, 0.50823800E+02, 0.45216600E+03, 0.10966900E+04, -.34852700E+03, -.33955200E+03, 0.60832000E+03, 0.72742800E+03, 0.12561400E+04, -.13844600E+03, -.51477100E+02, -.52998600E+03, 0.44808200E+03, 0.13708000E+03, -.10619000E+03, -.31254600E+02, 0.84722000E+03, 0.25756800E+03, -.69256700E+03, 0.10830600E+04, 0.33538000E+03, 0.60049400E+03, -.27898700E+03, -.93664300E+03, -.23376700E+04, 0.14042700E+03, 0.95614800E+02, -.27774600E+01, 0.49165100E+01, 0.79710900E+02, -.55875300E+02, -.61193600E+01, -.10355500E+03, 0.67529900E+02, 0.97704800E+02, -.10549300E+03, -.56571100E+01, 0.73944900E+02, -.38669700E+02, 0.12792600E+01, -.13586400E+03, 0.60430300E+02, 0.28761300E+04, -.44916300E+03, -.37192400E+03, -.10209500E+04, -.23263600E+03, 0.16419300E+04, 0.11660600E+04, -.81764600E+03, -.29853900E+04, -.37030800E+03, -.24551100E+02, 0.38841000E+03, 0.50237100E+03, -.15397700E+04, -.64752400E+03, 0.17440000E+03, -.18889900E+03, 0.75559400E+03, 0.78473500E+02, 0.23549600E+03, 0.46025400E+02, 0.64694600E+02, -.80163200E+02, 0.21167300E+03, 0.20166000E+04, 0.55403600E+03, -.33207900E+03, -.77611500E+03, 0.10373300E+03, 0.10600300E+04, 0.11029700E+04, -.65469800E+03, -.27322900E+01, 0.34214400E+02, -.35779500E+03, -.15241500E+03, 0.24478800E+03, 0.33877200E+02, -.82827700E+03, -.22799900E+03, 0.76671000E+03, 0.37214000E+03, -.21221500E+03, -.44713100E+03, 0.69012600E+03, 0.86752700E+03, 0.18576600E+04, -.16094100E+03, -.47000300E+03, 0.10818600E+02, 0.30330400E+03, 0.23572800E+03, -.23154100E+03, -.32754500E+03, -.10528600E+03, 0.26704300E+03, 0.77055800E+02, -.51830000E+02, 0.59072500E+02, -.21288800E+02, 0.25562700E+02, -.10493900E+04, -.31119500E+03, 0.52476000E+02, 0.20898500E+02, -.78519500E+02, -.10558200E+04, -.34600400E+02, 0.10747200E+02, -.22331500E+03, -.24190100E+03, 0.57904100E+02, -.21707500E+03, -.17804900E+02, -.27772900E+03, 0.24057600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.22007900E+01, -.11819200E+01, 0.68133400E+00, 0.25837400E+01, -.21309800E+01, -.18100600E+01, -.28190500E+00, 0.16618900E+00, 0.58109700E+00, 0.30507000E+00, 0.23945200E+01, 0.52433800E+00, -.27220800E+01, 0.19183500E+01, 0.43062500E+00, -.12300400E+01, -.10220300E+01, 0.18903500E+01, 0.57955700E+01, 0.85024500E+00, 0.52386900E+01, -.15687100E+01, -.18219800E+01, -.19689800E+01, 0.31563100E-01, 0.18034400E+01, -.68166500E+01, -.19412700E+00, -.40883200E-01, -.24711900E+01, 0.22603600E+01, -.10958400E+01, 0.74165900E+00, 0.11262700E+00, 0.15709100E+01, 0.63009300E+00, -.35098300E+01, 0.24417300E+00, 0.85915800E+03, 0.38868500E+03, 0.95340000E+04, 0.20018200E+04, -.12860900E+04, -.23008300E+04, -.72793000E+03, 0.36837800E+04, -.58780200E+02, -.22233600E+04, -.44333500E+03, 0.97010600E+03, 0.17225900E+03, -.15708300E+03, 0.22932600E+03, 0.32656300E+03, 0.11026500E+04, -.14653400E+03, -.19878800E+04, -.13142600E+03, 0.20872700E+03, 0.52069600E+03, 0.42332000E+03, -.10287900E+04, -.63714100E+03, 0.54379100E+03, 0.13142400E+04, -.18563100E+03, -.97285000E+03, 0.23853800E+03, -.10351500E+04, 0.41241400E+01, -.15397400E+04, 0.28969100E+02, -.24110100E+04, -.29345100E+04, 0.33706800E+03, 0.59310300E+03, 0.17875100E+03, -.13909700E+04, -.14126800E+04, 0.24483100E+03, 0.32894700E+03, -.18697000E+02, -.97515900E+01, 0.79711000E+02, -.20178400E+03, 0.93647600E+02, -.79313300E+02, 0.72430900E+02, 0.36789800E+03, -.27124700E+02, 0.36621900E+02, 0.43875100E+02, -.12016000E+03, 0.12192900E+03, 0.42553600E+02, 0.67826000E+02, -.99121400E+04, -.10058900E+04, 0.11911400E+04, 0.13254400E+04, 0.17321700E+04, -.32594900E+04, -.26729000E+02, 0.12432400E+04, 0.58716700E+04, 0.17783800E+04, -.83924000E+03, -.98381800E+03, -.90602300E+03, 0.21914900E+04, 0.12031600E+04, -.82735000E+03, -.95857500E+02, -.20128000E+04, 0.12567800E+03, -.30401100E+01, 0.71092000E+02, -.18466000E+03, -.40437900E+03, -.37528800E+02, 0.16089800E+03, 0.86423000E+03, -.98552800E+03, -.20676500E+03, -.57291200E+02, -.15120900E+03, -.11495500E+04, -.45236200E+03, 0.21895600E+03, -.40248600E+03, 0.95484600E+03, -.48777800E+02, 0.30117800E+03, 0.44971300E+03, 0.14400900E+04, 0.28811800E+03, -.44064600E+04, -.14995300E+04, 0.65221300E+03, 0.13022100E+04, 0.26010800E+03, -.19747800E+04, -.12052900E+04, 0.11981100E+04, 0.73974200E+03, 0.41784900E+03, -.72606100E+03, -.12516400E+02, -.28888500E+03, -.32714500E+02, -.81135100E+03, 0.29534700E+02, 0.13095200E+03, -.46090400E+02, 0.16978900E+03, 0.24543300E+02, 0.51310700E+02, -.40787000E+03, 0.13177400E+03, 0.13669500E+02, -.25524500E+03, -.31668700E+03, -.36936700E+03, -.28593400E+02, -.33441100E+02, 0.78504000E+02, 0.65863800E+02, -.88266500E+02, 0.12210600E+03, 0.80299300E+02, 0.15194100E+03, 0.30754900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10910600E+01, 0.27829800E-01, 0.28240000E+01, 0.99354500E+01, 0.57657300E-01, 0.10188900E+00, -.31376900E+00, -.11516600E+01, -.10082100E+01, 0.12912700E+00, 0.48484700E+00, 0.55638800E+00, -.17824300E+01, 0.27150800E+01, -.95488800E+00, 0.13254400E+01, -.70345200E+00, 0.55275900E+00, 0.21122200E+01, 0.11293800E+01, 0.19012300E+00, 0.40486100E+00, -.83709400E+00, -.29310000E+00, -.38537500E+00, -.10538100E+01, -.64162900E+00, 0.62391600E-01, 0.54048100E-02, 0.45118800E+00, 0.33033300E+01, -.11013700E+00, 0.22725000E+00, -.74045200E+00, 0.38192200E+00, 0.31933400E+00, 0.29119300E-01, -.25525100E+00, -.40535900E+00, 0.36688000E+03, 0.37861000E+04, 0.11096800E+04, -.72528200E+03, -.11840600E+04, -.15518800E+03, 0.16053600E+04, 0.34627900E+03, -.12335400E+04, -.17361100E+03, 0.60667600E+02, -.20618000E+02, -.41861900E+02, -.43601000E+02, 0.86139800E+02, 0.30032300E+03, -.71806400E+02, -.15814100E+04, 0.35128700E+03, 0.20230300E+03, 0.32288000E+03, 0.52878600E+03, -.70163800E+03, -.24546400E+03, 0.37347200E+03, 0.43203700E+03, -.25050100E+03, -.19140700E+03, 0.27528500E+03, -.53324800E+03, -.10505300E+03, -.48189400E+03, 0.21124000E+03, -.57454100E+03, -.16272700E+04, 0.12112600E+03, 0.32181900E+03, -.51374500E+02, -.35796700E+03, -.41860000E+03, -.12249400E+02, 0.18806100E+03, -.15274700E+02, 0.59468500E+01, 0.87158400E+02, -.12970000E+03, 0.50019900E+02, -.72797200E+02, 0.81736700E+02, 0.20025000E+03, -.51758600E+02, 0.27314200E+02, 0.63283500E+02, -.78473700E+02, 0.67672600E+02, -.11611100E+02, 0.72352000E+02, -.31042500E+04, -.51337500E+03, 0.29712400E+03, 0.86575800E+02, 0.76163700E+03, -.84389100E+03, -.54857100E+02, 0.15722300E+03, 0.83616700E+03, 0.10154600E+04, -.26873800E+03, -.11565700E+03, -.25466300E+03, 0.24213200E+03, 0.64928000E+03, -.13994300E+03, -.59528700E+02, -.77994000E+03, 0.75295600E+02, 0.46981800E+02, 0.11022200E+03, -.13752300E+02, -.17740300E+03, 0.21337200E+02, 0.21015900E+03, 0.70991500E+03, -.55768500E+03, -.29682100E+03, 0.11006400E+03, -.43573600E+02, -.61205300E+03, -.41230900E+03, 0.94824900E+02, -.17155200E+03, 0.35579800E+03, -.60133500E+02, 0.15922500E+03, 0.29896000E+03, 0.58269900E+03, 0.90195000E+02, -.33721200E+04, -.24758000E+03, 0.72127700E+03, 0.89734700E+03, 0.53655200E+03, -.13684000E+04, -.19892800E+03, 0.93156800E+03, 0.19519100E+03, 0.28580200E+03, -.28905900E+03, 0.93896300E+02, -.24336100E+03, -.17268600E+03, -.70117000E+03, 0.10955600E+03, 0.84818000E+02, -.45531500E+02, 0.10236700E+03, 0.12935000E+01, 0.44521900E+02, -.84533400E+01, 0.80935100E+02, 0.48336100E+02, -.19663400E+03, -.17454300E+03, -.12637800E+03, -.26099400E+02, -.18032000E+02, 0.24691800E+02, -.49080000E+02, -.41829200E+02, 0.62537800E+02, 0.61368300E+02, -.27685500E+02, -.75710900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23667400E+00, 0.12567000E-01, -.24792900E+00, 0.17605700E-01, 0.24558800E+00, 0.50764700E+00, 0.11699700E+00, -.24875900E+00, -.63769100E-01, -.19494600E-01, 0.11691400E+00, -.22214200E+00, 0.54739000E-01, -.37609000E+00, 0.10593400E+00, 0.25249900E+00, 0.69139200E+00, 0.53328000E-01, -.11518600E-02, 0.63760600E-01, -.40924700E+00, 0.14658300E+00, -.17661600E+00, -.22631200E+00, 0.11854500E+00, 0.35012000E+00, -.23120700E+00, -.27182100E-01, -.88716400E-01, -.77964300E-01, -.76741400E-01, 0.16586700E+00, 0.26926300E+00, -.96244200E-02, 0.52191400E+00, 0.19620000E-01, -.76466700E+00, -.94394500E-01, 0.18165500E-01, 0.11843800E+00, -.80383300E+03, 0.12260600E+03, 0.16780100E+03, 0.23246400E+03, -.97629800E+01, -.34506000E+03, -.11096300E+03, 0.22439800E+03, -.89206200E+02, -.52061400E+02, -.29524700E+02, -.11572200E+02, 0.30530700E+02, -.11794200E+01, 0.28927600E+02, -.95839600E+01, 0.47401500E+03, -.15152900E+01, -.23007100E+03, -.20845100E+03, 0.14429800E+03, 0.20705900E+03, 0.13017400E+03, -.20904700E+03, -.12698000E+03, -.13794100E+03, 0.76572600E+02, -.24199000E+01, 0.31571600E+02, -.66747600E+02, 0.13072000E+03, -.51974100E+01, 0.64570900E+02, 0.18491000E+03, 0.80800300E+01, 0.24753000E+02, -.49179100E+02, -.40106400E+02, -.33074200E+02, 0.34451300E+02, -.17152400E+02, 0.14955800E+02, 0.27307900E+01, -.63830500E+00, 0.95902300E+01, -.54028800E+01, 0.21913700E+01, -.83775000E+00, -.89719700E+01, -.86893900E+01, -.30317600E+01, -.14040600E+01, 0.97744900E+01, -.43180200E+01, -.11793100E+02, -.16018700E+01, 0.35090700E+03, 0.20564000E+03, -.29471800E+02, -.77094000E+02, -.66466600E+02, 0.20566500E+03, 0.12591700E+03, -.72706700E+02, -.25214600E+03, -.35529300E+03, -.15218300E+02, 0.23669900E+02, 0.60475200E+02, -.15662200E+03, -.12057300E+03, 0.11089400E+02, -.60598100E+01, 0.17037400E+03, -.11544700E+02, 0.10008100E+02, 0.78983200E+01, 0.12999000E+02, 0.23734200E+02, 0.10780100E+02, 0.57722900E+03, 0.11601400E+02, -.97336400E+02, -.17677900E+03, 0.77366500E+01, 0.22313800E+03, 0.14712700E+03, -.17160700E+03, -.98653600E+01, 0.47324800E+02, -.84803300E+02, -.34398100E+02, 0.74044100E+02, 0.16107900E+02, -.13599200E+03, -.32152000E+02, 0.29455800E+03, 0.37337700E+02, -.14206800E+03, -.14765400E+03, 0.13520700E+03, 0.14873100E+03, 0.10693100E+03, -.14456900E+03, -.74158500E+02, -.62871300E+02, 0.52029300E+02, 0.50763600E+01, -.16527000E+02, -.46989400E+02, 0.26818500E+02, -.25841600E+00, -.30509700E+00, 0.26969600E+01, -.26068100E+01, -.36629600E+01, -.25748100E+01, -.31774800E+02, -.19418100E+02, -.11277900E+01, -.74081200E+01, -.86623400E+01, -.36759900E+02, -.14151900E+01, 0.25131000E+01, -.26328500E+02, -.23677900E+02, 0.12218300E+02, -.44923200E+02, -.73167200E+01, 0.18015100E+02, 0.63805900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13067100E+01, 0.18185100E-02, 0.26239100E+01, 0.44879500E+01, -.10229500E+01, -.13826100E+01, -.11151900E+00, 0.20168100E+00, 0.15764300E+00, -.53753700E-01, 0.41440000E+00, -.45659400E+00, -.17606900E+01, 0.18127500E+01, -.46762400E+00, 0.10879000E+01, -.25866200E+01, 0.15293200E+01, -.12345700E+01, 0.85093100E+00, 0.42734100E-01, -.91713300E+00, -.51758300E-01, -.44682800E+00, -.41363000E+00, -.11743000E+01, 0.61364000E+00, -.20801100E-01, 0.29275400E-01, 0.16178200E+01, -.14028600E+01, -.69447500E+00, 0.69971500E-01, -.52401600E+00, 0.46174500E+00, -.57855900E+00, -.20741900E+00, 0.19817900E+00, -.21751600E+00, 0.10028400E+00, -.30361600E+01, 0.18462700E+04, 0.61090400E+02, -.14852600E+03, -.12741000E+03, -.55490900E+01, 0.20297300E+03, -.55172800E+02, -.22828100E+03, 0.87445900E+03, 0.37755600E+02, -.11874200E+03, 0.13749300E+03, 0.23989300E+03, 0.34567300E+03, -.79709300E+02, 0.22738400E+04, -.19005700E+04, -.11419300E+04, -.11585800E+04, 0.10258200E+04, 0.81861800E+03, 0.19390500E+03, -.12631000E+04, 0.11479100E+04, -.59736300E+03, -.59111000E+03, -.20336700E+03, -.13999000E+03, 0.21715900E+03, -.46591800E+03, -.29224500E+03, -.15933200E+04, -.70965400E+03, 0.61231800E+03, 0.82099100E+03, -.42521200E+03, -.11720300E+04, -.67732600E+03, 0.83868300E+03, 0.20906500E+03, -.13974700E+02, 0.42899700E+00, 0.18503300E+02, -.44865300E+02, 0.42981900E+02, -.93163000E+02, 0.20013800E+02, 0.16773800E+03, -.25318000E+02, 0.45258600E+01, 0.49713900E+01, -.21973500E+01, 0.25102100E+02, -.47732900E+02, 0.17240000E+02, -.16987600E+04, -.50890600E+03, 0.38896400E+03, 0.22752700E+03, -.18197400E+03, -.21291200E+03, 0.16692300E+03, 0.24987700E+03, 0.35448900E+03, 0.80890200E+03, -.20148000E+03, -.48914700E+02, 0.34217300E+03, -.13226700E+03, 0.31678200E+02, -.39625600E+02, -.44549500E+03, -.43805000E+03, 0.13592800E+03, 0.79430100E+02, 0.76621900E+02, -.13226900E+03, 0.18620200E+03, 0.10411700E+03, 0.13620900E+04, -.14978100E+03, -.89277000E+03, -.72913500E+03, 0.23973000E+03, 0.56116300E+03, -.11865700E+03, -.90070100E+03, 0.84731700E+02, -.50907900E+02, 0.18696900E+03, -.14258900E+03, 0.29103200E+03, 0.10419600E+03, 0.14009600E+03, -.11507200E+02, -.71292400E+02, -.20423900E+04, -.73096700E+03, -.59967500E+03, 0.12474600E+04, 0.14408700E+03, 0.39254900E+02, -.73211200E+03, 0.19517300E+03, 0.15783900E+03, -.21810800E+03, 0.26720800E+02, -.16879400E+03, -.78122600E+02, -.40703100E+03, 0.40700800E+02, 0.98162100E+02, 0.11441200E+02, 0.41071200E+02, -.55757200E+02, 0.39844700E+01, -.33661200E+02, 0.64665700E+02, -.75333900E+02, -.19169700E+03, -.87717700E+02, -.62901800E+01, -.32078100E+02, -.95201400E+00, 0.95530300E+01, 0.28036700E+01, -.83306500E+02, -.52318400E+02, -.11937200E+02, 0.26185600E+03, -.21974000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12163700E+01, -.50550200E-01, -.15917600E+00, -.48165500E+01, 0.66791000E+00, 0.26461900E+00, 0.14891600E+00, 0.86242100E+00, 0.41607500E+00, -.46989400E-01, 0.90455600E+00, 0.20262600E+00, -.79765500E+00, 0.47013300E+00, 0.29495500E+00, 0.20745900E+00, -.75176300E+00, 0.26795700E+00, -.17338600E+01, 0.95491600E+00, 0.53017400E+00, 0.58067600E-01, -.22554700E+00, -.39725600E+00, -.53520500E+00, -.28804300E+01, 0.86865900E+00, 0.12858900E+00, 0.45548500E+00, 0.13788600E+01, 0.52331200E+00, 0.26895400E+00, 0.20677000E+01, -.10409400E+01, 0.12453200E+01, -.43132500E+00, 0.15509900E+01, -.21081600E+00, 0.17832500E-01, 0.23109500E+00, 0.14872500E+01, 0.30977900E+00, 0.28669100E+03, 0.37080700E+03, -.36050700E+03, 0.12973400E+02, 0.15363600E+03, 0.39444600E+03, 0.46266900E+03, -.52804700E+03, 0.12412700E+03, 0.19643500E+03, -.30751000E+03, -.32587700E+03, -.73490200E+03, 0.13158200E+03, -.87872000E+03, -.19853700E+03, 0.13097900E+03, 0.22961300E+03, -.30687500E+03, -.22564300E+03, -.68856800E+03, 0.22092400E+03, -.30998400E+02, -.34206000E+02, 0.68320800E+02, -.78860000E+02, 0.29958300E+03, 0.10554900E+03, 0.38559900E+02, 0.72312400E+02, -.75136500E+03, 0.82336500E+03, 0.89600700E+01, -.59223000E+02, 0.31654100E+03, 0.30236600E+03, 0.43912300E+03, -.14320900E+03, 0.10996100E+02, -.40177900E+02, -.48922000E+02, -.37098100E+02, 0.35898600E+02, -.31968400E+02, -.42892300E+02, -.42510100E+02, -.34941900E+01, -.15073400E+02, -.37685700E+02, -.21851900E+02, -.23400300E+01, -.20473800E+02, -.37020000E+02, -.43384800E+02, 0.20435400E+04, -.17305700E+03, -.29330500E+03, -.29207200E+03, -.20086700E+03, 0.57245300E+03, 0.28541700E+03, -.23755500E+03, -.89126800E+03, 0.21996800E+03, 0.16545400E+03, 0.84784600E+02, 0.10762800E+03, -.21797500E+03, -.45950300E+03, 0.17392000E+02, 0.17288100E+03, 0.19346900E+02, -.26415900E+02, 0.37358300E+01, -.68218900E+02, 0.11121000E+03, 0.37928000E+02, -.14894400E+02, -.18715000E+04, -.33923900E+03, 0.43141300E+03, 0.51704600E+03, 0.59378400E+02, -.70091600E+03, -.30995600E+03, 0.57702200E+03, 0.95597200E+01, 0.30097100E+02, -.11519300E+03, 0.24385900E+02, -.26665200E+03, -.12119900E+03, -.17317700E+03, -.20013200E+03, -.25642600E+03, -.37270600E+03, -.54562000E+02, -.84532600E+01, -.14248500E+03, -.14001300E+03, -.33447300E+03, 0.79094000E+02, 0.86889000E+02, 0.25746500E+03, 0.14137900E+03, 0.71009300E+02, -.83185800E+01, 0.65374800E+02, 0.11700900E+03, 0.93378800E+02, 0.71311100E+01, 0.30556200E+01, -.56026500E+02, -.38128600E+02, -.22999400E+02, 0.99593800E+02, 0.65698300E+02, 0.16394700E+01, -.64499200E+01, 0.84070300E+02, 0.10513500E+03, -.36223200E+01, 0.19258000E+02, -.98184200E+02, -.70908100E+01, 0.32654400E+02, 0.11235000E+03, -.13045100E+02, 0.86406400E+02, -.65659400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11585900E+01, 0.18972700E-01, 0.29139900E+01, 0.12243100E+02, 0.94662000E+00, 0.69579800E+00, -.35081100E+00, -.11143500E+01, -.14074700E+01, 0.16290500E+00, -.13994200E+01, 0.15232100E+01, -.25051600E+00, 0.31925500E+00, -.89076000E+00, -.73557900E+00, 0.10590200E+01, -.90307700E-01, 0.68200800E+00, -.45827800E+00, 0.15058400E+01, -.81604900E+00, 0.35287400E+00, 0.54614300E-01, 0.32301700E+00, 0.90659300E+00, -.71836300E+00, -.47630800E-01, 0.61939300E-02, -.13436100E+01, -.36708400E+01, -.11126300E+01, -.13326700E+01, 0.48599800E+00, 0.24414000E-01, 0.81719300E-02, -.16539400E+01, 0.56510400E-01, 0.31335800E+00, -.43626400E+00, 0.87236200E+00, -.22105500E+00, -.83618500E+00, 0.88211500E+02, -.17139900E+03, 0.24162000E+02, 0.15549400E+03, 0.79455700E+02, 0.41436500E+03, -.27177700E+03, 0.91742500E+02, 0.10081300E+03, -.19202100E+03, -.13086600E+03, -.43694200E+03, 0.88595700E+02, -.57290100E+03, -.39913000E+03, 0.98952300E+02, 0.12323400E+03, -.12627100E+03, -.12030300E+03, -.35421100E+03, 0.10403500E+03, 0.14616200E+02, 0.11553600E+03, 0.48495800E+02, -.23486800E+02, 0.13876900E+03, 0.86114300E+02, -.21281100E+02, 0.37023900E+02, -.10967700E+03, 0.14221400E+03, -.22071900E+02, -.63587700E+02, 0.11503600E+03, 0.24116700E+03, 0.19308100E+03, -.96767700E+02, 0.43032600E+01, -.18842200E+02, -.17173900E+02, -.16308400E+02, 0.23563600E+02, -.22013300E+02, -.31808300E+02, -.17044100E+02, -.17008700E+02, 0.94994200E+01, -.14520900E+02, -.72915600E+01, -.33261500E+00, -.20969800E+02, -.25540800E+02, -.18103200E+02, 0.95233400E+03, 0.12729700E+03, -.75719400E+01, -.64266600E+02, -.14465800E+03, 0.25170800E+03, 0.15873500E+03, -.16930900E+02, -.57963900E+03, 0.19031700E+03, 0.46898100E+02, 0.42776000E+02, 0.12514700E+03, -.13256400E+03, -.24352900E+03, 0.13813000E+02, 0.34833600E+02, 0.38998700E+02, -.11396700E+02, 0.14389900E+02, -.45672300E+02, 0.25735500E+02, 0.18554800E+02, -.20943700E+01, -.10476700E+04, -.38378700E+03, 0.23358200E+03, 0.26197100E+03, 0.92224000E+02, -.35305300E+03, -.21922800E+03, 0.28125700E+03, -.79515900E+02, 0.49276200E+02, -.36917800E+02, 0.51543500E+02, -.19199400E+03, -.14790100E+03, -.13245100E+03, -.66637800E+02, -.73853100E+03, -.16306200E+03, 0.82255100E+02, 0.91789300E+02, 0.34297500E+02, -.22489600E+03, -.74500200E+02, 0.10788400E+03, 0.52628400E+02, 0.11572300E+03, 0.85681200E+02, 0.51923500E+02, 0.55926100E+01, 0.60516400E+02, 0.70952300E+02, 0.69010000E+02, -.23652100E+01, -.10751500E+01, -.27378400E+02, -.27844800E+02, -.10907600E+02, 0.57345800E+02, 0.24670600E+02, -.22781300E+02, -.12239300E+02, 0.50869100E+02, 0.63779700E+02, 0.17804000E+01, 0.10015100E+02, -.71263000E+02, -.12806700E+01, 0.14182700E+02, 0.89862700E+02, -.14758500E+02, 0.45310900E+02, -.32837800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.51785300E-02, 0.49491200E-01, -.39322200E+00, 0.22723400E+01, 0.17958800E+00, 0.22503900E-01, 0.33662800E+00, -.13164800E+00, -.20285800E+00, -.28378600E-01, 0.38207400E-01, -.29641200E+00, -.23923500E-01, 0.19729400E+00, 0.41713300E-01, 0.13843500E+00, 0.21600100E+00, -.79068100E-01, 0.21075000E+00, 0.19138100E+00, 0.24442500E+00, 0.11567000E+00, -.17217000E-01, 0.42120000E-01, -.35251700E-01, -.15415800E+00, -.30790400E+00, 0.31939700E-02, -.32405100E-01, -.52440500E-01, 0.92524200E-01, 0.22227300E+00, -.19634600E+00, 0.12175800E+00, 0.13843300E+00, 0.10960100E+00, -.20888300E+00, -.26118500E-01, -.43491000E-01, 0.10634400E+00, 0.75521000E-01, -.27795000E-01, 0.21048700E-02, 0.23534200E-01, 0.18164300E+02, -.25302800E+01, -.17744600E+02, 0.18446400E+00, -.12327800E+02, 0.24714900E+02, -.16593200E+02, -.70456100E+01, 0.16588400E+02, 0.23578100E+02, 0.27559600E+02, -.22564200E+01, 0.81829800E+02, 0.97214200E+02, 0.13864800E+02, 0.27839600E+01, -.41408800E+02, -.29299800E+01, 0.38327000E+02, 0.44399300E+00, 0.67991300E+02, -.83723100E+01, -.34045800E+02, -.39744600E+02, 0.30362900E+01, 0.21504200E+02, 0.90333600E+01, -.46501400E+02, -.64515500E+01, 0.19905500E+02, 0.33149900E+01, -.70413900E+00, -.12374900E+00, -.25697800E+02, -.98000900E+01, 0.55968300E+01, -.14850100E+02, 0.52109200E+01, 0.25255300E+01, 0.75780100E+00, 0.36964900E+00, 0.19193300E+01, 0.11993000E+02, 0.11404700E+01, -.12203100E+02, 0.36669200E+01, 0.27400100E+01, 0.96118300E+00, 0.93839700E+00, 0.92193200E-01, 0.70609500E+01, 0.19672000E+01, -.21980800E+03, -.28602500E+02, 0.26146800E+02, 0.34353600E+02, 0.38389400E+02, -.53862700E+02, 0.25332200E+02, 0.28781400E+02, 0.16163600E+03, -.48793100E+02, -.25329100E+02, -.20333800E+02, -.31767300E+02, 0.34865100E+02, -.11188500E+02, -.15692200E+02, -.22624600E+02, 0.10895100E+02, 0.13003300E+02, 0.48605200E+00, 0.79625200E+01, -.12073500E+02, -.42624400E+00, 0.43776400E+01, 0.85281300E+02, 0.10011500E+03, 0.69420000E+01, 0.10906000E+02, -.65234700E+02, 0.10923900E+02, 0.36756400E+01, 0.79828200E+01, 0.39506000E+01, -.16233800E+02, 0.14592800E+01, 0.27402300E+01, 0.19275400E+02, 0.20457400E+02, 0.28539600E+02, 0.14599700E+02, 0.24949000E+03, 0.22425600E+02, -.28577000E+02, -.49149700E+02, -.41497100E+02, 0.71640100E+02, 0.16675100E+02, -.57162600E+02, 0.55086000E+01, -.31602600E+02, -.16845600E+02, -.19873400E+02, 0.11039700E+02, 0.96872200E+01, 0.17892600E+02, -.17063600E+02, -.69057800E+01, 0.11198600E+01, 0.12391500E+01, 0.64011200E+01, 0.12624700E+01, -.64321700E+01, -.91280600E+00, 0.17758300E+01, 0.12939600E+02, -.40372500E+01, -.67952800E+01, 0.19764300E+01, -.14545200E+01, -.10211200E+01, -.27261800E+01, -.63013900E+01, -.18157700E+02, 0.23709200E+01, -.37954700E+01, 0.58699900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.50537900E+00, -.99655400E-01, -.10508400E+00, -.18325400E+01, 0.82071100E+00, -.30369100E+00, 0.18187500E+00, -.32671400E+00, -.14441300E+00, -.26035200E+00, -.21211800E+00, -.79464900E+00, 0.10795200E+01, -.68894500E+00, 0.17275700E+00, -.40753500E+00, 0.81823600E-01, 0.14741300E+00, -.19951900E+00, -.10730100E+01, 0.83889300E+00, -.80983800E+00, -.47368800E-01, 0.13668100E+00, 0.12157500E+00, -.14254200E+00, 0.93525000E+00, 0.27949300E-01, -.25098700E+00, -.41969900E+00, -.97328800E+00, 0.58847300E+00, 0.31033100E+00, 0.26367300E+00, 0.76182800E+00, 0.28909200E-01, 0.74885400E-01, -.12445200E+00, 0.46639500E-02, -.69292300E-01, 0.14884600E+01, -.94975600E-01, -.21434200E+00, 0.19024700E+00, -.66787400E+00, 0.25827800E+02, 0.38209400E+02, 0.12736300E+02, 0.21525700E+03, -.31084500E+03, -.26128300E+02, 0.15456200E+02, -.11730800E+03, 0.33291800E+01, -.15261700E+03, 0.37333400E+01, 0.16546200E+03, -.68236300E+02, -.39125400E+02, -.53598300E+02, -.15296500E+03, 0.11214700E+02, -.80652500E+02, -.86952400E+02, 0.14400600E+03, -.38351700E+02, -.51590300E+02, -.86894000E+02, 0.19581800E+03, 0.56341200E+02, -.48573200E+02, -.32073000E+02, -.11740700E+03, 0.21987500E+03, 0.37587300E+02, 0.30307300E+02, -.11995700E+02, 0.70706400E+02, 0.31937800E+02, -.36506700E+01, 0.18431200E+02, -.37782300E+02, -.13313600E+02, -.79075300E+01, 0.49403500E+01, 0.74288100E+01, -.27027800E+01, -.75015700E+01, 0.97565400E+01, -.23298100E+02, -.59727100E+01, -.27684500E+01, -.20618100E+01, 0.30136300E+01, -.25809400E+01, -.82863600E+01, 0.53076500E+03, -.23055900E+03, -.39662400E+02, -.54172200E+02, -.13997400E+03, 0.17653500E+03, 0.25819400E+02, -.28028700E+02, -.46964600E+03, 0.20278200E+03, 0.72448000E+02, 0.83136400E+02, 0.66317400E+02, -.17605900E+03, -.40353100E+02, 0.60603600E+02, -.65873800E+00, -.22102000E+02, 0.17502900E+02, 0.86767800E+00, -.32051200E+01, 0.22480700E+02, 0.11632500E+02, -.79401700E+01, -.33704900E+03, -.13385200E+03, 0.96061300E+02, 0.13384000E+03, -.12214300E+03, -.16112100E+03, -.42116400E+02, 0.14946700E+03, 0.71102300E+02, -.65407800E+02, -.35383800E+02, -.17367300E+02, -.52364700E+02, 0.22652800E+02, 0.24997900E+02, -.74570500E+02, -.31564000E+02, 0.60063000E+02, -.26537600E+02, -.54289500E+02, 0.62059000E+02, -.58207600E+02, -.12231100E+02, -.45345400E+02, 0.64379000E+02, 0.11945700E+03, 0.54995900E+01, 0.30264600E+00, 0.19473000E+02, 0.25493100E+02, -.16915600E+02, 0.13582300E+02, 0.83269600E+01, 0.52156700E+01, -.10107600E+02, -.17686200E+02, -.42062800E+01, 0.67195500E+01, 0.36444900E+01, 0.57348400E-01, 0.22102100E+02, 0.40313200E+02, 0.76555400E+01, -.65332900E+01, 0.17853300E+01, -.80797900E+01, 0.25433300E+01, -.45266100E+01, -.69324100E+01, 0.33477300E+01, 0.22436500E+02, -.25919400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.70499600E-02, -.39329800E-01, 0.31757300E+00, -.18385500E+01, -.16649000E+00, -.32224600E-02, -.25923300E+00, 0.12661400E+00, 0.20353200E+00, 0.24138000E-01, -.64980100E-01, 0.31575100E+00, 0.33018100E-01, -.86594700E-01, -.24195800E-02, 0.39261100E-01, -.17210500E+00, 0.94481200E-01, 0.55225300E+00, -.71692100E-01, 0.12814800E+00, -.28376700E-01, 0.62257800E-01, 0.73932800E-02, 0.99071500E-02, -.50646100E-01, -.58922200E-02, -.35639700E-02, -.29461200E-01, -.38015200E-01, 0.18698900E+00, 0.47099500E-01, 0.83555500E-01, -.27131400E-01, 0.23070700E-01, 0.46443100E-02, 0.67028200E-01, 0.12947000E-01, -.10792900E-01, -.15803300E-02, -.93137900E-01, 0.12794100E-02, 0.26147800E-01, -.74966600E-01, -.61411700E+00, -.85004600E-01, -.12960000E+02, -.48465600E-01, 0.27962900E+02, -.20168200E+02, -.78366700E+01, -.68581400E+00, -.72835000E+01, 0.11187800E+02, -.69113900E+01, 0.13134100E+01, 0.71383800E+02, 0.11247300E+02, -.13725400E+02, -.18507400E+02, -.22818500E+02, 0.16957900E+02, 0.19572100E+02, -.23727900E+02, 0.37913900E+02, -.11308200E+02, -.19255500E+02, -.23470000E+02, 0.21098900E+02, 0.11607500E+02, -.59433200E+01, -.23680800E+02, -.23542000E+02, 0.22063600E+02, 0.76553700E+01, 0.63884200E+01, -.25255800E+01, -.52898700E+01, -.64079500E+01, 0.64710700E+01, -.46653100E+01, -.76032000E+00, -.17752000E+00, -.26574900E+00, 0.11263700E+01, 0.47432500E+00, 0.35212000E+01, -.76620200E-01, -.44158100E+01, -.31524200E+00, 0.66815200E+00, 0.40232600E+00, 0.17571000E+00, -.39016000E+00, 0.21401200E+01, 0.31129200E+00, -.96258700E+02, 0.33192500E+01, 0.22119500E+02, 0.19320700E+02, 0.13629100E+02, -.17530700E+02, 0.34782200E+02, 0.20810400E+02, 0.51760200E+02, -.17489200E+02, -.14597800E+02, -.86778600E+01, -.10014700E+02, 0.43262500E+01, -.20167200E+02, -.83491900E+01, -.10289100E+02, 0.30511900E+01, 0.74121900E+01, 0.17507800E+01, 0.15146000E+01, -.25884100E+01, -.10892900E+01, 0.25527100E+01, 0.17404100E+02, 0.22341700E+02, 0.70937500E+01, 0.12890700E+02, -.40679800E+02, -.24542200E+01, 0.54123100E+00, 0.10944600E+02, 0.64971900E+01, -.10618500E+02, -.39460600E+01, -.15543500E+01, 0.48192700E+01, 0.77070800E+01, 0.11193900E+02, -.84353100E+00, 0.79501300E+02, 0.90707900E+01, -.21352900E+02, -.29132100E+02, 0.24368900E+01, 0.21072000E+02, 0.14056500E+02, -.33742200E+02, 0.21961600E+01, -.29123100E+00, -.44953900E+01, -.56916500E+01, 0.65332400E+01, 0.27556700E+01, 0.27712800E+01, -.39128800E+01, -.22216600E+01, 0.55484200E+00, 0.39366300E-01, 0.18158400E+00, 0.13025000E+00, -.47555700E+01, -.20935000E+01, -.64914000E+00, 0.67070300E+01, 0.25947500E+00, -.37691800E+01, 0.40288300E+00, -.34655300E+00, -.63534100E+01, -.27480100E+01, -.27777900E+01, -.97038900E+01, 0.69510400E+00, 0.38175300E+01, -.32427600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.27220500E+01, -.14300200E+01, -.27667800E+00, 0.89683400E+00, -.25099000E+01, -.21711200E+00, 0.67591800E+00, 0.68344200E+00, 0.79022800E-01, -.15503300E+01, -.41675100E+00, -.33047400E+01, 0.31169100E+00, -.10803700E+01, -.25235200E+00, 0.15434800E+01, -.27203900E+01, 0.34867200E+01, 0.59545100E+01, 0.13826400E+01, -.21606500E+01, -.18911600E+01, -.29956000E+01, -.98125500E+00, 0.91733700E+00, 0.66309700E+01, 0.31248300E+01, -.66195200E-01, -.14294000E+01, -.15235500E+01, -.21514800E+00, 0.43952700E+00, 0.36147200E+01, -.33996000E-01, 0.27352100E+01, -.33349000E-01, -.52986600E+00, -.50015800E+00, 0.44577000E+00, 0.59483600E+00, 0.86593100E+01, 0.20823900E+00, 0.36428000E-01, 0.90057300E+00, -.27325700E+01, 0.45678200E+01, -.96987900E+01, -.10056600E+03, 0.17858700E+01, 0.76867600E+03, 0.26875100E+03, 0.16135300E+03, 0.15688800E+03, -.15487800E+03, -.39205300E+03, 0.21145500E+03, -.12285900E+04, 0.95159700E+02, 0.79420300E+03, 0.75372900E+03, -.14916500E+03, -.28860600E+03, 0.19700400E+03, 0.86425300E+03, -.48801800E+03, -.32967700E+03, -.72238000E+02, 0.76920300E+02, -.42855500E+03, -.94469900E+02, 0.11400100E+03, -.60638700E+02, 0.17354400E+03, -.56054100E+03, -.12052800E+03, -.21564500E+03, 0.29316000E+03, 0.27168800E+03, 0.11859900E+03, -.14360400E+03, -.87566500E+02, 0.11326400E+03, 0.25440800E+02, 0.10493300E+02, -.30842800E+01, -.26873100E+02, 0.13552700E+02, 0.56724400E+01, -.91830100E+02, 0.93236800E+02, 0.13101000E+02, 0.13185600E+02, -.19524200E+02, -.22502300E+02, 0.29300900E+02, 0.14903700E+02, -.23791700E+04, 0.21702400E+04, 0.18307600E+03, 0.23328300E+03, 0.61527500E+03, -.65753600E+03, 0.48237100E+03, 0.17209400E+03, 0.19783600E+04, -.12857400E+04, -.26720000E+03, -.30693200E+03, -.22841800E+03, 0.52545300E+03, -.50606000E+03, -.25531200E+03, -.26285600E+03, 0.17297000E+02, 0.11381200E+03, 0.82439300E+02, -.16263300E+01, -.89852500E+02, 0.30757000E+02, 0.10451400E+03, -.11781300E+04, 0.94846100E+03, 0.41053700E+03, 0.47050500E+03, -.46859600E+01, -.45693600E+03, -.47284200E+03, 0.42537600E+03, -.17457900E+03, 0.17522400E+03, 0.81524300E+02, 0.11380000E+03, -.63586100E+02, -.57975600E+02, 0.11383000E+03, 0.15724700E+03, 0.18916300E+04, -.16800800E+04, -.80193200E+02, -.12612700E+03, -.75967800E+03, 0.82961600E+03, 0.48703800E+03, -.15069300E+03, -.41192700E+02, -.19789300E+03, -.85819400E+02, -.44880400E+02, 0.60456400E+01, 0.46195300E+02, 0.18715300E+02, -.10816500E+03, -.49307900E+02, -.13004300E+02, -.69516400E+01, 0.67755000E+02, 0.10563000E+02, 0.26283300E+02, 0.34391900E+01, -.52166100E+02, 0.90071000E+02, -.13181400E+03, 0.55222900E+02, 0.28398700E+02, -.21551100E+01, -.87622000E+02, -.42875000E+02, -.51423300E+02, 0.85320800E+02, 0.24112400E+02, -.21242300E+03, 0.25391100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14976800E+01, -.72517700E+00, -.87805100E+00, -.35676800E+01, -.60244400E+00, -.97712200E+00, 0.52208300E+00, 0.31905800E+00, -.17086200E+01, -.16082900E+01, 0.49297300E-01, 0.90360400E-02, 0.27834100E-01, -.29329100E-01, 0.19856800E+00, 0.10270200E+00, 0.63123500E+00, 0.16561400E+01, 0.12289700E+01, -.13566300E+00, 0.20031500E+01, -.15244800E+01, 0.15421100E+01, 0.75208700E+00, 0.26534700E+00, -.26054600E+01, 0.22855200E+01, 0.24872100E+00, 0.51308200E+00, 0.14515300E+01, -.30053700E+01, 0.10209700E+01, -.58615500E+00, 0.61878000E+00, 0.75075900E+00, -.15342100E+00, -.10197000E+01, -.90568200E-01, 0.21052500E+00, -.47584100E+00, 0.88805500E+00, -.15022500E+00, -.57585100E+00, 0.83333200E+00, 0.38376300E+01, 0.12607200E+01, -.44824100E+00, 0.16148600E+00, -.60555300E+03, 0.19539500E+04, -.97556300E+02, 0.34887700E+02, 0.77983200E+02, -.24761800E+03, 0.24676500E+03, -.22970300E+02, -.51978200E+03, -.67941900E+03, -.89063800E+02, -.16906600E+03, 0.68285400E+03, 0.14229700E+03, 0.36069000E+02, -.64609000E+02, -.52733200E+03, 0.76512300E+02, 0.44925800E+03, 0.44685200E+03, -.46404000E+03, -.26047500E+03, -.10858300E+03, 0.41595200E+03, -.91923600E+03, -.51622500E+02, 0.11342400E+03, 0.17802800E+03, 0.12489600E+03, -.31552500E+03, 0.13206700E+02, 0.18417300E+03, 0.98664800E+01, 0.10223100E+03, 0.77093200E+01, 0.43031500E+02, -.23175400E+02, -.36731000E+02, -.59028700E+02, 0.39492400E+02, 0.11880900E+02, 0.69607800E+02, 0.14151500E+02, 0.28879300E+02, 0.53961000E+01, -.75909800E+01, -.27411100E+02, 0.39877800E+02, 0.14249100E+04, -.81173600E+03, -.43246000E+03, -.39038000E+03, -.66194000E+01, 0.17541900E+03, -.47361400E+03, -.40822000E+03, -.54764900E+03, 0.12327500E+04, 0.25282700E+03, 0.24461500E+03, -.14025000E+03, 0.89730100E+02, 0.26428000E+03, 0.23763700E+03, 0.76103900E+02, -.83462400E+02, -.35153800E+02, 0.16491700E+02, 0.11054700E+02, 0.69142900E+02, 0.89360500E+01, 0.46206900E+02, 0.45869400E+03, -.37636300E+03, -.43777400E+03, -.54357500E+03, 0.62712900E+03, 0.31333600E+03, 0.18870400E+03, -.56963900E+03, -.10308000E+03, 0.21115200E+03, 0.31072700E+02, 0.15939800E+02, 0.11147300E+03, -.72618400E+02, -.12234500E+02, 0.10254700E+03, -.87644800E+03, -.11486300E+04, 0.29693500E+03, 0.21854100E+03, 0.17852600E+03, -.22336900E+03, -.18733200E+03, 0.31882800E+03, -.12391500E+02, -.68838100E+02, 0.19438400E+02, 0.62004000E+02, -.16350800E+03, -.94423800E+02, -.22284000E+03, 0.11740100E+02, 0.54318900E+01, -.33676900E+02, 0.82921900E+01, 0.13086200E+02, 0.21288600E+02, 0.16749400E+02, 0.14218200E+02, 0.96350700E+02, -.16391300E+03, -.81457900E+02, 0.29721200E+02, 0.91024500E+01, -.29672900E+01, 0.14158000E+03, 0.39401200E+02, 0.24492600E+01, 0.83349400E+02, 0.23620700E+02, -.92643200E+01, 0.71731200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12132700E+01, 0.42198400E-01, -.26997100E+01, -.41322300E+01, 0.14962700E+01, 0.13687400E+01, 0.17994900E+00, 0.13608900E+00, 0.73004900E-01, -.15444300E+00, 0.23008900E+00, -.27514700E+00, 0.15338600E+01, -.20331200E+01, 0.70056500E+00, -.64595200E+00, 0.17429200E+01, -.86396300E+00, 0.55725400E+00, -.98183700E+00, -.12390000E+01, 0.87516000E+00, -.63411000E+00, 0.60314600E+00, 0.10767800E+00, 0.86295800E+00, 0.19193100E+01, 0.12320700E+00, 0.21994200E+00, 0.28930900E+00, 0.18935300E+01, 0.12067800E+01, -.51466300E+00, 0.54536500E+00, -.13665800E+01, 0.44646800E+00, 0.28086500E+01, -.33769100E+00, -.10744800E+00, 0.13803200E-01, 0.23956800E+01, -.61510200E+00, 0.23436300E+00, 0.46304500E+00, 0.36871300E+01, -.96248700E-01, 0.28470600E+01, -.94964000E-01, 0.39633300E+00, -.71651300E+03, 0.52786600E+02, 0.22721600E+02, -.33729900E+01, -.56252400E+02, -.16282400E+03, 0.13599400E+02, -.55671300E+03, 0.53285400E+03, 0.31010300E+03, 0.33002800E+03, -.23814500E+03, -.23695700E+03, -.71819300E+02, 0.36108000E+03, 0.17026300E+02, 0.65792100E+02, -.11314300E+02, 0.37951000E+02, -.77906900E+01, 0.28606600E+02, 0.67713600E+02, 0.58449500E+02, 0.98936000E+02, -.27231400E+02, -.75904100E+01, -.84805400E+00, 0.42460800E+01, 0.91040000E+02, 0.11601300E+02, -.10981600E+02, 0.34894500E+02, -.31613600E+02, -.73115500E+01, -.21516900E+00, -.13144100E+02, 0.16064900E+02, -.66132600E+01, -.20272300E+01, 0.24431600E+02, -.16898600E+02, -.67786900E+01, 0.12086200E+01, -.17106400E+02, 0.96956000E+01, -.31142100E+01, -.29545300E+01, 0.86536600E+02, 0.17579900E+03, -.20017400E+02, -.45422900E+02, 0.23473900E+01, 0.49022500E+02, 0.98028100E+01, -.47776000E+02, 0.29061800E+02, -.22058400E+03, -.31482000E+02, -.54586700E+02, 0.42312800E+02, -.68060300E+01, 0.42665200E+01, -.57441000E+02, 0.11062000E+02, -.26069800E+02, 0.64478400E+01, 0.72533700E+01, -.10213900E+02, 0.30838000E+01, -.65547500E+01, 0.25358200E+01, -.57550400E+03, 0.16073600E+03, 0.20356200E+03, 0.24570800E+03, -.38077900E+02, -.22493200E+03, -.11470300E+03, 0.26752700E+03, 0.21120800E+02, -.64946700E+02, 0.29525100E+02, 0.11958200E+02, -.11299700E+03, 0.62725300E+01, -.26234400E+02, -.19224200E+02, 0.30654000E+03, 0.44004900E+03, 0.44664200E+02, 0.34947000E+02, -.21936500E+03, 0.13896200E+03, 0.14089700E+03, 0.68521200E+02, 0.47245600E+02, 0.55787900E+02, 0.51848500E+02, 0.88474500E+02, -.58666300E+02, 0.17312500E+00, -.38613800E+02, 0.95261800E+02, 0.13043500E+02, -.23515700E+01, -.52282600E+00, -.31725500E+01, 0.47354700E+00, 0.51889000E+01, -.10389000E+01, -.12182900E+02, 0.42139400E+02, 0.21791100E+02, 0.54552800E+01, -.67426600E+01, 0.17104800E+01, -.15397600E+02, -.95472800E+01, 0.40282500E+01, 0.34422900E+02, -.26396500E+01, -.70397700E+02, -.72413300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15774000E+00, 0.22936200E-01, -.81327000E+00, 0.26342500E+01, 0.39520100E+00, -.28895300E+00, 0.23186000E+00, -.11220500E+01, -.11288300E+01, -.42160100E-01, 0.45681800E+00, 0.16174700E+00, 0.10595900E+00, -.41161200E+00, 0.18762600E+00, -.27474200E+00, -.95146100E-01, 0.63093200E+00, 0.95691900E+00, -.75281300E+00, -.14908900E+01, 0.50136000E+00, -.80404900E+00, 0.31259800E-01, 0.75561100E-02, 0.26244000E+00, -.19776600E+00, -.67615000E-02, 0.44111500E-01, -.25805200E+00, 0.10905000E+01, -.23318100E+00, -.13805400E+00, -.60567200E-01, -.63947900E+00, 0.43806200E-01, 0.75370600E+00, 0.12548300E+00, -.44404500E-02, -.10916800E+00, -.13802200E+01, -.19470100E-01, 0.12141600E+00, -.53504100E-01, 0.37231700E+00, -.64199700E+00, -.32217900E+01, -.11758200E-01, -.36178900E-01, 0.26157700E+00, -.64465800E+02, -.24416300E+02, -.22059000E+02, 0.23428300E+02, 0.63599900E+02, -.21447900E+02, 0.49447100E+03, -.79563600E+02, -.25380300E+03, -.21882900E+03, 0.21995200E+02, 0.15660500E+03, 0.56374700E+02, -.26402800E+03, -.20295500E+02, -.17271100E+03, -.88007700E+01, -.78558400E+02, 0.14910300E+03, -.37935800E+02, 0.59998500E+01, -.64358300E+02, 0.45391800E+02, 0.12467200E+03, -.63082600E+02, -.79631900E+02, 0.42995700E+02, 0.22889300E+02, 0.87759200E+02, -.88438500E+02, -.32960500E+02, 0.73238400E+01, -.13988500E+01, -.65134400E+01, 0.12700400E+02, -.89487200E+01, 0.15280400E+02, -.58746800E+01, -.16898200E+02, -.12515000E+02, -.13108000E+01, -.58060400E+01, 0.97073400E+01, -.23511400E+01, 0.68468900E+01, -.73945600E+01, 0.97016400E+02, 0.30763800E+02, 0.38901800E+02, 0.11480200E+02, -.33632900E+02, 0.10219900E+03, 0.12394600E+03, 0.21929200E+02, -.20392100E+03, -.12456300E+03, -.47205200E+01, 0.49362200E+02, -.18507400E+02, -.14248500E+03, -.13094800E+03, 0.36871500E+02, -.34022700E+01, 0.75047900E+02, -.73075000E+01, -.14860500E+02, 0.24150300E+02, 0.13600100E+02, -.84250100E+01, -.21740100E+02, 0.37729100E+03, -.40442900E+01, -.51684800E+02, -.51682500E+02, -.16929600E+03, 0.79103700E+02, 0.21534200E+02, -.51783900E+02, 0.35610400E+02, 0.56723300E+00, -.68908200E+02, -.38492100E+02, 0.70351800E+02, 0.52346900E+02, 0.17342100E+02, -.48386100E+02, -.77020000E+02, 0.14159700E+02, -.89380300E+02, -.74446100E+02, 0.17427800E+03, -.44469200E+02, 0.86228600E+01, -.99241600E+02, 0.31195700E+02, -.13733700E+02, -.20149400E+02, -.63722500E+02, 0.35296400E+02, -.39518600E+01, 0.81410800E+00, -.58583900E+02, -.81321400E+01, 0.47745500E+01, -.23281900E+01, -.86839100E+01, -.44994200E+01, -.13668600E+02, -.60108300E+01, 0.98963700E+01, 0.69582000E+01, 0.20257800E+01, -.23778000E+02, 0.15822500E+01, -.60230500E-01, -.27819000E+02, -.21115500E+02, 0.67714000E+01, -.54548100E+02, 0.22712600E+01, 0.44690400E+02, -.55753500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.34671000E+00, -.73885300E-02, 0.10035000E+01, -.14985200E+01, 0.59508100E+00, -.30783500E+00, 0.95852700E-01, -.20391200E+00, -.34414900E+00, 0.40129900E-01, -.37117400E+00, 0.22155600E+00, -.13504000E+00, 0.46472000E-01, -.25798100E+00, 0.43916200E-01, 0.36370300E+00, -.45455800E-01, -.55927200E+00, 0.60731300E-01, 0.54528200E-01, -.66331800E-01, 0.27508400E+00, -.87881600E-02, 0.11694000E+00, 0.27611600E+00, -.98945100E-01, -.11327800E-01, 0.16722300E+00, 0.84966500E-01, -.79540600E+00, -.55077800E+00, -.53846900E+00, 0.12152100E+00, -.35703100E+00, -.53652200E-01, -.34157800E+00, 0.44421900E-01, 0.50595400E-01, -.66162900E-01, -.13601100E+00, -.36363900E-01, -.66374200E-01, 0.33424900E-01, -.75919600E+00, -.56780400E+00, -.14022600E+01, -.45761600E-01, -.13772600E+00, -.20539800E+00, 0.18663200E+00, 0.20297000E+02, -.12546600E+02, -.26359200E+02, -.76158200E+02, 0.12766700E+02, -.65937100E+02, -.20378700E+01, 0.95376100E+02, 0.60583900E+02, -.10541800E+03, -.41174900E+02, -.13743400E+02, 0.62166200E+02, 0.89870600E+02, 0.56435600E+02, -.39346800E+02, -.29644200E+02, 0.36227600E+02, 0.49593700E+02, -.19220800E+02, -.20768900E+02, -.17561200E+03, 0.43741200E+02, 0.56323300E+02, 0.55709800E+02, -.27789200E+01, -.25137600E+02, -.23359100E+02, 0.53637700E+02, 0.36563300E+01, -.76747300E+01, -.29075800E+01, -.85466400E+00, -.37313500E+00, 0.60817500E+01, 0.94376400E+00, -.11184100E+01, -.63786000E+01, 0.62180000E+01, 0.83142600E+00, 0.14435100E+01, -.29676300E+01, 0.85018300E+00, 0.36731900E+01, 0.54341700E+00, 0.24914700E+02, -.94128200E+02, -.21035200E+02, -.57827400E+01, 0.18483600E+02, 0.12709700E+02, 0.55781800E+02, 0.76067500E+01, 0.12573800E+03, 0.10136800E+03, -.24046200E+01, -.16404300E+02, -.24191700E+02, 0.40366900E+02, -.45785700E+02, -.24744800E+02, -.29879900E+02, -.28317400E+02, 0.28770800E+02, 0.93335100E+01, -.41676800E+01, -.48419400E+01, 0.13853400E+02, 0.16593000E+02, -.29840400E+03, 0.14577800E+02, 0.81097900E+02, 0.11204700E+03, -.39450900E+02, -.12149900E+03, -.59610000E+02, 0.10564600E+03, 0.10917700E+02, -.28105900E+02, 0.10737100E+02, 0.12560400E+02, -.44553100E+02, -.39336500E+01, 0.31770100E+02, 0.42715200E+01, 0.36917900E+03, -.12043800E+03, -.33548500E+02, -.81316200E+02, -.82307700E+02, 0.12278700E+03, 0.34729000E+02, -.75611000E+02, 0.23790200E+02, 0.25319200E+02, 0.13044900E+01, 0.15131000E+02, 0.34403200E+01, 0.23223200E+02, -.90451800E+01, 0.20528100E+02, -.20472100E+01, -.33897500E+00, -.48064700E+01, 0.16159000E+01, 0.97078700E+00, 0.51500900E+01, 0.29606200E+01, 0.40109300E+01, 0.19285300E+02, 0.14759900E+02, 0.12218600E+02, -.24789600E+00, -.27747700E+00, -.99126700E+01, 0.14886400E+01, -.13064300E+02, 0.10459600E+02, 0.32608600E+01, -.96602600E+01, -.69520800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13421600E+01, 0.51158100E-01, 0.33795200E+01, 0.62104100E+01, -.11142700E+01, -.14907600E+01, -.15974100E+00, -.16394200E+01, -.13986100E+01, 0.25307800E+00, 0.59275600E+00, 0.11425800E+01, -.18083100E+01, 0.21975400E+01, -.68019500E+00, 0.89420600E-01, 0.14176900E+01, -.48663100E+00, -.16452000E+01, 0.91171800E+00, -.10679700E+00, 0.37763300E+00, -.16637100E+01, -.51167600E+00, -.63461700E+00, -.18396900E+00, -.51855500E+00, 0.35439900E-01, 0.34436800E+00, 0.78390400E+00, 0.21143900E+01, -.75844000E+00, -.80072900E+00, -.47688100E+00, -.96074000E+00, -.20910300E+00, 0.29053100E+00, 0.95819600E-01, 0.74542100E-01, 0.57789000E-01, -.10875400E+01, 0.29648200E-01, -.18008800E+00, -.51394300E+00, -.90905600E+01, 0.47460100E+00, 0.71686300E+00, 0.71438400E-01, -.11637500E+00, -.36887400E+00, 0.11543000E+01, -.58887200E+00, 0.10004700E+03, 0.26142700E+02, -.68202100E+02, 0.15612300E+02, -.91210300E+03, 0.47959500E+03, 0.57839500E+03, 0.54641300E+03, -.38269200E+03, -.43774800E+03, -.12712900E+03, 0.59827100E+03, 0.44700700E+03, 0.36818400E+03, -.15135300E+03, -.92620500E+02, -.16263800E+03, 0.26683600E+03, 0.65721600E+02, -.14544100E+03, -.20865000E+03, -.16438900E+03, 0.13437000E+03, 0.12216500E+03, -.27845400E+01, -.99755000E+02, -.12745300E+03, 0.17589100E+03, -.37005800E+02, 0.16255800E+02, 0.19835100E+02, 0.20316500E+02, -.26497300E+02, 0.18863700E+02, 0.32751800E+02, 0.20233600E+02, -.66097200E+02, 0.59620200E+02, 0.21731500E+02, 0.22778200E+02, -.23453900E+02, -.18348800E+01, 0.27596000E+02, 0.28012200E+02, -.67119500E+03, -.28292500E+03, 0.41113400E+02, 0.10341100E+03, 0.15994300E+03, -.29118700E+03, -.33393800E+02, 0.69798600E+02, 0.82963700E+03, 0.16301100E+03, -.10340700E+03, -.15707600E+03, -.43567600E+02, 0.34370100E+03, 0.79542700E+02, -.10874500E+03, -.10799200E+03, -.53928500E+02, 0.92321600E+02, 0.30949200E+02, -.15922500E+02, -.65413400E+02, 0.46762300E+02, 0.61023900E+02, -.68918700E+03, 0.38848500E+03, 0.20507000E+03, 0.28771700E+03, -.25174400E+02, -.24767200E+03, -.18326700E+03, 0.25669600E+03, -.78357000E+02, -.47340400E+02, 0.11659700E+03, 0.12243500E+03, -.15147200E+03, -.34785300E+02, 0.88282200E+02, 0.17687300E+03, 0.77304200E+03, 0.10499900E+03, 0.95888400E+02, 0.30015800E+02, -.51531500E+03, 0.22935900E+03, -.22206900E+01, 0.29388400E+02, -.93322400E+02, -.72797900E+02, 0.75570800E+01, 0.63475600E+02, 0.61307100E+01, 0.58564900E+02, 0.76076400E+02, 0.76631800E+02, -.34080800E+02, -.82980200E+01, 0.28963500E+01, 0.47145000E+02, 0.16518300E+02, 0.45335200E+02, 0.30322200E+02, 0.45818100E+01, 0.50849200E+02, 0.34243700E+01, 0.68578400E+02, 0.12821500E+02, -.68160000E+01, 0.27650600E+02, 0.24907100E+02, -.57825500E+02, 0.54330400E+02, 0.13040900E+02, -.73178000E+02, 0.24389600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.82770900E+00, 0.22831900E-01, -.21529900E+01, -.82893900E+01, -.10022900E+01, -.29234800E+00, 0.34942300E+00, 0.12707800E+01, 0.99508400E+00, -.13030000E+00, 0.66726700E+00, -.20507600E+00, 0.32668100E+00, -.77082600E+00, 0.94980600E+00, -.74082000E+00, 0.10940500E+01, -.70896800E+00, -.41580900E+00, 0.42063000E+00, 0.22181500E+01, -.62833800E+00, 0.81399500E+00, -.12115300E+00, 0.35295900E+00, 0.12586800E+00, -.70745200E+00, -.17810700E-01, 0.13650900E+00, 0.27226700E+00, 0.25165400E+00, 0.50994600E+00, -.14148500E+00, 0.34174300E+00, 0.25142100E+00, -.53717300E-01, 0.49302800E-01, 0.71945600E-01, 0.13849100E+00, -.76408900E-01, -.10291900E+00, 0.15227900E+00, 0.14626700E+00, 0.34527400E+00, 0.19748800E+01, -.12880700E+01, 0.65080100E+01, -.14624200E+00, -.18442700E+00, -.37264400E+00, -.37132400E+00, 0.83014300E+00, -.30420900E+00, -.64146500E+02, -.67951200E+02, -.74421900E+01, -.38495400E+03, -.14321400E+03, 0.13741900E+03, 0.16886500E+03, -.42532000E+02, -.68639800E+02, -.59698200E+02, 0.20439500E+03, -.14844300E+03, -.10376000E+03, 0.73613600E+02, 0.95308800E+02, -.53500300E+02, -.47513500E+02, 0.83706100E+01, 0.10453200E+03, 0.11874900E+03, -.78662800E+02, -.69736100E+02, -.42156900E+02, 0.44448700E+02, 0.18846200E+03, 0.64311300E+02, -.51205700E+02, 0.50335000E+02, -.25252500E+00, -.92565000E+01, 0.80130400E+01, -.14251500E+02, 0.34564000E+01, -.43367100E+02, 0.59533400E+01, 0.47340100E+02, -.69623000E+01, -.84600100E+01, 0.58500900E+01, -.98645400E+01, 0.10844500E+02, -.29926300E+02, 0.33797500E+01, 0.49208500E+03, 0.14909000E+03, -.12524600E+03, -.11282300E+03, -.12966600E+03, 0.52278100E+02, -.12466000E+03, -.14001900E+03, -.31095000E+03, 0.68803900E+02, 0.12413700E+03, 0.76052700E+02, 0.73046900E+02, -.31800500E+02, 0.59687800E+02, 0.95204300E+02, 0.58143600E+02, -.41297700E+02, -.37402800E+02, 0.23095200E+02, -.22221800E+02, 0.42590000E+02, -.27069400E+02, 0.14133200E+02, -.25207800E+03, -.14782700E+03, 0.14603200E+01, -.14889200E+02, 0.15175000E+03, -.64260200E+02, -.16079800E+02, 0.49755100E+01, -.48573700E+01, 0.81805800E+02, 0.67010700E+01, 0.55218400E+00, -.39514500E+02, -.21310100E+02, -.90474200E+02, -.23831500E+02, -.34859700E+03, -.29147600E+03, 0.15157800E+03, 0.17361600E+03, -.99400700E+02, -.98935800E+02, 0.53153100E+02, 0.21274700E+03, 0.14967600E+02, 0.62324000E+02, 0.42984400E+02, 0.74611900E+02, -.82641000E+02, -.23032400E+02, -.97095600E+02, 0.56051500E+02, 0.25283400E+02, -.93858200E+01, -.37177900E+01, 0.26090600E+01, 0.39046000E+01, 0.44503500E+00, -.59552000E+01, 0.10195600E+02, 0.99125200E+01, -.37581400E+01, 0.50284800E+01, -.89992000E+01, 0.38247400E+01, 0.49576700E+02, 0.23500300E+02, 0.23137600E+02, 0.41988800E+02, 0.59153900E+01, -.62254700E+02, -.11703000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.47854200E+01, -.94515600E-01, -.24386400E+01, -.10121500E+02, -.32774000E+01, 0.25399200E+01, 0.37898600E+00, 0.25058800E+01, 0.37588000E+01, -.31817800E+00, 0.36547400E+01, -.50488300E+01, 0.17856600E+00, -.79957800E+00, 0.15665500E+01, 0.24235000E+00, -.33468700E+01, -.17190400E+01, -.27523600E+01, 0.47309500E+01, -.89782400E+01, 0.27212900E+01, 0.19659500E+01, -.12545000E-01, 0.46519500E+00, -.37610300E+00, -.13026900E+00, -.74339600E-01, -.80212400E+00, 0.23947300E+01, 0.52243100E+01, 0.25209000E+01, 0.85875200E+01, -.31689600E+01, 0.34548800E+01, -.60720800E+00, 0.11754800E+01, -.13969700E+00, 0.13580100E+00, -.14600300E+00, 0.19601400E+01, 0.39678300E+00, 0.39632600E+00, -.15069900E+00, -.63209800E+01, 0.19840400E+01, 0.16586000E+02, 0.28707900E+00, -.12097400E+01, -.35853400E+01, -.21499700E+01, -.41967100E+01, 0.64957400E+00, 0.31710900E+01, 0.21722600E+03, -.18733400E+02, -.10334400E+04, 0.16140000E+04, 0.13280000E+03, 0.17473100E+03, 0.24150000E+03, -.26681500E+03, -.96957700E+02, 0.25164500E+03, -.24145500E+03, 0.26707900E+03, 0.37757500E+03, 0.32636000E+03, -.40803600E+03, -.20656100E+03, 0.10126500E+03, 0.32680500E+03, -.37440300E+03, 0.15907000E+03, 0.56818600E+02, 0.82643700E+02, 0.47475300E+02, -.39748400E+03, 0.30230700E+02, 0.82259500E+02, -.55316800E+02, 0.56288200E+02, 0.16065500E+02, 0.27369100E+02, -.12666900E+02, -.28992600E+02, 0.41765500E+02, 0.25041800E+02, -.33189900E+02, 0.27908000E+02, 0.16349900E+02, 0.13524100E+02, -.20654000E+01, -.10339200E+02, 0.29866900E+02, 0.18927000E+02, 0.47275200E+03, -.71759800E+03, -.17441300E+03, -.13780300E+03, 0.12601500E+03, 0.96532700E+02, -.24924200E+03, -.10871300E+03, -.14696300E+03, 0.33585100E+03, 0.72099100E+01, -.30968200E+02, -.42806700E+02, 0.13023300E+03, 0.30214700E+03, -.59883000E+02, 0.65106000E+02, 0.10048500E+03, -.26348100E+02, -.72444700E+02, 0.85601700E+02, 0.17397800E+02, 0.41725700E+02, -.57532200E+02, 0.47991500E+03, 0.38277800E+03, -.52334700E+02, -.95046500E+02, 0.45004100E+02, 0.17276000E+03, 0.32388200E+02, -.66099200E+02, -.42247800E+02, -.91088600E+02, 0.23308700E+02, 0.99375500E+01, 0.48648500E+02, 0.54606600E+02, 0.40319800E+02, 0.66483700E+02, -.53322900E+03, 0.14869200E+04, 0.11233500E+03, 0.78579400E+02, 0.54757100E+02, -.84853200E+02, -.11570900E+03, 0.13158500E+03, 0.12427200E+03, -.17814500E+03, 0.10122000E+03, 0.78392200E+02, -.19373300E+03, -.94283400E+02, -.17478900E+01, 0.10747200E+03, -.20931000E+02, -.16680400E+02, 0.23945500E+02, -.22763600E+02, 0.87936300E+01, 0.11974100E+02, 0.23023900E+02, -.18376700E+01, -.10720900E+03, -.77753900E+02, -.13572600E+02, 0.15694500E+02, -.74298100E+01, 0.31926500E+02, 0.13166100E+02, -.27108900E+00, 0.74305900E+01, -.89076400E+00, 0.42049800E+02, 0.37979600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.77872900E+00, 0.40996100E-01, -.68251500E-01, 0.23309000E+01, 0.20117800E+00, -.13915800E-01, -.33266400E-01, -.69609300E+00, -.35051500E+00, -.11113200E-01, -.97680900E+00, 0.40624300E+00, 0.44810300E+00, -.10313800E+01, -.22365900E+00, 0.12838200E+00, 0.26618400E+01, -.12474800E+00, -.16593900E+01, -.23054800E+01, 0.39471200E+01, -.17675200E+01, -.17707300E+01, -.58507600E+00, 0.80137300E-01, 0.23573300E+01, 0.16957200E+01, -.53873300E-01, -.17175600E+00, -.18442500E+00, -.14178000E+01, -.89438700E+00, -.13681600E+01, 0.52064600E+00, -.12448100E+01, -.22896400E-01, -.39238000E+00, 0.52571900E-01, 0.12437400E-01, -.55758700E-01, -.63529600E+00, 0.34360700E-01, 0.18038000E-01, 0.10496500E+00, 0.26909700E+01, -.30063300E+00, -.55605700E+01, -.46896400E-01, 0.20106400E-01, 0.19042100E+00, -.16544600E+00, 0.75783500E+00, 0.12824200E-01, 0.30242100E+00, -.18482400E-01, 0.10963900E+02, 0.70486900E+03, -.24487800E+03, -.33779100E+03, -.32500800E+03, 0.12408600E+03, 0.25990700E+03, 0.99388500E+02, -.37886300E+03, 0.50810600E+02, -.15951100E+03, -.73963500E+02, -.12131600E+03, 0.16650200E+03, 0.22129000E+00, -.14893100E+02, -.11299000E+03, -.46936300E+02, 0.14666800E+03, -.12491600E+02, -.33168700E+02, 0.10026800E+02, -.55996600E+02, 0.39170400E+02, -.42303300E+02, -.23761500E+02, -.53177000E+01, -.37488800E+01, -.19576500E+02, 0.27406600E+02, -.13332600E+02, 0.12693700E+02, -.18302900E+02, -.12707200E+02, -.16233500E+02, -.47483900E+01, -.15651900E+02, 0.15562000E+02, -.99189900E+01, 0.79469500E+01, -.17889700E+02, -.22316800E+03, 0.17049200E+03, 0.13388400E+03, 0.92120300E+02, -.16454000E+02, 0.48277000E+02, 0.21940300E+03, 0.10728400E+03, -.16248300E+02, -.18823200E+03, -.75636100E+02, -.10071500E+02, 0.17868500E+01, -.11865900E+03, -.22714500E+03, -.24158600E+02, -.58048600E+01, 0.66896800E+02, -.47219500E+00, -.18561400E+02, 0.14084200E+02, -.13228500E+01, -.91347700E+01, -.22483000E+02, 0.96809300E+02, 0.55840400E+02, 0.14635900E+02, 0.21152900E+02, -.14235900E+03, -.10520700E-01, 0.25516000E+02, 0.92282100E+01, 0.37098600E+02, -.17331500E+02, -.73160900E+02, -.49003000E+02, 0.62964500E+02, 0.12496500E+02, 0.18810800E+02, -.69033900E+02, 0.72061600E+02, -.29458100E+02, -.20046500E+03, -.16868100E+03, 0.24230300E+03, 0.44660300E+02, 0.39203900E+02, -.21217200E+03, 0.12290600E+02, -.73957900E+01, -.29965400E+02, -.81483000E+02, 0.81351700E+02, 0.45329900E-01, 0.35986900E+02, -.70783700E+02, -.60018900E+01, 0.11678800E+02, -.37672600E+01, -.19771500E+02, -.11792000E+02, -.23575600E+02, -.12379000E+02, -.20490500E+02, -.30606900E+01, 0.25868800E+01, -.32484000E+02, 0.19681700E+01, 0.17216000E+01, -.59584100E+02, -.28212800E+02, 0.76520500E+01, -.52746700E+02, -.83738600E+01, 0.69134300E+02, -.88396800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.74121100E+00, 0.46637200E-01, 0.26227000E+00, -.74835200E-01, 0.16588500E+01, 0.49815700E+00, -.21095500E-01, -.19812400E+00, -.33742100E+00, 0.31179400E+00, -.11103300E+01, 0.11103900E+01, 0.82818300E+00, -.66253700E+00, -.19809600E-01, -.88919700E+00, 0.36717900E-01, -.16507000E+00, 0.81666400E+00, -.69533900E+00, -.29560300E+00, 0.12568000E+00, 0.45750200E+00, 0.33946800E+00, 0.86247700E-01, 0.50015000E+00, -.99159900E+00, -.47825400E-01, -.91407000E-01, -.20761100E+01, -.13743400E+01, -.11897900E+00, -.14273500E+01, 0.70966700E+00, 0.15704100E+00, 0.13893000E+00, -.20064800E-01, 0.71728700E-01, 0.16910300E+00, -.29401700E+00, 0.63761800E+00, -.11874200E+00, -.88773000E-01, 0.33146400E+00, 0.25178200E+01, -.44273600E+00, 0.50268400E+00, -.91468700E-01, -.74982400E-01, -.20998800E+00, 0.15473500E+00, 0.15274200E+01, -.24220100E+00, 0.40462100E+00, 0.96287600E-01, 0.48420300E+00, -.61174700E+03, 0.10505800E+03, 0.20460600E+03, 0.21571100E+03, 0.72614900E+02, -.17175400E+03, -.37696900E+02, 0.26616700E+03, -.16619700E+03, 0.24601600E+02, 0.11063600E+03, 0.17186800E+03, -.22761100E+03, -.72630900E+02, 0.80542600E+00, 0.14177400E+03, 0.89076600E+02, -.26309700E+03, 0.11472200E+02, 0.28241500E+02, -.22281400E+02, 0.45013900E+02, -.60952300E+02, 0.38359100E+02, 0.41683700E+02, 0.29785400E+00, -.14450700E+01, 0.16986900E+02, -.24378600E+02, 0.11293400E+02, -.24025800E+02, 0.16739200E+02, 0.34939500E+02, -.24879100E+01, 0.20299000E+01, 0.13587000E+02, -.11049500E+02, 0.11024700E+02, -.12881800E+02, 0.17756400E+02, 0.21003800E+03, 0.69247100E+02, -.96479800E+02, -.12656800E+03, 0.41544500E+02, -.11187500E+02, -.22341400E+03, -.15169100E+03, -.23515500E+03, 0.11066400E+03, 0.32251800E+02, 0.38293200E+02, 0.35880800E+02, -.10561500E+02, 0.20380300E+03, 0.56107400E+02, 0.27042800E+02, -.11284800E+03, -.60748500E+01, 0.16505000E+02, -.81291300E+00, 0.19814500E+02, 0.95297900E+01, 0.16312100E+02, 0.14726200E+03, -.20900200E+02, -.12874100E+03, -.13994600E+03, 0.21048600E+03, 0.10439200E+03, 0.34011600E+01, -.13575000E+03, -.26528400E+02, 0.18195500E+02, 0.69598200E+02, 0.98105300E+01, 0.20048200E+02, -.65262300E+01, -.17818200E+02, 0.46194400E+02, -.59056300E+03, 0.75701700E+01, 0.27376900E+03, 0.27804700E+03, -.10855700E+03, -.20573600E+03, -.35397000E+02, 0.31300800E+03, -.31903200E+02, 0.38202500E+02, 0.55546300E+01, 0.73730700E+02, -.90207200E+02, -.43554900E+02, -.97656700E+02, 0.47458300E+02, 0.17673000E+02, -.11913700E+02, 0.90836600E+01, 0.10950400E+02, 0.10163500E+02, 0.25600300E+02, 0.10306600E+02, 0.83081400E+01, -.30888600E+02, -.32319800E+02, 0.35319000E+02, -.60609300E+01, -.13283300E+01, 0.54651700E+02, 0.80115800E+01, -.54567500E+01, 0.42556200E+02, 0.26513300E+01, -.61092500E+02, 0.40497800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.60604000E+00, -.21283500E-01, 0.78505000E+00, 0.37111000E+00, -.27458800E-01, -.72171600E+00, -.57469000E-01, 0.43626900E+00, 0.12128400E+00, 0.18795600E-01, 0.24369700E+00, 0.30675400E-01, -.16484200E+00, 0.73010800E+00, -.32773500E-01, -.33645000E+00, -.12769600E+01, -.12075300E+00, -.35550200E-01, 0.42272900E+00, 0.62235400E+00, -.23090000E+00, -.11688900E+00, -.51171700E-01, -.15438300E+00, -.54847700E+00, 0.60120500E+00, 0.48564100E-01, 0.54069300E-01, 0.72817300E+00, 0.38980400E-01, 0.39306900E+00, 0.40104700E+00, -.26097400E+00, -.70066600E-01, -.10075700E+00, 0.69147900E-01, -.17664200E-01, -.76459800E-01, 0.16130000E-01, -.75754400E+00, 0.23639600E-01, -.67426300E-01, 0.19601500E+00, 0.20769700E+01, 0.29097800E+00, -.36302200E+01, 0.19751700E-01, 0.17292700E+00, 0.36584400E+00, 0.18529000E+00, 0.41177100E+00, -.16683400E+00, -.41340700E+00, 0.71359700E-01, -.25853900E+00, -.43219800E+00, -.23292300E+03, -.41609900E+02, -.29557600E+02, 0.11263600E+03, 0.41811400E+02, 0.22323700E+02, -.20969200E+02, -.85447600E+02, -.65852600E+02, 0.18203200E+02, 0.40763100E+02, -.50274600E+02, -.27287000E+02, -.64961600E+01, 0.29055600E+02, 0.60568200E+02, -.10237500E+03, -.11567700E+02, -.85442400E+01, -.43235500E+01, 0.55664100E+02, -.13207400E+02, -.59426900E+01, 0.19771100E+02, -.39215100E+01, -.27308100E+01, 0.15486000E+01, -.40117400E+01, 0.18284200E+01, -.16657300E+02, 0.14438300E+01, 0.19365300E+02, -.85677700E+01, -.26576300E+01, 0.11621300E+01, 0.22287100E-01, 0.31182800E+01, -.10311200E+02, 0.24154000E+01, 0.11375300E+03, 0.15263400E+03, -.16295600E+02, -.42326500E+02, -.37716000E+02, 0.17541600E+01, -.99683500E+02, -.60801900E+02, -.20361800E+03, -.68886800E+01, 0.33850300E+02, 0.50837700E+02, 0.38065600E+02, -.62898600E+02, 0.53210500E+02, 0.62108900E+02, 0.18588600E+02, -.42019600E+02, -.17534500E+02, 0.61870500E+01, -.72262600E+01, 0.13792400E+02, -.73854000E+01, 0.19746400E+01, 0.16647000E+03, -.90851400E+02, -.10132900E+03, -.11348900E+03, 0.11715600E+03, 0.94051300E+02, 0.32137000E+02, -.11582200E+03, -.48299700E+01, 0.31944200E+02, 0.94126000E+01, -.99643900E+01, 0.32592700E+02, -.13926800E+02, -.26209600E+02, 0.29681600E+00, -.37448600E+03, -.14805700E+03, 0.83278500E+02, 0.11517000E+03, 0.43790700E+02, -.13009000E+03, -.14187200E+02, 0.12377100E+03, -.53624200E+02, 0.35070300E+02, -.10633900E+02, 0.80515900E+01, -.36361900E+01, -.22007100E+02, -.36449100E+02, -.90932900E+01, 0.98944000E+01, -.21979400E+01, 0.98245200E+00, 0.11041300E+01, 0.10838000E+01, 0.18986800E+01, -.25837400E+01, -.15183100E+01, -.17880300E+02, -.98746500E+01, 0.72441600E+01, -.38147800E+01, 0.96218300E+00, 0.27028200E+02, 0.37891800E+01, 0.59154600E+01, 0.11604700E+02, -.18819400E+01, -.14303700E+02, -.38928700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17886300E+01, 0.70898000E+00, -.14459500E+01, -.54765600E+01, 0.49596000E+00, 0.24577700E+00, 0.32389200E+00, 0.56519300E+00, 0.33475900E-01, -.53176300E+00, -.12180200E+00, -.37271400E+00, 0.43377700E+00, 0.12116400E+01, 0.20784800E+00, 0.10703200E+01, -.51116800E+00, 0.13023700E+01, 0.27169400E+01, 0.17485700E+01, 0.25612600E+01, -.94670100E+00, 0.25862600E+01, 0.91220400E+00, 0.33518300E+00, -.26130900E+01, 0.64603600E+00, 0.20770500E+00, 0.64459800E+00, 0.16562400E+01, 0.22451400E+01, 0.45022900E+00, -.33609500E+00, 0.19915200E-01, -.13713700E+00, 0.69528200E-01, 0.19068400E+01, -.72916600E-01, -.28210400E+00, 0.50397200E+00, -.55884300E+00, 0.53286500E+00, 0.11643900E+01, -.29395100E+00, 0.57629400E+01, -.94194600E+00, 0.10475900E+02, 0.19273700E+00, -.51326500E-01, -.12780400E+00, -.81465700E+00, 0.91932400E-01, -.11755800E+01, 0.16110000E+01, -.22427100E-01, -.94508400E+00, -.17615900E+00, -.24569800E+01, -.15653800E+03, -.83330300E+02, 0.19766400E+03, 0.14289400E+03, 0.15039000E+03, -.82029300E+02, -.31201200E+03, -.60201600E+03, 0.39101500E+02, 0.11091800E+03, -.13119400E+03, -.16373900E+03, -.69272400E+02, 0.57446800E+02, -.89243100E+02, -.24063200E+03, 0.80567100E+02, 0.52460500E+02, -.44332600E+02, 0.20319600E+02, -.11571700E+03, 0.79149500E+02, 0.52021400E+00, -.11863800E+02, -.20193900E+01, -.35096300E+01, -.77468600E+01, -.66081400E+01, -.15905200E+02, -.79522700E+01, 0.18386400E+02, -.46447000E+02, -.23996500E+01, -.33701400E+01, 0.19995400E+01, 0.55426400E+01, -.33836700E+01, -.72108600E+00, -.22374900E+03, 0.26689600E+03, 0.12837200E+03, 0.22779700E+01, 0.54269700E+02, -.79971200E+02, -.63232800E+02, -.29465800E+02, 0.56249400E+02, 0.27431100E+03, -.11400800E+03, -.31178500E+02, 0.24350200E+02, -.22413100E+02, -.11492300E+02, -.10625800E+02, 0.37400400E+02, -.14058300E+03, -.54428700E+00, -.22380900E+01, -.31469600E+01, 0.58717100E+02, 0.11628800E+02, -.23001900E+01, 0.58840200E+03, 0.14698800E+03, -.20774300E+03, -.17916700E+03, 0.20120800E+02, 0.19725800E+03, -.23134900E+02, -.22270500E+03, 0.10254600E+02, 0.54507900E+02, -.10513300E+02, -.73671900E+02, 0.16740100E+03, 0.37973500E+02, 0.45991600E+02, -.20955000E+02, -.75303600E+03, -.18273900E+02, 0.94107800E+02, 0.21593600E+03, 0.10109100E+03, -.22247600E+03, -.12181900E+01, 0.21620400E+03, -.21592100E+03, 0.21554800E+03, 0.27075600E+02, 0.47001800E+02, -.41012600E+02, -.13614800E+03, -.14189100E+03, 0.28689700E+01, 0.99102900E+01, 0.20191300E+01, -.10643300E+02, -.10785000E+02, -.38184900E+01, 0.15587800E+02, -.21784200E+01, -.12032700E+02, -.18214200E+02, -.74682800E+02, 0.42074200E+02, -.49981300E+01, 0.40151800E+00, 0.97445300E+01, -.10832900E+02, -.12474000E+02, -.33766400E+02, -.53563000E+01, -.13061700E+02, -.47288100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12576100E+01, -.25824100E-01, -.29151600E+01, -.13824800E+02, -.49369100E+00, -.11560600E+01, 0.33489900E+00, 0.66286700E+00, 0.12660000E+01, -.15263500E+00, 0.79161800E+00, -.15945400E+01, 0.77821300E+00, -.81167500E+00, 0.75152800E+00, 0.73666900E+00, -.65526800E+00, 0.17944200E+00, -.30717100E+01, 0.40333400E+00, -.17686600E+01, 0.29948500E+00, 0.21567300E+00, -.26541700E+00, 0.12849800E+00, 0.10792700E+00, 0.43489600E+00, -.76449000E-01, -.12142700E+00, 0.12384900E+01, 0.77317900E+00, 0.59055300E+00, 0.22778900E+01, -.49731000E+00, 0.10713800E+00, -.41717900E+00, 0.49123600E+00, -.11238900E+00, 0.61734100E-01, -.99532200E-01, 0.16705000E+01, 0.43661100E-01, 0.16035300E+00, -.11584700E+00, -.25135800E+01, 0.15030900E+01, 0.38914900E+01, 0.15286200E+00, 0.52499700E-01, -.19804300E+00, -.10512300E+01, -.28003900E+01, -.80860000E-01, -.65344400E+00, -.44031500E-01, -.15832500E+01, -.12600300E+01, 0.18729800E+00, -.71547200E-01, -.50426100E+02, 0.12688100E+03, 0.47311800E+02, 0.54897800E+02, -.23944500E+02, -.16160800E+03, -.13958400E+02, 0.54699300E+02, 0.10224100E+03, -.11023800E+03, -.11231800E+03, -.72656800E+02, 0.74983600E+02, -.23041200E+03, -.45228300E+02, 0.47254900E+02, 0.53461500E+02, 0.12948100E+01, -.53421700E+02, -.27871100E+02, 0.47883700E+02, 0.21504100E+02, -.95653500E+01, -.12986700E+02, -.19367800E+01, -.20056000E+01, 0.12189400E+02, -.32401500E+01, -.18757300E+01, 0.19253100E+02, -.13239600E+02, -.57972200E+01, -.32155400E+01, 0.51913400E+01, 0.11180700E+02, 0.15295300E+01, -.89329400E+00, -.18241700E+03, 0.11900000E+03, -.45107300E+02, 0.12648500E+02, 0.41764600E+02, -.82833000E+02, -.73179500E+02, 0.12525800E+02, -.33732600E+02, 0.24593500E+02, 0.71938400E+02, 0.41520000E+01, 0.12450800E+02, 0.12742700E+02, 0.10777500E+03, 0.12669800E+02, -.28787100E+02, -.79309100E+02, -.64454700E+01, -.11044700E+02, 0.20133800E+02, 0.27012600E+02, 0.43214000E+02, -.10847500E+02, 0.25689600E+03, -.14397600E+02, -.11656100E+03, -.11768900E+03, 0.89536300E+02, 0.10068300E+03, 0.22792400E+02, -.12366100E+03, 0.48694900E+02, -.50208800E+02, 0.13900500E+02, -.39428600E+02, 0.61831800E+02, 0.40888400E+02, 0.28803200E+02, -.14731300E+02, -.45616700E+03, 0.65525400E+02, 0.15174700E+03, 0.13338500E+03, 0.37259500E+02, -.18686300E+03, -.44411200E+02, 0.14919800E+03, 0.10032300E+02, 0.55318600E+02, -.10398900E+02, 0.35235300E+02, -.52758000E+02, -.21936800E+02, -.70229700E+02, 0.24887500E+02, 0.10898800E+02, 0.90391900E-01, -.25463700E+01, -.47490400E+01, 0.10746600E+01, 0.10229600E+02, 0.17266000E+01, -.57249700E+01, -.23569900E+02, -.30756200E+02, 0.18856600E+02, -.67303700E+01, 0.97858300E-01, 0.27833700E+02, 0.20055300E+02, -.59524800E+01, 0.31126700E+01, -.20630900E+01, -.18969400E+02, -.13464400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13681800E+01, -.42388200E-01, 0.30596200E+01, 0.42550800E+01, -.10881100E+01, -.16961400E+01, -.80078700E-01, -.71785100E+00, -.81007200E+00, 0.29773800E+00, -.27572800E+00, 0.14547600E+01, -.10621700E+01, 0.79661900E+00, -.55626900E+00, -.68162100E-02, 0.80273400E+00, 0.25916100E+00, -.87146200E+00, -.57355000E+00, 0.20785100E+01, -.51483900E+00, -.50747600E+00, -.55522500E+00, -.11802800E+00, -.42811800E+00, -.12446100E+01, -.32561700E-01, 0.45355000E-01, -.12793600E+00, 0.17118700E+00, -.71392600E+00, -.10490600E+00, -.12772000E+00, -.41210400E+00, -.15653500E+00, -.94758400E+00, 0.19178400E+00, -.38464600E-01, -.13024900E-01, -.17693800E+01, 0.14744900E+00, 0.71889000E-01, -.10267700E+01, -.58407100E+01, 0.46990000E+00, -.51438500E+00, 0.91044000E-01, 0.56195900E-02, 0.12868100E+00, 0.25649400E+00, -.21534900E+01, 0.83639200E+00, -.46155100E+00, -.11195800E+00, 0.62348000E+00, 0.11121500E+00, -.53832000E+00, 0.17900500E+00, 0.11711200E-02, -.95471800E+02, -.47613500E+02, -.70484200E+02, -.12506000E+02, 0.29637000E-01, 0.88581300E+02, -.16166700E+02, -.51957000E+02, 0.12648000E+03, 0.32576000E+02, 0.43664700E+02, -.31121800E+02, 0.17454800E+03, 0.70559200E+02, -.46768100E+02, -.35617200E+02, -.12017000E+02, 0.73199500E+02, 0.36274100E+02, -.44525400E+02, -.22316000E+01, -.74424900E+00, -.47299800E+00, -.42773900E+01, 0.83299000E+01, -.13523500E+01, -.67759900E+01, -.32405500E+01, -.21980500E+01, 0.71096300E+01, -.11194200E+01, -.21146000E+01, 0.54091800E+00, -.16244000E+01, -.86219900E+01, -.55428800E+01, 0.12000000E+03, -.93023700E+01, -.30283900E+02, -.35192900E+01, -.14102100E+01, 0.77582700E+02, 0.13471800E+03, 0.24269000E+02, 0.74306900E+02, -.17059200E+03, 0.56135500E+01, -.23659200E+02, -.31447400E+02, 0.17876600E+02, -.44956600E+02, -.44913600E+02, 0.26409100E+02, 0.39294000E+02, -.21459200E+02, 0.24661500E+00, 0.12951200E+01, -.62366100E+01, -.24917300E+02, -.86140300E+00, -.35405500E+03, -.36333600E+02, 0.13593600E+03, 0.13781700E+03, -.89659800E+02, -.15143400E+03, -.24357100E+02, 0.15135000E+03, -.33062900E+02, 0.32725900E+02, 0.36408600E+01, 0.30424400E+02, -.64471700E+02, -.33188200E+02, -.65625200E+02, -.78311700E+01, 0.16469000E+03, -.32821600E+01, -.71933100E+02, -.93498700E+02, -.73172400E+01, 0.38742100E+02, -.32612900E+02, -.10413300E+03, 0.84058200E+02, -.52192700E+02, 0.90370100E+00, -.19137500E+02, 0.14083400E+02, 0.52502200E+02, 0.68795500E+02, -.81803700E+01, -.17784900E+01, -.14890700E+01, 0.39435500E+01, -.21081400E+01, -.23394800E+01, -.88659400E+01, -.54877800E+01, 0.66353100E+00, 0.14297000E+02, 0.29217100E+02, -.16453000E+02, 0.99112800E-01, 0.16255900E+01, -.36669700E+02, -.88588400E+01, 0.15562800E+02, -.39455700E+01, -.46845000E+01, 0.28089600E+02, 0.16837500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11931900E+01, 0.52353400E-01, 0.12949900E+00, 0.48552600E+01, -.57044100E+00, -.24914700E+00, -.13087400E+00, -.11108400E+01, -.48038300E+00, 0.60644700E-01, -.43374200E+00, -.40653500E+00, 0.58955700E+00, -.14494300E+01, -.23815300E+00, -.98856100E+00, 0.15867400E+01, -.96209000E+00, -.16336300E+01, -.21145400E+01, -.73252100E+00, -.24406300E+00, -.31984700E+00, 0.13733100E+00, 0.41350200E+00, 0.32990000E+01, -.26404600E+00, -.16177100E+00, -.43692400E+00, -.11089900E+01, 0.43766300E+00, -.38799600E+00, -.19389900E+01, 0.97332100E+00, -.17275000E+01, 0.46570500E+00, -.49378000E+00, 0.24521900E+00, 0.48533000E-01, -.31207500E+00, -.14713100E+01, -.37468600E+00, -.74653700E+00, 0.10850400E-01, 0.19952100E+00, -.68435300E+00, 0.17496800E+00, -.73570800E-01, -.68087400E-01, -.16830600E+00, 0.16717100E+00, 0.38808100E+00, 0.47239500E-01, 0.35724400E+00, 0.13835400E+00, 0.17329000E+00, -.25904700E+00, 0.97819600E+00, -.58806800E+00, 0.18731600E+00, 0.77575700E-01, 0.72351900E+02, 0.11057800E+03, 0.22100300E+01, -.16466200E+03, -.25980500E+03, 0.84947300E+01, 0.82928700E+02, -.82060400E+02, -.11172600E+03, -.11202000E+03, 0.59940700E+02, -.26135600E+03, -.12630100E+03, 0.47649900E+02, 0.15823700E+02, 0.38592300E+02, -.87413500E+02, -.44669900E+02, 0.18115800E+02, -.18140300E+02, -.81637200E+00, 0.34101200E+01, 0.44651700E+01, -.12152800E+02, -.38144300E+01, 0.84362900E+01, 0.18589300E+01, -.12429200E+02, -.13123900E+02, 0.38190700E+01, 0.39966200E+01, -.74133200E+01, 0.97806100E+00, 0.13893400E+02, 0.54096400E+01, -.25308500E+03, 0.11482800E+03, 0.98264400E+02, 0.24578900E+02, 0.66515900E+02, -.83160400E+02, -.38935500E+02, 0.88751200E+01, 0.18549500E+03, 0.18060100E+03, -.87977600E+02, -.24014500E+02, -.27100700E+02, 0.33977300E+02, -.31794900E+02, -.15208100E+02, -.56053200E+02, -.96997300E+02, 0.40987400E+02, 0.16213900E+01, -.74898800E+01, 0.69468100E+01, 0.38611900E+02, 0.79732100E+00, 0.15206600E+03, 0.55881900E+02, -.58694400E+02, -.69759900E+01, -.40095500E+02, 0.26466000E+02, -.41541400E+02, -.24707700E+02, 0.19176000E+02, -.84971600E+01, 0.10796900E+02, -.27893500E+02, 0.47639600E+02, 0.50292300E+02, 0.11846600E+03, 0.14969500E+01, -.71082300E+02, -.13726600E+03, 0.22498200E+02, 0.46458500E+02, -.17289100E+02, 0.29509000E+02, 0.68885800E+02, 0.52780500E+02, -.37119300E+02, 0.14508000E+03, -.94588400E+01, 0.13779000E+02, -.24953800E+02, -.50307300E+02, -.11971700E+03, -.61820500E+01, -.61013700E+01, -.20408400E+01, -.47666700E+01, -.34237800E+01, 0.20274000E+01, 0.17269900E+02, 0.69672800E+01, -.38864200E+01, 0.57803000E+01, -.36680900E+02, 0.28779400E+02, 0.24760400E+01, -.24981800E+01, 0.35710300E+00, -.10929700E+02, -.31205400E+02, -.39138400E+01, 0.72718900E+01, -.17468000E+02, -.31724000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.96239500E+00, -.29281400E-01, 0.21198200E+01, 0.88002800E+01, 0.46329800E+00, 0.46012200E+00, -.26163300E+00, -.66920500E+00, -.10316400E+01, -.10702700E-01, -.27844200E+00, 0.80547200E+00, -.58945200E+00, 0.58289500E+00, -.36396000E+00, -.31248700E+00, -.15152600E+00, 0.91604900E+00, 0.30058200E+01, -.21585100E+01, 0.14075300E+01, -.23961700E-01, -.96137100E+00, 0.76281500E+00, -.76082900E+00, -.21019400E+01, 0.15063000E-01, 0.15166300E+00, -.80716800E-01, -.10057500E+00, 0.20419400E+01, 0.34197000E+00, -.98430600E+00, -.94335800E-01, -.13693000E+01, 0.56409900E-01, 0.10828900E+01, 0.80951800E-01, -.21007500E+00, -.50039100E-02, -.72954000E+00, -.20429300E+00, -.36022500E+00, -.42600000E+00, -.48326200E+01, 0.14824500E+01, 0.17410900E+01, 0.13699300E+00, 0.28652300E+00, 0.37610800E+00, 0.71312000E-01, -.16910300E+01, 0.66962100E+00, -.69821100E+00, -.41334900E-01, -.30011000E+00, -.62525900E+00, -.49719900E+00, 0.37156300E+00, 0.85900800E-01, -.37552000E+00, -.17004800E+00, -.31371000E+02, -.11681400E+01, 0.20962500E+03, 0.12423000E+03, -.61684600E+02, -.59365500E+02, 0.32518900E+02, 0.10388900E+03, 0.38074700E+02, -.53126200E+02, 0.44910500E+02, 0.22853800E+02, -.25767900E+02, -.14683900E+02, 0.11278400E+02, 0.54243400E+02, 0.37550600E+02, -.13096900E+02, 0.48881800E+02, -.13602600E+02, -.89336400E+01, 0.13997100E+01, -.33995200E+01, 0.96664700E+01, -.23786200E+02, 0.21339000E+01, 0.44395100E+02, -.66868200E+01, -.75765500E+01, 0.17840800E+01, -.41016200E+01, 0.77284400E+01, -.23127200E+02, 0.13894600E+01, -.58424000E+02, 0.22949400E+02, -.27349500E+02, -.19284700E+02, 0.13522600E+02, -.19676400E+02, 0.85743600E+02, -.12440600E+02, 0.97119600E+02, -.19415800E+03, 0.29306500E+02, -.60275800E+01, -.15105100E+02, 0.52837900E+02, -.12766600E+02, -.69261100E+01, 0.52245100E+02, -.18065000E+00, -.25496600E+02, 0.13224600E+02, -.82619700E+01, 0.54112900E+01, -.35538600E+02, 0.20025100E+02, -.15556600E+03, 0.34942200E+02, 0.15844500E+02, -.10214200E+02, 0.44415000E+02, -.31145100E+02, 0.33750200E+02, -.29795800E+01, 0.16872000E+00, -.15153800E+02, 0.14115900E+02, -.50413500E+01, -.12529600E+02, -.33728900E+02, -.77372200E+02, -.15739700E+02, 0.14364900E+03, 0.36563800E+02, -.60009700E+02, -.67991400E+02, 0.24394500E+02, 0.57809200E+02, 0.14806500E+02, -.76532800E+02, 0.55587200E+02, -.76978000E+02, 0.56912200E+01, 0.53765600E+01, -.64304200E+01, 0.34666300E+02, 0.55226500E+02, 0.18243300E+02, 0.22830300E+02, -.86000200E+01, 0.79647900E+01, 0.40777300E+01, 0.19699600E+01, -.51966900E+01, -.37509900E+01, 0.47897700E+01, -.10153400E+01, 0.12444200E+02, -.56460000E+01, -.88645100E+01, 0.28147600E+01, -.76106900E+01, 0.85121200E+00, 0.21984500E+02, -.12156200E+00, -.68223700E+01, 0.10068300E+02, 0.23592400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.61489400E+00, 0.29656200E-01, -.13442500E+01, -.53365800E+01, -.25335300E+00, -.26728900E+00, 0.27146000E+00, 0.49037300E+00, 0.58484300E+00, -.13289000E+00, 0.32709300E+00, -.11461700E+01, 0.13843700E+00, -.84130400E-01, 0.23540700E+00, 0.57185700E+00, -.33943600E+00, -.65225800E-01, -.57363800E+00, 0.32676800E+00, -.38060400E+00, 0.78153000E-01, -.29736800E+00, -.23105800E+00, -.30516300E-02, 0.11659400E+00, 0.35030500E+00, -.13612200E-01, 0.24382800E-01, 0.50633400E+00, -.25765900E+00, 0.20799400E+00, 0.64431800E+00, -.59494900E-01, 0.25884500E+00, -.23813500E-01, -.12384300E+00, -.95361300E-01, 0.15115600E-01, 0.52734800E-01, 0.79814200E+00, 0.37756400E-01, 0.12439900E+00, 0.10989900E+00, 0.21495500E+01, 0.53763700E+00, -.13741400E+01, 0.70038000E-01, 0.87059800E-01, 0.10583100E+00, -.18950100E+00, -.63814700E+00, -.10213400E+00, -.11820700E+00, -.15653400E-01, -.14455200E+00, 0.31908100E-01, -.16989100E+00, -.10833700E+00, 0.25356700E+00, 0.19266600E+00, 0.16944600E+00, -.24090200E+00, -.93744400E+01, 0.38763700E+02, -.15248800E+01, -.20667300E+02, -.16621200E+02, 0.60983400E+01, 0.25932700E+02, 0.11758200E+01, -.96576900E+01, 0.73009500E+02, 0.51493700E+01, -.25896800E+01, -.94677600E+01, -.12112000E+02, 0.22920600E+02, -.66077100E+01, -.87159900E+01, 0.21222200E+01, -.36472100E+01, 0.32375400E+01, 0.32279000E+00, -.18001100E+01, -.76435900E+00, -.43615500E+00, 0.66430300E+00, 0.17801900E+01, -.22219600E+01, 0.17577300E+01, 0.94606000E+00, -.23226500E+01, -.11818400E+01, -.45042600E+00, 0.79185900E+00, -.14096200E+02, -.20440500E+02, 0.22115500E+02, -.23179500E+00, 0.13866800E+01, -.79912300E+01, 0.81918000E+01, -.30736200E+01, 0.31558400E+02, 0.28355300E+02, -.29300600E+02, -.53459800E+01, -.71990200E+00, 0.11574400E+02, -.22490500E+02, -.34839700E+01, 0.39250900E+01, 0.21029400E+01, 0.15406100E+02, 0.70931500E+01, -.10894200E+02, -.66408400E+01, -.78453200E+01, 0.50984800E+01, -.33410700E+02, 0.15183000E+02, 0.30949800E+00, -.54354200E+00, 0.65031900E+01, -.21766500E+01, 0.70750100E+01, 0.12600100E+01, -.14316800E+01, -.53527800E+01, -.63715800E+00, 0.35604500E+01, -.44252200E+01, -.12238700E+02, 0.18927600E+01, -.13210800E+01, 0.20496000E+02, 0.10876700E+02, -.12130200E+02, -.87972300E+01, 0.50670800E+01, 0.12219000E+02, 0.10826500E+02, -.14602900E+02, -.95472800E+01, 0.98992000E+01, -.62959900E+00, -.66129600E+01, 0.12191200E+02, 0.28005100E+01, 0.84124400E+01, -.30437900E+01, 0.10788100E+01, -.28090600E+00, 0.22178000E+00, 0.30893800E+00, -.40598100E+00, -.70437700E+00, 0.74898400E+00, 0.15760800E+00, -.11290400E+01, 0.37880400E+01, -.14247600E+01, 0.17738300E+00, -.72615200E-01, -.29396800E+01, -.30916500E+01, -.35744600E+01, 0.28070300E+00, -.78678400E+00, 0.47138200E+01, -.16046700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.98924000E+00, -.72954700E-01, -.27905500E+01, -.47767600E+01, -.62680100E+00, 0.11961200E+01, 0.20816600E+00, 0.17321100E+01, 0.15142300E+01, -.17056000E+00, 0.76712500E+00, -.90312200E+00, 0.95215800E-01, -.71743400E+00, 0.72231800E+00, 0.12076200E+01, -.17768000E+01, 0.14568100E+01, 0.25289700E+01, 0.12025900E+01, -.24101400E+01, 0.60942900E+00, 0.67194100E+00, 0.10835900E+00, 0.22443800E+00, -.11166100E+00, 0.11036100E+00, 0.10655100E-01, -.14494300E+00, -.16765700E+00, 0.23149300E+01, 0.62841300E+00, 0.85255900E+00, -.72781400E-01, 0.53255600E+00, 0.11565400E+00, 0.60627300E+00, -.20800800E+00, -.11330700E-01, 0.39867400E+00, 0.21274500E+01, 0.35943900E-01, 0.53954700E+00, -.51024800E+00, -.11782500E+01, 0.57004600E+00, -.34330100E+01, 0.48566700E-01, -.99432400E-01, -.24926500E+00, 0.10650800E+00, 0.61050700E+00, 0.25411300E+00, -.23158500E+00, 0.86586900E-01, 0.33240300E+00, 0.46272800E+00, 0.13865100E+00, -.48324200E+00, 0.22513300E-01, -.21683700E+00, 0.77580900E+00, -.70421300E-01, 0.19804000E+00, -.28066400E+03, -.12166300E+03, 0.56833100E+02, 0.79117900E+02, 0.15806900E+02, -.13239700E+03, -.17384400E+02, 0.10796100E+03, 0.32381700E+03, 0.30511000E+02, -.61986000E+02, -.56211800E+02, -.49790200E+02, 0.12209900E+03, 0.15141200E+02, -.79949900E+02, 0.13730800E+02, -.54151900E+01, -.94313500E+00, 0.49043700E+00, 0.14308800E+01, -.25258100E+01, -.13786000E+02, 0.19570700E+01, 0.20980200E+02, -.15790800E+02, -.50993500E+01, -.12371100E+01, -.87221000E+00, 0.20036500E+01, -.99351000E+01, -.44880200E+01, -.53581600E+02, 0.22938900E+03, 0.15737600E+02, -.26503600E+01, 0.22124000E+02, 0.17752800E+01, 0.17545200E+02, 0.65756800E+01, 0.17359300E+03, -.95487000E+02, -.20336900E+02, -.30530000E+02, -.40260100E+02, 0.49174900E+02, -.18400500E+02, -.46967200E+02, 0.34662100E+02, -.80515500E+01, -.25826600E+02, 0.35165300E+01, -.96158800E+01, 0.57523800E+01, -.18159200E+02, -.14012200E+02, -.16130300E+03, -.86911000E+02, 0.33982500E+02, 0.16575600E+02, 0.10654400E+02, -.56397400E+02, 0.30682600E+02, 0.44442500E+02, 0.84245100E+01, 0.39540000E+02, -.81202600E+01, -.31730400E+01, -.91090500E+01, 0.58323500E+01, -.37349400E+02, -.44666000E+02, -.71051600E+02, -.83631300E+02, 0.19609200E+02, 0.26547300E+02, -.10568900E+02, -.38234400E+02, -.10914700E+02, 0.39722500E+02, 0.43545100E+02, 0.10108400E+03, 0.13215300E+02, -.36310100E+01, -.27098700E+02, -.92818400E+01, -.40421600E+02, -.10490600E+02, 0.10167600E+02, 0.30683800E+00, -.37127900E+01, -.82814300E+01, -.19729700E+01, -.67902500E+01, -.55712700E+01, -.85215700E+01, 0.31086000E+01, 0.12304400E+01, -.17239500E+02, -.39612000E+01, 0.14252300E+01, -.18532100E+02, -.80328800E+01, 0.13615900E+02, 0.18707600E+01, 0.11752900E+01, -.69031400E+01, -.16411200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20128900E+01, -.10297000E+01, 0.10452600E+01, 0.53856700E+01, -.28341600E+01, -.58916700E+00, -.26240400E+00, 0.45162500E+00, 0.14107500E+01, 0.22389700E+00, 0.20273900E+01, -.47444400E+00, -.18045500E+01, 0.74193500E+00, 0.54519900E+00, 0.20049300E+00, -.21060100E+01, 0.33537800E+01, 0.94341500E+01, -.44639300E+00, 0.25411300E+01, -.95888200E+00, -.31845900E+01, -.12454700E+01, -.23530400E+00, 0.20066300E+01, -.47230800E+01, -.14267800E+00, -.89892200E+00, -.26855300E+01, 0.39069600E+01, 0.32937700E+00, 0.20474600E+01, -.67600000E-01, 0.45620400E+00, 0.38757200E+00, -.25215900E+01, 0.45464300E-01, 0.65671000E+00, -.18014400E+00, 0.17468800E+01, -.58667400E+00, -.10537900E+01, 0.50290100E-01, -.10626500E+02, 0.22515400E+01, 0.28615700E+01, -.34720600E-02, -.41976000E-01, 0.68964500E+00, 0.65688600E+00, -.38181600E+01, 0.14579500E+01, -.18229400E+01, 0.38822600E+00, -.19728300E-02, -.83963700E+00, 0.29418500E+01, -.76591800E+00, 0.13671500E+01, 0.11764900E+01, 0.60539100E+00, 0.16170400E+01, 0.43208200E+00, 0.83277700E-02, -.24150300E+03, 0.37769700E+02, 0.64766300E+02, -.92623800E+02, -.67512800E+02, -.10383600E+03, 0.51696900E+02, 0.32639000E+03, -.18765000E+03, 0.47094700E+02, 0.63721800E+02, -.15677000E+03, 0.66895400E+02, -.16317000E+03, 0.83437400E+02, 0.61224700E+01, -.35887400E+01, 0.75120500E+01, 0.42147400E+01, -.20995300E+01, -.20488000E+01, -.18413800E+00, 0.33950800E+01, 0.53210400E+01, -.98935600E+01, 0.56463500E+01, 0.43265600E+01, 0.17706900E+01, -.44263000E+01, -.42037300E+01, 0.59836700E+01, -.13561500E+03, -.14527500E+03, 0.57777700E+02, 0.10259400E+02, -.58084100E+02, -.78150400E+02, -.10768600E+03, -.22640700E+02, 0.10022500E+03, 0.52922900E+03, -.81703400E+02, -.44796700E+02, 0.80948700E+02, 0.71912400E+02, 0.67347300E+02, -.18862200E+02, 0.44796600E+02, -.18521800E+02, 0.10507900E+02, 0.15800400E+00, -.28114300E+02, 0.16860900E+02, 0.10157300E+02, -.23031600E+01, 0.32469600E+03, -.14388200E+03, -.12200000E+03, -.17375800E+03, 0.90217100E+02, 0.13251000E+03, 0.39725300E+02, -.19868100E+03, -.28120200E+01, 0.44470200E+02, -.23506000E+02, -.17109800E+02, 0.37174100E+02, 0.20057200E+02, 0.26760800E+02, 0.59882000E+01, -.64084700E+03, 0.52831400E+03, 0.17231800E+03, 0.22751600E+03, -.39884600E+02, -.28225100E+03, -.12873000E+03, 0.22822100E+03, -.14759400E+03, 0.99852400E+02, 0.62295300E+02, 0.63962400E+02, -.33208400E+02, -.93527300E+02, -.62351500E+02, 0.48076000E+02, 0.34925400E+01, 0.88527600E+01, -.10578400E+02, -.79636300E+01, -.13294800E+00, 0.39426300E+01, 0.74234200E+01, -.12409700E+02, -.94886100E+01, -.25360200E+02, 0.14181800E+02, -.55672200E+00, -.82064400E+00, 0.39671100E+02, 0.22418200E+02, -.10558600E+02, -.54346600E+00, 0.77798500E+01, -.14484400E+01, -.27878500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16823900E+01, -.16863600E-01, -.10282100E+01, -.28914900E+01, -.12316300E+01, 0.28841500E+00, -.27969200E-01, 0.48443900E+00, 0.10519400E+01, -.70934800E-01, 0.13407400E+01, -.14637200E+01, -.66595200E-01, 0.93065700E-01, 0.58778200E+00, 0.35451600E+00, -.17797100E+01, -.64173200E-01, -.22649300E+00, 0.17636200E+01, -.32984000E+01, 0.12158600E+01, 0.30836000E+00, -.92194500E-01, -.79220600E-01, -.83638500E+00, -.89185600E+00, -.26373300E-01, -.28677500E+00, 0.10566200E-01, 0.27293800E+01, 0.12589700E+01, 0.29707900E+01, -.10012200E+01, 0.13287600E+01, -.14449200E+00, 0.87024800E+00, -.12217500E+00, -.18518100E-01, 0.81051600E-02, 0.14022000E+01, 0.15809000E+00, 0.17163000E+00, -.20907500E+00, -.29518700E+01, 0.18314800E+01, 0.11096500E+02, 0.22720300E+00, -.10365400E+00, -.65423000E+00, -.10328100E+01, -.43048500E+01, 0.65197200E+00, -.50260400E+00, 0.15593200E+00, -.11366700E+01, -.53270200E+00, 0.10508900E+01, 0.28815100E+00, 0.26072600E+00, 0.53609100E+00, 0.44748800E-01, 0.56020500E+00, -.22376100E+01, 0.11088800E+01, -.43615600E+00, 0.91444500E+02, 0.55270500E+02, -.51914500E+02, -.68335500E+02, -.75751000E+02, 0.61014800E+02, 0.56649400E+02, -.16380700E+01, 0.35637500E+00, 0.19656400E+01, -.86075700E+00, 0.39457500E+02, 0.13586600E+01, 0.16584900E+01, 0.10940200E+02, -.53012400E+00, 0.56606900E+01, 0.31041000E+01, -.71145500E+00, 0.73656000E+01, 0.52503100E+01, 0.25200600E+01, 0.86477100E+01, -.51542800E+01, 0.52441300E+01, 0.20591300E+01, 0.76893900E+00, 0.53018000E+01, -.10183100E+01, 0.19146800E+01, 0.12078500E+03, -.16217800E+03, -.27253600E+02, -.25560700E+02, -.97140000E+02, -.27379600E+02, -.86347300E+02, -.58122900E+02, -.43697700E+02, 0.30122200E+03, -.96124600E+01, 0.25854500E+02, 0.63283700E+02, 0.30641300E+02, -.32159900E+02, 0.56899900E+02, 0.27184200E+02, 0.69462300E+02, 0.41794900E+02, 0.10690700E+02, -.35731800E+02, 0.29887200E+02, -.20991500E+01, 0.37549000E+01, 0.22597600E+03, -.15432200E+03, -.83348100E+02, -.13613900E+03, 0.11909800E+03, 0.86972100E+02, 0.35695500E+02, -.13344000E+03, 0.37817300E+02, -.18029200E+02, -.73218700E+02, -.38785600E+02, 0.17941800E+02, 0.36288100E+02, 0.23582700E+02, -.35348900E+02, -.28032900E+03, 0.25959800E+03, 0.88612200E+02, 0.99719600E+02, -.27925100E+02, -.13381600E+03, 0.19299900E+02, 0.10474800E+03, -.38502400E+02, 0.41289100E+01, 0.56501100E+02, 0.55042700E+02, -.18211800E+02, -.54596500E+02, -.87168000E+02, 0.58012100E+02, 0.66990400E+01, 0.59418900E+01, -.76872900E+01, -.24977900E+01, -.33830300E+00, -.98996600E+01, 0.38068900E+01, -.43459100E+01, -.25858900E+01, -.70198500E+01, -.10192500E+02, -.33954400E+01, -.58634800E+00, 0.50943500E+02, 0.28630300E+02, -.62420400E+01, 0.15143800E+02, 0.11718300E+02, -.49385200E+01, -.20349800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.45586400E+00, -.22426700E-01, 0.76459300E+00, 0.25346200E+00, -.28587700E+00, -.64143200E+00, -.50436100E-01, 0.25976300E+00, -.76764600E-01, 0.51968400E-01, 0.54589500E-01, 0.17975400E+00, -.45740800E-01, 0.49073000E+00, -.14359500E+00, -.37920400E+00, -.14759800E+01, 0.58124900E-01, 0.40290600E+00, 0.39028800E+00, 0.97306000E-01, -.34712300E-01, -.16884700E+00, -.20876300E+00, 0.44260600E-01, -.28455200E-01, 0.11692200E+00, 0.13473200E-01, -.11680100E+00, 0.32740000E+00, 0.17869000E+00, 0.36316000E+00, 0.78598500E+00, -.38402800E+00, 0.38959800E+00, -.12507500E+00, -.71248400E+00, -.12583200E+00, -.97332900E-01, 0.18996100E+00, 0.71992900E-01, 0.12134100E+00, 0.23344900E-01, 0.76080800E-01, 0.17043500E+01, 0.23940100E+00, -.19203000E+01, 0.55776900E-01, 0.12871400E+00, 0.30523600E+00, 0.78764900E-01, -.40418900E+00, -.97523100E-01, -.30883600E+00, 0.40328100E-01, 0.25130800E+00, 0.35159600E+00, 0.17008800E+00, -.14270900E+00, -.35329200E+00, 0.50802500E-01, 0.20578300E+00, 0.42024300E+00, -.55813800E+00, 0.41891000E+00, 0.13433000E+00, -.12631600E-01, -.21011100E+02, 0.35424700E+01, 0.15926900E+02, 0.11264500E+02, -.39453200E+02, -.10768600E+03, 0.67517900E+01, 0.23744800E+02, 0.16702700E+02, 0.20913100E+02, -.66528600E+01, -.24977200E+01, 0.28581200E+02, -.22374700E+02, 0.36539400E+01, 0.72800800E+00, -.43000000E+01, 0.26338300E+01, 0.10104000E+01, 0.12120000E+02, -.55828100E+01, -.22955900E+02, 0.59023000E+01, 0.20225600E+01, -.34520500E+01, 0.47379800E+01, -.81272100E-01, 0.10024400E+02, -.23872400E+01, 0.41386600E+02, -.88258600E+02, -.25450000E+02, 0.24706700E+02, -.35353500E+02, -.22354900E+02, -.49640300E+02, 0.15554700E+02, -.10794500E+03, 0.86031000E+02, 0.52065600E+02, 0.17729200E+02, 0.27534200E+02, -.20943400E+02, 0.43787700E+02, 0.31327000E+02, -.23284900E+02, 0.17060800E+02, 0.64792300E+01, -.67416600E+01, 0.62255000E+01, 0.65382800E+01, 0.15722900E+02, -.34015500E+01, 0.18963800E+03, 0.66933800E+01, -.29351500E+02, -.22330300E+02, -.15572300E+02, 0.59047600E+02, -.22091100E+02, -.37949900E+02, 0.16133000E+01, -.40624300E+01, -.12169600E+02, -.73548600E+00, 0.12852800E+02, 0.55225800E+01, 0.12402300E+02, 0.18927900E+02, -.95259600E+02, 0.25931200E+01, 0.32703900E+02, 0.40501500E+02, -.97719100E+01, -.56171200E+02, -.30300400E+02, 0.36134500E+02, -.66295400E+02, -.20654100E+02, 0.31628700E+01, 0.29144900E+01, 0.20790900E+02, -.13189300E+01, 0.24466100E+02, -.92794800E+00, -.11180100E+02, 0.40840700E+01, -.57988800E+01, 0.43581200E+01, -.12885500E+01, 0.10075100E+01, 0.22981600E+00, 0.40037300E+01, 0.41088400E+01, -.25769300E+01, 0.83609500E+01, 0.28670900E+01, -.43152600E+00, 0.22219700E+02, 0.17010000E+02, -.61420700E+01, -.39780300E+01, -.68089200E+00, -.63805500E+01, -.19732500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.89050200E+00, -.66123200E-01, 0.49056500E-01, 0.16506000E+01, -.15345000E+01, -.49953100E-01, -.43812400E-02, 0.29894800E+00, 0.23050600E+00, -.24159200E+00, -.94913500E-01, -.49870000E+00, 0.21990000E+00, -.10935800E+01, -.20415200E+00, -.46927800E+00, 0.13349200E+01, -.44583400E+00, -.86642300E+00, -.64984700E+00, 0.44494900E+00, -.11403100E+01, 0.83230600E+00, 0.31828900E+00, 0.62041200E+00, 0.15705700E+01, 0.14062800E+01, -.37959600E-01, -.46107500E+00, -.79072700E+00, 0.25976800E+00, 0.32127300E-01, 0.69486500E-01, 0.23970200E+00, 0.78177500E+00, 0.33030100E+00, 0.92030400E-01, 0.11764200E+00, 0.69604400E-01, -.16721200E+00, 0.29679200E+00, -.11118600E+00, 0.18729400E+00, -.39859100E+00, -.34936700E+01, -.69886500E+00, 0.39726300E+01, -.14700100E-01, -.21769200E+00, -.35232500E+00, 0.50599000E+00, 0.65557000E+00, 0.26119700E+00, 0.12914300E+00, 0.73001400E-01, 0.37946100E+00, 0.40444400E+00, 0.74491100E+00, -.28197600E+00, -.23063400E+00, 0.21342000E+00, 0.14453000E+00, -.36877000E+00, 0.44829600E-01, 0.12936500E+00, 0.32590500E+00, 0.65370100E-01, 0.47599100E+00, 0.35765600E+02, -.17412700E+02, 0.52055000E+00, 0.27618200E+01, -.59552800E+02, 0.84229300E+01, 0.32911300E+01, 0.53769700E+01, 0.12860400E+02, -.30410100E+01, 0.25434000E+02, 0.49997800E+01, 0.26547600E+02, -.99049900E+01, -.57867300E+01, 0.27754100E+01, -.28573000E+01, 0.61688000E+01, -.10733300E+02, 0.31422800E+01, 0.26123500E+02, -.11856300E+02, -.52529500E+01, 0.24812000E+01, -.51885100E+01, 0.69455400E+01, -.10222000E+02, 0.16763100E+01, -.37783600E+02, 0.13259700E+03, -.58892700E+01, -.13924500E+02, 0.15338200E+02, 0.23662500E+02, 0.81031300E+02, -.19046800E+01, 0.25695800E+02, -.14023600E+03, 0.10121200E+02, -.88374700E+01, 0.22711400E+00, -.72698100E+01, -.41818200E+02, -.16767700E+02, 0.24433900E+02, 0.37202400E+01, -.72749100E+01, 0.87453300E+01, -.16722200E+01, 0.14763400E+02, -.13195200E+02, 0.10165000E+02, -.17669700E+03, 0.40419400E+02, 0.57051300E+02, 0.41848200E+02, -.86154700E+01, -.75978400E+02, -.47911300E+01, 0.44945400E+02, 0.19709300E+02, -.10778100E+02, -.14539900E+02, -.25334800E+02, -.31962300E+01, 0.13354900E+02, -.45963500E+01, -.35786400E+02, 0.19956200E+03, -.15248900E+03, -.54178400E+02, -.64877500E+02, 0.10403800E+02, 0.72202300E+02, 0.31256300E+02, -.66437600E+02, 0.12395900E+02, 0.91600000E+01, 0.10105300E+02, 0.11789800E+01, 0.15478500E+02, -.97620500E+01, -.34631700E+02, 0.39880800E+01, 0.13934300E+02, -.57176000E+01, 0.37900000E+01, 0.12511700E+01, 0.20963300E+01, -.21222100E+01, -.14819200E+01, 0.41871200E+01, 0.32923300E+01, -.21231100E+01, -.20860900E+01, -.60832200E+01, 0.76926700E+00, -.16122600E+02, -.70677400E+01, 0.94812300E+01, 0.32286700E-01, 0.36993200E+01, 0.43258100E+00, 0.13906300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10487800E+01, 0.31298700E-01, -.24022800E+01, -.11106700E+02, -.32439700E+00, -.79408700E+00, 0.46513400E+00, 0.70253900E+00, 0.97077600E+00, -.12332300E+00, 0.42897200E+00, -.13450300E+01, 0.13400200E+01, -.19064300E+01, 0.76197700E+00, 0.31449000E+00, 0.15224300E+01, -.10309200E+01, -.58919400E+00, -.65767700E+00, -.81808700E+00, 0.74934600E+00, -.50630100E+00, 0.31239200E+00, 0.13534400E+00, 0.82642200E+00, 0.20885800E+01, 0.65977600E-01, 0.43058400E-01, 0.98742900E+00, 0.12404100E+01, 0.11668300E+01, 0.32017500E+00, 0.22595500E+00, -.16264400E+01, -.94479000E+00, 0.10400000E+01, -.97751200E-01, -.68316000E-01, 0.68634500E-01, 0.11104700E+01, 0.71479800E-01, 0.54763100E-01, 0.33524400E+00, 0.35036400E+01, 0.12162600E+01, -.28862000E+01, 0.11308100E-01, 0.24886200E+00, 0.26223300E+00, -.89688400E+00, -.11139200E-01, 0.94305700E-01, -.67748500E-01, 0.30379200E-01, 0.50295500E+00, -.97686000E-01, -.73880200E-01, -.30910400E-01, 0.63243900E-01, 0.34182400E-01, 0.70080600E+00, 0.19227800E-01, -.43793700E+00, -.50672400E+00, -.17915300E+00, 0.67382300E-01, -.17503300E+00, 0.41522800E+00, 0.22854500E+02, 0.27646000E+02, 0.16924600E+02, 0.28045200E+03, 0.33056600E+02, -.89659700E+01, -.20588400E+02, -.56307600E+02, 0.13682400E+03, 0.21487800E+01, -.22981100E+02, 0.12284500E+02, 0.18862000E+01, 0.44363300E+00, -.11911100E+01, 0.29836500E+01, -.15322000E+01, -.15216900E+02, 0.15826000E+00, 0.15235800E+02, -.18624800E+01, -.25440800E+01, -.19947900E+01, 0.36576900E+01, -.27551800E-02, -.12775600E+02, -.29793200E+01, -.78809000E+02, 0.64939400E+02, -.13700700E+02, -.35293700E+01, 0.90783000E+01, -.28871800E+02, 0.26741700E+02, -.67935200E+01, 0.17914400E+03, -.53357000E+02, -.96477500E+01, -.17975800E+02, -.32858700E+02, 0.66528100E+02, -.12772300E+02, -.15109100E+02, 0.42728900E+02, 0.18059700E+02, -.24011500E+02, 0.53729500E+01, -.87294500E+01, 0.46817300E+01, -.30211300E+02, -.57032700E-01, 0.49010600E+02, -.48899500E+02, -.27451600E+02, -.56978800E+02, 0.37768800E+02, 0.53613700E+02, 0.39091700E+02, -.45190300E+02, -.18304200E+02, 0.28454000E+02, 0.34888500E+01, 0.16859300E+02, -.29531100E+01, -.39204000E+02, -.89877800E+02, -.30308200E+01, -.74194700E+02, 0.71112800E+02, 0.12231500E+02, 0.24877900E+02, -.16594800E+02, -.51849700E+02, -.17340900E+02, 0.24509900E+02, -.13520600E+02, 0.96256500E+01, 0.24980700E+02, 0.21736200E+02, -.31629800E+02, -.17839000E+01, 0.57824800E+01, 0.24741500E+02, 0.70400900E+01, 0.22718400E+00, -.42108900E+01, -.19829400E+01, -.19015100E+01, -.80057200E+01, -.60327500E+01, -.42280600E+01, 0.36473300E+01, 0.10190100E+02, -.89634000E+01, -.23586500E+01, 0.22637000E+01, 0.12600900E+01, 0.25897300E+01, 0.17359800E+02, -.47807500E+01, -.81740300E+01, -.52346900E+00, -.42183200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.72411900E+00, 0.20492900E-01, 0.33455800E+00, 0.15897900E+01, -.15722300E+01, -.10117000E+01, -.96233600E-01, 0.57483000E+00, 0.39390500E+00, 0.20445700E+00, 0.42874100E-02, 0.28790400E+00, -.15872300E+00, -.40856800E+00, -.87215200E-01, 0.21764500E+00, -.45859200E+00, -.27352700E+00, 0.50005700E+00, 0.54517000E+00, -.34444900E+01, 0.14847000E+01, 0.15233900E+01, 0.10006500E+01, 0.75876600E-01, 0.22093500E+00, -.70052100E-01, 0.15375700E-01, 0.22651900E+00, -.10893100E+00, -.24532600E+00, -.90935800E+00, -.87118900E+00, 0.72575200E-02, -.84251200E+00, -.52599300E-02, 0.51725100E+00, 0.32690900E-01, -.71060600E-01, 0.20419900E+00, -.81218900E+00, 0.54559700E-02, 0.12393400E+00, -.15417400E+00, 0.23146600E+01, -.11842700E-01, -.63140200E+01, 0.44768300E-01, 0.10844700E+00, 0.93664300E-01, -.68025100E+00, 0.84292800E+00, 0.33809700E-02, -.33863400E+00, -.24073600E-02, 0.76237700E+00, -.13556800E+00, 0.47418300E+00, 0.88713600E-01, -.28503200E+00, -.26846800E+00, -.97264500E-01, 0.38447900E+00, -.54737900E+00, 0.46493100E+00, 0.46321700E-01, -.52632200E-01, 0.11906900E+01, 0.31304400E+00, -.46244000E+00, 0.16679200E+02, 0.23688100E+02, 0.17756500E+03, 0.38380200E+02, -.59449700E+02, -.62946500E+02, 0.87537900E+01, 0.73439200E+02, 0.57313500E+02, -.77958000E+02, 0.92574600E+01, 0.53002500E+01, 0.78312100E+00, -.11955300E+00, 0.37684000E+01, -.36953900E+01, -.10859300E+02, 0.76773600E+00, 0.15089500E+02, -.26442500E+01, -.23886400E+01, -.15796700E+01, 0.18004200E+01, -.33699300E+00, -.10596400E+02, -.35773800E+01, -.84718500E+02, 0.90036600E+02, 0.10346400E+02, -.13143800E+02, 0.43214200E+02, -.77807700E+01, 0.67346200E+02, -.12344200E+02, 0.21896500E+03, -.14199800E+03, -.51960800E+02, -.17412800E+02, -.58600600E+02, 0.57433300E+02, -.89563300E+02, -.23684600E+02, 0.24068000E+02, 0.19091600E+02, -.87628700E+01, 0.75521700E+01, -.84634400E+01, -.48800200E+01, -.27638500E+02, 0.13203300E+01, -.66589800E+02, -.17518000E+02, 0.56300600E+01, -.85215200E+01, 0.27249500E+02, -.10624500E+02, 0.24717500E+02, 0.14848600E+02, -.95304900E+01, 0.21013300E+02, -.84601300E+00, 0.86255800E+01, -.39230800E+01, -.15057300E+02, -.57461900E+02, -.17177800E+02, 0.12677700E+03, -.42314600E+02, -.43183600E+02, -.56080300E+02, -.36041800E+00, 0.71213600E+02, 0.82622900E+02, -.51067500E+02, 0.81121000E+02, -.59757400E+01, 0.36235500E+01, 0.16609700E+01, -.37246900E+02, 0.13176900E+02, -.15582900E+02, 0.92554100E+01, 0.68629800E+01, -.12489500E+01, 0.62234300E+00, -.45783900E+01, -.19319000E+01, -.77319400E+01, -.54857500E+01, -.56129000E+01, 0.16520800E+01, 0.78693000E+01, -.17710000E+02, -.18141000E+01, 0.16835600E+01, -.18515800E+02, -.13419200E+02, 0.12621300E+02, 0.31691400E+00, -.41919700E+01, 0.38320600E+01, -.84219900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.33155900E+01, -.12331600E+01, 0.58402000E+00, 0.18801900E+01, -.20531500E+01, -.20119200E+01, 0.23102200E+00, -.69737700E+00, -.17092700E+01, -.10879400E+01, 0.93487600E+00, -.76868400E+00, -.10733300E+01, 0.41280200E+00, -.23109500E+00, -.19346200E+01, 0.18428100E+00, 0.14815900E+01, 0.28453900E+01, -.28767000E+00, 0.29468300E+01, -.24877300E+01, -.11830700E-02, -.91368900E-01, 0.49713500E+00, 0.23001000E+01, -.26177200E+01, -.73535200E-01, -.24763100E+00, -.23353600E+01, 0.14838900E-01, -.75508600E+00, -.17254800E+00, 0.87057700E+00, 0.19765800E+01, 0.95643500E+00, -.18485800E+01, 0.10435800E+00, 0.75475600E+00, 0.30389200E-01, 0.12089000E+01, 0.16472200E+00, 0.79657300E+00, 0.45565400E+00, 0.11035000E+02, -.88903600E+00, 0.33168000E+01, 0.14672700E+00, 0.18860100E+00, 0.20246800E+00, -.38474500E+00, -.16822100E+00, -.54380000E+00, 0.21996600E+01, -.68064900E-01, 0.10005400E+00, -.58192800E+00, 0.13595800E+01, -.49625700E+00, 0.96201000E+00, 0.16444500E+01, 0.11238800E+01, -.10357000E+01, 0.21049000E+01, -.45680000E+00, -.37926500E+00, 0.13504000E+01, -.12724000E+01, -.24614400E+00, 0.15104400E+01, -.48248500E+00, -.93135700E+02, -.71768500E+03, -.22997100E+03, 0.20217800E+03, 0.21376600E+03, -.25121300E+02, -.41554200E+03, -.17397700E+03, 0.26052000E+03, -.48337600E+02, 0.10057200E+02, -.79497600E+01, 0.50174500E+00, 0.18101000E+01, -.88842700E+01, 0.32358400E+02, -.37287500E+01, -.60348000E+02, 0.27150500E+02, 0.32162100E+01, 0.70417200E+01, 0.80105300E-01, -.15493700E+02, 0.35575200E+02, 0.13389400E+02, 0.50448100E+01, -.27551200E+03, 0.64224900E+02, 0.27222300E+02, 0.15065900E+03, 0.14913700E+03, 0.81158000E+02, 0.80373600E+02, -.24262000E+03, 0.11423300E+03, -.73342600E+02, -.10183700E+03, 0.48955500E+02, -.13126700E+03, 0.13984600E+03, -.13872700E+03, -.77252900E+02, -.81643600E+02, 0.41877100E+01, -.24029700E+02, 0.66688300E+02, -.16408500E+02, 0.81179900E+02, 0.16900800E+02, -.11578300E+03, 0.41474600E+03, 0.13975200E+03, 0.20151800E+03, -.21961100E+03, -.11511100E+03, -.13001900E+03, 0.10322300E+03, -.36563500E+02, -.21643000E+02, 0.48526900E+02, 0.35509100E+01, 0.14249800E+02, 0.18737600E+02, 0.15410300E+03, 0.10075700E+03, 0.37970300E+03, -.10374400E+03, -.83216800E+02, -.10133700E+03, 0.11108300E+02, 0.17526300E+03, -.12006900E+03, -.12874400E+03, -.90248900E+02, -.11699300E+03, -.10737100E+02, -.27600600E+02, 0.75482100E+02, -.16461400E+02, 0.53600100E+02, -.52486700E+02, -.30895500E+02, -.53934600E+01, 0.59837600E+01, 0.14363800E+02, 0.77860700E+01, 0.38450900E+02, 0.19171900E+02, 0.24110600E+02, -.75539600E+01, -.30086200E+02, 0.61904600E+02, 0.12796600E+02, -.54309600E+01, -.67571200E+02, -.37285900E+02, -.33939700E+02, -.25645200E+02, 0.74820600E+01, 0.17393500E+02, 0.32879800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.12064600E+01, 0.58207700E-01, 0.75756400E-02, 0.31252200E+01, -.14028500E+01, 0.21655600E+00, -.10920000E-01, -.10536500E+00, 0.38769000E+00, -.23061700E-01, 0.11497500E+00, -.73862800E+00, -.12361800E+00, -.11656300E+00, -.20615100E+00, 0.46994800E+00, 0.13364700E+01, -.50358500E+00, -.23921800E+01, -.51275300E+00, 0.94203200E-01, -.71742000E+00, -.11727800E+01, -.30784600E+00, 0.16458100E+00, 0.24606600E+01, 0.28614700E+01, -.14811300E-01, -.46272600E+00, 0.14486500E+01, 0.99309200E+00, -.87160200E-01, 0.77423100E+00, -.60246700E+00, -.49730000E+00, -.21331300E+00, 0.27986200E+00, -.29198300E-01, -.40812600E-01, 0.14892200E+00, -.66044500E+00, 0.17022700E+00, 0.12624500E+00, -.98358000E-01, 0.18623600E+00, 0.37720300E+00, -.11403500E+01, 0.11659300E+00, 0.71313300E-01, 0.12130800E+00, -.34207600E+00, -.84835300E+00, -.12166800E+00, -.33702600E+00, -.84774400E-01, -.87872800E-01, 0.12526500E+00, -.66955000E+00, 0.14813200E+00, -.20994000E+00, -.31024000E+00, -.19144800E+00, 0.12173200E+00, -.16051100E+00, 0.32330500E+00, -.36178700E+00, 0.69289900E-01, 0.56861800E+00, -.43592100E+00, -.52072500E+00, 0.26625300E+00, -.23999000E-01, 0.19345100E+03, -.59437200E+01, -.15577400E+02, -.17397600E+02, -.42827100E+02, 0.93284000E+02, -.91752400E+01, -.99933800E+01, 0.11624500E+02, -.33973000E+01, -.20491300E+01, -.12116800E+01, 0.37411000E+01, 0.11664300E+01, -.72574400E+01, -.47969900E+00, 0.13605300E+02, -.49095100E+01, -.35942200E+01, -.68576900E+00, 0.24708700E+01, 0.11992000E+01, -.10934100E+02, -.97192300E+00, -.16700600E+03, 0.15309600E+02, 0.67741800E+01, 0.11954600E+02, 0.38051100E+02, -.61158100E+02, 0.39978600E+02, 0.73943300E+01, 0.17665500E+03, 0.10278200E+02, -.17108700E+02, -.37476200E+02, -.86175300E+01, 0.73926000E+02, -.18852900E+02, -.30877700E+02, 0.46831400E+02, 0.18160900E+02, -.22740200E+02, 0.46469800E+01, -.13923000E+02, 0.94122500E+01, -.18377100E+02, 0.29641900E+01, 0.31784900E+02, -.49378200E+02, -.34678400E+01, -.46626900E+02, 0.41485800E+02, 0.23912500E+02, 0.29898600E+02, -.43333900E+02, -.86674100E+01, 0.27683400E+02, -.17013200E+02, -.49689200E+01, 0.82695200E+01, -.17121800E+02, -.52606000E+02, -.11698300E+02, -.11819900E+03, 0.15959100E+03, 0.17869200E+02, 0.37398800E+02, -.61593200E+01, -.59449400E+02, -.17540500E+02, 0.31864500E+02, -.35129100E+02, 0.26740300E+01, 0.33344300E+02, 0.13105200E+02, 0.20332600E+00, -.62355800E+01, 0.22958500E+02, 0.17987600E+02, 0.68204000E+01, -.10204300E+01, -.32071100E+01, 0.16153100E+01, -.59150100E+00, -.44560100E+01, -.22276600E+01, 0.32599300E+00, 0.67398700E+00, 0.73041000E+00, -.18973700E+01, -.31322700E+01, 0.16561100E+01, -.26089100E+01, 0.38232400E+01, 0.12967200E+02, -.12638100E+00, -.17274200E+01, 0.27259100E+01, -.14685900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27217500E+01, 0.12954300E+01, -.29535100E+00, -.57220300E+01, 0.27091600E+01, 0.85463700E+00, -.48185200E+00, 0.82373800E+00, 0.26384500E+01, 0.13774900E+01, -.50930800E-01, 0.64356700E-01, 0.22527000E+01, -.44240700E+01, 0.72230100E+00, -.17168100E+01, 0.47766600E+01, -.40994000E+01, -.73279200E+01, -.44232200E+01, 0.16304800E+01, 0.26282400E-01, -.37747100E+01, -.90027700E+00, -.60256400E+00, 0.31503600E+01, 0.51694500E+01, -.57671000E-01, 0.70343000E+00, 0.28466200E+01, -.43955100E+01, -.25010700E+01, -.12965600E+01, -.12637300E+01, -.33163100E+01, -.14727700E+01, -.14283500E+01, -.85278200E+00, -.13559300E+00, 0.32402700E+00, 0.94673700E+00, -.34666800E-02, 0.89311000E+00, 0.26529900E-01, 0.79392600E+01, 0.41722800E+00, -.99877100E+01, -.31106300E+00, -.35269700E+00, -.11960400E+01, -.27718900E+01, 0.96100200E+00, 0.70923200E-01, 0.11339200E+01, 0.99659100E-01, 0.25232400E+01, 0.35761600E+00, -.22949100E+01, 0.96508400E-02, -.59008900E+00, -.15010300E+01, 0.10539300E+01, -.97472500E+00, -.20975800E+01, -.17549300E-01, -.72826400E+00, -.73232900E+00, -.89714100E+00, 0.35133500E+00, -.35121400E+00, 0.52897500E+00, -.71711800E+00, 0.14685700E+01, 0.10071000E+03, 0.21861800E+02, 0.47425700E+02, -.36635600E+02, 0.27983900E+02, -.18856300E+02, 0.48618200E+02, 0.31819600E+02, -.83940800E+01, -.82502400E+01, 0.56341500E+00, -.80275400E+01, 0.12030500E+02, -.16122300E+02, 0.96839900E+00, 0.27381500E+02, -.76302800E+01, -.25685900E+01, 0.31642000E+01, -.50936500E+01, 0.94702100E+01, -.92468400E+01, 0.32305600E+01, 0.12591200E+03, 0.11288600E+03, -.58675200E+02, -.40102200E+02, -.15364300E+02, 0.48427200E+02, 0.41376600E+02, -.28994200E+02, -.38050300E+02, -.15690100E+03, 0.42825200E+02, -.43871700E+01, 0.18777200E+02, 0.87033700E+01, 0.45117600E+02, -.84244000E+01, 0.39513900E+01, -.34324900E+02, 0.33032600E+01, 0.11805700E+02, 0.85144700E+01, 0.17151800E+02, -.48364000E+01, 0.14753500E+02, -.40193500E+02, 0.13064600E+03, -.99158500E+01, -.18989000E+02, -.16825500E+02, -.22083000E+02, -.24962000E+02, -.28565800E+02, 0.64769900E+01, -.34276800E+02, 0.13990500E+02, -.69125600E+01, 0.16677000E+02, -.29991900E+01, -.47471600E+01, -.11381800E+02, -.40974400E+02, -.15316500E+00, 0.10761800E+02, 0.11173300E+02, -.66535800E+01, -.49831800E+02, -.43473100E+02, 0.10390000E+01, 0.16844000E+02, -.36430700E+02, -.88099100E+01, 0.10018000E+02, -.16728900E+02, 0.58770200E+01, 0.67700000E+01, 0.11352400E+02, 0.15106500E+02, -.67644000E+01, 0.59525800E+01, 0.52910600E+01, 0.27321400E+01, 0.39153400E+01, 0.30280500E+00, 0.70799800E+01, 0.18542900E+01, -.60814700E+01, 0.63172100E+01, -.67663600E+01, 0.91885600E+00, 0.12389300E+01, 0.63699700E+01, 0.26569800E+01, -.11217900E+02, -.21560100E+00, 0.47168800E+00, 0.13648900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10958700E+01, -.72580100E-01, -.28316900E+01, -.50711900E+01, -.92779000E+00, 0.12281000E+01, 0.25317900E+00, 0.12741700E+01, 0.97069300E+00, -.14903300E+00, 0.27052200E+00, -.46502200E+00, 0.16822400E+00, -.10087200E+01, 0.44290700E+00, 0.50760400E+00, -.31039800E+00, 0.10090800E+01, 0.18541600E+01, 0.17563400E+00, -.53746000E+00, -.22144600E+00, 0.16392700E+01, 0.59453600E+00, 0.45239300E+00, -.94058600E-01, 0.11197600E+00, 0.24758900E-01, -.16891500E+00, -.84861800E+00, 0.68654100E+00, -.12956900E+00, 0.15808700E+00, 0.29220000E-01, 0.68511200E-01, 0.10637500E+00, 0.56732500E+00, -.41937000E-01, 0.83244800E-01, 0.12633800E-01, 0.79608700E+00, -.12774000E-01, 0.29334600E+00, -.52508500E+00, -.28687800E+01, 0.55058800E+00, -.10521200E+01, 0.14053600E+00, 0.60559700E-01, 0.10954600E+00, 0.46858000E+00, -.59186700E-01, 0.23360400E+00, -.38588700E+00, 0.39937300E-01, 0.61252700E-01, 0.39082800E+00, 0.51500000E-01, -.35195900E+00, 0.21054600E-01, 0.25720900E-01, 0.45757900E+00, -.34262200E-01, 0.15921700E+00, 0.68263600E+00, 0.32279700E+00, -.16159500E+00, 0.61457000E+00, 0.26239500E+00, 0.13458000E+00, 0.42628600E+00, 0.27714500E+00, 0.57298400E-01, 0.31457200E+00, -.52482300E+02, -.56116500E+02, 0.60096100E+02, 0.17964000E+02, 0.53300600E+02, -.64106700E+02, -.52492700E+01, 0.38263100E+00, 0.48579400E+01, 0.48286500E+00, -.94797800E-01, -.96411300E+00, 0.46129500E+01, -.78630000E-01, -.26621900E+01, -.56797600E+00, 0.15945000E+01, -.13781500E+01, 0.19549600E+00, 0.36785200E+00, 0.32804300E-01, -.20791500E+01, 0.22044500E+02, -.22116500E+02, 0.32642400E+01, 0.10750700E+01, -.41553300E+02, -.35263500E+02, -.47138900E+02, -.15641200E+02, -.90113200E+02, 0.40250200E+02, 0.17428800E+02, 0.46351900E+02, 0.96607900E+01, -.25363900E+02, -.29895300E+02, 0.58564400E+02, -.16084500E+01, 0.32301600E+02, 0.11940500E+02, 0.21683700E+01, -.17277300E+02, -.55245300E+01, -.93354700E+01, -.33400900E+01, 0.77482000E+02, -.95270600E+02, -.29014300E+02, -.28695900E+02, 0.37362000E+02, 0.31113300E+02, 0.21973500E+02, -.16398500E+02, 0.10587600E+02, 0.64384900E+00, -.17346700E+02, -.69747700E+01, -.43737300E+01, 0.84153200E+01, -.34784500E+00, -.88024500E+01, -.92608300E+02, 0.27962000E+01, 0.27683100E+02, 0.25858200E+02, 0.11557100E+02, -.20032500E+02, 0.44192900E+02, 0.33474100E+02, 0.20155200E+02, -.91500500E+01, -.86111300E+01, -.95072700E+01, 0.67585900E+01, 0.11864100E+02, 0.83585400E+01, -.11708700E+02, -.13777600E+01, 0.27212000E+01, -.67956600E+00, -.70977200E+00, -.14907200E+01, -.73450400E+01, -.18314700E+01, -.27391900E+01, -.32959900E+00, 0.46973900E+01, -.12377000E+02, 0.53299200E+00, 0.86022900E-01, 0.18999100E+02, 0.62125800E+01, 0.39809900E-01, 0.82666100E+01, 0.23611700E+00, -.64358100E+01, -.14425300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11903400E+01, -.37764300E-01, -.13560000E+00, 0.24976600E+01, -.12785600E+01, -.50828200E+00, 0.25051100E-01, -.39475700E+00, -.17904000E+00, -.21881600E+00, 0.18021300E+00, -.88884100E+00, 0.13092400E+00, -.66771900E+00, -.14511000E+00, -.15007900E+00, 0.15870600E+01, -.67246900E+00, -.15515600E+01, -.68582900E+00, -.23991000E+00, -.37341700E+00, -.73845000E+00, 0.21217900E+00, 0.10936000E+00, 0.17191000E+01, 0.20372600E+01, 0.29141000E-01, -.17033200E+00, 0.11683200E+01, -.14804100E+00, -.65871200E+00, 0.47629100E+00, -.43382000E+00, -.88257000E+00, -.10844400E+00, -.57884500E+00, -.52983400E-01, -.53300500E-01, 0.16400000E+00, -.34137700E+00, 0.47657600E-02, 0.41449900E-01, 0.12472700E-01, 0.13313400E+01, -.65400400E+00, -.94457700E+01, -.13690300E-01, -.33352700E+00, -.54039300E+00, -.22695300E+00, 0.24472100E+01, -.11568200E+00, 0.30326000E-01, 0.17046000E+00, 0.73054200E+00, -.11767700E+00, 0.10749400E+01, -.40031600E+00, -.36102000E+00, -.54799000E+00, 0.37932200E+00, 0.22050500E+00, -.13529900E+01, 0.47996200E+00, -.98080200E-01, 0.22095200E+00, 0.12151300E+01, 0.49707300E+00, 0.83812900E+00, -.58495600E+00, -.11974900E+00, 0.14104200E+00, -.12902000E+00, 0.80155100E+00, 0.23018000E+02, -.37962300E+02, -.48101100E+02, -.31485500E+02, 0.26236400E+02, 0.57337900E+01, -.12730500E+00, -.99425800E+00, -.23870600E+00, 0.19867800E+01, -.26855200E+01, -.36353000E+01, -.29989900E+00, 0.66466000E+01, -.22175500E+00, -.34087500E+00, 0.28257100E+01, -.24676400E+01, -.26544500E+01, -.27894200E+01, 0.25382200E+01, -.10619300E+03, 0.96176800E+01, 0.59370000E+02, -.35550300E+01, 0.11351700E+03, 0.25998200E+02, 0.95736800E+02, 0.14516700E+02, 0.18705900E+03, -.66791400E+02, -.10588900E+03, -.75087000E+02, -.47827100E+02, 0.47712000E+02, -.99245300E+01, -.93467000E+02, 0.22890800E+02, -.24373400E+02, -.31605000E+01, 0.82752200E+01, -.46262400E+00, -.75563500E+01, -.77151100E+01, 0.12728100E+02, -.28715600E+03, 0.13428800E+03, 0.75133200E+02, 0.71596200E+02, -.10792700E+02, -.11743500E+03, -.86503000E+01, 0.66135300E+02, -.27202300E+02, 0.25272700E+02, 0.14664100E+02, 0.58783700E+01, -.35961200E+01, -.13547600E+02, 0.45500900E+01, 0.15808100E+01, 0.18764800E+03, 0.46098900E+02, -.67312100E+02, -.75572400E+02, 0.51118500E+01, 0.10346900E+03, 0.14945600E+02, -.84695100E+02, 0.23701900E+02, -.14620100E+02, 0.23096600E+01, -.78077000E+01, -.12270600E+01, 0.45170900E+01, 0.32531600E+02, -.23329400E+01, 0.27222300E+01, -.60540600E+01, 0.90445700E+01, 0.14532900E+01, 0.10844600E+01, 0.69012200E+01, 0.29580100E+01, 0.32430100E+01, -.46098800E+01, -.56896400E+01, 0.60190400E+01, -.73478600E-01, -.45395200E+00, -.47149800E+02, -.28603100E+02, -.50843100E-01, -.96415300E+00, 0.12851200E+01, 0.16451900E+02, 0.14119300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17370200E+01, 0.31188400E-01, 0.38365400E+01, 0.16633900E+02, 0.58747100E+00, 0.86270000E+00, -.54680400E+00, -.90012200E+00, -.18888400E+01, 0.17966100E+00, -.38897800E+00, 0.23817700E+01, -.11939200E+01, 0.19987100E+01, -.79283900E+00, -.65488600E+00, 0.46320800E+00, 0.21398800E+00, 0.74845300E+01, -.13918000E+01, 0.36880400E+01, 0.25010700E+00, 0.12502100E-01, 0.13219400E+01, -.69221400E+00, -.27579100E+01, -.98192400E+00, 0.26095100E+00, -.25137600E+00, -.95307100E+00, 0.62914000E+01, 0.13415100E+01, -.24741100E+01, 0.89873300E-01, -.11097700E+01, 0.71348500E+00, 0.16736000E+01, 0.13732800E+00, -.62645700E+00, 0.80024800E+00, -.38653800E+01, 0.13711200E-01, 0.13471500E+00, -.57786400E+00, 0.12957900E+01, -.16916700E+01, 0.52736300E+01, -.14318000E+00, 0.41134400E-02, 0.14106900E+00, 0.11426600E+01, 0.15819400E+01, 0.30171700E+00, 0.13756000E+01, 0.70094300E-01, 0.33185500E+00, -.44544800E+00, 0.29288400E+00, 0.83000300E+00, -.74056300E+00, -.63390900E+00, -.90920600E+00, 0.67820200E+00, -.51776300E+00, -.46429800E-01, -.49117800E+00, 0.38722000E+00, -.16953200E+01, -.42506600E+00, -.45285400E+00, -.12911400E+01, -.12892000E+00, -.35728900E+00, 0.50035200E-01, -.97179200E+00, -.85947700E+00, -.28607700E+02, -.60709600E+02, -.24220900E+02, -.46119300E+01, -.84021200E+00, -.30029900E+01, 0.37623300E+01, -.17455200E+01, 0.46694000E+01, -.34164300E+01, 0.48468500E+01, -.24180500E+01, 0.13885500E+01, -.76533800E+00, 0.20879900E+01, 0.12756300E+01, -.19470800E+01, -.38604400E+01, 0.22069200E+00, 0.82720200E-01, -.24641900E+03, -.53592800E+02, 0.84218600E+02, 0.18284900E+02, 0.12698900E+03, -.45115500E+02, 0.80594600E+02, 0.34974600E+02, 0.25517700E+03, 0.35692400E+02, -.11531500E+03, -.53869500E+02, -.77106000E+02, 0.70048300E+02, -.54626200E+02, -.71697600E+02, 0.40857200E+02, -.31569200E+01, 0.14871700E+02, 0.10528600E+02, -.25636200E+02, -.11397700E+02, -.15043800E+02, 0.11469700E+02, -.27891600E+03, 0.65528400E+02, 0.77786600E+02, 0.67778100E+02, 0.17269000E+02, -.10837900E+03, 0.14002500E+02, 0.66488100E+02, -.20436400E+02, 0.28486800E+02, -.83549700E+00, 0.53131500E+01, -.15834500E+02, -.12507400E+02, 0.77947100E+01, -.11276000E+01, 0.27612900E+03, 0.68664000E+02, -.97704400E+02, -.10488600E+03, 0.62983400E+01, 0.15790300E+03, 0.62363600E+02, -.10866000E+03, 0.57791400E+02, -.27848400E+02, 0.11085300E+01, -.18390000E+02, 0.62965200E+00, 0.19276900E+02, 0.35196000E+02, -.14804600E+02, -.12249500E+00, -.23897600E+01, 0.60835400E+01, -.69862300E+00, -.90087700E+00, 0.18672000E+01, 0.28689400E+01, -.45644200E+00, -.49732700E+01, -.13724000E+01, -.19602700E+01, 0.98284900E+00, -.46608600E+00, -.42758100E+02, -.26162300E+02, -.37927000E+01, 0.65696900E+01, 0.22148200E+01, 0.18601000E+02, 0.10579400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23931000E+01, -.75590000E-01, -.49396300E+01, -.10899800E+02, 0.93513900E+00, -.17195300E+00, -.36260900E+00, 0.93652500E+00, 0.11351200E+00, -.10658200E+00, -.18783600E+01, 0.83553600E+00, 0.20607100E+01, -.22153300E+01, 0.27185600E+00, -.11864200E+01, 0.27765300E+00, 0.55663100E+00, 0.28770200E+01, -.19598800E+01, 0.22844000E+01, -.10188300E+01, 0.32691500E+01, 0.15005900E+01, 0.79032500E+00, -.58159000E+00, 0.78424400E-01, 0.74309500E-01, 0.17605100E+00, -.10563800E+01, -.39797100E+01, -.68082700E+00, -.13638300E+01, 0.84560300E+00, -.10867600E+01, -.23214700E-01, -.23668000E+00, 0.26386900E+00, 0.13070300E+00, -.75603000E+00, -.16632500E+01, -.43807400E-01, 0.24200500E-01, 0.43136800E+00, 0.84657300E+01, -.25040000E+01, -.83116000E+01, -.22236000E+00, 0.14844700E-01, 0.72897000E+00, 0.36384300E+00, 0.37032600E+01, -.13053000E+01, 0.19386300E+00, -.17398500E+00, 0.20456100E+00, 0.68589900E+00, -.10726000E+01, -.80249600E-01, -.30567100E+00, 0.14955500E+00, -.18657500E+00, -.30770700E+00, 0.78120400E+00, -.62524500E+00, 0.45538100E+00, -.44571200E+00, 0.56802000E-01, -.24759800E+00, 0.66201300E+00, -.33706000E+00, 0.25291700E+00, -.50206300E+00, -.25812000E+00, 0.94658000E+00, 0.23653700E+00, -.72776500E-01, -.45518200E+02, 0.56966500E+00, -.33833100E+01, 0.11134100E+01, 0.33234800E+01, -.67519100E+00, -.24762300E+00, 0.24432600E+00, -.31591400E+01, -.19917400E+01, 0.42448900E+00, 0.17049900E+01, 0.55904900E+00, 0.51911800E-01, -.68510700E+00, 0.11447700E+01, -.19208500E+01, 0.31615500E+01, -.19674600E+00, 0.66627100E+02, 0.40623000E+02, -.14527700E+01, -.11773600E+02, -.21860900E+01, 0.64000700E+02, 0.27809700E+02, -.15617800E+01, -.13598300E+03, -.46200100E+02, -.12173000E+02, -.12505200E+01, 0.36171700E+02, -.63889200E+02, 0.54152600E+01, -.10532100E+02, -.17314300E+02, -.13122600E+02, 0.60783800E+01, -.12910500E+01, 0.15999600E+02, -.77227100E+01, 0.56562900E+01, 0.75317300E+00, 0.15440900E+02, 0.52468100E+02, 0.94664300E+01, 0.16600900E+02, -.38220900E+02, 0.32418400E+01, -.27904000E+02, 0.14933100E+02, -.65808400E+01, -.11223700E+02, 0.16957300E+02, 0.25710800E+01, 0.93391500E+01, -.55076100E+01, 0.85775500E+01, 0.37758800E+01, 0.26887900E+02, -.43692600E+02, 0.47094700E+01, -.11390100E+02, 0.78851200E+01, 0.39121400E+02, 0.27326100E+02, -.97825500E+01, 0.13586100E+02, -.32563200E+01, -.74047400E+01, -.60913800E+01, 0.15138400E+01, -.62807100E+01, -.99555800E+01, -.50472100E+01, 0.67780700E+00, -.52428400E+00, 0.31214300E+01, -.16395000E+01, -.28214400E+00, 0.29618400E+01, 0.48654400E+00, 0.19170900E+00, 0.12273200E+00, -.19683100E+01, -.19382600E+01, 0.82299700E+00, -.30993600E+00, -.14441000E+02, -.98038100E+01, -.24582500E+01, -.54697100E+01, -.28960700E+01, -.37401100E+01, 0.31595400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16797800E+01, -.29241600E-01, -.32658100E+01, -.60508100E+01, 0.12362300E+01, 0.13721900E+01, -.50377500E-01, -.43332400E+00, -.27817400E+00, -.10869900E+00, 0.30321800E-01, 0.70195600E+00, 0.10886300E+01, -.15456000E+01, 0.66299300E+00, -.11422000E+01, 0.63211900E+00, 0.50503200E+00, 0.16540400E+01, -.24323400E+01, 0.12054800E+01, 0.18250400E+00, 0.37657400E+00, 0.86762800E+00, -.16111300E+00, -.11953500E+01, -.17903700E+01, 0.97404100E-02, -.48518000E+00, -.98981000E+00, 0.32895500E+01, 0.14124300E+01, 0.79963100E+00, 0.14984400E+00, -.24855000E+00, 0.41491700E+00, 0.70510600E+00, 0.35954500E-01, 0.14090100E+00, -.18656400E+00, 0.20942600E+01, -.29605100E+00, 0.29162100E+00, -.50701400E-01, 0.67322500E+00, 0.23823700E+00, 0.80856000E+01, 0.87296000E-01, -.51755900E-01, -.27866400E+00, -.44455500E+00, -.72444000E+00, -.43715000E+00, -.84994100E-01, 0.54222900E-01, -.11910600E+01, -.10856900E+00, 0.10818500E+01, -.37897200E+00, 0.54554100E+00, 0.12227800E+01, 0.64279200E+00, -.28513900E+00, 0.62970200E+00, -.73362800E+00, -.25648800E-01, 0.41118100E+00, -.15401800E+01, -.13080500E+00, 0.78136300E+00, -.14222100E+01, 0.16313100E+00, 0.57392000E+00, 0.93064600E-01, 0.84937800E+00, 0.37200300E+00, 0.46936100E+00, -.11328400E+00, 0.16572800E+02, -.46814400E+01, 0.78477500E+01, 0.21954800E+01, -.56280900E+01, -.10232100E+01, -.95464700E+00, 0.32685100E+01, -.37179900E+01, -.17799800E+00, 0.64427000E+01, -.28175300E+00, -.34790800E+01, -.32117100E+01, 0.39840700E+01, 0.31755700E+01, 0.22586700E+01, -.22743500E+01, 0.73403500E+02, 0.63029100E+02, -.47086600E+02, -.97317300E+01, -.45066900E+02, 0.39018000E+02, -.86989900E+01, -.39903600E+01, -.24292500E+03, -.70094700E+02, 0.72450900E+02, 0.49783900E+02, 0.37144900E+02, -.94059100E+02, 0.41468500E+02, 0.48377100E+02, -.33118300E+02, -.99420100E+01, -.12470800E+02, -.10010300E+02, 0.25171500E+02, 0.22815200E+01, 0.17915100E+02, -.12237800E+02, 0.22677200E+03, -.43853300E+02, -.61803400E+02, -.52781700E+02, -.24821900E+02, 0.94900500E+02, 0.32701100E+01, -.54427800E+02, 0.23126700E+02, -.24962200E+02, 0.11538700E+02, -.80233900E+01, 0.22947700E+02, 0.90323600E+01, -.81840200E+01, -.34489800E+01, -.27605600E+03, -.91667400E+02, 0.99099900E+02, 0.98289400E+02, -.71153900E+01, -.11889000E+03, -.25914200E+02, 0.10575500E+03, -.24762100E+02, 0.22479900E+02, -.19558700E+02, 0.22888900E+01, -.76190300E+01, -.96881700E+01, -.13797800E+02, -.32671700E+01, 0.37333900E+01, 0.15600700E+01, 0.10014900E+00, -.17744600E+01, -.18735600E+00, 0.27280800E+01, -.16562200E+01, -.23192000E+01, 0.36737100E+01, -.19000500E+01, 0.44540300E+00, -.17411000E+01, 0.66581900E+00, 0.11221300E+02, 0.54277900E+01, 0.35221500E+01, -.10116500E+02, -.39055200E+01, -.18539900E+02, -.22612300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.89944300E+00, 0.61511300E-01, -.19836400E+01, -.29967900E+01, 0.51876700E+00, 0.13556700E+01, 0.39891500E-01, 0.49716100E+00, 0.40351900E+00, -.29985100E+00, 0.99548000E+00, -.91359300E+00, -.43480600E+00, 0.63564200E+00, 0.26383600E+00, 0.81307900E+00, -.13866200E+01, 0.37249100E+00, 0.58414800E+00, 0.97101400E+00, -.11597000E+00, 0.31359700E+00, 0.21668100E+00, -.22917100E-03, -.21089300E+00, -.17561900E+01, 0.46978000E+00, 0.73123200E-01, 0.71127300E-01, 0.13438200E+01, 0.14398800E+01, 0.10228000E+01, 0.12174200E+01, -.50989000E+00, 0.21769100E+00, -.10284300E+00, 0.50756000E+00, -.15672700E+00, -.28004900E+00, 0.30752700E+00, -.27305200E+00, 0.85756700E-01, 0.92509600E-01, 0.20508200E+00, 0.21491100E+01, 0.43434300E-01, 0.33104500E+01, -.38842100E-01, 0.23040600E+00, 0.40543400E+00, -.58031600E+00, -.18053000E+01, -.81910700E-01, -.43094600E+00, -.36286300E-01, -.55834200E+00, -.61297200E+00, 0.17611600E+00, -.54345200E-01, 0.26806900E+00, 0.74401000E-01, 0.11546200E+00, 0.62197100E-03, 0.46479500E+00, 0.16005600E+00, 0.92744300E-01, -.13256900E+00, 0.54538600E-01, -.22679300E+00, -.44402600E+00, 0.64010000E+00, 0.91299100E-01, 0.11867500E+00, -.54022600E-01, -.17535000E+00, -.55850900E-01, -.49414200E+00, 0.35785000E-01, 0.14589500E-01, -.37293100E+01, 0.24536900E+00, -.34634700E+00, 0.12097500E+01, -.80016700E+00, 0.10753400E+01, 0.36462400E+00, -.75197100E+00, -.93185600E+00, 0.20417800E+00, 0.43706500E+00, 0.11770900E+01, -.63321100E+00, 0.97746800E-01, 0.29905200E+00, -.14947200E+01, -.83099500E+00, -.28809600E+02, 0.25173300E+02, -.15767800E+01, 0.93085600E+00, 0.36715800E+01, -.15852100E+02, 0.63214400E+01, 0.25326700E+01, 0.41230700E+02, -.11871600E+02, -.18198400E+01, 0.51819000E+01, -.13111800E+02, 0.15403500E+02, -.16335700E+02, 0.40452500E+01, 0.37351300E+01, 0.21678700E+00, 0.76099100E+01, 0.21402600E+01, -.54059000E+01, -.16053400E-01, -.52001600E+01, 0.31455500E+01, -.29066400E+02, -.54039200E+01, 0.49523000E+01, 0.92396500E+01, 0.77332800E+01, -.12159400E+02, -.75352000E+01, 0.87999300E+01, -.62599800E+01, 0.94379100E+00, 0.17481600E+01, 0.28001500E+01, -.52980200E+01, -.33386000E+01, -.22684600E+01, 0.25485900E+01, 0.10158700E+03, -.28209400E+02, -.33776000E+02, -.37135300E+02, -.57825800E+00, 0.44477600E+02, 0.25003700E+02, -.36845600E+02, 0.28560000E+02, -.15349900E+02, -.27694400E+01, 0.32614000E+01, -.10702000E+02, 0.63968800E+01, -.10841300E+02, 0.87909800E+00, -.43458100E-01, 0.17179100E+00, 0.23669800E+00, -.13519300E+01, -.79393000E+00, -.20370200E+01, -.12446000E+01, -.15279800E+01, 0.69483500E+00, 0.11332800E+01, -.30446100E+01, -.66038300E-01, 0.30818400E+00, 0.16933400E+00, 0.96775500E+00, -.62673400E+00, 0.23390000E+01, -.12874400E+01, 0.33796800E+01, 0.12988800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.75023800E+00, 0.56440500E-01, -.17422400E+01, -.71068400E+01, -.55941900E+00, -.69710900E-01, 0.20089000E+00, 0.60176900E+00, 0.69340200E+00, -.23254700E+00, 0.10887700E+01, -.11360900E+01, -.39116400E+00, 0.23053200E+00, 0.43716500E+00, 0.87604700E+00, -.12227600E+01, 0.37204400E+00, -.27822400E+00, 0.76830800E+00, -.75144600E+00, 0.59129800E+00, -.53948500E+00, -.27224200E+00, -.37591900E+00, -.13393400E+01, 0.51351600E+00, 0.55912600E-01, 0.90629300E-01, 0.15393800E+01, 0.20175000E+01, 0.10729200E+01, 0.15510300E+01, -.47425500E+00, 0.24789700E+00, -.85835300E-02, 0.81336400E+00, -.79780900E-01, -.61527300E-01, 0.16319800E+00, 0.94198100E-01, 0.56871800E-01, 0.30584900E+00, 0.94910300E-01, 0.34098300E+01, 0.11683400E+00, -.20680400E+01, -.80152100E-01, -.76336300E-01, -.33613700E+00, -.72352800E+00, 0.53622900E-01, -.18870400E+00, 0.51196000E+00, 0.77189700E-01, 0.51533600E+00, 0.23572900E+00, -.52036100E+00, 0.10156000E-01, -.41624400E-01, -.45697900E+00, -.36072900E-01, 0.13786600E+00, 0.14308300E+00, 0.41781900E+00, 0.10647400E+00, -.38778400E+00, 0.53910900E-01, -.34546200E+00, -.54206900E+00, 0.14174700E+00, -.10154100E+00, -.16990600E+00, 0.10064400E+00, -.18337300E+00, -.52398000E+00, 0.24819700E+00, 0.20079700E+00, 0.29104900E+00, -.56760500E+00, 0.67538900E+01, -.39343000E+01, 0.31706800E+00, -.30036400E+00, 0.22604500E+01, -.23370900E+00, -.35421900E+01, 0.17190800E+00, 0.69398600E+01, -.27520900E+01, -.22114600E+00, -.32324300E-01, -.66845500E+00, 0.95964300E-01, -.41922600E+01, -.24033100E+00, -.85626000E+02, 0.45061300E+02, 0.19055500E+02, 0.13761100E+01, 0.43477600E+02, -.11353200E+02, 0.56067100E+02, 0.48007200E+01, 0.16354700E+03, -.26468800E+02, -.44295100E+02, -.29630200E+02, -.33009100E+02, 0.51162500E+02, -.49230300E+02, -.33174300E+02, 0.15205800E+02, -.55982000E+01, 0.36308700E+01, 0.42789700E+01, -.40240000E+01, -.23484900E+01, -.94324700E+01, 0.75405200E+01, -.16178000E+03, 0.45925300E+02, 0.32451200E+02, 0.33737800E+02, 0.11657300E+02, -.56088800E+02, -.26218300E+01, 0.34569300E+02, -.96688300E+01, 0.25288400E+00, 0.68702300E+01, 0.16468900E+01, -.77206600E+01, -.95393000E+01, -.76987000E+01, -.30627400E+01, 0.19670800E+03, -.10568100E+02, -.68733500E+02, -.76084800E+02, 0.72689900E+01, 0.83512300E+02, 0.35382700E+02, -.80769000E+02, 0.17587600E+02, -.18257300E+01, 0.10253400E+02, 0.74004500E+01, -.90357000E+01, 0.10197800E+01, -.84566900E+01, 0.95679700E+01, 0.32941600E+01, -.20784700E+01, 0.17440800E+01, -.75745900E+00, -.53591500E+00, -.21838600E+01, -.76245400E+00, -.44343800E+00, -.89579500E+00, -.17920400E+01, -.22070400E+01, -.11496200E+01, 0.67222400E+00, -.15382600E+02, -.77163800E+01, 0.14075900E+01, 0.19366900E+01, -.22603000E+01, 0.11323700E+02, 0.79714100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11733600E+01, 0.65382100E+00, 0.22126600E+00, 0.33377800E+00, 0.11862200E+01, 0.76389600E+00, -.10342600E+00, -.10899300E+00, 0.26783400E+00, 0.65360800E+00, -.35739200E+00, 0.80620500E+00, -.21275200E+00, 0.62082700E+00, -.17166600E+00, 0.56951700E+00, -.50830900E+00, -.80829100E+00, -.26933800E+01, 0.46231400E+00, -.11884900E+01, 0.10850900E+01, -.25671200E+00, -.24064700E+00, -.51962600E+00, -.10328000E+01, 0.20859400E+00, -.74842200E-02, 0.43196900E+00, 0.11878000E+01, -.60669800E+00, -.12345300E+00, -.73480100E+00, -.24237400E+00, -.10888300E+01, -.47870900E+00, 0.75901900E+00, 0.47723500E-01, -.31863900E+00, -.67649400E-02, -.19880700E+01, 0.15263600E+00, -.15000700E+00, -.31843500E+00, -.18899000E+01, 0.79395300E+00, -.57739000E+00, 0.60792900E-01, 0.26536500E+00, 0.43548200E+00, 0.48666000E-01, -.23608100E+01, 0.44759600E+00, -.77036100E+00, -.11968600E+00, -.26391500E+00, -.33026000E+00, -.11499200E+01, 0.49935000E+00, 0.28025900E+00, -.18147900E+00, -.47023900E+00, 0.57384300E+00, 0.20358500E+00, 0.43691000E-01, 0.72101000E-01, -.25356900E+00, 0.20616800E+00, -.52141100E-01, -.98720700E-01, 0.34112600E+00, -.14269400E+00, -.45886400E+00, -.11231500E+00, -.12285700E-01, 0.10352900E+00, -.35074100E+00, 0.33134200E-01, -.21953300E+00, -.40503300E+00, -.36432100E+00, 0.51437900E+01, 0.31098100E+00, -.65553000E+00, 0.21716100E+01, -.13154700E+01, -.24520000E+01, -.61568200E+00, 0.36215500E+00, 0.84003500E+00, 0.65501500E-01, -.60002800E+00, 0.83108800E+00, -.83265700E+00, -.25645600E+01, -.73196500E+00, -.24603400E+02, 0.30563600E+02, 0.44398800E+01, -.53814000E+00, 0.12744800E+02, -.11458300E+02, 0.17801500E+02, 0.18299200E+01, 0.85184400E+02, -.25316600E+02, -.15451400E+02, -.44048700E+01, -.17881200E+02, 0.29831700E+02, -.34420100E+02, -.67498700E+01, 0.73549400E+01, 0.38878200E+00, 0.91481600E+00, 0.95510900E+00, -.27762300E+01, -.17401200E+00, -.60990000E+01, 0.37780300E+01, -.55952900E+02, 0.15368400E+02, 0.17166400E+02, 0.17466600E+02, 0.44455300E+01, -.23118100E+02, -.12728200E+02, 0.16703700E+02, -.11406200E+02, 0.26527500E+01, 0.14652400E+01, 0.35385400E+01, -.39513600E+01, -.78004100E+01, -.76383600E+01, 0.23762300E+01, 0.15996700E+03, -.36659800E+02, -.53645300E+02, -.57629000E+02, -.15634500E+01, 0.70990600E+02, 0.35959100E+02, -.59608700E+02, 0.26869100E+02, -.18214500E+02, -.60541800E+00, 0.30918300E+01, -.81450500E+01, 0.57242000E+01, -.80115300E+01, 0.28246300E+01, -.12242000E-01, -.28290400E+00, 0.24574400E-01, -.20315300E+01, -.67823200E+00, -.24366700E+01, -.17634100E+01, -.18790500E+01, 0.64205000E+00, 0.15865500E+01, -.26302000E+01, 0.84508900E-01, 0.65768800E+00, -.49962100E+01, -.13188000E+01, 0.14924000E+01, 0.15363200E+01, -.18441700E+01, 0.65926300E+01, 0.16752500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11403800E+01, -.19669700E-02, 0.26209000E+01, 0.40529400E+01, -.14009300E+01, -.13787700E+01, -.10565900E+00, -.28686700E+00, -.50378000E+00, 0.12859700E-01, -.11039400E+00, 0.11814900E+00, -.16000700E+01, 0.13170100E+01, -.76459800E+00, 0.49289000E+00, -.15955400E+01, 0.14185700E+01, -.16863300E+01, -.95795300E-01, 0.47941300E+00, -.11820900E+01, 0.39157400E+00, -.16559400E+00, -.21425200E+00, -.87321900E+00, 0.27048300E+00, -.35765100E-01, -.32332900E-01, 0.72345500E+00, -.22759600E+01, -.13905700E+01, -.47430600E+00, -.38996100E+00, 0.39017600E+00, -.61117600E+00, -.11302200E+01, 0.23070600E+00, -.74594900E-01, 0.12624100E+00, -.21261900E+01, 0.87238500E+00, 0.82297600E-01, -.11769400E+00, 0.21376000E+00, -.27846100E+00, -.36251400E+01, -.39788500E-01, -.33002800E+00, -.89642600E+00, -.50364700E+00, 0.14218800E+01, -.47255400E-01, 0.39135400E+00, 0.83139400E-01, 0.54087000E+00, 0.21657800E+00, 0.22019400E+00, -.36129800E+00, -.14094300E+00, 0.10164800E+00, 0.80485800E+00, -.19418400E+00, -.63533800E+00, -.39934300E+00, -.12518800E-01, 0.10358600E+00, 0.10611600E-01, 0.40598600E+00, 0.96186000E+00, -.16154500E+00, 0.91326800E-01, 0.12952600E+00, 0.51930900E-01, 0.57465900E+00, 0.94539100E+00, -.38502900E+00, -.23942000E+00, 0.15268900E+00, -.73875800E-02, -.90910400E+00, -.10750500E+00, 0.29725400E+01, -.59455800E+00, 0.23558100E+01, -.12019400E+01, -.40726600E+00, -.30583700E+00, -.41745800E+00, 0.15202300E+01, 0.13399200E+01, -.99453800E+00, 0.15947000E+00, -.10310200E+01, -.93245100E+00, -.11791300E+01, -.77754500E+02, 0.20344200E+02, 0.13918600E+02, 0.15214100E+02, 0.43220600E+01, -.40054000E+02, 0.48591100E+01, 0.14573100E+02, 0.10568100E+03, 0.27224600E+02, -.10389700E+02, -.31042100E+01, -.17928000E+02, 0.41903900E+02, -.38556400E+02, -.17191100E+01, 0.55667800E+01, 0.94760100E+01, 0.94421000E+01, 0.15995500E+01, -.79619900E+01, -.52570600E+01, -.73809400E+01, 0.34257000E+01, -.71865000E+02, -.18065400E+02, 0.17093200E+02, 0.21255300E+02, 0.11207100E+02, -.21475400E+02, -.89215900E+00, 0.22994500E+02, -.81312700E+01, 0.29175400E+01, 0.37170300E+01, 0.53755400E+01, -.12168700E+02, -.85045200E+01, -.46659800E+01, 0.33473300E+01, 0.20541600E+03, -.23259500E+02, -.62512200E+02, -.71579100E+02, 0.45744100E+01, 0.86320600E+02, 0.40514900E+02, -.71849500E+02, 0.14522800E+02, -.61363600E+01, 0.82553900E+01, 0.79528100E+01, -.69604600E+01, 0.13807100E+01, -.15012800E+02, 0.81127500E+01, -.37318100E+00, 0.81107100E+00, -.79439800E+00, -.21203100E+01, -.11377100E+01, -.42714200E+01, -.15024100E+01, -.20957900E+01, 0.52994900E+00, 0.16688000E+01, -.45252300E+01, 0.48396600E+00, 0.67279500E+00, 0.23592500E+00, 0.31534500E+01, -.25824300E+00, 0.43620000E+01, -.18700000E+01, 0.67699000E+01, -.22460600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.30823100E+01, 0.16370500E+01, 0.76537300E+00, -.76004700E+00, 0.38184000E+01, -.15719700E+00, -.10376200E+01, -.20907800E+01, -.77215200E+00, 0.25291200E+01, -.66893800E+00, 0.47703700E+01, 0.23742100E+00, 0.11724400E+01, -.20280900E+00, -.31029200E+01, 0.30175300E+01, -.76264900E+01, -.11600000E+02, 0.90760800E+00, -.11364600E+00, 0.39789100E+01, 0.11776100E+01, -.10331400E+01, -.68694000E+00, -.72298700E+00, -.80680400E+01, -.43161500E+00, 0.90921300E+00, 0.17125100E+00, 0.22484900E+01, 0.20977400E+00, -.26724000E+01, 0.11142800E+00, -.24483100E+01, 0.42399400E+00, -.15284000E+00, 0.64433700E+00, 0.17287600E+00, -.11325300E+01, -.62240300E+01, -.65141700E+00, -.83266200E+00, -.53134000E+00, -.85198000E+01, -.40747100E+01, 0.17292500E+02, -.52806700E+00, 0.12685400E+00, -.63081100E-01, 0.22889600E+01, 0.28274900E+01, 0.16561000E+00, 0.44745200E+00, 0.17173800E+00, -.24020300E+00, 0.35598000E+00, 0.11316700E+01, -.60844200E+00, -.13297400E+00, -.78810900E-01, -.71599600E+00, -.61887500E+00, 0.46182900E-01, -.10780200E+01, 0.14888900E+01, -.12555300E+01, 0.11294600E+01, 0.12736600E+01, 0.18488300E+01, -.26204800E+01, -.40685000E+00, -.19071400E+01, 0.91197400E-03, 0.22857400E+01, 0.80059200E+00, 0.12266200E+01, 0.29671500E+00, 0.87412300E+00, -.28921500E+01, 0.38160800E+01, -.15226500E+01, -.20925200E+01, -.76734100E+01, 0.11108200E+02, -.15719200E+01, -.10279900E+02, -.82437800E+01, 0.27975700E+01, -.52334800E+01, -.18628200E+01, -.11082700E+02, 0.11351000E+02, 0.24247600E+01, -.10111900E+02, -.12030100E+02, -.62382400E+01, -.18311400E+03, -.18546600E+02, 0.46164900E+02, -.44309300E+02, -.88824000E+02, -.10978000E+02, 0.59416900E+02, 0.18075200E+03, 0.51640700E+03, 0.39454200E+02, -.16054800E+01, -.70424400E+00, 0.11653900E+03, -.10033700E+03, -.60360700E+01, 0.23585300E+02, -.56507800E+00, 0.18213100E+02, 0.46409200E+01, -.12939900E+02, 0.61376700E+00, -.20551500E+02, 0.14094600E+02, 0.23331900E+01, -.35621800E+02, 0.15354100E+02, 0.27429100E+02, 0.16965400E+02, -.76757100E+01, -.49842500E+02, 0.24129400E+02, -.21196900E+02, -.92905100E+01, 0.13140500E+01, 0.20871900E+01, 0.12220600E+01, -.26794700E+02, -.41353000E+02, 0.37815600E+01, 0.78973300E+03, -.19343100E+03, -.20722800E+03, -.26220700E+03, -.30779700E+01, 0.34332500E+03, 0.17660200E+03, -.26488300E+03, 0.81224700E+02, -.21401000E+02, 0.40520400E+02, 0.43236900E+02, -.37125700E+02, 0.10883200E+02, -.62436600E+02, 0.47102100E+02, 0.16514400E+01, 0.50812500E+01, -.13788600E+02, -.93435700E+01, -.75927000E+01, -.14973900E+02, -.10932600E+02, -.46713100E+01, 0.11413700E+02, 0.12210800E+02, -.15901300E+02, -.24788100E+01, 0.24636400E+01, 0.10896200E+02, 0.31625700E+02, 0.41167000E+01, 0.11868100E+01, -.14506900E+02, 0.10418700E+02, -.15104600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23299000E+01, 0.84405900E-01, 0.51896500E+00, 0.75439500E+01, 0.16274500E+01, -.19347100E+01, -.83903700E+00, -.28217000E+01, -.31305000E+01, 0.29468700E+00, -.29733200E+01, 0.45781700E+01, 0.17656600E+00, -.74347000E+00, -.95758800E+00, -.19220800E+00, 0.54275400E+01, 0.14267100E+01, 0.26871100E+01, -.51666100E+01, 0.39985800E+01, -.76878200E+00, -.37806500E+00, 0.94911100E+00, -.27371900E+00, 0.26639700E-01, -.17892400E+01, 0.22475500E-01, 0.27781200E+00, -.31024900E+01, 0.44788700E+00, -.18453300E+01, -.58213700E+01, 0.20362000E+01, -.33794100E+01, 0.42037700E+00, 0.20116100E+01, 0.31180400E+00, 0.13390700E+00, -.31574200E+00, -.17756200E+00, -.39781700E+00, -.22409300E+00, -.66894700E+00, -.85295500E+01, 0.70302400E-01, 0.97958200E+01, 0.42578900E-01, 0.16542700E+00, 0.18443400E+00, 0.47889300E-01, -.71531700E+00, 0.71839500E+00, -.16744200E+01, -.30535600E+00, -.75744300E+00, 0.17789300E+00, 0.17017800E+00, 0.13488000E-01, -.44910000E+00, 0.35114400E+00, 0.16150400E+00, 0.66722800E+00, -.24962500E+01, 0.80418900E+00, 0.20270400E+00, 0.23082000E+00, 0.65734100E+00, 0.81397800E-01, -.43251300E+00, 0.76702400E+00, 0.56844800E-01, 0.90766100E-01, -.27146800E-01, 0.26050500E+00, 0.49480700E-01, -.85494300E-01, -.25483500E+00, 0.74948000E+00, 0.56012000E+00, 0.24512400E+01, 0.62567400E-01, -.31815800E+00, -.23821400E+00, -.70478900E+01, 0.47792300E+01, -.16789300E+00, -.12445900E+01, 0.10477200E+01, -.53119300E+01, 0.69712700E+00, -.68927500E+00, 0.37259000E-01, 0.53576000E+01, 0.25533900E+01, -.10558800E+01, 0.19390200E+03, -.14965500E+03, -.35085400E+02, -.47096100E+01, -.84982600E+02, 0.18151000E+02, -.99170600E+02, -.55825600E+01, -.34570800E+03, 0.19536500E+03, 0.78339600E+02, 0.49139600E+02, 0.83750000E+02, -.95175700E+02, 0.78018000E+02, 0.55769800E+02, -.11450800E+02, -.11495000E+01, 0.19959900E+02, 0.62532500E+01, -.49381600E+01, 0.10641900E+02, 0.48621800E+01, -.20757500E+00, 0.25455700E+03, -.28017100E+02, -.58968200E+02, -.62383400E+02, -.82278000E+01, 0.80912800E+02, -.87646900E+00, -.60831100E+02, 0.21852100E+02, -.14125400E+02, -.13765200E+02, -.12532100E+02, 0.23425500E+02, 0.16064600E+02, 0.10458500E+02, -.71377900E+01, -.19915400E+03, -.20446300E+02, 0.89068800E+02, 0.75423500E+02, 0.62912500E+01, -.66849000E+02, 0.20988000E+01, 0.80745300E+02, -.37421900E+01, 0.50686500E+01, -.70268400E+01, -.12961700E+01, 0.73060800E+01, -.17257500E-01, -.66642300E+01, 0.20798400E+01, 0.16498000E+01, 0.35925600E+01, -.39131900E+01, 0.16579500E+01, -.18957900E+00, 0.35956300E+01, 0.70033600E+00, 0.28195500E+01, 0.27095100E+01, 0.38975000E+01, 0.34483800E+01, -.16766100E+01, -.12124600E+01, 0.27183600E+02, 0.18020600E+02, -.58709900E+01, -.50164700E+01, 0.21068800E+01, -.19348500E+02, -.57381800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11580700E+01, -.40704600E-01, 0.26743400E+01, 0.11001000E+02, 0.64203200E+00, 0.52839700E+00, -.35685400E+00, -.92358500E+00, -.12668800E+01, 0.21129600E+00, -.42612900E+00, 0.18356300E+01, -.96934900E+00, 0.12638300E+01, -.71824500E+00, -.49714000E+00, 0.58079000E+00, 0.22456100E+00, -.68859100E-01, -.21970900E+00, 0.20480500E+01, -.74677500E+00, 0.39691800E+00, -.18115700E+00, 0.75017000E-01, -.75579300E+00, -.13512300E+01, -.19155600E-03, 0.15342700E+00, -.71326500E+00, -.58421100E+00, -.10065200E+01, -.84756600E+00, -.27476600E-01, -.28275400E+00, 0.67905700E-03, -.31401300E+00, 0.13928700E+00, -.98260600E-01, -.16854800E-01, -.11360400E+01, -.86499000E-01, -.50304100E+00, -.51560900E+00, -.63852300E+01, 0.12608500E+01, -.71226600E+00, 0.10966400E+00, 0.26083000E+00, 0.53342900E+00, -.14674100E+00, -.24752800E+01, 0.82154500E+00, -.85726000E+00, -.17296200E+00, 0.26826700E+00, -.59952300E+00, -.29348600E+00, 0.21486100E+00, 0.15817400E+00, 0.63122300E+00, -.19570000E+00, 0.29737600E+00, 0.13194000E+00, -.20801500E+00, 0.16514800E+00, -.97961600E-01, 0.55325700E+00, 0.42555200E+00, 0.10210600E+00, 0.53766700E+00, 0.83903700E-01, -.19167100E+00, -.45625700E-01, 0.30907000E-01, -.25954600E+00, 0.65796500E-01, -.93073700E-01, -.11523900E+00, -.44252300E+00, 0.19180500E+00, 0.44700900E+00, 0.11306900E+00, -.88884700E-01, 0.10188300E+00, -.10759800E+01, -.64825500E+00, -.18961500E+00, 0.11240500E+01, -.83406500E+00, 0.29751900E+00, 0.23827900E+00, 0.19459400E+00, 0.37107700E-01, 0.13617300E+00, 0.18821400E+00, 0.21590100E+02, 0.17475200E+02, -.67759100E+01, -.10678900E+02, 0.11450700E+02, 0.19325300E+02, 0.14993100E+02, -.88675100E+01, -.52451500E+01, -.33955200E+02, -.93910800E+01, -.45969000E+01, -.83609600E-01, -.65701200E+01, -.21855100E+01, -.66621400E+01, 0.45519600E+01, -.35462200E+01, 0.85467200E+00, 0.97817800E+00, 0.20552600E+01, 0.30575400E+01, 0.62467600E+00, 0.14488000E+01, 0.12883100E+02, 0.20879600E+02, 0.16947600E+02, 0.38671200E+01, -.14734000E+02, -.53417200E+01, -.22284500E+02, 0.19657500E+01, -.11542600E+02, 0.59532400E+01, 0.29570300E+01, 0.20102100E+01, 0.39283800E+01, -.16733400E+01, 0.14028800E+01, 0.24470500E+01, 0.28894700E+02, -.16605300E+02, -.14883200E+02, -.10694700E+02, 0.24581200E+01, 0.15438300E+02, 0.14633500E+01, -.12324600E+02, 0.24288100E+02, -.20403000E+02, -.37854300E+01, -.27711100E+01, -.59920800E+01, 0.40314800E+01, -.16769700E+01, -.31941700E+01, 0.63277000E+00, -.67537200E+00, 0.63395500E+00, 0.89733100E+00, -.10973100E+00, 0.19159300E+01, 0.79835200E+00, 0.13139400E+01, 0.27912000E-01, -.65213300E+00, 0.22461800E+01, -.14282200E-01, -.48324900E+00, -.44473800E+01, -.36620400E+01, -.73365300E+00, -.37424800E+00, 0.50613600E+00, 0.15434800E+01, 0.33773700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.28630600E+01, -.97727200E-01, -.36242800E+01, -.11102100E+02, -.31993600E+00, -.39952000E-01, -.20998000E+00, 0.12530100E+01, 0.13927600E+01, -.12644300E-02, 0.20164500E+01, -.23494600E+00, 0.16390500E+01, -.36305800E+01, 0.16825200E+01, -.23509200E+01, 0.28215600E+01, -.26832800E+01, -.26010600E+01, -.22350100E+01, 0.14759100E+01, 0.58430100E+00, -.18034900E+01, -.33118600E+00, -.19307500E+00, -.83472300E+00, 0.20656100E+01, 0.13017400E+00, 0.33596000E-01, -.28265900E+00, 0.15739100E+01, 0.14913700E+01, 0.35117600E+01, -.82236200E+00, 0.81750400E+00, -.29109000E+00, 0.54863100E+00, -.57318200E+00, -.16934600E+00, 0.44263300E+00, 0.11865200E+01, -.25668900E+00, 0.15347200E+01, -.18959400E+00, 0.50599000E+01, -.27469000E+01, 0.83308100E+01, -.24730000E+00, -.41247500E+00, -.30946000E+00, -.21510900E+00, -.18628800E+01, -.34595700E+00, -.15191500E+00, 0.31734400E+00, -.39623000E+00, -.30770900E+00, 0.21858200E+01, -.31268400E+00, -.67411600E+00, -.70072000E-01, 0.41180900E+00, 0.57804000E+00, -.22100700E+01, 0.25212800E+01, 0.26565500E-01, 0.94522800E+00, 0.10444200E+01, 0.19040300E+00, -.15671400E+01, 0.15041900E+00, -.99587000E-01, 0.10414400E+01, 0.13043300E-01, -.19981100E+01, -.88257300E+00, 0.34427400E+00, -.31329900E+00, 0.60380400E-01, 0.29785100E+01, 0.15152400E+01, 0.38459700E+00, -.65419500E+00, -.54018200E-01, 0.82796800E+00, -.10450900E+01, 0.94596300E+01, 0.76440100E+00, -.16491800E+01, 0.34487900E+01, 0.13299600E+00, 0.50443800E+00, -.10883200E+01, -.13484100E+01, 0.74458300E+01, 0.86503700E+00, -.67423600E+02, 0.19049600E+03, 0.60177800E+01, 0.59475400E+00, 0.26305800E+01, -.22751500E+01, -.17775900E+02, -.82503100E+01, -.68471200E+02, -.26590600E+03, 0.80268500E+01, 0.23976700E+02, -.11962200E+02, -.47082800E+02, 0.29659000E+02, 0.31647100E+02, -.10096800E+02, 0.12217500E+02, -.15101800E+02, -.92318200E+01, 0.72806800E+01, -.21711700E+01, 0.13978900E+02, -.16519900E+02, 0.80403100E+02, -.57255700E+02, -.17705900E+01, -.98575800E+01, -.30871100E+02, 0.32049300E+02, 0.15683400E+02, -.54429000E+01, 0.10626500E+02, -.79975800E+00, -.68448500E+00, -.38772300E+00, -.74570500E+00, 0.85214500E+01, 0.54535800E+01, -.45143300E+01, -.33759000E+03, -.58351700E+02, 0.95845900E+02, 0.12023800E+03, 0.16516300E+01, -.15166200E+03, -.77735500E+02, 0.12845600E+03, -.23197000E+02, -.44754900E+01, -.24662300E+02, -.20571300E+02, 0.11338800E+02, 0.16293200E+01, 0.34425600E+02, -.27543600E+02, -.91828000E+00, 0.28487500E+00, 0.52545100E+01, -.29530400E+00, 0.90426900E+00, 0.36814400E+01, 0.36340300E+01, -.20780700E+01, -.25189600E+01, -.47916800E+01, 0.42614200E+01, 0.14159100E+01, -.12013300E+01, 0.54665900E+01, -.60810600E+01, 0.12502500E+01, -.14314800E+01, 0.34943600E+01, -.10463800E+02, 0.85355300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13669700E+01, -.14880200E-01, -.33317500E+01, -.13547700E+02, -.71423400E+00, -.60270600E+00, 0.53432000E+00, 0.13041100E+01, 0.16725400E+01, -.15377100E+00, 0.74440600E+00, -.19284100E+01, 0.96419500E+00, -.13777800E+01, 0.10098800E+01, 0.13218900E+00, 0.54976500E+00, -.97148900E+00, -.12560900E+01, -.34031300E+00, 0.28765000E+00, 0.20145500E+00, -.71915200E+00, -.49077800E+00, -.86631200E-01, 0.41492600E+00, 0.39565900E+00, -.24621000E-01, 0.28131800E+00, 0.62930800E+00, -.12158600E+01, 0.53028400E-01, 0.35256000E+00, 0.16916400E+00, -.39019400E+00, -.35624900E+00, 0.51737800E+00, 0.44920900E-01, 0.18192000E+00, -.27855500E+00, -.57565600E-02, 0.76954800E-01, 0.39153000E+00, -.68012900E+00, -.12836100E+01, 0.60171800E+00, -.19225700E+01, 0.10227600E+00, -.74864700E-01, -.39295500E+00, 0.15848500E+00, -.36905800E+00, 0.30813300E+00, 0.32291700E+00, 0.40125400E-01, 0.48654000E+00, 0.42536700E+00, -.27823500E+00, -.32850600E+00, -.44167300E-01, -.13396500E+00, 0.32926500E+00, 0.15328700E+00, 0.75200600E+00, 0.61198900E-01, 0.31910000E-01, -.12851600E-01, 0.47850600E+00, 0.22736600E-01, 0.22279300E+00, 0.17355800E+00, 0.21954200E-01, -.54589700E-01, 0.10714000E+00, 0.58667700E+00, 0.86616400E+00, 0.22624600E+00, -.47098300E-01, -.12201000E+00, -.43498500E-01, -.93872400E+00, -.87688800E+00, -.50206800E+00, 0.11888300E+00, -.42286400E+00, -.28732500E+00, -.45037200E+00, 0.12069100E+01, -.74129200E+00, -.63216700E+00, -.99195300E+00, -.23803900E+01, 0.16303800E+01, 0.47273800E+00, 0.22313200E+01, -.17305800E+01, 0.44421600E+02, 0.91825200E+02, -.13451500E+02, 0.19191100E+02, -.82972900E+02, -.27100600E+02, -.84825700E+02, 0.13789700E+02, -.17186000E+03, -.32730000E+02, 0.77864800E+02, 0.62112100E+02, 0.29503900E+02, -.47739200E+02, 0.19326400E+02, 0.72155200E+02, -.14072700E+02, 0.44381200E+01, -.11513300E+02, -.91091500E+01, 0.51041000E+01, -.22698200E+01, 0.51831200E+01, -.12752800E+02, 0.13453100E+03, -.11279400E+03, -.24346500E+02, -.21262000E+02, -.12572500E+02, 0.56334900E+02, 0.64957500E+01, -.14702500E+02, 0.30291800E+01, -.12171800E+02, 0.71870300E+01, 0.47849600E+00, 0.10608400E+01, -.47421800E+00, -.24313800E+01, -.31097900E+00, -.11757400E+03, -.10062300E+03, 0.50128100E+02, 0.45067800E+02, 0.14577700E+02, -.49728600E+02, -.39875000E+01, 0.55183100E+02, -.21300000E+02, 0.17576500E+02, -.16972200E+02, -.41860200E+01, 0.61696900E+01, -.26387200E+01, -.75023300E+01, -.76300200E+01, -.50841500E+00, 0.42133500E+01, -.17440200E+01, -.42991700E+01, -.65603200E+00, -.36268000E+01, -.28470800E+01, -.51544100E+01, 0.22217800E+01, 0.19928000E+01, -.37995300E+01, 0.16600900E+00, 0.42479600E+00, 0.26682900E+02, 0.17309300E+02, 0.35446600E+01, 0.30539300E+00, -.28037300E+01, -.13987400E+02, -.49754500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.30685000E+00, 0.21922300E-01, -.31571200E-01, -.19110600E+01, 0.11273000E+00, -.20484800E+00, -.32615400E+00, -.28788900E+00, -.24825800E+00, 0.83535600E-01, -.16317200E+00, 0.49536300E+00, -.83466700E-01, 0.30626500E+00, -.18211200E+00, -.29006900E+00, 0.50912600E+00, -.23911100E+00, 0.15744600E+00, -.72599900E-01, 0.54716900E+00, -.94256600E-01, 0.17010500E+00, 0.91204900E-01, 0.15733300E-01, -.18522800E+00, -.15363800E+00, 0.20577300E-01, 0.95250300E-01, -.14052600E+00, 0.17579800E-01, -.28927900E+00, -.47841000E+00, 0.68689300E-02, -.28969100E+00, 0.20826000E-02, 0.17890600E+00, 0.90384100E-02, -.37655800E-01, 0.33494900E-01, -.33168200E+00, 0.30071200E-01, -.20382400E-02, 0.23323500E-01, 0.43968600E+00, -.35258100E+00, -.56801600E-01, -.77841700E-02, 0.26846300E-02, 0.13431100E+00, 0.17420600E+00, 0.18257100E+00, -.14369200E+00, 0.98897700E-01, -.57009700E-01, -.22437100E+00, -.56043000E-01, -.27142400E+00, 0.86122500E-01, 0.29568600E-01, -.11374800E-01, -.10646200E+00, -.64707000E-01, 0.13776300E+00, -.13586500E+00, -.11380900E+00, 0.72042000E-01, -.30561800E+00, -.18905000E+00, 0.10557500E+00, -.39591000E+00, -.21913500E-01, -.49047000E-01, -.81740000E-01, -.55604100E-01, -.37262200E-01, 0.11852300E+00, 0.10508200E+00, 0.11125400E-01, -.25181800E+00, -.24617100E+00, -.43191100E-01, 0.20526200E+00, -.15961900E-01, -.10840900E+00, -.13939500E-01, -.66502400E-01, -.77499400E-01, 0.46699800E+00, -.76350100E+00, -.82230500E-01, 0.10593000E-01, 0.45030200E-01, 0.28765400E+00, -.31952800E+00, -.35772500E-01, 0.61265400E+01, 0.90112300E+01, 0.14539100E+01, -.54580000E+00, -.16606000E+01, -.99354200E-02, -.16603800E+01, -.56545400E+00, 0.15228100E+01, -.59519800E+01, -.23921100E+01, -.52800500E+00, 0.16027600E+01, 0.20812300E+01, -.19163000E+01, 0.11340200E+00, 0.23832600E+01, 0.15871900E-02, 0.73547600E+00, 0.14954600E+01, -.13697600E+01, 0.11619100E+01, -.17362200E+01, 0.14517200E+01, 0.69094800E+01, 0.40752100E+01, 0.23271400E+01, -.22764700E-01, -.26159500E+01, 0.22341900E+00, -.39396900E+01, 0.42008200E+00, -.21585300E+01, -.72387400E+00, -.11387600E+01, -.11161500E+00, 0.14421300E+01, -.13517700E+01, -.19962000E+01, -.51394100E+00, 0.15110100E+02, -.21769000E+02, -.46676700E+01, -.62586800E+01, 0.31067900E+01, 0.96208500E+01, 0.11043800E+02, -.58473600E+01, 0.33074200E+01, -.28731300E+01, 0.98878100E+00, 0.73458800E+00, -.64139500E+00, 0.77685900E+00, -.20312600E+01, 0.88123500E+00, 0.21494300E+00, 0.85763500E-01, -.31334300E+00, 0.19202900E+00, -.25721300E-01, 0.12817900E+00, 0.31274800E-01, 0.39624300E+00, 0.37260700E+00, 0.41587300E+00, 0.13764700E+00, -.16435300E+00, -.54119100E-01, 0.23198400E+00, 0.54327400E+00, 0.13285200E+00, -.31741500E+00, -.15893700E+00, -.40905200E+00, -.79744100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11770100E+01, 0.58885700E+00, 0.67270000E-02, -.22836900E+00, 0.95316400E+00, 0.66339400E+00, -.10517400E+00, -.22692600E-02, 0.31472600E+00, 0.53356900E+00, -.15463500E+00, 0.61544600E+00, -.23683300E+00, 0.56587600E+00, -.70155100E-01, 0.57943600E+00, -.73092100E+00, -.56066100E+00, -.21836900E+01, 0.49457900E+00, -.12676100E+01, 0.10537100E+01, -.42174400E+00, -.28182900E+00, -.52249200E+00, -.11116100E+01, 0.24178000E+00, 0.11994900E-02, 0.40272300E+00, 0.11675600E+01, -.41402700E+00, 0.54180200E-01, -.48643400E+00, -.21990300E+00, -.87850100E+00, -.41355700E+00, 0.81052900E+00, -.14062200E-03, -.31914900E+00, 0.43896800E-01, -.16753500E+01, 0.13616900E+00, -.11329800E+00, -.29423700E+00, -.17346300E+01, 0.77362900E+00, 0.24947600E+00, 0.50394700E-01, 0.26451200E+00, 0.44207200E+00, 0.23737200E-01, -.22676500E+01, 0.45288500E+00, -.73471200E+00, -.80688600E-01, -.21739500E+00, -.33077800E+00, -.76529100E+00, 0.37799600E+00, 0.22964800E+00, -.14223200E+00, -.35649300E+00, 0.63948200E+00, 0.18244700E+00, 0.21290600E+00, 0.56195600E-01, -.17337600E+00, 0.29505700E+00, -.11840800E+00, -.17655200E+00, 0.25269300E+00, -.12466600E+00, -.33463000E+00, -.76622400E-01, -.35253100E-01, 0.73540600E-02, -.22281000E+00, 0.73774700E-02, -.11612200E+00, -.24183000E-01, -.18705300E+00, 0.63235100E-01, -.27760300E+00, 0.56991800E-01, -.20276500E+00, 0.92718300E-01, -.11667600E+00, 0.41996900E-01, -.11677800E+01, 0.45133100E+01, 0.19350900E-01, 0.18363500E+00, -.20130000E+00, 0.73422500E-01, -.25209800E+00, 0.14202400E-01, 0.61783600E+00, 0.32603200E+02, 0.67845800E+01, 0.13386100E+01, -.37732100E+01, -.77983600E+01, -.91173500E+01, 0.14745100E+01, 0.16121900E+02, -.38790200E+02, -.39499700E+01, 0.32507000E+01, -.20876800E+01, 0.65867600E+01, -.10518900E+02, 0.46673200E+01, 0.24972700E+01, 0.15108800E+01, 0.19739600E+01, 0.22219600E+01, -.31339800E+01, 0.13567600E+01, -.29546200E+01, 0.20372000E+01, 0.48773600E+00, 0.73031700E+01, 0.68894700E+01, 0.57943100E+01, -.61501200E+01, -.35165900E+01, -.65259200E+01, 0.71957800E+01, -.24375500E+01, -.36852600E+01, -.26498400E+01, 0.70087900E+00, 0.22430600E+00, -.28500700E+01, -.35295700E+01, -.84145300E+00, 0.62493700E+02, -.60956300E+02, -.18105800E+02, -.22476600E+02, 0.39957800E+01, 0.32756400E+02, 0.25232600E+02, -.21483500E+02, 0.14244200E+02, -.11774100E+02, -.29754000E+01, -.86610800E+00, -.11791600E+01, 0.43534700E+01, -.44602500E+01, -.11058800E+01, 0.19168900E-01, 0.47267300E+00, -.85827900E-01, -.87456100E+00, 0.61738500E-01, -.10570900E+00, -.11087900E+00, -.55443100E+00, 0.49380200E+00, 0.12140600E+01, -.15563900E+00, -.24438100E-01, -.32325100E-01, 0.82481300E+00, 0.10706700E+01, 0.10711000E+00, -.21768300E+00, -.78671200E-01, 0.52868800E+00, 0.79091400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49238400E+00, -.32177200E-02, -.12234900E+01, -.49389100E+01, -.42487600E+00, -.16087500E+00, 0.17768900E+00, 0.51071200E+00, 0.62331100E+00, -.90782000E-01, 0.55770600E+00, -.81107100E+00, -.56494900E-01, -.79162800E-01, 0.34914900E+00, 0.37033500E+00, -.53490900E+00, 0.15816400E-01, -.55010700E+00, 0.36919300E+00, -.39975800E+00, 0.20567800E+00, -.47915300E+00, -.27207200E+00, -.14682200E+00, -.16583700E+00, 0.34098700E+00, 0.29525200E-02, 0.42760300E-01, 0.76888100E+00, 0.29792900E+00, 0.35687900E+00, 0.68261900E+00, -.19460100E+00, 0.11632900E+00, -.95592700E-01, 0.10042200E+00, -.43969300E-01, -.30901000E-01, 0.66289800E-01, -.71446300E-02, 0.58158800E-01, 0.66014000E-01, 0.44688700E-01, 0.99218700E+00, 0.23228700E+00, -.12547700E+01, -.15734500E-01, -.30976900E-01, -.16133700E+00, -.29936300E+00, -.22641700E+00, 0.33724400E-01, 0.11629900E+00, 0.32366600E-01, 0.19440100E+00, -.58208300E-01, -.91267000E-01, 0.47059600E-02, -.30132400E-01, -.18862100E+00, -.29074200E-01, 0.76375600E-01, -.51098200E-01, 0.10634100E+00, 0.23102000E-02, -.85373000E-01, 0.96144900E-01, -.53431100E-01, -.19726100E+00, 0.15202200E+00, -.63605700E-01, -.17284000E-01, 0.16334800E-01, -.14030700E+00, -.62281100E-01, 0.11354500E-01, 0.55289200E-03, 0.22951400E-01, 0.87821600E-02, -.13246000E-01, -.58459200E-01, 0.74584800E-01, 0.16130000E-02, -.38272300E-01, 0.10242100E+00, -.36488800E-01, 0.26635300E-01, -.17620600E+00, -.55993800E-01, 0.46721100E+00, 0.68152400E-02, -.81206500E-01, -.19788700E-01, 0.34536200E-01, -.60865800E-01, -.29652300E+01, 0.55660600E+01, 0.37749900E+01, 0.16087400E+01, -.27534600E+00, -.23432200E+01, -.29366500E+01, 0.16035700E+01, 0.26262400E+01, -.48551400E+01, -.20162200E+01, -.58462400E+00, -.18985300E+00, 0.79552800E+00, -.19032500E+00, -.12707900E+00, 0.49552600E+00, 0.69053600E+00, -.41379200E+00, 0.20035500E+00, -.60629600E+00, 0.20375000E+00, -.30927800E+00, -.27031100E+00, -.86686200E+01, 0.25812600E+01, 0.50833400E+00, 0.18025200E+01, 0.82755500E+00, -.28687400E+01, 0.29265100E+01, 0.24146000E+01, 0.14635800E+01, -.94038300E+00, -.18215800E+01, -.75402500E+00, -.11545900E+00, 0.12716500E+00, -.97848400E+00, -.15504300E+01, -.52135400E+01, -.99471400E+01, 0.18453000E+01, 0.10235500E+01, 0.10719300E+01, -.10939500E+01, 0.15136900E+01, 0.12470500E+01, -.19124900E+01, 0.19741500E+01, 0.10456500E+00, -.28221100E+00, 0.15212400E+01, -.27454000E+00, 0.97045500E+00, -.39539500E-01, 0.56958900E-02, 0.12337200E+00, 0.35819400E-01, -.34608700E+00, -.88473100E-02, -.15908200E+00, -.30201500E-01, -.39589300E+00, -.72525900E-01, 0.53208900E-02, -.17393000E+00, -.26189700E-01, 0.57094200E-01, -.15282300E+00, -.22230400E-01, 0.21844700E+00, -.23077900E+00, 0.41538500E-01, -.14093900E+00, -.21151000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.68778000E+00, -.15891500E-01, -.14729700E+01, -.20880000E+01, 0.25797300E+00, 0.94705600E+00, 0.84773000E-01, 0.11299600E+00, 0.88346700E-01, -.73664600E-01, 0.21054600E+00, -.34033100E+00, 0.43240400E-01, -.17813400E+00, 0.12731500E+00, -.13049000E+00, -.10949100E+00, 0.45931000E-01, -.75294800E-01, 0.21457800E-01, 0.60920000E-01, -.76420500E-01, 0.13703200E+00, 0.62636300E-02, 0.60079100E-01, -.29562100E-01, -.15850400E+00, -.15409900E-02, -.54667300E-01, -.19629100E+00, 0.48030300E+00, 0.15204900E+00, 0.29050600E+00, -.22329300E-01, 0.14181200E+00, 0.74958500E-01, 0.12127700E+00, -.51985000E-02, 0.43009600E-01, -.11459000E-01, 0.40625700E+00, -.27884100E-01, 0.72695000E-01, -.13453100E-01, -.32346600E-01, 0.10327400E+00, 0.86484800E+00, 0.12319900E-01, 0.65717400E-02, -.55666600E-01, -.10779500E+00, -.17375500E+00, 0.35731100E-01, 0.42601300E-01, 0.32650800E-01, 0.32966600E-01, -.19128900E-01, 0.21428600E+00, -.15043300E+00, -.21916800E-01, -.13785300E-01, 0.18269900E+00, -.48515300E-01, 0.51239900E-01, 0.36321800E-01, 0.66199900E-01, -.20662100E-01, 0.99619400E-01, 0.13212800E+00, -.44720500E-01, 0.17061600E+00, 0.28818000E-01, 0.76685700E-01, 0.24063300E-01, -.54145000E-02, 0.75046100E-01, -.43872000E-01, -.12854700E+00, 0.28081100E-01, 0.24893800E+00, 0.62429000E-01, -.45531900E-02, -.97167700E-01, -.65285300E-01, -.12318800E-01, -.13693200E+00, -.52491400E-01, -.23966800E+00, -.21252000E+00, -.16807200E+00, -.67343500E+00, -.13766700E+01, 0.10687900E+01, 0.61843600E+00, 0.12138800E+01, -.12668300E+01, 0.31816700E+02, 0.26113600E+02, -.74997200E+01, 0.78394900E+01, -.37428900E+02, -.11700300E+02, -.39984100E+02, 0.64551400E+01, -.81373800E+02, 0.11760000E+02, 0.33824200E+02, 0.26045100E+02, 0.17010600E+02, -.20201600E+02, 0.78654400E+01, 0.30414500E+02, -.50098000E+01, 0.19114700E+01, -.16842200E+01, -.25315700E+01, 0.13279200E+01, 0.31375600E+00, 0.22990200E+01, -.44324900E+01, 0.69026300E+02, -.41747000E+02, -.96869500E+01, -.89110600E+01, -.85653000E+01, 0.24756000E+02, -.24256700E+01, -.62045600E+01, 0.17934500E+01, -.65442500E+01, 0.82127400E+00, -.89885000E+00, 0.29770400E+01, -.91301500E-02, -.18671700E+01, -.13912900E+01, -.24826200E+02, -.62305500E+02, 0.17028700E+02, 0.10999100E+02, 0.67882000E+01, -.77773000E+01, 0.71712800E+01, 0.15183500E+02, -.39215700E+00, 0.28714300E+01, -.58757700E+01, -.60684400E+00, 0.91549900E+00, 0.15475900E+00, -.59650900E+01, -.14160600E+01, 0.10896100E+00, 0.20397100E+01, -.13205400E+01, -.19636200E+01, -.61489800E+00, -.11855900E+01, -.10318500E+01, -.18924700E+01, 0.13269600E+01, 0.13147400E+01, -.12302200E+01, -.11640200E+00, 0.16497500E+00, 0.12031700E+02, 0.87476100E+01, 0.77294100E+00, -.41722400E+00, -.12375000E+01, -.62268300E+01, -.23568900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.72178700E+00, 0.13782400E-01, 0.17236200E+01, 0.25858500E+01, -.42201700E+00, -.89107400E+00, -.63699400E-01, -.46246800E+00, -.51536800E+00, 0.12652800E+00, -.47861800E+00, 0.58705100E+00, -.89957700E-01, 0.17652500E+00, -.42934300E+00, -.10564900E+00, 0.55465700E+00, -.14033100E+00, -.71709300E+00, -.24362500E+00, 0.18567800E-01, -.15842900E+00, 0.44427600E+00, 0.17247300E+00, 0.14053500E+00, 0.26287900E+00, 0.89107300E-01, -.34890600E-02, 0.58668000E-01, -.13520100E+00, -.67959300E+00, -.57224500E+00, -.50101200E+00, 0.80557400E-03, -.40048200E+00, -.74231000E-01, -.15886100E+00, 0.60841500E-01, 0.23457600E-01, -.15365000E+00, -.39192100E+00, -.22329400E-01, -.12695000E+00, -.13702700E+00, -.22483700E+01, 0.66309800E-01, 0.57856700E+00, 0.58265000E-01, 0.10565600E+00, 0.31148000E+00, 0.49424800E+00, -.57661300E+00, 0.16053700E+00, -.45323100E+00, -.48950900E-01, -.31174000E+00, 0.15488600E-01, 0.12050500E+00, -.58841100E-01, 0.10036200E+00, 0.35214200E+00, 0.99584400E-01, 0.42319100E-01, 0.40587700E+00, -.51046500E-02, 0.31779700E-01, 0.12440000E+00, 0.25045100E+00, 0.83915600E-01, 0.32408500E+00, -.58543800E-01, 0.11413900E+00, -.34073100E-01, -.51203200E-01, 0.24635600E+00, 0.22876100E+00, -.17560800E+00, -.27151500E-01, -.16921700E+00, -.18118900E-01, 0.59942600E-01, 0.13314500E+00, -.32987200E+00, -.39564100E-01, -.56107300E-02, -.35789900E+00, -.47808200E-01, 0.26182800E+00, 0.35138800E+00, 0.20267700E+00, 0.88353500E+00, -.10281200E+00, 0.48921800E+00, 0.18489000E+00, 0.20128600E+00, 0.32423500E+00, 0.66834800E+01, -.21648300E+02, -.16963700E+02, -.80909700E+01, 0.51360900E+01, 0.79037000E+01, 0.14091200E+02, -.72299500E+01, -.14076900E+02, 0.27687300E+02, 0.83761300E+01, 0.34774400E+01, 0.92701300E+00, -.53738500E+01, 0.18362600E+01, 0.10465000E+01, -.12050900E+01, -.16066600E+01, 0.26190700E+01, -.43514000E+00, 0.20300200E+01, 0.41228800E+00, 0.22852900E+01, 0.13862800E+01, 0.36545600E+02, -.65084100E+01, -.12555500E+01, -.72447100E+01, -.37821800E+01, 0.10107000E+02, -.13954200E+02, -.10769400E+02, -.44125900E+01, 0.43140500E+01, 0.40622500E+01, 0.17615700E+01, 0.18860300E+01, 0.80735100E+00, 0.37237500E+01, 0.50353300E+01, 0.25861700E+02, 0.31029000E+02, -.87395400E+01, -.53485200E+01, -.69351000E+01, 0.79100100E+01, -.51505400E+01, -.69719100E+01, 0.12628300E+02, -.11341800E+02, -.11845700E+01, 0.32004700E+00, -.61202000E+01, 0.23752700E+01, -.14337400E+01, -.74067700E+00, 0.10631900E+00, -.62617000E+00, 0.19444900E+00, 0.13218100E+01, 0.84839100E-01, 0.10490100E+01, 0.54461100E+00, 0.15078300E+01, 0.21174400E+00, -.20832100E+00, 0.11456400E+01, 0.60290800E-01, -.14650300E+00, 0.32139700E+00, -.19093100E+00, -.12918600E+01, 0.67644200E+00, 0.34823400E+00, 0.11432100E+01, 0.18676400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.38338800E+01, 0.99439500E-01, 0.47143000E+01, 0.12278100E+02, 0.17721700E+00, -.32193800E+01, -.46700300E+00, -.26642200E+01, -.29344100E+01, 0.48112000E+00, -.17096300E+01, 0.24629500E+01, -.45695300E+00, 0.15548000E+01, -.16067600E+01, -.12372000E+01, 0.35097200E+01, -.11391700E+01, -.59836600E+00, -.80896200E+00, 0.16973200E+01, -.70337600E+00, 0.32091900E+00, 0.54984700E+00, 0.28252500E+00, 0.14952700E+01, -.30011700E+00, 0.54587800E-02, 0.42926400E-01, -.11923400E+01, -.77727500E+00, -.17726900E+01, -.28610800E+01, 0.41936000E+00, -.12651300E+01, 0.14844300E+00, -.58132400E+00, 0.12138400E+00, 0.27179000E-01, -.59088900E-01, -.78467300E+00, -.73016200E-01, -.43389300E+00, 0.50893100E-01, -.24732600E+01, -.75808900E+00, -.20820800E+00, 0.71542600E-01, 0.57666200E-01, 0.61665000E+00, 0.11209000E+01, 0.10080800E+01, -.22686300E+00, -.41562000E+00, -.25527200E+00, -.99932900E+00, -.12213500E+00, -.49761800E+00, 0.36611700E+00, -.16567900E-01, 0.43076300E+00, -.36689500E+00, -.35879000E+00, -.24409100E+00, -.61162200E+00, -.26557700E+00, 0.37912600E+00, -.95747400E+00, -.24184200E+00, 0.74639000E+00, -.11435200E+01, 0.85686500E-01, -.55783500E-02, -.22504300E+00, 0.36060500E+00, -.32237200E-01, 0.11349600E+00, 0.37392600E+00, 0.96018500E-01, -.97117200E+00, 0.58410500E-01, 0.24366600E+00, 0.27876400E+00, 0.20293500E-01, 0.93424700E-01, -.11839000E-01, 0.81151700E-01, -.46397100E+00, 0.85211500E+01, 0.14280200E+01, 0.12599800E+01, -.12179300E-01, -.85448300E+00, -.21953300E+01, 0.19287700E+01, 0.10305400E+01, -.40218900E+02, -.12580500E+03, -.40204200E+02, -.77681400E+01, 0.26729700E+02, 0.24243300E+02, 0.49873500E+02, -.71019600E+01, -.20786600E+02, 0.90151800E+02, 0.29315400E+02, -.10214600E+01, -.16162600E+02, -.21255700E+02, 0.28397800E+02, -.11789700E+02, -.21101300E+02, -.47778000E+01, -.65265900E+01, -.13952900E+02, 0.16214200E+02, -.11220900E+02, 0.15598000E+02, -.96298800E+01, -.11143800E+02, -.45437400E+02, -.23231500E+02, -.13746600E+02, 0.20476600E+02, 0.13646400E+02, 0.17644000E+02, -.23060500E+02, 0.58255400E+01, 0.18725600E+02, 0.23139100E+02, 0.57421400E+01, -.11307300E+02, 0.10925300E+02, 0.21060200E+02, 0.15398300E+02, -.13333800E+03, 0.28921200E+03, 0.35642600E+02, 0.59336600E+02, -.37186400E+02, -.95822400E+02, -.12245600E+03, 0.52466700E+02, -.22455200E+02, 0.14803900E+02, -.54358800E+01, -.29587400E+01, -.57042300E+01, -.57818300E+01, 0.19214800E+02, -.55719600E+01, -.16610600E+01, -.25051500E+01, 0.30998600E+01, 0.23234500E+01, 0.50322500E+00, 0.14258200E-01, -.19182700E+00, 0.72149800E+00, -.26889700E+01, -.49524000E+01, 0.10298000E+00, 0.14335200E+01, 0.39594800E+00, -.48640300E+01, -.71319900E+01, -.15463600E+01, 0.36153600E+01, 0.87422600E+00, 0.48176000E+01, 0.32896900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16169600E+01, -.26852900E-01, -.38404900E+01, -.54825000E+01, 0.13812400E+01, 0.20965500E+01, 0.21154600E+00, 0.11396500E+01, 0.12648400E+01, -.22857200E+00, 0.57744500E+00, -.11832400E+01, 0.11406900E+01, -.12186800E+01, 0.10075100E+01, -.38679400E+00, 0.49550000E+00, -.68628900E+00, 0.17130600E+01, -.36634000E+00, 0.14620600E+01, -.61631200E-01, -.87949400E-01, -.21972000E+00, 0.70933600E-01, -.25357500E+00, -.15570500E+00, 0.20384400E-01, 0.17147200E+00, -.24280200E+00, -.75073700E+00, 0.17881400E+00, 0.30773700E+00, 0.16649700E+00, 0.38344400E+00, 0.17492600E+00, 0.25894600E+00, -.15910900E+00, 0.40517200E-01, 0.48132200E-01, 0.11228400E+01, -.94121500E-01, 0.22706100E+00, 0.41633100E+00, 0.69485100E+01, -.58598100E-01, -.34800500E+01, -.17288500E+00, 0.10091300E+00, 0.17403100E+00, -.10862200E+01, -.60387900E+00, -.35913600E+00, 0.49726500E+00, -.92390600E-01, 0.56860900E+00, 0.16414900E+00, -.72746400E+00, -.69964300E-01, -.25693800E+00, -.53145300E+00, 0.16746500E+00, -.43084200E+00, 0.87458300E-01, 0.54355000E-01, -.10505700E+00, -.47594000E+00, -.54737000E+00, -.65600600E-01, -.83070400E+00, -.75498200E-01, -.16872600E+00, 0.52810700E+00, 0.35826000E-01, -.40428800E+00, -.25519300E+00, -.21413000E+00, 0.75221200E-01, 0.82974300E-01, 0.13832500E+01, 0.56231800E+00, -.37626600E-01, 0.53051000E-01, 0.16509200E+00, 0.49382400E+00, -.52175000E+00, 0.33811800E+00, -.33959100E+00, 0.20214600E+01, 0.16774200E+00, 0.16481900E+01, -.12461000E+00, -.13527600E+00, 0.46705800E-01, 0.57545800E+01, 0.31306800E+00, -.20424400E+02, 0.14581200E+02, -.92588000E+01, -.11699500E+02, 0.21598000E+02, 0.21287100E+02, 0.31246400E+02, -.12116700E+02, 0.11581200E+02, -.61128200E+02, -.13974200E+02, -.61030900E+01, -.12367100E+02, -.64321300E+01, 0.92790600E+01, -.81562400E+01, -.32213000E+01, -.85771500E+01, -.29573200E+01, -.52798400E+01, 0.80397700E+01, 0.84496600E+00, 0.68125200E+01, -.54004500E+01, -.45697800E+01, 0.21682400E+01, -.53334700E+01, -.71538000E+01, 0.21340400E+01, 0.25924500E+01, -.42835900E+01, -.11023100E+02, 0.68569000E+00, 0.35776600E+01, 0.94098100E+01, 0.13921700E+01, -.13078900E+01, 0.58793900E+01, 0.15497000E+02, 0.30692300E+01, -.15467300E+03, 0.12251400E+03, 0.38657700E+02, 0.49708600E+02, -.42955200E+01, -.70929900E+02, -.36746500E+02, 0.47651700E+02, -.11054500E+02, 0.86616500E+01, -.87443200E+01, -.32028500E+01, -.24424300E+01, -.58969500E+01, 0.20409000E+01, -.29480200E+01, -.21488800E+00, -.29190300E-01, 0.16205700E+01, 0.62770000E+00, 0.12294300E+00, 0.17536200E+01, 0.15436800E+01, -.55339600E+00, -.15208800E+01, -.24680900E+01, 0.19868900E+01, 0.45838800E+00, -.42144500E+00, -.40813400E+01, -.59774900E+01, -.16462300E+01, 0.16555800E+01, 0.11731800E+01, -.60600000E+00, 0.20087500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.65722600E+00, -.26648700E-02, -.14010400E+01, -.21038200E+01, 0.15921900E+00, 0.84103100E+00, 0.72342100E-01, 0.17021100E+00, 0.11250200E+00, -.84985400E-01, 0.26272600E+00, -.31385100E+00, -.26483600E-01, -.91089300E-01, 0.13897700E+00, -.45322200E-01, -.28197200E+00, 0.11747600E+00, -.93993900E-02, 0.12018300E+00, -.95147300E-01, -.25779100E-02, 0.57116400E-01, -.25371600E-01, 0.15484600E-01, -.15832400E+00, -.57428400E-01, 0.88638900E-02, 0.87297400E-02, 0.26621000E-03, 0.21461300E+00, 0.11139500E+00, 0.28070300E+00, -.57571700E-01, 0.12015600E+00, 0.89170800E-02, 0.11782300E+00, -.24490700E-01, 0.11229800E-01, 0.21335600E-01, 0.23223600E+00, 0.77721600E-02, 0.45733200E-01, 0.41595600E-02, 0.26647800E+00, 0.21018900E+00, 0.19818400E-01, 0.19639100E-01, 0.20331200E-01, -.21650000E-01, -.99031400E-01, -.24471900E+00, 0.35174300E-01, 0.68823700E-01, 0.29059400E-01, 0.59515000E-01, -.38010800E-01, 0.11657500E+00, -.66006900E-01, -.31100200E-01, -.29119500E-02, 0.11392800E+00, 0.70854100E-01, 0.80847900E-01, 0.32422500E-01, 0.14621400E-01, 0.13590000E-01, 0.11000400E+00, 0.86136300E-02, -.83668900E-01, 0.16085800E+00, 0.18779800E-01, 0.56534900E-01, 0.28960600E-01, -.97666200E-01, 0.81958200E-02, 0.21141900E-01, -.97205100E-01, -.19368000E-02, 0.19771000E+00, -.13098600E+00, -.88634000E-01, -.36454100E-01, -.28128800E-01, -.47148600E-01, -.32085000E-01, -.28617800E-01, 0.10061300E+00, -.10316100E+00, -.84393100E-01, -.10287500E+00, -.14413300E+00, 0.60649600E+00, -.55821800E-01, 0.66106200E-01, -.49882300E+00, 0.51697600E+01, 0.24419300E+01, 0.73645300E+01, 0.77213200E+01, -.12447300E+02, -.83998800E+01, -.17885700E+02, 0.73913000E+01, -.12139300E+02, 0.14636400E+02, 0.54334700E+01, 0.34138300E+01, 0.51924200E+01, -.99419900E+00, -.97676300E-01, 0.54356700E+01, -.11147200E+01, 0.16634200E+01, -.83481400E+00, -.15863800E-02, -.89692400E+00, -.72827200E+00, -.51851300E+00, -.12675700E+01, -.10620000E+02, -.45081800E+01, -.14023300E+01, 0.34588400E+01, 0.15411500E+01, -.17852200E+01, 0.80012500E+01, 0.59937900E+01, 0.39784300E+01, -.42996100E+01, -.25112400E+01, -.15019600E+01, -.58215800E+00, -.40082200E+00, -.23985900E+01, -.33085200E+01, 0.28674200E+01, -.32450500E+02, 0.35237500E+01, -.14866400E+01, 0.46433400E+01, 0.26117700E+01, 0.52410600E+01, -.38075200E-01, -.75152400E+01, 0.87537400E+01, 0.12285100E+01, 0.56212800E+00, 0.41235300E+01, -.16639800E+01, -.16667100E+01, 0.12011000E+01, -.45409800E-01, 0.74625300E+00, -.67798600E+00, -.11740200E+01, -.22462400E+00, -.95707600E+00, -.55117800E+00, -.10894000E+01, 0.17061900E+00, 0.43421700E+00, -.10359900E+01, -.90850300E-01, 0.19425000E+00, 0.26811300E+01, 0.27418400E+01, 0.60642500E+00, -.36469300E+00, -.49154100E+00, -.13553900E+01, -.21348000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14040600E+01, -.32486700E-01, -.82223200E-01, -.39711900E+01, 0.16010400E+01, 0.45409700E+00, 0.12166800E+00, 0.32385500E+00, -.26549600E+00, 0.22351800E-01, 0.55954900E-02, 0.75385200E+00, -.16125300E+00, 0.10209000E+01, 0.18971700E-01, 0.12143800E+00, -.20010600E+01, 0.11915900E+01, 0.31523200E+01, 0.10736600E+01, -.55643400E+00, 0.44484600E+00, 0.33455000E+00, 0.14831400E-01, -.93787800E-01, -.13149600E+01, -.18978500E+01, 0.27410000E-02, 0.11195000E-01, -.16941700E+01, 0.16306300E+00, 0.62442700E+00, -.26498600E+00, 0.40846100E+00, 0.11169700E+01, 0.22124400E+00, 0.52717700E+00, -.75840700E-01, -.16298800E-01, 0.82483100E-01, 0.14185000E+01, -.78832400E-01, -.85732600E-01, -.71430400E-01, -.32499200E+00, 0.18325400E+01, 0.17534500E+01, 0.11072900E+00, 0.29433200E+00, 0.25938400E+00, -.47042900E+00, -.11918000E+01, 0.30266900E+00, -.38914700E+00, 0.98799900E-01, 0.51047100E+00, 0.40482200E+00, 0.52611300E+00, 0.48905700E-01, 0.67203800E-01, 0.68188700E+00, 0.28164700E+00, 0.45549700E+00, 0.23114200E+00, 0.15371800E+00, 0.13925800E+00, 0.46769300E-01, 0.42844700E+00, 0.11646700E-01, -.38315900E+00, 0.10324300E+01, 0.16821500E+00, 0.23366400E+00, 0.18811700E+00, -.12184200E+00, -.25163200E+00, -.88379500E-01, -.47747500E+00, 0.27544000E+00, 0.44403600E+00, -.34641200E+00, -.12493700E+00, 0.16340900E+00, -.11716000E+00, -.22794500E+00, 0.21735600E+00, -.18825100E+00, -.21293500E-01, 0.44555000E+00, -.23072300E+00, -.82313000E+00, 0.18116900E+00, -.58825500E+00, -.10076800E+00, 0.49188300E-01, 0.11024200E+00, -.42984400E+02, -.19633200E+02, 0.15234200E+01, 0.96464800E+01, 0.81482300E+01, -.96314100E+01, 0.88651800E+01, 0.12661900E+02, 0.22655700E+02, 0.58751200E+02, 0.71285400E+01, -.67919200E+01, -.19988800E+01, 0.50871800E+01, 0.26336100E+01, -.92260700E+01, 0.27172800E+01, -.21261400E+00, 0.14309800E+01, 0.12171500E+01, -.86543700E+00, -.25517000E+00, -.74660200E+00, 0.19178600E+01, -.11646100E+02, 0.59014800E+00, 0.68540400E+01, 0.54091400E+01, -.13544100E+01, -.40655700E+01, -.34812700E+01, 0.36550900E+01, -.24886900E+00, 0.29082100E+01, 0.82320900E+00, 0.40661600E+00, -.28778500E+01, 0.10062900E+00, -.58298600E+00, 0.87353200E+00, 0.81408000E+02, -.10769000E+01, -.22728400E+02, -.23850700E+02, -.22472700E+01, 0.30713600E+02, -.73005500E+01, -.25847500E+02, 0.44794600E+01, 0.80871600E-01, 0.48904200E+01, 0.17852400E+01, -.18050400E+01, 0.60107800E-01, -.79732500E+00, 0.16875100E+01, -.86834500E-01, -.27724600E+00, -.34104500E+00, 0.63298600E+00, 0.84581400E-01, -.18590400E+00, 0.29314600E+00, 0.11690100E+01, 0.53576400E+00, -.98054500E+00, 0.50865600E-01, 0.14964500E-01, -.11398500E+00, -.24350700E+01, 0.55231300E+00, -.41155900E+00, 0.59937700E+00, 0.19005700E+00, 0.25492800E+01, -.18619700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.63559000E+00, 0.25733700E-01, 0.18551600E-01, 0.16452300E+01, -.74222100E+00, -.85936800E-01, -.38105100E-01, -.91168500E-01, 0.13008000E+00, -.16770900E-02, 0.98805500E-01, -.30605300E+00, -.10432400E+00, -.18070400E+00, -.81368500E-01, 0.63607100E-01, 0.10474700E+01, -.58205600E+00, -.89169200E+00, -.37502200E+00, 0.81946100E+00, -.27607700E+00, -.55440100E+00, -.12709700E+00, 0.25223900E-03, 0.81186300E+00, 0.79147400E+00, -.10878400E-01, -.11120600E+00, 0.71246000E+00, 0.43028200E+00, -.11401700E+00, 0.34267600E-01, -.14993200E+00, -.31067300E+00, 0.22659000E-01, -.11333800E+00, 0.29783100E-01, -.86274200E-01, 0.12709400E+00, -.83078500E+00, 0.61091000E-01, 0.41308900E-01, 0.53101100E-01, 0.15328100E+01, -.55606700E+00, -.66614100E+00, -.35666900E-01, -.11086900E+00, -.12039200E+00, -.20134400E+00, 0.45069900E+00, -.23912300E+00, 0.34978200E+00, -.32276700E-01, 0.16668100E-02, -.23119800E+00, -.34548900E+00, 0.24055500E+00, -.12762900E+00, -.12706200E+00, -.29418000E+00, -.66940300E-01, -.31045700E+00, -.28179600E+00, -.14551800E+00, 0.27039900E-01, -.52469900E+00, -.21342400E+00, -.69670100E-01, -.40658500E+00, -.81451600E-01, 0.11687600E+00, -.33249200E-01, -.14980500E+00, -.19759500E+00, 0.90552900E-01, 0.11123000E+00, 0.15320200E+00, -.55612500E+00, -.40600700E-01, -.21604500E-01, 0.53586900E+00, 0.29187600E-01, -.39002700E-01, -.27431400E+00, 0.24236400E-02, -.41371100E+00, 0.18896700E+01, 0.24670800E-02, 0.26804900E+00, -.19266200E-01, 0.49844800E+00, 0.11595700E+00, 0.40637100E-01, 0.40392000E+00, -.16543900E+00, 0.43886300E+02, 0.64690600E+01, 0.96114800E+00, -.50515900E+01, 0.13665300E+01, -.75051100E+01, -.98486000E-01, -.23399700E+02, -.59955900E+02, -.34268400E+00, 0.50828400E+01, 0.20904900E+01, -.12414600E+02, 0.42049000E+01, 0.70427900E+01, 0.15153900E+01, 0.90421600E+00, -.21852000E+01, 0.12618700E+00, -.62586300E+00, 0.14950900E+01, -.10354300E+01, -.18445800E+01, 0.13791300E+01, 0.15543600E+01, 0.26921000E+01, 0.89517800E-01, -.31996300E+01, -.15370000E+01, 0.10729100E+01, 0.17239400E+01, -.43336200E+00, -.64997200E+00, -.25729700E+01, -.14107600E+01, 0.18244000E+01, 0.78119500E+00, -.26509400E+00, -.33278500E+01, -.59149600E+02, -.28924900E+02, 0.15493300E+02, 0.18860000E+02, 0.35600800E+01, -.21996300E+02, -.60157000E+01, 0.20357400E+02, 0.20042400E+00, -.23232600E+01, -.72011100E+01, -.51994800E+01, 0.38336600E+01, 0.17834300E+01, 0.59518400E+01, -.56151300E+01, 0.13805700E+00, 0.37027000E+00, 0.74764900E+00, -.82179700E+00, 0.68286600E-02, -.51138500E-01, -.27280800E+00, -.11424800E+01, 0.39375100E-01, -.88755400E-01, -.13652600E-01, -.91675200E-01, -.24636900E+00, 0.61827400E+00, -.97132700E+00, 0.83714300E+00, -.79886700E+00, 0.22774500E+00, -.23449600E+01, 0.13851300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.49119700E+00, -.20630500E-01, 0.93624400E-02, -.11921000E+01, 0.66291900E+00, 0.10813100E+00, 0.53181300E-01, 0.74277000E-01, -.72175000E-01, 0.21144400E-02, -.23307300E+00, 0.25595900E+00, 0.26192600E+00, -.72543000E-01, 0.81398400E-01, -.62325700E-01, -.62930200E+00, 0.35315400E+00, 0.11704300E+01, 0.22428200E-01, -.25252600E+00, 0.16759400E+00, 0.45054500E+00, 0.19292000E+00, 0.54601200E-02, -.56284300E+00, -.61873400E+00, 0.13127300E-02, -.29410300E-01, -.82983700E+00, -.22125500E+00, 0.25216200E+00, -.24574800E+00, 0.24704600E+00, 0.35352000E+00, 0.98180800E-01, 0.11554600E+00, -.21806900E-01, -.13546000E-02, -.70376500E-02, 0.51004300E+00, -.63826600E-01, 0.53647200E-02, 0.30559900E-01, 0.31689300E+00, 0.63212400E-01, 0.11128100E+01, -.24066500E-01, 0.36606800E-01, 0.11928300E-01, -.38583800E-01, 0.16286400E+00, 0.17113300E-01, -.52273000E-01, 0.42169700E-01, 0.15216800E+00, 0.22907100E+00, 0.19270600E+00, -.11363000E+00, 0.49528100E-01, -.17465600E-01, 0.12151400E+00, 0.14178600E-01, -.28637500E-01, 0.12967300E+00, 0.11342200E+00, -.83888900E-01, 0.21628800E+00, 0.16674500E+00, 0.35690300E-02, 0.24071100E+00, 0.24962400E-01, -.51315100E-01, 0.30746300E-01, 0.10724100E+00, 0.93749200E-01, -.83053100E-01, -.53343000E-01, -.47997400E-01, 0.38709900E+00, 0.91853100E-01, -.47992900E-02, -.23150200E+00, 0.20878900E-01, 0.39100300E-01, 0.12124500E+00, 0.43271100E-01, 0.11019000E+00, -.86868300E+00, -.29888300E-01, -.85458300E-01, -.88901500E-03, 0.63490000E+00, 0.53836200E-01, -.67579700E-01, 0.57662500E+00, 0.15946900E+00, 0.40492300E+00, 0.83893100E+01, -.62881700E+00, 0.52332700E+01, -.13947600E+01, 0.71697300E+00, -.88089500E+00, 0.35047000E+02, -.15229900E+02, -.15598400E+02, -.82514800E+01, -.43461200E+01, 0.14458000E+02, -.65427600E+01, -.75893000E+01, 0.17713900E+01, -.69716300E+00, 0.69441200E+00, 0.11951700E+01, -.16172700E+01, 0.11817100E+00, -.17687200E+01, 0.12439500E+01, -.18249800E+02, 0.11652200E+02, -.53915000E-01, 0.26316200E+01, 0.21210800E+01, -.53724000E+01, 0.46987700E+01, 0.37070500E+01, 0.15287900E+01, -.26817600E+01, -.17179400E+01, -.40074200E-01, -.72762700E+00, -.12838900E+01, -.18534000E+01, -.10738300E+01, 0.39433900E+01, -.21299600E+01, -.19340600E+01, -.47545600E+01, 0.40289800E+01, 0.53572400E+01, 0.14686500E+02, -.43253100E+01, -.39281400E+01, 0.36122100E+01, 0.41452300E+01, 0.21852400E+01, 0.44363400E+00, -.15685600E+01, -.31464100E+01, 0.32505800E+01, 0.22814400E-02, 0.16864600E+00, -.52828300E+00, -.21046300E-01, 0.35934400E-01, 0.60466700E-01, 0.21773600E+00, 0.23846200E-01, -.16851800E+00, 0.61997600E+00, -.21265400E-01, -.32540800E-01, 0.12989400E+00, -.18434300E+01, -.73581900E+00, 0.13114600E-01, -.40572300E+00, -.99616700E-01, 0.31808600E+00, -.14088900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.58079300E+00, -.58535400E-02, -.14005400E+01, -.20048400E+01, 0.31816200E+00, 0.81627300E+00, 0.58660000E-01, 0.41591600E+00, 0.42056100E+00, -.12034400E+00, 0.49198600E+00, -.58772800E+00, -.46811600E-01, 0.86818700E-01, 0.28621000E+00, 0.23547300E+00, -.70816000E+00, 0.20990800E+00, 0.20090200E+00, 0.48612800E+00, -.36057600E+00, 0.12504100E+00, -.23676200E+00, -.18073400E+00, -.71284400E-01, -.27274500E+00, 0.78707900E-01, 0.10018100E-01, 0.16914600E-01, 0.31663400E+00, 0.45434500E+00, 0.35699500E+00, 0.60764600E+00, -.13229700E+00, 0.28481800E+00, -.89165200E-02, 0.18085200E+00, -.70451500E-01, -.19208600E-01, 0.98742000E-01, 0.40304700E+00, 0.26310000E-01, 0.60036500E-01, 0.55586600E-01, 0.73493900E+00, 0.36628300E+00, -.22282400E+00, 0.10847200E-01, 0.25068000E-01, -.66299300E-01, -.26925700E+00, -.33668500E+00, 0.32655600E-01, 0.66657800E-01, 0.34486300E-01, 0.70438400E-01, -.97718000E-01, 0.10346400E+00, -.48876300E-01, -.29058000E-01, -.13316500E+00, 0.76264700E-01, 0.67995100E-01, -.30805300E-01, 0.11582800E+00, -.22234200E-01, -.63746000E-02, 0.38573100E-01, -.49732200E-01, -.19390300E+00, 0.18842600E+00, -.21945600E-01, 0.47423100E-01, 0.28938100E-01, -.17669600E+00, -.78809500E-01, 0.57613800E-01, -.47921600E-01, 0.28602600E-01, 0.14506900E+00, -.17007300E+00, -.99073800E-01, 0.18568700E-01, -.40904500E-01, -.10263100E+00, 0.10473100E+00, -.79715400E-01, 0.92452200E-01, -.14278500E+00, -.11407900E+00, -.33435300E+00, 0.63045400E-01, -.94705600E-01, -.42357500E-01, 0.37340100E-02, -.29790500E+00, 0.13794800E-01, -.28197400E+00, 0.67686500E+00, 0.52088100E+01, -.77527900E+01, -.35395900E+01, -.94682400E+01, 0.57312000E+01, -.26679800E+02, 0.21891600E+02, 0.11864800E+02, 0.55782600E+01, 0.47301300E+01, -.10048600E+02, 0.46590900E+01, 0.59272600E+01, -.13197400E+01, 0.17375200E+01, -.34899100E+00, -.22278100E+00, 0.32927900E+00, -.27232900E+00, 0.73198300E+00, -.11255400E+01, -.61675100E+00, -.50158200E+01, 0.94813200E+00, 0.17387700E+01, -.72454000E+00, -.72514800E+00, 0.16047300E+01, 0.23638700E+01, 0.16250900E+01, -.21442200E+00, -.13558700E+01, -.13136600E+01, 0.64689600E+00, 0.10069800E+01, -.15612200E+00, -.18847500E+01, 0.46883700E+01, -.21744100E+02, 0.18940700E+01, 0.71874900E+00, -.62984800E+00, 0.31502800E+00, -.85165900E+01, 0.94126100E+00, 0.42216400E+00, 0.15124800E+01, -.23189800E+01, -.17711500E+01, 0.23801700E+01, 0.79274300E+00, 0.25167500E+01, -.20210400E+01, 0.36135200E-01, 0.21024800E+00, 0.43676900E-01, -.61106600E+00, -.10960700E+00, -.43181600E+00, -.33632900E+00, -.49940000E+00, 0.20472800E+00, -.30819300E+00, -.38940300E+00, -.76265100E-01, -.10033100E+00, 0.18111900E+01, 0.14900000E+01, 0.17796900E+00, -.22958800E+00, 0.16814600E-01, -.65857400E+00, 0.79269400E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11788300E+01, 0.43454200E-01, 0.31064200E+01, 0.10414500E+02, 0.50629900E+00, -.15713200E+00, -.34489900E+00, -.15071100E+01, -.16006400E+01, 0.11761300E+00, 0.48156100E+00, 0.10749900E+01, -.21339700E+01, 0.34217100E+01, -.10898500E+01, 0.75021100E+00, -.12740300E-01, 0.37466800E+00, 0.69230800E+00, 0.11793500E+01, 0.25442800E+01, -.43501100E+00, -.74825900E+00, -.69892800E+00, -.30632900E+00, -.15926600E+01, -.99023900E+00, 0.70274100E-01, 0.29087600E+00, 0.10626800E+01, 0.24766500E+01, -.44589800E+00, 0.89248800E-01, -.70588300E+00, 0.18841700E+00, 0.15066300E+00, -.59232300E-01, -.11107400E+00, -.44213500E+00, 0.89182800E+00, -.14746200E+01, 0.17627700E+00, -.65298500E-02, -.38079400E+00, -.25365200E+01, 0.19747800E+00, 0.32231800E+01, 0.13233700E+00, 0.29297600E+00, 0.66441100E+00, -.23166800E+00, -.17698400E+01, 0.32998100E-01, -.10465400E+01, -.21763600E+00, -.10451500E+01, -.93895300E+00, -.45781000E+00, 0.30904500E+00, 0.18619500E+00, 0.69175800E-01, -.23989300E+00, 0.86411700E-01, 0.10364600E+00, -.91464100E-01, 0.89342200E-01, -.11640000E+00, 0.11056100E+01, 0.70800600E+00, 0.25726100E+00, 0.68107100E+00, -.75869400E-01, -.40484800E+00, 0.16820300E-01, 0.22667800E+00, 0.71920700E-01, -.69837900E-01, -.10163500E+00, -.47477900E+00, -.76479900E+00, 0.96837200E-01, 0.22559500E+00, -.62606800E+00, -.49631800E-01, -.16158300E+00, 0.70957800E+00, -.17078700E+00, 0.17914600E+00, -.17850600E+01, 0.85299100E-01, -.25082900E+00, 0.50879600E-01, 0.52492700E+00, 0.11476600E+00, -.43376800E+00, 0.40045200E+00, 0.27182900E+00, 0.85416000E+00, 0.36054800E+00, -.42040700E+00, -.11141600E+02, -.16575800E+02, -.10765800E+02, -.17719700E+00, 0.21431100E+02, 0.35048500E+01, 0.62089300E+01, 0.84314700E+01, -.22326800E+00, 0.16373600E+02, -.10304900E+02, 0.95321600E+01, 0.40139800E+01, -.48478700E-01, 0.50382700E+00, 0.15676400E+01, -.40855700E+01, 0.11762700E+00, -.52929600E+01, 0.27907400E+01, 0.41993100E+02, -.70695300E+01, -.65817600E+01, -.77612400E+01, -.11484800E+01, 0.15195800E+02, -.28060200E+01, -.67564200E+01, -.31576800E+01, -.66134300E+01, 0.38958300E-01, 0.24685800E+01, 0.43836900E+00, -.47721300E+01, -.59722600E+01, 0.32657500E+01, 0.90148600E+02, -.22137300E+02, -.34962000E+02, -.32014300E+02, 0.82633500E+01, 0.43616400E+02, 0.28828300E+02, -.30423800E+02, 0.11946200E+02, -.11842400E+02, 0.67786400E+01, 0.41901800E+01, -.67640500E+01, 0.27547600E+01, -.81445500E+01, 0.36383800E+01, -.13576800E+00, 0.47346000E+00, -.16005200E+01, 0.12531400E+00, -.13816000E+00, -.10591100E+01, -.43366900E+00, 0.27423400E+00, 0.11510200E+01, 0.23796600E+01, -.11908400E+01, 0.61307900E-02, 0.38441900E+00, 0.52695000E+01, 0.50358400E+01, 0.68485100E+00, -.34661800E+00, -.13124700E+01, 0.11148700E+01, -.59228400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14754500E+01, -.75309200E+00, -.13842600E+00, 0.45203000E+00, -.11457100E+01, -.46445700E+00, 0.18964600E+00, 0.84902000E-01, -.39081700E+00, -.74802500E+00, 0.19895300E+00, -.82354800E+00, 0.22923800E+00, -.70575000E+00, 0.68411900E-01, -.25683100E+00, 0.78244600E+00, 0.11806900E+01, 0.33437700E+01, -.45779000E+00, 0.13490100E+01, -.12708200E+01, 0.90059000E+00, 0.46892200E+00, 0.70009700E+00, 0.86341300E+00, -.23758200E-01, 0.17374000E-01, -.50718300E+00, -.10897400E+01, 0.69894200E+00, 0.19158300E+00, 0.87469000E+00, 0.20856200E+00, 0.12077300E+01, 0.55356200E+00, -.93909600E+00, -.92146000E-01, 0.29703100E+00, 0.71310700E-01, 0.24189000E+01, -.18070700E+00, 0.23085100E+00, 0.38179300E+00, 0.26940600E+01, -.10362200E+01, 0.21469700E+01, -.22282200E-01, -.18689300E+00, -.23982500E+00, 0.12378500E+00, 0.18605200E+01, -.57289000E+00, 0.62322400E+00, 0.11246600E+00, -.40062900E+00, -.22351300E-01, 0.19401800E+01, -.73840100E+00, -.77689300E-01, 0.78587700E+00, 0.80662600E+00, -.90921500E+00, 0.39353900E+00, -.35523100E+00, -.28272500E+00, 0.66886300E+00, -.97547500E+00, -.19447900E+00, 0.34700400E+00, -.73127100E+00, 0.30296500E+00, 0.78041100E+00, 0.65521700E-01, -.22907800E+00, 0.17364800E+00, 0.32151600E+00, -.23452800E-01, 0.32232400E+00, 0.28143300E+00, -.90423100E+00, 0.53775300E+00, 0.98369300E+00, -.19305400E+00, 0.36912800E-01, -.87447200E+00, 0.13784800E+00, -.84391400E-01, 0.36886700E+01, 0.51009300E+00, -.34990300E+00, 0.76574800E+00, 0.14717900E+01, 0.23943200E+00, -.12026100E+00, 0.46410800E+00, 0.24817300E+00, -.18120600E+01, 0.28034400E+01, 0.44172800E+00, -.25376700E+00, 0.26961500E+02, 0.48761100E+01, -.29266000E+01, -.10360800E+03, -.58523000E+01, 0.91690400E+01, 0.57793100E-01, 0.11735000E+02, -.53507300E+02, 0.37168700E+02, 0.18349200E+01, 0.27933900E+01, 0.19587300E+01, -.11653400E+02, -.44240900E+01, 0.53821300E+01, 0.25825900E+01, 0.44971800E+01, -.92235400E+01, -.30439000E+01, -.23372900E+02, -.45123200E+01, -.15244500E+02, 0.10752400E+02, 0.84187200E+00, 0.18259900E+02, -.13674600E+02, 0.35436400E+01, 0.19995400E+02, -.55645300E+01, -.83408000E+01, 0.87239200E+01, 0.10716800E+02, 0.12552000E+02, -.91108900E+01, -.28053600E+03, 0.72633500E+02, 0.75219300E+02, 0.96981000E+02, 0.34005400E+00, -.12756500E+03, -.87248400E+02, 0.97183400E+02, -.40658600E+02, 0.31318600E+02, -.52023200E+01, -.10231400E+02, 0.13998100E+02, -.10261200E+02, 0.25095800E+02, -.10056800E+02, 0.43772800E+00, -.42559600E+00, 0.14600000E+01, 0.40575500E+00, 0.16709100E+00, 0.11817400E+01, 0.12810300E+00, -.10706300E+01, -.12154600E+01, -.39173900E+01, 0.16116000E+01, -.37475600E-01, -.12856400E+01, -.12060500E+01, -.60408700E+01, 0.23154500E+01, 0.53757800E+00, 0.31185400E+01, -.59452900E+01, 0.16769600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.82170700E+00, 0.95870900E-02, 0.17240800E+01, 0.27071000E+01, -.22230100E+00, -.92271000E+00, -.80320800E-01, -.15146100E+00, -.12052700E+00, 0.79539300E-01, -.16306800E+00, 0.22258700E+00, -.13447200E+00, 0.38817400E+00, -.24055800E+00, 0.20675700E+00, 0.57625000E-01, -.71310400E-01, -.56975600E+00, 0.16691400E+00, -.22792200E+00, -.32966600E-01, 0.66334500E-01, -.27085700E-01, 0.24409300E-01, 0.11312900E+00, 0.27713500E+00, -.22596400E-02, 0.73061500E-01, 0.26434000E+00, -.44177000E+00, -.31039700E+00, -.91242900E-01, -.10510900E+00, -.22485500E+00, -.10640300E+00, -.48068600E-01, 0.10827700E-01, -.14083900E-01, -.57556200E-01, -.23419900E+00, 0.46592600E-03, -.12461700E+00, -.66707700E-01, -.16441000E+01, 0.35337300E+00, -.93382300E-01, 0.69924500E-01, 0.12008100E+00, 0.26305300E+00, 0.26627400E+00, -.80546800E+00, 0.12724600E+00, -.47604400E+00, -.70551000E-01, -.51572800E+00, -.28294000E+00, 0.32042200E-01, 0.11558800E+00, 0.17784400E+00, 0.23880300E+00, -.13140900E+00, -.11768400E-02, 0.17269900E+00, -.85550000E-01, -.30804800E-01, 0.86433200E-01, -.24724200E+00, -.74896700E-01, 0.94324300E-01, -.17928300E+00, 0.10579400E-01, -.13724400E+00, -.57279100E-02, 0.11421700E+00, -.10490800E+00, 0.87815600E-01, 0.77061900E-01, 0.67947300E-01, -.57614500E+00, -.39261200E+00, -.38285400E-01, 0.30373300E+00, -.92262900E-01, -.29689200E+00, 0.22450800E-01, -.26799200E+00, -.39835400E+00, 0.11237600E+01, -.18814600E+00, -.55808300E+00, 0.59013100E+00, 0.41328100E+00, 0.11714900E-01, -.21751600E-01, 0.73922900E+00, 0.34277800E-02, 0.70248200E+00, -.46041000E+00, -.32058100E+00, -.19700700E+00, -.28871700E+00, -.59493100E+01, -.76116700E+00, -.71489100E+01, 0.18997600E+00, 0.31070300E+01, 0.19043500E+01, -.21868800E+01, -.48254500E+01, 0.29362100E+01, 0.26628000E+01, 0.28392700E+01, 0.57815400E+00, -.38607300E+01, -.68104000E+00, -.10838000E+00, 0.81080100E+00, -.55097000E+00, -.18750700E+01, 0.11265600E+02, -.11109900E+02, -.45449000E+01, -.67510900E+01, 0.37947800E+01, 0.50440300E+01, 0.71303900E+01, -.52723100E+01, -.16095000E+00, 0.35747200E+01, -.23610000E+01, -.11922700E+01, 0.26067100E+01, 0.68606500E+00, -.15050600E+00, -.14764400E+01, -.41179000E+02, 0.11620500E+01, 0.97618700E+01, 0.14676700E+02, 0.16307500E+01, -.18079300E+02, -.12116200E+02, 0.15898700E+02, -.85578400E+01, 0.59031500E+01, 0.66701400E+00, -.13125100E+01, 0.19550700E+01, -.18928100E+01, 0.42042000E+01, -.17234400E+01, 0.39035800E-01, -.27803300E+00, -.21341900E+00, -.84291500E-02, 0.14737900E+00, 0.32401200E-01, 0.17740700E-01, -.27764200E+00, -.18155300E+00, -.17212400E+00, 0.90786000E-01, -.37576700E-01, -.47933900E+00, 0.93458700E+00, -.57840400E+00, 0.98709200E+00, 0.77205900E-01, 0.55512500E+00, -.12360800E+01, -.10339200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15398200E+01, 0.20565600E-01, 0.33209500E+01, 0.55063600E+01, -.52481900E+00, -.15637600E+01, -.37331600E-01, -.22769900E+00, -.74328400E-01, 0.11963200E+00, -.77132400E+00, -.29423900E-01, -.40575600E+00, 0.43285300E+00, -.51817000E+00, 0.60686600E+00, 0.34026800E+00, -.30379900E+00, -.12083100E+01, 0.60187700E+00, 0.63958400E+00, -.52829600E+00, -.58606700E+00, -.66284900E+00, 0.14101500E+00, 0.11879700E+01, 0.58116600E+00, -.89070100E-01, 0.85646000E-01, 0.54269200E+00, -.42630500E+01, -.87015600E+00, -.26810700E+00, 0.10402500E+00, 0.16290200E+00, -.50025600E+00, -.16665300E+01, -.41877500E-01, 0.11672300E+00, -.14998900E+00, 0.64354900E-01, 0.48784700E-01, -.75484700E+00, 0.76821700E+00, -.82259300E+00, 0.64366100E+00, 0.32902500E+00, 0.43406900E-01, -.49781800E-01, -.38643700E+00, -.96926200E+00, -.99241500E+00, 0.13239700E+00, -.10437600E+00, -.26404500E-01, 0.63068800E-01, -.60891500E+00, -.75086400E+00, 0.27867000E+00, 0.70376900E-01, -.91773800E+00, -.45082100E+00, 0.46923000E+00, -.15024900E+01, 0.45531600E+00, -.15922900E+00, -.10775500E+00, 0.11106300E+01, -.11198300E+00, -.29717000E+00, 0.78765300E+00, -.19133700E+00, -.57079700E-01, -.57000200E-01, -.25083900E+00, 0.10937600E+00, -.17592100E+00, 0.12901200E+00, -.41310100E+00, -.14507500E+00, 0.58663400E+00, -.16036700E+00, -.19507000E+00, 0.85478900E-01, 0.34428500E+00, -.21036200E+00, 0.39177400E-02, 0.25962200E+00, -.10756900E+01, 0.26442100E+00, 0.35171500E+00, -.45239900E+00, -.11541400E+01, -.33483000E-01, -.26830300E+00, -.13525400E+01, 0.24730900E+00, 0.45146300E+00, -.27850800E+01, -.16135100E+00, -.40900600E+00, -.30086900E+00, -.46922700E+00, -.45059400E+01, 0.49830200E+02, -.51670600E+02, -.13273300E+02, -.46299500E+01, -.14290800E+02, 0.18965100E+02, -.63111300E+01, -.89854900E+00, -.66501300E+00, -.24112300E+01, -.74008900E+01, -.33657800E+01, 0.20382600E+01, -.11983300E+01, -.33676700E+00, -.34549300E+01, -.13592500E+02, -.16535900E+01, -.54749200E+01, -.29577700E+01, 0.30527100E+01, -.17243900E+01, 0.12874800E+02, -.26158300E+00, -.18626400E+00, 0.77897400E+00, 0.35161000E+01, 0.15164700E+01, -.13864300E+01, 0.33095400E+00, 0.21251100E+01, 0.71090000E+00, -.68708900E+02, 0.32180700E+02, 0.11938900E+02, 0.18632900E+02, 0.80629700E+01, -.30284400E+02, -.27665800E+01, 0.20879800E+02, -.21562200E+02, 0.13889400E+02, 0.51202500E+01, 0.27724400E+01, -.78033800E+00, -.69067000E+01, -.82637400E+00, 0.40053800E+01, -.15748900E+00, 0.12297600E+00, 0.11475100E-01, -.13306400E+00, 0.69349300E-01, 0.75290200E-01, -.24236900E+00, -.93974800E+00, -.57621100E+00, -.31744400E+00, -.11717900E+00, 0.21127200E+00, 0.15990300E+00, 0.13371500E+01, -.71888300E+00, 0.17168100E+01, -.39000400E+00, -.85997400E-01, -.11020600E+01, -.20342700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18077000E+01, 0.28643500E-01, 0.63579100E+00, 0.40863700E+01, -.24402600E+01, -.73423400E+00, -.94168400E-01, 0.58834900E+00, 0.86073700E+00, 0.66550500E-01, -.14176300E+01, -.25172600E+00, 0.11018800E+01, -.17806100E+01, -.63281800E+00, -.54679300E+00, 0.22595900E+01, -.14599900E+01, -.13169900E+01, -.13448800E+01, 0.17210000E+00, -.11910400E+01, 0.19921400E+01, 0.10285400E+01, 0.91733900E+00, 0.27300900E+01, 0.24884200E+01, -.69534100E-01, -.76263000E+00, -.72686000E+00, -.83822100E+00, -.75993000E+00, -.23592100E+00, -.65675200E-02, 0.32146100E+00, 0.32076400E+00, -.48213200E+00, 0.45061200E+00, 0.17019000E+00, -.65953400E+00, -.22526900E+01, -.93051300E-01, 0.82318800E-01, -.57331200E+00, -.40008100E+01, -.18674300E+01, 0.13965200E+01, -.65322900E-01, -.30271500E+00, -.20922800E+00, 0.14851700E+01, 0.15241600E+01, 0.83139900E-01, 0.87520800E+00, -.55279600E-01, 0.51087300E+00, 0.84976000E+00, -.11818500E+01, 0.29804500E+00, 0.50032100E-01, 0.24129500E+00, -.10904200E+01, -.10727900E+01, 0.16485300E+01, -.99704000E+00, 0.66666000E+00, -.52808900E+00, -.63513300E+00, 0.95476400E+00, 0.17077400E+00, -.21824600E+00, 0.11275000E+00, -.78396300E+00, 0.76628500E-01, 0.61860800E+00, -.40528300E+00, -.21467600E-01, 0.37383000E+00, -.33447900E+00, -.96418600E+00, -.65580200E-01, 0.51510100E+00, 0.37594000E-01, 0.26541300E-02, -.81983200E-01, 0.32769200E+00, -.61946000E-01, -.26121800E+00, -.27180000E+00, 0.16866500E+00, 0.20026200E+00, 0.95011000E-02, 0.73269600E+00, 0.17014300E+00, -.10825100E-01, 0.72521100E+00, -.75140700E-01, 0.12445400E+01, 0.41821900E+00, -.51318400E+00, 0.53919800E+00, 0.15845800E+00, 0.18682700E+00, -.59408500E-01, -.46060400E+02, 0.23778600E+02, 0.21185600E+00, 0.12313100E+01, 0.13655600E+02, -.13094500E+02, 0.77020400E+01, 0.29574900E+00, -.30072100E+01, 0.33366600E+01, 0.13809300E+01, 0.13528400E+00, 0.45106000E+00, 0.79569100E-01, 0.25598100E+01, -.26108200E+00, 0.15021200E+02, -.37491400E+01, -.77700900E+01, -.71403900E+01, 0.32155000E+01, 0.84374700E+01, 0.55348600E+01, -.83129800E+01, 0.13025400E+01, 0.37486800E+00, -.40092900E+00, 0.15564400E+00, -.63775700E+00, -.48250000E+00, -.50823500E+01, 0.76676100E+00, -.86792400E+02, 0.40062100E+02, 0.30927800E+02, 0.28098700E+02, -.49605400E+01, -.36866800E+02, -.66700900E+01, 0.27260000E+02, -.45065300E+01, 0.11520600E+01, 0.36015800E+01, 0.47884100E+01, -.34362500E+01, -.12545100E+01, 0.31968000E+01, 0.54178000E+01, 0.40482500E-01, 0.17079900E+00, -.32247600E-01, 0.72151000E+00, 0.22629500E-01, 0.51260000E-01, 0.44753000E+00, 0.72308600E+00, -.34289700E+00, -.16457300E+00, 0.95927000E-01, 0.27029600E-01, 0.14696300E+00, -.46201200E+00, 0.15383700E+00, -.34816100E+00, -.53113700E+00, -.31561400E+00, -.22134000E+01, -.34872900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.53719100E+00, -.32406100E-01, -.28419700E-01, -.14245800E+01, 0.63944700E+00, 0.18983100E+00, 0.79114500E-01, 0.15681600E+00, -.51258900E-01, -.43411300E-01, -.17252600E+00, 0.24769500E+00, 0.18550200E+00, -.18752600E-01, 0.11430100E+00, 0.32397800E-01, -.82336600E+00, 0.53736000E+00, 0.14387800E+01, 0.97403000E-01, -.32597500E+00, 0.21455400E+00, 0.42629700E+00, 0.18006900E+00, -.17543400E-01, -.73296400E+00, -.64713700E+00, 0.12292000E-01, 0.28089500E-01, -.70216200E+00, -.38891700E+00, 0.22403800E+00, -.22816400E+00, 0.23991700E+00, 0.36069200E+00, 0.67524800E-01, 0.10413100E+00, -.31127600E-01, -.23669600E-02, 0.94462000E-02, 0.52495700E+00, -.56300300E-01, -.62731200E-02, 0.47296700E-01, 0.46130700E+00, 0.98294000E-01, 0.30766400E+00, -.29473700E-01, 0.84933900E-02, -.53263800E-01, -.96696400E-01, 0.38227500E+00, 0.23369100E-01, 0.27187500E-01, 0.71518800E-01, 0.34248800E+00, 0.29588000E+00, 0.23615400E+00, -.13123100E+00, -.57760000E-01, -.41711600E-01, 0.16025600E+00, 0.14880500E+00, -.81739600E-01, 0.20118800E+00, 0.11308300E+00, -.82864100E-01, 0.40298200E+00, 0.90171900E-01, -.93188300E-01, 0.37325200E+00, 0.34215300E-01, 0.31927100E-03, 0.37518000E-01, 0.19150300E-02, 0.85397200E-01, -.46440100E-01, -.73458900E-01, -.40385200E-01, 0.52400100E+00, 0.13030500E+00, -.78264400E-01, -.24031400E+00, 0.11949900E-01, -.12286900E-01, -.22934500E+00, 0.37306800E-01, 0.10852800E+00, -.15126200E+00, -.81356000E-01, 0.61281100E-01, 0.17332300E+00, 0.19706100E+00, -.36493600E-01, 0.72778500E-01, 0.96149800E-01, -.23216600E+00, -.46202800E+00, 0.30104100E+00, 0.47809600E+00, 0.20636600E-01, 0.16429000E+00, 0.22830800E+00, -.19170900E+00, -.11039700E+00, -.11647900E+02, -.22276200E+01, -.63445100E+00, 0.18633200E+01, 0.97740300E+00, 0.61552300E+00, -.62064100E+00, -.12647100E+01, -.11208200E+01, 0.15925700E+01, 0.11748900E+00, 0.72827600E-01, -.11511300E+00, 0.60055400E+00, 0.32603700E+00, 0.60628500E+01, 0.47131000E+01, 0.75004500E+00, 0.40580800E+00, -.43150300E+01, 0.17339500E+01, -.22347100E+01, -.65795700E-01, 0.22705200E+00, -.21237500E+01, 0.17852300E+01, 0.13585700E+01, -.16313200E+01, -.15430200E+00, -.34873600E+00, 0.14789600E+01, 0.41537600E+01, 0.35613700E+01, -.18499600E+01, -.21685700E+01, 0.10784900E+01, 0.30118900E+01, 0.45930900E+01, -.23021600E+01, 0.39575400E+01, -.41811600E+01, 0.66106500E-01, 0.50101200E+00, -.16922100E+01, 0.68989000E+00, -.19559000E+01, 0.74151900E+00, -.32929300E-01, 0.31246100E+00, 0.20321700E-01, 0.18334800E+00, 0.27259200E-01, 0.43190500E+00, 0.27466700E+00, 0.29232000E+00, 0.26798200E-01, 0.15838000E+00, 0.45553800E+00, 0.67977100E-01, 0.11166900E+00, -.14108100E+00, 0.21066700E+00, -.62922400E+00, -.48413100E+00, -.13389200E+00, -.14293600E-01, 0.10323700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.43399900E+00, -.21113800E+00, -.31491200E+00, -.46648700E+01, -.98919300E+00, -.32707700E+00, -.35603300E+00, 0.37541900E+00, 0.53737000E+00, -.12680200E+00, 0.51764100E-01, -.31183900E+00, 0.28519300E-01, -.26642600E+00, -.13407700E-01, -.18434100E+00, 0.37435700E+00, -.48142500E+00, -.14976800E+00, -.27970900E-01, 0.46492300E+00, -.19652500E+00, -.20556800E-01, -.85756500E-01, 0.12498900E+00, 0.83188200E+00, -.10350400E+00, -.23208700E-01, -.16099600E+00, -.22322700E+00, 0.87828100E+00, 0.31616400E+00, 0.13529000E+00, 0.24619700E+00, -.87773500E-01, 0.14185100E+00, 0.51040100E-01, 0.63337500E-01, 0.75480100E-02, 0.25008900E-01, 0.54069600E-01, -.67283700E-01, -.76961300E-02, -.15881200E+00, -.11189900E+01, -.39926900E+00, 0.18512100E+01, -.31171700E-01, -.65850100E-01, -.18981100E+00, -.76191000E-01, 0.31973000E+00, 0.26861500E-01, 0.95825500E-01, -.13053900E-01, 0.26547500E-01, 0.57321600E-01, -.76851100E-01, -.90473000E-01, -.50038700E-01, -.65091000E-01, 0.13595900E+00, -.20959400E-01, -.23247900E+00, 0.33874300E-01, 0.93698300E-01, -.63969000E-01, 0.11881700E+00, 0.82490100E-01, -.42786900E-01, 0.14996200E+00, 0.84911700E-02, -.89028900E-01, 0.27107400E-01, 0.10710000E+00, 0.37676600E-01, -.28069000E-01, 0.10628800E-01, 0.16370700E-01, 0.13487700E+00, -.74015600E-02, 0.28681800E-01, 0.29508300E-01, -.37655200E-01, 0.73432100E-01, 0.16777200E+00, 0.55460200E-02, -.23776200E-02, -.49890700E+00, -.24481600E-01, -.19196900E+00, -.59622200E-01, -.36317300E+00, -.73430100E-01, -.63759300E-01, -.28399100E+00, -.10743600E+00, -.25155500E+00, -.31533200E+00, 0.38552300E+00, 0.12048600E+00, -.31209800E-01, -.37031900E+00, 0.14665400E+00, 0.12660000E+00, -.97474900E-01, 0.15975800E+01, -.59903100E-01, -.42666100E+00, 0.36345100E+00, 0.10211700E+01, -.11312800E+00, 0.24511900E+00, -.81174400E+00, -.31335900E+00, 0.73043300E-01, 0.31905400E+00, -.26017600E+00, 0.94393900E-02, -.23874800E-01, -.19062700E+01, -.24378800E+01, 0.18876600E+01, 0.12467400E+01, -.78029500E+00, -.17135500E+01, -.24430400E+01, 0.15034400E+01, -.12050700E+01, 0.14402900E+01, 0.86719900E+00, 0.18551400E+00, -.14537800E+00, -.39389800E-01, 0.17952600E+01, 0.17945800E+00, 0.52959300E+01, 0.19561500E+01, -.15069300E+01, -.11207500E+01, 0.68879600E+00, 0.12408500E+01, -.41602700E+01, -.11511000E+01, 0.53923100E+00, -.30504400E+00, -.81894000E+00, -.10784400E+01, 0.78380100E+00, 0.60973100E+00, 0.15112700E+01, -.12419600E+01, -.20045100E-01, -.27277100E+00, 0.76033300E-01, 0.19700600E+00, 0.14884800E+00, 0.37392300E+00, 0.47112900E-01, 0.31680900E+00, -.50436500E-01, -.18201100E+00, 0.33240400E+00, 0.17278600E-01, -.13383400E+00, 0.90542900E-01, 0.16564500E-01, -.86424400E-01, 0.57074800E+00, 0.23735100E+00, 0.10078900E+00, 0.38802500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.29974900E+01, 0.49663500E-01, 0.37944200E+01, 0.11610600E+02, 0.28357400E+00, 0.23234900E+00, 0.20529700E+00, -.15544100E+01, -.91656400E+00, 0.15860400E+00, -.47576400E+00, -.84144700E+00, -.20360200E+01, 0.11821200E+01, -.14555100E+01, 0.10396600E+00, -.16128100E+01, 0.41414700E+00, -.43150400E+01, -.11113400E+00, -.14860100E+01, -.10312400E+01, -.12935200E+00, -.97942100E+00, 0.30679400E+00, 0.38472300E+01, -.20383000E+01, -.32616800E+00, -.62338200E+00, -.13906700E+01, -.44311000E+01, -.19219100E+01, -.15696400E+01, 0.56116300E+00, 0.98579600E+00, 0.62223000E-01, -.33143700E+01, 0.63245000E+00, 0.41718700E+00, -.71831000E+00, -.20575000E+01, 0.20410100E+00, -.18230000E+01, -.15902700E+00, -.10422800E+02, 0.31045900E+01, -.79012800E+01, 0.52349200E+00, 0.23083800E+00, 0.17026100E+00, 0.16099400E+01, -.75848500E+00, 0.41570200E+00, -.32678900E+00, -.36994500E+00, -.29745800E+00, 0.31331300E+00, -.25670100E+01, 0.67342700E+00, 0.79965800E+00, 0.30354000E+00, -.13267900E+01, -.14772100E+00, 0.47862000E+01, -.19622800E+01, 0.26288200E+00, -.79339200E+00, 0.17007600E+00, 0.46216700E-01, 0.50843300E+00, 0.22409200E+00, -.41756400E-01, -.89836100E+00, -.32208600E+00, 0.47274400E+00, 0.50734600E+00, -.53838900E+00, -.22294600E+00, -.59525500E+00, -.22693500E+01, -.11635300E+01, -.32716800E+00, -.10492100E+01, 0.40983100E+00, -.77096700E+00, 0.90358700E+00, -.27583500E+00, 0.33922200E+00, -.45607700E+01, -.10978100E+00, 0.76092300E+00, -.83256300E+00, -.12721700E+01, -.18396800E+00, 0.21095700E+00, -.66664000E+00, -.13283500E+01, -.12776500E+01, -.76691100E+00, 0.61878900E+00, -.69844900E+00, -.29764500E+00, -.23804200E+01, -.12032800E+01, -.15157100E+01, 0.42117400E+00, 0.24767300E+01, 0.10292400E+02, -.69500800E+01, -.11142200E+02, -.39046200E+02, 0.10846100E+02, 0.11062700E+02, 0.40876200E-01, -.54782900E+01, 0.98347300E+00, -.61853800E+01, 0.30182700E+01, -.84001300E+01, 0.13691400E+01, 0.31674000E+02, -.11732000E+02, -.49988400E+01, -.13742000E+02, 0.48597100E+01, 0.14707700E+02, 0.12237100E+02, -.74891200E+01, -.94431900E+01, 0.33941200E+01, -.15297500E+01, 0.27890700E+01, 0.35455600E+01, -.30776100E+01, -.34948600E+01, 0.24214500E+01, 0.40101700E+02, -.19396500E+02, -.23886200E+02, -.16796400E+02, 0.18218000E+02, 0.27915300E+02, 0.35831300E+02, -.13055800E+02, -.96301600E+01, 0.63402100E+01, 0.14523200E+02, 0.99663400E+01, -.14011800E+02, -.86630000E+01, -.14617500E+02, 0.10733100E+02, -.57621000E-01, 0.69368400E+00, -.15906000E+01, 0.30245200E+00, 0.74768200E-01, -.14708700E+01, -.22598400E+00, 0.22998800E+00, 0.38282400E+00, 0.19821500E+01, -.15076100E+01, 0.14728100E+00, -.27478400E+00, -.40660300E+00, -.13146900E+01, 0.25223600E+01, 0.51800400E+00, 0.26728300E+00, -.57391700E+00, -.34289600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.60670600E+00, -.17840600E-01, -.14723800E+01, -.19781000E+01, 0.42394500E+00, 0.92238500E+00, 0.68708500E-01, 0.37844900E+00, 0.43308300E+00, -.10861400E+00, 0.45500300E+00, -.64324200E+00, 0.21037800E-01, 0.26851000E-01, 0.28537900E+00, 0.15062700E+00, -.52720300E+00, 0.11293300E+00, 0.14310500E+00, 0.39910000E+00, -.92717600E-01, 0.13513800E-01, -.15589600E+00, -.16601500E+00, -.23361800E-01, -.14980800E+00, -.38926900E-01, -.14836500E-02, -.53032200E-01, 0.10474900E+00, 0.64716900E+00, 0.37007000E+00, 0.66340200E+00, -.12036800E+00, 0.33828700E+00, 0.49061100E-01, 0.12557600E+00, -.46600700E-01, 0.17015100E-01, 0.61853000E-01, 0.52471500E+00, -.34172700E-02, 0.67844400E-01, 0.53927400E-01, 0.54844400E+00, 0.31950700E+00, 0.26858300E+00, 0.81649600E-02, 0.63707900E-02, -.11388300E+00, -.31102700E+00, -.28237100E+00, 0.17590900E-01, 0.57580300E-01, 0.32479800E-01, 0.57117900E-01, -.91747000E-01, 0.13794000E+00, -.88179600E-01, -.14405800E-01, -.16872700E+00, 0.70872500E-01, -.79407600E-01, -.97682800E-01, 0.93970900E-01, 0.14277800E-01, -.59340200E-01, -.24223700E-01, 0.61383800E-01, -.17671800E+00, 0.18178100E+00, -.39351400E-01, 0.21680400E-01, 0.33258300E-01, -.13013600E+00, -.59281400E-01, 0.31245500E-01, -.54444100E-01, 0.37452900E-01, 0.10577400E-01, 0.17937400E-01, -.35383100E-01, 0.44188200E-01, -.36604800E-01, -.20371500E-01, 0.21524400E+00, -.51442400E-01, 0.23773600E+00, 0.15266500E+00, 0.85583100E-02, 0.10945500E+00, -.17435500E+00, 0.56295900E-01, 0.24937100E-02, -.42169400E-01, 0.20744100E+00, 0.35859000E-01, -.56094600E+00, 0.36735900E+00, -.30273900E+00, -.11592800E+00, 0.29911000E-01, 0.26715700E+00, -.17938100E+00, 0.45701700E-01, 0.74745400E+00, 0.70749600E+00, 0.66222800E-01, -.19057900E+01, -.65722500E+00, 0.26567500E+01, 0.29470700E+00, -.95305700E-01, 0.15163100E+01, -.23249500E+00, -.77066100E-01, -.36801700E-01, 0.11662100E+00, -.24050100E+00, -.67310200E+00, -.11003100E+02, 0.61316300E+01, -.18900000E+01, 0.43480300E+00, 0.37227300E+01, -.44950200E+01, 0.40121300E+01, 0.45751000E+00, 0.26914100E+01, -.51394900E+00, -.31756700E+01, -.22462600E+01, 0.19041800E+01, 0.16165300E+01, -.22249800E+00, -.28273700E+01, -.22065700E+02, -.39940300E+01, 0.68202200E+01, 0.77751000E+01, -.27565700E+01, -.10513300E+02, -.76969700E+01, 0.76770400E+01, 0.73673300E+00, 0.58948200E+00, -.20175700E+01, -.18159100E+01, 0.17452000E+01, 0.84701600E+00, 0.42050300E+01, -.15873700E+01, 0.15338600E+00, -.86471800E-01, 0.32863100E+00, -.53567600E+00, -.27333700E+00, -.53126800E+00, -.37521000E+00, -.77764100E+00, -.45291700E-01, -.22301700E+00, -.54851100E+00, -.13070500E+00, 0.70439600E-01, 0.50050300E-01, -.29397600E+00, 0.37599100E+00, -.76110200E+00, -.35563800E-01, -.14065400E+00, 0.59422600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.19126700E+01, -.41042500E-01, 0.35519100E+01, 0.87736600E+01, 0.74990600E+00, 0.32819600E+00, -.22227300E+00, -.13123000E+01, -.10551700E+01, 0.10480300E+00, -.25174000E+00, 0.69376400E+00, -.54119000E+00, 0.13280500E+01, -.46099300E+00, 0.43268100E+00, -.46784900E+00, 0.49586700E+00, 0.13237100E+01, -.94519700E+00, -.12717500E+01, 0.12761000E+01, -.24789600E+01, -.55889000E-01, -.11480300E+01, -.14527800E+01, -.15497600E+01, 0.35142400E-02, -.82753500E-01, -.13260000E+01, 0.20178100E+01, 0.10034100E+00, -.74379400E+00, 0.28992400E+00, -.23813600E+00, 0.45894500E+00, 0.12454900E+01, 0.24616500E+00, -.62263800E-01, -.81626200E-01, -.79758600E+00, -.24666600E+00, 0.16206200E-02, -.81616800E+00, -.59946300E+01, 0.86012000E+00, 0.10742900E+02, 0.20464800E+00, 0.36514700E+00, 0.45624700E+00, -.16815000E+00, -.26283200E+01, 0.29592200E+00, -.76705400E+00, -.19687900E+00, -.15521400E+01, -.12911600E+01, -.17180700E-01, 0.61457300E+00, 0.52948700E+00, -.25865600E+00, -.76792400E+00, 0.17602000E+00, -.17076200E+00, -.29953500E+00, -.14163200E+00, 0.10991100E+00, -.67836000E+00, 0.52441700E+00, -.21385900E+00, -.12085400E-01, -.44901500E-01, -.19368000E+00, 0.14911200E+00, -.21787900E+00, -.29934900E+00, 0.30166500E+00, -.13809500E+00, -.35882900E+00, -.43744100E+00, -.19290100E+00, 0.26649000E+00, 0.62441700E+00, -.86536700E-01, 0.30232500E+00, 0.28718500E+00, 0.24496000E+00, -.29899600E-01, 0.10703500E+01, 0.98778200E-01, 0.79520900E+00, -.14632800E+00, 0.16299700E+01, 0.37364600E+00, -.35381200E+00, 0.57318000E+00, -.18008400E+00, 0.76073100E+00, 0.26040800E+01, -.73217900E+00, 0.20718700E+00, 0.18063800E+00, 0.11641800E+01, -.35459700E+00, 0.35155600E+00, -.97135400E+00, -.30357200E+01, 0.39795900E+00, 0.25648600E+01, 0.10969300E+02, 0.15636600E+02, -.15406900E+01, -.12223500E+02, -.11482800E+02, 0.24059700E+01, -.23115900E+01, 0.90192700E+01, -.51201400E+01, 0.74267500E+01, -.81237000E+00, 0.87527600E+01, -.30159100E+01, 0.47636500E+01, 0.69921700E+01, -.16314200E+02, 0.37551600E+01, -.21299100E+02, 0.30049500E+01, -.43485300E+01, -.35848400E+01, 0.19031600E+02, 0.61984100E+01, -.68081100E+01, -.24608900E+01, 0.12886700E+02, 0.92030300E+01, 0.12465200E+02, 0.44414400E+02, 0.84560000E+01, -.23554600E+00, -.12533600E+00, -.17860600E+01, -.15157800E+02, -.41709400E+00, 0.42784900E+01, -.49393100E+01, -.14570900E+02, -.57971900E+01, 0.43193200E+01, 0.35198100E+01, -.51439600E+01, -.83984300E+01, -.43979400E+00, -.21457500E+00, -.10887500E+00, 0.91701600E+00, 0.65053300E+00, 0.33425000E+01, 0.81680700E+00, 0.17640700E+01, -.12994400E+00, -.81058100E+00, 0.32258000E+01, 0.32550900E+00, 0.21342100E+00, 0.10364900E+01, 0.12070600E+01, -.32914500E+01, 0.11895800E+01, -.86395400E+00, -.17726500E+01, 0.50758900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20914200E+01, 0.19501900E+00, 0.41279900E+01, 0.90004600E+01, 0.18603000E+01, -.64263600E+00, -.38697100E+00, -.22038300E+01, -.21024800E+01, 0.46071800E+00, -.30987900E+00, 0.19091500E+01, -.10181200E+01, 0.12051400E+01, -.92305200E+00, -.16271500E+01, 0.21617200E+01, -.18507500E+01, -.36547100E+01, -.13240400E+01, 0.14161400E+01, 0.41143700E+00, -.11168000E+01, -.42697400E+00, -.56282600E+00, -.31804200E+00, -.22639900E+01, -.75842700E-01, 0.38869000E+00, -.18062800E-03, 0.29641200E-01, -.57521000E+00, -.14335200E+01, 0.33397600E+00, -.11411200E+01, 0.18298000E+00, -.33090600E+00, 0.43437900E+00, 0.35469700E+00, -.74179500E+00, -.12336400E+01, -.48506600E+00, -.81428300E+00, 0.14105900E+00, -.57115400E+01, -.77551300E+00, 0.26022600E+01, -.18297900E+00, -.19944900E-01, -.23998800E+00, 0.39953600E+00, 0.15239700E+01, 0.21915900E+00, -.46971900E-01, -.71326800E-01, 0.13226700E+00, 0.27108300E-01, 0.27413000E+00, -.29638000E+00, -.11132400E-01, -.12489800E+00, -.16446500E+00, -.18927000E+00, 0.82921000E+00, -.14806700E+01, 0.33587000E+00, -.44867000E+00, -.13349400E+00, 0.68787200E+00, 0.11087900E+01, -.47883800E+00, -.12293300E+00, -.67448900E+00, -.12022500E+00, 0.56470600E+00, 0.63928500E+00, 0.18137500E+00, -.14569100E+00, 0.30130100E+00, -.91578500E+00, 0.34477600E+00, 0.17772200E+00, -.53115600E+00, 0.14022500E-01, 0.45141200E-01, 0.63057100E+00, 0.35057800E-01, 0.40843200E+00, -.18464800E+01, 0.11072800E+00, 0.58196100E+00, -.44869800E+00, -.53036500E+00, -.10703100E+00, -.31383600E+00, -.83832600E+00, 0.23266700E+00, -.63170900E+00, -.12040100E+01, -.74854700E+00, -.67814100E+00, -.50462100E+00, 0.24320700E+00, -.16801600E+00, -.36241700E+00, 0.10095500E+01, 0.17264200E+01, -.11584600E+00, 0.90959000E+00, -.17987000E-01, -.14695000E+02, 0.88136700E+00, -.24804100E+01, -.17606400E+01, -.18557800E+01, -.69075000E+00, 0.97343300E+00, -.74004300E+00, -.18215700E+01, -.78752200E+00, 0.10016600E+02, -.56453700E+01, -.12932900E+02, -.10071800E+02, 0.66219700E+01, 0.97248000E+01, 0.14408800E+02, -.58286100E+01, -.37221100E+00, -.19602000E+01, 0.10760500E+01, 0.10011900E+00, 0.41134800E+01, -.46179900E+00, 0.30894700E+01, 0.44320200E+00, -.44910600E+02, 0.37350900E+02, 0.11711800E+02, 0.11827000E+02, 0.13803600E+02, -.16292700E+02, 0.97226200E+01, 0.14277500E+02, -.16232100E+02, 0.18479400E+02, 0.11040000E+02, 0.70142800E+01, -.59770900E+01, -.93175600E+01, -.14959900E+02, 0.89586400E+01, -.77998500E-01, 0.45545500E+00, -.21805800E+01, 0.35312700E+00, -.21587400E+00, -.86293400E+00, -.45889700E+00, 0.18867300E+00, 0.25953600E+00, 0.10956200E+01, -.90551700E+00, 0.13334500E+00, 0.23494000E+00, 0.65915200E+00, 0.66906200E+00, 0.81614900E+00, -.60432400E+00, -.33505700E+00, -.30516800E+01, -.54255700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14655800E+01, -.36396800E-01, -.32791600E+01, -.56549400E+01, 0.16357000E+01, 0.13449900E+01, -.86349700E-01, 0.17850000E+00, 0.58399500E+00, -.21503300E+00, 0.75299700E+00, -.14448400E+00, 0.93835300E+00, -.12646100E+01, 0.10479300E+01, -.10802200E+01, 0.35018200E+00, 0.10579100E+00, 0.13634400E+01, -.21087400E+01, 0.21432200E+01, -.18402600E+00, -.55885500E-01, 0.48330800E+00, -.25562600E+00, -.15039300E+01, -.14118300E+01, 0.31368500E-02, -.54435000E+00, -.56248700E+00, 0.23473800E+01, 0.17808600E+01, 0.16073400E+01, -.22121700E-01, 0.50629400E+00, 0.31811200E+00, 0.56754800E+00, 0.26124000E-01, 0.23647400E+00, -.31381900E+00, 0.23323200E+01, -.34046800E+00, -.13715100E+00, 0.27734100E+00, 0.34924900E+00, 0.16267600E+01, 0.70329400E+01, 0.14395300E+00, 0.37522600E-01, -.49458500E+00, -.11168800E+01, -.13242900E+01, -.35600300E+00, 0.34862400E+00, 0.13081700E+00, -.54558300E+00, -.20173100E+00, 0.57827200E+00, -.26652500E+00, 0.58961000E+00, 0.50965200E+00, 0.31601700E+00, -.22229300E+00, 0.55005000E+00, -.10369900E+01, 0.25452700E-01, -.35980500E-01, -.11281500E+01, -.80556800E-01, 0.58607700E+00, -.77647300E+00, -.24148600E-01, 0.18630200E+00, 0.22787500E+00, 0.61819800E+00, 0.43784700E+00, 0.52126800E+00, -.20477100E+00, 0.73026400E+00, -.95750100E+00, -.36596500E+00, -.49288600E+00, 0.76485000E+00, 0.17268600E-01, -.11264400E+00, 0.78875800E-01, -.14403300E+00, -.23154200E-01, 0.14316000E+01, -.13690200E+00, -.38733700E+00, 0.48289500E-01, 0.18315400E-01, 0.16040000E+00, -.42809000E+00, 0.11898100E+00, -.12255700E+00, 0.55397600E+00, -.69236900E+00, -.11303100E+01, 0.24181400E+00, 0.68867900E-02, 0.25856600E-01, -.12539700E+00, 0.31804400E-02, 0.10159800E+01, -.99363200E+00, 0.98988100E-02, 0.13066600E+01, -.68280700E-01, 0.28800700E+00, 0.21272800E+01, 0.42510600E+01, -.93067000E+00, -.33024600E+01, -.58326500E+00, -.17500600E+00, 0.57538200E+00, 0.13852100E+00, -.13364100E+01, -.34788100E+02, -.60955500E+01, 0.93671800E+01, 0.69703800E+01, 0.43022400E+01, -.13189000E+02, -.27317200E+01, 0.75764400E+01, 0.12253800E+01, 0.39316000E+01, -.22793800E+01, -.15389600E+01, -.36074400E+01, 0.16252700E+01, 0.48604800E+01, -.31547700E+01, -.43205200E+01, -.12510500E+02, 0.22789200E+01, 0.14854100E+01, 0.20360100E+01, -.26291100E+01, -.59446800E+01, 0.10411200E+01, -.13404800E+02, 0.97654900E+01, -.50536600E+01, -.52830000E+01, 0.10071200E+02, -.11334300E+01, 0.73829100E+01, -.50690100E+01, -.68616900E-01, -.12991000E+00, 0.67410200E+00, -.50285500E+00, 0.37249900E+00, 0.46282400E+00, 0.21744400E+00, -.71980100E+00, -.10249800E+01, -.10779300E+01, 0.21132000E+00, -.45433200E-01, -.46252800E+00, -.96195600E-02, -.30363600E+00, 0.26233800E+00, 0.28137500E+01, 0.12691700E+01, 0.85057200E+00, -.35600500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15465200E+01, 0.57659400E-01, 0.36981000E+01, 0.62505400E+01, -.45214300E+00, -.20447900E+01, -.22177400E+00, -.13274200E+01, -.11972600E+01, 0.13762300E+00, 0.14401000E+01, 0.84712400E+00, -.24435200E+01, 0.37003100E+01, -.41873100E+00, 0.34452900E+00, 0.10005700E+00, -.15636800E+00, -.22487100E+01, 0.22222400E+01, 0.15070200E+01, 0.33146600E-01, -.30289200E+01, -.19287700E+01, -.75023400E+00, -.10004600E+01, -.11574100E+01, 0.12354900E-01, 0.60981800E+00, 0.24182600E+01, 0.12495200E+01, -.17510600E+00, 0.67049000E+00, -.79557200E+00, 0.17941800E+00, -.41660100E+00, -.11154400E+01, -.10602600E+00, -.55459500E-04, 0.31141400E+00, -.84527200E-01, 0.23471100E+00, -.35780400E+00, -.37334800E+00, -.79723500E+01, 0.16239500E+01, -.16023300E-01, 0.20437900E+00, 0.19649300E+00, 0.19641800E+00, 0.52615000E+00, -.22483500E+01, 0.81628400E+00, -.92259800E+00, -.12440400E+00, -.43083200E+00, -.21037600E+00, -.71871600E+00, 0.22636300E+00, -.46857000E+00, -.36081900E+00, -.24689200E+00, 0.46686100E+00, -.36079200E+00, 0.28538300E+00, -.19801900E+00, -.37459300E-01, 0.10475400E+01, -.36073900E+00, -.50948000E+00, 0.38354700E+00, -.19577200E+00, 0.18647300E+00, -.17350300E-02, -.56177100E+00, -.15463700E+00, 0.16441200E+00, -.18397200E+00, 0.21678100E+00, -.40749100E+00, 0.17078100E+00, -.28304400E+00, -.17249700E+00, 0.69922400E-01, -.28074500E+00, 0.71290800E+00, -.15792600E+00, -.41991400E-01, -.12873500E+00, -.88393900E-01, -.23290600E+01, 0.52344800E+00, -.11586400E+01, 0.55826800E-01, -.34527600E+00, 0.12833900E+00, 0.85184100E+00, -.36535500E+00, 0.41561900E+00, 0.35902300E+00, 0.44375300E+00, 0.25718400E+00, 0.28627600E+00, -.35043000E-01, -.80939800E+00, 0.25923500E+01, -.11187800E+01, -.24080600E+00, 0.20570500E+01, 0.20299800E+00, 0.32416900E+00, -.66354200E+00, 0.91432300E+01, 0.42464300E+01, -.71445300E+01, 0.57477300E+00, -.38592200E+01, 0.15241300E+01, -.36129100E+01, 0.13462700E+01, -.23477200E+02, -.27551400E+02, 0.38547300E+01, 0.24876100E+00, 0.13163000E+02, -.49918100E+01, 0.40857600E+01, 0.21909000E+01, -.38486300E+01, 0.14192300E+02, -.99831400E+00, 0.15321700E+01, -.57282700E+01, -.16171700E+01, -.52180600E+01, 0.60151000E+00, -.31588200E+01, 0.36256600E+02, 0.57253100E+01, -.29561100E+01, -.15077200E+00, 0.80467000E+00, 0.41559600E+01, -.62046000E+01, -.16866000E+02, 0.93091500E+01, 0.27654700E+01, 0.44202500E+01, -.91837000E+00, -.22642500E+01, 0.10590700E+02, 0.69262500E+01, -.19570000E+00, 0.31869500E+00, 0.99039900E+00, 0.60261200E+00, 0.10462000E+01, -.47158300E+00, 0.27535700E+00, 0.11809500E+00, -.82966700E+00, -.56323400E+00, -.74018100E+00, 0.78681800E-01, -.79580800E+00, -.70458900E+00, -.56640000E-01, 0.23100000E+01, 0.48241400E+01, 0.14714200E+01, 0.16330600E+01, -.63046200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17964100E+01, 0.70921900E+00, -.26650500E+00, 0.27363400E+00, 0.14697600E+01, 0.12538200E+01, -.76154100E-01, 0.22272500E+00, 0.89487700E+00, 0.78477500E+00, -.47841100E+00, 0.18492500E+00, 0.56284900E-01, 0.26148600E+00, -.17980900E+00, 0.81017100E+00, -.11764900E+01, -.63130200E+00, -.25011300E+01, 0.48740200E+00, -.18677000E+01, 0.94309800E+00, -.47030800E+00, -.53669300E+00, -.34659300E+00, 0.32310000E+00, 0.55152400E+00, -.10115600E+00, 0.24345600E+00, 0.10332800E+01, -.22963200E+01, -.50614700E+00, -.66913400E+00, -.31540300E+00, -.85366300E+00, -.47514600E+00, -.32006700E+00, -.10671800E+00, -.38662000E+00, 0.79973700E-01, -.11637400E+01, 0.54930700E-01, -.43741300E+00, -.14508600E+00, -.19386500E+01, 0.18060600E+01, -.49270000E+01, 0.12123000E+00, 0.39525800E+00, 0.74164500E+00, 0.84776200E-01, -.36303400E+01, 0.78754900E+00, -.16903500E+01, -.13027400E+00, -.66449800E+00, -.11184800E+01, -.22223400E+00, 0.32491900E+00, 0.41274700E+00, -.16101600E+00, -.34618800E+00, 0.61755000E+00, 0.35136400E+00, 0.37656500E-01, 0.54277900E-01, 0.22972000E-01, -.10703200E+00, 0.36513000E+00, 0.30211400E-01, 0.37424800E+00, -.61630700E-01, -.33616200E+00, -.13282800E+00, 0.27627600E-01, 0.29619600E+00, -.51968600E+00, -.17776700E+00, -.24161400E+00, -.22935500E+00, -.14460500E+01, 0.31019200E+00, 0.76467400E+00, 0.79810000E-01, -.15875100E+00, 0.80708600E+00, -.13450200E+00, 0.13617100E+00, -.14823900E+01, 0.89854400E-02, 0.67759700E-01, -.41388600E+00, -.10677500E+00, -.95695500E-01, 0.25990800E+00, -.19618300E+00, -.69201700E+00, 0.72581000E+00, -.55402300E+00, 0.69417000E+00, -.12799300E+01, -.73577100E+00, 0.10936100E+01, -.26731300E+00, -.41046400E+00, -.15107800E-01, -.11458600E+01, -.19486300E+00, 0.65795700E+00, 0.22623200E+00, 0.89434100E-01, -.37094900E-01, 0.19455600E+00, 0.80011100E+01, -.42199300E+01, 0.49438100E-01, -.10342400E-01, 0.14524300E+00, -.25335700E+01, 0.85645500E+00, 0.27094200E+02, -.13992800E+01, -.95594700E+01, -.87205200E+01, 0.26327200E+01, 0.10688900E+02, 0.48948900E+01, -.69353100E+01, -.51173200E+01, 0.25882500E+01, 0.17863600E+01, 0.77904500E+00, 0.39267000E+01, -.21777600E+01, -.41818600E+01, 0.17291600E+01, 0.21188100E+01, 0.78346600E+01, -.13467200E+02, -.41248800E+01, 0.94994100E+01, 0.42126800E+01, 0.58240000E+01, -.35010400E+01, -.41951500E+01, 0.15694100E+01, 0.12763800E+02, 0.82816300E+01, -.10590000E+02, -.41310900E+01, -.39462700E+01, 0.90625200E+01, -.48887100E-01, -.88738200E-02, -.75431900E+00, 0.93901100E+00, 0.17451600E+00, -.55861000E-01, 0.12842600E+00, 0.87973400E+00, 0.51530800E+00, 0.50694700E+00, 0.22909400E-01, 0.22775300E+00, 0.50940000E+00, 0.27086600E+00, 0.33390500E+00, 0.17618200E+01, -.45498200E+00, -.57165500E+00, 0.24342200E+00, -.10324300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.51387100E+00, -.13386000E-01, -.12852900E+01, -.51817800E+01, -.39087000E+00, -.15247300E+00, 0.19576100E+00, 0.49828700E+00, 0.65434000E+00, -.79013800E-01, 0.51791000E+00, -.91315600E+00, -.84461700E-02, -.10658400E+00, 0.31866700E+00, 0.40743800E+00, -.45439200E+00, -.56539700E-01, -.72452300E+00, 0.37756100E+00, -.33731000E+00, 0.13976200E+00, -.37210700E+00, -.26384900E+00, -.92677800E-01, -.30181000E-01, 0.39063000E+00, -.76161500E-02, -.13097900E-01, 0.75221400E+00, 0.32983700E+00, 0.37417300E+00, 0.77223200E+00, -.23063100E+00, 0.84534300E-01, -.10530200E+00, -.10361000E-01, -.35799800E-01, -.17546600E-01, 0.27302200E-01, 0.10182700E+00, 0.33501000E-01, 0.32676900E-01, 0.36069900E-01, 0.50735100E+00, 0.31002500E+00, -.16247600E+01, -.12492400E-01, -.28953100E-01, -.15525900E+00, -.28739500E+00, -.38711500E+00, 0.88901400E-01, -.56952100E-01, 0.19276400E-01, 0.13023000E+00, -.94207500E-01, -.72581200E-01, -.49720800E-01, 0.37026200E-01, -.17644700E+00, 0.16589300E-02, -.22834400E-01, 0.33815000E-01, 0.96834200E-01, 0.46839800E-01, -.12885200E+00, 0.85713500E-01, 0.57043600E-01, -.12389000E+00, 0.19460300E+00, -.56830100E-01, -.59746800E-01, 0.57853700E-02, -.13587500E-01, 0.27306900E-01, -.91436600E-01, 0.47427400E-02, 0.59430000E-02, -.14712500E+00, -.80683300E-01, 0.25400000E-02, 0.44939000E+00, -.27843300E-01, 0.29091400E-01, 0.29707300E+00, -.69908700E-01, 0.18216900E-01, 0.12606900E+00, -.27145200E-01, -.89888500E+00, -.49545500E-01, 0.18849600E-01, 0.56731400E-01, -.28361000E-01, 0.16498000E+00, -.46949700E-01, 0.43995700E+00, 0.14322300E+00, -.13516200E+00, -.27100400E+00, -.14491100E+00, 0.36108200E+00, -.13201700E+00, -.11502800E-01, 0.16960000E+00, 0.31051900E+00, -.34363900E-01, 0.45677900E+00, 0.42662800E-01, -.78519900E-01, 0.44593400E-01, 0.61681500E-01, -.72071000E-01, -.44649900E+01, -.10098100E+01, 0.80147000E+00, 0.54941500E+00, 0.22217300E-01, -.87849000E+00, 0.92403300E+01, 0.16769600E+01, -.71832600E+01, -.51913200E+01, 0.19376100E+01, 0.54470300E+01, 0.77035300E+01, -.45141800E+01, 0.17119100E+01, -.16789500E+01, -.16740400E+01, -.10256900E+01, 0.22708200E+01, 0.21116700E+00, -.25827900E+01, -.95228800E+00, -.30841100E+02, 0.45116300E+01, 0.47950400E+01, 0.84646400E+01, 0.34937700E+01, -.11421700E+02, 0.13972000E+01, 0.91671900E+01, -.87859500E+01, 0.70106600E+01, 0.59155400E+01, 0.31201400E+01, -.19555100E+01, -.36442800E+01, -.82448300E+00, 0.35401100E+01, -.25252000E-01, 0.14371700E-01, -.44220800E+00, 0.12354100E+00, 0.70241500E-02, -.20348400E+00, -.35010600E-01, -.10006200E+00, 0.10137900E+00, 0.81931400E-01, -.18149000E+00, 0.19962700E-01, 0.40967100E+00, 0.12599500E+00, 0.16146400E+00, 0.12760300E+01, -.11938500E+01, -.30460900E+00, -.82623900E+00, -.10939100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.84019700E+00, 0.40478400E-01, -.15271600E+01, -.12751400E+01, 0.57320600E+00, 0.10872900E+01, 0.13793800E+00, -.14497600E-01, -.16142200E+00, -.12494800E+00, -.91067200E-01, -.46059600E+00, 0.21156300E+00, -.11850000E+00, -.46613700E-01, -.93908300E-01, 0.10742600E+00, -.52836500E-01, -.20383200E+00, -.60978800E-01, -.38228200E-01, -.19631800E+00, 0.34007900E+00, 0.89548900E-01, 0.18677900E+00, 0.13653100E+00, -.61013700E-01, -.56826000E-02, -.73685500E-02, -.48685200E+00, -.53078500E+00, -.18471300E+00, -.11669800E+00, 0.13546200E+00, 0.12442400E+00, 0.10197100E+00, 0.36246800E-01, -.40986900E-01, 0.50219900E-01, -.54644400E-01, 0.84459100E+00, -.64163400E-01, -.21701200E-01, 0.48588400E-01, 0.19517900E+00, 0.42333000E+00, 0.88639700E+00, 0.77133400E-01, 0.10818900E+00, 0.17637500E+00, -.11145200E+00, -.67679700E+00, -.50665400E-01, -.14414300E+00, -.26595400E-01, -.15884000E+00, 0.72148000E-01, -.91388100E-01, -.10072900E+00, 0.76626900E-01, 0.18467000E+00, 0.20446600E+00, -.14949700E-01, 0.52606700E+00, -.24493500E-01, -.58539800E-01, 0.83214600E-01, 0.21969600E+00, -.46632800E-02, -.76633500E-02, 0.90461600E-01, 0.15681300E-01, 0.20909800E+00, -.19985500E-02, -.37155300E-01, 0.17293200E+00, -.12641100E-01, -.17155900E+00, -.68478800E-01, 0.29859400E+00, -.27428500E+00, -.24932600E+00, -.21920300E+00, -.19935900E-01, -.72017900E-01, -.22922800E+00, -.57835000E-01, 0.15500400E+00, 0.25264600E+00, -.11181500E+00, 0.27325500E+00, -.15870100E-01, 0.20238900E+00, -.56990200E-01, 0.60173700E-01, 0.43025500E-01, -.14831000E+00, -.26535100E+00, -.14708400E+00, 0.41954000E+00, 0.12442800E-01, 0.25266400E-01, -.64625900E+00, 0.11736000E-01, -.12481500E+00, -.71817800E+00, -.47770100E+00, -.18627600E-01, -.63683800E+00, -.39931600E-01, 0.10451800E+00, 0.49129200E-01, 0.57974400E-01, -.21955100E+00, -.64177900E-01, 0.13129200E+01, 0.14524100E-02, -.49206300E-01, -.10082400E+01, 0.73350000E+00, 0.78987500E+01, 0.88636600E+01, -.13030000E+01, -.18773500E+01, -.24352100E+01, 0.14521100E+01, -.12866700E+01, -.17156200E+01, -.22447800E+01, -.16607800E+01, 0.11525800E+01, 0.54962400E+00, 0.14306800E+01, -.83004600E+00, -.14467300E+00, 0.43471700E+00, 0.84793200E+01, -.41884900E+01, -.65655800E+01, -.25711100E+01, 0.22369400E+01, 0.37531300E+01, -.18714000E+01, -.24283300E+01, 0.53612000E+01, -.47656000E+01, 0.13569500E+01, 0.25624100E+00, -.26984500E+01, 0.10313900E+01, -.84017700E+00, 0.14072300E+00, 0.64194700E-01, -.21582400E+00, -.21893800E+00, 0.40683100E+00, 0.11211700E-02, 0.41176600E+00, 0.16207200E+00, 0.58435000E+00, 0.18745100E+00, 0.16383300E+00, 0.48305100E+00, -.29268500E-01, 0.29427700E-01, -.33108300E-02, -.39597300E-01, -.13163700E+00, -.87083500E+00, -.29321300E+00, 0.21955500E+00, 0.55221400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14359100E+01, 0.63428600E-01, 0.20167700E+01, 0.44127200E+01, 0.20240900E+00, -.45188200E-01, 0.16652900E+00, -.58201100E+00, -.43140200E+00, 0.80527900E-01, -.62042400E+00, 0.98684500E-01, 0.23137000E-01, 0.40337900E-01, -.48068000E+00, 0.19518900E+00, 0.14716300E+01, -.44132900E+00, -.11600400E+01, -.42365000E+00, 0.24744500E-01, -.32913000E+00, -.43926800E+00, -.56510900E-01, 0.13304800E+00, 0.14764000E+01, 0.83808700E+00, -.43463900E-01, -.62974600E-01, 0.26348800E+00, -.17677100E+01, -.76536200E+00, -.62291200E+00, 0.15012200E+00, -.20926700E+00, -.47710800E-01, -.87274800E+00, 0.42304000E-01, 0.37433600E-01, -.84626000E-01, -.50396800E+00, 0.21618300E-02, -.15129900E+00, 0.85992400E-01, 0.30443700E-01, -.46482100E+00, -.20273300E+01, 0.19997100E-02, -.36959400E-01, 0.20841900E+00, 0.50753000E+00, 0.40891800E+00, -.14415000E+00, -.26570500E+00, -.10687900E+00, -.52982200E+00, -.16038100E+00, 0.38018400E-01, 0.22390600E+00, 0.14612000E+00, 0.31666600E+00, -.33475800E+00, -.23831300E+00, 0.36562100E-01, -.18432800E+00, -.23826700E+00, 0.27993800E+00, -.62931400E+00, -.18296400E+00, 0.31974300E+00, -.84177400E+00, 0.10731200E-01, 0.14182500E-01, -.44711700E-01, 0.20690400E+00, -.13995700E+00, 0.12733900E+00, 0.23251500E+00, -.73440800E-02, -.82608800E+00, -.68022300E-01, 0.22731900E+00, 0.16286800E+00, 0.14017100E-01, -.86058400E-01, -.10009800E+01, -.74625800E-01, -.41545700E+00, 0.24332100E+01, 0.30626600E+00, 0.10005100E+01, -.11201600E+00, 0.70969400E+00, 0.23263000E+00, 0.19110200E+00, 0.40244300E+00, -.29577600E+00, 0.14816300E+01, -.76210900E+00, -.46274200E+00, -.68302200E+00, -.39914100E+00, 0.51598500E+00, -.12421100E+00, -.34047100E+00, -.12759700E+01, -.29314100E+01, -.34636100E+00, -.16239100E+01, -.60506600E-01, 0.27993000E+00, 0.10590200E+00, 0.77250800E+00, -.45567400E+00, -.25349500E+00, 0.22761700E+00, 0.17315000E+01, 0.54773900E+00, -.75212400E+00, -.16159800E+00, 0.61284400E+02, 0.19379000E+02, 0.85631800E+00, -.71357100E+01, -.19068200E+02, 0.13823400E+02, -.83104300E+01, -.67918600E+01, -.80517800E+01, -.35514600E+01, 0.25521800E+01, 0.10424600E+01, 0.85735400E+01, -.17821100E+01, -.41587200E+00, 0.24257400E+01, 0.30333000E+02, -.35044500E+02, -.29547000E+02, -.90775500E+01, 0.14462500E+02, 0.15241600E+02, -.38420100E+01, -.54566000E+01, 0.22133700E+02, -.19073300E+02, 0.10643200E+02, 0.19530900E+01, -.11855600E+02, 0.12576200E+01, -.65289100E+01, -.31496800E-01, 0.41173900E+00, -.62063800E+00, -.14727400E+01, 0.11641300E+01, -.77981800E+00, 0.12581700E+01, 0.24074000E+00, 0.19066900E+01, 0.14301600E+01, 0.50957500E+00, 0.16573600E+01, 0.15998300E+00, 0.68409300E+00, 0.83535600E+00, 0.43838000E+00, 0.18287700E+00, -.42503400E+01, -.10554100E+01, -.87410600E+00, 0.21126300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13627500E+01, 0.30948900E-01, 0.18936600E+01, 0.41371100E+01, 0.21733300E+00, -.10424500E+00, 0.13012500E+00, -.61801400E+00, -.50817100E+00, 0.77983700E-01, -.60115900E+00, 0.21455100E+00, 0.76514300E-02, 0.11403900E-01, -.46905200E+00, -.27717400E-02, 0.16416500E+01, -.49944600E+00, -.11832200E+01, -.56320300E+00, 0.48194100E+00, -.41373500E+00, -.11811000E+00, 0.55220200E-01, 0.17359400E+00, 0.12415100E+01, 0.54672300E+00, -.35637600E-01, -.68091900E-01, 0.15740700E+00, -.11247500E+01, -.73434200E+00, -.60735700E+00, 0.11319900E+00, -.35427300E+00, 0.69715500E-02, -.73188100E+00, 0.97108300E-01, 0.86648100E-01, -.15608700E+00, -.50035900E+00, -.44226600E-01, -.12645900E+00, 0.14999400E-01, -.78917600E+00, -.64484800E+00, -.10696600E+01, -.96271400E-02, -.82779300E-01, 0.80292700E-01, 0.49156400E+00, 0.64924500E+00, -.14929300E+00, -.15927700E+00, -.95071400E-01, -.45042000E+00, -.70434800E-01, -.41017200E-01, 0.13967800E+00, 0.13379900E+00, 0.28497900E+00, -.25730100E+00, -.33642400E+00, 0.14354300E+00, -.27719800E+00, -.15540000E+00, 0.17005000E+00, -.56316100E+00, -.69018300E-01, 0.36371600E+00, -.76038500E+00, 0.12649200E-01, -.10683800E-01, -.48627500E-01, 0.26522400E+00, -.27493000E-01, 0.87592100E-01, 0.18503000E+00, 0.86680300E-02, -.88294500E+00, 0.42435800E-01, 0.24973500E+00, 0.26247700E+00, -.16456600E-02, 0.14919800E-01, -.26058900E+00, -.26370800E-01, -.29053200E+00, 0.16667400E+01, 0.25712700E+00, 0.62273800E+00, -.78982900E-01, 0.37878100E+00, -.16537100E+00, 0.11395400E+00, -.59227100E+00, 0.11654000E+00, -.56608000E-02, -.92001200E+00, -.20728000E+00, 0.12512200E-01, 0.12125500E+00, 0.59349000E+00, 0.24365000E+00, 0.16436300E-01, 0.11878300E+01, 0.19976200E+01, 0.18389400E+00, 0.80109100E+00, 0.11443500E+00, -.10756000E+00, -.61151800E+00, -.37783800E+00, 0.56072000E+00, 0.52198000E+00, -.14292400E+01, -.57657100E+00, -.16516100E+01, 0.35989200E+00, -.63296800E+00, -.15047800E+02, 0.71398000E+00, 0.74759700E+01, 0.58461600E+01, -.19763300E+01, -.56941600E+01, -.23016200E+01, 0.49744900E+01, -.16503300E+01, -.10094200E+00, 0.18912800E+01, 0.14385100E+01, -.42101000E+01, -.10122600E+01, 0.61123000E-01, 0.96190600E+00, 0.16727900E+02, -.42150800E+01, -.60218800E+01, -.31043200E+01, -.26172600E+01, 0.30084300E+01, -.10970000E+02, -.33294000E+01, 0.57662600E+01, -.75249300E+01, -.42214800E+01, -.41993500E+01, 0.24361500E+01, 0.37249800E+01, 0.54393600E+01, -.54369800E+01, -.17800600E+00, -.43003700E+00, 0.54570100E+00, -.15978000E+00, -.28567600E+00, -.34855600E+00, -.23982500E+00, -.92799400E-01, -.51324700E+00, -.42527400E+00, -.37728100E+00, 0.11727000E+00, 0.17216800E+00, -.82199800E+00, -.74984900E+00, -.25930900E+00, 0.54693600E+00, -.28100600E+00, 0.14025100E+01, 0.19708500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11421800E+01, -.21952000E-01, 0.24301900E+01, 0.38860200E+01, -.81573100E+00, -.11776200E+01, -.41808400E-01, -.64635000E+00, -.88169400E+00, 0.68271100E-02, -.10419200E+00, 0.41685400E+00, -.60331600E+00, 0.20333900E+00, -.17121900E+00, -.43215400E+00, 0.44813300E+00, 0.91195800E+00, 0.52907100E+00, -.20064700E+01, 0.48415600E+00, -.86640700E-01, -.13277700E+01, 0.44779900E+00, -.71451900E+00, -.13980500E+01, 0.29644500E+00, 0.13047200E+00, 0.24267300E+00, 0.69081100E+00, 0.69712600E+00, -.58759800E+00, -.54379500E+00, -.24009400E+00, -.15283800E+01, -.38428900E+00, 0.96885400E+00, 0.87678100E-01, -.89774800E-01, -.47330000E-02, -.13287100E+01, 0.19461200E+00, 0.58058700E-01, -.28911400E+00, -.28051500E+01, 0.25565300E+00, 0.32469700E+01, 0.10709500E+00, 0.13860200E+00, 0.32131600E+00, -.89547100E-01, -.15309700E+01, 0.14059000E+00, -.28650000E+00, -.18410700E+00, -.86370300E+00, -.61657100E+00, -.10847600E+01, 0.35632000E+00, 0.18704200E+00, 0.10166700E+00, -.60580200E-01, 0.35588200E+00, -.40210500E+00, -.48643100E+00, -.52194800E-01, 0.12573300E+00, -.11821100E+00, -.71952000E-01, 0.64184300E+00, -.40255600E+00, 0.23756900E-02, -.26360900E-01, -.14843000E+00, 0.52940800E+00, 0.65974800E+00, -.32619000E+00, -.98645900E-01, 0.19445600E+00, -.40425800E+00, -.13531900E+00, 0.21614400E+00, 0.25893300E+00, 0.93887600E-01, 0.18457400E+00, 0.31402600E+00, 0.11788500E+00, -.17796100E+00, -.16130800E+01, 0.10976600E+00, -.21324600E+00, -.18309700E+00, -.10920400E+01, -.17483600E+00, 0.13760300E+00, -.96412000E+00, -.10544400E+00, -.22159800E+00, -.57826200E+00, 0.19233600E+01, -.22193400E+00, -.14415400E+00, -.13340400E+01, 0.63651900E+00, -.53437300E-01, -.57470600E+00, 0.17215900E+01, -.31010100E+00, -.16761200E+01, -.43623500E-01, -.15202500E+00, -.24610700E+00, 0.24724200E+00, 0.38287900E-01, 0.25089200E+00, 0.27046600E+00, 0.77982900E-01, -.11696200E+00, -.23385900E+01, 0.32551900E+00, 0.22318100E+02, 0.24709700E+00, -.11772200E+02, -.10276100E+02, 0.65691600E+01, 0.11544700E+02, 0.74929300E+01, -.99566500E+01, -.16758600E+01, -.81668300E+00, 0.27572900E+00, 0.10682500E+00, 0.40459500E+01, -.76082000E+00, -.21515300E+01, 0.15388400E+01, -.16469500E+02, 0.17359100E+02, 0.43385400E+01, 0.62945100E+01, -.13269900E+01, -.60651700E+01, 0.22792900E+01, 0.75356100E+01, -.83406000E+01, 0.31889700E+01, 0.31852800E+01, 0.55124300E+01, -.39303800E+01, -.41244800E+01, -.38927200E+01, 0.60849900E+01, 0.30119100E-01, -.33992600E+00, 0.96817100E-01, -.69169100E-01, -.32338000E+00, -.11828300E+01, -.57787600E+00, -.10163600E+00, 0.38328500E+00, 0.49950600E+00, -.11343400E+01, -.91197900E-02, -.69817900E-02, 0.53134100E-01, -.13548400E+00, 0.66120300E+00, -.11249400E+01, -.87057200E+00, -.10791200E+01, -.43952200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.97766100E+00, 0.20756600E-01, -.24904600E+01, -.52567700E+01, -.22879900E+00, 0.84200200E+00, 0.24902200E+00, 0.15096900E+01, 0.97683300E+00, -.16792700E+00, 0.29584100E+00, -.38282700E+00, 0.24115200E+00, 0.95149800E-01, 0.41604600E+00, 0.89877700E+00, -.82859300E+00, 0.46865000E+00, 0.13304900E+01, 0.22048100E+01, 0.51944800E-01, -.22692200E+00, 0.20693400E+01, 0.51264300E-02, 0.73473900E+00, -.53550700E-01, 0.20280400E+00, -.56245800E-02, 0.57628600E-02, 0.75210000E+00, 0.18397200E+01, 0.10129700E+01, 0.68033600E+00, -.52615000E-01, 0.40536200E+00, 0.16226900E-01, 0.27659500E+00, -.20691300E+00, -.13572600E+00, 0.35546700E+00, 0.14230400E+01, 0.47847000E-01, 0.32206500E+00, -.97890800E-01, 0.44358300E+00, -.10224900E+00, 0.17839500E+01, -.85872500E-01, -.57960200E-01, -.12511200E+00, -.12251700E+00, -.27198400E+00, 0.29268100E+00, -.11264600E+00, 0.67805600E-01, 0.33444900E+00, 0.36789600E+00, 0.47537500E+00, -.42157600E+00, 0.90039400E-01, 0.38686300E-02, 0.65046000E+00, 0.27170700E+00, -.25084900E+00, 0.87036400E+00, -.15750800E+00, 0.27623600E+00, 0.26709600E+00, -.66241400E-02, 0.14906000E+00, -.64794100E+00, -.13996100E+00, 0.12411200E+00, -.23760000E+00, -.32851900E+00, 0.94542100E-01, -.32414900E-01, 0.10736300E+00, 0.36100700E-01, 0.90867200E+00, 0.14989700E+00, 0.62477300E-01, -.73850200E+00, 0.50370000E-01, -.10307500E+00, 0.47208600E+00, -.36589000E-02, 0.11227100E+00, -.24544400E+01, -.10180800E+00, -.35450200E+00, 0.16756600E-01, -.10065600E+01, -.22410400E+00, 0.16020600E+00, -.20566200E+00, 0.18218900E+00, -.96510300E+00, 0.30126800E+00, 0.64006000E+00, -.18232000E+00, -.93770200E-01, -.19297800E+00, 0.24078500E+00, -.32652100E+00, 0.63949500E+00, 0.86869900E+00, 0.10792200E+00, 0.91356900E+00, 0.18984200E-01, -.61897800E-01, -.40211100E+00, -.16851000E+00, -.97287800E-01, -.28102000E+00, 0.59870900E+00, -.44486800E+00, -.19488100E+00, -.44806300E+00, 0.10063500E+01, 0.45838500E+02, -.16732100E+02, -.63669800E+00, -.60734800E+01, -.87539500E+01, 0.14823100E+02, -.85327500E+01, -.60002100E+01, -.63758800E+01, 0.48863200E+01, 0.35396400E+01, 0.28665000E+01, 0.25888600E+01, -.15131600E+01, 0.27270000E+00, 0.45859800E+01, 0.56096800E+02, -.10601800E+02, -.20201000E+02, -.15247100E+02, 0.20301400E+00, 0.23141800E+02, 0.28228500E+01, -.15198400E+02, 0.12762100E+02, -.94811600E+01, 0.31933100E+01, 0.27943700E+01, -.10512400E+02, 0.25290200E+01, -.17845000E+01, 0.31153200E+01, -.51459300E-02, 0.23376700E+00, -.44839600E+00, 0.93942200E+00, 0.46081800E-01, 0.67556400E+00, 0.28638100E+00, 0.13631700E+01, 0.90656900E+00, 0.43824000E+00, 0.82394700E+00, 0.25785700E+00, -.15148500E+00, 0.26966800E+00, 0.31478300E+00, -.13260400E+00, 0.24691200E+00, 0.25972000E+00, 0.31331600E+00, 0.46508300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.32947800E+01, -.92778800E-01, -.44740900E+01, -.10878200E+02, -.56687500E-01, 0.11189000E+01, 0.21810300E-01, 0.18027000E+01, 0.17500300E+01, -.22183700E+00, 0.19150500E+01, -.89430700E+00, 0.86138300E+00, -.83403500E-01, 0.16228100E+01, 0.48215300E+00, -.41820200E+01, 0.11996600E+01, 0.43961700E+01, 0.14860300E+01, -.31634100E+01, 0.20480400E+01, 0.14433300E+00, 0.16425600E+00, -.78008400E+00, -.40905400E+01, -.23188400E+01, 0.69391000E-01, 0.19520900E+00, -.13943300E+01, 0.36628600E+01, 0.25014000E+01, 0.99788000E+00, 0.41430900E+00, 0.20896800E+01, 0.74576500E+00, 0.20500000E+01, -.24059400E+00, -.42004800E+00, 0.55658800E+00, 0.12164100E+01, -.42671700E-01, 0.99187500E+00, -.66819400E+00, 0.38521300E+01, -.57155200E+00, 0.32992200E+01, -.25103200E+00, 0.15208400E+00, 0.50941000E+00, 0.70670500E+00, 0.87100700E+00, -.14488300E+00, 0.17084700E+00, 0.12495900E+00, -.41537900E-01, 0.50327500E+00, 0.13400300E+01, -.37144300E+00, 0.32600500E+00, 0.36890100E+00, 0.31909200E+00, -.88153500E+00, 0.92069500E+00, 0.44203200E-01, 0.31763000E+00, -.94020600E-01, -.15304100E+01, 0.65558100E+00, 0.35353600E+00, -.11927700E+01, -.90791900E-01, -.97199600E+00, -.79639700E-01, -.11512900E+00, -.71421400E+00, 0.19249000E+00, 0.25019100E+00, 0.14757500E+00, 0.95124700E-01, -.13245600E+00, 0.72865500E+00, -.45763300E+00, -.17805900E+00, -.43961800E+00, 0.93561700E+00, -.14508400E+00, -.52481100E+00, -.98237900E+00, -.18587700E+00, -.10731800E+01, 0.18738200E-01, -.46396800E+00, -.71556500E-01, 0.24498500E+00, 0.74656000E+00, 0.82440200E-01, -.36951300E+00, 0.24378000E+01, 0.10298300E+01, -.11236000E+01, -.52803300E+00, 0.17234000E+01, -.66800100E+00, -.70563000E+00, -.58745100E+00, 0.90743200E+00, 0.15127600E+00, 0.56627600E+00, 0.47348300E+00, 0.10803000E+00, -.85099200E+00, 0.90129700E+00, 0.19493000E+00, -.18576700E+01, -.39804300E+00, -.40692200E+00, -.12553600E+01, 0.20327800E+00, -.75634500E+00, 0.12150300E+03, 0.15347700E+02, -.12654300E+01, -.15515500E+02, -.37511100E+02, 0.36107700E+02, -.61670100E+01, -.18294900E+02, -.74509100E+01, -.99144200E+01, 0.24022700E+01, 0.40324600E+01, 0.80749900E+01, -.26940100E+01, -.74095900E+01, 0.68843600E+01, 0.57714400E+02, -.67781700E+02, -.46861900E+02, -.12445800E+02, 0.12874000E+02, 0.24435400E+02, -.33213700E+01, -.64718600E+01, 0.45380900E+02, -.42358200E+02, 0.14427300E+02, 0.45244900E+00, -.22357000E+02, 0.98217800E+01, -.72738100E+00, -.36994700E+01, 0.13973600E+00, 0.67139800E-01, -.24431800E+01, 0.23374400E+01, -.14738500E+01, 0.46197900E+00, 0.21519400E+00, 0.34071000E+01, 0.27154600E+01, 0.14628600E+01, 0.11508900E+01, 0.45878000E+00, 0.20206000E+01, 0.11828100E+01, 0.14364200E+01, 0.39190500E+00, -.88498400E+01, -.19070300E+01, -.17953300E+01, 0.46912100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.72678800E+00, 0.35269100E-01, -.15271500E+01, -.12603400E+01, 0.76014000E+00, 0.10237900E+01, 0.12507700E+00, 0.27696900E+00, 0.16594300E+00, -.17175000E+00, 0.15631900E+00, -.74893600E+00, 0.14746200E+00, 0.15906300E+00, 0.10559700E+00, 0.30712900E+00, -.37957000E+00, 0.78820000E-01, -.42621200E-01, 0.41617400E+00, -.45457200E+00, -.34448900E-02, 0.18004900E-01, -.36568000E-01, 0.35428200E-01, -.11885300E+00, 0.19972300E+00, 0.51194300E-02, 0.74419700E-01, 0.35213100E-01, -.29923900E+00, 0.11052000E+00, 0.91663800E-01, 0.11212100E+00, 0.11318300E+00, 0.78568300E-01, 0.39436500E+00, -.72457900E-01, -.87841400E-02, -.18689200E-02, 0.77704500E+00, -.60873600E-01, -.75321000E-02, 0.10231600E+00, 0.69043700E+00, 0.54604000E+00, 0.95381900E+00, 0.53625800E-01, 0.16706300E+00, 0.23327700E+00, -.25980800E+00, -.78433100E+00, -.12575100E-01, -.26651400E+00, -.29692600E-01, -.27914000E+00, -.16146300E+00, 0.74265200E-01, -.33139500E-01, 0.18512700E+00, 0.15616400E+00, 0.12979600E+00, 0.19568200E-01, 0.38911200E+00, -.86449800E-02, -.74498500E-01, 0.87453400E-01, -.17448500E-01, -.75435700E-01, -.44705600E-01, 0.10215500E+00, 0.86150200E-02, 0.11322700E+00, -.14369200E-03, 0.52672900E-01, 0.78772600E-01, -.17469400E-01, -.76733200E-01, 0.24312000E-01, 0.19999000E+00, -.37985400E+00, -.22807500E+00, -.16099000E+00, -.45530700E-01, -.22068700E+00, 0.11074700E-01, -.18934200E+00, 0.12460300E+00, 0.19512500E+00, -.13664400E+00, -.11610700E+00, -.75600500E-01, -.11105200E+00, -.98875200E-01, 0.53042300E-01, -.28899300E-01, -.56234900E-03, -.28537900E+00, 0.15545700E-01, 0.71838400E+00, -.11171500E+00, -.11062600E+00, -.23454800E+00, 0.15369700E-01, -.14701800E+00, -.38699900E+00, -.13278800E+00, -.44769000E-01, -.40410800E+00, -.27081500E-01, 0.79847900E-01, -.59138900E-01, 0.98808900E-01, -.96303900E-01, -.14492200E+00, 0.54499800E+00, -.83975000E-01, -.45704900E-01, 0.10423300E+00, 0.49791900E+00, -.11967000E+00, 0.12122700E+02, 0.15205200E+01, 0.54385500E+00, -.40281100E+01, -.17051900E+01, 0.18811800E+01, -.94675100E-01, 0.11124000E+01, -.36514100E+01, -.13116800E+01, -.91217000E+00, 0.66383700E+00, 0.15667700E+00, -.87061000E+00, -.11848700E+01, -.16419900E+02, -.10412500E+02, 0.69554900E+00, 0.54058200E+01, 0.27378700E+01, -.68418800E+01, -.39718100E+01, 0.66375000E+01, 0.38569000E+01, -.48583400E+01, 0.81858400E+00, -.21573000E+01, 0.14201500E+01, 0.11491300E+01, 0.13805400E+01, -.34536300E+01, 0.67631600E-01, -.14719700E+00, -.32125500E+00, 0.97891500E-01, -.24792600E+00, 0.37642400E-01, -.47673000E-01, 0.17492300E+00, 0.97080000E-01, 0.87726500E-02, 0.99346600E-01, -.45716100E-01, 0.35386400E+00, 0.11050700E+00, 0.10414700E+00, 0.91884900E-01, -.18646400E+01, -.37092000E+00, -.59681700E+00, 0.97332400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.51206100E+01, -.99921600E-01, 0.49067600E+01, 0.96558900E+01, -.70471700E+00, -.46194100E+01, -.69441600E+00, -.30348600E+01, -.32808100E+01, 0.44899800E+00, -.16167400E+01, 0.27630900E+01, -.80439000E+00, 0.17372300E+01, -.17233600E+01, -.14668600E+01, 0.39416100E+01, -.94884800E+00, -.36337700E+00, -.80552300E+00, 0.22599300E+01, -.10215900E+01, 0.33258700E+00, 0.50623200E+00, 0.32789800E+00, 0.16888200E+01, -.12100400E+01, 0.12975300E-01, 0.21867600E+00, -.17609100E+01, -.66674900E+00, -.22996000E+01, -.38128100E+01, 0.68604600E+00, -.21197400E+01, -.17483500E-01, -.87291500E-01, 0.42025400E+00, 0.19023600E+00, -.41010200E+00, -.19380400E+01, -.21591100E+00, -.86084900E+00, -.30014100E+00, -.95020700E+01, -.10127000E+01, -.45973300E+00, 0.14833700E-01, -.67736800E-01, 0.20829300E+00, 0.16180500E+01, 0.28390200E+01, 0.19994400E+00, -.16721100E+00, -.26703700E+00, -.16117200E+00, 0.34214100E+00, -.11786100E+01, 0.46335600E+00, -.51519600E+00, -.19320200E+00, -.81187300E+00, 0.17289900E-01, -.12147100E+01, -.93078600E+00, 0.16877500E+00, -.23453900E+00, 0.10706500E-01, 0.11827400E+00, 0.73926400E+00, -.77419500E+00, -.24935000E-01, -.49120600E+00, -.17893700E+00, 0.75715600E+00, -.17063100E+00, 0.31446500E+00, 0.40409800E+00, 0.14001800E+00, -.13128800E+01, 0.85994200E+00, 0.30377100E+00, 0.25981000E+00, -.61990900E-01, 0.34077500E+00, 0.11740800E+01, -.18890700E-01, -.65483600E+00, 0.63308400E+00, 0.49850400E-01, -.13316300E+01, -.11763000E+00, -.18762200E+01, 0.38649500E-01, -.24159500E+00, -.62979400E+00, 0.37449800E+00, 0.36713000E+00, -.12742600E+01, -.21664000E+00, 0.43661700E+00, -.12247900E+00, -.68787300E+00, 0.56176800E+00, 0.52928400E+00, 0.33919700E+00, 0.43268300E+01, 0.12169900E+00, 0.13094300E+01, 0.15620200E+00, -.11549200E+00, -.30572600E+00, 0.15385900E+01, -.62782100E+00, -.16067400E+01, -.18795200E+01, 0.19170600E+01, -.48154400E-01, -.32487600E+00, -.64697400E+00, 0.11960200E+00, 0.12390200E+00, -.34638000E+02, -.14056500E+02, 0.19800000E+02, 0.18089000E+02, 0.27624900E+02, -.15338300E+02, 0.13140300E+02, -.13230900E+02, -.27953400E+01, -.24657200E+01, 0.13839500E+01, 0.79248600E+00, -.53166800E+01, -.17100000E+01, -.63692900E+02, 0.10508700E+02, 0.33404800E+02, 0.21597200E+02, -.15223400E+02, -.26815400E+02, 0.25498700E+02, 0.22118300E+02, -.32424900E+02, 0.31005800E+02, -.28622500E+01, 0.52924500E+01, 0.52818800E+01, -.69945100E+01, -.11179000E+02, 0.68205800E+01, -.55592200E+00, 0.97953900E+00, -.92731300E-01, -.14184200E+01, 0.10231400E+00, -.29266200E+01, -.86223000E+00, -.23744600E+01, -.16070200E+00, 0.13484000E+01, -.30006000E+01, -.19314000E+00, 0.71542200E+00, -.33009500E+00, -.14191600E+00, 0.50279900E+00, -.24927700E+01, -.18143600E+01, -.24237500E+01, -.59628300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17396700E+01, -.44075100E-01, -.23524200E+01, -.52220300E+01, -.23767000E+00, 0.27022100E+00, -.95087600E-01, 0.74433200E+00, 0.72037900E+00, -.87508700E-01, 0.71435300E+00, -.38421900E+00, 0.14304700E+00, -.24272300E+00, 0.67913000E+00, -.95791600E-01, -.19705400E+01, 0.59381100E+00, 0.13338100E+01, 0.70187900E+00, -.10004400E+01, 0.56180000E+00, -.23503400E+00, -.19719300E+00, -.24451800E+00, -.11162900E+01, -.69222900E+00, 0.17091400E-01, 0.22511000E-01, -.48574900E+00, 0.11268100E+01, 0.95342200E+00, 0.77064000E+00, 0.94178500E-02, 0.74921000E+00, 0.80895400E-01, 0.90395700E+00, -.11973400E+00, -.69231100E-01, 0.19619900E+00, 0.86655000E+00, 0.41114800E-01, 0.22719100E+00, -.64375000E-01, 0.12704400E+01, 0.86250900E+00, 0.20639900E+01, 0.35427900E-01, 0.77187500E-01, -.17655400E+00, -.63122800E+00, -.66373500E+00, 0.14962000E+00, 0.34650200E+00, 0.13731000E+00, 0.47477600E+00, 0.35237600E-02, 0.25959100E+00, -.47862400E-01, -.13974100E+00, -.36596200E+00, 0.23701600E+00, 0.38813100E+00, -.54692100E+00, 0.28893500E+00, -.30149200E-01, -.16719200E-01, 0.25829100E+00, 0.71769100E-01, -.34918800E+00, 0.43210400E+00, -.10085800E+00, 0.10521300E+00, 0.10941500E+00, -.36012400E+00, 0.23035900E-01, 0.12722500E+00, -.34000100E+00, 0.46718400E-01, 0.98529100E+00, -.14422700E+00, -.31287700E+00, -.26677100E+00, 0.84151100E-02, -.66283700E-03, -.26353400E+00, 0.33738500E-01, 0.21293800E+00, -.58013500E+00, -.17300600E+00, -.41062300E+00, 0.14287700E+00, -.49440300E+00, -.18213500E+00, 0.16914800E+00, -.17917200E+00, 0.75739500E-01, -.12484200E+01, 0.70097600E+00, 0.10674500E+01, -.14224400E+00, 0.16041000E+00, -.47963900E+00, -.84741400E-01, -.40253800E+00, 0.10961100E+01, 0.20281200E+01, 0.29814300E+00, -.55562200E+00, -.16612900E-01, -.33380000E+00, -.77944900E-01, -.53379700E+00, 0.68779000E+00, 0.60386900E+00, -.10629200E+01, 0.33549800E+00, 0.12420500E+00, -.89235200E+00, -.86256200E+00, 0.53446100E-01, -.15836900E+01, 0.10040800E+00, -.43266100E+01, 0.36209600E+01, 0.63007900E+00, 0.44160600E+01, -.60794600E+01, -.17436100E+01, 0.32386200E+01, -.57459500E+00, 0.60333800E+00, 0.65943300E+00, 0.11192000E-01, -.26499100E+01, 0.12369000E+01, -.30277500E+02, 0.28694600E+02, 0.17526000E+02, 0.14692200E+02, -.12190500E+02, -.18108800E+02, -.20200800E+02, 0.13793400E+02, 0.59528200E+01, -.10748400E+02, -.65059600E+01, -.16400400E+01, -.32981500E+00, 0.31508800E+01, 0.75661000E+01, -.13084300E+01, 0.24417700E+00, 0.34568700E-02, 0.61058500E+00, -.39036300E+00, -.12749200E+00, -.11159300E+01, -.49473800E+00, -.46988300E+00, -.98240500E-01, -.16162300E+00, -.10554900E+01, -.22379900E+00, -.87155700E+00, -.55037400E-01, -.43999700E-01, 0.62809800E-01, -.95177500E+00, 0.38302200E-01, -.36650000E+00, 0.21741100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.26971000E+01, -.93422500E+00, 0.71145500E+00, 0.30247300E+01, -.20141500E+01, -.77508800E+00, 0.27005500E+00, 0.91662400E+00, 0.27394600E+00, -.29880800E+00, 0.11265700E+00, -.50538200E+00, -.24672500E+00, -.15880000E+01, 0.35071200E+00, -.12862800E+01, 0.10413500E+01, 0.83197800E+00, 0.22551600E+01, -.25162100E+01, 0.18471200E+01, -.13803400E+01, -.10294100E+01, 0.89210500E-01, 0.13073700E+00, 0.33166100E+00, -.70160000E-01, 0.25413200E-01, -.66181800E+00, -.17688400E+01, 0.23769900E+01, 0.19052200E+00, 0.94486900E+00, 0.85954200E-01, 0.96792900E+00, 0.28628900E+00, -.98785800E+00, 0.10525600E+00, 0.11724100E+00, 0.19532200E+00, 0.12780900E+01, -.97914100E-01, 0.43360400E+00, -.89693900E+00, -.72008600E+01, -.13336600E+01, 0.57648500E+01, -.21436700E+00, -.50311600E+00, -.98235300E+00, -.45259300E+00, 0.11059200E+01, 0.59379600E+00, -.41082900E+00, -.74933400E-01, 0.11365500E+01, 0.11049200E+01, -.14114700E+00, -.55288600E+00, -.55356100E+00, -.59160900E+00, 0.65502200E+00, -.48871100E+00, -.25827300E+01, 0.80699400E+00, -.50036900E-01, -.32287600E+00, 0.84082800E+00, 0.11192700E+01, 0.41179500E+00, -.10545000E+01, -.81032900E+00, -.34355200E+00, -.38131800E+00, -.30842400E+00, 0.64770500E+00, -.34046200E+00, -.22547700E+00, 0.25778500E+00, -.17404100E+01, 0.14631300E+01, 0.63988700E+00, 0.64244100E+00, -.13291100E+00, 0.75183800E+00, -.13825100E+00, -.49957900E-01, -.41746800E+00, 0.19530100E+01, 0.79502000E+00, 0.29707700E+01, -.69471800E+00, -.66312800E+00, -.52130400E-01, -.21097700E+00, -.20471800E+01, -.30427400E-01, -.11595800E+00, -.41499200E+01, -.18291300E+01, -.86470000E-01, -.27572200E+00, -.49225100E+00, 0.57708700E+00, -.12899000E+00, -.21603500E+01, -.13266200E+01, 0.12950700E+00, 0.32483400E+00, 0.21398700E+00, 0.58879000E+00, -.45465500E+00, -.19806400E+00, -.47687100E+00, 0.39972000E+00, -.94997500E+00, 0.99161000E+00, 0.12327100E+01, -.16968700E+00, -.63581000E-01, -.58759000E+00, -.41715900E+00, 0.79989300E-01, -.51218900E+00, -.61981800E+01, -.11417800E+01, 0.19223400E+01, -.10386700E+01, 0.20189000E+01, 0.24748700E+01, 0.89404600E+00, 0.27832800E+01, -.56580700E+01, 0.29082500E+01, -.11364700E+01, 0.25360300E+01, -.29715100E+02, 0.36505400E+02, 0.15198300E+02, 0.13968400E+02, -.54832600E+01, -.16843900E+02, -.16929900E+02, 0.13925800E+02, -.36943400E+01, 0.36355300E+01, 0.36456300E+01, 0.53172500E+01, -.85132400E+01, -.25440700E+01, 0.54902500E+01, 0.66343800E+01, -.16399800E+00, -.54451300E+00, 0.15680900E+01, 0.80314800E+00, 0.51733700E+00, 0.34096800E+00, 0.58347900E+00, 0.13866900E+01, -.59966900E+00, -.14069800E+01, 0.29599400E+00, 0.17356500E+00, -.33850300E+00, 0.95439900E-01, 0.35048400E+00, -.24174700E+00, -.70286000E+00, 0.10902800E+01, -.75023200E+00, 0.17650000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.37742200E+01, 0.70007800E-01, 0.52168500E+01, 0.12032300E+02, 0.45784000E-02, -.16465400E+00, 0.37247600E+00, -.15238500E+01, -.11951300E+01, -.17225000E-01, -.10860600E+01, -.77599500E-01, -.11834900E+01, 0.15336200E+01, -.12873900E+01, 0.17966900E+01, 0.11480300E+01, 0.52570700E+00, -.32815200E+01, 0.74334200E+00, -.81787600E+00, -.62448700E+00, 0.42576200E+00, 0.30710800E+00, 0.19685600E+00, 0.11289300E+01, 0.16858900E+01, -.20778000E-01, -.26192800E+00, 0.18946400E+01, -.34331100E+00, -.58306700E+00, -.15397200E+00, -.35791600E+00, -.50814000E+00, -.12184900E+00, -.11974300E+01, 0.27934000E+00, -.11766200E-01, -.88104600E-01, -.21168100E+01, 0.76021700E-01, -.16973500E+00, -.16865900E+00, -.24577400E+01, -.92946400E+00, -.20066800E+01, 0.74422800E-01, -.98223100E-01, 0.23960500E+00, 0.92855600E+00, 0.81116600E+00, -.34840100E+00, -.12440000E+00, -.25233900E+00, -.10294600E+01, -.58084900E+00, -.88044300E+00, 0.59103600E+00, 0.65136100E+00, 0.35741200E+00, -.10774600E+01, -.63553900E+00, 0.13779600E+01, -.11814200E+01, -.40833300E+00, 0.32743700E+00, -.13649300E+01, -.53385800E+00, 0.12962200E+01, -.11667500E+01, 0.19476000E+00, -.50786000E+00, -.22902700E+00, 0.47419000E+00, 0.24069200E+00, 0.12441400E+00, 0.59633800E+00, -.26752600E+00, -.28126200E+01, -.51427600E+00, 0.29132400E+00, 0.46503900E+00, 0.16875000E+00, -.50980100E+00, -.57220900E+00, -.50449900E-01, -.88014300E-01, 0.22971700E+01, 0.38156900E+00, 0.46398200E+00, 0.24158000E+00, 0.25339700E+01, 0.30523200E+00, -.68734400E+00, 0.59807100E+00, -.11991600E+01, 0.89019900E+00, 0.45489500E+00, -.12771500E+01, -.19936300E-01, 0.47750900E+00, 0.74251100E+00, -.65920900E+00, -.49783000E+00, 0.91681100E+00, -.46979900E+01, -.45861000E+00, -.10854700E+01, -.10004700E+00, 0.41963500E+00, 0.12718400E+00, 0.14981700E+00, -.53175900E-01, 0.57668600E+00, -.35179600E+00, -.13839400E+00, 0.11032800E+00, -.63510800E+00, -.49459600E+00, 0.24949500E+00, -.19979100E+01, 0.77645600E-01, 0.83089900E+00, -.82780200E+00, -.67004300E+01, -.54573100E+01, 0.23165900E+01, -.92464400E+00, 0.29426100E+01, -.16236800E+00, -.28081300E+00, -.22710200E+01, 0.26466100E+01, 0.47528300E+01, -.11953000E+01, -.26727100E+02, 0.31088900E+02, -.75929200E+01, 0.74457200E+01, 0.12185100E+02, -.10146000E+02, -.17667700E+02, 0.92199700E+01, -.49215600E+01, 0.64964400E+01, 0.12253100E+02, 0.58037400E+01, -.79769900E+01, -.52762500E+01, 0.44122800E+01, 0.61749800E+01, -.28066200E-01, -.17743900E+01, 0.58107500E+00, 0.14910100E+01, 0.22831600E+00, 0.17959900E+01, 0.76283200E+00, 0.22874300E+01, -.67082400E+00, -.14901500E+01, 0.16674800E+01, 0.23264000E+00, 0.41689900E+00, -.14801700E+00, -.21955100E+00, -.34276000E+00, 0.19394500E+01, 0.10604900E+01, 0.40033100E+00, 0.18325000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23378300E+01, 0.36267400E-01, 0.43760500E+01, 0.68833300E+01, -.14801800E+01, -.25559000E+01, -.17003700E+00, 0.29731500E+00, -.33917100E+00, 0.15617100E+00, 0.74832600E+00, 0.13108600E+00, -.15356300E+01, 0.30687600E+01, -.43307800E+00, 0.64393800E+00, -.55730600E+00, -.44778200E+00, 0.25038600E+00, 0.30053800E+01, -.52507700E+00, 0.37471000E+00, -.27155900E+00, -.56541000E+00, -.12179500E+00, -.67538800E+00, 0.11619700E+01, 0.13727900E+00, 0.49272400E+00, 0.24280800E+01, 0.15603200E+01, 0.37267000E-01, 0.48962800E-01, -.92640300E+00, 0.26599300E-01, -.37942700E+00, -.56448300E+00, -.17301200E+00, -.33701600E+00, 0.55998100E+00, -.20883100E+01, 0.32475300E+00, -.37055400E+00, -.45865900E-01, -.47944800E+00, 0.37783400E+00, -.87192200E+01, -.71794900E-01, 0.13659600E+00, 0.40000000E+00, 0.11729300E+01, 0.77267700E-01, 0.61159900E+00, 0.39487000E+00, 0.34438500E-02, 0.41563100E+00, -.61267300E+00, 0.62739700E-01, 0.44992200E+00, -.14669100E+00, -.84299600E+00, -.76195400E+00, 0.11484700E+00, -.11786400E+00, 0.21892500E+00, -.27860300E+00, -.20571300E-01, 0.25729300E+00, -.17238300E+00, 0.48553800E+00, -.33342600E+00, -.15201300E+00, -.18271400E+01, -.28581900E+00, -.87745600E+00, -.27433200E+00, 0.20535500E+00, 0.16487500E+00, -.76348600E+00, -.16199400E+01, -.42290500E+00, 0.19938900E+00, 0.64711600E+00, 0.43778000E-01, -.46251800E+00, 0.25365900E+00, -.34059800E+00, 0.82814600E-01, 0.29932700E+01, 0.39814200E+00, 0.34647300E+00, 0.55700200E+00, 0.10200600E+01, 0.91621400E-01, -.14454000E+00, 0.21783000E+00, 0.31467900E+00, 0.76646800E-01, 0.23259800E-02, -.22603600E+01, 0.54346400E+00, 0.38419600E+00, 0.11448700E+01, -.70125500E+00, 0.22942400E+00, 0.26029800E+01, -.13691800E+01, 0.15023400E+00, 0.17468300E+01, 0.46639800E-01, -.14278000E+00, -.36778400E+00, -.85609100E+00, 0.48643700E+00, 0.21684200E+01, -.51583000E+00, -.54220700E+00, 0.15490900E+01, -.43100900E+00, 0.23924300E+00, -.49344800E+00, -.24281400E+01, -.32417800E+00, -.33566400E+00, 0.59489300E+00, 0.33935600E+00, 0.59080800E+01, 0.10073500E+01, 0.40988900E+01, -.28087500E+01, -.61967900E+01, -.57160200E+01, 0.78381800E+01, 0.71781500E+00, 0.18652600E+01, -.56814800E+01, -.42570000E+01, -.38773300E+02, 0.24895800E+01, 0.26779700E+01, 0.27175500E+01, -.29667600E+01, -.66452500E+00, 0.39418700E+01, -.59557700E+01, 0.22463200E+01, 0.29861600E+00, -.58070300E+01, 0.13020100E+02, -.10870000E+01, -.29438300E+01, -.69928800E+01, 0.37972100E+00, 0.91140200E+00, -.19337400E+01, -.45964600E+00, -.72179300E+00, -.10072300E+01, -.93272500E+00, -.10122400E+01, 0.11772400E+01, 0.84052700E+00, -.89095500E+00, -.29938300E+00, -.16160900E+00, 0.11981300E+01, 0.90511900E+00, 0.57743400E+00, -.20740300E+01, -.33980700E+00, -.20515700E+01, -.24426900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15555700E+01, -.59960900E-01, 0.30351400E+01, 0.43202000E+01, -.72080800E+00, -.17673600E+01, -.86610800E-01, -.12570900E+00, -.13179900E+00, 0.17219900E+00, 0.34765400E+00, 0.80144000E+00, -.12280200E+01, 0.13478700E+01, -.19497000E+00, 0.72787500E+00, -.29018200E+00, 0.57321700E+00, -.46628400E+00, 0.40386200E+00, 0.13193500E+01, -.17415300E+00, -.11266500E+01, -.88060700E+00, -.37152100E+00, -.10137500E+01, -.80530700E+00, -.12884800E-01, 0.19927200E+00, 0.95920200E+00, 0.36075000E+00, -.46364700E-01, 0.48769500E+00, -.20603900E+00, -.17716600E-01, -.19534000E+00, -.52586800E+00, 0.44503300E-01, -.11945300E+00, 0.17066100E+00, -.12252600E+01, 0.16826500E+00, 0.63211100E-01, -.82878700E+00, -.50558500E+01, 0.85194300E+00, -.15873000E+00, 0.61762500E-01, 0.92772100E-01, 0.14441900E+00, -.46394900E-01, -.20433300E+01, 0.88915500E+00, -.51202200E+00, -.57222300E-01, 0.54478100E+00, -.28876700E+00, 0.47085700E-01, 0.12155800E+00, -.10632200E+00, 0.64536100E+00, 0.52528000E-01, 0.22834300E+00, -.26307900E+00, 0.40069300E+00, -.61498000E-01, 0.11245600E+00, 0.19074900E+00, -.20139100E+00, -.25145300E+00, 0.49309000E+00, 0.15007200E+00, 0.17062700E+00, 0.12367600E+00, 0.91568200E-01, -.12807600E+00, 0.36948200E-01, -.49301400E-01, 0.13377400E+00, 0.85460100E+00, 0.92375400E-01, -.61219500E-01, -.27565300E+00, -.76507400E-01, -.12536100E+00, 0.23056500E+00, -.11607500E+00, 0.13532100E+00, -.10190600E+01, -.24654400E+00, -.11925500E+01, 0.43980100E+00, -.26615100E+00, -.13618500E+00, -.50827100E-02, 0.22878300E+00, 0.50753700E+00, -.34436100E+00, 0.79850300E+00, 0.65271800E+00, -.33978000E+00, 0.55256800E-01, 0.46032600E+00, -.10000800E+00, -.32174500E+00, 0.58014100E+00, -.13609500E+01, -.18105100E+00, 0.65751300E-01, 0.13590700E+00, -.10740700E+00, -.37070000E+00, 0.23791500E+00, 0.16778000E-01, 0.49420000E+00, -.21007400E+00, 0.22383000E+00, 0.19081000E+00, 0.30558700E-01, -.11204300E-01, -.11218000E+00, -.20596200E+00, 0.16681700E-01, -.11599100E+00, 0.32367900E+00, 0.74553500E-01, 0.42337200E-01, -.18625900E+01, -.29189500E+01, -.12679700E+00, 0.12176400E+01, 0.17752900E+00, 0.20205700E+01, -.15229500E+01, -.52200100E-01, 0.81494200E+00, 0.15602000E+01, 0.40286100E+01, -.33586100E+01, -.17479000E+01, 0.32498000E+00, 0.18644500E+01, 0.36596800E+01, -.17889500E+01, 0.47390000E+01, -.64783800E+01, -.13271100E+01, -.17386000E+01, 0.10474900E+01, 0.26130700E+01, 0.15839900E+01, -.20543300E+01, 0.12154100E-01, 0.38175800E+00, -.44789900E+00, -.12085700E+00, -.60929800E-01, -.32666900E+00, -.11596700E+00, -.29934100E+00, 0.28048000E+00, 0.66738900E+00, -.34114900E+00, -.60196700E-01, -.35777600E+00, 0.19344900E+00, 0.22993000E+00, -.25641400E-01, -.53092100E+00, -.44071300E+00, 0.19841500E+00, 0.16948800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14497100E+01, 0.72507000E-01, 0.37190500E+01, 0.61404500E+01, -.73993700E+00, -.20191300E+01, -.19101900E+00, -.21071400E+01, -.21317400E+01, 0.24442800E+00, 0.59723800E+00, 0.16960700E+01, -.22629800E+01, 0.29635600E+01, -.89352600E+00, -.74871000E+00, 0.24335300E+01, -.87556700E+00, -.36265300E+01, 0.54076700E+00, 0.33582700E+01, -.87964800E+00, -.16538500E+01, -.98603800E+00, -.54726800E+00, -.78878300E+00, -.82994600E+00, 0.45649600E-01, 0.60838800E+00, 0.13880900E+01, 0.27446600E-01, -.13273300E+01, -.81301100E+00, -.56137700E+00, -.12148300E+01, -.39027000E+00, -.56797700E+00, 0.24710800E+00, 0.12510300E+00, -.27117100E+00, -.25352700E+01, 0.11324100E+00, -.47408000E+00, -.49288400E+00, -.90700100E+01, 0.85140700E+00, -.54792000E+00, 0.21203900E+00, 0.19620300E+00, 0.37110900E+00, 0.12429900E+01, -.17561100E+01, 0.83868600E+00, -.97223500E+00, -.12977800E+00, -.69374400E+00, -.39476700E+00, -.26799600E+00, 0.28808900E+00, -.15397300E+00, 0.21154800E+00, -.41854500E+00, -.60308400E-01, -.64949700E+00, -.51254100E+00, 0.81974600E-01, -.22347800E+00, 0.53136700E+00, 0.22171700E+00, 0.16022300E+00, -.31741900E+00, -.23827900E+00, -.16145500E+00, 0.39057300E-01, 0.15854900E+00, -.55100800E-03, 0.23803400E+00, 0.28911700E-01, 0.19503300E+00, -.12942500E+01, 0.14595900E+00, -.13905500E+00, 0.36922700E+00, 0.41689200E-01, -.17128900E+00, 0.95262600E+00, -.13585600E+00, -.48500200E+00, -.22884300E+00, -.10233300E+00, -.21076800E+01, 0.41086800E+00, -.89337000E+00, 0.17016300E+00, -.36282600E+00, 0.36466900E+00, 0.37973000E+00, 0.18129900E+00, 0.73270200E+00, 0.23000400E+00, 0.85563800E+00, 0.55938000E-01, 0.26015700E-01, 0.10046300E+00, -.34184700E+00, 0.17890700E+01, 0.61760700E+00, -.14142300E-01, 0.21830800E+01, 0.63308900E-01, 0.36258600E+00, -.14775400E+00, 0.62723000E+00, 0.27157600E+00, -.99503800E+00, 0.39788000E+00, -.39720000E+00, -.50382800E+00, -.42666000E+00, 0.18383900E+00, 0.29733200E+00, 0.36513600E+00, 0.69741400E-01, 0.28572400E+00, -.40258000E+00, -.56177600E-01, 0.22455600E-01, 0.59290700E+00, 0.50176400E+01, 0.12025800E+01, -.32545000E+01, -.94999200E+00, -.29027600E+01, 0.25905100E+01, 0.89021300E+00, -.10237800E+01, -.17662200E+02, -.73364600E+01, 0.16095900E+02, 0.88189800E+01, -.42176900E+01, -.97949400E+01, -.67099800E+01, 0.85367700E+01, -.13587400E+02, 0.10574000E+02, -.17806400E+00, 0.20399800E+01, 0.17763300E+01, -.48524200E+01, 0.94904500E+00, 0.21009900E+01, -.10990700E-01, -.10357600E+01, 0.11714100E+01, 0.16279800E+00, 0.24407600E+00, 0.47659100E+00, 0.22699600E+00, 0.64926800E+00, -.64119500E+00, -.13349800E+01, 0.39118500E+00, 0.73519700E-01, 0.23873400E+00, -.50584200E+00, -.66481000E+00, 0.87925500E-01, 0.57438800E+00, 0.99286400E+00, -.10011500E+01, 0.67947400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23068500E+01, 0.71268600E+00, -.94535000E+00, -.22609500E+01, 0.13475200E+01, 0.21840900E+01, -.11030800E+00, 0.39547500E+00, 0.81567100E+00, 0.65452600E+00, 0.93702700E-01, 0.38264400E+00, -.35359500E+00, 0.52265500E+00, -.12221300E+00, 0.91275700E+00, -.69319300E+00, -.15941900E+01, -.61424500E+01, 0.73399300E+00, -.16993500E+01, 0.11253300E+01, 0.25461000E+00, -.28263400E+00, -.49509300E+00, -.18161800E+01, 0.21005700E+01, 0.33318600E-01, 0.57227100E+00, 0.27686600E+01, -.21908000E+01, -.28283900E+00, 0.27233600E-01, -.10051700E+01, -.19842000E+01, -.11547800E+01, 0.96079100E+00, 0.47388800E-01, -.57198900E+00, -.24223400E+00, -.32095900E+01, 0.12872000E+00, -.71081100E+00, -.51211800E+00, -.68116200E+01, 0.21716700E+01, -.72304300E+01, 0.87409900E-01, 0.34061000E+00, 0.53630600E+00, -.56063600E-01, -.42778000E+01, 0.10928100E+01, -.19054300E+01, -.12145300E+00, 0.15143800E+00, -.37037800E+00, -.19094300E+01, 0.71632700E+00, 0.27625600E+00, -.38906500E+00, -.82509900E+00, 0.13601200E+01, 0.10488600E-01, 0.13529300E+00, 0.19637300E+00, -.70255000E+00, 0.14149700E+01, -.15917400E+00, -.71525800E+00, 0.11787700E+01, -.46081400E+00, -.48557700E+00, -.28123600E+00, -.38683600E+00, 0.39847800E+00, -.67958100E+00, 0.18769100E+00, -.57392400E+00, -.51005000E+00, -.15566300E+01, -.23908800E+00, 0.12776900E+01, 0.49304000E-03, -.28710300E+00, 0.10811100E+01, -.28718500E+00, 0.10410400E+00, 0.15333000E+01, -.15225000E+00, -.11056500E+01, -.27850800E+00, -.30845400E+00, 0.22011200E+00, -.27986000E+00, 0.29579600E+00, -.54648700E+00, 0.10264100E+01, -.36206400E+00, -.78624600E+00, 0.14415900E+00, -.18841100E+00, 0.51211900E+00, -.20898300E+00, 0.40090900E+00, -.72516200E+00, -.52327000E+00, 0.69715000E+00, 0.22105600E+01, 0.41765300E+00, -.62288200E+00, 0.46724800E+00, -.95344600E-01, 0.14341500E+00, 0.61707100E-01, -.67083700E+00, 0.16619700E+00, -.67185200E-01, -.37977100E+00, 0.42240400E-01, -.40497100E+00, 0.17110400E+01, 0.28098600E+00, 0.19958000E+00, 0.46199900E+00, -.96163900E-02, -.32996400E+00, -.46168200E+00, -.18555400E+00, 0.10147100E+02, -.19928400E+01, -.16405300E+01, 0.46563600E+01, -.20850500E+00, 0.26840600E+01, -.10429100E+01, 0.66018100E+02, -.34293700E+02, -.27755700E+02, -.24138800E+02, 0.61439200E+01, 0.29562000E+02, 0.11900100E+02, -.25632400E+02, 0.45687900E+01, -.26952100E+01, 0.55517000E+00, -.24291700E+01, 0.19126800E+01, 0.79925200E+00, -.37794600E+01, -.17528800E+01, 0.23334000E+00, 0.61079300E+00, -.11533700E+01, -.24844200E+00, -.58449600E+00, 0.38044300E-01, -.33784600E+00, -.71137200E+00, 0.98668600E+00, 0.80397400E+00, 0.11509900E+00, 0.14732200E+00, 0.63064800E+00, 0.32260100E+00, 0.15375300E+00, 0.36834000E+00, -.25925100E+00, 0.55425200E+00, 0.16881200E+01, -.17906100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.91585600E+01, 0.28512400E+00, -.95613800E+01, -.24111600E+02, 0.49724700E+00, 0.76508500E+01, 0.32279800E+00, 0.56391700E+01, 0.73005500E+01, -.23158900E+00, 0.38908200E+00, -.43610400E+01, 0.48883200E+01, -.73845800E+01, 0.32483400E+01, 0.11705400E+01, -.39323800E+01, -.96204200E-01, 0.28831700E+01, -.10249100E+01, -.47055800E+01, 0.17921600E+01, 0.86336400E+00, 0.42238600E+00, 0.30700600E+00, 0.22222300E+01, 0.25534200E+01, -.18235800E+00, -.91346700E+00, -.30968900E+00, 0.16502500E+01, 0.39840000E+01, 0.23426100E+01, 0.54000700E+00, 0.18298800E+01, 0.42640700E+00, 0.30070000E+01, -.25170800E-01, 0.54885600E+00, -.93940400E+00, 0.41844900E+01, -.44527800E+00, 0.52488200E+00, 0.20282400E+01, 0.13815700E+02, -.20506600E+01, 0.14566500E+02, -.42993300E+00, -.40008700E+00, -.13643300E+01, -.83880300E+00, 0.39226000E+01, -.23226500E+01, 0.23305400E+01, 0.38515400E+00, -.16729500E+01, 0.10684600E+01, -.26961100E+00, 0.17383200E+00, 0.49790000E+00, -.20770100E+01, -.11668800E+01, -.90704800E+00, 0.31844300E+01, -.10422200E+01, 0.48425000E+00, -.95606200E+00, -.19472400E+01, 0.15649000E+00, -.22127900E+01, 0.15700000E+01, 0.53468300E-01, -.85548700E-01, 0.51409400E+00, -.71903800E+00, -.15235500E+01, -.15078200E+00, -.34932600E+00, -.76719600E-01, -.15387100E+01, -.39657200E+00, 0.11097800E+01, 0.72922900E+00, 0.17792700E+00, 0.51086600E+00, -.11672300E+01, 0.30512400E+00, -.14056700E+00, 0.87868400E+00, 0.12391300E+01, 0.32015000E+01, -.30933900E+00, 0.52695000E+00, 0.36520900E+00, 0.48800200E+00, -.11672100E+01, 0.28278500E+00, 0.22632400E+01, -.35536300E+01, -.34949100E+01, 0.47185400E+00, 0.47716100E-01, 0.77530500E+00, 0.63704500E+00, 0.15702200E+01, -.17652200E+01, 0.18941400E+01, -.80743200E-01, -.17709300E+01, -.37338300E+00, -.80462200E-01, 0.52353700E+00, -.20349400E+01, 0.10498100E+01, 0.13467000E+01, -.40599900E+00, -.16809200E+01, 0.41391300E+00, -.88515300E+00, 0.12993700E+00, 0.41463300E+00, -.92902200E+00, -.38218400E+00, -.92059600E+00, -.32153000E+01, 0.30130200E+00, 0.22637900E+01, -.51528000E+00, -.51923700E+00, 0.17424400E+01, 0.18852400E+02, 0.22939100E+02, -.43235500E+02, 0.10281000E+02, -.15482800E+02, 0.21730900E+02, -.22707000E+03, 0.31538700E+03, 0.13111000E+03, 0.90278400E+02, -.41655100E+02, -.10788400E+03, -.74784400E+02, 0.88862300E+02, -.32798300E+02, 0.21901700E+02, 0.46738800E+01, 0.41232500E+02, -.53479700E+02, -.16563000E+02, 0.30828900E+02, 0.50243400E+02, -.12154100E+01, -.55622500E+01, 0.13992000E+02, 0.25883800E+01, 0.38931700E+01, 0.85583900E+00, 0.36505000E+01, 0.61739500E+01, -.71264500E+01, -.89246200E+01, 0.36549900E+00, 0.57634100E+00, -.31690700E+01, -.33051400E+01, -.20406900E+01, -.19413800E+01, 0.60970700E+01, 0.29543400E+01, -.25451800E+01, 0.14127800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.61498900E+00, 0.84267600E-02, 0.15097100E+01, 0.62757800E+01, 0.50134700E+00, 0.30761300E+00, -.21989600E+00, -.58373500E+00, -.76298100E+00, 0.90865800E-01, -.55233100E+00, 0.95104800E+00, -.64746500E-01, 0.27014000E+00, -.44772800E+00, -.35418000E+00, 0.42418800E+00, 0.78970500E-01, 0.58308500E+00, -.33478700E+00, 0.36136100E+00, -.21707200E+00, 0.57618500E+00, 0.32391200E+00, 0.14301400E+00, -.15882600E-01, -.30857200E+00, 0.12921700E-01, -.44796500E-02, -.70164700E+00, -.23727500E+00, -.41671800E+00, -.68386900E+00, 0.12122800E+00, -.22374200E+00, 0.16384000E-01, -.12678800E+00, 0.42314700E-01, 0.26424900E-01, -.92777300E-01, -.85828400E-01, -.33005000E-01, -.10263700E+00, -.12774200E+00, -.21531900E+01, -.44371100E-01, 0.15156800E+01, 0.49675700E-01, 0.75285100E-01, 0.24452300E+00, 0.49161000E+00, -.81893600E-01, 0.11244000E+00, -.36905400E+00, -.26008300E-01, -.20118700E+00, 0.16901000E+00, 0.24306200E+00, -.12854300E+00, 0.84198300E-02, 0.35639600E+00, 0.19855900E+00, -.90039000E-01, -.41378900E-01, -.49499600E-01, 0.70311500E-01, 0.10726000E+00, 0.24597000E+00, 0.15478500E+00, 0.38936900E+00, -.69431000E-01, 0.84419500E-01, -.18274400E-01, -.71599700E-01, 0.27091200E+00, 0.31622300E+00, -.18572800E+00, -.23890900E-01, -.81092700E-01, 0.28930700E+00, 0.18099900E+00, 0.27199400E-01, -.76529200E-01, 0.32034800E-01, 0.21143700E+00, -.37585300E-01, 0.89635200E-01, 0.80397800E-01, -.54028300E+00, 0.98076100E-01, 0.49481500E+00, -.10392900E+00, 0.33442000E+00, 0.37658500E-01, -.86502700E-01, -.10983700E+00, -.79729400E-02, 0.23616400E+00, 0.58997700E-01, 0.61135600E-01, -.12937600E+00, 0.19835400E-01, -.55445200E+00, 0.11239400E+00, -.22672200E+00, 0.42789100E-01, 0.10589100E+01, -.47460800E-01, -.37877100E+00, 0.75691500E-02, -.97735600E-02, -.84722400E-01, 0.53796800E-01, 0.27874200E-02, 0.69471000E+00, 0.63587300E-01, 0.49448700E-01, -.23190400E-03, 0.30371300E+00, -.29989000E+00, 0.13162800E+00, -.75235000E+00, -.28384600E-02, -.16844400E-01, 0.13382700E+00, -.29778700E-01, -.10691600E+00, 0.16810000E+00, 0.29396200E+00, -.20619300E+00, 0.16833500E-01, -.15282000E+01, 0.27478300E+01, -.16197300E+01, -.93015000E+00, -.18574100E+01, 0.84082200E+01, -.23376600E+02, -.59919100E+01, -.37298600E+01, 0.12498300E+01, 0.35917500E+01, 0.26392000E+01, -.38822600E+01, 0.51115100E+01, -.43680000E+01, -.18493300E+01, -.47012800E+01, 0.54022700E+01, 0.28138500E+01, -.12269100E+01, -.56601500E+01, 0.14101600E+00, 0.83271900E+00, -.14163500E+01, -.33431900E+00, -.61885200E+00, -.13830700E+00, -.26648200E+00, -.75802900E+00, 0.61625700E+00, 0.83789800E+00, -.63303900E-01, -.12846000E+00, -.22626600E+00, 0.38095200E+00, 0.37502000E+00, -.38645600E-01, -.76306900E+00, -.82741900E+00, 0.82243000E-02, -.11807600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.48635500E+01, -.14447600E+00, -.58525500E+01, -.15707500E+02, -.25814400E+00, 0.35073200E+01, 0.47260400E+00, 0.30147500E+01, 0.34107600E+01, -.49236300E+00, 0.19982300E+01, -.26687500E+01, 0.77778000E+00, -.22577100E+01, 0.21100200E+01, 0.57936900E+00, -.37649200E+01, 0.11945000E+01, -.34461000E-01, 0.76140900E+00, -.24107100E+01, 0.77354100E+00, -.80849500E+00, -.78655600E+00, -.32699200E+00, -.97449000E+00, 0.23482200E-01, -.24868700E-01, 0.18673500E-01, 0.10022000E+01, 0.44408000E+00, 0.18664400E+01, 0.33163600E+01, -.32353800E+00, 0.14899700E+01, -.15079700E+00, 0.74944100E+00, -.40003800E-01, 0.36103100E+00, -.38011000E+00, 0.16717100E+01, -.14073100E-01, 0.39075800E+00, 0.86930500E-01, 0.23346500E+01, 0.95343000E+00, -.41936400E+01, -.12200100E+00, -.36378300E+00, -.14134100E+01, -.10215700E+01, 0.14841300E+01, 0.20110400E+00, 0.14893500E+01, 0.46250600E+00, 0.21370200E+01, 0.10265200E+01, 0.54328400E+00, -.50361600E+00, -.26752400E+00, -.88543600E+00, 0.24016500E+00, 0.69890400E+00, 0.17244800E+00, 0.92257300E+00, 0.38315100E+00, -.48107900E+00, 0.16478800E+01, 0.14009100E+00, -.74061300E+00, 0.11520900E+01, -.98296500E-01, -.48275100E+00, 0.45567300E+00, -.29115700E+00, -.41134800E+00, 0.71672500E+00, -.24830100E+00, 0.32696500E-01, -.53573300E+00, 0.54831900E+00, 0.10394900E+00, 0.14939000E+00, -.18762100E+00, -.17658900E+00, 0.67793100E+00, 0.21049500E-01, 0.46382100E+00, -.23419100E+01, -.43305400E+00, -.20186700E+01, 0.12149600E+01, 0.12106900E+01, 0.62360800E-01, -.38220300E+00, 0.15076600E+01, 0.75041100E+00, -.61512000E+00, 0.35228200E+01, -.35975800E+00, 0.61149100E+00, 0.69980600E+00, 0.62559400E+00, -.26750800E+00, 0.63985400E+00, -.28221300E+00, -.10500600E+01, 0.38641400E+00, -.69848300E+00, -.32783300E-01, -.11811800E+01, 0.73606000E+00, -.15246300E+01, 0.48198100E+00, 0.13714000E+01, 0.30432100E+00, -.89857200E+00, -.29924900E+00, -.36094500E+00, -.10818800E+00, -.33625200E+00, 0.15687600E+00, -.14667900E+00, -.20832200E+00, 0.15676900E+00, 0.76459200E-01, -.34203100E+00, -.47483200E+00, 0.10490800E+00, 0.43813000E+00, -.15050500E+00, -.27649700E+01, 0.61315200E+01, -.20601100E+01, -.15796100E+01, 0.96884700E+00, -.24164400E+02, 0.22001100E+02, 0.12162100E+02, 0.90976100E+01, -.37964800E+01, -.10768300E+02, -.58824300E+01, 0.85106000E+01, 0.14353100E+02, -.15897900E+02, -.59331100E+01, -.77179500E+01, 0.61268200E+01, 0.75729000E+01, 0.44370800E+01, -.77141300E+01, 0.38055900E+00, 0.22167600E+01, -.25264300E+01, -.76453700E+00, -.20571700E+01, -.13390300E+01, -.83982800E+00, -.17079100E+01, 0.13573600E+01, 0.21708800E+01, -.11903300E+01, -.25578900E+00, -.21416000E+01, 0.17246400E+01, 0.17783500E+01, -.38472900E+00, -.22479200E+01, -.10998700E+01, -.18301800E+01, -.14110900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.69430500E+00, -.14039400E-02, 0.39014400E-01, -.12967200E+01, 0.68551100E+00, 0.31474300E+00, 0.59312100E-01, 0.22532300E+00, 0.42374200E-01, 0.77660700E-01, 0.17862200E+00, 0.55631900E+00, -.11551700E+00, 0.28234700E+00, 0.22800200E+00, -.15998100E+00, -.10641300E+01, 0.32370400E+00, 0.12692500E+01, 0.29827400E+00, -.27901600E+00, 0.52507700E+00, 0.52285800E+00, 0.17801300E+00, -.21298600E+00, -.14834900E+01, -.10087000E+01, 0.25057700E-01, 0.97784600E-01, -.53418600E+00, 0.10145400E+00, 0.44918400E+00, -.14093600E+00, 0.13200400E+00, 0.69592000E+00, 0.14175700E+00, 0.28529400E+00, -.39718200E-01, -.58996000E-01, 0.14385100E+00, 0.96699700E-01, -.27784500E-02, 0.41312400E-01, 0.92313500E-01, 0.21564300E+01, 0.31217800E+00, 0.12674000E+00, -.37322600E-01, 0.80543700E-01, 0.81982400E-02, -.25640600E+00, 0.10382900E+00, -.16948300E-02, 0.18141000E+00, 0.73725500E-01, 0.50739900E+00, 0.28642100E+00, 0.17903300E+00, -.38254900E-01, -.17937100E+00, -.17243200E+00, 0.71361800E-01, 0.18933100E+00, -.44080100E+00, 0.10152700E+00, 0.66815000E-01, -.11860700E+00, 0.11231100E+00, -.45835600E-01, -.17410900E+00, 0.31530600E+00, -.18550200E-01, -.25785700E-01, 0.20022900E-01, -.26660200E+00, -.10673300E-01, -.85358700E-01, -.67461400E-01, 0.87528200E-01, 0.17918000E+00, 0.23258800E+00, -.14817900E+00, 0.16801700E-01, 0.31167500E-01, 0.18210400E-01, -.17058300E+00, 0.37845400E-01, 0.79792200E-01, -.52999400E+00, -.59613200E-01, -.10287200E-01, 0.11055400E-01, 0.34076200E+00, 0.77993200E-02, -.26520100E-01, 0.26406300E+00, -.52621800E-01, -.13312800E+00, 0.74547000E+00, 0.27023200E+00, -.61992000E-01, 0.59532000E-02, 0.11582200E+00, -.18530500E+00, -.13027700E+00, 0.54293200E+00, 0.12844700E+00, 0.50651800E-01, 0.75489100E+00, 0.90596600E-01, 0.95703000E-01, 0.13616300E+00, 0.85219700E-01, 0.73040600E-01, -.27092000E+00, -.13271600E+00, 0.47742900E+00, 0.29275300E-01, -.23171600E-01, 0.10972500E+00, -.18829500E+00, -.30313900E+00, 0.73403000E-01, 0.35642300E+00, 0.22573200E+00, -.17894600E+00, 0.16434500E+00, -.63529700E-01, 0.37204500E+00, -.26747000E+00, -.25744100E-01, -.21158200E+00, 0.75666000E-02, -.13797300E+01, -.10312700E+01, -.36476400E+00, 0.18034300E+02, -.14989900E+02, -.19270600E+02, -.10537900E+02, 0.77464700E+01, 0.11144200E+02, 0.11450400E+02, -.10201900E+02, 0.53364800E+01, -.28909400E+01, 0.36096400E+01, -.96004300E+00, -.88894400E+00, 0.19603600E+01, -.91415300E+00, -.16064400E+01, -.15270400E+00, 0.37575900E+00, -.99531800E+00, 0.21377900E+00, -.20231500E+00, 0.31046700E+00, 0.17290500E+00, -.74748600E-02, 0.33567600E+00, 0.64543000E+00, 0.34741600E+00, 0.11440000E+00, 0.63682900E+00, 0.96902700E-01, 0.28099100E+00, 0.81661300E-01, 0.37129500E-01, -.33715800E+00, 0.12413100E+01, -.72354100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18219600E+01, -.14843700E-01, -.38219300E+01, -.58675700E+01, 0.95590500E+00, 0.21227100E+01, 0.23906700E+00, 0.41588900E+00, 0.33621100E+00, -.11135500E+00, -.16412900E+00, -.34769700E+00, 0.12553400E+01, -.17646400E+01, 0.55510700E+00, -.11427900E+01, 0.17195000E+01, -.90886100E+00, 0.10736500E+01, -.14361600E+01, 0.18511700E+01, -.31067700E+00, 0.65682500E+00, 0.21996000E+00, 0.29724200E+00, 0.19208400E+00, -.67227000E+00, 0.12196600E-02, 0.14284800E+00, -.12802900E+01, -.15919900E+01, -.56379700E+00, -.70331900E+00, 0.45348100E+00, -.12903400E+00, 0.21640500E+00, -.13968500E+00, -.21821900E-01, 0.17395100E+00, -.20900100E+00, 0.97657000E+00, -.23379700E+00, 0.14100800E+00, 0.27394400E+00, 0.48889100E+01, -.58365400E+00, -.26303700E+01, -.10921900E+00, 0.21774300E-01, 0.12592500E+00, -.36170800E+00, -.27435200E+00, -.33649300E+00, 0.37427600E+00, -.92970200E-01, 0.22689900E-01, -.46783200E-02, -.14376800E+00, -.19630200E+00, 0.16991800E+00, 0.15168400E+00, 0.35616800E+00, -.44959900E+00, 0.91929000E+00, -.41700600E+00, 0.12822600E-02, -.20577200E+00, -.96391000E+00, 0.12367700E+00, -.10582300E+00, -.73785300E+00, -.67731400E-01, 0.12662000E+00, -.85594900E-01, -.24000100E+00, 0.18180800E+00, -.19257600E+00, -.14158600E-01, 0.97532700E-01, 0.97376100E+00, -.12445800E+00, -.20300200E+00, 0.37629900E+00, 0.28029400E+00, 0.29814700E+00, -.65138600E+00, 0.34814300E+00, -.25519200E+00, 0.33089200E+01, 0.23787000E+00, 0.20914600E+01, -.14845000E+00, 0.50283900E+00, 0.17101400E+00, 0.91233200E+00, 0.18349700E+00, -.34449300E+00, -.78791100E-01, 0.44733700E+00, -.51304300E+00, 0.21924100E+00, 0.18437000E+00, 0.39560300E+00, -.17776200E-01, 0.17172100E+00, 0.73770900E+00, 0.91488100E+00, 0.14192500E+00, -.92675500E+00, -.35269700E+00, -.22961800E+00, 0.46991300E+00, -.74456100E+00, 0.25351100E+00, 0.44773400E-01, 0.12529300E+00, -.34451800E+00, 0.76047100E-02, -.10173500E-01, 0.43407700E+00, -.26034100E+00, 0.56208700E+00, -.53674400E-01, -.36660200E+00, -.38163200E+00, -.31135800E-02, 0.23021700E+00, 0.76389800E+00, 0.67478400E+00, 0.15213400E+00, 0.12630100E+00, 0.37202100E+00, 0.14515700E+00, -.36673300E+00, -.27586100E+01, -.23773700E+00, 0.23205200E+02, -.41975000E+01, -.12631200E+02, -.80791600E+01, 0.49118900E+00, 0.98224800E+01, 0.25878000E+00, -.84201400E+01, 0.16165200E+02, -.75471300E+01, -.14746100E+01, -.67315300E+00, -.61102400E+01, 0.46069400E+01, -.45529900E+00, -.27588900E+00, 0.41248700E-02, 0.47765200E+00, -.24969800E+00, -.41803400E+00, -.16265200E+00, -.47811000E+00, -.47059400E+00, -.52651000E+00, 0.17525100E+00, 0.30193500E+00, -.43606300E+00, 0.30860900E-02, 0.12923600E+01, -.15419900E-02, 0.24111700E+00, 0.36174700E+00, -.40983000E+00, -.45583500E+00, 0.13450600E+01, 0.26050200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10135600E+01, 0.75559500E-01, -.19673100E+01, -.29546000E+01, 0.30690100E+00, 0.14415300E+01, 0.41454400E-01, 0.13330800E+00, -.26624800E-02, -.22043000E+00, 0.69239600E+00, -.52339900E+00, -.41359800E+00, 0.30222600E+00, 0.57608900E-01, 0.34388700E+00, -.74825200E+00, 0.19118400E+00, 0.18543700E+00, 0.36920800E+00, 0.27057800E+00, 0.14548100E+00, 0.52076000E+00, 0.16785700E+00, -.99036200E-01, -.14916300E+01, 0.24269200E+00, 0.66824500E-01, 0.29413300E-01, 0.79507100E+00, 0.13518300E+01, 0.54182400E+00, 0.83855500E+00, -.48628400E+00, -.63671000E-01, -.11101900E+00, 0.30910100E+00, -.66661500E-01, -.24752200E+00, 0.24665300E+00, -.67482000E+00, 0.11380800E+00, 0.15062100E+00, 0.83314500E-01, 0.21485200E+01, -.23759100E+00, 0.12242100E+01, -.40754900E-01, 0.94284900E-01, 0.25596200E+00, -.44514700E+00, -.13766200E+01, -.12461900E+00, -.18445700E+00, -.53343200E-01, -.25419800E+00, -.34080600E+00, -.26856500E+00, -.23538200E-02, 0.26742700E+00, 0.23009700E+00, 0.10335300E+00, -.17747600E+00, 0.64705500E+00, -.82645300E-01, 0.48056600E-01, -.18937400E+00, -.20097600E+00, -.14451600E+00, -.26541400E+00, 0.15171500E+00, -.82510500E-01, -.61849200E-02, -.14704800E+00, -.49180400E+00, -.55747500E-01, -.37585900E+00, 0.70023900E-01, -.86241700E-01, 0.36272600E+00, 0.72024600E-01, -.42842200E-01, 0.15812700E+00, 0.53998400E-01, 0.68718300E-01, -.14853100E+00, 0.10862300E+00, -.13310000E+00, 0.62620000E+00, 0.21756200E-01, 0.61908700E+00, -.10570200E+00, 0.40971600E+00, 0.99624100E-01, -.16911100E-01, 0.18373300E+00, -.32053500E+00, 0.39863900E+00, -.25545200E+00, -.56659200E+00, 0.30433500E+00, 0.17691200E-01, -.28488900E+00, -.26139400E-01, 0.15588800E+00, -.36123200E+00, 0.10065200E+00, 0.94623200E-01, -.12203400E+00, -.84695800E-01, 0.19822800E-01, 0.35291500E+00, -.16632300E+00, -.98024800E-01, -.22076000E+00, 0.25113000E+00, -.77666800E-01, -.14906600E+00, -.62971000E-01, -.61787600E-01, 0.40426100E-01, 0.57095700E-01, 0.24308600E-01, 0.96638100E-01, -.13802200E+00, 0.13014500E-01, -.13914600E+00, -.22048100E+00, 0.73805300E-01, -.23603700E-01, -.36847000E-01, -.46274700E+00, 0.15317200E+00, 0.35568500E-01, -.44304800E-01, -.10043800E+01, 0.84238200E+01, -.10207100E+02, -.32706500E+01, -.29055200E+01, 0.14462100E+00, 0.32168100E+01, 0.75403700E+00, -.31272800E+01, 0.12738400E+01, 0.63889800E+00, 0.17997900E+00, -.27101600E+00, -.68198500E-01, -.99531000E-01, -.14181000E+01, -.25749900E+00, 0.16583600E-01, 0.23822100E-01, -.44615900E-01, -.93677800E-01, 0.26461000E-01, 0.84954900E-01, 0.23161200E-01, -.11837000E+00, -.17997700E-01, -.53328000E-01, 0.95262700E-01, -.39621300E-02, 0.22748900E+00, -.81928000E-01, -.77723700E-01, 0.15874600E-02, 0.73488900E-01, -.76479800E-01, 0.35418100E+00, -.19398300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.40795500E+01, 0.18783200E+00, 0.50474800E+01, 0.13080900E+02, 0.44313300E-01, -.37456700E+01, -.59151500E+00, -.28477900E+01, -.30742500E+01, 0.58374200E+00, -.16745500E+01, 0.26551000E+01, -.60887200E+00, 0.18533200E+01, -.17046400E+01, -.12432100E+01, 0.34241800E+01, -.12913300E+01, -.85934000E+00, -.62198800E+00, 0.12936400E+01, -.50573700E+00, -.85779200E-01, 0.40923600E+00, 0.16257700E+00, 0.15019300E+01, -.12853700E+00, 0.59708500E-02, 0.10685600E+00, -.10930800E+01, -.96628800E+00, -.18178700E+01, -.30352200E+01, 0.41679800E+00, -.12590900E+01, 0.97405100E-01, -.41509800E+00, 0.50754700E-01, -.90615700E-01, 0.91782000E-01, -.91553000E+00, -.76844900E-02, -.46627500E+00, 0.54690700E-01, -.23741900E+01, -.44854000E+00, 0.13477300E+00, 0.10967100E+00, 0.17405600E+00, 0.86229600E+00, 0.11158100E+01, 0.41071600E+00, -.16640300E+00, -.58750600E+00, -.28620800E+00, -.11769600E+01, -.35393800E+00, -.53087500E+00, 0.50305500E+00, -.43193400E-01, 0.38196000E+00, -.45117200E+00, -.16666500E+00, -.43768200E+00, -.53545200E+00, -.35278500E+00, 0.48249700E+00, -.10220700E+01, -.36621500E+00, 0.63325400E+00, -.11845100E+01, 0.58618700E-01, 0.37596300E-01, -.24369000E+00, 0.20757700E+00, -.17473400E+00, 0.16217200E+00, 0.35917800E+00, 0.12498100E+00, -.69370600E+00, 0.43624700E+00, 0.56198600E+00, -.20884800E-01, -.44362600E-02, 0.16950700E+00, 0.32523700E+00, 0.35805200E+00, -.65855700E+00, -.73994800E+01, -.96701900E+00, -.21341300E+01, 0.22259000E-01, 0.45733700E+00, -.82321700E+00, -.28704100E+00, -.42108400E+00, -.55103300E+00, -.62047100E+00, 0.10001500E+01, 0.35399800E+01, -.77349400E-01, 0.11431700E+00, -.24999400E+01, 0.54868600E+00, -.13326600E+01, -.53079300E+00, 0.22056400E+00, -.56823800E+00, -.19350100E+01, -.14104500E-01, 0.31284800E+00, -.12018700E+01, 0.20746500E+01, -.64291600E+00, -.37112500E+00, 0.13122600E+01, -.10132000E+00, -.15646600E+01, 0.22362900E+01, -.15361900E+01, 0.98824700E+00, -.18291300E+01, -.53502000E+00, -.49220600E+00, -.85875700E-01, -.15311900E+00, -.11365200E+01, 0.13661900E+01, 0.11699500E+01, -.86944700E+00, -.38177600E+00, -.14511800E+01, -.63632100E+00, 0.18390300E+01, 0.44491900E+00, -.42420600E+00, -.12148100E+03, 0.28991200E+02, 0.74764500E+02, 0.59380500E+02, -.32862800E+02, -.71357400E+02, -.56806300E+02, 0.60046200E+02, -.48780200E+01, -.29772100E+01, -.21355700E+02, -.15193100E+02, 0.21584800E+02, 0.54889700E+01, 0.58163700E+01, -.17607500E+02, -.92327600E+00, 0.18742400E+01, -.21821200E+01, -.91827000E+00, -.14011100E+01, -.25450100E+01, -.19335000E+01, -.16455900E+01, 0.80965700E+00, 0.95096300E+00, -.24238000E+01, -.41594300E+00, -.41459400E+01, 0.97406900E+00, 0.70000400E+00, -.13739100E+01, -.25380200E+01, -.12951100E+01, -.69268500E+01, -.16039700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13899900E+01, 0.34805400E-01, -.27261400E+01, -.45344800E+01, 0.11469800E+01, 0.14814100E+01, 0.21399300E+00, -.30537700E+00, -.48010300E+00, -.99662500E-01, -.24531600E+00, 0.17095100E+00, 0.17245600E+01, -.25903100E+01, 0.44610300E+00, -.13150200E+01, 0.29053200E+01, -.11259700E+01, -.24347900E-01, -.20051800E+01, -.48219600E+00, 0.47963100E+00, -.13063000E+00, 0.86495400E+00, 0.34986400E+00, 0.12272500E+01, 0.15116700E+01, 0.97836200E-01, 0.10185600E+00, -.76333400E+00, 0.96439800E+00, 0.54180800E+00, -.10354500E+01, 0.73745800E+00, -.12825500E+01, 0.48332200E+00, 0.18080400E+01, -.27425800E+00, 0.85716100E-01, -.29322300E-01, 0.34205400E+01, -.77850000E+00, 0.25008400E+00, 0.33252400E+00, 0.36272900E+01, -.82155400E-01, -.96008900E+00, -.12004300E+00, 0.87750200E-01, 0.10438900E+00, -.60541200E+00, 0.14925500E+01, -.49913700E-01, 0.36060700E+00, 0.96565200E-01, 0.55751600E+00, 0.99267600E-01, 0.27666400E+00, -.24130100E+00, -.52373100E-01, 0.12135500E-01, 0.63941400E+00, -.33305000E+00, -.68928900E+00, -.41783300E+00, -.61863000E-01, 0.10908200E-01, -.23711700E+00, 0.34531700E+00, 0.76779900E+00, 0.12755300E+00, 0.70619500E-01, 0.11636700E+00, 0.19201900E+00, 0.63432600E+00, 0.81289900E+00, -.35461600E+00, -.17882700E+00, 0.51321200E-01, 0.10012500E+01, -.80304100E+00, -.33458000E+00, 0.46267400E+00, -.66360800E-01, -.12514800E+00, -.68435500E-01, -.73467500E-03, -.23192200E-01, 0.43157500E+00, -.30355700E+00, -.13298300E+01, 0.40219700E+00, 0.32936100E+00, 0.59340900E-01, -.11417900E+00, 0.73811000E+00, 0.32262600E+00, -.59839200E+00, 0.18504300E+01, 0.50974500E+00, 0.60560500E+00, 0.42275600E+00, -.22437600E+00, 0.55382200E-01, 0.50671800E+00, 0.57680900E+00, 0.16667800E+01, 0.30309200E+00, -.15118500E+01, -.21813500E+00, -.64824300E+00, 0.52893500E+00, -.73904600E+00, 0.73934600E+00, -.14229600E+00, -.54716900E+00, -.12386800E-01, -.31797300E+00, -.59756200E+00, -.10151300E+01, 0.16756100E+00, -.83684300E+00, 0.42772000E-01, 0.76590900E+00, -.27105500E+00, -.60305500E-01, -.16561200E+00, -.15126100E+00, 0.49496600E+00, -.14160300E-01, -.41944700E-01, 0.54948000E+00, 0.23590600E+00, -.14971200E+01, -.15417700E+00, 0.68261100E+00, -.15456000E+00, 0.22018200E+02, -.89574000E+01, -.22398700E+01, 0.33438600E+01, 0.37076600E+01, 0.95564200E+01, -.15400200E+01, 0.36762000E+01, 0.17564500E+00, 0.39608400E+00, -.97236600E+00, -.22287900E+01, 0.36570700E+01, 0.58181300E+01, 0.30614900E+00, -.37955200E+00, 0.21412300E+00, -.11038500E+00, 0.18785100E+00, 0.11353700E-01, -.42316700E+00, -.31238200E+00, 0.78091900E-01, 0.22753000E+00, 0.54323300E+00, -.46356100E+00, 0.96511500E-01, 0.79676400E+00, -.19276500E+00, 0.19810500E+00, 0.18325800E+00, -.54220300E-02, -.17732700E+00, 0.40112500E+00, -.28394500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20315400E+01, -.13732300E+00, 0.23742600E+01, 0.39878200E+01, -.26458600E+00, -.19243800E+00, 0.60120900E+00, -.26064200E+00, 0.43421600E-01, -.94869500E-01, -.55399900E+00, -.88441900E+00, 0.27564800E+00, -.43557600E+00, -.27771800E+00, 0.48485500E+00, 0.19007300E+01, -.43230500E+00, -.19381500E+01, -.48181400E+00, -.15181500E+00, -.72392100E+00, -.92008800E+00, -.26607000E+00, 0.27024500E+00, 0.27075100E+01, 0.13568700E+01, -.92453000E-01, -.24346000E+00, 0.16032900E+00, -.28512500E+01, -.87346400E+00, -.29127900E+00, 0.36217500E+00, 0.55988800E+00, 0.12359300E+00, -.14921400E+01, -.35368600E-02, 0.18999500E+00, -.69845100E-01, 0.53344200E+00, 0.22301500E-02, 0.51097900E-01, 0.13829000E+00, 0.17576400E+01, -.23012400E+00, -.25033100E+01, 0.81326000E-01, -.66536600E-01, 0.11294000E+00, 0.48771100E+00, 0.63787300E-01, -.26261300E+00, -.24370600E+00, -.11532600E+00, -.10442200E+01, -.52423700E+00, 0.40423400E+00, 0.13651500E+00, 0.19557100E+00, 0.30761800E+00, -.26754700E+00, -.75253300E+00, -.49339200E+00, -.23351500E+00, -.21342300E+00, 0.40995300E+00, -.91511500E+00, 0.80776600E-01, 0.20094600E+00, -.44633900E+00, 0.13508600E+00, 0.25277600E+00, 0.36485600E-01, 0.30827400E+00, 0.92503400E-01, 0.24767900E-02, 0.47347400E-01, -.79045800E-01, -.71070300E+00, -.21651100E+00, 0.34247500E+00, 0.23737600E+00, 0.64296000E-01, 0.12109900E+00, -.15384600E+00, -.58290700E-02, -.19011000E+00, 0.62117300E+00, 0.33517400E+00, 0.11405200E+00, 0.32788400E-01, 0.41428200E+00, 0.25853900E+00, 0.23846300E+00, 0.38750400E+00, -.39479500E+00, 0.81567400E+00, 0.20596200E+00, -.22837700E+00, -.13293500E+00, 0.43119000E-01, 0.57272800E+00, 0.40319600E-02, 0.10126300E+00, -.46841500E+00, -.15008200E+01, -.42614400E+00, -.11546400E+01, -.31057400E+00, 0.11446900E+00, -.82199900E-01, 0.42833300E+00, -.11606700E+00, -.48805700E+00, 0.62035800E+00, -.27914900E+00, 0.21881500E+00, 0.76369800E+00, 0.46314000E+00, 0.12787400E+00, 0.76797800E+00, -.84185600E-01, -.64915500E+00, 0.48728300E-01, 0.24973400E+00, 0.64586400E+00, 0.24385700E+00, 0.22267200E+00, 0.23918700E+00, 0.17531200E+00, 0.81048600E+00, 0.15211900E+00, -.91274400E+00, 0.85174200E+00, -.11876700E+00, -.45021700E-01, -.11668200E+01, -.15371600E+02, -.62701900E+01, 0.10643400E+02, 0.90550600E+01, 0.26618300E+02, -.41111700E+01, -.39052800E+01, 0.36422900E+01, 0.10899500E+01, -.31282100E+01, 0.32696300E+01, 0.35246300E+01, 0.67309700E+01, -.32386000E+01, -.59347300E+00, -.86660900E-01, -.54996600E+00, 0.70715800E+00, 0.65166900E+00, 0.59754000E+00, 0.21474600E+00, 0.68151200E+00, 0.28572500E+00, 0.10113700E+01, 0.43386300E+00, 0.88981900E-01, 0.13358000E+01, -.74746200E+00, -.39850100E+00, 0.24414800E+00, 0.35029100E+00, 0.44166700E-01, -.10440800E+00, -.72444200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.58118600E+01, -.39133400E+00, 0.57966000E+01, 0.11561600E+02, -.17635100E+01, -.67114100E+01, -.63023200E-01, -.25741600E+01, -.30926200E+01, 0.89977900E-01, -.16747200E+01, 0.15091000E+01, -.31575900E+00, 0.21375400E+01, -.15001900E+01, -.62225600E+00, 0.32370000E+01, -.35709100E+00, 0.23323600E+01, 0.42115400E+00, 0.15323700E+01, -.93900200E+00, 0.59253000E-01, 0.44983600E+00, 0.54823100E+00, 0.25195100E+01, -.69333000E+00, -.27569900E-01, -.28976600E+00, -.18541500E+01, 0.13098200E+00, -.13422500E+01, -.24268300E+01, 0.76362200E+00, 0.13391600E+00, 0.72690400E+00, -.11753200E+01, -.10823100E+00, -.44823500E-01, 0.56133100E+00, 0.89829000E+00, -.56852200E-01, 0.45883900E-01, -.15352100E+00, -.34780500E+00, -.72204100E+00, 0.49953300E+01, 0.22996000E+00, 0.11711900E+00, 0.77864600E+00, 0.11422900E+01, 0.53255100E+00, -.45113700E+00, -.28427600E+00, -.30401900E+00, -.21959600E+01, -.10770700E+01, 0.50714400E+00, 0.38095000E+00, 0.20992600E+00, 0.72951300E+00, -.21865800E+00, -.91168700E+00, -.58925400E+00, -.74675300E+00, -.83077700E+00, 0.11895800E+01, -.22537200E+01, -.46804700E+00, 0.99675300E+00, -.17843500E+01, 0.24558100E+00, 0.45618700E+00, -.16317800E+00, 0.10303200E+00, -.48195000E-01, 0.35498900E+00, 0.41681900E+00, 0.12657600E+00, -.57400700E+00, -.15430000E+01, 0.25103500E+00, 0.55347300E+00, -.70337200E-01, -.41657900E+00, -.88132500E+00, -.21256800E-01, -.79116400E+00, 0.31265500E+01, 0.24400700E+00, -.12091600E+01, 0.38298100E+00, 0.48480800E-01, 0.25249800E-01, -.14961600E+00, 0.33747000E-01, 0.17177000E+00, -.12099000E+01, 0.20712700E+01, 0.18430900E+01, -.13549000E+00, 0.48395200E+00, 0.24730800E+00, -.81793300E-01, -.97485700E+00, 0.14065400E+01, -.12837100E+01, 0.28875100E-01, 0.77297800E+00, 0.42147100E+00, 0.34276200E+00, -.10316800E+01, 0.80883300E+00, 0.46589000E+00, -.12111000E+01, -.76986500E+00, 0.24302900E+00, -.23163700E+00, -.64848600E+00, -.55469000E+00, 0.39718000E+00, -.15872600E+01, -.10867400E+00, 0.80238700E+00, -.40416000E+00, -.20460500E-01, 0.22184200E-02, 0.43775500E+00, 0.22854000E+01, -.57611300E+00, 0.19964500E+00, 0.30168000E+01, 0.97565700E+00, -.11462400E+01, -.20392800E+01, 0.33878000E+00, -.12751000E+01, -.42246600E+00, 0.11418100E+01, 0.18180400E+02, -.25097500E+02, -.24600600E+02, -.57388000E+02, 0.19188500E+02, 0.39400600E+02, -.19322600E+02, -.15172600E+02, -.10255000E+02, -.34522600E+01, 0.12841300E+02, -.93348400E+01, -.12317300E+02, -.14219100E+01, 0.18864200E+01, -.24272600E+01, -.12105200E+01, -.38769500E+00, -.42218300E+01, -.35131600E+01, -.20092600E+01, 0.12741100E+01, 0.10708300E+01, -.38705800E+01, -.30858400E-01, 0.58805300E+00, 0.59253500E+00, 0.73789400E+00, -.71007300E-01, -.22684500E+01, -.14536000E+01, 0.44443800E-01, -.13047600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.91294600E+01, -.32052100E+00, -.11191400E+02, -.32661700E+02, -.28738700E+00, 0.47373700E+01, 0.34375800E+00, 0.56294500E+01, 0.58445200E+01, -.82282100E+00, 0.61423200E+01, -.31404900E+01, 0.15899400E+01, -.39259600E+01, 0.47317600E+01, -.16140200E-01, -.60487100E+01, 0.10521000E+01, 0.40325100E+01, 0.37124500E+00, -.31229300E+01, 0.40821200E+01, 0.18924500E+01, 0.69390200E+00, -.15661100E+01, -.99759300E+01, -.55502700E+01, 0.18762600E+00, 0.91313000E+00, 0.12710400E+01, 0.12634200E+02, 0.54458900E+01, 0.40441600E+01, -.40592400E-01, 0.19707000E+01, 0.18017700E+01, 0.38965000E+01, 0.15092300E-01, -.16382200E+00, 0.14859500E+00, 0.24533800E+01, -.88000100E+00, 0.21251400E+01, -.17229600E+01, 0.16948100E+01, -.46646600E+01, -.23701700E+01, -.10942200E+01, -.10249000E+01, -.19350400E+01, 0.21591800E+01, 0.10892000E+02, -.49209900E+00, 0.25525400E+01, 0.61488100E+00, 0.22508000E+01, 0.30111300E+01, 0.22691000E+01, -.17427100E+01, 0.46455800E+00, 0.96498800E+00, 0.13932200E+01, -.24900200E+01, 0.55121100E+01, -.15283300E+01, 0.12343000E+01, -.13798100E+01, -.42292100E+01, 0.13073700E+01, 0.90709100E+00, -.31834500E+01, -.33455500E+00, -.22947700E+01, 0.42322100E+00, 0.26413200E+00, -.99523600E+00, 0.88913800E+00, -.24618900E+00, 0.11532500E+01, -.27535300E+01, -.87900300E+00, 0.10128100E+01, 0.13387300E+01, -.50601600E+00, -.11898300E+01, 0.19647300E+01, -.61924000E+00, -.13692200E+01, 0.32536600E+01, -.58551100E+00, -.11735800E+01, 0.52972000E+00, 0.11823300E+01, 0.15836600E+00, 0.28277600E-01, 0.24533600E+01, -.11679000E+01, -.20243300E-01, 0.46864600E+01, -.90778100E+00, -.19498000E+01, -.12765400E+01, 0.35543200E+01, -.17836700E+01, 0.15131000E+01, -.12817500E+01, 0.13520300E+02, 0.10339300E+01, 0.52568700E+01, 0.52386500E+00, -.11858900E+01, 0.85555800E+00, 0.68489600E+00, -.17079300E+00, -.21613700E+01, -.21044800E+01, -.10681000E+01, -.23845900E+01, 0.34231300E+01, -.11100000E+01, 0.15227700E+01, 0.15854200E+01, -.13320300E+00, -.91131600E+00, 0.15691600E+01, -.16243600E+01, -.61643800E+00, -.33172200E+01, -.12100100E+01, -.57157000E+00, -.16263200E+00, 0.15882900E+01, -.51576500E-01, -.19239400E+01, -.37210100E+01, 0.47598200E+00, -.15267300E+01, 0.18322900E+01, 0.22062600E+00, 0.74118700E+00, 0.15428800E+02, -.21521800E+01, -.28942900E+02, -.18646000E+01, 0.20208500E+02, -.10613900E+02, 0.26588500E+00, -.10742100E+02, 0.48312400E+01, 0.43765000E-01, -.19921200E+02, -.14324300E+02, 0.75875100E-01, 0.42441100E+01, -.64987400E+01, -.45124000E+00, -.33326400E+01, -.81621400E+00, -.25944700E+00, -.20378300E+01, 0.15173300E+01, 0.20088400E+01, -.25879700E+00, -.45900300E-01, -.20480100E+01, 0.31886800E+01, 0.22832700E+01, -.12790100E+01, -.16814400E+01, -.13963700E+01, -.14681500E+01, -.63504700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26770800E+01, -.11379200E+00, -.53283600E+01, -.99104200E+01, -.10064800E+00, 0.22800500E-01, -.63720800E+00, 0.12877600E+01, 0.90017400E+00, -.57465700E-01, -.16431400E+01, 0.36804300E+00, 0.27246900E+01, -.41305700E+01, 0.59216500E+00, -.13456400E+01, -.45338700E+00, 0.51826400E+00, 0.38004800E+01, -.27967600E+01, -.86249100E+00, 0.22900300E-01, 0.26874900E+01, 0.19042600E+01, 0.77545300E+00, 0.96935700E+00, 0.12474100E+01, 0.63109500E-01, -.51924200E+00, -.15452100E+01, 0.62554500E+00, 0.35509100E+00, -.15648500E+00, 0.27060400E+00, -.11588400E+01, 0.39691200E-01, 0.11357100E+01, 0.53067100E-01, 0.84223900E-02, -.32631400E+00, -.23565100E+00, 0.13360000E-01, 0.57004900E+00, 0.32634900E+00, 0.67288800E+01, -.32185400E+01, 0.41746300E+00, -.31396100E+00, -.58473000E+00, -.72001400E+00, 0.61527100E-01, 0.38881700E+01, -.91785700E+00, 0.23074200E+01, 0.23503900E+00, 0.10822900E+01, 0.90038100E+00, -.46865200E+00, -.33889200E+00, -.27744300E+00, -.85309100E-02, 0.47757800E+00, 0.49837100E+00, 0.11625300E+01, 0.30321100E+00, 0.11525700E+00, 0.21489000E+00, -.50340900E+00, -.10119800E+01, -.69779200E-01, -.40355300E+00, 0.43714000E+00, 0.15562100E+00, -.32560400E+00, -.41319700E+00, -.17719100E+00, -.12601300E+00, 0.72200900E+00, -.26168500E+00, 0.22554200E+01, -.18476500E+00, 0.38436100E-01, -.20202600E-01, -.16518800E+00, 0.29905800E+00, -.15178600E+01, 0.41378300E+00, 0.31048600E+00, 0.11616900E+01, -.25884100E+00, 0.22083500E+01, -.93749200E-01, 0.12864000E+01, -.27840400E+00, 0.38924800E+00, -.33910100E-01, -.13727800E+01, -.15673600E+01, 0.15105300E+00, 0.14745300E+00, -.11840900E+01, 0.42855600E+00, -.99855500E+00, -.78164300E+00, 0.97166300E-01, -.19612000E+01, -.16094800E+01, 0.83318600E+00, 0.32024700E-01, 0.49588800E+00, -.66207700E+00, -.26840500E+00, -.47871500E+00, -.65303500E+00, 0.11094100E+01, -.60643600E+00, 0.96291900E+00, 0.82382900E+00, -.20800300E+00, -.39186300E+00, -.51815200E+00, -.90426900E+00, -.17708200E-01, -.12697300E+00, 0.81678900E+00, -.97401700E-01, -.74503300E+00, -.65524800E+00, -.72236700E+00, -.61713400E+00, -.21812600E+00, -.18671100E+00, 0.56447400E-01, -.18644200E+00, -.50585100E+00, 0.44469600E+00, -.34865600E+00, 0.28208800E+00, 0.18210400E-01, 0.16913500E+00, -.24289400E+00, -.68390700E+01, -.19897900E+02, -.34355900E+01, 0.35796900E+01, -.56649600E+01, -.27157500E+01, -.42967600E+01, 0.60438100E+01, 0.60938900E+00, -.36382900E+01, -.49157000E+01, -.47049300E-01, 0.21742800E+01, -.20925200E+01, -.22371200E+00, -.13634800E+01, -.81151500E+00, -.12698000E+00, -.10459700E+01, 0.65779700E+00, 0.42020800E+00, -.52141800E+00, -.88400800E-01, -.21175900E+01, 0.17450700E+01, 0.16033900E+01, -.87883300E+00, -.85144100E+00, -.58460700E+00, 0.91386900E+00, -.25735300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.66439300E+01, -.20014000E+00, -.12582700E+02, -.29363400E+02, 0.44415100E+01, 0.65212900E+01, 0.93366300E+00, 0.28865000E+01, 0.30389800E+01, -.96426900E+00, -.36291100E+01, -.38591700E+01, 0.64373900E+01, -.97912400E+01, 0.14304600E+01, -.17871500E+01, 0.54444100E+01, -.10210000E+01, -.39571400E+01, -.69017500E+01, 0.63342700E+01, -.48209200E+01, 0.71476800E+01, 0.22416800E+01, 0.32068700E+01, 0.47480400E+01, 0.27749000E+01, -.30137400E+00, -.82340400E+00, -.48030900E+01, -.12151700E+02, -.16493300E+01, -.30845000E+01, 0.40627300E+01, 0.17324900E+00, 0.15803000E+01, 0.46384300E+00, 0.79655900E+00, 0.62207600E+00, -.19375800E+01, 0.14073200E+01, -.10095300E+01, 0.28866000E+00, 0.94034600E+00, 0.22127900E+02, -.33034100E+01, -.19894600E+01, -.25580700E+00, 0.44079000E+00, 0.16347600E+01, -.31692700E+01, 0.44378600E+01, -.34565300E+01, -.16087500E+01, -.66871400E+00, -.11071200E+01, -.38310300E+00, -.60610400E+00, -.30871400E+00, -.45913200E-02, -.21349500E+00, 0.12850700E-01, -.20256000E+01, -.11194500E+01, -.20001800E+01, 0.53547500E+00, -.79485800E+00, -.19887800E+01, 0.17251900E+01, 0.78618200E+00, -.43323200E+00, -.10240600E+00, 0.64611600E+00, -.11862000E+00, 0.16611800E+01, 0.10251800E+01, -.67317800E+00, -.51537600E+00, 0.94202300E+00, -.11523500E+01, 0.18708000E+01, 0.47209500E+00, 0.83459100E+00, 0.62802600E-01, 0.16872400E+01, 0.79550500E-01, 0.46078900E+00, -.50322600E+00, -.85706300E+00, 0.57489500E+00, 0.44131000E+01, -.21886700E+01, -.51407700E+00, 0.11215800E+00, 0.55899700E+00, -.19790100E+01, -.24223800E+01, 0.35876200E+00, -.28678200E+01, 0.22294800E+01, -.25133200E+00, -.75176100E+00, -.38361800E+01, 0.13655400E+01, 0.49637700E+00, -.69888600E+01, 0.34938100E+01, -.11483900E+01, -.81969300E+01, -.13176100E+01, 0.13235700E+01, 0.17901400E+01, 0.46930200E+00, -.95065200E+00, -.30436800E+01, 0.24779300E+01, 0.13793500E+01, -.72369400E+00, 0.23727500E+01, 0.14505400E+00, 0.23658400E+00, 0.25175900E+01, 0.55010100E+00, -.15851700E+01, -.25425200E+00, -.11228100E-01, 0.63081500E+00, 0.16280900E+01, 0.12563100E+01, 0.55529600E+00, 0.30575200E+00, 0.28596500E+00, 0.39638600E-01, 0.20416500E+01, 0.31945400E+01, -.42002200E+00, 0.11775600E+01, -.18480000E+00, -.16125300E+01, -.58649500E+00, 0.59565100E+00, -.15443600E+01, 0.22452800E+02, 0.43075200E+01, -.12594200E+02, 0.72312900E+00, -.46018100E+01, -.26719300E+01, 0.70890600E+01, 0.58727000E+01, 0.16904000E+02, -.15973600E+01, -.36784400E+00, -.27051600E+01, 0.29072700E+01, 0.14360800E+01, 0.37270600E+01, 0.15369800E+01, 0.13268600E+01, 0.26487900E+01, -.18132600E+01, -.11984300E+01, 0.12963400E+01, -.14097800E+00, 0.64929000E+00, -.24515600E+01, -.21275700E+01, 0.49492900E+00, 0.17815500E+01, 0.14305400E+01, 0.82680100E+00, 0.29025700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.14113600E+01, 0.39128600E-01, 0.33694400E+01, 0.65029200E+01, -.89954200E+00, -.14644700E+01, -.19985300E+00, -.96785900E+00, -.55425600E+00, 0.15155700E+00, 0.13630200E+01, 0.34613500E+00, -.19281400E+01, 0.27081900E+01, -.24759300E+00, 0.93757300E+00, -.57158500E+00, 0.85142500E-01, -.53897700E+00, 0.22018500E+01, -.14929900E+01, 0.10663700E+01, -.30497300E+01, -.14489400E+01, -.77116600E+00, -.16593400E+00, -.77165000E+00, -.59193400E-02, 0.24076800E+00, 0.15803700E+01, 0.30041000E+01, 0.26062800E+00, 0.78790900E+00, -.78114800E+00, 0.42682900E+00, -.27307900E+00, -.43238300E+00, -.24076300E+00, -.31473600E-01, 0.57246800E+00, 0.11483700E+01, 0.17087400E+00, -.12679700E+00, -.37479600E+00, -.80273900E+01, 0.13412200E+01, 0.16270600E+01, 0.98965200E-01, -.10615000E+00, -.54853800E+00, 0.35095200E+00, -.15555200E+01, 0.99666800E+00, 0.17675800E+00, 0.25183000E-01, 0.64371000E+00, 0.53583500E+00, -.78709700E+00, -.14131300E+00, -.40656600E+00, -.53582800E+00, 0.20584300E+00, 0.62159100E+00, -.26897900E+00, 0.73482800E+00, -.11193400E+00, 0.70491600E-02, 0.11003400E+01, -.38385800E+00, -.51669300E+00, 0.49008300E+00, -.63188300E-01, 0.27337200E+00, 0.18110600E-01, -.58113800E+00, -.16884500E+00, 0.70845800E-01, -.13003900E+00, 0.18164700E-01, 0.19807600E+00, -.64725200E-01, -.20554700E+00, -.14077600E+00, 0.27925600E-01, -.13798200E+00, 0.14326500E+00, -.68499500E-01, 0.24627800E+00, -.10408700E+00, -.61929200E-01, -.57856500E+00, 0.84268600E-01, -.74805500E+00, -.79737200E-01, -.10348200E+00, -.24671400E+00, 0.36182300E+00, -.41500300E+00, -.44656800E+00, -.37322900E+00, -.30432500E+00, 0.76052100E-01, 0.18993300E+00, -.24919100E+00, -.46222300E+00, 0.11801300E+01, -.13970800E+01, -.21516300E-01, 0.18742300E+01, 0.26569500E+00, 0.17462000E+00, -.47978900E+00, 0.44221300E+00, -.25613800E+00, 0.63136700E+00, -.32432200E-01, -.15576900E-01, 0.27801100E+00, 0.25035600E-01, 0.91164300E-01, -.94451100E-01, -.45167600E+00, -.92206200E-01, -.10831200E+00, 0.34342100E+00, 0.12468600E-01, -.50337700E-01, -.51016600E+00, -.70555900E+00, -.10859400E+00, -.40759700E-01, -.63224100E-01, -.10786000E+00, 0.23377600E+00, -.32552200E+00, -.12728700E+00, -.47993300E-01, -.17524700E+00, 0.16187300E+00, 0.99186400E-01, 0.48776100E-01, -.42667900E-01, -.50504600E-01, -.19593100E+01, -.43685200E+01, 0.20489200E+01, 0.66511700E+00, 0.13736900E+01, 0.34975700E+00, -.13793100E+01, 0.10269700E+01, 0.19426300E+01, 0.12756200E+00, -.19443500E+00, 0.44828100E+00, 0.14401300E+00, 0.11918900E-01, 0.18212900E+00, 0.19631000E+00, 0.22075200E+00, -.14852400E+00, -.32989400E+00, 0.16977000E+00, 0.17338000E-02, -.31385000E+00, -.53643400E-02, 0.90319400E-03, -.44019800E-01, 0.12767000E+00, 0.10223500E+00, 0.46232200E+00, 0.12408400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10406300E+02, 0.38654700E+00, 0.11661900E+02, 0.36423900E+02, -.19322100E+01, -.45744100E+01, 0.13649400E+00, -.32171700E+01, -.44613300E+01, 0.98520000E+00, -.68847800E+01, 0.31631000E+01, -.24699700E+01, 0.45621600E+01, -.57492500E+01, 0.44793600E+01, 0.12017000E+01, 0.15236200E+01, 0.48895200E+01, 0.24509300E+01, -.86936500E+01, 0.20444900E+00, -.10594000E+01, 0.59349700E+00, 0.96481700E+00, 0.89138000E+01, 0.86002200E+01, 0.10392800E-01, -.27865100E+00, -.47058700E+00, -.10153300E+02, -.58530100E+01, -.71540400E+01, 0.49750700E+00, -.15927300E+01, -.15448100E+01, -.29096500E+01, -.21551200E+00, -.10474600E+01, 0.13872100E+01, -.85046300E+01, 0.15239200E+01, -.87294100E-01, -.65950100E+00, -.17515000E+01, -.34770800E+01, -.15754800E+02, -.85336900E-01, 0.27045700E+00, 0.21971700E+01, 0.33252300E+01, -.37713500E+00, 0.22804300E+01, -.23836300E+01, -.51067200E+00, -.28467500E+00, -.21743300E+01, 0.42959400E+00, 0.23902600E+01, -.11848700E+01, -.40108100E+00, -.17407400E+01, 0.22341000E+01, -.57141800E+01, 0.43131200E+01, -.12918300E+01, 0.22629200E+01, 0.21898600E+01, -.59515400E+00, -.10432200E+01, 0.19497200E+01, 0.16507100E+00, -.16327400E+01, -.63904000E+00, -.16770000E+01, -.10226700E+01, -.13827000E+01, 0.48612400E+00, -.23086500E+01, 0.23218200E+01, -.11279200E+01, 0.62192400E+00, -.90195900E+00, 0.28344100E-02, -.60445500E+00, 0.80356100E+00, -.23253600E+00, -.19625700E+00, -.36893500E+01, -.34670100E+00, -.17806000E+01, 0.71246600E+00, 0.79987000E+00, -.34483000E+00, 0.63666500E+00, 0.12652600E+01, 0.21295500E+01, 0.19336500E+01, 0.28240800E+01, 0.32334600E+01, 0.10858900E+01, 0.10285100E+00, 0.14534300E+01, 0.70361100E+00, -.16317100E+01, 0.26061200E+00, -.12855000E+02, -.20421200E+01, -.13201400E+02, -.12231000E+01, -.18187000E+01, -.79582700E+00, -.22979400E+01, 0.12045800E+01, 0.44555700E+01, 0.24730900E+01, -.77802800E+00, 0.24169300E+01, 0.86566000E+00, 0.82473700E+00, -.11651700E+01, -.36478100E+01, -.49665100E+00, 0.11342200E+01, 0.92792700E+00, 0.21356400E+01, 0.12889700E+01, 0.99168700E-02, -.15402900E+01, 0.72428700E+00, -.10596300E+00, 0.14575300E+01, 0.21162100E+00, -.43658800E+01, -.11680700E+01, 0.62611600E+00, 0.85346000E+00, -.42480100E+00, 0.15379300E+01, -.95107800E+00, -.35404700E+00, 0.32441000E+00, 0.25598700E+00, -.13917800E+00, 0.94711700E+02, -.39420900E+02, -.91523400E+01, -.20956800E+01, -.42635100E+02, 0.19644500E+02, -.11667000E+02, -.35885000E+01, -.17725400E+00, 0.27357000E+01, -.95089400E+00, -.29292300E+01, -.64761800E+00, -.22394000E+01, -.26432400E+01, -.34214600E+01, 0.83928000E-01, 0.17754700E+01, -.25640200E+01, 0.55124100E+00, 0.71479800E+01, 0.87184700E+00, 0.16775000E+01, 0.20636800E+01, -.94083000E+00, -.89780000E+00, 0.67336300E-01, 0.36052300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.55364600E+01, 0.59431100E+00, 0.10404900E+02, 0.25920800E+02, 0.46696300E+01, -.35642000E+01, -.15457300E+01, -.56580200E+01, -.64323100E+01, 0.16134700E+01, -.29544600E+01, 0.75835500E+01, -.24111200E+01, 0.55743400E+01, -.29289900E+01, -.35148300E+01, 0.32162700E+01, -.31302500E+01, -.93554900E+00, -.46286200E+00, 0.26423000E+01, 0.17776600E+01, -.17940800E+01, -.51694300E+00, -.13780700E+01, -.18093800E+01, -.61178700E+01, -.36736600E-01, 0.14075100E+01, -.12472400E+01, -.29419900E+01, -.21744300E+01, -.62879200E+01, 0.12289600E+01, -.22268500E+01, 0.29874200E+00, -.70145000E+00, 0.58564700E+00, 0.14398600E+00, -.46901900E+00, -.46283400E+01, -.55232900E+00, -.20675900E+01, 0.12010900E+01, -.10111500E+01, -.11081300E+01, -.69498100E+00, -.32313400E+00, 0.49672700E+00, 0.74609000E+00, 0.10090200E+01, 0.26164600E+01, 0.12500800E+00, 0.43317100E+00, -.22535200E+00, -.49379700E+00, -.16124200E+01, 0.96971200E+00, 0.77776100E+00, -.10387900E+01, -.93550900E+00, -.13896600E+01, 0.11060200E+01, -.13335600E+01, -.32255000E+01, -.15934300E+00, 0.27238200E+00, -.20700500E+01, 0.19517200E+00, 0.10556800E+01, -.14532300E+00, 0.47560700E-02, -.99559900E+00, -.13684200E+00, -.85880400E+00, 0.28655400E+00, 0.99455100E+00, -.33821800E+00, -.22204200E+00, 0.22832200E+00, -.16504100E+01, -.95715400E+00, -.86330600E+00, 0.47956500E+00, -.43366800E-01, 0.69089800E+00, 0.47983200E+00, 0.18451600E+01, -.57560000E+01, -.49320300E+00, 0.60297000E+00, -.18429600E+01, -.67385900E+00, -.22762500E+00, 0.38883900E+00, -.59207100E+00, -.92844200E+00, -.13551100E+01, 0.14816800E+01, 0.19791300E+01, -.32537300E+01, -.10494900E+01, -.16035500E+01, -.12650200E+01, -.61069200E+00, 0.15194300E+01, 0.71519200E+01, -.16421500E+00, 0.12845900E+01, -.26978600E-01, 0.85622900E+00, 0.42743600E+00, 0.79246800E+00, -.74362100E+00, 0.13509300E+01, 0.28167600E+01, -.22895300E-01, 0.50731800E+00, 0.39018700E+01, 0.18719700E+01, -.44192600E+00, 0.31751600E+01, -.85732600E-01, -.70772400E+00, 0.49966300E+00, -.65166600E+00, 0.54807200E+00, -.30262500E+01, -.20618100E+01, -.10681200E+00, 0.46171500E-01, -.50990100E-02, -.27108100E-02, 0.45412200E+01, 0.16053200E+01, -.11630700E+01, 0.76713200E+00, -.85070300E+00, -.41260800E+00, -.78615000E+00, 0.24128800E+00, 0.55654400E+00, 0.28483100E+00, 0.13715600E-01, -.38349400E+00, 0.26806100E+02, 0.67098900E+01, 0.13342500E+02, -.23103900E+02, -.41277800E+01, -.22742900E+01, 0.15415800E+02, -.33151200E+00, -.15132200E+01, 0.28638100E+01, 0.20557200E+00, 0.31115000E+01, -.42643100E+00, -.15667100E+01, 0.10194300E+01, -.54530100E+00, -.17745000E+01, -.90256700E+00, 0.93629600E-01, 0.50929400E+01, -.11528200E+01, -.84888500E+00, 0.20201700E+01, 0.10354900E+01, 0.94266000E+00, -.61194900E-01, 0.12432700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.51093500E+01, -.95724200E-01, 0.88156300E+01, 0.24720200E+02, 0.12840900E+01, -.25189600E+01, -.14494500E+01, -.41628100E+01, -.42432600E+01, 0.46865500E+00, 0.39591200E+00, 0.32679300E+01, -.23906600E+01, 0.10852300E+01, -.12577400E+01, -.31361100E+01, -.96267000E+00, 0.51226000E+00, 0.70482300E+00, -.66585800E+01, -.25753400E+01, 0.22699700E+01, -.86811100E+01, -.29939400E+00, -.34713300E+01, -.30397100E+01, -.17039700E+01, 0.16537900E+00, 0.59035600E-01, -.35167500E+01, -.78198400E+00, -.40809200E+00, -.31983600E+01, 0.79857200E+00, -.98527200E+00, 0.20917800E+00, 0.22948100E+01, 0.11956600E+00, 0.47825400E-01, -.37072600E+00, -.89929200E+00, -.34829200E+00, -.99582500E+00, 0.59196500E-01, -.42899200E+01, 0.34018100E+01, -.16539100E+01, 0.32020900E+00, 0.74231200E+00, 0.94278100E+00, 0.11045700E+01, -.34084000E+01, 0.96516100E+00, -.77124000E+00, -.71919500E-01, -.11911800E+01, -.14975700E+01, 0.60433300E+00, 0.42041900E+00, 0.39864200E+00, -.79972600E+00, -.83009700E+00, 0.11556800E+01, 0.57037300E+00, 0.49015700E+00, 0.31043200E+00, 0.23392000E-01, 0.47851500E+00, -.95340900E-01, -.90097600E+00, 0.11555600E+01, 0.29824300E+00, -.61210600E+00, 0.16052500E+00, -.44373900E+00, -.58202000E+00, 0.70346400E+00, 0.24033200E+00, -.15066700E+00, 0.44951100E+00, 0.18229700E+01, -.16069900E+00, -.15245000E+01, 0.29564200E+00, 0.28692900E+00, 0.21319200E+00, 0.41715300E+00, 0.75731600E+00, -.28344500E+01, 0.23557100E+00, -.17160000E+01, 0.24083000E+00, 0.42452400E-01, 0.41697100E+00, -.12067800E+00, 0.10298400E+01, -.84731400E+00, -.40222300E+00, 0.19995300E+01, -.17894700E+01, 0.91959400E+00, 0.46167000E+00, 0.71980300E+00, -.12373900E+01, -.55911600E+00, 0.26551800E+01, -.11881600E+01, 0.37349600E-01, 0.27455300E+01, -.19423800E+00, 0.64832700E+00, -.73827100E+00, 0.98608500E+00, 0.21316200E+00, -.63649800E+00, 0.84200600E+00, -.79193100E+00, 0.60397200E+00, -.39878300E+00, -.24532400E+00, 0.62222900E+00, -.27970900E+01, -.32271900E+00, -.43972100E+00, 0.11881700E+01, 0.90062800E-01, 0.13953100E+01, -.29705700E+00, 0.55866900E+00, -.44979500E+00, -.15697800E+00, 0.47702000E-01, -.41014900E+00, 0.25677300E+01, 0.10147500E+00, -.73205100E+00, 0.81220000E+00, -.24614000E+00, -.70013100E+00, -.28048400E+00, 0.31390400E+00, -.87208700E+00, 0.17263100E-01, -.22345300E-02, -.16285000E-01, -.11550400E+00, -.18566200E+02, -.11960800E+00, 0.11022200E+01, 0.43292800E+01, 0.10234100E+02, -.10026100E+01, 0.23538800E+00, -.63748000E+00, 0.30082200E+01, 0.25476300E-01, 0.18696500E+01, 0.11814700E+01, 0.19928700E+00, 0.96417900E+00, -.30923700E+00, -.76845100E+00, 0.10672800E+01, -.22942200E+00, 0.20973300E+01, -.12388300E+01, -.11138900E+01, 0.56377700E+00, 0.69587000E+00, 0.88790900E+00, -.21748900E+00, 0.39858000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.32546300E+01, 0.10865400E+00, -.39494900E+01, -.79675200E+01, -.21007000E+00, 0.38621400E+00, -.52252000E+00, 0.11034500E+01, 0.13608600E+01, 0.45741800E-01, 0.76336900E+00, -.63115700E+00, 0.11822200E+01, -.22386600E+01, 0.99378300E+00, -.10847900E+01, -.23926500E+01, -.11006200E+00, 0.13931700E+01, -.41304300E+00, -.25928300E+01, 0.11297100E+01, -.93347000E-01, 0.18634600E+00, -.16998200E+00, -.97215300E-01, -.50213400E-02, -.13008700E-01, -.19753500E+00, -.15230400E+01, 0.19765000E+01, 0.16310000E+01, 0.29894700E+00, 0.24617800E+00, 0.58878700E+00, 0.15914000E+00, 0.25497200E+01, -.14736300E+00, 0.83995600E-01, -.16169400E+00, 0.24188100E+01, -.14451500E+00, 0.97734700E-01, 0.76174300E+00, 0.25117100E+01, 0.15230400E+00, 0.86962800E+01, -.70812700E-01, 0.12297900E+00, -.11815600E+00, -.27871000E+00, 0.45801200E+00, -.43869900E+00, 0.56317600E+00, 0.19847600E+00, -.25238800E+00, 0.59192100E+00, 0.61895200E-01, -.32223500E+00, -.17105200E+00, -.11131200E+01, 0.24697000E+00, 0.43399900E+00, 0.11235600E+01, 0.26643100E+00, 0.34456000E+00, -.40553400E+00, 0.55292400E+00, -.11013500E+00, -.12569100E+01, 0.12918400E+01, -.40286100E-01, 0.17378100E+00, -.27056400E-01, -.93933800E+00, -.60957400E+00, -.19605500E+00, -.62609800E-01, 0.15352300E+00, 0.11988400E+01, 0.56931400E+00, 0.16543500E-01, -.96113600E+00, 0.14522400E+00, 0.24342200E+00, -.66038600E+00, 0.44635800E+00, 0.14778900E+00, -.30233300E+01, 0.10885400E+00, 0.59155000E-01, -.18049300E-01, -.14940800E+01, -.22363800E+00, 0.18894100E-01, -.10855700E+01, -.26888500E+00, -.17395500E+01, -.12504400E+01, 0.40511400E+00, 0.15136000E+00, 0.33051500E+00, -.21153000E+01, -.20621500E+00, -.97712800E+00, -.17111800E+00, -.34782600E-01, 0.28996200E+00, 0.53353500E-01, 0.18833400E+00, 0.50771600E+00, -.61720600E+00, 0.32599400E+00, 0.32961600E-01, -.24042000E+00, 0.81816100E-01, 0.35145600E+00, 0.34896900E-02, -.10867400E+01, -.89362600E+00, 0.30680500E+00, -.21682300E+01, -.84167800E-01, 0.24093400E+00, -.88269800E+00, -.37619100E+00, -.26137300E+00, -.10466300E+01, 0.25125700E+00, -.83443000E-01, -.15016300E-01, -.73234000E+00, -.18592500E+00, -.96820800E-01, -.22288700E+00, 0.54161500E+00, 0.33007000E+00, 0.12032900E+01, 0.44241700E+00, 0.88024600E-01, 0.99621400E-01, 0.71509200E+00, -.22795600E+00, -.98711600E+00, -.12939700E+00, -.20635000E+00, -.52672900E+00, 0.15496100E+02, -.18557700E+02, -.24366400E+01, 0.98504700E+01, 0.16402900E+02, 0.11778100E+01, -.37164800E+01, 0.61383300E+01, 0.73533900E+00, 0.35066700E+01, 0.23774200E+01, 0.12528200E+01, 0.29096800E+01, -.18422700E+01, -.31882700E+01, 0.20883200E+01, -.46519100E-01, 0.27528700E+01, -.17637300E+01, -.16017300E+01, 0.15299800E+01, 0.22857400E+01, 0.21055700E+01, 0.12491900E+01, 0.82670000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18253100E+01, -.43324600E-01, 0.20454800E+01, 0.31872100E+01, -.26686800E-01, -.15291400E+00, 0.17435200E+00, -.61627700E+00, -.37421400E+00, 0.68786700E-01, -.50049200E+00, 0.78994300E-01, -.28750300E-02, -.49136100E+00, -.42913200E+00, -.15566000E+00, 0.21189900E+01, -.66855800E+00, -.20491200E+01, -.94302500E+00, 0.51179400E+00, -.61974000E+00, -.36283400E+00, -.45779800E-01, 0.23155900E+00, 0.19653200E+01, 0.92196700E+00, -.54581500E-01, -.93066100E-01, 0.21576000E+00, -.16210600E+01, -.10220300E+01, -.66558600E+00, 0.13769000E+00, -.47847300E+00, -.10360900E+00, -.77987100E+00, 0.17602100E+00, 0.93858900E-01, -.17830300E+00, -.11491500E+01, -.93734100E-02, -.10735800E+00, -.15356200E+00, -.21745200E+01, -.93899800E+00, -.15098800E+01, -.34885500E-02, -.16002600E+00, -.81669800E-01, 0.66813800E+00, 0.14088200E+01, -.18404900E+00, 0.21706900E+00, -.87106800E-01, -.42135400E+00, -.31399900E+00, -.25419600E+00, 0.43964200E+00, 0.11941400E+00, 0.17722200E+00, -.55515300E+00, -.24950200E+00, 0.13548600E+00, -.73496200E+00, -.23930300E+00, 0.20551700E+00, -.93566000E+00, -.49854900E-01, 0.42902700E+00, -.85986300E+00, 0.96267200E-02, -.11823100E+00, -.13756800E-01, 0.11616700E+00, -.17199500E+00, 0.24969200E+00, 0.17306700E+00, -.15357600E+00, -.89732700E+00, -.61787400E+00, 0.23258200E+00, 0.50124300E+00, 0.10416400E-01, -.92575200E-01, -.19547200E+00, 0.11378600E-01, -.38817600E+00, 0.22416800E+01, 0.12331300E+00, 0.45831100E+00, -.12648100E+00, 0.31726900E+00, 0.11384700E+00, 0.41725200E-01, 0.57287400E-01, -.12721300E-01, 0.88467400E+00, -.27806700E+00, -.59186700E+00, -.23101400E+00, -.19777000E-01, 0.55665700E+00, -.48073200E-01, 0.86249600E-01, -.38409100E+00, -.80972600E+00, 0.15117500E+00, -.47140900E+00, 0.12667900E+00, -.27801300E+00, -.16509100E-01, -.93342300E-01, 0.62138700E-01, 0.22447500E+00, -.86668400E+00, 0.21548100E+00, -.47060400E+00, -.20726300E+00, -.64235800E+00, 0.66271500E-01, -.72045100E+00, -.55670300E-01, 0.23287700E-01, -.40274300E-01, -.12219300E+00, -.31115600E-01, 0.18485500E-01, -.54049300E+00, 0.13048000E+00, 0.83789400E-01, 0.52351200E+00, -.22041800E+00, -.37449200E+00, -.67129900E+00, -.36108800E+00, -.23278600E+00, 0.10868300E+00, -.70020000E-01, 0.28481400E+00, 0.17856600E+00, -.24968700E+00, -.14455000E-01, 0.21011300E+00, -.29400800E-01, -.12041300E+00, 0.57851200E-01, -.42493200E-01, -.18728800E+01, 0.20326800E+01, 0.89801700E+01, 0.43339200E+00, 0.42510300E-01, -.62098900E+00, 0.75552300E+00, 0.30310500E-01, -.18466800E+00, -.13279000E+00, -.38135600E+00, 0.28789000E+00, -.24910100E+00, -.34300300E+00, -.32817200E+00, 0.65477400E-01, 0.11008100E+01, -.49680500E+00, -.29969000E+00, 0.31505100E+00, -.27004000E-01, -.82988100E-01, 0.22265400E+00, 0.16228700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.26176700E+01, 0.11462000E+00, -.33046500E+01, -.62111800E+01, 0.48510000E+00, 0.63232900E+00, -.14886600E+00, 0.32942000E+00, 0.13094000E+01, 0.35255200E+00, 0.74540600E+00, -.66692700E+00, 0.57413100E+00, -.86327000E+00, 0.38657500E+00, 0.13994400E+00, -.14723400E+01, -.12825800E+01, -.29112600E+01, 0.18234500E+01, -.30094500E+01, 0.92824400E+00, 0.34608200E+00, -.10357700E+01, 0.52301100E+00, 0.23946800E+01, -.19398700E+00, -.21151500E+00, -.22555600E+00, -.48130300E+00, -.34743200E+01, -.71341900E-01, 0.15842200E+01, -.29696400E+00, 0.13509900E+01, -.40420700E+00, -.15966800E+01, -.26798000E+00, 0.15153700E+00, -.54996400E-01, 0.93650200E+00, 0.10750300E+00, -.52624600E+00, 0.11290200E+01, 0.69911900E+01, 0.99213000E+00, -.14348500E+02, -.98118500E-01, -.43589700E-02, 0.50169200E-02, -.87827700E-01, 0.91646600E+00, -.27191200E+00, 0.42185400E+00, 0.19064300E+00, 0.92403800E+00, 0.13834600E+00, 0.10380600E+01, -.34897800E+00, 0.94341600E-01, 0.32395400E-01, -.15839400E+00, -.50746900E+00, 0.93132600E+00, -.78075300E-01, -.57650500E-01, -.20570700E+00, -.20286200E+00, -.75816800E+00, -.54333000E+00, 0.76370600E+00, 0.15767000E+00, -.75936400E-01, 0.23689700E+00, -.24671200E+00, -.62933500E+00, 0.24362800E+00, 0.29276000E-01, -.16936700E+00, 0.25665700E+00, -.25208300E+00, -.48259400E+00, -.18102200E+00, 0.21513700E-01, -.47206200E+00, -.39839200E+00, -.20374100E+00, 0.12007700E-01, 0.10304400E+01, -.31033400E+00, -.11005300E+01, 0.34299100E+00, 0.42103600E+00, 0.42512700E-01, 0.16264800E+00, 0.11600300E+01, 0.20033900E+00, 0.42466800E+00, 0.82670800E+00, -.45903200E-01, 0.60977100E+00, 0.22884100E+00, 0.48594000E-01, -.31512200E+00, 0.32370500E+00, 0.85232300E+00, -.26406100E-02, -.31973400E+00, -.17963600E+01, -.63625700E+00, -.13272200E+00, 0.41797600E+00, 0.45255100E-01, 0.56732600E-01, 0.17334500E-01, 0.26068800E+00, 0.98516300E-01, -.50701300E-01, -.19185300E+00, -.48647100E+00, 0.12482200E+00, -.57086500E+00, -.78569300E-01, 0.10697800E+00, -.21546400E-01, -.81895800E-02, 0.16630700E+00, 0.19853900E-03, 0.72313400E-01, -.92954000E-01, -.82324400E-01, -.33574100E+00, 0.30023800E-01, 0.43263400E-01, -.17742500E+00, 0.24815700E+00, 0.73035200E-01, -.90229700E-02, -.11762400E+00, 0.17960900E-01, 0.90826100E-02, -.24772700E+00, -.53055100E-01, -.14697500E+00, 0.63162800E-01, 0.58553100E-01, 0.13409500E+00, -.17507900E+00, -.74415200E+00, 0.44364800E+01, 0.11168900E+02, 0.90771500E+00, 0.21084100E+00, -.11658800E+01, 0.11513800E+01, 0.33607100E+00, 0.19856000E+00, 0.51938600E+00, 0.38014200E+00, 0.95609900E+00, -.62290900E+00, -.69405700E+00, 0.36394900E+00, -.68620300E-02, 0.56641500E-01, -.49888400E+00, -.37506800E+00, 0.31432500E-01, 0.29243800E+00, 0.21054600E+00, 0.68782600E+00, 0.21908900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.71844300E+01, 0.32343800E+00, -.82238400E+01, -.18875300E+02, 0.20492100E+01, 0.46892400E+01, 0.24499500E+00, 0.19789900E+01, 0.48036100E+01, 0.86084200E+00, 0.83650100E+00, -.24598000E+01, 0.22466400E+01, -.11203200E+01, 0.11781300E+01, 0.31588100E+01, -.76916700E+00, -.37690000E+01, -.56241200E+01, 0.64336300E+01, -.31499000E+01, 0.19426400E+01, 0.42681400E+01, -.17925300E+01, 0.22406500E+01, 0.58917000E+01, -.13577700E+01, -.54587300E+00, -.59573200E+00, 0.13640400E+01, -.53817500E+01, -.26734400E+00, 0.41357500E+01, -.10790000E+01, 0.20860300E+01, -.38818400E+00, -.45647300E+01, -.26473500E+00, 0.60290500E+00, -.27167600E+00, 0.20495100E+01, -.13327200E+00, -.12262600E+01, 0.23242100E+01, 0.16301900E+02, 0.18218800E+01, -.36509000E+02, -.25634100E+00, -.43254900E+00, -.10360700E+01, -.16812700E+01, 0.57524900E+01, -.13646900E+01, 0.19322900E+01, 0.46912600E+00, 0.36993100E+01, 0.14362400E+01, 0.13786300E+00, -.41818700E+00, -.76897700E+00, -.45427900E+00, -.73657100E+00, -.98406000E+00, 0.15038800E+01, -.16809200E+01, 0.21688600E-01, -.13172700E+01, -.10538500E+01, -.19672300E+01, -.19025000E+01, 0.30716900E+01, 0.36112200E+00, 0.70863500E+00, 0.10080500E+01, -.51457200E+00, -.15983300E+01, 0.59079200E+00, 0.26585800E+00, -.54216700E+00, 0.15189000E-02, -.16178700E+01, -.18781900E+01, 0.17141800E+01, -.19134500E+00, -.62321600E+00, -.17793500E+01, -.23163000E+00, -.18881200E+00, 0.76356500E+01, -.12964200E+01, -.19033400E+01, 0.87300400E+00, 0.33081200E+01, 0.62467000E+00, -.43700400E-01, 0.41213800E+01, 0.23914600E+00, 0.22864300E+01, 0.35886500E+01, -.16021800E+01, 0.13765700E+01, 0.11076000E+01, 0.56722600E+00, -.16519700E+01, 0.15703200E+01, 0.59802800E+00, -.32019700E+01, 0.48403300E-01, -.40945900E+00, -.23303300E+00, -.69733400E+00, 0.20718100E+01, 0.44547300E+00, -.49385000E+00, 0.45941000E+00, -.12816100E+01, 0.18765500E+01, -.35640500E+00, -.50414000E+00, -.28238500E+01, -.24925900E-01, 0.29224600E+00, 0.30099600E+00, 0.14488400E+01, -.54865000E+00, -.10363100E+00, -.11400700E+01, -.15167600E+01, -.11053800E+01, -.29471600E+00, -.23394400E+00, -.98973800E+00, 0.44289900E+00, -.93920200E+00, -.15975700E+01, 0.14475500E+01, -.86740700E+00, -.96374300E+00, 0.76505100E+00, 0.51778700E+00, -.33719600E+00, 0.44035400E+00, -.89683000E-01, 0.28393700E+00, 0.24332600E+00, 0.53447300E+00, -.51274400E-01, -.82985200E+00, -.34277200E+01, 0.25490700E+01, 0.18709400E+02, 0.21547000E+01, 0.43209200E+00, -.13540200E+01, 0.12908700E+01, 0.35448400E+00, -.10899800E+01, 0.19656100E+00, 0.64606700E-01, 0.75005600E+00, -.25126900E+00, -.74901000E+00, -.40405500E-01, 0.60146000E-01, 0.15427300E+00, -.39552200E+00, -.24591100E+00, -.43359700E-01, -.34428100E-01, -.80150400E-01, 0.81944900E-01, 0.25618900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20574100E+01, 0.54464300E-01, 0.43504300E+01, 0.66960400E+01, -.19831100E+01, -.24325200E+01, -.10573600E+00, -.67830100E+00, -.15152900E+01, 0.31063300E+00, -.29210200E+00, 0.12080000E+01, -.13117000E+01, 0.23269800E+01, -.10095400E+01, 0.40606700E+00, 0.48645700E+00, -.10931800E+00, 0.45840200E-01, 0.18502900E+01, -.13081200E+01, 0.53703900E+00, 0.44945700E+00, 0.21247800E+00, -.12324400E-01, -.98027500E-01, 0.11112500E+01, 0.15743100E+00, 0.50370200E+00, 0.16335900E+01, 0.25855900E+01, -.10239300E+01, -.10537500E+01, -.89682000E+00, -.16811900E+01, -.41054900E+00, 0.64384100E+00, -.75853400E-01, -.51152200E+00, 0.61079600E+00, -.38865000E+01, 0.52749900E+00, 0.21898400E+00, -.54771200E+00, -.72333000E+00, -.11372400E+01, -.53634000E+01, -.44559700E-01, 0.10691200E+00, 0.86176600E+00, 0.18771500E+01, -.81576100E+00, 0.58677300E+00, 0.24903200E-01, -.16008400E+00, -.12126000E+00, -.17033700E+00, -.42554200E+00, 0.29959000E+00, -.59423700E+00, -.99562100E-02, -.34894800E+00, 0.45503700E+00, -.14215100E+00, 0.66373600E+00, -.11435200E+00, 0.39480300E+00, 0.68627100E+00, -.29553800E+00, 0.38596700E+00, -.80508200E+00, 0.15150100E+00, -.78669900E+00, -.46577200E+00, -.44996100E+00, -.32691800E+00, -.20342500E-01, 0.33045900E+00, -.30384000E+00, 0.53511400E+00, 0.51070600E+00, 0.77464200E+00, -.94294800E+00, 0.38437800E-01, -.83239700E-01, 0.21460100E+00, 0.56486700E-01, 0.20989900E+00, -.15271200E+01, 0.36078000E+00, 0.56331900E+00, 0.21762200E+00, 0.59516900E-01, -.36550000E+00, 0.65544600E+00, -.35491600E+00, 0.38433000E+00, -.14867900E+01, 0.10519100E+01, 0.17075800E+01, 0.89120600E-01, 0.20940600E+00, -.44602700E+00, 0.31776500E+00, 0.50305400E+00, 0.46700300E+00, 0.40845200E+01, 0.71259100E-01, -.80093600E+00, -.96544200E-01, -.63223600E+00, -.68576000E+00, -.10400600E+01, 0.58049000E+00, 0.73620800E+00, 0.42325700E+00, -.10314700E+01, 0.18889800E+00, 0.21067700E+00, 0.12489100E+01, -.30850500E+00, 0.94235200E-01, -.13326200E+00, -.24872600E+00, -.75302900E-01, -.29672200E-01, 0.71581000E+00, 0.28605200E+00, 0.60428600E-01, 0.31517900E+00, 0.11223300E+00, -.87889100E+00, 0.86663100E-01, 0.16417000E+01, 0.10182100E+01, -.47525000E+00, 0.26589600E+00, 0.45941300E+00, -.97252200E+00, -.25746700E+00, -.26033400E-01, -.39441400E-01, 0.13394500E+00, 0.17729500E+00, -.69232200E-01, 0.17418700E+00, -.45095000E-01, -.17346500E+00, -.71063400E+00, -.14892400E+00, 0.61021000E-01, -.16280700E+01, 0.10991200E+00, -.15030900E+01, 0.53341000E+00, 0.45072200E+00, 0.35688700E+00, 0.37807800E+00, -.70598000E-01, 0.81161700E+00, -.18743400E+00, -.24439900E+00, 0.32889300E+00, 0.88421200E-02, 0.96894600E+00, -.13515500E+01, -.14620900E+01, 0.37297300E+00, 0.34291200E+00, 0.17210600E+00, -.81175500E-01, 0.20401800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.12858200E+01, -.42379800E-01, 0.24259400E+01, 0.39762500E+01, -.53809500E+00, -.11974700E+01, -.55790800E-01, -.14042600E+00, -.32329800E+00, -.91794600E-01, 0.43904700E+00, -.11040400E+00, -.69368200E+00, 0.52367300E+00, 0.14103500E+00, -.64227100E-01, -.45210400E+00, 0.10051100E+01, 0.76076800E+00, -.12149100E+01, -.91256000E-01, 0.18698700E+00, -.20872100E+01, -.23008700E-01, -.87755400E+00, -.16178500E+01, 0.51285300E+00, 0.12446000E+00, 0.25224400E+00, 0.13245300E+01, 0.12453600E+01, 0.36543200E+00, 0.84626200E-01, -.19726500E+00, -.70086300E+00, -.29016400E+00, 0.79671200E+00, -.38613000E-01, -.82156400E-01, 0.71641600E-01, -.28842100E-01, 0.10896400E+00, 0.40182800E-01, -.28107200E+00, -.36947100E+01, 0.66619700E+00, 0.52688300E+01, 0.81646700E-01, 0.19185600E+00, 0.26836300E+00, -.11635000E+00, -.15434500E+01, 0.37426400E+00, -.46621300E+00, -.86434800E-01, -.77019000E+00, -.66148500E+00, -.18824000E+00, 0.17606400E+00, 0.41135300E+00, -.35106000E-02, 0.13466900E+00, 0.43308900E+00, -.55926900E+00, 0.45386600E-01, -.10117500E+00, 0.21202600E+00, 0.30848200E-01, 0.31598600E-01, 0.78486400E+00, -.47040400E+00, -.36274200E-01, -.37102300E+00, -.12444500E+00, 0.57608100E+00, 0.70176300E+00, -.30406600E+00, -.15023900E+00, 0.11204400E+00, -.62857700E-01, -.13616600E+00, 0.10833700E+00, 0.31796200E-01, 0.58902900E-01, -.37883700E-01, 0.38113600E+00, -.44676500E-01, -.15175800E+00, -.13953000E+01, 0.18148500E-01, -.55767400E+00, 0.72063300E-01, -.10049600E+01, -.20996500E+00, -.16390900E-01, -.78883700E+00, 0.12502000E+00, -.48036700E+00, -.37312000E+00, 0.11984200E+01, -.12369300E+00, -.87285100E-01, -.75917500E+00, 0.41569400E+00, -.19301400E+00, 0.34971300E+00, 0.10122600E+01, -.12366600E+00, -.14265100E+01, -.72998500E-01, -.27668500E+00, -.33795200E+00, -.12488100E+00, 0.25210000E+00, 0.59746200E+00, -.10776500E+00, 0.37728000E-01, 0.24274500E+00, 0.35704200E+00, -.15306900E+00, -.54330300E-01, -.11892300E+01, -.89933700E-01, 0.73942800E-01, 0.27072100E+00, 0.60692000E-01, 0.13670300E+00, 0.49792100E-01, 0.14523700E+00, -.12940700E+00, -.53735900E-01, 0.45320000E+00, -.14416700E-01, -.98533800E+00, -.45512000E+00, 0.21763800E+00, -.84396300E-01, 0.31610400E+00, 0.27214800E+00, 0.68298800E-01, 0.36134400E-01, 0.18362900E-01, -.49409800E-01, -.20869200E+00, 0.29075600E-01, -.10836800E+00, 0.13974600E-01, 0.17766600E+00, -.11618200E-01, 0.99433500E-01, 0.51305800E-03, 0.50232900E+00, -.19349900E+00, 0.13989800E+01, -.65388500E+00, -.44388300E+00, -.53772700E+00, -.66912800E+00, -.24397200E+00, -.87423100E+00, 0.23938000E+00, 0.31074800E+00, -.65321400E+00, 0.23042800E-01, -.46808400E+00, 0.10889800E+01, 0.12407200E+01, -.23864500E+00, -.43320800E+00, -.34170400E+00, 0.37032100E-01, -.17153100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.82698000E+01, -.26561300E+00, -.89113600E+01, -.33157400E+02, -.31626500E+00, 0.51701800E+01, 0.90507600E+00, 0.66769800E+01, 0.70022500E+01, -.36121400E+00, 0.17834400E+01, -.19548400E+01, 0.59462500E+01, -.67175900E+01, 0.43321000E+01, 0.42308400E+00, 0.62059900E+01, -.48476600E+01, 0.97143500E+00, -.19739100E-01, 0.52943800E+01, 0.13354100E+01, -.14144700E+01, -.59010400E-01, 0.13457500E+00, -.22751100E+01, 0.74451600E+01, 0.43190800E+00, 0.25668500E+00, 0.50605600E+01, 0.15047100E+00, 0.38838600E+01, 0.11603700E+02, -.33916700E+01, 0.27849900E+01, -.15740500E+01, -.49467200E+01, -.17361900E+01, 0.28290800E+00, 0.80484400E+00, 0.79022200E+01, -.97865800E+00, 0.29388400E+01, 0.43105600E-02, 0.14957000E+02, -.42995400E+00, -.11418900E+02, -.14509700E+00, -.98102900E+00, -.16993500E+01, -.23793600E+01, -.22849200E+01, -.67639700E+00, -.64976100E+00, 0.51643700E+00, 0.76933700E+00, 0.76938100E-01, 0.29172800E+01, 0.21403900E+00, -.16082200E+01, 0.29486600E+00, -.42678900E-01, 0.58453700E-01, -.49835000E+01, 0.26170300E+01, -.65502000E+00, 0.19807300E+01, 0.23810100E+00, 0.90905700E+00, 0.66854000E+00, -.11126300E+01, 0.15617300E+00, 0.25990800E+01, 0.29428500E+00, -.13050200E+01, 0.13068600E+01, -.11221900E+01, 0.40864300E-01, -.30855400E+00, 0.65693900E+01, 0.47474900E+00, -.48728500E+00, 0.62356000E+00, 0.20026000E+00, 0.70704700E+00, -.41193500E+01, 0.17655600E+01, -.51156500E+00, 0.63954700E+01, -.18224500E+00, -.24284100E+01, 0.23418400E+01, 0.51657600E+01, 0.10799500E+01, 0.39291200E+00, 0.52028800E+01, 0.34242700E+01, 0.22439000E+01, 0.93532700E+01, -.38700000E+01, 0.96844700E+00, 0.10062300E+01, 0.75791800E+01, -.73451800E+00, 0.19892800E+01, 0.90786300E+01, 0.49433700E+01, 0.20670600E+01, 0.70640200E+01, 0.10194900E+01, -.26447800E+01, 0.85716700E+00, -.20608000E+01, 0.37530400E+01, -.15080300E+01, -.51467400E+01, -.18524500E+01, -.28553900E+01, -.36579100E+01, -.33447100E+01, 0.17496000E+01, -.39106900E+01, 0.19254400E+00, 0.40296600E+01, -.24316100E+01, -.10264600E+01, -.10500300E+00, -.11512800E+01, 0.69278600E+00, 0.43179900E-02, 0.38528300E-01, 0.14278600E+01, -.95006100E-01, -.37069300E+01, -.11767400E+01, 0.14888100E+01, -.60073800E+00, 0.19942500E+01, 0.21301700E+01, 0.48299500E+00, 0.44573000E-01, 0.94490800E+00, -.82840600E-02, 0.90243700E-01, -.26073600E+00, 0.73815000E+00, -.76550900E+00, 0.81154500E+00, -.13426200E+01, -.12853000E+01, 0.21033900E+00, 0.45761800E+00, -.54165000E+01, 0.71841600E+01, -.29328700E+01, -.37229800E+01, -.90295400E+01, -.34737000E+01, -.12890700E+01, -.62239200E+01, 0.37991300E+00, 0.12250800E+01, -.47473700E+01, 0.45825200E+00, -.37424000E+01, 0.61330000E+01, 0.69431000E+01, -.21719300E+01, -.35912500E+01, -.36903800E+01, 0.17678200E+01, -.80555400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.12246100E+01, 0.87899400E-01, 0.94543200E+00, 0.22214700E+01, -.39668200E+00, -.37125000E+00, 0.35108600E+00, -.17881300E+00, -.22526200E+00, -.74719200E-02, 0.26373600E-01, -.22973000E+00, -.31839700E+00, 0.13794400E+00, -.33340200E-01, -.28475400E+00, 0.13177200E+01, -.66948800E+00, -.20095800E+01, -.51076800E+00, 0.50540500E+00, -.14749500E+00, -.10746700E+01, -.28905800E+00, -.25293100E+00, 0.48401800E+00, -.12523600E+00, -.33319100E-01, 0.11503700E+00, 0.22858900E+00, 0.44313700E-01, -.41536700E+00, -.53757100E+00, 0.19806100E+00, -.30258900E+00, 0.70991100E-01, 0.22613100E+00, 0.16495000E+00, 0.88494600E-01, -.14727100E+00, -.66245200E+00, -.24292300E-01, -.70827000E-02, -.18068700E+00, -.21326400E+01, -.31953000E+00, 0.41280000E+01, 0.29333800E-01, 0.16811100E-02, -.74895700E-03, -.42010000E-01, -.40017500E+00, -.20959600E-01, -.33769000E-01, -.11596300E+00, -.47460700E+00, -.28945500E+00, -.26535600E+00, 0.16895400E+00, 0.13859600E-01, -.95864900E-02, -.25664000E+00, -.12677800E+00, -.25476400E+00, -.28148600E+00, 0.25599500E-01, -.53024200E-01, -.13780500E+00, 0.20575700E+00, -.57472000E-02, -.10152800E+00, -.58609100E-01, 0.70542500E-02, -.58815400E-03, 0.92218200E-01, 0.18513200E-01, 0.47161400E-01, -.53104200E-01, 0.10185000E+00, -.52301200E+00, 0.30082600E+00, 0.18753200E+00, 0.23802100E+00, -.19367800E-01, 0.24497100E+00, 0.14610500E+00, 0.96895900E-01, -.13165000E+00, 0.11522900E+00, 0.12947800E+00, 0.27904500E+00, -.15569500E+00, 0.14324700E-03, 0.78888800E-01, -.90962000E-01, -.25389800E+00, -.13913300E+00, 0.19784100E+00, -.12799000E+00, 0.78821100E-01, 0.38829000E-01, -.35192700E-01, -.11810700E+00, 0.13916400E+00, 0.42885700E-01, -.60299300E+00, -.26641400E+00, -.72836800E-01, 0.60724800E-01, 0.12417200E+00, 0.17311100E+00, -.34335400E-01, 0.22217700E+00, -.91798000E-01, -.17866400E+00, 0.80911600E-01, 0.14643000E+00, 0.10141100E-01, 0.30507200E+00, -.19836200E-01, -.16006400E-02, 0.31161700E+00, 0.38795600E-01, -.14755200E+00, 0.12551500E-01, -.21598300E-01, -.55800300E-02, 0.13194800E+00, 0.15640000E+00, 0.22097800E-01, 0.20222000E-01, 0.73756400E-01, 0.56743600E-02, 0.59003600E-01, 0.13559300E+00, -.55519000E-01, 0.42457400E-01, -.25079000E-01, -.11948000E-01, -.17680500E-01, 0.14249800E-01, -.34461000E-01, 0.20127900E-01, 0.34365200E-02, -.30489600E-02, -.19321200E-01, -.83785200E-02, 0.24972300E-01, 0.44851600E-01, -.70667000E-01, -.18471300E-01, -.37044900E-01, -.65492400E-01, -.38635300E-03, 0.19416100E+00, -.58512200E-02, 0.33699800E-01, 0.55409700E-02, 0.18266200E-02, 0.20658100E-01, -.56892900E-01, -.10039700E+00, -.19086800E-02, -.42803100E-02, 0.55442300E-01, -.93615200E-02, 0.16234900E-01, 0.69524100E-02, 0.69277800E-02, 0.84549300E-02, 0.25988700E-01, -.20479500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.37209200E+01, 0.11446000E+00, 0.45537400E+01, 0.12048600E+02, -.67148600E+00, -.11754400E+01, 0.70376400E-01, -.91128200E+00, -.14234200E+01, 0.28147400E+00, -.22884200E+01, 0.95290600E+00, -.11463100E+01, 0.75692600E+00, -.20851800E+01, 0.94397700E+00, 0.31318700E+01, -.67219500E+00, -.74790900E+00, 0.15457200E+00, 0.35387600E+00, -.10271200E+01, 0.93039700E+00, 0.39617400E+00, 0.89339200E+00, 0.39394900E+01, 0.34993800E+01, 0.33307700E-01, 0.12771500E+00, 0.13402100E+01, -.21028800E+01, -.28412400E+01, -.31904900E+01, 0.16817000E-01, -.21462700E+01, -.35961100E+00, -.11283900E+01, 0.18262300E+00, 0.14409900E-01, 0.95014300E-01, -.28874800E+01, 0.14491800E+00, -.45588500E+00, 0.13400100E+00, -.21579900E+01, -.24471100E+01, -.14299800E+02, -.25837200E+00, -.60576900E+00, -.91110900E+00, 0.10350700E+01, 0.56170400E+01, 0.65360500E+00, 0.90505300E+00, 0.99464000E-01, 0.23925500E+01, 0.82692900E+00, -.93806300E+00, 0.16056800E+00, -.14249700E+01, -.94139200E+00, 0.70426400E-02, 0.10039600E+01, -.95417500E+00, 0.83516800E+00, 0.70037900E-01, -.23568500E+00, 0.17112400E+01, -.35978400E+00, -.94829100E+00, 0.17361700E+01, -.73794800E-04, -.12971800E+00, -.15545000E-01, -.91641100E+00, -.17918700E+00, -.39961800E+00, -.89154700E-01, -.44759100E+00, 0.21125900E+00, -.56333600E-01, -.57530900E+00, 0.72824700E+00, -.92109800E-01, 0.65521700E-01, -.18839400E+00, -.11389800E+00, 0.17696000E+00, 0.11919800E+01, -.28408100E+00, -.33513000E+00, 0.25089800E+00, 0.26587300E+00, -.35235800E-01, -.48099600E-01, 0.15343700E+00, 0.42622700E-01, -.28066700E-01, -.22596400E+00, 0.13216900E+00, 0.81326600E+00, 0.28694100E+00, -.11233900E+01, 0.17609800E+00, 0.67482400E+00, -.51874200E+00, 0.69794600E+00, -.20930300E+00, -.12040200E+01, -.10692800E+00, -.38125000E+00, 0.77699800E+00, -.91137700E-01, 0.59149100E-02, 0.31924400E+00, 0.29294000E+00, 0.55037300E-01, -.11311600E+00, 0.76188400E+00, -.12656200E+01, 0.51561200E-01, -.79197800E+00, -.54535000E-01, -.90286700E-01, 0.37573800E+00, 0.12888800E+00, 0.48192900E-01, -.56201100E+00, -.44831300E+00, 0.89439300E-01, -.18878900E+00, -.14154300E+01, 0.17708500E+00, -.12100500E+00, 0.65330500E+00, 0.10047100E+01, 0.16382700E+00, -.68569900E+00, 0.16359100E+00, -.50314700E-02, -.25862400E+00, -.80056400E-01, -.24373800E+00, 0.22948100E+00, 0.58763700E-01, 0.53521500E-01, 0.13161000E+00, -.30672900E+00, 0.11799200E+01, -.27484900E+00, -.14345200E+00, -.15938900E+00, -.20726700E+01, 0.27369600E+00, 0.53361600E+00, 0.86486100E+00, 0.21637200E+01, 0.11211200E+01, 0.16693200E+01, 0.90973000E+00, -.33289900E+00, -.38668400E+00, 0.17992600E+01, -.17683100E+00, -.26958300E+01, -.18664500E+00, -.70292900E+00, -.53811300E+00, 0.11986500E+01, 0.11270200E+01, 0.45565600E+00, -.61296200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11717900E+01, -.25890100E-01, -.23443200E+01, -.41767300E+01, 0.10817600E+01, 0.14515400E+01, 0.17499400E+00, 0.19760100E+00, 0.15681900E+00, -.19755400E+00, 0.28620400E+00, -.49000000E+00, -.16001900E-01, -.79769800E-01, 0.34429600E+00, 0.43265200E+00, -.64960300E-01, 0.47195200E+00, 0.11881500E+01, 0.45383400E+00, -.85572100E+00, 0.45479000E+00, 0.62598300E+00, 0.25898900E+00, -.65038200E-01, -.11279400E+01, -.99255200E+00, 0.10907800E-01, 0.22815300E+00, -.48567600E+00, -.50020100E+00, 0.12587800E+00, -.45322100E+00, 0.49339000E+00, 0.38643400E+00, 0.22972000E+00, 0.40113700E+00, 0.15438000E-01, 0.92955100E-01, -.56228800E-01, 0.91168500E+00, -.18878600E+00, -.93233800E-02, 0.86099600E-01, 0.11978500E+00, -.16346300E+00, 0.19461800E+01, -.59563200E-01, 0.47110900E-01, 0.25716300E-02, -.22036100E+00, 0.47198200E+00, -.15935700E+00, -.13067800E+00, -.97200900E-01, -.34147100E+00, -.12756800E+00, -.21020500E-01, -.42416600E-01, 0.16397500E+00, -.92559300E-01, 0.14590700E-01, -.23292400E+00, 0.23562000E+00, -.21064700E+00, -.10754900E+00, -.39458700E-01, -.57711100E+00, -.11401900E+00, -.24340700E+00, -.22183400E-01, -.57888700E-01, 0.21805100E+00, 0.45110100E-01, -.15804800E+00, -.85213000E-01, 0.13558400E+00, -.15266600E+00, 0.23897700E+00, -.10069100E+00, -.25004700E-01, -.71114800E-01, 0.25218400E+00, -.45675700E-01, 0.91384500E-02, 0.11308300E-01, -.71617700E-01, -.75262700E-01, 0.87457200E+00, -.16282200E-01, -.84790100E-01, -.25198700E-01, -.46677700E+00, -.48040900E-01, 0.48684400E-01, -.29375500E+00, -.19855600E-01, -.38824500E+00, -.34223200E+00, 0.95152500E-01, -.15080400E+00, -.22204500E-01, -.13113900E+00, 0.73654300E-01, -.25997000E-01, -.17695800E+00, 0.26636000E+00, -.58698600E-01, -.69874100E-01, -.78701500E-01, 0.11788900E+00, 0.40839300E-01, -.18205600E-01, -.26320000E-01, -.14751600E+00, 0.15985400E+00, -.83991500E-01, 0.21723200E-02, -.64121600E-01, 0.17068200E+00, 0.19191500E-01, 0.24006900E+00, 0.14394800E-01, -.21018100E-01, -.78087700E-01, 0.15607400E-01, 0.73143300E-01, 0.16148700E-01, 0.50409900E-02, 0.57982000E-01, 0.29290000E-01, -.58244300E-01, -.14941200E-02, 0.28416900E-01, 0.24081700E-01, -.45118300E-01, -.18011900E-01, -.88939500E-01, 0.20844500E-01, 0.82365300E-02, 0.62332600E-01, -.71350700E-01, 0.30658500E-01, 0.48930300E-01, -.44683600E-02, -.98491300E-02, 0.56260600E-02, 0.19522700E-01, -.18080400E-01, 0.49749100E-01, -.68946300E-02, -.18345600E-01, 0.23971100E+00, -.41499700E-01, 0.67296200E-02, 0.17383800E+00, -.71893400E+00, -.37123600E+00, -.41594100E+00, 0.10480700E+00, 0.37758000E-01, 0.36552100E-01, -.53843500E+00, 0.44398300E-01, 0.38568200E+00, 0.59571400E-01, 0.16873700E+00, 0.50968200E-01, -.31670000E+00, -.34761900E+00, -.45429000E-01, 0.10324200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.33297700E+01, 0.16205100E+01, 0.15932100E+00, -.15706900E+01, 0.31486900E+01, 0.14804400E+01, -.16864300E+00, 0.57371400E-01, 0.87562000E+00, 0.13669800E+01, -.45431700E+00, 0.15602900E+01, 0.79529400E+00, 0.67035700E+00, 0.16019500E+00, -.73630700E+00, 0.32578100E+01, -.38536800E+01, -.90404600E+01, -.17051200E+01, 0.15493900E+01, 0.74093300E+00, 0.25729900E+00, 0.26156500E+00, -.95132600E+00, -.41313200E+01, 0.38925000E+01, 0.16345500E+00, 0.15217700E+01, 0.37227700E+01, -.66588800E+01, -.28524900E+01, -.21487900E+01, -.14703500E+01, -.28258700E+01, -.19559300E+01, 0.62978600E+00, -.24138900E+00, -.53850000E+00, -.72499300E-01, -.48896100E+01, 0.10257100E+01, 0.66313700E-01, 0.50041700E+00, 0.10682000E+02, 0.16386300E+01, -.97352900E+01, 0.16622200E+00, 0.39615800E+00, 0.13290200E+01, -.66468900E+00, -.57932300E+01, -.39585100E+00, -.73442200E+00, -.12172700E+00, -.11855500E+01, -.11198400E+01, -.11334100E+01, 0.72879600E+00, 0.15063100E+00, -.22674200E+00, -.28585500E+00, 0.54019900E+00, 0.40619300E+00, 0.55940700E+00, -.14985900E+01, 0.97784300E+00, -.58084300E+00, -.12708300E+01, 0.13717200E+00, -.24445800E+01, -.65281800E+00, 0.12642200E+01, -.82168700E+00, -.18891900E+01, 0.62100500E+00, 0.11646300E+00, 0.31151100E+00, -.60495200E+00, 0.19278200E+00, -.89811300E+00, -.13875200E+01, -.27434600E+00, 0.45009700E+00, -.45255700E+00, -.18799700E+01, 0.10835700E-01, 0.57551300E+00, 0.56046400E+01, 0.29459200E+00, 0.30867900E+01, -.90919900E+00, 0.15611900E+01, 0.56000000E+00, 0.60317200E+00, 0.10389500E+01, -.72394700E+00, 0.17033100E+01, 0.93387100E+00, -.13507900E+01, -.15359700E+00, -.31981900E+00, 0.11672300E+01, -.56607200E+00, -.84905600E+00, -.10106800E+01, -.46135600E+01, 0.43266300E+00, 0.14859100E+01, 0.21615500E+00, 0.25903600E+00, -.37520300E+00, 0.10054900E+01, -.86055400E+00, -.17875500E+01, 0.34815000E+00, 0.36981700E+00, -.84662200E+00, 0.45975600E+00, 0.34354100E+00, -.38278500E-01, 0.23202400E+01, 0.12602700E+00, -.48179700E-01, 0.71548000E+00, -.45923200E+00, -.78378100E+00, -.30013500E+00, 0.63039800E+00, -.48553300E+00, -.22058000E+00, 0.11016000E+01, -.26361300E+00, -.11410700E+00, -.12290000E+01, -.13250500E+00, -.45232500E+00, 0.57078000E+00, -.75200600E+00, 0.46148300E+00, -.52625000E-01, -.36684400E+00, -.33309600E+00, 0.19932100E+00, -.54803000E-01, -.21519800E+00, 0.36720800E+00, -.39712100E+00, 0.14627600E+01, -.12905200E+00, -.23912000E+00, -.36984200E+00, -.88795000E+00, 0.80028200E-01, 0.10320400E+01, 0.59908100E+00, -.10067100E+01, 0.27071400E+01, -.98945300E-02, 0.27534600E+00, -.25287000E+00, 0.72514900E-01, 0.20319700E+01, 0.12047900E+00, 0.20149900E+01, -.15047700E+00, 0.33668100E+00, 0.17519300E+00, -.52226600E-01, 0.56912500E-01, 0.18690800E+00, 0.22636100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20346100E+01, 0.52606600E-01, 0.25082600E+01, 0.65674300E+01, 0.98402500E-01, -.17138800E+01, -.24667900E+00, -.14139900E+01, -.15564500E+01, 0.25718300E+00, -.90538400E+00, 0.13053800E+01, -.23325800E+00, 0.80788200E+00, -.85195700E+00, -.69588300E+00, 0.19196200E+01, -.64552400E+00, -.35025300E+00, -.47191900E+00, 0.95755400E+00, -.39074100E+00, 0.18068500E+00, 0.29216900E+00, 0.15972100E+00, 0.81750900E+00, -.16053800E+00, 0.15480400E-02, 0.21838100E-01, -.64374200E+00, -.48610900E+00, -.96663300E+00, -.15230700E+01, 0.22526900E+00, -.65444100E+00, 0.82889500E-01, -.35178900E+00, 0.59025700E-01, 0.17536300E-01, -.30881100E-01, -.36985200E+00, -.40821600E-01, -.24223000E+00, 0.42621200E-01, -.12721300E+01, -.36990300E+00, -.19999100E+00, 0.42303100E-01, 0.38013000E-01, 0.34157100E+00, 0.60245500E+00, 0.51635500E+00, -.12341100E+00, -.23373900E+00, -.13838000E+00, -.54689100E+00, -.72482600E-01, -.27014500E+00, 0.19468100E+00, -.83448400E-02, 0.23021300E+00, -.19642600E+00, -.19208400E+00, -.10258800E+00, -.32665200E+00, -.14038100E+00, 0.20487400E+00, -.50037600E+00, -.12661600E+00, 0.38318100E+00, -.59886700E+00, 0.47603700E-01, 0.27405100E-02, -.11554300E+00, 0.18208300E+00, -.31839500E-01, 0.68659200E-01, 0.18942100E+00, 0.50834000E-01, -.52202900E+00, 0.92044500E-02, 0.12722200E+00, 0.15981100E+00, 0.67787500E-02, 0.44829400E-01, 0.19061900E-01, 0.43346800E-01, -.25539800E+00, 0.72229300E+00, 0.10476600E+00, 0.68815900E-03, -.12078500E+00, -.21990200E+00, 0.10412700E-01, -.40290800E-01, -.29313100E+00, -.11068500E+00, 0.12879000E-01, -.40466600E+00, 0.28214700E+00, -.12529900E+00, -.57934300E-01, -.36318400E+00, 0.93795500E-01, -.23848700E+00, 0.17764900E-01, 0.29467200E+00, -.96733800E-01, 0.90017400E-01, 0.42230000E-01, 0.19270000E+00, -.27252300E+00, 0.50178100E+00, -.14663300E+00, -.16878100E+00, 0.46593400E-01, 0.12813700E+00, -.27921500E-01, 0.36230300E+00, -.13464600E+00, 0.12205400E+00, -.10369500E+00, -.15783400E-01, -.75085500E-01, 0.33781200E-01, -.38781300E-01, -.14043000E+00, 0.71516400E-01, 0.16667000E+00, -.18812500E+00, -.38391800E-01, 0.22687100E+00, -.87582600E-01, 0.19186900E+00, 0.37587200E-01, -.67913600E-01, 0.59723900E-01, -.37787200E-01, 0.22451900E-01, 0.20683500E-01, -.36696100E-02, 0.29819800E-01, 0.10304100E-01, 0.46990400E-02, -.12145000E-01, 0.15821500E-01, -.10077300E-01, 0.14192600E-01, -.21215100E-01, -.10204500E-01, 0.99399200E-03, -.10865100E-02, -.85708400E+00, 0.17060400E+00, -.34422600E+00, 0.27154800E+00, -.67860700E+00, -.19740300E+00, -.72416900E+00, 0.16793500E+00, 0.19404800E+00, 0.17423800E+00, -.19907900E+00, 0.25734400E-02, 0.16508500E+01, -.50252000E-01, 0.25367900E+00, 0.40197400E+00, -.31332300E+00, -.14551300E+00, -.40270600E+00, 0.16189900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15945400E+01, -.32948600E-01, -.25162000E+01, -.45568100E+01, 0.48763300E+00, 0.13863300E+01, 0.30975700E-01, 0.33970700E+00, 0.45845900E+00, -.19229200E+00, 0.62678900E+00, -.72256900E+00, 0.18364800E+00, -.31801800E+00, 0.56064000E+00, -.52910100E-01, -.32833200E-02, 0.18271400E-01, 0.42384000E+00, 0.47415600E+00, 0.18227400E+00, 0.67062400E-01, -.30874100E-01, -.16065000E+00, -.18851900E-01, -.53656800E+00, -.50330000E+00, 0.81806300E-03, -.51099300E-01, 0.61222400E-01, 0.11764300E+01, 0.73921200E+00, 0.90793900E+00, -.10617700E+00, 0.39042200E+00, 0.10626000E+00, 0.20291700E+00, -.60613600E-01, 0.73273500E-01, -.94164600E-02, 0.12402200E+01, -.77232600E-01, 0.75158000E-01, 0.13901700E+00, 0.10504500E+01, 0.30769500E+00, 0.19806600E+01, -.66975800E-02, -.11240000E-01, -.19981600E+00, -.60504400E+00, -.38164700E+00, -.59454800E-01, 0.69316400E-01, 0.30451000E-01, -.41077800E-01, -.11079900E+00, 0.28520100E+00, -.10412000E+00, 0.11870100E+00, -.40049900E-01, 0.15725700E+00, -.46943200E-01, -.21253400E+00, 0.89166100E-01, -.12506900E+00, 0.79795000E-01, -.22922000E+00, -.99012700E-01, -.21729400E+00, -.40351900E-01, -.72430800E-01, 0.23827700E+00, 0.48622100E-01, -.16773600E+00, -.44299800E-01, 0.11148500E+00, -.20310000E+00, 0.25747600E+00, -.63427500E-01, -.20960700E-01, -.64387700E-01, 0.30206100E+00, -.66540000E-01, -.63601500E-02, 0.93030200E-01, -.95011500E-01, -.86620300E-01, 0.95390100E+00, -.26219000E-01, -.21983000E+00, 0.63431300E-01, -.54109100E+00, -.52637800E-01, 0.21707400E-01, -.28541300E+00, 0.10480100E+00, -.43231600E+00, -.41970200E+00, -.63752700E-01, -.16050000E-01, 0.15561200E-01, -.14340000E+00, 0.13832000E+00, 0.64488700E-01, -.12092900E+00, 0.45012700E+00, -.44262900E-01, -.10663700E+00, -.12062600E+00, 0.40855800E-01, 0.92514200E-01, -.16582900E+00, 0.56218200E-01, -.83071200E-01, 0.97668700E-01, -.19123300E+00, -.21715900E-02, -.13979000E+00, 0.50395300E-01, 0.40376000E-01, 0.74143600E-01, -.32189300E-02, -.40569000E-01, -.31660400E-01, 0.38670000E-01, 0.10893000E+00, 0.31458600E-01, -.33867700E-01, 0.11446500E+00, 0.28750400E-01, -.10431500E+00, 0.21650100E-01, -.10759900E+00, 0.21845500E-01, 0.70231100E-02, -.98820700E-02, -.85000500E-01, -.97703400E-02, -.84754400E-03, 0.40406000E-01, -.11992100E+00, 0.10066700E-01, 0.47812400E-01, 0.12471300E-01, -.27492500E-01, 0.36666400E-01, -.19329800E-01, 0.74103100E-01, 0.11545000E-01, -.22108500E-01, -.34886600E-01, 0.13085300E+00, -.39226900E-01, -.13224000E+00, 0.32170300E+00, 0.13230200E+01, 0.33318600E-02, 0.34974300E-01, -.27715100E+00, 0.14842300E-01, -.36380300E-02, -.22520900E-01, 0.82679800E-02, 0.62005400E-01, 0.28989200E-01, 0.47775200E-01, 0.12704000E-01, -.12296300E-03, -.43074700E-02, 0.32327300E-01, -.37393300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.74804900E+01, -.29332900E+00, -.13439600E+02, -.26229800E+02, 0.21173600E+01, 0.99574200E+01, 0.10822600E+01, 0.48710600E+01, 0.65537300E+01, -.11196500E+01, -.37270300E+01, -.69855400E+01, 0.94179300E+01, -.13977100E+02, 0.25801300E+01, 0.43834100E-01, 0.20083200E+01, -.33182000E+00, 0.18425000E+01, -.74548500E+01, -.32542500E+01, -.21035100E+01, 0.44924500E+01, 0.30721300E+01, 0.28755500E+01, 0.88505700E+01, 0.59861600E+01, -.41837100E+00, -.30484900E+01, -.62061500E+01, -.49179500E+01, 0.22836300E+01, 0.12145800E+01, 0.31142900E+01, 0.24843600E+01, 0.17416400E+01, 0.10012900E+01, 0.17719700E+00, 0.58909300E+00, -.13933700E+01, 0.65736500E+01, -.94995100E+00, 0.11652700E+01, 0.14235100E+01, 0.23257200E+02, -.40558200E+01, 0.94110400E+01, -.60120100E+00, -.11906100E+01, -.19924300E+01, -.33407400E+01, 0.52039700E+01, -.26524200E+01, 0.37824900E+01, 0.42997300E+00, 0.19597100E+01, 0.17287100E+01, 0.71091300E+00, -.16256900E+01, 0.69798900E+00, -.34841300E+00, 0.13086600E+01, -.19018700E+01, -.85144800E-01, -.76098300E-01, 0.33247400E+00, 0.12435200E+00, -.39933000E+01, 0.46879300E+00, 0.10678500E+01, -.27336900E+01, 0.36736900E+00, 0.13830200E+01, -.33001900E+00, 0.12859000E+01, 0.76651400E+00, -.93480100E+00, -.36340100E+00, 0.81190100E+00, 0.26127600E+01, 0.32451800E+01, 0.15315000E+01, -.62060000E+00, -.22266200E+00, 0.22371400E+01, -.16825100E+01, 0.68312100E+00, -.44749900E-01, -.10089500E+01, 0.92824000E+00, 0.83866600E+01, -.25085700E+01, 0.11120900E-01, -.48188300E+00, 0.17017100E+01, -.27080000E+01, -.26138900E+01, -.74906000E+00, -.50968300E+01, 0.23476300E+00, -.15366300E+01, -.69397200E+00, -.20514300E+01, 0.14120700E+01, 0.22520300E+01, -.78979400E+01, 0.46074700E+01, -.56185000E+00, -.81902300E+01, -.13538500E+01, 0.24155500E+00, 0.99800400E+00, -.15366000E+01, -.11016800E+01, -.14132700E+01, -.13728100E+00, 0.97917900E+00, -.14348200E+00, 0.56987200E+00, -.37768800E-01, 0.17288400E+00, -.39516900E+00, 0.30216200E+00, -.17220500E+01, 0.11218400E+01, 0.14015500E+00, 0.69377200E+00, 0.17074900E+01, -.10167600E+01, 0.31083100E+00, 0.19906400E+00, 0.40123200E+00, -.60794800E+00, 0.28743800E+01, 0.24848100E+01, -.11871600E+01, 0.16069300E+01, -.57564800E+00, -.72654400E+00, -.85622000E+00, -.18204700E+00, -.90815900E+00, -.67398500E+00, -.14319100E+01, 0.22185000E-01, -.28196200E+00, 0.52073700E+00, 0.13393800E+00, 0.95223400E+00, -.24873900E+00, -.49317300E+00, -.16691500E+01, -.14997100E+01, -.56892300E+00, 0.55481400E+01, -.18442900E+01, -.12405100E+01, 0.21299400E+00, -.35194400E+01, -.10166200E+01, -.24704100E+01, -.17109300E+01, -.13275500E+00, 0.11565500E+00, -.40719400E+00, 0.28040200E+00, 0.52963300E+00, -.29453200E+00, 0.28327400E+00, -.22637700E+00, 0.44541300E+01, -.23259400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12560000E+01, 0.56075400E-01, -.76603200E+00, -.21171700E+01, 0.11142800E+01, 0.11131000E+01, -.13822200E-01, 0.31050400E+00, 0.37737300E+00, -.10478500E+00, 0.10952100E+00, -.30869500E+00, 0.53872700E+00, -.34536500E+00, 0.26658300E+00, 0.33340100E+00, -.13335600E+01, 0.66120900E+00, 0.14244700E+01, 0.20549100E+00, -.68775800E+00, 0.19083500E+00, 0.33157900E+00, 0.65598200E-01, 0.31891800E-01, -.62868000E+00, -.92180100E-01, 0.36355600E-02, -.16092900E+00, -.43788600E+00, 0.41123900E+00, 0.89398100E+00, 0.58183700E+00, 0.11874700E+00, 0.70874800E+00, 0.73094000E-01, 0.19064700E+00, -.13043600E+00, -.38506400E-01, 0.92548400E-01, 0.12953500E+01, -.41515300E-01, 0.12987500E+00, -.58611700E-02, 0.60762400E+00, 0.38117000E+00, 0.18458400E+00, -.32029200E-01, 0.78417800E-02, -.49288800E-01, -.28179300E-01, 0.99250400E-01, 0.50401700E-01, -.61863200E-01, 0.80587200E-01, 0.10550100E+00, 0.18066500E+00, 0.38338700E+00, -.22800400E+00, 0.21340900E+00, -.10970200E-01, 0.30839800E+00, -.26119200E-01, 0.39540100E+00, 0.34463800E+00, 0.31445900E-01, 0.22849600E-01, -.88432500E-01, 0.12440000E+00, 0.11948500E+00, 0.47683800E-01, 0.38690200E-01, -.11911700E+00, 0.74870400E-01, 0.13545700E+00, 0.68883000E-01, -.38198300E-02, -.73015200E-01, -.13039600E+00, 0.20877000E+00, -.30968900E+00, -.34423700E-01, -.21018000E+00, 0.17669700E-01, -.15295700E+00, 0.95628700E-01, -.46356800E-01, 0.20123600E+00, -.70659800E+00, -.45668900E-01, 0.41616700E-01, -.48719600E-01, 0.22261900E+00, 0.17843500E-02, -.30028800E-01, 0.20643600E+00, 0.12398600E+00, 0.25460200E+00, 0.13684800E+00, -.43830600E+00, -.11060100E+00, -.14721900E+00, 0.40775700E+00, -.13233300E+00, 0.39534700E-01, 0.10724700E+00, -.18034200E+00, -.45259700E-01, -.64603700E-01, -.55054300E-01, 0.37959300E-01, 0.13395600E+00, -.18303300E+00, 0.98943200E-02, 0.21564300E+00, 0.17055700E+00, -.17621900E+00, 0.37639800E-01, 0.87453200E-02, 0.13659100E+00, 0.53160400E-02, 0.48291500E-01, -.50192800E-01, -.17453400E-01, -.52667900E-02, 0.41464700E-01, 0.60678000E-01, -.19385600E+00, -.28268400E+00, 0.65742500E-01, -.38149800E-03, -.90122700E-01, -.18906600E-01, -.65355800E-01, -.42820200E-01, 0.30405000E-01, 0.46952500E-01, -.39557500E-01, 0.10609100E-01, -.60327600E-01, 0.16823800E-01, -.68120500E-01, 0.22151600E-02, 0.23819300E-01, 0.12443400E-01, 0.20431900E-01, 0.10651900E-01, -.15143200E-01, -.86421300E-01, 0.52937800E-01, 0.12084200E-01, -.27161800E-01, 0.16859300E+00, -.19459000E-01, -.46775100E+00, -.77594800E-01, -.70586500E-01, 0.22970500E-02, -.14787900E-01, -.25383500E-01, -.22459200E-01, 0.17977000E+00, -.13903900E-01, -.19209900E-02, -.95315800E-01, -.20619700E-01, -.38766700E-01, -.15521200E-01, 0.12391100E-02, -.34634100E-02, 0.70362600E-01, -.21765700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.86100500E+01, 0.14195400E+00, 0.93336600E+01, 0.33219600E+02, -.20345800E+00, -.54355700E+01, -.12757400E+01, -.59021100E+01, -.60525800E+01, 0.90198300E+00, -.36093200E+01, 0.34666000E+01, -.52776100E+01, 0.12009100E+02, -.45882700E+01, 0.16176700E+01, -.93186400E+01, 0.46758500E+01, 0.10355900E+02, 0.63557200E+01, -.24981200E+01, 0.12093400E+00, 0.33393200E+01, -.70752300E+00, 0.36419600E+00, 0.14421100E+01, -.15533800E+02, -.58536700E+00, -.86052900E+00, -.88339000E+01, -.11997900E+01, -.34346900E+01, -.82914000E+01, 0.23473800E+01, 0.10499000E+01, 0.14981200E+01, -.38539900E+01, 0.20694200E+01, -.79727300E-01, -.10526400E+01, -.12423100E+02, 0.74106200E+00, -.43432000E+01, -.20042700E+01, -.33371900E+02, 0.30218700E+01, 0.16851200E+02, 0.98782600E+00, 0.13658000E+01, 0.31202900E+01, 0.57981800E+01, -.76760000E+01, 0.16314300E+01, -.26311900E+01, -.14975300E+01, -.31738700E+01, 0.69359000E+00, -.71896200E+01, 0.23430900E+01, 0.91351100E+00, -.22189900E+00, -.57186500E+01, 0.12529900E+01, 0.81865700E+01, -.73783300E+00, 0.16000700E+01, -.20442100E+01, 0.23839800E+01, -.10802800E+01, -.30525000E+01, 0.10494500E+01, -.21341600E+00, -.34310600E+01, -.12877600E+01, -.79427500E+00, -.30026900E+01, 0.15351300E+00, 0.22871600E+01, -.17047300E+01, -.45123200E+01, 0.32503500E+01, 0.77979200E+00, -.54493300E+01, 0.67469900E+00, -.17185700E+00, 0.22081700E+01, -.15573700E+00, 0.10311200E+00, -.10866100E+02, 0.71873600E+00, 0.23575400E+01, -.20874400E+01, -.51833700E+01, -.85126200E+00, 0.18181900E+00, -.47579300E+01, -.24759600E+01, -.25261900E+01, -.62205900E+01, 0.17722100E+01, -.10630000E+01, -.18130000E+01, -.14231900E+01, -.72312500E+00, -.15064300E+01, 0.51488600E+01, 0.16284100E+02, 0.23286500E+01, 0.13994500E+02, 0.21959400E+01, 0.72602400E+00, -.21918500E+01, 0.16006700E+01, -.98081300E-01, -.89534500E+00, -.30504800E+01, -.18608100E+01, -.15739000E+01, -.14530500E+01, 0.10214300E+01, 0.10475000E+01, -.68554200E+00, -.10491400E+00, 0.52108800E+00, -.10474700E+01, -.26973100E+00, 0.40697700E-01, -.32259300E-02, -.13265600E+01, -.18423000E+00, 0.12250500E+00, -.66888000E+00, -.10534700E+01, 0.23272800E+01, -.14780500E+01, -.14721000E+01, -.36786700E+00, -.18851500E+01, 0.14740400E+01, 0.82537000E+00, 0.11356100E-01, 0.90752700E+00, -.91706900E-01, 0.48341300E+00, -.14255800E+00, 0.48279200E+00, -.64240500E+00, 0.54457100E+00, -.14307800E+01, -.74213700E+00, 0.25501700E+00, 0.57963100E+00, -.43420900E+01, 0.83990900E+00, 0.38494500E-01, 0.30038500E+00, 0.30440200E+00, -.10014800E+00, 0.33112000E-01, -.39433500E+00, -.26786600E-01, 0.43687400E-02, 0.25576000E+01, 0.94651600E-01, 0.17111300E+01, -.35575200E+00, -.58541700E-01, 0.25279000E+00, 0.10777300E+00, 0.21497100E-01, -.94460600E-01, 0.20944300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.72546000E+00, 0.37768100E-01, -.87090800E+00, -.24187100E+01, -.13387100E+00, 0.21521600E+00, -.41886400E-01, 0.43478400E+00, 0.50083700E+00, -.52063700E-02, 0.35919400E+00, -.24757600E+00, -.28882700E-01, -.49682800E-01, 0.27268800E+00, 0.21449400E+00, -.80544400E+00, 0.13202900E+00, 0.24313700E-01, 0.31467500E+00, -.36101800E+00, 0.27846200E+00, -.12018500E+00, -.13339500E+00, -.14328700E+00, -.55125500E+00, -.99304100E-02, 0.10027000E-01, 0.59604200E-01, 0.36214200E+00, 0.52140200E+00, 0.37728200E+00, 0.45717100E+00, -.15227600E+00, 0.50626600E-01, -.76601500E-01, 0.35666600E+00, -.29637800E-01, -.61720300E-01, 0.55833500E-01, -.71100300E-01, 0.42772000E-01, 0.66840900E-01, -.51714300E-01, 0.15448600E+00, 0.30160000E+00, 0.22568100E+00, -.26457300E-03, 0.30411400E-01, -.63726200E-01, -.26109200E+00, -.50497800E+00, 0.10383500E+00, 0.29258700E-01, 0.33583200E-01, 0.18606800E+00, -.34947400E-01, -.10297700E+00, -.85443100E-02, -.15422600E-01, -.16325000E+00, 0.34493300E-01, 0.16955300E+00, -.13420400E-01, 0.12171600E+00, 0.61819100E-01, -.11579400E+00, 0.22220700E+00, 0.12066600E-01, -.18818800E+00, 0.31269000E+00, -.39945000E-01, -.44933100E-01, 0.16512200E-01, -.12287400E+00, 0.17210700E-02, -.56877700E-01, -.61290400E-01, -.14155400E-01, 0.22512900E+00, -.35548200E-01, -.75283500E-01, -.47793200E-01, 0.35538800E-02, -.26117800E-01, 0.12684000E+00, -.20831900E-01, 0.10661100E+00, -.52658600E+00, -.70749200E-01, -.18436900E+00, 0.14258600E-01, -.14309600E+00, -.25337300E-01, -.15828600E-01, 0.35916500E-01, 0.34324400E-01, -.10024500E+00, 0.13257200E+00, 0.10016300E-01, 0.63150000E-01, 0.18356500E-02, 0.16898000E-01, -.46339900E-01, 0.51090200E-01, 0.14441200E+00, 0.16203900E+00, 0.54874700E-01, 0.19314500E+00, 0.32711000E-02, -.49912900E-01, 0.66290500E-01, -.12678900E+00, 0.62147500E-01, 0.48950800E-01, -.39418200E-01, -.14542500E-01, -.17125200E-01, -.13565700E+00, 0.17614000E-01, -.42430600E-01, -.22240200E-01, 0.16915200E-01, 0.61145300E-01, 0.43669000E-02, -.52852500E-02, 0.25080300E-01, -.34983000E-01, -.36207700E-01, 0.37724200E-01, 0.11818200E-02, -.92278400E-01, 0.86153400E-02, 0.27418600E-01, -.87616300E-02, 0.21954800E-01, 0.32054500E-02, 0.41580900E-01, -.25598000E-01, -.10272700E-01, -.19278300E-02, 0.77963200E-03, -.85947600E-02, -.10501100E-01, -.70016600E-03, -.44296300E-02, -.28295300E-02, 0.12258800E-01, -.58172000E-02, -.53228000E-02, 0.72607100E-03, -.67133300E-03, 0.20214000E+00, -.41207600E-01, 0.14003800E+00, -.75341300E-01, 0.12450400E+00, 0.50459000E-01, -.25286200E+00, -.72393600E-02, 0.58470100E-02, 0.13539100E-01, 0.24751200E-03, 0.46271500E-01, -.25783000E-03, -.24884100E-02, -.14069700E-02, 0.57256500E-02, 0.58646400E-02, 0.61143400E-02, -.53731200E-02, 0.21049500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10671100E+02, 0.22106300E+00, 0.12911600E+02, 0.35090000E+02, -.12357100E+01, -.85280000E+01, -.12447100E+01, -.68851500E+01, -.73776200E+01, 0.66230700E+00, -.24111700E+01, 0.49577100E+01, -.44399900E+01, 0.67017400E+01, -.39960500E+01, 0.95955400E+00, 0.16743900E+01, 0.14809500E+01, -.27102900E+01, 0.22824000E+01, -.59093800E-01, -.70872500E+00, 0.25788000E+01, 0.17074700E+01, -.66083200E-01, -.25509200E+01, -.45816000E-01, 0.22058300E+00, 0.34149600E-01, 0.12664100E+01, 0.31004700E+01, -.13827500E+01, -.36187200E+01, -.72407400E+00, -.23731000E+01, -.18317200E+00, 0.41876500E+00, 0.44025500E+00, -.80954300E+00, 0.76890100E+00, -.75126100E+01, 0.70960900E+00, -.25552600E+00, 0.24427500E+00, -.17412600E+00, -.68871100E+01, 0.40863700E+01, -.23233100E+00, -.61075100E+00, 0.82621500E+00, 0.37381300E+01, 0.66033200E+01, -.19197300E+01, 0.10844000E+01, -.45601100E+00, -.34127900E+01, -.91262700E+00, -.19714900E+01, 0.14534900E+01, 0.11874600E+01, 0.16178800E+00, -.28599900E+01, -.10603200E+01, 0.11887400E+01, -.16516100E+01, -.12431600E+01, 0.12717200E+01, -.32450900E+01, -.24089800E+01, 0.26610800E+01, -.47983500E+01, 0.30139900E-01, -.20656000E+01, -.98114300E+00, 0.20178100E+00, -.11272300E+01, 0.18664800E+01, 0.19733100E+01, -.42207900E+00, -.75010800E+01, -.24185100E+01, 0.11736100E+01, 0.25942500E+01, -.65117000E+00, -.19053600E+01, 0.59088800E+00, -.12917300E+01, -.98533400E+00, 0.73254800E+01, 0.32628000E+00, -.22807900E+01, 0.40047800E+00, 0.15540000E+01, 0.41573600E-01, -.23369300E+01, -.32380700E+00, 0.23114000E+00, 0.24297300E+01, -.15840100E+01, -.25624800E+01, -.32543000E+00, -.10227600E+00, 0.11078200E+01, 0.29633300E+00, 0.99049400E+00, -.11232700E+01, -.21754600E+01, -.30791000E+00, 0.44224500E+00, 0.27022900E+00, -.18606200E+00, 0.68293900E-01, -.12053700E+01, 0.69149800E+00, 0.19288300E+01, -.12516600E+01, -.66682300E+00, 0.80692400E+00, -.11664700E+01, 0.84804900E-01, 0.15441700E+00, -.19522500E+01, -.10175900E+00, 0.11095300E+01, -.27921600E+00, 0.35920800E+00, 0.87038200E+00, -.14806000E+01, -.18753000E+01, 0.64816700E+00, 0.19607100E+00, -.10087600E+01, -.25049400E+00, 0.87663600E+00, -.93514500E+00, -.53918300E+00, -.25290500E-01, -.62036100E+00, 0.43177700E+00, -.26441500E+00, 0.18091200E+00, -.94918000E-01, 0.12669000E+00, -.96956800E-01, -.28005600E-01, 0.12556900E+00, -.64375300E-01, 0.70935600E-01, -.50987300E+00, -.33247600E-01, 0.87698400E-01, 0.87854400E-01, 0.17156300E+01, -.36914700E+00, -.15207400E+01, -.14816100E+01, 0.47943200E+00, 0.50843900E-01, -.41197900E+00, 0.62791900E+00, 0.80638700E-01, -.13209400E+01, 0.22389300E+00, -.31610100E+01, -.55028900E+01, -.88024500E-02, -.82110900E+00, -.10274400E+01, 0.33091800E+00, 0.17224100E+00, 0.32606200E+00, -.64985200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13585400E+01, 0.27572100E-01, 0.33321800E+01, 0.50841500E+01, -.87738800E+00, -.15410300E+01, -.55609900E-02, -.76163500E+00, -.81343300E+00, 0.19671200E+00, -.13371500E+01, 0.66935000E+00, -.34829100E+00, 0.22173100E+00, -.84100300E+00, 0.18917900E+00, 0.10195600E+01, -.28693500E+00, -.13168800E+01, 0.37315300E-01, 0.78659000E+00, -.56351100E+00, 0.75368800E-01, -.30252200E+00, 0.29002700E+00, 0.12570000E+01, -.16123900E-01, -.93647200E-01, 0.14092700E+00, -.10200100E+00, -.47118600E+01, -.12853600E+01, -.11830800E+01, 0.42163500E+00, -.19896000E+00, -.40566700E+00, -.19761600E+01, 0.45869800E-01, 0.19083600E+00, -.27639100E+00, 0.12542800E+00, -.78603200E-01, -.78478100E+00, 0.69012100E+00, -.19096400E+01, -.94409800E-01, 0.73166300E+00, 0.13516700E-01, -.17633300E+00, -.53233600E+00, -.45466100E+00, 0.17934200E+00, 0.67287200E-01, -.25132800E+00, -.12421800E-01, -.53133400E+00, -.85402300E+00, 0.14409700E-01, 0.27100600E+00, 0.40726700E+00, -.41133400E+00, -.39003600E+00, 0.23489900E+00, -.11427100E+01, 0.10699800E+00, -.21150900E+00, 0.14580600E+00, 0.35386300E+00, -.13984700E-02, 0.21437100E+00, 0.26428800E+00, -.99734500E-01, -.24634300E+00, -.17482800E-01, 0.40086800E-01, 0.27131000E+00, -.12058500E-01, 0.10020300E+00, -.29919100E+00, -.21631100E+00, 0.12117300E+00, -.22126000E+00, -.91186600E-01, 0.13051300E+00, 0.13660400E+00, -.16053400E+00, 0.24076800E-02, 0.25275900E+00, -.45060800E+00, 0.22105800E+00, 0.53166900E-01, -.23192900E+00, -.51918300E+00, 0.71220800E-01, -.37854300E+00, -.78661600E+00, 0.34291400E+00, 0.50625000E+00, -.16742800E+01, -.69244400E+00, -.93581200E-01, -.68001400E-01, 0.16200300E+00, 0.39599600E+00, -.45583800E+00, 0.14830500E+01, -.25566700E+01, -.51504800E-01, 0.60266200E+00, -.46193900E-02, 0.27929000E+00, 0.19653000E+00, -.14966600E+00, 0.21477600E+00, 0.56587700E+00, -.23907200E+00, 0.83035700E-01, 0.45203400E+00, -.61187900E+00, 0.21942000E+00, -.15118700E+00, -.73010100E+00, -.19981900E-01, 0.30005900E+00, -.16432600E+00, 0.24553800E+00, 0.15706700E+00, 0.39303800E+00, 0.87776000E-01, 0.36918800E-01, 0.57575600E-01, 0.40143200E+00, -.61263700E-01, -.62030700E-01, -.39491900E-02, -.31710300E+00, 0.11676600E+00, -.76802700E-01, 0.13851100E+00, -.66395500E-01, -.65474200E-01, 0.49471600E-01, 0.62427100E-01, -.62225700E-01, 0.24042000E-01, 0.39574800E-02, -.51678100E-01, 0.90824300E-01, -.31608900E+00, 0.29360500E-01, 0.29605700E-01, 0.10215400E+00, 0.18657600E+00, 0.28169000E-02, -.39826000E+00, -.23041200E+00, -.24894200E+00, -.22383500E-01, 0.13062600E+00, 0.47280600E-01, -.10100400E-01, 0.77629500E-01, 0.25293700E-01, -.11917800E+00, -.12052700E-02, 0.28089200E+00, -.15392800E+00, -.10344700E-01, -.23385700E-01, 0.16761400E-02, 0.34520500E-01, -.52619200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.13627700E+02, -.29418600E+00, -.16361300E+02, -.36543700E+02, 0.45068800E+01, 0.11186600E+02, 0.99503300E+00, 0.16768700E+01, 0.65976100E+01, -.11726300E+01, 0.54523700E+01, -.84370900E+01, 0.39878400E+01, -.92436700E+01, 0.53955100E+01, 0.68608400E+00, -.92392400E+00, 0.39823800E+00, -.11794600E+02, -.47323000E+01, -.27103300E+01, 0.41497000E+00, -.43936800E+01, -.26653500E+01, -.16854200E+00, 0.27885700E+01, -.28093000E+01, -.69804300E+00, -.14345600E+01, -.14416800E+01, -.27029700E+01, 0.36977700E+01, 0.82721700E+01, 0.11872000E+01, 0.34496200E+01, 0.69018200E-01, 0.31772500E+01, -.64031800E+00, 0.17015900E+01, -.12414100E+01, 0.19511400E+02, -.12384900E+01, -.38455700E+00, 0.25079300E+01, 0.35075200E+01, 0.11178300E+02, 0.15616000E+02, 0.70602800E+00, 0.28116500E-01, -.34549900E+01, -.11307100E+02, -.53361000E+01, -.12425100E+01, -.77241500E+00, 0.10379700E+01, 0.21183600E+01, 0.10013600E+01, 0.20058000E+01, -.37129900E+01, 0.31725000E+00, 0.20031700E+00, 0.62376900E+01, 0.18730700E+01, -.28394500E+01, -.27356400E+00, 0.89871800E+00, -.14296200E+01, 0.39745100E+01, -.65361900E+00, -.24544000E+01, 0.59237400E+01, -.29994400E+00, 0.63898700E+01, 0.11377700E+01, 0.56601600E+00, 0.29266600E+01, -.14208400E+01, -.22995900E+01, 0.32102400E+01, 0.45719400E+01, 0.30972200E+00, -.47955500E+01, 0.24136500E+01, -.48929500E+00, 0.15254800E+01, -.30036900E+01, 0.28356400E+00, -.19425900E+00, 0.23403600E+01, -.27111100E+01, -.30918500E+01, -.10578000E+01, -.52001200E+01, -.40855100E+00, -.68141600E+00, -.16588800E+01, -.21130800E+01, -.30749300E+01, -.43723700E+01, 0.50206500E+01, -.21121200E+00, 0.46134000E-01, -.91685400E+01, 0.37686700E+00, -.34458700E+01, -.90345500E+01, -.75306200E+01, -.53661200E+00, -.72694800E+01, -.46702700E+00, 0.10666900E+01, 0.32725100E+01, 0.42140100E+01, -.28797900E+01, -.46128700E+01, 0.46375500E+00, 0.63727100E+01, -.16210600E+01, 0.97315900E+00, -.63630900E+01, 0.72961000E+00, 0.12827600E+00, 0.96076000E+00, 0.15329100E+01, 0.15703600E+01, -.56916200E+00, -.31862100E+01, -.16422300E+01, -.68671800E+00, -.11671700E+01, -.74402700E+00, -.14507900E+01, 0.39484400E+00, -.16530600E+01, -.27291900E+01, 0.26890600E+01, -.74860000E+00, -.27721200E+01, 0.16705300E+01, 0.91986600E+00, -.54847400E+00, 0.32735300E-01, -.57478500E+00, -.11589400E+00, 0.48642400E+00, -.40680800E+00, 0.93099400E+00, -.86525100E+00, 0.52464300E+01, 0.95094500E+00, -.10060200E+01, -.37747000E+01, -.47715700E+01, 0.32221300E-01, -.10047500E+02, 0.19158600E+01, 0.40556200E+01, 0.20375000E+00, -.19322300E+01, 0.14294500E+01, -.56406500E-01, -.47330800E+01, -.11055400E+00, -.40782100E+01, 0.21265100E+00, 0.86347400E+01, 0.44144900E+01, -.17797100E+00, -.35472900E+00, -.67619700E-01, -.28127200E+00, -.37404900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.65461200E+00, 0.11595600E+00, 0.14505300E+01, 0.56603000E+01, 0.37209700E+00, -.28651600E+00, -.83091200E-01, -.61677600E+00, -.63747900E+00, 0.20325200E+00, -.47656300E+00, 0.73803600E+00, -.12641700E+00, 0.33209100E+00, -.37744000E+00, -.18373200E+00, 0.45887500E+00, -.13900900E+00, -.30331300E+00, -.14047200E+00, 0.73885500E-02, 0.12276100E-01, 0.15126100E+00, 0.13321400E+00, -.76297100E-02, 0.13055400E+00, -.15076600E+00, -.46181900E-02, 0.46235200E-01, -.27039900E+00, -.39117000E+00, -.40605900E+00, -.81595200E+00, 0.89652600E-01, -.38769900E+00, -.23240400E-01, -.49627800E-01, 0.52357700E-01, -.39096400E-01, -.39082000E-01, -.58327200E+00, -.21060200E-01, -.14232100E+00, -.64546600E-01, -.12638400E+01, -.15820000E+00, 0.10154200E-01, -.14136800E-02, 0.23818700E-01, 0.14864600E+00, 0.29748400E+00, 0.62578200E-01, 0.68315700E-01, -.18691700E+00, -.45979200E-01, -.15330100E+00, -.72253700E-01, -.73681500E-01, 0.12307700E+00, -.15168600E-01, 0.20680300E-01, -.15253000E+00, 0.76275800E-01, -.23281300E+00, -.10460200E+00, -.18656100E-01, 0.43251600E-01, -.13629900E+00, 0.10528500E-01, 0.17561100E+00, -.18211700E+00, 0.11008900E-01, -.79274200E-01, -.48161200E-01, 0.10174400E+00, 0.44643100E-01, -.35438200E-01, 0.57009200E-01, -.26187400E-01, -.18122100E+00, -.45992600E-01, 0.97129300E-01, 0.56812400E-01, 0.24041300E-01, 0.19060500E-01, -.70401200E-02, 0.20772800E-01, -.59499300E-01, 0.16417700E+00, 0.92529600E-01, 0.12501800E+00, -.62137600E-01, 0.12319800E-01, 0.15017500E-01, 0.46684100E-02, -.97770400E-01, -.51561800E-01, 0.13252300E+00, -.15228500E+00, -.40657600E-01, -.86063200E-01, -.50137500E-01, 0.88333000E-01, 0.15241300E-01, -.54667200E-01, 0.13046100E+00, 0.14625700E+00, -.39793400E-02, 0.15014800E+00, 0.36479600E-01, 0.30607900E-01, -.82125100E-01, 0.94648400E-01, 0.42925600E-01, -.50692800E-01, -.18195500E+00, 0.56716500E-01, -.15777700E-01, 0.10673200E-01, -.41664900E-01, 0.23039300E-01, -.95441000E-01, 0.15060400E-01, 0.14068300E-01, -.24937800E-01, -.21700800E-01, 0.55257500E-03, 0.48373600E-01, 0.40441700E-01, -.15294900E-01, 0.53225300E-02, 0.59313900E-01, -.47482200E-01, 0.13990700E+00, 0.53307500E-01, -.87017000E-01, 0.33017000E-01, 0.10541900E-01, 0.90761000E-02, 0.24289800E-02, 0.10179400E-01, 0.97290200E-02, -.45886000E-02, -.20059200E-01, -.15124000E-01, 0.46042600E-02, -.20327000E-01, 0.38747800E-01, 0.19611300E-01, -.34908500E-01, -.68820500E-02, -.14517300E-01, -.15161500E+00, 0.24235200E-01, -.35216600E-01, -.25051800E-02, -.12221500E+00, -.23396100E-01, 0.98290300E-01, -.14255700E-01, 0.94383900E-02, 0.26360300E-01, 0.57249000E-02, 0.66190700E-01, 0.12072500E-01, -.38027500E-01, -.32284600E-02, 0.88868200E-01, 0.10759700E-01, 0.97962200E-02, -.99264300E-02, -.43920400E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.58410200E+00, 0.14940300E+00, 0.96427700E+00, 0.22855200E+01, -.61668500E+00, -.21890100E+00, -.39986700E+00, -.46896900E+00, -.24177900E+00, 0.24053200E+00, -.29141700E+00, 0.74018300E+00, -.22804000E+00, 0.33491200E-01, -.37263800E+00, -.17681900E+00, 0.10901100E+01, -.61887900E+00, -.14504300E+01, -.56664900E+00, 0.41043700E+00, -.84840100E-01, -.22149200E+00, 0.20770100E-01, -.48434900E-01, 0.28180700E+00, 0.68305800E+00, 0.10513900E-01, 0.58146300E-01, 0.64518900E+00, 0.12947000E+00, -.59776900E+00, -.27523700E+00, -.29623200E+00, -.91414300E+00, -.17917800E+00, 0.42784200E-01, 0.62320100E-01, -.10736600E+00, -.62053100E-03, -.11161600E+01, 0.39493400E-01, -.11130300E+00, -.24159900E+00, -.24609900E+01, -.11454100E+00, -.18709700E+01, 0.36106900E-01, -.27728900E-01, 0.84836200E-01, 0.21142800E+00, -.91309700E-01, 0.14059400E+00, -.32670800E+00, -.45145000E-01, -.32770900E-01, -.16113800E+00, -.23022800E+00, 0.11227300E+00, -.11449400E+00, -.40773800E-01, -.12806200E+00, 0.20605100E+00, -.29471200E+00, -.53175000E-01, -.32018400E-01, -.10216500E-02, 0.27799700E+00, 0.57062200E-01, 0.19505700E+00, -.28329900E+00, -.10226400E+00, -.30024300E-01, -.98463100E-01, 0.14468300E+00, 0.17721700E+00, 0.32322700E-02, 0.39411000E-01, -.11359900E-01, -.36644200E+00, -.43361100E-01, 0.74445700E-01, 0.10683600E+00, -.36521900E-02, -.99956400E-03, -.40799200E-01, -.16326000E-02, -.11116400E+00, 0.43150500E+00, 0.61603500E-01, 0.24259700E+00, -.64564400E-01, 0.15461400E-01, -.23422400E-02, -.25473300E-01, -.12366700E+00, -.12419000E+00, 0.11387300E+00, -.45591100E+00, -.43992100E-01, 0.68918800E-01, -.93151400E-02, -.31139100E+00, 0.52951500E-01, -.47927300E-01, -.29336300E+00, -.93204600E-02, 0.39542400E-01, -.11634800E+00, 0.99419500E-02, 0.35831400E-01, -.18598100E-01, 0.42735800E-01, -.40991300E-01, -.79011500E-01, 0.17072300E-01, 0.10822100E+00, 0.95728500E-02, -.56228900E-01, -.52674600E-01, -.21547500E-01, -.19374700E-01, 0.19540500E-01, -.12212400E-01, -.24494400E-01, -.52655000E-01, -.79502700E-01, -.35480400E-01, 0.53436900E-01, -.54030800E-02, -.11123800E-01, -.62792200E-01, -.24559300E-01, 0.25945300E-01, -.28684800E-02, 0.47510700E-01, 0.24509800E-01, 0.13763000E+00, -.53730400E-01, 0.32445300E-02, 0.28354200E-02, 0.52429900E-01, -.79995400E-02, -.70150700E-01, -.70928100E-02, -.24100500E-01, -.26626300E-01, 0.54322900E-01, 0.49956000E-01, -.17304000E-01, -.76647100E-02, 0.34378000E-04, 0.26178500E-01, -.60982000E-02, -.10233300E-02, 0.24656500E-01, 0.70086600E-01, 0.63563200E-02, -.65981500E-02, 0.75038000E-01, 0.58956500E-02, -.26863600E-01, -.43929700E-02, 0.12549000E+00, -.38393200E-02, -.56520600E-01, -.40629800E-02, 0.12475900E+00, 0.11124400E+00, 0.25596800E-01, -.17945000E-01, -.16775300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.98831400E+00, 0.14517600E+00, 0.15254400E+01, 0.49543000E+01, 0.55533700E+00, -.62023200E-01, -.21919800E+00, -.95762600E+00, -.10088600E+01, 0.25912900E+00, -.75932700E+00, 0.10713100E+01, -.20281400E+00, 0.64817900E+00, -.69070700E+00, -.28231800E+00, 0.12669200E+01, -.58799100E+00, -.83702800E+00, -.21358500E+00, 0.53640200E+00, -.22949900E+00, 0.36949900E+00, 0.23447400E+00, 0.12367200E+00, 0.38462000E+00, 0.17813800E+00, 0.82426000E-03, 0.54474500E-01, -.20140100E+00, -.80872300E+00, -.80067900E+00, -.11093400E+01, 0.36192900E-01, -.64272900E+00, -.84598500E-01, -.27166300E+00, 0.39104700E-01, -.11871300E+00, 0.11134700E-01, -.83529300E+00, 0.17621100E-01, -.22264100E+00, -.83651900E-01, -.18264700E+01, -.55598400E-01, 0.60494000E+00, 0.71753700E-01, 0.14613200E+00, 0.52278400E+00, 0.47965500E+00, -.85381300E+00, 0.52632200E-01, -.62287700E+00, -.15612900E+00, -.75755000E+00, -.39889800E+00, -.24767300E+00, 0.24635600E+00, 0.17842500E+00, 0.34400300E+00, -.20872500E+00, -.93868300E-01, 0.70499300E-01, -.33618900E+00, -.13843400E+00, 0.18695900E+00, -.40629900E+00, -.66543200E-01, 0.25788900E+00, -.35336900E+00, 0.81817300E-03, 0.14489000E-01, -.16067300E+00, -.65808200E-02, 0.10658700E+00, -.16503400E+00, 0.84290300E-01, -.12617200E+00, -.21570000E+00, -.46555800E+00, 0.84898700E-01, 0.23534500E+00, 0.13039500E-01, -.29304700E-01, 0.11736400E-01, -.73049500E-02, -.19936200E+00, 0.79641500E+00, 0.77694300E-01, 0.12401200E+00, -.13052300E+00, 0.74753300E-01, 0.45904500E-01, -.24269800E-01, -.53621700E-01, -.23389100E+00, 0.28089100E+00, -.29959700E+00, 0.96873100E-01, -.40837400E-01, -.82748800E-01, -.17160200E+00, 0.43281000E-01, -.11765500E+00, -.26817000E+00, -.15929900E+00, -.26406300E-01, -.16039300E-01, 0.25741500E-01, 0.99368200E-01, -.60181500E-01, 0.28922900E+00, -.98919700E-01, -.25911700E+00, 0.14362100E+00, 0.73585600E-01, -.71206900E-01, 0.19161100E+00, -.62180000E-02, 0.51959700E-01, 0.16517200E+00, 0.18756300E-01, -.13012500E-01, -.56913900E-02, 0.56093200E-02, -.85991700E-01, 0.93056100E-02, 0.16739600E+00, -.56198400E-01, -.62459900E-02, 0.27492100E+00, -.99201400E-02, -.18452100E-01, 0.11966500E-01, 0.61299000E-01, -.20498300E-01, -.92379100E-01, 0.76822000E-01, 0.37935300E-01, -.67777100E-03, 0.10350400E-01, 0.96627500E-02, 0.85335600E-02, -.33763300E-02, 0.34965500E-02, -.50915700E-02, -.33900300E-02, 0.51303600E-01, -.12921900E-01, -.50904300E-02, -.16255300E-01, -.26208800E+00, 0.52012400E-01, -.18871000E+00, 0.94464100E-01, -.20242200E+00, -.51896900E-01, 0.30928800E+00, -.67205800E-03, -.76373900E-02, -.41323400E-01, -.21191600E-03, 0.13069800E+00, -.28113300E-02, 0.47473400E-02, 0.73776200E-03, 0.88944800E-01, 0.21793800E+00, 0.10005100E+00, 0.94198200E-02, -.21670000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11840900E+01, -.11018800E-01, -.57415300E+00, -.21255200E+01, 0.53100800E+00, 0.24438200E+00, 0.12944300E+00, 0.31504200E+00, 0.29335200E+00, -.82455100E-01, 0.11703400E+00, -.31477100E+00, 0.33427400E+00, -.24763800E+00, 0.32825000E+00, -.66508600E-01, -.64550600E+00, 0.21630800E+00, 0.16557000E+00, 0.51233300E-01, 0.29262400E+00, -.13856700E+00, -.47306900E+00, -.33565100E+00, -.46789800E-01, -.12812600E+00, 0.31163300E-01, -.88712800E-02, -.81352000E-01, 0.78165800E-02, -.19331900E+00, 0.61312700E+00, 0.58532000E+00, -.44783000E-04, 0.45571900E+00, -.10064600E+00, -.16718100E+00, -.75184700E-01, 0.28352200E-01, -.56317500E-01, 0.69561100E+00, 0.37108000E-01, 0.38624100E-03, 0.14121400E+00, 0.57149500E+00, 0.28619300E+00, 0.81819500E+00, -.19555700E-01, -.26994200E-01, -.11088100E+00, -.13074300E-01, -.27915700E+00, 0.41929600E-01, 0.19137000E+00, 0.73158000E-01, 0.37531200E-01, 0.75699500E-01, 0.13806400E+00, -.18269700E-01, 0.10929700E+00, 0.38259900E-01, 0.57987000E-01, 0.71264800E-01, 0.18308200E+00, 0.12447000E+00, -.87052000E-01, 0.99671600E-01, -.17962300E+00, -.18675100E+00, -.32520000E-01, -.93510200E-01, 0.33418700E-02, -.14123400E-01, 0.36257900E-01, -.16236800E+00, -.62735800E-01, 0.44689100E-01, -.23398100E-01, -.50678700E-01, 0.17722900E+00, -.26272600E+00, -.78392300E-01, -.10185600E-01, 0.16789500E-01, -.14845900E+00, -.64006500E-01, -.28193800E-01, 0.60342000E-01, 0.19301100E+00, -.49003600E-01, -.30624500E+00, 0.14092200E+00, 0.20997900E-01, -.66508400E-02, -.12521200E-02, 0.13136800E+00, 0.21279900E+00, -.93023400E-02, 0.21821000E+00, -.15534200E+00, -.92771000E-01, 0.40765500E-01, 0.31238400E+00, -.90669000E-01, -.80024800E-01, 0.42141600E+00, -.55028000E+00, 0.33388100E-01, 0.18363200E+00, 0.46010600E-01, -.10694500E+00, -.44733600E-01, -.10946600E+00, 0.11051300E+00, 0.30023400E+00, -.12363300E+00, -.11461100E+00, 0.69985100E-01, -.14391500E+00, -.34227700E-01, -.18803100E-01, -.23348700E+00, -.45824400E-01, 0.11649800E+00, -.73796600E-02, 0.38916100E-01, 0.45089400E-02, -.16293900E+00, -.14048300E+00, 0.26748900E-01, -.69361600E-02, -.13330200E-01, 0.18293400E-01, -.22210900E+00, -.19423600E+00, 0.22406900E-01, -.61790900E-01, 0.58621000E-01, 0.64638000E-01, 0.17491000E-01, -.30344000E-02, 0.45674700E-01, -.11070600E-01, -.64797500E-02, 0.75219000E-02, 0.72035700E-05, -.65531500E-02, 0.77643400E-02, -.37286300E-01, 0.18455300E-01, 0.13845400E-01, 0.45845900E-01, 0.17774300E+00, -.94021100E-02, -.26537900E+00, -.12396000E-01, 0.68778800E-01, 0.78595000E-02, 0.14561300E-01, 0.14267100E+00, -.51245300E-01, -.12384800E+00, -.17599000E-02, 0.29559600E-02, 0.14949000E-01, -.13998200E-01, -.32254200E-02, -.13083500E+00, 0.61396200E-02, -.60269000E-01, 0.16496400E+00, -.79288800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.48701100E+01, -.97515300E-01, -.63529100E+01, -.12549200E+02, 0.83980100E+00, 0.79786900E+00, -.52446800E+00, 0.15427800E-01, 0.11316800E+01, -.93399900E-01, 0.96419500E+00, -.15370400E+00, 0.11918900E+01, -.71129400E+00, 0.15624800E+01, 0.30767900E+00, -.39496100E+01, 0.19992500E+01, 0.21872100E+01, 0.13918300E+00, -.27788700E+01, 0.16813300E+01, -.10872400E+01, -.42196000E+00, -.69618600E+00, -.22779900E+01, -.35058700E+01, -.11278800E+00, -.13648700E+00, -.12628300E+01, 0.17039600E+00, 0.16725700E+01, 0.30293400E+01, -.89351200E-01, 0.83370500E+00, -.43316100E+00, 0.12858600E+01, -.33325500E+00, 0.27020900E+00, -.23260700E+00, 0.50552100E+01, -.61620200E-01, -.14104700E-02, 0.41551900E+00, -.10860500E+01, 0.42831900E+01, 0.13143600E+02, 0.41441000E+00, 0.60399200E+00, 0.29302200E+00, -.30210700E+01, -.64479400E+01, -.92999400E-01, -.16830000E+01, -.31145000E-01, -.20757100E+01, -.13687900E+01, 0.90796900E+00, -.25132500E+00, 0.12794000E+01, 0.85139500E+00, 0.77178200E+00, 0.70968100E+00, -.10512300E+01, 0.37665500E+00, -.20536100E+00, 0.45952700E+00, 0.30199100E+00, -.66515800E+00, -.66268400E-01, 0.64183200E+00, 0.74000800E-01, 0.91518400E+00, 0.16689700E+00, 0.67580300E+00, 0.68743900E+00, -.32666900E+00, -.26401700E+00, 0.61763300E+00, 0.92168600E+00, -.32457000E+00, -.94732100E+00, 0.42444100E+00, -.50800700E-01, -.16046700E+00, 0.40875200E+00, -.72573300E-01, -.38498700E+00, 0.16561500E+00, -.88889100E+00, -.23732200E+01, 0.44603400E+00, -.38383200E+00, 0.81886000E-02, -.31757900E+00, 0.84521700E+00, 0.19302400E+00, 0.32430800E+00, 0.22844200E+01, 0.18759100E+01, 0.44591800E+00, -.46241900E-01, 0.27273700E+00, 0.23120200E+00, -.42742100E+00, 0.13164500E+01, -.19126500E+01, -.42043000E+00, -.73400700E+00, 0.15455800E-01, -.41734600E+00, 0.62754000E+00, 0.58129600E+00, -.24272800E+00, -.39667900E+00, 0.16909800E+00, 0.53643400E+00, -.56899300E+00, 0.38306300E+00, -.34149200E+00, 0.12596600E+00, -.53655200E+00, 0.11082100E+00, 0.61300200E+00, -.34389500E-01, 0.23592900E+00, -.43424000E+00, 0.95744700E-01, 0.66195500E-01, -.32456300E+00, -.19013800E+00, 0.85574800E+00, 0.11165300E+00, -.28868600E+01, -.16965900E+01, 0.10087800E+01, -.49889400E+00, -.37562700E+00, 0.12040300E+01, 0.37428000E+00, -.13103500E+00, -.44328200E-01, -.18475600E+00, -.16685700E+00, 0.28342800E+00, -.12686100E+00, 0.13761300E+00, -.19932200E+00, 0.60192800E+00, 0.92419400E-01, 0.13820500E+00, 0.72801300E-01, -.51983100E+00, 0.22072300E+00, 0.34798400E+01, 0.30218600E+00, -.13109300E+01, -.25148900E-01, -.10774400E-01, -.11301400E+01, 0.76950600E-01, 0.56442200E+00, 0.20647400E-01, 0.13801700E+00, -.47904200E-01, 0.25267800E+01, 0.29451100E+00, 0.10261200E+01, 0.14109000E+00, -.59448900E+00, 0.44852100E+00, 0.23161000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 } },
        { { 0.26563500E+06, -.13694300E+06, -.51522400E+05, -.65846600E+05, -.14534100E+05, 0.10559200E+06, 0.14963700E+05, -.62398800E+05, -.20876400E+06, 0.10642000E+06, 0.43983500E+05, 0.57906000E+05, 0.76855300E+04, -.87746100E+05, -.20254100E+05, 0.56006400E+05, -.15028700E+06, 0.83570000E+05, 0.28719900E+05, 0.36484800E+05, 0.70989400E+04, -.57814000E+05, -.23379800E+04, 0.33622400E+05, -.13326400E+06, 0.58527300E+05, 0.29799200E+05, 0.37247700E+05, 0.50818700E+02, -.54133300E+05, -.79194500E+04, 0.36368500E+05, -.89748300E+05, 0.37386000E+05, 0.20457800E+05, 0.25488700E+05, 0.60589800E+03, -.36908400E+05, -.65634400E+04, 0.25428000E+05, -.11602200E+06, 0.59569100E+05, 0.28219200E+05, 0.35873000E+05, -.34553300E+04, -.47887900E+05, -.88256200E+04, 0.34285800E+05, -.14868300E+06, 0.72912900E+05, 0.29102100E+05, 0.38127100E+05, 0.82379400E+04, -.62287900E+05, -.15737000E+05, 0.36658900E+05, 0.97696100E+05, -.49248500E+05, -.20863600E+05, -.27537400E+05, -.28952800E+04, 0.41676200E+05, 0.11604100E+05, -.26439100E+05, 0.16303000E+06, -.87386200E+05, -.35889300E+05, -.46315600E+05, -.51789000E+04, 0.67635700E+05, 0.14103200E+05, -.45009500E+05, -.11312400E+06, 0.58313400E+05, 0.21849500E+05, 0.28761400E+05, 0.63822600E+04, -.46942000E+05, -.85244100E+04, 0.27303600E+05, -.53179100E+05, -.79484200E+04, -.13362200E+05, -.31806100E+05, -.32325900E+05, 0.22199200E+05, 0.37318500E+05, 0.18811900E+05, 0.30881900E+05, 0.54737200E+04, 0.39289600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11184500E+00, 0.19401200E+05, 0.17959000E+05, 0.24173500E+05, -.24296700E+05, -.23138800E+05, -.43759200E+05, 0.24297100E+05, 0.39733300E+02, -.22129500E+05, -.20340800E+05, -.27897500E+05, 0.26434700E+05, 0.22266100E+05, 0.47093200E+05, -.28462100E+05, -.29680000E+05, -.59196100E+03, -.79336700E+04, -.10802700E+05, 0.19521800E+05, 0.29760600E+04, 0.27513700E+05, -.11418600E+05, 0.27159100E+05, -.17288000E+05, -.98535100E+04, -.12955900E+05, 0.63066100E+04, 0.18941500E+05, 0.18641100E+05, -.12689200E+05, 0.22183300E+05, -.14743000E+05, -.69510700E+04, -.91850100E+04, 0.35524700E+04, 0.14284600E+05, 0.12874000E+05, -.89932500E+04, 0.51497100E+03, -.11333200E+05, -.10597000E+05, -.14634500E+05, 0.14052700E+05, 0.11407900E+05, 0.24086400E+05, -.14813500E+05, 0.25528500E+05, -.27444900E+05, -.13942100E+05, -.18894900E+05, 0.11126800E+05, 0.21125500E+05, 0.27416900E+05, -.18715400E+05, -.32089600E+04, 0.14009300E+05, 0.10882900E+05, 0.15103200E+05, -.13317900E+05, -.11940400E+05, -.24413100E+05, 0.15359900E+05, 0.65663000E+04, 0.12593200E+05, 0.15236900E+05, 0.20849400E+05, -.21383300E+05, -.13468800E+05, -.35169400E+05, 0.21668300E+05, -.17262700E+05, -.68527400E+04, -.96837800E+04, -.13426000E+05, 0.18109600E+05, 0.87432000E+04, 0.29027700E+05, -.13803100E+05, -.94772300E+03, 0.13004200E+05, -.32506700E+04, 0.15086600E+05, -.47783500E+04, 0.83544400E+04, 0.11469900E+04, 0.97340100E+04, 0.37537900E+03, -.82952900E+04, -.12918800E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27556800E+00, -.23134000E+01, 0.43950800E+05, 0.60326800E+05, -.56004600E+05, -.58013400E+05, -.11998600E+06, 0.61780600E+05, 0.67581500E+05, 0.74577500E+04, -.61027200E+05, -.83954600E+05, 0.57261600E+05, 0.80404800E+05, 0.12771400E+06, -.85282600E+05, -.93548600E+05, 0.43912600E+05, -.13321900E+05, -.19646900E+05, 0.43265200E+05, 0.73557700E+03, 0.76735800E+05, -.21993800E+05, 0.82697300E+05, -.18745200E+05, -.24802100E+05, -.34036900E+05, 0.98176300E+04, 0.52157600E+05, 0.53892700E+05, -.34214100E+05, 0.83150300E+05, -.20054600E+05, -.20526100E+05, -.27857500E+05, 0.38659800E+04, 0.45073000E+05, 0.36290200E+05, -.27712400E+05, 0.16812300E+05, 0.13439800E+05, -.25009000E+05, -.36352600E+05, 0.25602000E+05, 0.35092900E+05, 0.66969300E+05, -.37115300E+05, 0.99008100E+05, -.46623600E+05, -.41713700E+05, -.56079300E+05, 0.24672700E+05, 0.65086500E+05, 0.73361700E+05, -.55806300E+05, -.48777500E+05, 0.12340100E+04, 0.33462700E+05, 0.46450300E+05, -.28365700E+05, -.45504100E+05, -.65391800E+05, 0.46953100E+05, -.25703200E+05, -.19099700E+05, 0.43437000E+05, 0.60323400E+05, -.46855400E+05, -.50238700E+05, -.96998900E+05, 0.62080100E+05, 0.64960400E+04, 0.29412300E+05, -.30951100E+05, -.42822800E+05, 0.38289500E+05, 0.38306400E+05, 0.76918900E+05, -.43543000E+05, 0.10305300E+05, 0.61809200E+05, -.13795900E+05, 0.60448300E+05, 0.34274100E+04, 0.14012100E+05, -.87847800E+04, 0.53017500E+05, 0.10121200E+05, -.17162000E+05, -.27007700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.36489200E+00, -.84357500E+00, 0.71025400E+00, -.75416700E+04, 0.33083900E+04, 0.28409900E+05, 0.56683100E+05, -.50828500E+04, -.42774200E+05, 0.75555100E+04, 0.12393600E+05, 0.22241400E+05, -.70311600E+04, -.40262800E+05, -.56817000E+05, 0.19452400E+05, 0.36185300E+05, -.22554100E+05, -.88862200E+04, -.58121000E+04, 0.31803900E+03, -.35629300E+04, -.38027600E+05, -.66327000E+04, 0.57465000E+04, -.23085600E+04, -.56803900E+04, -.32746100E+04, 0.51957300E+04, -.98846100E+04, -.28637500E+05, -.39563500E+04, -.46802500E+04, 0.25863300E+04, -.15142700E+04, 0.39779300E+03, 0.25056600E+04, -.97986600E+04, -.19131300E+05, -.25617700E+03, 0.69201800E+04, -.11585900E+05, -.58552300E+04, -.19052800E+04, 0.68706500E+04, -.10657600E+05, -.31935700E+05, -.27373600E+04, -.57376300E+05, 0.32672500E+05, 0.11698300E+05, 0.18690100E+05, -.13671000E+04, -.34232000E+05, -.32974300E+05, 0.16422700E+05, 0.36317300E+05, -.11018800E+05, -.83483800E+04, -.14386300E+05, 0.22719200E+04, 0.24729700E+05, 0.28425900E+05, -.12768400E+05, 0.12045400E+05, 0.10280400E+05, -.61622600E+04, -.13060400E+05, 0.70437000E+04, 0.21495600E+05, 0.42864100E+05, -.11692000E+05, -.21623000E+05, -.12319900E+04, 0.62716900E+04, 0.12166500E+05, -.50848600E+04, -.24953400E+05, -.34717500E+05, 0.10062900E+05, -.15478800E+04, -.29510000E+05, 0.18565400E+05, -.18861500E+05, -.10835800E+05, 0.90630700E+04, 0.39800100E+04, -.31226300E+05, -.16445900E+05, 0.23221800E+05, -.57837300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18624100E+00, 0.44798800E+00, 0.25721400E-01, 0.27052900E+00, -.41157400E+04, -.34498900E+04, -.14622400E+04, -.68601100E+03, -.31747800E+03, -.29500800E+04, 0.90915600E+03, 0.11500300E+04, 0.20483400E+04, 0.25162800E+04, 0.65260700E+03, 0.15913600E+04, 0.46865900E+04, -.14894300E+04, -.56843600E+03, -.64013400E+03, 0.23180000E+04, 0.26145900E+04, -.29154300E+03, -.16836000E+02, 0.15580600E+04, -.21404200E+04, -.24424700E+04, -.27053600E+04, 0.49057500E+04, 0.37807100E+04, 0.28628400E+04, -.24815300E+04, -.22660500E+04, -.10645600E+04, -.10727100E+04, -.11468600E+04, 0.35252900E+04, 0.16417000E+04, 0.23134700E+04, -.10258900E+04, 0.79001300E+04, -.49250700E+04, -.25077100E+04, -.28269400E+04, 0.35857500E+04, 0.38270800E+04, 0.20270200E+03, -.24175500E+04, -.13007000E+03, -.75775800E+03, 0.31835600E+03, 0.31093600E+03, 0.13856200E+04, 0.21680700E+04, 0.98403600E+03, 0.47909500E+03, -.24306100E+04, 0.29252500E+04, -.24732700E+03, -.26303700E+03, -.39296800E+03, -.13947200E+04, 0.15536000E+03, -.47019900E+03, 0.28234600E+03, 0.18287200E+04, -.63078600E+03, -.77374800E+03, -.19029100E+04, -.12090800E+04, -.72489200E+03, -.10715500E+04, -.19628300E+04, -.18962000E+04, 0.13670000E+04, 0.16758800E+04, 0.61580900E+03, 0.14300800E+04, -.38262100E+03, 0.20325300E+04, 0.31245200E+03, -.24711700E+04, -.14322300E+03, -.22677300E+04, -.20198700E+04, 0.14783100E+04, 0.12326600E+04, -.10845400E+04, 0.50066200E+03, -.66817200E+03, -.72847000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.31190200E-01, -.76489700E+00, -.48483900E-02, 0.68275700E-01, 0.56700900E-01, -.43306700E+04, -.27823700E+04, -.43333200E+03, 0.20036600E+04, 0.97838400E+03, 0.49184000E+03, 0.89361300E+03, -.10780000E+04, 0.24613500E+04, 0.81809300E+03, 0.12442900E+04, -.15311800E+04, 0.61700700E+03, -.16534800E+03, -.31427900E+03, 0.75091600E+03, 0.19577500E+04, 0.29169600E+04, -.13743700E+03, -.30423000E+04, 0.26139400E+04, 0.78996800E+03, 0.91046800E+03, -.21577400E+03, 0.68982700E+03, 0.38354300E+03, 0.11536100E+04, -.19380000E+04, 0.20360200E+04, 0.56006000E+03, 0.65879400E+03, -.26602100E+03, 0.53187800E+03, -.14592600E+02, 0.83174400E+03, 0.66303900E+03, 0.73626400E+03, 0.69068400E+03, 0.10230500E+04, -.92534100E+03, 0.94361500E+03, 0.29887100E+03, 0.12013600E+04, 0.27907400E+04, -.12598400E+04, 0.24780800E+03, 0.30814500E+03, -.11424600E+04, 0.15783800E+04, -.46981700E+00, 0.58711300E+03, -.22800100E+04, -.70991000E+00, -.24367800E+03, -.42119300E+03, 0.86655400E+03, -.97836200E+03, 0.37230100E+02, -.59089900E+03, -.15841900E+04, -.82493800E+03, -.44593100E+03, -.80442900E+03, 0.98238300E+03, -.98620300E+03, -.37202900E+03, -.99883200E+03, -.33883700E+03, 0.17749100E+04, -.19499600E+03, -.27665600E+03, 0.50909900E+03, 0.26810500E+04, 0.21188700E+04, -.20152500E+02, 0.45887800E+02, 0.53707300E+03, -.97030500E+03, 0.27562000E+02, 0.66938600E+03, -.10188100E+04, 0.32790400E+02, 0.10984200E+04, 0.14821200E+04, -.13369200E+04, 0.40979800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12399300E+00, 0.30370200E+00, 0.37735200E-01, -.17035100E-01, 0.59008300E+00, 0.70964200E+00, -.95711900E+04, 0.86175700E+03, 0.15834800E+05, -.85433800E+04, -.31941900E+04, -.38130200E+04, 0.16942300E+03, 0.57845700E+04, 0.98918000E+04, -.43978300E+04, -.16368500E+05, 0.98148200E+04, 0.51606800E+04, 0.63572200E+04, -.24468900E+04, -.67408100E+04, 0.51348100E+04, 0.57717600E+04, 0.31812500E+04, -.43178600E+04, -.56329700E+03, -.13616200E+04, -.34118500E+03, 0.24143100E+04, 0.10939500E+05, -.18986200E+04, 0.64721300E+04, -.56742100E+04, -.16798700E+04, -.24992400E+04, 0.37940300E+03, 0.33492500E+04, 0.77719100E+04, -.28085600E+04, -.24033300E+04, 0.61816800E+03, 0.23807400E+04, 0.25822100E+04, -.31683500E+04, -.40969500E+03, 0.66722800E+04, 0.20742800E+04, 0.14769700E+05, -.85755100E+04, -.44276500E+04, -.54668000E+04, 0.18856300E+04, 0.62403000E+04, 0.74813900E+04, -.58621600E+04, -.92932400E+04, 0.51538500E+04, 0.18721000E+04, 0.22251100E+04, -.41102500E+02, -.37507700E+04, -.44893500E+04, 0.25133400E+04, -.10661300E+05, 0.48935400E+04, 0.19774100E+04, 0.23246100E+04, -.64801800E+02, -.45849100E+04, -.83969900E+04, 0.28071700E+04, 0.42553400E+04, -.27018700E+04, -.26392400E+03, -.11557600E+03, -.65239300E+03, -.20588600E+03, 0.31107700E+04, -.41460600E+03, 0.12039300E+04, 0.62578600E+04, -.28838600E+04, 0.31227400E+04, 0.34595500E+04, -.12471500E+04, -.20349100E+04, 0.50738700E+04, 0.20653700E+04, -.33906800E+04, 0.16371100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.32631800E+00, -.16493000E+00, 0.17279500E+00, 0.76926400E+00, -.27877700E+00, 0.18613500E+01, 0.13711700E+01, -.18210800E+04, -.12693900E+05, 0.46533400E+04, 0.61730600E+03, 0.56691200E+03, 0.18961800E+04, -.17449100E+04, 0.21794100E+04, 0.23864000E+04, 0.15263700E+05, -.65358800E+04, -.40440600E+04, -.48708100E+04, 0.85945500E+03, 0.66777700E+04, -.15318000E+03, -.36927000E+04, -.63347500E+04, 0.89148600E+03, 0.16693800E+04, 0.26975900E+04, -.96720100E+02, -.39765700E+04, -.55323100E+04, 0.35129300E+04, -.88696500E+04, 0.19703600E+04, 0.23356700E+04, 0.33599700E+04, -.27465600E+03, -.46211100E+04, -.37806500E+04, 0.39314900E+04, 0.74031200E+03, -.14088500E+03, -.23419600E+04, -.29710300E+04, 0.27791500E+04, 0.16441600E+04, 0.61373300E+02, -.19558500E+04, -.70316000E+04, 0.23739200E+04, 0.19422100E+04, 0.24832300E+04, -.83041800E+03, -.13532000E+04, 0.26381600E+03, 0.36449100E+04, 0.46756400E+04, -.11503200E+04, 0.11082900E+03, 0.33849100E+03, -.94174400E+03, -.33117600E+03, -.22521200E+04, -.66225900E+03, 0.13279500E+05, -.69262100E+04, -.60621500E+03, -.48709300E+03, -.23052400E+04, 0.23158100E+04, -.84987800E+03, -.17641500E+04, 0.11634800E+04, -.13734900E+04, -.78551800E+03, -.95919600E+03, 0.28978300E+03, 0.18949900E+04, 0.23603700E+04, 0.14839400E+03, -.15569200E+04, -.12910600E+04, 0.15874200E+03, -.37453400E+03, -.21973500E+04, -.87901200E+03, 0.19513400E+04, 0.98527300E+02, 0.12308200E+04, -.89549200E+03, -.58807100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23280000E+00, 0.87550600E+00, 0.72607000E-01, 0.16552000E-01, 0.78037500E-01, -.16392000E+00, 0.32622300E+00, 0.20692400E+00, -.10368400E+05, 0.14031700E+04, 0.26968800E+04, 0.38435500E+04, -.80338600E+03, -.50068800E+04, -.50730600E+04, 0.35681800E+04, -.98043700E+04, 0.20781600E+04, 0.12424500E+04, 0.12604900E+04, 0.19744300E+04, -.27572900E+04, 0.47195700E+04, 0.11685200E+04, -.84162500E+04, 0.56026600E+04, 0.21288500E+04, 0.27530100E+04, -.48942000E+03, -.33991500E+04, -.12781400E+04, 0.27783100E+04, -.50490700E+04, 0.43327700E+04, 0.13039200E+04, 0.17766400E+04, -.67407500E+03, -.23912200E+04, -.24447300E+04, 0.17063100E+04, -.74084100E+04, 0.10574400E+04, 0.20668500E+04, 0.28565300E+04, -.44332700E+03, -.34122000E+04, -.13682400E+04, 0.27739400E+04, 0.11269400E+04, 0.17683100E+04, 0.53610100E+03, 0.81786500E+03, -.14437100E+04, -.14804700E+03, -.41165600E+04, 0.83239800E+03, 0.45597300E+04, -.53999700E+03, -.13921800E+04, -.20424100E+04, 0.72034000E+03, 0.26663700E+04, 0.36882800E+04, -.19353400E+04, 0.11306500E+05, -.36849100E+03, -.24794800E+04, -.35270500E+04, 0.17524000E+02, 0.50028100E+04, 0.22971800E+04, -.32833600E+04, -.66849100E+04, 0.66859500E+03, 0.92360800E+03, 0.13047900E+04, 0.46734500E+03, -.25821400E+04, -.23135500E+04, 0.10079000E+04, -.32363700E+04, -.12975800E+04, 0.40879800E+02, -.21275400E+04, -.17545700E+04, 0.13400300E+04, 0.22916100E+04, -.16390500E+04, 0.19244600E+03, 0.38584900E+03, 0.14568600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.43352400E-01, -.10712300E+01, -.16929000E+00, -.27131700E-01, -.61249200E+00, -.44300800E+00, -.55197900E+00, -.13447100E+00, -.90869000E+00, 0.47615300E+04, 0.12824600E+03, 0.19611000E+03, 0.16118400E+03, 0.34855300E+02, 0.25292800E+03, 0.47594800E+02, -.50240900E+04, 0.70462000E+03, 0.18227500E+03, 0.84278300E+02, 0.18764200E+04, -.11277700E+04, 0.41650700E+04, 0.71486900E+02, -.26020000E+04, 0.63285700E+04, 0.58672100E+03, 0.65519700E+03, 0.64894900E+03, -.10661200E+04, 0.98149200E+03, 0.70773400E+03, -.25978700E+03, 0.47127600E+04, 0.19934200E+03, 0.19066000E+03, 0.12479000E+03, -.26732000E+03, 0.16249200E+02, 0.18608400E+03, -.10920400E+03, 0.27364100E+04, -.96503000E+02, 0.10194400E+02, 0.92912500E+03, -.12056400E+03, 0.10720400E+04, 0.50110100E+02, -.11328300E+04, 0.20860300E+04, 0.86476900E+03, 0.10477600E+04, -.85971800E+03, -.10309600E+04, -.21000400E+04, 0.10190500E+04, -.10454800E+04, -.23382500E+04, 0.15881600E+03, 0.17711600E+03, -.88746900E+02, -.30926600E+03, 0.25895300E+03, 0.25010900E+03, 0.23267700E+04, -.37078800E+04, -.54991000E+03, -.74425900E+03, -.31812400E+03, 0.10898400E+04, -.10650600E+04, -.64057700E+03, 0.19050000E+04, 0.27740900E+04, -.96049800E+03, -.13492000E+04, 0.80420400E+03, 0.16683800E+04, 0.13563500E+04, -.14399600E+04, -.39714500E+03, 0.11981100E+04, -.63370200E+03, 0.85296900E+03, -.29667000E+03, 0.89907800E+03, 0.53075200E+03, 0.12708800E+04, 0.10678100E+04, 0.26999900E+03, 0.52553000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.86423800E+00, 0.83805700E+00, -.50508300E+00, -.14946500E+00, -.21428800E+01, 0.30951700E+01, 0.51373800E+00, -.79349500E+00, 0.11362500E+01, -.13094400E+01, -.58104100E+04, -.82471900E+04, 0.73587900E+04, 0.96179900E+04, 0.11860300E+05, -.83314500E+04, 0.14046600E+05, -.55394200E+04, -.11768400E+04, -.10570000E+04, -.32217500E+04, 0.42885300E+04, -.47212000E+04, -.67097000E+03, 0.69814400E+04, -.20595100E+04, -.34497000E+04, -.36919100E+04, 0.38013300E+04, 0.53214000E+04, 0.32454300E+04, -.42891300E+04, 0.30011700E+04, -.27179700E+04, -.22188700E+04, -.24201900E+04, 0.35679900E+04, 0.34746700E+04, 0.42811400E+04, -.27580400E+04, 0.37030700E+04, 0.40631900E+03, -.52502100E+04, -.71661500E+04, 0.55449600E+04, 0.59451800E+04, 0.55995900E+04, -.72628700E+04, -.54734400E+04, 0.12520500E+04, -.13973500E+04, -.16677200E+04, 0.36836300E+04, 0.45070800E+04, 0.63059000E+04, -.19337600E+04, -.21225700E+04, 0.14165400E+04, 0.39845200E+04, 0.56215800E+04, -.42703100E+04, -.64140600E+04, -.82417900E+04, 0.56613100E+04, 0.37822400E+04, -.26083800E+04, 0.40878900E+04, 0.61349300E+04, -.64303700E+04, -.63178000E+04, -.85722100E+04, 0.61198900E+04, 0.66616900E+04, -.47913800E+04, -.22001800E+04, -.26894000E+04, 0.78524200E+03, 0.58091200E+04, 0.33807900E+04, -.26215100E+04, 0.98122400E+03, 0.22427400E+04, -.27082000E+03, 0.30852000E+04, -.11829100E+04, 0.25290700E+04, -.35791900E+03, 0.34058800E+04, -.13379800E+03, -.16131700E+04, -.46829200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15666400E-01, 0.71573600E+00, 0.16621500E-01, -.95671700E-01, -.87836000E-01, -.62651500E+00, 0.93121700E-01, 0.11098000E-02, 0.35164500E+00, 0.69991100E-01, 0.16453400E+00, -.21016700E+03, -.10703100E+03, -.95880000E+03, -.74744500E+03, -.15870300E+03, -.16930200E+04, 0.11615000E+04, 0.11430000E+04, 0.13792900E+04, -.11659000E+04, -.10087500E+04, -.26499500E+03, 0.13830700E+04, -.45344900E+03, -.56508300E+03, 0.39320900E+03, 0.40024500E+03, -.51573900E+03, -.15706600E+03, 0.95685400E+03, 0.45566400E+03, -.11619000E+03, -.42247600E+03, 0.10398100E+03, 0.95607700E+02, -.19504400E+03, -.42544500E+02, 0.46547900E+03, 0.12581900E+03, -.21150800E+04, 0.83899300E+03, 0.74812800E+03, 0.68121800E+03, -.65965300E+03, -.97877300E+03, 0.52367200E+03, 0.71216800E+03, 0.74535900E+02, -.21357400E+03, -.41394500E+03, -.55962000E+03, 0.52305900E+03, -.64145000E+03, -.22935000E+03, -.57731700E+03, 0.57808700E+03, -.30433000E+03, -.87516300E+02, -.18913600E+02, 0.13733400E+01, 0.81239900E+03, 0.70287500E+03, -.37139400E+02, -.19006700E+04, 0.67220200E+03, 0.29433100E+03, 0.54118600E+03, 0.33010900E+03, -.22537400E+02, 0.32963800E+03, 0.50038300E+03, -.17131400E+03, 0.27145800E+03, 0.39013900E+03, 0.47617000E+03, -.43468600E+03, -.83681200E+03, -.97942000E+03, 0.54131400E+03, -.52700800E+03, 0.18786900E+03, -.11374200E+03, -.30193700E+03, 0.24791600E+03, -.31504800E+03, 0.16293400E+03, -.11935300E+03, -.12678900E+03, -.19826300E+02, 0.51883300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11062800E+01, -.16507900E+01, 0.70093200E+00, 0.12731400E+00, 0.48805800E+00, 0.20884800E+01, -.16203100E+01, -.27828200E+00, -.16515500E+01, 0.11534600E+01, 0.96563100E+00, -.11186400E+01, -.15982200E+04, -.54132900E+04, -.14303000E+05, -.12734100E+04, -.28067800E+05, 0.59237700E+03, 0.67852800E+04, 0.78794300E+04, -.67768600E+03, -.10364900E+05, 0.54963700E+04, 0.75543800E+04, -.26722100E+04, 0.15071100E+05, 0.34122500E+04, 0.36138600E+04, -.56078600E+04, -.78170500E+03, -.68585400E+03, 0.34945500E+04, 0.38326400E+04, 0.15174900E+05, 0.41693200E+03, 0.29535200E+03, -.39046800E+04, 0.89271400E+03, -.42264600E+04, -.24524100E+03, -.15500700E+05, 0.25022000E+04, 0.58659000E+04, 0.67035000E+04, -.55699700E+04, -.75582600E+04, -.28340000E+04, 0.61212100E+04, 0.16518500E+05, 0.40038800E+04, -.46698800E+04, -.56803200E+04, 0.47047800E+03, 0.41453700E+04, -.72394500E+04, -.59127200E+04, -.31212000E+04, -.54773800E+03, 0.52747300E+03, 0.40796800E+03, 0.13616100E+04, 0.26640000E+04, 0.10253200E+05, 0.10557500E+04, 0.86898700E+04, 0.73262100E+04, -.16217900E+04, -.23728500E+04, 0.96595400E+03, 0.70497200E+04, 0.75148000E+04, -.15092200E+04, 0.12987600E+04, 0.61264600E+03, -.56771200E+03, -.36145700E+03, -.77939400E+03, -.33512500E+04, -.10994100E+05, -.14285300E+04, -.38463000E+04, -.11729900E+04, 0.21556500E+04, -.43812900E+04, 0.12376800E+04, 0.21704000E+04, 0.11294700E+04, -.39536500E+04, -.45762500E+04, 0.29811900E+04, 0.16954900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.30848400E+00, 0.48505100E+00, 0.22064400E+00, 0.65008100E+00, 0.14550500E+01, 0.25951800E+00, 0.11393500E+00, 0.10831000E+00, 0.10752600E+00, 0.14968200E-01, -.12498100E+00, 0.12953300E+01, 0.33364700E-02, 0.25596900E+04, 0.26456900E+04, 0.62031500E+02, 0.53181200E+04, -.19372000E+04, -.21645900E+04, -.24834300E+04, 0.14889500E+04, 0.23212200E+04, -.44121900E+03, -.24753400E+04, -.23061100E+03, -.82996600E+03, -.86497800E+03, -.80963100E+03, 0.17317700E+04, 0.31656400E+03, -.90285600E+03, -.89508300E+03, -.70788100E+03, -.65582300E+03, -.11011400E+03, -.55987400E+02, 0.71501300E+03, 0.73301500E+02, -.41921100E+02, -.66069800E+02, 0.42809600E+04, -.17992600E+04, -.20399700E+04, -.22299000E+04, 0.20103900E+04, 0.23354400E+04, -.11726500E+03, -.22178000E+04, -.15619100E+04, -.49263100E+01, 0.87898800E+03, 0.10557400E+04, -.77400500E+03, 0.13013200E+04, 0.12805200E+04, 0.10869100E+04, -.10570400E+04, 0.76346600E+03, 0.18208800E+03, 0.30181200E+03, 0.61581400E+02, -.18599000E+04, -.20972000E+04, 0.24433900E+03, 0.24704200E+04, -.20299900E+04, -.35014600E+03, -.39773800E+03, -.41913400E+03, -.93489400E+03, -.15395900E+04, -.43500400E+03, 0.14740900E+04, -.68737800E+03, -.32330300E+03, -.47129500E+03, -.12245200E+03, 0.20640300E+04, 0.18125900E+04, -.45620800E+03, 0.11385800E+04, -.50207600E+02, -.14047700E+03, 0.98096400E+03, -.58806700E+03, 0.26674200E+03, -.37149800E+03, 0.70550600E+03, 0.41936100E+03, -.53598300E+03, -.10136400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.82073300E+00, 0.12189200E+01, 0.22444400E+00, 0.69364300E+00, 0.11014800E+00, -.69300900E+00, -.10100300E+01, -.88365300E+00, 0.33764000E+00, -.11218600E+01, 0.37365900E+00, 0.29712300E+00, -.41100100E+00, -.70226200E+00, -.48165100E+04, -.29253700E+03, -.16913300E+05, 0.29043400E+04, 0.42738300E+04, 0.49061000E+04, -.36502200E+03, -.60875800E+04, 0.42353500E+04, 0.48351700E+04, -.28566000E+04, 0.68568900E+04, 0.21113700E+04, 0.22284000E+04, -.25043300E+04, 0.54570900E+03, 0.19814400E+04, 0.22676500E+04, 0.85394000E+03, 0.64399300E+04, 0.47314000E+03, 0.41343700E+03, -.17063900E+04, 0.11327000E+04, -.29497300E+03, 0.22508300E+03, -.77560800E+04, 0.25057400E+04, 0.36508200E+04, 0.40698000E+04, -.35068100E+04, -.27219400E+04, 0.11685400E+03, 0.39596200E+04, 0.43756900E+04, 0.25192800E+04, -.22822100E+04, -.26086700E+04, 0.16306700E+04, 0.30350800E+04, -.30849000E+04, -.27801200E+04, -.16214600E+04, -.15032900E+03, 0.33526200E+03, 0.33010000E+03, 0.17573300E+03, 0.20378300E+02, 0.38038600E+04, 0.43672200E+03, 0.19509600E+04, 0.26316600E+04, -.72364300E+03, -.89801000E+03, 0.26366600E+03, 0.76095800E+03, 0.13846200E+04, -.78126200E+03, 0.45837300E+03, 0.12571900E+04, -.15035400E+03, -.46386400E+02, -.33278000E+02, -.27480100E+03, -.46974300E+04, -.32403500E+03, -.23557200E+04, 0.12609700E+03, -.15318900E+03, -.19980600E+04, 0.10170700E+04, 0.26914500E+03, 0.89148500E+03, -.90643900E+03, -.48833800E+03, -.29914500E+03, 0.67863600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.34472700E+01, -.48192000E+01, 0.70473100E+00, -.13574100E+01, 0.41530500E+01, 0.27876700E+01, 0.18330500E+01, 0.14631700E+01, -.25395500E+01, 0.44955800E+01, -.69084700E+00, -.80312200E+01, 0.11367800E+01, 0.78264800E-01, -.96051800E+00, 0.16159400E+04, 0.13263900E+05, 0.54143600E+04, 0.29370000E+04, 0.36067900E+04, -.11573000E+05, 0.35179700E+04, -.10995800E+05, 0.36306200E+04, 0.22642500E+04, -.23198800E+05, 0.49942500E+04, 0.54503600E+04, -.10517000E+05, 0.12851500E+03, -.38345300E+04, 0.58705600E+04, -.29521200E+04, -.16588700E+05, 0.37004600E+04, 0.43402700E+04, -.56126600E+04, -.18325600E+04, -.17031200E+04, 0.46974900E+04, -.94477600E+04, 0.38030800E+04, 0.74343100E+04, 0.75632800E+04, -.11316100E+05, -.21496200E+04, 0.16247200E+04, 0.81340100E+04, -.14662900E+05, -.28356500E+04, -.89332100E+03, -.64930300E+03, 0.75229600E+04, -.38458700E+04, 0.58572800E+04, -.21301500E+03, 0.95165700E+04, -.22733700E+04, -.15229500E+04, -.18819600E+04, -.12319000E+04, 0.29267800E+04, -.21915200E+04, -.28844500E+04, -.23064100E+05, 0.95262900E+03, 0.36576800E+04, 0.49038600E+04, 0.31580800E+04, -.94943200E+04, 0.35167800E+04, 0.37565600E+04, -.24773800E+04, 0.31482500E+04, 0.27435400E+04, 0.40956200E+04, -.18015200E+04, -.36634400E+04, -.15091400E+04, 0.53174900E+04, -.12304500E+04, -.25311300E+03, -.12379400E+04, -.13006800E+04, 0.60166100E+04, -.10797100E+05, -.13649900E+04, 0.17787600E+03, 0.29365500E+04, -.25616400E+04, 0.35127800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.50432500E-01, -.10077300E+01, -.11776900E+00, -.43976900E-02, 0.44845300E-01, 0.11976400E+01, -.73167000E-01, 0.65319300E-01, -.50451900E+00, 0.18891600E+00, -.14515700E+00, -.55619100E+00, -.57740200E-01, -.11469100E+00, 0.18943700E+00, -.43787300E-01, 0.38498500E+04, -.10424600E+04, -.66863600E+03, -.72749500E+03, -.89387700E+03, 0.13367100E+04, -.13265400E+04, -.80464900E+03, 0.10846100E+04, -.14671600E+04, 0.34845300E+03, 0.30963000E+03, -.88971800E+03, 0.22557700E+03, -.12415100E+04, 0.35622100E+03, -.14953000E+03, -.10511200E+04, 0.43332100E+03, 0.45735300E+03, -.48990500E+03, -.21780900E+03, -.87106100E+03, 0.48454500E+03, 0.12540000E+03, -.31751900E+03, 0.68946100E+02, 0.21256000E+02, -.35651600E+03, 0.20170600E+03, 0.27638900E+03, 0.45494600E+02, -.23892100E+04, 0.57119200E+03, 0.39722500E+03, 0.42161900E+03, 0.56533100E+03, -.55254400E+03, 0.13108900E+04, 0.55235200E+03, 0.33787800E+03, -.41678600E+02, 0.82976500E+02, 0.12532800E+03, -.32252700E+03, -.14205000E+03, -.95965800E+03, 0.95343200E+02, -.35663700E+03, 0.41470500E+02, -.48152800E+02, -.12761200E+03, 0.46206700E+03, 0.24094100E+03, 0.16336500E+04, -.71607700E+02, 0.28619700E+03, -.71056000E+03, -.22328700E+03, -.18854700E+03, 0.21628400E+03, 0.22172700E+03, 0.60854200E+03, -.22895500E+03, 0.32403000E+03, -.22079200E+03, 0.13252900E+03, 0.11786200E+03, 0.55786200E+03, -.10118700E+04, -.34408400E+03, 0.20373600E+03, -.73115500E+01, 0.17713200E+03, -.28321300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.11153300E+00, 0.28948100E+00, -.18963100E-01, -.20703100E-01, 0.39164400E+00, 0.53456300E+00, 0.70948300E+00, -.59887600E-01, -.37013300E+00, 0.52741100E-01, -.53918400E-01, -.68001000E-01, 0.69969800E-01, 0.27101400E+00, -.26056700E-01, 0.23988200E-01, -.20437300E+00, 0.34047100E+03, 0.17651700E+03, 0.16873400E+03, -.16098300E+03, -.11930800E+03, -.94958500E+01, 0.18524200E+03, -.10614000E+03, 0.11162100E+03, -.90011100E+02, -.54605800E+02, 0.16463500E+03, 0.41332200E+02, 0.17407800E+03, -.57846900E+02, -.24357200E+03, -.28114400E+03, -.84262200E+02, -.60617200E+02, 0.24915600E+03, 0.51656500E+02, 0.28296700E+03, -.44467300E+02, -.14099400E+03, 0.30403400E+03, -.35752800E+02, -.41437600E+02, 0.10455200E+03, -.66308500E+02, 0.89600300E+02, -.39056000E+02, -.50129000E+03, -.44383900E+02, 0.33477500E+02, 0.79892600E+02, 0.19504400E+02, -.12898900E+03, 0.59109600E+02, 0.61280000E+02, 0.11104800E+03, -.78694900E+02, 0.13793700E+01, -.85430800E+01, -.98573900E+01, 0.55986000E+02, 0.23213100E+02, 0.36153900E+01, -.41689400E+03, 0.37287500E+02, 0.60995500E+02, 0.97221100E+02, 0.15596400E+02, -.10650200E+03, 0.26032500E+02, 0.85254000E+02, -.38629800E+03, -.96405400E+02, 0.14163600E+03, 0.17263700E+03, -.49774300E+01, -.12025900E+03, -.18470300E+02, 0.17742100E+03, -.77781000E+02, 0.40151600E+02, -.53909300E+02, -.27815400E+02, -.69441000E+02, 0.57958200E+02, 0.76250100E+02, 0.53168600E+02, 0.54697100E+02, -.48866800E+02, 0.79709900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.50145400E+00, 0.66141800E+00, -.39230300E+00, -.40784600E+00, -.56304300E+00, -.26972200E+00, -.62946900E+00, -.16842800E+00, 0.31426600E+00, -.32686500E+00, 0.24406400E+00, 0.75486400E+00, 0.57648900E-01, 0.39164100E-01, -.19346700E+00, -.57041500E-01, -.28688300E+00, 0.19200200E+01, -.42011200E+03, -.25387000E+03, 0.18453600E+03, 0.12616100E+03, 0.38368000E+03, -.33094900E+03, -.15783600E+04, -.67590000E+03, 0.12144600E+04, 0.10468100E+04, -.80771800E+03, -.57245400E+03, 0.21927800E+03, 0.11075900E+04, -.11077900E+04, 0.23011400E+03, 0.10261200E+04, 0.91029900E+03, -.86654600E+03, -.60330500E+03, -.34274600E+03, 0.90268900E+03, -.10742500E+04, -.37046000E+03, 0.52793700E+03, 0.57385300E+03, -.49675300E+03, -.33029700E+03, 0.30588400E+03, 0.58078900E+03, -.84379000E+03, 0.50997000E+03, 0.52932400E+02, -.59156200E+02, 0.48590000E+03, -.21065300E+03, 0.12399800E+03, -.14582400E+02, 0.32090500E+03, -.38906900E+01, 0.48873600E+02, 0.37023900E+02, -.17321100E+03, 0.97303800E+02, -.20052500E+03, 0.16820200E+02, -.11963200E+03, 0.93394800E+02, -.26367800E+03, -.35006600E+03, 0.46254400E+03, 0.17541000E+03, 0.25748900E+03, -.35237200E+03, 0.53624000E+03, 0.26848200E+03, -.44217700E+03, -.37453800E+03, 0.15426500E+03, 0.28771500E+03, 0.26681800E+01, -.41848200E+03, -.30440500E+03, 0.38392300E+02, -.13342700E+03, 0.94965900E+02, 0.25097100E+03, -.76277400E+03, 0.83755100E+02, 0.14539900E+03, 0.18548500E+03, -.14089600E+03, 0.62969800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.18798600E+01, -.16246900E+01, 0.92391300E+00, 0.55912800E+00, -.11922500E+01, 0.50988700E+01, -.15937500E+01, -.10807700E+01, -.40336600E+00, -.54053700E+00, 0.20579400E+01, 0.29400700E+01, 0.57244100E+00, 0.77723600E+00, 0.88372900E+00, -.22438800E+00, 0.18584500E+01, -.55589900E+01, 0.19203900E+01, -.85119000E+03, 0.28406700E+04, -.30822200E+03, 0.44398900E+03, -.51841000E+03, 0.13911000E+04, 0.68777800E+04, -.40950900E+04, -.35190900E+04, 0.48037200E+04, 0.23327300E+03, -.73516700E+03, -.37619200E+04, 0.13610100E+04, 0.55142300E+03, -.34858400E+04, -.31674800E+04, 0.43493200E+04, 0.12928400E+04, 0.18084500E+04, -.30324500E+04, 0.62211800E+04, 0.12729300E+04, -.36493000E+04, -.40390100E+04, 0.48060600E+04, 0.15158500E+04, -.24288200E+04, -.40102300E+04, 0.43062100E+04, -.26924200E+04, 0.17478100E+03, 0.71723300E+03, -.35361700E+04, 0.82070700E+03, -.16947200E+04, 0.48500000E+03, -.13972300E+04, -.16370000E+03, -.20220000E+03, -.24621800E+03, 0.94519800E+03, -.15054400E+03, 0.16533900E+04, -.11958400E+03, 0.19092000E+04, -.10430400E+04, 0.45906600E+03, 0.77461500E+03, -.18699000E+04, -.11296800E+02, -.20192800E+04, 0.70561000E+03, -.31175700E+04, -.10456100E+04, 0.14985100E+04, 0.11846600E+04, 0.64234000E+01, -.99576900E+03, 0.21828700E+03, 0.13390900E+04, 0.98358900E+03, -.46422800E+03, 0.73528700E+03, -.14682600E+03, -.28097600E+04, 0.44346000E+04, 0.57398000E+03, -.99071900E+03, -.10220300E+04, 0.82009000E+03, -.53604900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17552700E+00, 0.77953100E+00, -.84117300E-02, -.45262700E-01, 0.28385500E+00, -.49483600E+00, 0.62755200E+00, 0.13616900E+00, -.11962500E+00, -.24395700E+00, -.20427800E+00, -.36063500E+00, 0.79354300E-01, 0.24272200E+00, -.53681200E-01, 0.45213900E-01, 0.26010300E+00, -.11243400E+00, 0.10337100E+00, 0.53077900E-01, 0.11775900E+03, -.80529900E+02, 0.16403600E+03, 0.26691900E+02, 0.31574300E+03, 0.47952100E+03, -.37097800E+03, -.40239100E+03, 0.47759800E+03, 0.20171700E+03, 0.17746500E+03, -.40557500E+03, -.31881100E+02, 0.12602700E+03, -.19762800E+03, -.22765800E+03, 0.37305200E+03, 0.95701900E+02, 0.18542600E+03, -.21598800E+03, 0.39513300E+03, 0.15901500E+03, -.27895900E+03, -.28433600E+03, 0.30995700E+03, 0.10738600E+03, -.85067500E+02, -.27687700E+03, 0.41334500E+02, -.11643500E+03, -.73666900E+02, -.11615900E+03, -.73917400E+00, 0.13179900E+03, 0.17149800E+03, -.13074900E+03, -.12013300E+03, -.32676700E+02, -.39335700E+01, -.14693600E+02, 0.86637400E+02, -.64427400E+01, 0.14694000E+03, -.14813600E+02, 0.10627900E+03, -.14865400E+03, -.44546900E+02, -.51053400E+02, -.54695800E+02, 0.11491700E+03, -.26705400E+02, -.58608300E+02, -.23194500E+03, -.10066900E+03, 0.10741100E+03, 0.11378100E+03, -.55626200E+02, -.60848500E+02, -.40497700E+02, 0.12639900E+03, 0.47360100E+02, 0.89255000E+01, 0.31383600E+02, 0.10279600E+02, -.21109200E+03, 0.32578300E+03, 0.41524100E+02, 0.79832100E+01, -.46946700E+02, 0.60580200E+02, 0.54364700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.85377200E+00, 0.18620400E+00, -.17262600E+00, -.82468800E-01, -.96561400E+00, 0.24948700E+01, 0.42488500E+00, -.37891700E+00, 0.20056000E+00, -.75107800E+00, 0.93459700E+00, 0.10828100E+01, 0.12000200E+00, -.12952600E+00, 0.23154000E+00, -.14507000E+00, 0.36752900E+00, 0.13311800E+00, -.23458100E+00, -.54170600E-01, 0.22908200E+01, 0.42071000E+03, -.56754600E+03, 0.29360400E+02, 0.10097500E+03, -.14601200E+04, 0.65773700E+03, 0.71492300E+03, -.14680900E+04, -.64070000E+03, -.14815500E+04, 0.58826000E+03, 0.79380200E+03, -.61186600E+03, 0.24639600E+03, 0.28716200E+03, -.11605600E+04, -.28128800E+03, -.95854100E+03, 0.13302700E+03, -.48305600E+03, -.61504600E+03, 0.79603800E+03, 0.83871000E+03, -.11186400E+04, -.20278300E+03, -.61771200E+03, 0.80198000E+03, 0.90826500E+03, -.30717100E+03, 0.15296400E+03, 0.25683800E+03, -.37128100E+03, -.16172100E+03, -.61135600E+03, 0.29288900E+03, 0.59357800E+03, 0.12445400E+03, -.22159700E+03, -.23743500E+03, -.33728000E+02, 0.10758200E+03, -.14490500E+03, -.26296700E+03, 0.56039500E+03, 0.79062600E+02, 0.16365400E+03, 0.19151100E+03, -.16642600E+03, -.27346700E+03, -.18335500E+03, 0.23745100E+03, 0.76906500E+02, 0.20923600E+03, -.71180100E+02, -.83950100E+02, 0.23687800E+03, -.15208800E+03, 0.23711900E+03, -.64197600E+02, 0.64872400E+02, -.14833700E+03, 0.76439500E+02, -.12199600E+03, 0.49097300E+03, -.42731200E+03, -.25778800E+03, -.26938600E+03, -.95736200E+01, 0.14656900E+01, -.41394800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15307100E+01, -.18140200E+01, -.71841400E+00, -.14456300E+01, -.15271600E+01, 0.19243700E+01, 0.19893400E+01, 0.11704600E+01, -.43382200E+00, 0.21627600E+01, 0.77316200E-01, -.33058300E+00, 0.35337500E+00, 0.90859800E-02, -.82279500E+00, 0.10633000E-01, 0.23946200E+01, -.26140800E+01, 0.11849200E+01, 0.49806200E+00, 0.23791900E+01, 0.49308000E-01, -.15028000E+04, 0.29411600E+02, 0.16643700E+04, -.27654200E+04, -.94049900E+03, -.93335300E+03, 0.31620900E+03, 0.62149900E+03, -.32258900E+03, -.11118400E+04, 0.95946500E+03, -.71897800E+03, -.49268700E+03, -.44645300E+03, -.38086300E+02, 0.31197900E+03, 0.14931000E+03, -.57370800E+03, 0.72468500E+03, -.10182100E+04, -.46689200E+02, -.39052800E+02, -.64000600E+03, 0.31935900E+03, -.14246900E+04, -.22169800E+03, 0.26381000E+04, -.13142900E+04, -.52536700E+03, -.53377000E+03, -.67941500E+02, 0.64486400E+03, -.76936700E+03, -.66125900E+03, 0.31841000E+03, 0.11945800E+03, -.27659500E+03, -.31694900E+03, 0.32366100E+03, 0.24504500E+03, 0.60850900E+03, -.26903200E+03, -.12527100E+04, 0.27341900E+03, 0.58493900E+03, 0.76601400E+03, -.51342400E+03, -.14084400E+04, -.15459400E+04, 0.69545300E+03, -.23522500E+03, 0.10111100E+04, 0.55382700E+03, 0.60190100E+03, -.69205100E+03, -.81112300E+03, -.89147400E+03, 0.63001900E+03, 0.22640100E+03, -.30837000E+03, 0.29529200E+03, -.16296600E+03, -.20225700E+03, 0.53867600E+03, -.32052600E+03, -.70237000E+03, -.37341200E+03, 0.13742500E+03, 0.44102900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.77996100E+00, 0.34841700E+00, -.24115800E+00, -.68990600E+00, -.78388900E+00, -.15243800E+01, -.15962700E+01, -.19445600E+01, 0.44852900E+00, -.82684800E+00, 0.60415100E+00, -.19374900E+01, 0.32549500E+00, -.57674900E+00, -.58281600E+00, 0.21428000E+00, -.24298400E+01, -.13067300E+01, -.14603500E+01, -.25662600E+00, 0.56723900E+00, -.65182200E+00, -.49518900E+00, -.13166800E+03, -.10206800E+04, 0.83789700E+03, 0.61383500E+03, 0.54557900E+03, -.19001300E+03, -.16374600E+03, -.85979400E+02, 0.56553200E+03, -.83762200E+03, 0.53452300E+03, 0.45611500E+03, 0.48533900E+03, -.37784700E+03, -.21055000E+03, -.21194700E+03, 0.46761300E+03, -.12918400E+03, -.26587700E+03, -.17897500E+03, -.33485300E+03, 0.47055600E+03, 0.11249300E+03, 0.68123800E+03, -.32882500E+03, -.17521400E+04, 0.12116900E+04, 0.41968000E+03, 0.53164700E+03, 0.11417300E+03, -.54709200E+03, 0.13133300E+03, 0.68347700E+03, -.23147300E+03, 0.11577600E+03, 0.25161500E+03, 0.33482900E+03, -.44257800E+03, -.26182500E+03, -.85181800E+03, 0.30369000E+03, 0.15342800E+04, 0.35245600E+02, -.41661900E+03, -.57153700E+03, 0.51272500E+03, 0.10324600E+04, 0.96029800E+03, -.45098000E+03, 0.72509500E+03, -.91568200E+03, -.39524800E+03, -.34774500E+03, 0.39106800E+03, 0.63921200E+03, 0.57594300E+03, -.38155600E+03, -.37577500E+02, -.46195900E+02, 0.49427000E+02, 0.71476900E+02, 0.23742300E+02, -.17271000E+03, 0.30493900E+02, 0.20882800E+03, 0.24300600E+02, 0.99004800E+02, -.31473400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.56023200E+00, 0.13000100E+01, 0.24793200E+00, 0.76960500E+00, 0.82201600E+00, -.21519200E+01, -.11847700E+01, -.33577000E+00, 0.45722800E+00, -.71732200E+00, -.12766200E+00, 0.22782100E+01, -.63423200E-01, 0.88531000E+00, -.71146900E-01, -.10170000E+00, -.10699400E+01, 0.17425400E+01, 0.64236300E+00, 0.18982500E-01, 0.11486300E+01, 0.17952300E+00, -.22736100E+00, 0.16523000E+00, -.92309600E+03, -.22468400E+03, 0.42273200E+03, 0.45977100E+03, -.17981100E+03, -.13522400E+03, 0.56664500E+03, 0.55419300E+03, 0.23858700E+03, -.48956000E+02, 0.57415500E+02, 0.72048200E+02, -.12860300E+03, 0.13757200E+03, 0.83944000E+02, 0.11712100E+03, -.26655000E+03, -.18220600E+03, 0.34076000E+02, -.11608400E+02, 0.32192400E+03, 0.13393800E+02, 0.69043100E+03, 0.83019500E+02, -.37227400E+03, 0.31150400E+03, 0.65771500E+02, 0.73536700E+02, 0.13019100E+03, -.16481900E+03, -.76022300E+02, 0.86190400E+02, 0.22858800E+02, 0.18722100E+02, 0.84554600E+02, 0.12147900E+03, -.20408000E+03, 0.83418600E+00, -.21704700E+03, 0.11630500E+03, -.36911800E+03, 0.19999800E+03, 0.42724700E+02, 0.33824300E+02, 0.16497600E+03, -.57634600E+02, 0.16691500E+03, 0.56582300E+02, 0.35882300E+03, 0.16717800E+03, -.15775800E+03, -.16066700E+03, 0.17300800E+02, 0.18624800E+03, -.64342000E+01, -.18471900E+03, -.36067500E+02, 0.42647600E+02, -.65301000E+02, -.15379700E+02, 0.13883500E+03, -.33075000E+03, 0.10103800E+03, 0.65621000E+02, 0.72773600E+02, -.72576300E+02, -.57847100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.88444700E+00, 0.91662800E+00, -.55938700E+00, -.32916600E+00, -.15891100E+01, 0.22893400E+01, -.15211600E-01, 0.31013600E+00, 0.64794500E+00, -.94139900E+00, 0.79372000E+00, 0.26065000E+01, 0.56080200E-01, 0.38776900E+00, -.51238800E-01, -.13796300E+00, -.32473800E+00, 0.94748000E+00, 0.12591500E+01, 0.34265200E+00, -.17179600E+01, -.10846700E+00, -.38441100E+00, -.50554800E-01, 0.94368300E+00, -.14790800E+04, 0.34393500E+03, 0.45957600E+03, -.77316900E+03, -.75177000E+02, -.40786300E+03, 0.42090600E+03, -.21917100E+03, -.18022300E+03, 0.33282300E+03, 0.45213700E+03, -.72710300E+03, -.19436200E+03, -.30720200E+03, 0.36453600E+03, -.55743400E+03, -.47119300E+03, 0.60620200E+03, 0.68691600E+03, -.12415300E+04, -.20920500E+03, -.61134400E+03, 0.61438700E+03, -.21761200E+02, -.11868400E+02, -.32114600E+03, -.44316900E+03, 0.62006600E+03, 0.31113300E+03, 0.43768400E+03, -.44059300E+03, -.10026000E+03, 0.13583700E+03, -.61214800E+02, -.49189300E+02, 0.16352700E+03, -.78783200E+01, 0.11189700E+03, -.65528800E+02, -.55175000E+03, 0.10400300E+03, 0.73772300E+02, 0.33447600E+02, 0.88320500E+02, -.16053300E+03, -.91925800E+02, 0.10824500E+02, 0.50661300E+03, 0.14542900E+03, 0.64652500E+01, 0.52807700E+02, -.19795000E+03, 0.15719600E+02, -.33797300E+03, 0.56737800E+02, -.46958500E+02, 0.24504700E+02, 0.39218800E+01, 0.35830400E+02, 0.46273800E+03, -.52999500E+03, -.24968300E+03, 0.12234800E+02, -.32510400E+02, -.12093500E+02, 0.74003700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15904800E-02, 0.13809700E+01, 0.85137300E-01, -.26652500E-01, -.10767200E-01, -.89419100E+00, 0.17474500E+00, 0.20892300E-01, 0.23584100E+00, -.42979700E+00, 0.12700000E+00, 0.88592200E+00, 0.85614600E-02, 0.12072200E+00, -.69203000E-01, -.42733000E-01, -.59944900E+00, 0.23615200E+00, 0.19349200E+00, -.23526600E-01, 0.32256300E+00, 0.16149400E+00, -.43185600E-01, -.46429200E-01, -.20382500E+00, 0.20762400E-01, 0.63759600E+02, 0.10714800E+03, -.16716500E+03, 0.13195100E+02, -.51158500E+02, 0.14109200E+03, 0.21868800E+03, -.11832200E+03, -.51513600E+02, -.20486000E+02, -.61950200E+02, 0.89367100E+02, -.53847600E+02, 0.18770700E+01, 0.44393500E+02, -.17459200E+02, 0.81588700E+02, 0.84439900E+02, -.79821000E+02, -.98655200E+01, 0.43180900E+02, 0.11053200E+03, -.15887200E+03, 0.95919400E+02, 0.98967900E+02, 0.59450100E+02, 0.95428900E+00, -.52691600E+02, 0.55848200E+02, 0.70427200E+02, -.23060000E+03, 0.33769300E+02, -.11079000E+02, 0.57904100E+00, 0.33783900E+02, -.50136000E+02, 0.37735800E+01, -.12490200E+01, -.20440900E+03, 0.96800400E+02, -.11706900E+02, -.40383700E+02, 0.12125200E+03, 0.39114700E+02, 0.29557900E+03, -.32337100E+02, 0.16040700E+03, -.72593700E+02, -.20489400E+02, 0.18462700E+02, -.10572600E+02, 0.27700000E+02, -.26188000E+02, 0.11254100E+02, 0.75940900E+02, -.20198200E+02, 0.62316700E+00, -.40058900E+02, 0.15883300E+03, -.18726100E+03, -.51300500E+02, 0.17601600E+02, -.82991500E+01, 0.75798800E+01, 0.12766800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.67340500E+00, -.14121600E+01, -.98121500E-01, -.49795100E+00, 0.39889600E+00, 0.14772200E+01, 0.12723200E+01, 0.84682400E+00, -.80260000E+00, 0.15075000E+01, -.43306900E+00, -.96405700E-01, 0.42597000E+00, 0.12744700E+01, -.58882500E+00, 0.13482500E+00, 0.74360700E+00, -.98765600E+00, -.25385500E+00, 0.10172800E+00, -.81999500E-01, -.10968000E+00, 0.81760600E-01, -.29102800E+00, 0.33762000E+00, 0.10969600E+00, 0.16805200E+01, -.15051600E+03, 0.16233000E+03, -.11603400E+03, -.23859600E+03, -.30685800E+03, -.75454300E+03, 0.17888600E+03, 0.25860200E+03, 0.16206400E+03, 0.47817300E+02, -.32176800E+03, 0.46173100E+01, 0.66748500E+02, -.22239500E+03, -.13902900E+02, -.43351000E+02, -.75601600E+02, -.11797000E+03, -.56216300E+02, -.38119100E+03, -.19504500E+03, -.10282300E+03, -.67108100E+01, -.16044400E+03, -.56694500E+02, 0.70870200E+02, 0.24758300E+01, -.13055100E+03, -.80858900E+02, 0.32221100E+03, -.47561500E+02, -.74049100E+01, -.48212200E+02, 0.62873100E+02, 0.27759600E+02, -.76666800E+01, -.44236400E+02, 0.60326700E+03, -.28849600E+03, -.53606000E+02, -.95494600E+01, -.20344500E+03, 0.11927500E+02, -.52881100E+03, -.28640600E+02, -.17475000E+03, -.38147800E+02, 0.95752000E+02, 0.55576100E+02, -.79712800E+02, -.44302200E+02, 0.68346300E+02, 0.81075700E+02, -.15447700E+03, 0.34806100E+02, -.17949300E+01, 0.92628100E+02, -.30579100E+03, 0.39333100E+03, 0.26884100E+02, -.16752400E+02, 0.26498100E+02, -.10734000E+02, -.29574100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10631900E+01, 0.15167100E+01, 0.50482800E+00, 0.11369800E+01, 0.84552400E+00, -.20318200E+01, -.13771100E+01, -.77045100E+00, 0.31942400E+00, -.13178400E+01, -.41065300E+00, -.48802200E-01, -.20309000E+00, 0.69709300E+00, 0.49033100E+00, 0.77819500E-02, -.17200700E+01, 0.16604000E+01, 0.20669100E+00, -.61672800E-01, 0.90375400E+00, 0.63027500E-01, -.47540100E+00, 0.93617400E-01, 0.12473000E+01, 0.68163400E-01, 0.33346100E+00, -.23328100E-01, 0.13580100E+03, 0.50336900E+02, 0.25691400E+02, 0.58705400E+01, -.66819200E+02, -.13004900E+03, 0.76371800E+00, 0.16442100E+02, 0.14176200E+03, 0.14846900E+02, 0.16918000E+02, 0.32025000E+02, -.50449100E+02, 0.22021000E+02, -.10082300E+03, -.16614500E+03, 0.22322400E+03, 0.96197500E+02, 0.28276400E+03, -.14726200E+03, -.20503500E+03, 0.19449100E+03, 0.11373400E+03, 0.20714000E+03, -.14982200E+03, -.14606100E+03, -.19482800E+03, 0.20444200E+03, 0.46168800E+02, 0.56823700E+02, 0.37701200E+02, 0.43016200E+02, -.71667300E+02, -.23783700E+02, -.13708600E+03, 0.47018000E+02, 0.18578600E+03, 0.72996900E+02, 0.61959600E+02, 0.92666900E+02, -.12120300E+03, 0.84313000E+01, -.45330300E+02, 0.94793600E+02, 0.18370300E+03, -.12007800E+03, 0.20099200E+02, 0.39035200E+02, -.37465100E+02, 0.85290000E+02, 0.86737000E+02, 0.36622900E+02, -.32201700E+02, 0.16285700E+02, -.36772000E+02, 0.45666500E+01, -.38611800E+02, -.45751600E+02, 0.55189000E+02, 0.33449500E+02, 0.41752500E+02, -.47809600E+02, 0.34462800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.94950800E+00, 0.72991700E+00, -.36812500E+00, 0.11776200E+00, -.57410000E-01, 0.12889600E+01, -.31967400E-01, 0.52780800E+00, -.51670900E+00, 0.72390000E+00, 0.13834200E+00, 0.20562800E+01, 0.33555500E-01, 0.92416100E+00, 0.33590300E+00, -.15176300E+00, 0.15654600E+01, 0.40380500E+01, 0.11745800E+01, 0.21585500E+00, -.10194000E+01, 0.72665500E+00, 0.52044800E+00, -.60491400E+00, -.75044200E+00, 0.40790300E+00, -.29380700E+01, 0.25840600E+00, -.55776500E-01, 0.44494300E+03, 0.11285800E+04, 0.24404900E+03, 0.17798500E+04, -.51000400E+03, -.57160300E+03, -.58331100E+03, 0.12054800E+03, 0.77069900E+03, 0.10402800E+03, -.43824700E+03, 0.63832800E+03, -.58292000E+03, -.91920700E+02, -.17817900E+03, 0.69944500E+03, 0.25463900E+03, 0.11882800E+04, 0.69128900E+02, -.55155800E+03, 0.60635200E+03, 0.51760400E+03, 0.29177200E+03, -.24327800E+02, -.20534000E+03, 0.51814600E+03, 0.42551300E+03, -.12329600E+04, 0.14002100E+03, 0.48078000E+02, 0.16185400E+03, -.16982600E+02, -.32220100E+03, -.24332800E+03, 0.11267500E+03, -.20633900E+03, 0.30973200E+03, -.62239500E+02, -.26577500E+03, 0.47104500E+03, 0.53848300E+03, 0.15043700E+04, -.14791600E+03, 0.66725000E+03, -.16943400E+03, -.20156500E+03, -.11765500E+03, -.72302800E+02, 0.26418400E+03, -.79125600E+02, -.15542500E+03, 0.44478400E+03, -.67869300E+02, 0.25374200E+02, -.16090400E+03, 0.43107800E+03, -.48402100E+03, -.80773900E+02, 0.17132600E+03, -.47875000E+02, 0.10999300E+03, -.87029000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15377600E+01, 0.15687400E+01, -.66130100E+00, 0.37005300E+00, -.86622800E+00, 0.33934200E+01, 0.82494400E+00, -.48001700E-01, 0.11415500E+01, -.88801200E+00, 0.61167300E+00, 0.25307500E+01, -.95623900E-01, 0.15239400E+01, 0.65015300E-01, -.94622100E-01, 0.10953200E+01, -.22847800E+01, -.20183500E+00, 0.18160700E+00, 0.23880300E+00, -.17109000E-01, 0.15642200E-01, 0.24265400E-01, 0.13722800E+01, 0.29896100E+00, 0.26758700E+01, 0.63184800E+00, -.47641500E+00, -.64774500E+00, 0.35315400E+03, 0.57724300E+02, 0.30487600E+03, -.16318900E+03, -.10479600E+03, -.11006400E+03, 0.74531000E+02, 0.84844100E+02, 0.13362700E+03, -.57802800E+02, 0.30861500E+02, 0.46762800E+02, -.88477000E+02, -.75590900E+02, 0.17461600E+03, 0.10057500E+02, 0.25338100E+03, -.27968300E+02, 0.42158300E+03, -.11028600E+03, -.62718300E+01, -.69899500E+02, -.12582900E+03, 0.49085300E+02, 0.18398900E+02, -.66769900E+02, -.15796300E+03, 0.81623100E+01, 0.30686200E+02, 0.50298000E+02, 0.78747900E+01, -.79513500E+01, 0.10068700E+03, 0.53201900E+02, -.18295900E+03, 0.88807100E+02, 0.12537800E+03, 0.96005100E+02, -.68710700E+02, -.88664100E+02, -.34251800E+02, 0.86913700E+02, 0.22182600E+03, 0.89725000E+02, -.81098700E+01, -.48371300E+02, -.34045800E+02, 0.53210500E+02, -.11230300E+03, -.48112100E+02, 0.36673700E+02, 0.43263200E+02, 0.14829000E+01, 0.13986100E+02, 0.37524800E+02, -.72820600E+02, 0.24130800E+02, 0.15925900E+02, -.40402200E+02, -.78311000E+01, -.12838400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.66037200E+00, 0.67349600E+00, -.48831400E+00, -.66102500E+00, -.15015200E+01, -.74638100E-01, -.92384900E+00, -.13777900E+01, 0.77085500E+00, -.10454200E+01, 0.60942300E+00, -.19811700E+00, -.14738500E+00, -.59396600E+00, 0.17508300E+00, -.55299600E-01, 0.12169000E+00, -.41224800E+00, 0.22400700E-01, 0.70986600E-01, -.50632900E+00, -.47931800E-01, -.11441100E-02, 0.53512000E-02, -.26655400E+00, 0.10472600E+00, -.87379400E+00, 0.25724700E+00, 0.22440200E+00, 0.28593700E+00, -.28183200E+00, 0.30894500E+02, 0.37198500E+02, 0.13036500E+02, -.18857700E+02, -.72590700E+01, -.16800900E+02, 0.64478100E+01, -.11794300E+02, 0.95600900E+01, 0.74376000E+02, 0.65654800E+02, 0.62487000E+02, 0.28477400E+02, -.14673700E+02, -.54588000E+01, -.22175100E+02, 0.41256800E+02, 0.22953700E+03, -.15548400E+03, -.12393100E+02, -.39553100E+02, -.47545800E+02, 0.50491500E+02, -.14773400E+02, -.50886400E+02, 0.40904500E+02, -.16160800E+02, -.50005300E+02, -.45839500E+02, 0.28787200E+02, 0.62124200E+02, 0.97536000E+02, -.38999500E+02, -.26031200E+03, 0.45981500E+02, 0.14525800E+01, 0.17334600E+02, 0.65887400E+02, -.83224700E+02, 0.15822100E+02, 0.10017900E+02, -.43970300E+02, 0.91733800E+02, 0.58469700E+01, 0.30473300E+02, 0.11684600E+01, -.49334900E+02, -.44098500E+02, 0.25946700E+02, 0.29112000E+02, -.45946200E+01, -.55839200E+01, -.11377800E+02, 0.31804200E+02, -.57205300E+02, -.10508000E+02, -.26306900E+02, -.95670200E+01, -.11389600E+02, 0.35464600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10011700E+01, -.15394000E+01, 0.63687400E+00, 0.14050200E+00, 0.11436800E+01, 0.16062800E+01, -.60820200E-01, -.74666200E+00, -.50156400E+00, 0.56436600E-01, 0.63127300E-01, -.19428600E+01, 0.23069700E-01, 0.11149700E+00, 0.39987800E+00, 0.27038300E+00, -.16088000E+00, -.24004000E+01, -.76281800E+00, -.25594100E-01, 0.52399700E+00, -.32123200E+00, -.39074400E-01, 0.17350800E+00, 0.24033700E+00, 0.18217600E-01, 0.30853400E+01, 0.69361500E+00, 0.52770100E+00, 0.48293200E-01, -.46609600E+00, 0.99767100E+00, 0.37255500E+03, -.28632600E+02, -.58103600E+02, -.11838700E+03, 0.49528800E+02, 0.20430600E+03, 0.79260700E+02, -.10528100E+03, -.21079000E+03, 0.22914500E+03, -.17626300E+03, -.11158400E+03, 0.19588300E+03, -.36445900E+02, 0.17223800E+03, -.96421100E+02, 0.26440300E+03, -.80031200E+02, -.65130300E+02, 0.53687900E+02, -.20695300E+03, 0.90592700E+02, -.13818300E+03, 0.56580800E+02, 0.41620500E+03, -.24332200E+02, 0.75964000E+02, 0.54526200E+02, -.13987200E+03, 0.10382200E+03, -.13730400E+03, 0.46556700E+02, 0.22964400E+03, -.53471500E+02, 0.23457100E+03, 0.29511900E+03, -.40998600E+03, -.14170800E+03, -.50623600E+03, 0.28974200E+03, -.28213300E+03, 0.29455500E+03, 0.15294700E+02, -.12169600E+03, 0.16169000E+03, 0.87134800E+02, 0.18269800E+03, -.10103200E+03, -.13805100E+03, 0.45088100E+02, -.22659100E+02, 0.48891600E+02, -.14756400E+03, 0.13429700E+03, 0.12554900E+03, 0.15720300E+02, 0.47716400E+02, -.32729400E+02, -.53573600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.84437600E+00, 0.11193800E+01, -.37255900E+00, 0.28637400E+00, -.71206500E+00, 0.21316600E+01, 0.30165900E+00, -.46906500E+00, 0.12588400E+01, -.14570800E+01, 0.56380600E+00, 0.26518400E+01, -.17381000E+00, 0.11515800E+01, -.19493600E-01, -.49675500E-01, -.78227900E-01, 0.16270300E+00, 0.31545200E+00, 0.60382200E-01, 0.22519200E+01, 0.39439500E+00, 0.11647600E-01, 0.36293700E+00, 0.74338100E+00, 0.47546500E+00, -.28382800E+00, -.23687300E+00, -.55814200E+00, -.16109500E+00, 0.12321500E+00, -.20081800E+00, 0.57711300E+00, -.32785000E+03, -.79960300E+02, -.49596900E+02, 0.17762600E+03, -.79460200E+01, -.15629300E+02, -.24958600E+02, 0.73482000E+02, 0.10353400E+02, 0.85378700E+02, -.53418500E+02, 0.33406600E+02, 0.75319500E+02, 0.12625200E+03, -.46630800E+02, -.32272700E+03, 0.15532400E+03, 0.18090800E+03, 0.20391100E+03, -.79917100E+02, -.21099400E+03, -.16160100E+03, 0.19370400E+03, -.25396900E+03, 0.79562000E+02, -.80366200E+02, -.78464700E+02, 0.13519400E+03, -.74747400E+02, 0.49711100E+02, -.61106100E+02, -.19350900E+03, 0.83882900E+02, -.55676800E+02, -.30529600E+02, 0.10246600E+03, -.24559000E+02, 0.28423500E+03, -.32452500E+02, 0.28782500E+03, -.15502000E+03, 0.14928700E+03, 0.30249700E+03, -.27984400E+03, -.12028200E+03, -.16573500E+03, 0.27712100E+03, 0.11905400E+03, -.17160800E+02, -.47524000E+02, -.55436100E+02, 0.10564900E+03, -.15716100E+03, -.64905300E+02, 0.66226200E+01, 0.28921700E+02, -.49123900E+02, 0.14224300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.16481600E+01, -.72260400E+00, 0.45644400E+00, 0.12900800E+00, 0.52852700E+00, -.28747100E+01, -.86915600E-03, -.25328500E+00, 0.12962100E+01, 0.20449700E+00, -.86584600E+00, -.77817800E-01, -.64938400E+00, -.77073700E-01, 0.15390500E+00, 0.25585100E+00, -.48665200E-01, -.41352700E+01, -.84010400E+00, 0.23825700E-01, -.12774400E+01, -.12666900E+01, 0.13297200E+00, 0.36886100E+00, 0.25454000E+00, -.75267300E+00, 0.34715300E+01, 0.16432400E+00, -.98024700E+00, -.11178100E+01, 0.66257300E+00, -.56593300E-01, 0.10019200E+01, -.37187200E+00, -.85383000E+02, -.66272900E+01, -.29061400E+02, -.11588100E+03, -.26811900E+03, -.34807600E+02, 0.53089200E+03, -.70353600E+03, 0.25865500E+03, 0.99779400E+02, -.11232500E+03, 0.13234000E+03, 0.14102500E+02, 0.12419500E+03, -.45217200E+03, 0.37550600E+03, 0.42589300E+03, 0.32465700E+03, -.38575000E+02, -.17031700E+03, 0.27310700E+03, 0.40380000E+03, -.85449500E+03, 0.18402900E+03, -.11872400E+03, -.55454500E+02, 0.20972900E+03, -.30198100E+03, -.82500400E+02, -.71126000E+02, 0.73367600E+03, 0.22832900E+02, -.34764500E+03, -.48129200E+03, 0.37151900E+03, 0.69360100E+03, 0.10947900E+04, -.40610700E+03, 0.59353300E+03, -.66050900E+03, -.10595300E+03, 0.83106600E+02, -.19390700E+03, 0.66925300E+02, -.54757700E+02, 0.54086400E+02, 0.32862900E+03, -.12849400E+03, 0.28814500E+02, -.12519600E+03, 0.28083300E+03, -.20727300E+03, -.21656900E+03, 0.51680400E+02, -.48236200E+02, 0.92510200E+02, -.12121200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10497700E+01, 0.40974700E+00, -.12633700E+00, 0.69462000E-01, -.15658400E+01, 0.25728300E+01, 0.20007500E+00, -.11347200E+01, 0.79580400E+00, -.11464900E+01, 0.11801400E+01, 0.17776100E+01, 0.15849000E+00, 0.57087100E+00, 0.28516200E-01, -.61222500E-04, -.38227000E-01, -.30914000E+01, -.14908900E+00, 0.14011000E+00, 0.20482600E+01, 0.27295000E+00, -.16680700E+00, 0.42599600E+00, -.19986200E+00, 0.23706800E-01, 0.16363800E+00, -.39007500E+00, -.24263600E+00, -.34984400E+00, 0.22820500E+00, 0.57585500E-01, 0.76709600E+00, 0.34271800E+00, 0.56646800E+00, -.22988500E+02, 0.70435400E+02, 0.53044800E+02, 0.14139300E+03, 0.82512300E+00, -.18914100E+03, 0.21408800E+03, -.52230800E+02, -.12005000E+02, 0.16803800E+02, -.49359400E+02, -.57619400E+02, -.35128600E+02, -.17388000E+03, 0.50924800E+02, -.67388500E+02, -.18957100E+02, 0.51403500E+02, -.10733600E+03, -.20679900E+03, -.64444200E+02, 0.11151400E+03, -.95467600E+02, 0.54193600E+02, 0.35219800E+02, -.30050900E+02, 0.29759800E+02, 0.41767000E+02, 0.56730500E+02, -.45895100E+03, 0.53107100E+02, 0.75655700E+02, 0.13482000E+03, -.38213500E+02, -.28152600E+03, -.24580500E+03, 0.94066900E+02, -.10444400E+03, 0.11233300E+03, -.26569500E+01, -.25022200E+02, 0.14530000E+02, -.24021900E+02, 0.23213000E+02, -.28146400E+02, -.96703300E+02, 0.48646900E+02, -.27026600E+02, 0.32204100E+02, -.80058300E+02, 0.49272200E+02, 0.63269200E+02, -.30954100E+01, 0.25031200E+02, -.54648300E+02, 0.14045100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.92277000E+00, -.81459300E+00, 0.48963900E+00, 0.67227200E+00, -.14920800E+00, 0.24629500E+01, 0.15918200E+01, 0.11403600E+01, -.18117100E+00, 0.29650000E+00, 0.50483200E-01, 0.34404600E+00, -.94797600E-01, -.14261500E+00, 0.27094800E+00, 0.10288900E+00, 0.19523800E+00, 0.84658200E+00, 0.41594400E+00, 0.14931000E+00, -.50164600E+00, 0.20411600E-03, 0.24210500E+00, -.22789000E+00, -.42820800E+00, 0.42796500E+00, -.80046900E+00, 0.41270900E+00, 0.52462100E+00, 0.44936700E+00, 0.26360600E+00, 0.11978200E+01, 0.46513000E+00, 0.93072800E-02, 0.59351100E-01, 0.20266400E+00, -.45503400E+02, -.86883200E+01, -.34892800E+02, -.87719200E+01, 0.14309000E+03, -.28421300E+03, 0.36776900E+02, 0.57201700E+02, -.20737700E+02, 0.36897400E+02, -.53151100E+01, 0.64148000E+02, -.41407600E+03, 0.19922700E+03, 0.17707400E+03, 0.15579700E+03, 0.40663400E+02, -.10188200E+03, 0.11831300E+03, 0.18066000E+03, -.18932000E+03, 0.10033000E+03, 0.83425700E+01, 0.27502400E+02, -.31348700E+02, -.13576100E+03, -.17855600E+03, 0.13603400E+02, 0.16831200E+03, 0.66306000E+02, -.40620200E+02, -.12255700E+03, 0.11199300E+03, 0.19504400E+03, 0.34715200E+03, -.89691700E+02, 0.13507700E+03, -.26993200E+03, -.42879400E+02, -.44594700E+02, -.69397600E+01, 0.73614600E+02, 0.19991800E+02, -.42738200E+02, 0.62454000E+02, -.62910900E+02, 0.11180300E+02, -.54401600E+02, 0.51873600E+02, -.37303600E+02, -.37244900E+02, 0.21855200E+02, 0.69751400E+01, 0.25732600E+02, -.51458300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.23726000E+01, -.40743100E+01, 0.29263700E+01, 0.20863400E+01, 0.19016000E+00, 0.40679200E+01, -.36309400E+01, -.22051700E+01, 0.49930800E+00, -.37377800E+01, 0.12367500E+01, 0.22832100E+01, -.57437300E+00, 0.12081000E+01, 0.18941600E+01, 0.75980700E-01, -.27153100E+01, 0.73406400E+01, 0.11717900E+01, -.21166800E+00, -.70525800E+00, -.11300600E+00, -.17290100E-03, -.11458900E+00, 0.49795700E+00, 0.13191600E+00, -.32858700E+01, -.33493100E+00, 0.25564500E+00, 0.13694200E+01, -.98497200E+00, -.16804000E+01, 0.12400700E+01, 0.11594300E+01, 0.16882200E-01, -.19966100E+01, 0.13263400E+01, 0.89723600E+02, 0.29765800E+03, 0.12630900E+02, -.41321300E+03, 0.58833600E+03, -.22467900E+03, -.20838300E+03, 0.76745200E+02, -.18063000E+03, -.13422000E+03, -.24229600E+03, 0.62870500E+03, -.17027800E+03, -.34756200E+03, -.32068300E+03, -.18127300E+02, 0.34868000E+03, -.24571200E+02, -.34325700E+03, 0.14081400E+03, -.27616300E+03, 0.13219300E+03, 0.13687400E+03, -.30040400E+02, 0.11493000E+03, 0.17558200E+03, 0.13946300E+03, -.56669500E+01, -.19524700E+03, 0.15618400E+03, 0.25355700E+03, -.23438100E+03, -.22420600E+03, -.62932800E+03, 0.23083300E+03, -.24706100E+03, 0.60553000E+03, -.61504500E+02, -.11714600E+03, 0.17501000E+03, -.44954100E+01, 0.10252600E+02, -.72524300E+02, -.22782000E+03, 0.11742000E+03, 0.56450900E+02, 0.14118800E+03, -.22194400E+03, 0.22392800E+03, 0.11553700E+03, 0.14581500E+02, -.93156600E+02, 0.43090400E+02, -.75631700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10058700E+01, -.20138600E+01, -.16013300E+00, -.61598600E+00, -.13812200E+00, 0.27306300E+01, 0.19184200E+01, 0.10488400E+01, -.12035200E+01, 0.18494200E+01, -.55891000E+00, 0.51333900E+00, 0.34152100E+00, 0.17939400E+01, -.37018600E+00, 0.13021600E+00, 0.17798500E+01, -.11921000E+01, 0.95230600E-01, 0.26384200E+00, 0.94021500E+00, -.10349500E+00, 0.27005000E+00, -.17505800E+00, 0.13295600E+01, -.12148300E+00, 0.18639900E+01, 0.56736900E+00, -.40427600E+00, -.64510000E+00, 0.17606400E+00, -.58676200E+00, -.32722700E+00, 0.27204900E+00, -.19139100E-01, -.26552000E+00, -.39205600E-01, 0.64471600E-01, -.47487100E+02, 0.24921900E+01, 0.30295300E+02, 0.48076600E+02, 0.57113800E+02, 0.83662000E+02, -.42420500E+02, -.61673200E+01, -.40745900E+02, 0.88738500E+02, 0.23576400E+03, -.20299000E+03, -.48544600E+02, -.72306700E+02, 0.36034300E-01, 0.31102600E+02, -.68759400E+01, -.81108900E+02, 0.15695900E+03, -.19527000E+02, -.26703600E+02, -.40349700E+02, -.17003200E+02, 0.91539600E+02, 0.75776600E+02, -.34047300E+02, -.39727000E+03, 0.94597800E+02, 0.27029700E+02, 0.41300600E+02, 0.62348400E+02, -.15187100E+03, -.66209800E+02, 0.27670100E+02, -.58787300E+02, 0.61413000E+02, 0.18908400E+02, 0.79996700E+01, -.49524200E+01, 0.27237900E+01, -.62589200E+02, 0.76286200E+01, 0.45731500E+01, -.80821800E+01, -.55515200E+01, -.15232400E+02, 0.19742500E+02, -.28288000E+02, 0.72333700E+01, -.38461300E+02, 0.53898800E+01, -.20013800E+02, 0.18509700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.61426100E+00, 0.89284000E+00, -.39604700E+00, -.39523100E+00, -.10361700E+00, -.15595400E+01, -.13025700E+01, -.12271600E+01, 0.72080100E+00, -.90101300E+00, 0.42750000E-01, 0.18327400E+01, -.29844500E+00, 0.49851700E+00, 0.17429400E+00, -.11092300E+00, 0.30022700E+00, -.30234300E+00, -.22891100E+00, 0.69999900E-01, 0.71218100E+00, 0.18597700E+00, 0.58725900E-01, 0.14356000E+00, 0.42975900E+00, 0.29659800E+00, 0.33525300E-01, 0.42060000E+00, -.16745100E+00, 0.79237400E-01, 0.20128500E+00, 0.22133400E+00, -.17730200E+00, 0.11167100E+00, -.28346600E+00, 0.61075300E-01, 0.35196800E-01, -.22725500E+00, 0.32755000E+00, -.75416000E+01, -.15583000E+02, 0.25892500E+02, -.54432500E+02, -.68530900E+02, 0.49780700E+02, 0.57860500E+01, 0.58189800E+02, -.60996200E+02, 0.49360000E+02, 0.46715000E+01, -.24636700E+02, -.15094000E+02, -.18461400E+02, 0.84754500E+02, 0.54090500E+02, 0.13428500E+01, -.19314900E+02, 0.30453800E+01, 0.77889700E+00, 0.40317500E+01, 0.41903500E+01, -.13435800E+02, -.18275600E+02, -.42021100E+01, 0.31487100E+03, -.10294400E+03, -.11627000E+02, -.16265400E+02, -.66675800E+02, 0.96941500E+02, -.56872200E+01, 0.15895500E+00, 0.13498700E+02, 0.85173400E+02, 0.56063400E+02, 0.38762200E+02, -.11837900E+02, -.26620100E+02, -.22899700E+02, 0.42366500E+02, -.44910800E+01, -.52536800E+01, 0.15513700E+02, 0.10444700E+01, -.15733300E+02, 0.25343000E+02, 0.24822900E+01, 0.35517000E+01, -.93322900E+01, 0.28787600E+02, 0.10663400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18121300E+01, -.25427500E+01, 0.48914200E+00, -.46997200E+00, 0.39189400E+01, -.15054500E+00, 0.94914400E+00, 0.16698500E+01, -.20331100E+01, 0.31643100E+01, -.10638400E+01, -.44495000E+01, 0.22142800E+00, -.94527500E+00, 0.74153800E-01, 0.37974800E+00, 0.12972000E+01, -.28904800E+01, -.46122300E+00, 0.11601000E+00, -.16315400E+01, 0.13388800E+00, -.22589800E-01, -.26404200E+00, -.44779100E+00, 0.27855700E+00, 0.12280300E+01, 0.50288000E+00, 0.71302500E+00, 0.13719900E-01, 0.66826000E+00, 0.78560700E+00, -.62843100E+00, -.10567900E+01, -.10537700E+00, 0.63678600E+00, -.76613500E-01, -.10609000E+00, 0.78807500E+00, 0.15035200E+01, 0.23201500E+03, -.91213900E+02, 0.64400900E+02, 0.31118500E+02, -.39711700E+02, 0.12654900E+03, 0.23373700E+02, 0.35695500E+02, -.33841700E+03, 0.11984800E+03, 0.81970700E+02, 0.10192400E+03, 0.84825400E+02, -.10740500E+03, -.14526400E+02, 0.93910800E+02, -.51093700E+02, 0.47752200E+02, -.22327800E+02, -.31476200E+02, -.92382500E+01, -.87772700E+02, -.97533200E+02, -.34878300E+02, -.19952600E+03, 0.39173400E+02, -.47070800E+02, -.58002100E+02, 0.12319200E+03, -.39829100E+02, 0.13540000E+03, -.61739200E+02, 0.95289400E+02, -.11775000E+03, -.20112000E+01, 0.48777400E+02, -.55008600E+02, 0.11275900E+02, 0.21558500E+02, 0.41151000E+02, 0.92757300E+02, -.76762700E+01, -.42157500E+02, -.12087000E+02, 0.78733700E+02, -.81151200E+02, -.55419200E+02, 0.21785100E+02, 0.67674100E+02, -.49111900E+02, 0.40000900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.94451400E+00, 0.18597900E+01, 0.13519700E+00, 0.74878800E+00, -.41039800E+00, -.45945400E+00, -.13819600E+01, -.11345200E+01, 0.11653500E+01, -.24232100E+01, 0.59786500E+00, -.49976400E+00, -.64320400E+00, -.16960500E+01, 0.98568900E+00, -.22736100E+00, -.71406000E+00, 0.18246000E+01, 0.40516900E+00, -.10236300E+00, -.15859300E+01, 0.14157400E+00, -.19516300E+00, 0.20903700E+00, -.10095000E+01, -.16190000E+00, -.17321600E+01, -.87237000E+00, 0.76078600E-01, 0.46039900E+00, -.43131800E+00, 0.86472800E+00, -.32614500E+00, -.58467500E+00, -.27911100E+00, 0.13284900E+00, -.86398900E+00, -.20851800E+00, 0.56247000E+00, 0.83723000E+00, -.14221200E+00, -.16467300E+03, -.31307900E+02, -.53001100E+02, 0.42540400E+02, 0.43924500E+02, 0.95223000E+02, -.49903700E+02, -.36227800E+03, 0.24095000E+03, 0.10565100E+03, 0.13612700E+03, 0.17329600E+02, -.56058900E+02, 0.25328000E+02, 0.14985800E+03, -.15494400E+03, 0.86011400E+02, 0.33908200E+02, 0.41435200E+02, -.13536700E+02, -.13697200E+03, -.17227400E+03, 0.27606100E+02, 0.33705200E+03, -.21948000E+02, -.79382600E+01, -.49373800E+02, -.21990100E+02, 0.15764400E+03, 0.13956100E+03, -.31453200E+02, -.61867700E+02, -.16252500E+03, -.56255200E+02, -.35437100E+02, 0.63008600E+02, 0.29673600E+02, 0.13245300E+03, -.41526300E+02, 0.12522200E+02, -.12348400E+02, -.12483200E+02, -.89345600E+01, 0.38469900E+01, -.58761100E+01, -.10929300E+02, 0.44084900E+02, 0.27639900E+02, -.63476100E+01, -.39751700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.30571400E+01, 0.39615900E+01, -.26869800E+01, -.12535000E+01, -.10106600E+01, 0.42015500E+00, 0.47223400E+01, 0.14320000E+01, -.84928700E-01, 0.18558200E+01, -.99417700E+00, -.28718600E+01, 0.10704000E+00, -.10786100E+01, -.10910700E+01, 0.45423900E-01, 0.20847200E+01, -.89894600E+01, -.18075800E+01, 0.22659600E+00, -.11771600E+01, -.78346100E+00, -.43772700E+00, 0.59599600E-01, 0.80156100E+00, 0.82854300E-01, 0.23225900E+01, 0.82318000E-01, 0.21462900E+00, -.18956900E+01, -.11813100E+00, 0.40246400E+01, 0.74910500E-02, 0.46360000E+00, -.54423800E+00, 0.46115400E+00, -.91073500E+00, -.10801700E+01, -.48063100E+00, -.22262000E+01, -.14303000E+00, -.31152200E-01, -.18443400E+03, -.11040700E+03, 0.67322300E+02, -.62978400E+02, -.43110900E+02, -.10246800E+03, -.37388000E+03, 0.30360800E+03, 0.23261000E+02, -.14944500E+02, 0.10127200E+03, 0.50093700E+02, 0.27429800E+03, 0.30446000E+02, -.63057500E+03, -.16073500E+03, 0.74328900E+02, 0.64256200E+02, 0.11754600E+03, -.16725100E+03, 0.54892200E+02, 0.43736400E+02, 0.33000900E+03, -.15182200E+03, -.12011100E+03, -.14005900E+03, 0.64980600E+02, 0.27909100E+03, 0.38038700E+03, -.11951900E+03, 0.56583200E+03, 0.19457200E+03, 0.67342400E+01, 0.94456500E+01, -.15345500E+03, 0.16433200E+03, -.20413800E+03, 0.29843900E+02, 0.10638200E+02, -.24502200E+02, 0.90534600E+02, -.96838200E+01, -.13429900E+02, 0.24165700E+02, -.10314200E+02, 0.62490900E+02, -.67300700E+02, 0.13987500E+03, -.32336600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23274400E+01, -.23895800E+01, 0.20500300E+00, -.10255800E+01, 0.22467700E+01, 0.16660700E+01, 0.15978600E+01, 0.80866200E+00, 0.47738700E+00, 0.10655800E+01, -.87247900E-01, -.56437800E+01, 0.45969800E+00, -.84530400E+00, -.88870900E+00, 0.55447000E+00, -.68641500E+00, -.53009000E+01, -.66987100E+00, -.23989900E-01, -.12102200E+01, -.10867700E+01, -.14008200E+00, 0.54838800E+00, -.22582600E+00, -.37140800E+00, 0.74569100E+01, 0.93376500E+00, -.23548100E+00, -.31521800E+00, -.36576000E+00, 0.21829100E+00, -.44399300E+00, -.14988300E+01, -.60204900E-01, 0.32892800E+00, -.83979900E+00, 0.20519800E+00, 0.18574900E+01, 0.10315100E+01, 0.54919700E-01, 0.12573600E+01, 0.18441800E-01, -.86046600E+02, 0.13664800E+03, 0.84654300E+02, 0.27772600E+03, -.67135900E+02, 0.47879400E+03, -.68845700E+02, 0.26461700E+01, 0.15244500E+03, -.25482100E+03, 0.13313000E+03, -.18202900E+03, 0.16243100E+03, 0.41797600E+03, 0.24354800E+02, -.30127800E+02, -.15640500E+02, -.12674300E+03, 0.57938100E+02, -.19116800E+03, -.21491100E+02, 0.58193300E+03, -.30821700E+02, 0.11621600E+03, 0.17650100E+03, -.29319400E+03, 0.48409400E+02, -.31959300E+03, 0.19032800E+03, -.28988900E+03, 0.92989500E+02, 0.28288400E+02, -.50118200E+02, 0.16942100E+03, 0.37216000E+01, 0.30936200E+03, -.45880600E+02, -.21754700E+02, 0.42841300E+02, -.67221800E+02, 0.40807000E+02, -.37479900E+02, 0.41684600E+02, 0.38125900E+02, 0.21264600E+02, 0.89326000E+02, -.77666100E+02, 0.50438100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.14292500E+01, -.78931200E+00, 0.49180600E+00, 0.10412300E+01, 0.27668600E+00, 0.32326700E+01, 0.29473000E+01, 0.22215100E+01, 0.70126200E+00, 0.42949700E+00, -.44415400E+00, 0.43679000E+01, -.95631900E+00, 0.59901800E+00, 0.14677600E+01, -.29218900E+00, 0.43168100E+01, -.27175300E+01, 0.47474000E+00, 0.57451800E+00, -.32723900E+01, 0.44369200E+00, 0.58934700E+00, -.11039000E+01, -.32516000E+00, 0.15702000E+00, 0.11441000E+01, 0.11779100E+01, -.82049000E+00, -.27366400E+00, 0.62374600E+00, 0.21278500E+01, 0.27193900E+00, -.57020800E+00, 0.23994400E+00, 0.20850300E+00, -.56390700E+00, -.59778600E+00, -.78924700E-02, 0.46663000E+00, -.14493400E+00, 0.15785300E+00, 0.36067000E+00, -.42517200E+00, 0.69518000E+02, 0.35521600E+02, 0.12904900E+03, 0.11467700E+02, 0.17950700E+03, -.47543200E+02, 0.24712300E+02, 0.68228900E+02, -.89557200E+02, 0.46708800E+02, -.77318800E+02, 0.78728900E+02, 0.30791100E+03, 0.29169200E+02, 0.34746100E+01, -.66986300E+01, -.11766700E+03, 0.48879600E+02, -.13159300E+03, -.10047200E+02, 0.30506900E+03, -.17385800E+02, 0.27874000E+02, 0.25469500E+02, -.95412900E+02, 0.65787900E+02, -.90084700E+02, 0.44480700E+02, -.28544500E+03, -.15490900E+02, -.43407800E+02, -.44493200E+02, 0.14048600E+03, -.48546100E+02, 0.17503800E+03, -.47641400E+02, -.19122300E+02, -.32075100E+01, -.28282000E+02, -.62425700E+01, -.18564400E+02, 0.17156900E+02, 0.32633700E+02, -.69446100E+01, 0.53262400E+02, -.27492900E+02, -.54192600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.72839400E+00, 0.73822200E+00, -.49235400E+00, -.59419400E+00, -.13191800E+01, 0.19495300E+00, -.84884200E+00, -.62075100E+00, 0.59731500E+00, -.69153400E+00, 0.62687700E+00, 0.71949400E+00, 0.21538000E+00, 0.13382900E+00, -.44416400E+00, 0.99047000E-02, -.97596200E+00, 0.12257300E+01, 0.11595000E+01, 0.15714800E+00, 0.12003900E+00, -.80858800E-01, -.32417000E+00, 0.11804000E+00, 0.97062000E+00, 0.40787900E+00, 0.12538200E+01, 0.83423800E+00, 0.39896700E+00, 0.45084200E-01, 0.94264100E-01, 0.86145000E+00, 0.37659100E+00, -.27461800E+00, 0.33118300E+00, 0.16072200E+00, -.17700900E-01, 0.17250500E+00, 0.25028400E+00, 0.21343200E+00, 0.27810200E+00, -.55891700E-01, -.54480600E-02, -.23366700E+00, 0.89182500E-01, 0.30183500E+02, 0.42359700E+02, 0.12876300E+01, -.82888500E+02, 0.21822600E+02, -.52354800E+01, 0.12838900E+02, 0.36103400E+02, -.33973900E+02, -.27122600E+02, 0.74730400E+01, 0.96939500E+02, 0.18051600E+02, -.62567500E+01, -.11314200E+02, -.32516900E+02, 0.84492700E+01, -.38579400E+02, -.95101500E+01, -.44848400E+02, 0.25651900E+02, 0.37262500E+01, 0.57665400E+01, 0.12029600E+02, -.28586100E+02, -.65110700E+01, 0.46960800E+01, -.24540600E+02, -.30613100E+02, 0.31967200E+02, 0.30662500E+02, -.92975300E+01, -.32430800E+02, 0.88854000E+01, 0.25206100E+02, 0.11224700E+01, -.15651700E+01, -.11092300E+02, -.61613000E+01, 0.71266700E+01, -.91843600E+01, -.16483200E+01, -.65696800E+01, 0.21545400E+02, -.16529300E+02, 0.20265100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.40507000E+01, 0.31571500E+01, 0.12388100E+00, 0.14826700E+01, -.37660300E+01, -.44280700E+01, -.24894400E+01, -.22374100E+01, -.34160100E+00, -.25010000E+01, 0.42174800E+00, 0.22264700E+01, 0.15556200E+00, 0.18361600E+01, 0.68110400E+00, -.36555600E+00, -.18653700E+01, 0.72412700E+01, 0.37282000E+00, -.31130600E+00, 0.64284800E+01, 0.55367000E+00, 0.48389800E+00, 0.50089500E-01, 0.18182900E+01, -.17527200E+01, -.28158700E+01, -.99488200E+00, 0.39061600E+00, 0.19193000E+00, -.12038100E+01, -.19095400E+01, -.40937600E+00, 0.11501900E+01, 0.48240100E-02, -.12067700E+01, 0.49447600E+00, 0.82334000E+00, 0.90590700E+00, -.29074200E+01, -.10305500E+00, 0.98604600E+00, 0.21140500E+00, -.12975400E+00, -.61128000E+00, -.39161700E+01, 0.13103000E+03, 0.32507500E+01, 0.10151300E+04, -.31721100E+03, -.52564100E+02, 0.11953500E+02, -.49442400E+03, 0.12057200E+03, -.39859300E+03, -.12844300E+02, 0.51616000E+03, 0.20785000E+03, -.10240700E+03, -.99283300E+02, -.66004400E+01, 0.23479300E+03, 0.98077300E+02, -.81258400E+02, 0.60012900E+03, 0.37106600E+02, 0.23179800E+03, 0.22038400E+03, -.49663200E+03, -.23864900E+02, -.55609400E+03, 0.21177500E+03, -.25069900E+03, -.35791500E+02, 0.15696400E+03, -.22595100E+01, 0.11881700E+03, -.67419100E+02, 0.25990800E+03, -.13167000E+01, -.15420700E+02, 0.47948500E+02, -.43099900E+02, 0.39097200E+02, -.46428100E+01, 0.93746800E+01, 0.96968600E+01, -.75464600E+02, 0.39155400E+01, -.65405900E+02, 0.38124000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.64086300E+00, 0.84202400E+00, -.44877500E+00, -.23366000E+00, -.84794100E+00, 0.10244600E+01, -.16917300E+00, 0.20161200E+00, 0.62531100E+00, -.52987200E+00, 0.46975000E+00, 0.17696500E+01, 0.16936000E-01, 0.26616500E+00, -.15431000E+00, -.88277300E-01, -.11773700E+00, 0.14465600E+01, 0.91313100E+00, 0.11651300E+00, -.12594900E+01, -.18018700E+00, -.60937600E-01, 0.12958100E-01, 0.17743700E+00, 0.44864100E+00, -.21163700E+00, -.26222000E+00, -.28241100E+00, -.83682700E-01, 0.40821300E-01, -.81102300E+00, -.43339200E+00, 0.97953500E-01, -.86249500E-01, -.25794500E+00, -.83440800E-01, 0.11915100E+00, 0.45722100E+00, 0.73997600E-02, -.27435400E-01, 0.21009400E+00, 0.37045200E-01, 0.14420800E+00, 0.26691100E+00, -.68518900E+00, -.13234900E-01, -.24529700E+01, -.36612900E+02, 0.52211500E+01, 0.54973900E+01, 0.16109000E+02, -.17360200E+02, -.51310900E+02, -.48810000E+02, 0.67206500E+01, 0.21454200E+02, 0.20869700E+02, -.11490700E+02, -.95660200E+01, 0.60793000E+01, 0.13063000E+02, 0.89859700E+01, -.54592900E+01, -.53663600E+02, 0.27135200E+02, 0.13390700E+02, 0.21181400E+02, -.18852900E+02, -.39685300E+02, -.29988200E+02, 0.14742800E+02, 0.43780800E+02, -.18260600E+02, 0.36038700E+02, 0.22450000E+02, -.33845100E+02, -.93458400E+01, -.18022700E+02, 0.21284400E+02, 0.26582800E+01, 0.40409600E+01, -.48482300E+01, 0.17647700E+01, 0.10887600E+01, -.23240100E+01, -.24951700E+01, -.62583500E+01, 0.23478400E+00, -.98634900E+01, 0.13597500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.26366100E+01, 0.35320700E+01, -.58324400E+00, 0.59361400E+00, -.25118400E+01, -.27210600E+01, -.20470800E+01, -.13753600E+01, 0.16621300E+01, -.34010300E+01, 0.67599800E+00, 0.27521800E+01, -.16323400E+00, -.58860600E+00, -.38509300E+00, -.67508700E+00, -.24324900E+01, 0.20533900E+01, -.99551900E+00, -.68579200E+00, 0.23957500E+01, 0.11759500E+00, -.51537500E+00, 0.81329800E+00, 0.57842800E+00, -.24443100E+00, 0.89426700E+00, -.82976100E+00, -.61665400E+00, -.44262500E+00, -.43845700E+00, -.16982600E+01, 0.21304800E+00, 0.12364000E+01, -.38713500E+00, -.13368700E+01, 0.60453200E+00, 0.10529700E+00, -.16453800E+01, -.89488600E+00, -.10762400E+01, -.83999000E+00, -.28906800E+00, -.21259700E+00, 0.47478900E+00, 0.68469500E+00, -.25050600E+00, -.30297000E+00, 0.45772200E+03, -.13725700E+03, -.11553000E+03, -.11077600E+03, -.40354200E+02, 0.17553400E+03, 0.20300000E+02, -.11149100E+03, 0.84881900E+01, -.33949200E+02, -.23353500E+02, -.27998600E+02, 0.52854600E+02, 0.42029400E+02, 0.11964900E+03, -.29003500E+02, 0.20318000E+03, -.48232700E+02, 0.35855000E+02, 0.48811000E+02, -.12473700E+03, 0.19700900E+02, -.22600100E+03, 0.29131300E+02, -.20270200E+03, 0.12472200E+03, 0.21778600E+01, -.53423600E+02, 0.10055500E+03, 0.31906700E+02, 0.10484700E+03, -.52653800E+02, -.18645500E+02, 0.46515000E+02, -.12142300E+02, 0.48863300E+02, -.19540600E+02, 0.25851200E+02, 0.16118900E+02, 0.91628000E+01, 0.22662300E+01, -.19972600E+02, -.10626200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.32558300E+01, -.20337000E+01, 0.23713200E+01, 0.20308000E+01, -.19011200E+01, 0.39474600E+01, -.26128700E+01, -.31555800E+01, 0.40033600E+01, -.82970200E+01, 0.18904000E+01, 0.47643400E+01, -.17304300E+01, -.30472700E-01, 0.22590400E+01, -.52362400E+00, -.29373200E+01, 0.35447500E+01, 0.14074800E+01, -.80537900E-01, -.20317300E+01, 0.16038500E+00, -.82186700E+00, 0.74955100E+00, -.10503900E+01, -.25840600E-01, -.13304800E+01, -.13497800E+01, 0.47927500E+00, 0.97725300E+00, -.86043100E+00, -.11335800E+01, 0.91751800E+00, -.14086100E+01, 0.92245100E+00, 0.85612900E+00, -.24602500E+01, -.11394900E+00, 0.60760100E+00, 0.34646800E+01, 0.29646800E+00, 0.12524800E+01, -.13434900E+00, 0.21451200E+00, -.45479400E+00, 0.11682700E+01, -.32637600E+00, -.11162600E+01, -.71226600E-01, -.15490600E+03, -.71127800E+01, -.60551200E+02, 0.29140600E+02, -.13101700E+03, -.12615300E+02, -.96586000E+02, 0.34339000E+03, 0.20739600E+03, -.41373300E+02, -.37388500E+02, -.49251400E+02, 0.15372800E+03, 0.18595400E+02, -.21698000E+02, -.54958500E+03, 0.25766500E+03, 0.16254200E+03, 0.11648600E+03, 0.28217400E+02, -.18389200E+03, -.90619500E+02, 0.10361700E+03, 0.13415900E+03, -.32895500E+03, 0.70121300E+02, 0.62079800E+02, -.88405700E+02, 0.27700300E+02, -.38175100E+02, 0.67501300E+02, 0.42417500E+01, -.32063200E+02, 0.71009200E+01, -.34719500E+02, -.15792100E+01, -.80207400E+01, -.42013200E+01, -.67627100E+02, -.43574800E+02, -.19110900E+02, -.73636500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.51176100E+01, -.76812000E+01, 0.11306700E+01, -.13348200E+01, 0.10800400E+02, -.50922200E+01, 0.44334600E+01, 0.60964100E+01, -.75326100E+01, 0.11591900E+02, -.49804700E+01, -.14407000E+02, 0.85282800E+00, -.27368500E+01, -.61647000E+00, 0.90203800E+00, 0.47603900E+01, -.90608500E+01, -.29929800E+01, 0.12313000E+00, -.58299600E+01, -.99395000E-01, -.41025500E-01, -.11202400E+01, -.41780200E+00, -.51013900E+00, 0.59892600E+01, 0.18905000E+01, 0.48253000E+00, -.11852700E+01, 0.11516800E+01, 0.30926400E+01, -.21002500E+01, -.26464700E+01, -.70645100E+00, 0.12718300E+00, -.49330900E+00, -.49069800E+00, 0.26649000E+01, 0.34302000E-01, 0.24942800E+01, 0.65697900E+00, 0.98230900E+00, 0.23873000E-01, 0.22599000E+00, -.35259500E+01, 0.96335600E+00, -.79240100E-01, -.10546200E+01, 0.36064100E+00, -.18506600E+03, -.18827600E+03, 0.25458800E+03, 0.22245100E+03, 0.23136300E+03, -.17899600E+03, -.23621800E+03, -.14574900E+03, 0.14666900E+02, 0.11604800E+02, 0.61949100E+02, -.89803300E+02, 0.83395000E+02, 0.28742100E+01, 0.14675500E+03, -.20720100E+03, -.12700000E+03, -.95725300E+02, 0.75868300E+02, 0.61930900E+02, -.20319500E+02, -.11450300E+03, -.27767700E+03, 0.27826600E+03, 0.11468800E+02, -.16157700E+02, 0.69954000E+02, -.52696100E+02, -.10404900E+02, -.27081100E+02, -.94000100E+01, 0.44086100E+02, 0.15328900E+01, 0.45075300E+02, -.38388000E+01, 0.13647600E+02, 0.10206000E+02, 0.46682800E+02, 0.16700700E+02, 0.55265400E+01, 0.11596800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.15675400E+01, -.17656300E+01, 0.59533300E+00, -.14537300E+00, 0.26689700E+01, 0.49289000E+00, -.33824900E+00, -.41348600E+00, -.99647100E+00, 0.62134400E+00, -.33953700E+00, -.45730900E+01, -.15773600E+00, -.14570900E+01, 0.70929000E+00, 0.29567300E+00, 0.21313900E+00, -.10485600E+01, -.11540400E+01, -.33844400E+00, 0.21005200E+00, -.25685000E+00, 0.31590000E+00, 0.29484000E+00, -.12067100E+01, -.24406000E+00, 0.16539000E+01, 0.84298000E-01, 0.73633700E+00, 0.50935800E+00, -.77667000E+00, 0.57701500E+00, -.25219400E+00, -.99439400E-01, -.69058400E+00, 0.45927600E-01, 0.25937900E-01, -.17112900E+00, -.44623300E+00, 0.36972000E-01, -.43409400E+00, -.35857500E+00, 0.25858400E-01, 0.15049700E+00, 0.59808100E+00, -.13781900E+01, 0.94260300E-01, -.81428600E+00, 0.31117000E+00, 0.37524500E+00, -.80734700E-01, 0.60411400E+02, -.53161400E+02, 0.40650300E+02, -.40563400E+02, 0.63326400E+02, -.11165000E+03, -.16130500E+02, 0.12440500E+02, 0.10370000E+02, 0.16487000E+02, -.61841900E+02, -.49123500E+02, 0.22837500E+01, 0.37713300E+02, -.34590700E+02, 0.22850100E+00, 0.39503300E+02, -.62152200E+02, -.54700600E+02, -.86331300E+02, 0.33599600E+02, -.12373400E+02, 0.17666100E+03, 0.34470200E+02, 0.83485600E+01, -.17030200E+02, -.13518800E+02, -.51037400E+02, 0.62797500E+01, 0.10267300E+01, 0.11070800E+02, -.16705600E+02, 0.10864800E+02, 0.10341200E+01, -.68769700E+01, -.52957200E-01, 0.14820800E+02, 0.30813600E+02, -.23190100E+02, 0.22379900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.80118800E+00, 0.72674700E+00, -.36643900E+00, -.39921100E+00, 0.10455000E+00, -.20023700E+01, -.16433900E+01, -.86410100E+00, -.32739200E+00, 0.54302600E+00, -.67218000E-01, 0.53668100E+00, 0.12958000E+00, 0.61804700E+00, -.15583700E+00, -.11049100E-01, 0.58573400E-01, 0.32603000E+01, 0.54033900E+00, -.99347700E-01, 0.12565700E+01, 0.32718500E+00, 0.44132000E+00, -.10224000E+00, -.56846900E-01, -.22704100E+00, -.22812600E+00, -.10017900E+00, -.55726400E-01, 0.25023700E+00, 0.27819300E+00, -.80842700E+00, 0.12859200E+00, 0.16174500E+00, 0.99746400E-01, -.31995700E+00, 0.68139700E+00, 0.25274400E+00, -.98615600E-01, -.19449800E+00, 0.80413500E-01, 0.46628800E-01, -.25680800E+00, -.34847100E-01, -.35325900E+00, -.80926000E+00, 0.14875900E+00, 0.65639800E+00, 0.76480600E-02, -.41996900E-02, 0.10073600E-01, -.41860400E+00, 0.24843600E+02, 0.60628400E+02, 0.57304100E+02, 0.19722500E+01, -.38442100E+02, -.98616900E+01, 0.12995400E+02, 0.13240300E+02, -.97561700E+01, -.25148700E+02, -.31210000E+02, 0.10874600E+02, 0.48974500E+02, -.24236900E+01, -.21956400E+02, -.73162800E+01, 0.19115900E+01, 0.13854800E+02, -.15673800E+02, -.14402600E+02, -.54197400E+02, 0.80573600E+02, -.16647100E+02, -.18221000E+02, 0.28087700E+02, 0.52887400E+01, -.34968000E+01, -.21369900E+02, -.50140100E+01, 0.48343400E+00, -.23113300E+01, 0.24503600E+01, -.32362300E+01, 0.29374800E+01, 0.41317400E+01, 0.18042900E+02, 0.82635100E+01, -.77061100E+01, -.61478700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.60837400E+00, -.70990200E+00, 0.38651600E+00, -.91085900E-01, 0.32185200E+00, -.13956300E+01, -.47182200E+00, -.23878000E+00, -.46521100E+00, 0.43232400E+00, -.62421500E-01, -.59239700E+00, 0.12118000E+00, -.43662400E+00, -.31785900E-04, -.30606900E-01, 0.21452900E+00, 0.42302700E+00, 0.61408500E-01, 0.15196900E-01, -.81268600E+00, 0.51635900E-01, -.29030400E-02, -.96902900E-01, -.61841700E+00, 0.53899700E-01, -.10257400E+01, -.33382600E+00, 0.26406000E+00, 0.19272200E+00, -.22733400E+00, 0.93923300E-01, -.42440200E+00, -.15742700E+00, -.16861500E+00, 0.41059400E+00, -.52211500E+00, -.13867900E+00, 0.15806600E+00, -.22843000E+00, -.90815000E-01, 0.26234600E+00, 0.74251500E-02, 0.59894100E-01, -.14955300E+00, -.29521600E+00, -.11390500E-01, 0.34129900E+00, 0.10347900E-01, 0.73529100E-01, 0.53873300E-02, 0.26612800E-01, 0.92162600E-01, 0.57978900E+02, 0.37886500E+02, 0.97838400E+01, -.23586700E+02, 0.13513600E+02, 0.11253900E+02, 0.18557100E+02, -.92055900E+01, -.34604300E+02, -.34536500E+02, 0.16989700E+02, 0.18114900E+03, -.63951200E+02, -.13019400E+02, -.26890600E+02, -.30308100E+02, 0.61386800E+02, 0.25124400E+02, -.18139200E+02, -.47727600E+02, 0.36734700E+02, 0.12685800E+02, 0.58225700E+01, -.24550700E+01, -.41006300E+02, -.81482600E+01, 0.12574400E+01, 0.52825600E+01, -.78644300E+01, 0.17080200E+01, -.75276400E+01, 0.56543600E+01, -.49234700E+01, -.45653900E+01, 0.32849500E+01, -.80691000E+00, 0.92230400E+01, 0.37594800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.95004100E+00, 0.95687600E+00, -.53637300E+00, -.27428000E+00, -.18820100E+01, 0.24121300E+01, -.74853300E-01, -.13771900E+00, 0.10290200E+01, -.99923800E+00, 0.10065800E+01, 0.30726000E+01, 0.12499900E+00, 0.84028300E+00, -.22634900E+00, -.92075300E-01, -.11255700E+00, 0.23350300E+00, 0.13745300E+01, 0.43830700E+00, -.14287100E+01, -.77611400E-01, -.35518500E+00, -.13702900E+00, 0.12141700E+01, 0.94669200E+00, 0.79568300E+00, 0.33368000E+00, -.10653900E+00, -.11270400E+00, -.15565900E-01, -.61282700E+00, -.28543300E-01, -.14134700E+00, 0.19680100E+00, -.22188900E-01, -.21380200E+00, 0.87872100E-01, 0.19972900E+00, -.11293800E+00, 0.22806000E+00, -.36149500E+00, 0.13935000E+00, 0.38277700E+00, -.32101600E+00, 0.43083200E+00, -.50373300E-01, 0.89143200E-01, -.14935500E+00, 0.15757600E+00, -.52083300E-01, -.28295300E+00, -.41887500E+00, 0.10020900E+01, -.18665700E+02, -.47339000E+01, -.54562900E+02, -.20659300E+02, 0.23975800E+00, -.11551500E+02, 0.18700500E+02, -.51231300E+01, 0.16796000E+02, -.16844700E+02, -.59717100E+02, 0.67325700E+01, -.23090300E+02, -.52627800E+01, 0.25020000E+02, -.34416500E+02, -.32938400E+02, -.14650200E+02, -.10427500E+03, 0.67271900E+02, -.39116900E+02, -.18718800E+02, 0.63538400E+02, -.23069700E+01, 0.19212200E+02, -.18349500E+02, -.80755000E+01, 0.10988400E+02, -.67597700E+01, 0.12122100E+02, -.60153500E+01, 0.23765900E+01, 0.69039900E+01, 0.88772500E+01, 0.13845400E+02, -.15837900E+02, 0.35445700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.74107600E+00, 0.65476600E+00, -.51085600E+00, -.23794200E+00, -.16642400E+01, 0.29240800E+01, 0.64851800E+00, -.22253900E+00, 0.68470700E+00, -.10382900E+01, 0.75271300E+00, -.48950600E+00, -.67512400E-01, -.47525100E+00, 0.20192700E+00, -.49368800E-01, 0.76939600E-01, 0.98978900E+00, 0.15213500E-01, -.55303300E-01, -.42235400E-01, 0.24406600E+00, 0.13289400E-01, -.13464100E+00, -.67859000E-01, 0.28791300E-02, -.43205500E+00, -.35886500E-01, 0.25393400E+00, 0.20671700E+00, -.11494300E+00, 0.10063600E-01, -.28376200E+00, -.23261400E+00, -.14770600E+00, -.15247100E+00, 0.10638400E+00, 0.35762100E-01, 0.16829700E+00, 0.48543300E+00, 0.49760800E-01, 0.14023700E+00, -.76610000E-01, -.15884400E+00, 0.15334500E+00, -.20887900E+00, 0.37243400E-01, -.10077900E+01, -.32494200E-01, -.62221900E-01, 0.55024800E-02, 0.30250500E+00, -.45772200E+00, -.77258300E+00, -.31763800E+00, -.63515700E+01, 0.12827500E+02, 0.23338600E+02, -.24205300E+01, 0.25227300E+01, -.21348300E+01, 0.24204500E+01, -.28356300E+01, 0.55114200E+01, 0.22559500E+02, 0.20021500E+02, 0.73825000E+01, 0.12394000E+02, -.27487300E+02, -.64974500E+01, -.33780600E+02, 0.31877000E+01, 0.13115900E+02, 0.57158700E+00, 0.21167200E+02, 0.64700500E+01, -.15283900E+02, -.43747700E+01, -.69373700E+01, 0.40492400E+01, 0.34519900E+00, 0.47948000E+01, -.34554100E+01, 0.36256600E+01, 0.37144800E+00, 0.16116500E-01, -.16684800E+00, 0.42510300E+01, -.22035300E+01, -.95470700E+01, 0.30451400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.43511400E+01, -.49739600E+01, 0.13340800E+01, -.74440400E+00, 0.60669000E+01, -.10952600E+02, 0.50386400E+00, 0.16115800E+01, -.48692700E+01, 0.63369100E+01, -.39263200E+01, -.15105300E+02, -.22811600E+00, -.59603600E+01, 0.48464000E+00, 0.47749800E+00, 0.19578200E+01, -.47741600E+01, -.46524300E+01, -.10667500E+01, -.20888100E+01, -.36048000E+00, 0.67950800E+00, -.41065300E+00, -.52617400E+01, -.24805700E+01, 0.70668300E+00, -.52480200E-01, 0.27157200E+01, 0.29790200E+00, 0.59612200E+00, 0.31718900E+01, -.17603100E+01, -.28798900E+01, -.47046600E+00, 0.17564300E+01, -.50590600E+00, -.67141300E+00, 0.73057900E+00, 0.35824200E+01, 0.38603300E-01, 0.10047300E+01, -.72609200E+00, -.96827800E+00, 0.94047400E+00, -.19395700E+01, -.34015800E+00, 0.37555400E+01, 0.34974600E+00, -.55685200E+00, 0.13819500E+00, 0.52295400E+00, 0.26519300E+01, -.26404200E+01, 0.35750200E-01, -.29412000E+01, 0.30373200E+03, 0.16442900E+03, -.27205800E+02, 0.13796700E+01, -.64964300E+02, 0.47396800E+02, -.67654700E+02, 0.21768500E+02, 0.26528600E+03, 0.19003100E+02, 0.10942400E+03, 0.37258800E+02, -.14659600E+03, 0.12865800E+03, 0.49956200E+02, 0.58070200E+02, 0.18478200E+03, -.30129700E+03, 0.16632900E+03, 0.13075000E+03, -.20810500E+03, -.74392000E+02, -.48887100E+01, 0.11509400E+03, 0.36186800E+02, -.40576000E+02, 0.64761300E+01, -.51183300E+02, 0.26593400E+02, -.18919500E+02, -.30990800E+02, -.47887300E+02, -.30370800E+02, 0.29375000E+02, 0.29018600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18916500E+01, 0.31320800E+01, -.21329700E+01, -.13852200E+01, 0.35169000E+00, -.87675200E+00, 0.34562900E+01, 0.16359300E+01, -.30018100E+00, 0.22320700E+01, -.94848000E+00, -.18648900E+01, 0.34388600E+00, -.24073600E+00, -.11392200E+01, 0.99040700E-02, 0.19174800E+01, -.76145500E+01, -.16616500E+01, 0.11571200E+00, -.35039600E+00, -.86847400E-01, -.36916800E+00, -.39699200E-01, 0.79656000E+00, 0.68705100E-01, 0.32865300E+01, 0.41975000E+00, -.25386700E+00, -.14813200E+01, 0.14988000E+00, 0.24029700E+01, -.39424500E+00, 0.32235000E+00, -.63143200E+00, 0.44749600E+00, -.74388000E+00, -.79321000E+00, -.48349500E+00, -.98998100E+00, 0.20702600E+00, 0.37950100E+00, 0.52067500E+00, -.62702000E+00, 0.36211800E+00, -.14581300E+01, 0.39069600E+00, -.12044600E+01, 0.32702400E-01, 0.40018500E+00, 0.26271800E+00, 0.15577800E+00, 0.17205400E+00, 0.52567600E+00, -.10238200E+01, 0.23707200E+00, -.19840000E+00, 0.50826900E+02, -.13403700E+02, -.98899600E+01, 0.94356300E+01, 0.34427600E+01, 0.13573000E+02, -.92491000E+01, 0.22514400E+02, -.13052700E+01, -.52095000E+01, -.47514100E+01, -.15969700E+02, -.98334200E+01, -.23258400E+02, -.12082900E+02, -.53388700E+02, 0.19081000E+02, 0.83592600E+01, 0.37569200E+01, 0.15361700E+02, -.16574500E+02, 0.66639700E+01, -.23553700E+00, -.22953400E+01, 0.24573600E+01, -.47797100E+01, 0.16642300E+01, -.20342000E+01, -.45265500E+00, 0.26506900E+01, 0.77225900E+00, -.92988500E+00, -.10040200E+02, 0.64572000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.53815000E+00, -.70769400E+00, 0.36243400E+00, 0.33883000E+00, 0.19858600E+00, 0.13999700E+01, 0.10453900E+01, 0.89439600E+00, -.45412400E+00, 0.40022000E+00, 0.72414900E-01, -.11494100E+01, 0.23027700E+00, -.38591000E+00, -.13158000E+00, 0.71648200E-01, -.40308800E+00, 0.60146300E+00, 0.96666600E-01, -.40990700E-01, -.84986300E+00, -.76731100E-01, -.14960200E+00, -.51625000E-02, -.60011900E+00, 0.82135000E-01, -.72064600E+00, -.27695400E+00, 0.29236000E+00, 0.24381300E+00, -.24294600E+00, -.19156600E+00, -.20277800E+00, -.20480600E+00, -.19508500E-01, 0.42088100E+00, -.36295200E+00, 0.42022100E-01, 0.48660100E+00, 0.24414200E+00, 0.49911600E-01, 0.40761700E+00, -.18872900E-01, -.99997100E-02, -.18968600E-02, 0.12068100E+00, -.73975500E-01, 0.24013400E+00, 0.87621100E-01, -.82824300E-01, -.61985800E-01, 0.29030700E-01, -.31163500E+00, 0.36038200E+00, -.17620100E+00, 0.53665600E+00, -.30785100E-01, 0.12434600E-01, 0.83695100E+01, 0.24933500E+01, -.31075700E+01, -.29703600E+01, -.55818300E+01, 0.16937600E+01, -.17914100E+02, 0.76929700E+00, 0.43223900E+01, 0.21150400E+01, 0.35117100E+00, -.62588300E+01, -.20045500E+01, 0.29845900E+01, 0.10744900E+02, -.14289300E+02, -.27151200E+01, 0.28091600E+01, -.74795800E+01, 0.27996200E+01, -.63555900E+01, 0.33656100E+01, 0.25283600E+00, -.82852100E+00, 0.11005200E+01, -.68940100E+00, 0.14544800E+00, -.29781700E+00, -.36610900E+00, -.43279900E+00, 0.11016000E+01, 0.13411100E+01, -.16412100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.63741900E+01, -.72532300E+01, 0.33381600E+00, -.30504100E+01, 0.53624300E+01, -.26576000E+01, 0.57708300E+01, 0.43165200E+01, -.14964200E+01, 0.57441000E+01, -.27323600E+01, -.16552200E+02, 0.13359800E+01, -.55070400E+01, -.41084200E+01, 0.84771900E+00, -.21553700E+01, -.19842500E+02, -.45763400E+01, -.43521400E+00, -.88036200E+01, -.31020000E+01, -.18455000E+01, 0.97472100E+00, -.26827200E+01, -.73551200E+00, 0.11510500E+02, 0.40499300E+00, 0.42484000E+00, -.17966800E+01, -.83545300E+00, 0.13972400E+01, -.20290400E+01, -.28843200E+01, -.45488700E+00, 0.19168700E+01, -.47298800E+00, -.20935400E+00, 0.26771700E+01, 0.38403800E+01, -.77682200E+00, 0.79111100E+00, -.20516200E-01, 0.16190700E+01, 0.50754600E+00, 0.43657500E+01, -.13695900E+01, 0.23921000E+01, 0.20942600E+01, -.11575700E+00, -.65269500E+00, -.10251600E+01, 0.11370200E+01, -.24749400E+01, -.24043900E+01, -.30282100E+01, -.83766700E+00, 0.31822600E+01, 0.75924400E+01, 0.59874200E+02, -.32864000E+02, -.69742200E+02, -.80573200E+02, 0.70078500E+02, 0.40640200E+03, -.11191800E+03, -.23778200E+01, -.11723100E+02, -.99959500E+02, 0.14466800E+03, 0.75638700E+02, 0.37692700E+01, -.36079300E+02, -.11186300E+03, 0.94166400E+02, 0.84213300E+02, -.84040600E+02, -.15725900E+03, 0.32932200E+02, 0.66506000E+02, 0.42016400E+02, 0.87760500E+01, -.57954600E+01, 0.37955100E-02, 0.45938300E+02, -.36185300E+02, -.36210300E+02, 0.44440400E+01, -.15409900E+02, 0.13976500E+02, 0.24387600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.20772700E+01, -.28548500E+01, 0.18413600E+01, 0.97896300E+00, -.22391700E+01, 0.35298500E+01, -.28967200E+01, -.21452200E+01, 0.15386900E+01, -.37038000E+01, 0.20343000E+01, 0.36763300E+01, -.57752100E+00, -.19066600E+00, 0.13718200E+01, -.10888800E+00, -.14601200E+01, -.46084600E+00, 0.19615100E+01, 0.31185400E+00, 0.12758800E+01, -.47588700E+00, 0.68046500E-01, 0.87222000E+00, -.11753800E+01, -.72023400E-01, -.34288200E+01, -.21286200E+01, -.12048400E+00, 0.35771400E+00, 0.51441600E-01, -.14993100E+01, 0.18302300E+01, 0.54560800E+00, 0.12314100E+01, 0.69207600E+00, -.78259800E-01, 0.72147800E+00, 0.76397100E-01, 0.11728900E+01, 0.28014500E+00, 0.36497600E-01, -.49470900E+00, -.37597100E+00, 0.62516500E-01, 0.14831600E+00, -.10126400E+00, 0.15472700E+00, -.72073100E+00, -.33654000E+00, -.14419000E+00, 0.17468200E+00, 0.33138300E+00, -.92639000E+00, -.13236100E+01, 0.16931000E+01, -.95709600E-01, 0.72850200E+00, -.89570400E+00, -.27650400E+00, 0.98240600E+01, -.16594700E+02, -.27446800E+02, -.31387500E+01, 0.69723500E+02, 0.30337900E+01, 0.55225900E+02, 0.20705500E+02, -.29063800E+02, 0.74523900E+02, 0.34079100E+02, 0.39571200E+02, -.78928000E+01, -.13485000E+03, -.34538000E-01, 0.11342500E+02, -.38739200E+01, 0.17192000E+02, 0.64443800E+02, 0.13833100E+02, 0.18105300E+02, -.28693500E+01, -.24291700E+01, -.45165400E+01, 0.15250400E+02, -.14636400E+02, -.16125800E+02, -.53581100E+01, 0.47958300E+01, 0.11863600E+02, -.11791800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.17312200E+01, 0.26716800E+01, -.39546600E+00, 0.75645800E+00, -.26158100E+01, -.71436600E+00, -.14157900E+01, -.14359500E+01, 0.17808600E+01, -.31879900E+01, 0.57908200E+00, 0.41326400E+01, -.62012600E+00, 0.25597400E+00, 0.33838800E+00, -.38045500E+00, -.14778600E+01, 0.23744100E+01, 0.19257300E+00, -.20891500E+00, 0.24620300E+01, -.28698400E-01, -.47375100E-01, 0.53193900E+00, 0.10615100E+01, -.44719800E-01, -.15550600E+01, -.90775900E+00, -.72372900E+00, -.38024100E+00, -.35052800E+00, -.37215400E+00, 0.10510000E+01, 0.14440000E+01, 0.40669600E-01, -.11267500E+01, 0.44365300E+00, -.16802100E-01, -.15508400E+01, -.19391900E+01, -.69700900E+00, -.95758100E+00, 0.11262400E+00, -.17350400E+00, 0.29205100E+00, 0.40662300E+00, 0.48447900E-01, -.15682500E+01, -.49307300E-01, 0.15288600E+00, -.10527900E-01, 0.34843500E+00, -.60050600E+00, -.19788500E+00, 0.34510300E+00, 0.47733000E+00, 0.46091000E-01, -.40438900E+00, -.11745500E+01, -.75259500E-01, 0.27711600E+00, 0.13226400E+02, 0.12270900E+02, 0.14173900E+01, -.16054500E+02, 0.91618300E+01, -.25560700E+02, -.11983400E+02, 0.12453700E+02, -.25404100E+02, -.15384600E+02, -.20636000E+02, 0.64546700E+01, 0.72775400E+02, 0.70169300E+00, -.12691000E+02, 0.33172600E+01, 0.25158500E+01, -.32679800E+02, -.13061300E+02, -.83217300E+01, 0.14309500E+01, 0.13644700E+01, 0.26339700E+01, -.82314800E+01, 0.87125500E+01, 0.74842300E+01, 0.30716000E+01, -.36213800E+01, -.59799700E+01, 0.15818000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.52475600E+01, 0.25516700E+01, -.30893700E+01, -.26961400E+01, 0.95836700E+00, -.47008400E+01, 0.56625400E+01, 0.37645800E+01, -.20250100E+01, 0.10473500E+02, -.28130900E+01, -.27854200E+01, 0.10790400E+01, 0.15053100E+01, -.21399800E+01, 0.90874300E+00, 0.66620600E+01, -.60605100E+01, 0.57519400E-01, 0.94051400E+00, 0.23339300E+01, -.84224400E+00, 0.27650600E+01, -.77283500E+00, -.29654100E+00, -.12980800E+01, 0.39180900E+01, 0.18783400E+01, -.18785500E+01, -.11883400E+01, 0.16114100E+01, 0.27416900E+00, 0.15809500E-01, -.94311300E+00, 0.12253100E+01, 0.26366900E-01, -.63136500E+00, -.69547800E-01, 0.15284200E+01, -.27835200E+01, 0.32013500E+00, 0.20821600E+00, 0.28726900E+00, 0.50268700E+00, -.41952900E+00, -.51345900E+00, 0.15338800E+00, 0.82039600E+00, -.43114500E+00, -.82061900E+00, -.12159600E+00, -.11871400E+00, -.26262100E+01, 0.30151100E+01, 0.12157400E+01, 0.47017300E+01, 0.26745600E+00, -.11151300E+01, 0.26260900E+01, 0.61674900E-01, -.13496000E+01, -.47788200E+00, -.53808700E+02, -.12023300E+02, 0.93260600E+01, 0.45698400E+02, 0.21335200E+02, -.12796600E+02, 0.47264600E+02, 0.72834900E+02, 0.34278300E+02, 0.68729000E+01, -.14232800E+03, 0.10511400E+01, -.11352500E+03, -.10361800E+03, 0.14359900E+03, 0.10815400E+03, 0.11105300E+03, -.90163300E+02, -.43935900E+01, 0.10283400E+02, -.42494400E+01, 0.16905700E+02, -.82255600E+01, 0.53468100E+01, 0.24025800E+01, 0.10355800E+02, 0.14365600E+02, 0.13439800E+01, -.59295200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10524700E+01, -.76132900E+00, 0.50960500E+00, 0.42450700E-01, -.80635900E-01, -.17285700E+01, -.72323600E+00, -.65178600E+00, 0.63866400E-02, 0.84986700E-01, -.14277900E+00, 0.76167700E+00, -.23853400E+00, -.25915400E+00, 0.25845400E+00, 0.98312100E-01, -.32610600E-01, -.24696800E+00, 0.45096900E+00, 0.22796300E+00, -.55080400E+00, -.19129100E+00, 0.15263700E+00, -.22760000E+00, -.69603500E+00, 0.30838400E+00, -.20247200E+01, 0.18193700E-01, 0.56496200E+00, 0.50287400E+00, -.40064100E+00, 0.72898800E+00, 0.51967900E+00, 0.34036700E-01, 0.33734600E+00, 0.46010200E+00, 0.56456600E+00, 0.40589300E-01, 0.15218900E-01, 0.21068700E-01, -.68415300E-01, -.36665000E+00, 0.19550000E+00, 0.39399700E+00, -.11286500E+00, 0.46733100E+00, -.13111200E+00, 0.70743900E+00, -.21244900E+00, -.97278900E-01, -.17608500E+00, -.10025100E+00, 0.37842900E+00, -.57740000E+00, 0.25311200E+00, -.10551700E+01, 0.41934600E-01, 0.25343000E+00, 0.50266700E+00, 0.12711300E+00, -.60695000E-01, 0.10900600E+00, 0.25709700E-01, -.20131800E+01, 0.13127900E+02, -.24182000E+02, 0.19446500E+02, 0.21167000E+02, -.22486300E+02, 0.97944400E+01, -.18783300E+02, 0.29102300E+02, -.26732200E+02, -.22208700E+02, -.81541800E+00, 0.12043500E+01, 0.10390900E+02, -.92850900E+01, 0.10406500E+02, 0.46985100E+01, -.42008900E-02, 0.11521200E+01, -.22500600E+00, 0.11327600E+01, 0.12781800E+01, -.44291200E+01, -.12291200E+00, 0.40112600E+00, 0.80238300E+00, 0.64547000E+01, 0.10542500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.69397300E+00, 0.88527900E+00, -.39542600E+00, 0.15030700E+00, -.26873400E+00, 0.21653800E+01, 0.48694400E+00, 0.12794600E+00, 0.80869700E+00, -.11943500E+01, 0.35234800E+00, 0.22331200E+01, -.22377000E+00, 0.66627100E+00, 0.11453200E+00, -.56069400E-01, -.26689800E+00, -.98234400E-01, 0.18077100E+00, 0.24339000E-01, 0.17440000E+01, 0.32432600E+00, -.59298000E-01, 0.27551300E+00, 0.54741200E+00, 0.45020600E+00, 0.80167000E-02, -.12407900E+00, -.39732300E+00, -.64768900E-01, 0.15198400E-01, -.73795000E+00, 0.50491100E+00, 0.80920700E+00, 0.96868700E-01, -.16637000E+00, 0.60144000E+00, 0.25434800E+00, 0.26852300E+00, 0.41526400E+00, -.43234400E-01, -.25146300E+00, -.26964600E-01, 0.14733000E+00, 0.89968900E-01, 0.21471100E+00, -.85787600E-01, 0.57109200E+00, 0.10115700E+00, -.79422900E-01, -.78744200E-01, -.24693500E+00, -.13588100E+00, -.31317500E+00, 0.98275800E-01, 0.19206600E+00, -.11456700E+00, 0.31838800E+00, 0.96734400E+00, 0.79880600E-01, 0.57899700E-01, 0.15984700E-01, -.20588500E-01, 0.17733400E+00, -.27121400E+02, 0.10150700E+01, 0.44681700E+01, 0.31565700E+01, 0.55579700E+01, -.60732500E+01, 0.32797300E+01, 0.45189300E+01, 0.15576100E+02, -.93633100E+01, -.25234000E+01, 0.23229900E+01, -.60081100E+01, 0.54956300E+01, -.44268600E+01, 0.36791600E+01, 0.13120800E+01, -.10753800E+01, 0.11125400E+01, -.99280200E+00, 0.14903700E+01, -.15194200E+01, -.11528100E+01, -.87915000E+00, -.85498700E+00, 0.24130300E+01, -.10060000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.61719900E+00, 0.81997800E+00, -.45601900E+00, -.25000200E+00, -.72228300E+00, 0.10424500E+01, -.11413400E+00, 0.46648400E+00, 0.43129400E+00, -.55596000E+00, 0.35039700E+00, 0.15919700E+01, -.25968100E-01, 0.69757000E-01, -.68199000E-01, -.83387600E-01, -.41692500E+00, 0.10942700E+01, 0.89944100E+00, 0.10331200E+00, -.16098000E+01, -.43849200E+00, -.11624400E+00, 0.18774900E+00, -.12757700E+00, 0.46996500E+00, -.69006000E+00, -.62165000E+00, -.33907800E+00, -.83565800E-01, 0.93384000E-01, -.55428000E+00, -.13306100E+00, 0.34961300E+00, -.53208100E-01, -.31209700E-01, 0.18254300E+00, 0.95899100E-01, 0.25509200E+00, -.64607600E+00, -.26310600E+00, 0.29520100E+00, 0.86960700E-01, 0.16318100E+00, 0.26723500E+00, -.75352900E+00, 0.24953000E-01, 0.88906700E+00, 0.76339200E-01, 0.39170800E-01, 0.69515700E-01, 0.36925000E-01, 0.18354700E-01, 0.31653200E+00, -.10207200E+00, -.13492900E+00, -.17435500E-01, -.32694500E-01, -.10831200E+00, -.38580800E-01, -.77353100E-03, -.11863500E+00, -.90738400E-02, -.33743900E+00, -.66244400E+00, -.16565400E+02, 0.19532600E+01, 0.46665600E+01, -.60400300E+01, 0.53656600E+00, -.70195200E+01, 0.82556200E+01, 0.20058400E+01, -.79197700E+01, 0.44806900E+01, 0.72377300E+01, -.69301300E+01, -.62170000E+01, -.10499300E+02, 0.85431200E+01, 0.12214400E+01, -.57432800E+00, 0.20334500E+01, -.28347600E+00, 0.18426200E+01, -.20470500E+01, -.11368400E+01, -.83495300E-01, -.13220700E+01, 0.58379300E+01, 0.20712900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.20627900E+01, -.34251400E+01, 0.41620800E+00, -.10731500E+01, 0.31114100E+01, 0.26159400E+01, 0.80937400E+00, 0.13944000E+01, -.23712200E+01, 0.38016700E+01, -.29913600E+00, -.36568900E+01, 0.93645900E+00, 0.22972200E+00, -.67237400E+00, 0.57022200E+00, 0.55144800E+00, -.31585800E+01, -.43634200E+00, 0.12319900E+00, -.10810700E+01, -.22381900E+00, -.28217200E+00, -.24650900E-01, 0.58207000E+00, 0.86026900E+00, 0.24446600E+01, 0.81342500E+00, 0.15953700E+00, -.44636600E+00, 0.81971200E+00, 0.34091200E+00, 0.42493900E+00, 0.31495100E+00, 0.61177200E-01, 0.35191100E+00, 0.17182100E+01, 0.31870300E+00, 0.57943900E+00, -.12104300E+00, 0.78822200E+00, -.76396800E+00, 0.23259200E+00, 0.27336300E-01, 0.57600300E-01, -.11029000E+01, 0.39529200E+00, 0.52365300E+00, -.33953300E+00, 0.20627600E-01, 0.34719100E+00, -.73122800E-01, 0.11637200E+01, -.12967700E+01, -.46644000E+00, -.14567800E+01, -.19425900E+00, 0.71047500E+00, -.16804600E+00, -.30284600E-01, 0.45048900E+00, -.18057200E-01, -.13926200E+00, -.14453400E+01, -.94587600E+00, 0.16820200E+01, 0.34967600E+02, 0.29641900E+02, -.28681800E+02, 0.19080400E+02, -.27747600E+01, 0.35619900E+02, 0.85575800E+02, -.57290100E+02, 0.12822100E+01, 0.83463600E+01, -.21371000E+02, 0.30828100E+02, 0.14351600E+02, 0.10301500E+02, 0.41397600E+01, -.12466700E+01, -.31834400E+01, -.32280200E+01, 0.52862500E+01, -.81496700E+01, -.32884200E+01, -.21208400E+01, 0.30191800E+01, 0.51646300E+01, 0.27822200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.10824100E+01, 0.86544600E+00, -.31983800E+00, 0.25685500E+00, -.42012000E+00, 0.13805200E+01, -.23001500E+00, -.62435600E-01, -.14285800E+00, 0.45408500E+00, 0.33927300E+00, 0.26476700E+01, 0.46981000E-01, 0.14464300E+01, 0.26265800E+00, -.98037800E-01, 0.15379700E+01, 0.29194400E+01, 0.12181800E+01, 0.30374900E+00, -.55059800E+00, 0.60581400E+00, 0.45213000E+00, -.63695400E+00, -.25057100E+00, 0.36430000E+00, -.16230400E+01, 0.54146200E+00, 0.12647200E+00, 0.68857000E+00, 0.25471400E+00, 0.40084800E+00, 0.39000600E-01, -.22504200E+00, 0.16640200E+00, 0.21823900E+00, -.17792000E+00, -.99940900E-02, 0.20582100E+00, 0.27538600E+00, 0.20768500E+00, 0.31312400E+00, 0.17975400E-01, 0.15559100E-01, -.32501300E-01, -.14186600E+00, -.18243600E-01, 0.15409700E+01, -.12376100E+00, -.18171200E+00, -.86110000E-01, -.26076500E+00, 0.83186500E+00, -.49659100E+00, -.22243900E-01, -.23703500E+00, 0.16981300E+00, -.19909100E+00, 0.75509900E+00, 0.64017800E-01, -.27010700E+00, 0.19506500E+00, 0.65184800E-01, 0.44700900E+00, -.68992000E+00, -.15540300E+00, -.47199200E-01, -.11276700E+02, 0.18759000E+02, 0.16486700E+02, 0.18981700E+02, -.69423900E+01, -.72065600E+01, -.22426900E+02, -.23114100E+02, -.11005900E+02, 0.17597600E+02, 0.14506100E+02, 0.12004000E+02, -.10055400E+02, 0.96235200E+00, -.25862900E+01, 0.23971300E+01, -.15066600E+01, 0.81182400E+00, -.72099900E+00, -.96687700E+00, -.25188000E+01, -.20726900E+01, 0.49292400E+01, -.94548700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13486600E+01, 0.25865900E+01, 0.25293100E+00, 0.10104100E+01, -.16277100E+00, -.20761300E+01, -.22649800E+01, -.14204800E+01, 0.15398200E+01, -.27983700E+01, 0.89186000E+00, 0.10453500E+01, -.80670600E+00, -.21799500E+01, 0.12401900E+01, -.29397400E+00, -.84075400E+00, 0.47763200E+00, 0.63476900E+00, 0.23946700E-01, -.23860900E+01, 0.11340600E+00, -.22013500E+00, 0.52205300E-01, -.16961800E+01, 0.28594100E+00, -.90029600E+00, 0.82923800E-02, 0.48105600E+00, 0.90384100E+00, -.25422500E+00, 0.18537400E+01, -.54108500E-01, -.87575300E+00, -.12488200E+00, 0.48791700E+00, -.59097400E+00, -.17686600E+00, -.33782500E-01, 0.42688900E+00, 0.57841900E+00, 0.40827700E+00, 0.22857000E+00, 0.10103400E+00, 0.15669800E+00, -.40815700E+00, 0.22247300E+00, -.13155100E+00, -.45256800E+00, 0.22059600E+00, 0.18572500E+00, 0.19482700E+00, 0.37963800E+00, -.64360200E+00, -.12429800E+00, -.92351200E+00, -.57744300E-01, 0.24123000E+00, 0.54363200E+00, 0.17977700E+00, 0.21232500E+00, 0.74749400E+00, 0.47452900E-01, -.73202600E+00, 0.80592500E+00, -.33286000E-01, 0.26208700E+00, -.10236300E+00, 0.68003500E+01, 0.79566900E+01, -.66926800E+01, 0.21672900E+01, -.21013300E+02, -.29004000E+01, 0.50208300E+01, -.33003800E+01, 0.44917900E+01, -.13133800E+02, 0.84248200E+01, -.31645200E+01, 0.10009900E+01, 0.29495100E+00, -.14471600E+01, 0.46747600E+00, -.39207100E+00, -.50304800E+00, -.78565600E+00, -.49751600E+00, 0.95557100E+00, -.12225400E+01, 0.36242800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11468100E+01, 0.12618800E+01, -.66363400E+00, -.65291100E+00, -.98044500E-01, -.22751300E+01, -.18208600E+01, -.13796700E+01, 0.56601400E+00, -.55060300E+00, -.28556000E-01, 0.19878500E+01, -.29499600E+00, 0.59393300E+00, 0.25932500E+00, -.20139000E+00, 0.10635000E+01, -.19504600E+01, -.35530800E+00, 0.99536000E-01, 0.14346600E+00, 0.13130100E-01, 0.10944600E+00, -.23088200E-01, 0.75521300E+00, -.16385300E-01, 0.14594100E+01, 0.25742000E+00, -.38641600E+00, -.44387800E+00, 0.46881100E+00, -.35127400E+00, -.23057300E+00, -.46788900E-01, -.18103000E-01, -.14829300E-01, 0.54628400E-01, 0.24699100E-01, 0.11817300E+00, 0.50962300E-01, -.17906400E+00, -.72451800E-01, 0.92840300E-01, -.69455900E-01, 0.22813600E+00, -.27163700E-01, 0.59093600E-01, -.17441600E+00, 0.13587100E+00, 0.87356900E-01, -.24592200E-01, 0.54443200E-01, -.14214900E+00, 0.18091300E+00, -.12214300E+00, 0.55596400E+00, -.12196800E+00, 0.65842500E-01, 0.30537600E+00, -.10687500E+00, -.67465500E-01, -.61616600E+00, 0.10055400E-01, -.77521800E+00, -.85533700E+00, 0.15347600E+01, 0.35108700E+00, 0.25116600E+00, 0.60627300E+00, -.13264600E+02, 0.11271700E+02, -.29993100E+01, -.30175900E+02, 0.14603500E+02, -.17792100E+01, 0.82096600E+01, 0.46584700E+01, -.22350700E+02, -.28083100E+01, 0.67116100E+01, 0.12519700E+01, -.32228400E+00, 0.39922100E+01, -.11059500E+01, 0.26484200E+01, -.24774800E+01, -.12987000E+01, -.11837600E+01, -.35340000E+01, 0.13520700E+00, 0.84027400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.39727200E+01, -.54399800E+01, 0.38637700E+01, 0.26710600E+01, 0.33733500E+00, 0.40065300E+01, -.55283300E+01, -.21381900E+01, 0.52502400E+00, -.36297800E+01, 0.21780300E+01, 0.58947800E+01, -.54212900E+00, 0.11385000E+01, 0.24334800E+01, -.34989700E+00, -.72548400E+00, 0.13773400E+02, 0.29448100E+01, -.11765400E+00, 0.90341900E+00, 0.16050400E+01, 0.10386600E+01, -.39473600E+00, -.81492300E+00, 0.89186800E+00, -.37519300E+01, 0.79791900E-01, 0.62136400E-01, 0.25896700E+01, 0.44897600E+00, -.23542800E+01, 0.19195400E+00, 0.49303300E+00, -.33489200E+00, -.11801700E+01, 0.23694200E+01, 0.78913500E+00, -.32651600E+00, 0.98895700E+00, -.34678200E+00, -.27976400E+00, -.89875700E+00, -.47266800E-01, 0.48847200E+00, -.13325300E+01, 0.29778000E+00, -.25982300E+00, 0.18421100E+00, 0.74485000E+00, 0.39574200E+00, 0.43380500E+00, 0.14889900E+01, -.51684500E+00, 0.28501600E+00, -.15612000E+01, 0.52304800E-01, 0.13307700E+00, 0.79702000E+00, 0.10010100E+00, -.28526500E+00, 0.50161400E+00, 0.20440100E+00, -.35011900E+01, -.37614300E+01, 0.29334800E+00, 0.12750500E+01, -.35541500E+00, 0.25059400E+01, -.14756200E+01, 0.67214700E+02, 0.67671900E+01, -.95781300E+02, -.49553400E+02, -.22355700E+02, 0.34813400E+02, 0.18751400E+02, -.67761900E+02, -.38105300E+01, 0.35312900E+02, 0.79512800E+01, -.13846100E+02, 0.18879200E+02, -.15330900E+02, 0.15020200E+02, -.11362700E+02, -.78938400E+01, -.13982900E+02, -.18721200E+02, 0.21704100E+02, -.64091100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.12011700E+01, -.10343500E+01, 0.50571900E+00, -.63803100E-01, 0.36918700E+00, -.17164300E+01, -.48688500E+00, 0.75911700E-01, -.53864000E+00, 0.35259200E+00, -.40873400E+00, 0.42364600E+00, -.33910700E+00, -.77319400E+00, 0.54934700E+00, 0.23486100E-01, 0.14103900E+00, 0.75238700E+00, 0.46553100E+00, 0.17194800E+00, -.11552100E+01, -.73635600E-01, 0.21412400E+00, -.34185800E+00, -.10437100E+01, 0.28869500E+00, -.27235800E+01, -.12852400E+00, 0.55212100E+00, 0.67734500E+00, -.48790800E+00, 0.76741000E+00, 0.44068000E+00, 0.14235000E-01, 0.20690400E+00, 0.31708200E+00, 0.68383400E+00, -.35963100E-02, -.64605000E-01, -.41111700E+00, -.22554700E+00, -.33776600E+00, 0.25190300E+00, 0.41864700E+00, -.13318400E+00, 0.30111100E+00, -.77710100E-01, 0.59282500E+00, -.16583300E+00, 0.85814300E-02, -.95499900E-01, -.13792000E+00, 0.22004200E+00, -.24351900E-01, 0.51985500E+00, -.58854000E+00, 0.13639700E-02, 0.13947600E+00, 0.43096400E+00, 0.59891300E-01, -.72506300E-01, -.12743700E+00, -.14079700E-01, 0.15690800E+00, 0.35339800E-01, 0.89975400E+00, 0.16929600E+00, -.22662400E-02, 0.52462400E+00, -.11406600E+00, 0.21485300E+00, -.27401700E+01, 0.13695000E+02, 0.12955500E+02, -.52962700E+00, -.52560000E+01, -.95966100E+00, 0.13173200E+02, -.19860600E+01, -.61040900E+01, -.10638100E+01, 0.15703100E+01, -.10175200E+01, 0.15163700E+01, -.15309300E+01, 0.14477000E+01, 0.98633200E+00, 0.15217200E+01, 0.79911600E+00, -.17825800E+01, -.20352700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.25025400E+01, -.21786500E+01, -.26890900E+00, -.11977000E+01, 0.34837600E+01, 0.12317000E+01, 0.13291500E+01, 0.26773200E+01, -.13484600E+01, 0.31180900E+01, -.78163300E+00, -.27314600E+01, 0.18791200E+00, -.17812500E+01, -.72524800E+00, 0.11735100E+00, 0.17538600E+01, 0.60879100E+00, 0.49407600E+00, 0.86751200E-01, -.44891500E+01, 0.87919700E+00, -.32258300E+00, -.66755800E+00, -.17758700E+01, 0.16815400E+01, -.42274000E+01, 0.77464600E-01, 0.15184800E+00, 0.11664000E+01, 0.21969700E+00, 0.89788500E+00, -.16138000E+01, -.70969800E+00, -.10228300E+01, 0.13971200E+01, -.61496900E+00, -.42317700E+00, 0.24266200E-01, 0.22804500E+01, 0.97726300E+00, -.16412800E+00, -.21323100E+00, -.32601000E+00, 0.52605900E-01, 0.73610800E+00, 0.10045400E+00, -.24072100E+01, -.80667700E+00, 0.11872300E+00, 0.16862500E+00, 0.72042000E+00, 0.10638300E+01, -.10705300E+01, -.12383400E+01, -.40687500E+00, -.11717300E+00, 0.24173600E+00, -.30294300E+01, -.25716900E+00, 0.83180200E+00, 0.55773800E-01, -.38485600E+00, -.63811500E-01, -.15598900E+01, -.47456000E+00, -.48904900E-01, 0.15114600E+00, -.54101100E+00, -.88897300E+00, 0.33729900E+00, 0.48104800E+00, 0.82461500E+02, 0.36844300E+02, 0.35037900E+02, 0.27342000E+02, -.57010200E+02, -.20805500E+02, -.66027900E+02, 0.28280800E+02, 0.34633000E+01, 0.12790000E+01, 0.80227000E+00, 0.37501700E+00, 0.23383300E+01, -.49987900E+01, -.27769300E+01, 0.41145400E+00, -.43169600E+00, 0.15888400E+01, 0.19282900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.72482700E+00, -.88738600E+00, 0.36925200E+00, -.19461400E+00, 0.66356500E+00, -.14475800E+01, -.30739700E+00, 0.26004400E+00, -.77497400E+00, 0.64186200E+00, -.24390600E+00, -.94942300E+00, 0.64426400E-01, -.82302400E+00, 0.13787500E+00, -.39799500E-01, 0.16307300E+00, 0.30300700E+00, 0.38195000E-01, 0.29096800E-02, -.12686500E+01, 0.21135800E-01, -.22387100E-01, -.14752700E+00, -.93190800E+00, 0.20272700E-01, -.11976600E+01, -.36558200E+00, 0.34671200E+00, 0.36581200E+00, -.40647700E+00, -.31962600E+00, -.51499600E+00, -.30732800E+00, -.12566200E+00, 0.40038700E+00, -.24858400E+00, 0.97616400E-02, 0.38332900E+00, 0.22394300E+00, -.13344000E+00, 0.24909800E+00, -.64449600E-01, 0.69726500E-01, -.48161900E-01, -.26775000E+00, -.36255800E-01, 0.73446900E-01, 0.10044800E+00, 0.47246500E-01, -.38802700E-01, 0.63376400E-01, -.21227500E+00, 0.64701000E+00, -.12630500E+00, 0.40561100E+00, -.10467400E+00, 0.17509700E+00, 0.28246200E+00, 0.34380600E-01, 0.11176300E+00, 0.82584900E-02, -.56499900E-01, 0.53540800E+00, 0.10297300E+01, -.94451300E+00, -.30152800E+00, -.18076800E+00, -.27084600E+00, -.47505600E+00, 0.12489700E+00, 0.43482000E+00, 0.28103100E+00, -.13510000E+02, -.23089700E+01, 0.86886300E+00, 0.20451100E+01, 0.27165400E+01, 0.11014500E+02, -.57669400E+00, 0.93653100E+00, -.43042000E+00, -.57927800E-01, -.60632500E+00, 0.11184000E+01, -.59104300E+00, -.78467800E+00, -.38791200E+00, 0.58481700E+00, -.21687800E+00, -.46062000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.48158400E+01, 0.80925700E+01, -.91381300E+00, 0.21123800E+01, -.71847300E+01, -.18467600E+00, -.52184200E+01, -.49159100E+01, 0.64528400E+01, -.10289700E+02, 0.29740400E+01, 0.11549900E+02, -.18184500E+01, 0.10518100E+01, 0.15703900E+01, -.82306000E+00, -.47069600E+01, 0.92421000E+01, 0.18981000E+01, -.48261100E+00, 0.76525400E+01, 0.46130000E+00, 0.12482000E+00, 0.14396800E+01, 0.22654000E+01, -.23541800E+00, -.45494700E+01, -.21504600E+01, -.15408800E+01, -.31373700E+00, 0.77865400E+00, -.12311000E+01, 0.29369300E+01, 0.22658400E+01, 0.10902800E+01, -.19735700E+01, 0.70373800E+00, 0.40680300E+00, -.26633400E+01, -.16533200E+01, -.73156700E+00, -.11569800E+01, -.51033200E+00, -.52475400E+00, 0.41941600E+00, 0.25830700E+01, -.29429100E+00, -.12870300E+01, -.34083700E+00, -.40705600E+00, -.23285700E+00, 0.20125600E+00, -.97103800E+00, -.13257000E+01, 0.79756500E+00, 0.87210500E+00, 0.64377300E+00, -.16640000E+01, -.26678400E+01, -.19227500E+00, 0.48376200E+00, 0.22486100E+01, -.93553200E-02, 0.13613200E+01, 0.45651700E+00, -.21347600E+01, -.14158600E+01, 0.13866600E+00, 0.90076400E-01, -.12733600E+01, 0.21533000E-01, 0.60809400E+00, 0.15872500E-01, -.16339200E+01, -.34570600E+02, -.12139900E+02, 0.28722600E+02, 0.28083300E+02, 0.25453900E+02, -.12454100E+02, -.14539800E+01, 0.90254900E+00, 0.22698700E+01, 0.14972500E+01, 0.95268800E+00, -.17321100E+01, 0.14008200E+01, 0.17172700E+01, 0.18987200E+01, 0.21922800E+01, -.73725400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.11566500E+02, 0.97941200E+01, 0.91882800E+00, 0.45632500E+01, -.87042400E+01, 0.57874000E+01, -.10338400E+02, -.97937200E+01, 0.24982400E+01, -.16339300E+02, 0.54933000E+01, 0.12063700E+02, 0.11093000E+00, 0.53754200E+01, 0.24975800E+01, -.98792000E+00, -.11949200E+02, 0.18408700E+02, 0.79386200E+00, -.12686000E+01, 0.13896100E+02, 0.17559600E+01, -.24053400E+01, 0.13749300E+01, 0.57261300E+01, 0.57322000E+00, -.14618700E+02, -.42684400E+01, 0.32055800E+01, 0.68353700E+00, -.10795600E+01, -.53409100E+01, 0.24014200E+01, 0.68436400E+01, 0.41484600E-01, -.28775700E+01, 0.55859200E+01, 0.19922300E+01, -.45362600E+01, -.20372200E+01, -.68787900E+00, -.28929700E+01, -.71755400E+00, -.21469300E+01, 0.49370700E+00, -.27407600E+01, 0.25640100E+00, 0.21309100E+01, 0.15351500E+01, -.41426900E+00, -.21066700E+00, 0.30816500E+00, 0.30910300E+01, -.46066300E+01, 0.30537400E+01, -.75326400E+01, 0.13081700E+01, 0.13850900E+01, 0.34079500E+01, 0.87967900E+00, -.29748200E+00, 0.31297600E+01, -.30261500E+00, -.13520900E-01, 0.90204000E+01, -.29586400E+01, 0.22409400E+01, 0.66458100E+00, 0.18421900E+01, 0.33827000E+01, -.11443900E+01, -.91041000E+01, 0.78472900E+00, 0.32541800E+01, -.73494600E+00, -.64464300E+02, 0.50413200E+02, 0.97560100E+02, -.55249800E+02, -.59701100E+02, -.17315300E+02, -.10856700E+02, 0.14723900E+02, -.56304500E+01, -.19634100E+02, 0.24568300E+02, 0.13667500E+02, -.56282900E+01, -.16747400E+02, 0.17044900E+02, -.49406000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.27635500E+01, -.43596400E+01, 0.15725300E+01, 0.16084500E+00, 0.22065600E+01, -.44466900E+01, 0.90169600E+00, 0.49906300E-01, -.25964200E+01, 0.34836700E+01, -.19371700E+01, -.72488700E+01, 0.10761100E+00, -.13391300E+01, 0.19190000E+00, 0.49661500E+00, 0.97630900E+00, -.84695400E+01, -.29324200E+01, -.10922300E+00, -.40050800E+00, -.44329200E+00, -.85556100E-01, -.46635700E+00, -.10815000E+01, -.12384700E+01, 0.33497700E+01, 0.12658900E+01, 0.21848600E+01, -.20081300E+00, 0.29751600E+00, 0.31832200E+01, 0.13349700E+01, -.16973100E+01, 0.64410800E+00, 0.10371400E+01, -.80834800E+00, -.54450600E+00, -.19415800E+01, 0.35163000E+00, 0.70343600E+00, -.70534600E+00, -.27401100E+00, -.87696300E+00, -.48067100E+00, 0.13959300E+01, -.25129800E+00, -.95776500E+00, -.24674200E+00, 0.77187200E-01, 0.25932600E+00, -.33472900E-01, 0.94709200E+00, -.13200900E+00, 0.67090400E+00, -.17667700E+01, 0.56642000E+00, -.47370400E+00, -.24482900E+01, -.14251900E+00, -.40565900E+00, -.11562900E+01, 0.89494000E-01, -.26540400E+00, 0.18249600E-01, -.76707600E+00, 0.50173500E-01, -.63919100E+00, 0.75755300E+00, 0.88291600E+00, 0.17346700E-01, -.14719200E+01, 0.33383300E+00, 0.43910800E+00, -.40683800E+00, 0.21052000E+00, 0.10334900E+02, 0.23169300E+02, 0.15710100E+02, 0.18104800E+00, -.13787800E+01, 0.22602100E+01, -.28915200E+01, 0.22301300E+01, -.80651100E+00, 0.59518800E+00, 0.16833300E+01, 0.30765200E+01, 0.46892300E+01, -.26896700E+01, -.23105000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.73080500E+01, -.70058400E+01, -.99031500E+00, -.35460700E+01, 0.91709500E+01, -.45561100E+01, 0.54813200E+01, 0.89226700E+01, -.57217600E+01, 0.12812800E+02, -.42137000E+01, -.89615400E+01, 0.69440300E+00, -.46860600E+01, -.24450100E+01, 0.27316600E+00, 0.79119200E+01, 0.18123700E+01, 0.12223800E+01, 0.40828900E+00, -.99807700E+01, 0.15242000E+01, 0.88211100E+00, -.21596500E+01, -.39546000E+01, 0.23826600E+01, 0.42648300E+00, 0.27690000E+01, -.13418600E+01, 0.19725900E+01, 0.24834200E+00, 0.43601600E+01, -.46370600E+01, -.40689900E+01, -.24937200E+01, 0.23141700E+01, -.34270200E+01, -.14834900E+01, 0.31777900E+01, 0.15246400E+01, 0.97003300E+00, 0.18244000E+01, 0.16124000E+00, 0.11048900E+01, 0.30793000E-01, 0.14306700E+01, 0.44280500E+00, -.35676500E+01, -.22971700E+01, -.37428500E+00, 0.14814200E+00, 0.90442800E+00, -.12380700E+01, 0.82055300E+00, -.96786300E+00, 0.39219000E+01, -.48566000E+00, -.86007500E+00, -.54286100E+01, -.62200100E+00, 0.16450100E+01, 0.10699900E+01, -.57348000E+00, -.11215100E+01, -.43577200E+01, 0.42399300E+00, -.30808200E-01, 0.94063000E+00, -.79175100E+00, -.26578600E+01, 0.82955600E+00, 0.31883300E+01, 0.12904800E+01, -.61980400E+01, 0.97414200E+00, -.13023900E+00, -.11829100E+01, 0.38014100E+02, 0.55295100E+02, -.44443500E+01, 0.15668700E+01, -.26299100E+01, 0.18749700E+00, -.30153800E+01, 0.14049300E+01, 0.40699900E+01, -.53673500E+00, -.11832400E+01, 0.35461800E+01, -.98147400E+00, -.75417000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.18967500E+01, -.95706400E+00, 0.37110100E+00, -.87629800E-01, 0.12740500E+01, -.28715400E+01, 0.33220200E+00, 0.82880000E+00, 0.46902200E+00, 0.69494600E+00, -.12083000E+01, -.10124900E+01, -.67979000E+00, -.10009800E+01, 0.41023600E+00, 0.62843900E-01, 0.36273400E+00, 0.52059300E-01, -.99966200E+00, -.26027000E+00, -.15206900E+01, -.56025900E+00, 0.38117600E+00, 0.10015300E+00, 0.10938200E-01, -.75003000E+00, 0.19170000E+01, 0.71632900E-01, -.11927400E+01, -.64566400E+00, 0.26898900E+00, -.18354100E+00, 0.46159000E+00, -.10483900E+00, 0.21141600E+00, -.11966900E+01, 0.77650600E-01, -.11679600E+00, -.44927200E+00, -.10699500E+01, -.21574400E+00, -.29157100E+00, 0.10652600E+00, 0.96794900E-02, -.13119100E+00, -.20123100E+00, 0.12802400E+00, -.17295100E+01, -.17117500E-01, 0.29968100E+00, 0.23007000E+00, 0.27240100E+00, -.84537400E+00, 0.10502100E+01, 0.11931100E-01, 0.88234400E+00, -.17543000E+00, -.26898100E+00, -.15726600E+01, -.21492600E+00, 0.17529300E+00, -.73958800E+00, -.40057100E-01, -.31950000E+00, -.33822500E+00, 0.93037700E+00, -.34245600E+00, -.62085900E+00, -.37456400E+00, -.17695500E+00, 0.14904700E+00, 0.82321900E+00, -.15950600E-01, -.14359000E+00, -.35021600E-01, 0.19659600E-01, -.74090000E-01, -.12979800E+00, 0.29429300E+02, -.10660800E+01, 0.15208100E+01, 0.14245700E+01, -.44890500E+01, 0.31490900E+00, 0.91628800E+00, -.12328400E+01, -.85625200E+00, 0.73871100E+00, 0.52695100E+01, -.50931300E+01, 0.56698300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.13296800E+01, 0.12531800E+01, -.69581700E+00, 0.18761900E+00, -.24600100E+00, 0.33811400E+01, 0.11259600E+01, 0.90782400E+00, 0.48300700E+00, -.56793900E+00, 0.26694800E+00, 0.18072500E+01, -.19239100E+00, 0.75619500E+00, 0.31735800E+00, -.14371100E+00, 0.90638600E+00, -.16989000E+01, -.34916000E+00, 0.83292500E-01, -.50840700E+00, -.26286800E-01, -.14423700E-01, -.15241800E-02, 0.94856700E+00, 0.27464500E+00, 0.18929100E+01, 0.40698600E+00, -.51141200E+00, -.43966400E+00, 0.77577100E+00, -.42501000E+00, -.54843200E-01, 0.75335400E-01, -.44132100E-01, -.21392600E+00, 0.55780700E+00, 0.15406300E+00, 0.71760200E-01, 0.11172900E+00, -.32742500E+00, -.37652400E-01, -.85615400E-01, -.93121800E-01, 0.27247700E+00, -.57080600E-01, -.13933000E-01, 0.45276400E+00, 0.26300900E+00, -.30858900E-01, -.41445700E-02, -.12792300E+00, 0.10559000E+00, -.13456200E+00, -.36302400E+00, 0.18068900E+00, -.20126800E+00, 0.27796200E+00, 0.31702800E+00, -.15599800E-01, 0.16500600E+00, -.23865200E+00, -.11580800E+00, -.66725500E+00, 0.95239900E+00, 0.66386000E+00, 0.20004600E+00, -.57500000E-01, 0.44315800E+00, -.48586600E-01, 0.18981300E+00, 0.23273900E-01, 0.92631000E-01, -.82009400E+00, 0.81862800E-01, 0.48865700E-01, 0.12357700E-02, 0.13974900E+00, 0.39516700E-01, -.25413800E+01, 0.69070500E+00, 0.23388400E+01, -.21361700E+01, 0.19400600E+01, 0.42449400E+00, -.15449500E+01, -.57907400E+00, 0.17909500E+01, 0.11206300E+01, -.20543700E+01, 0.79276500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.16933500E+01, 0.24938100E+01, -.27271800E+00, 0.55403000E+00, -.11451400E+01, 0.18207900E+00, -.16264000E+01, -.11178300E+01, 0.15459900E+01, -.28686300E+01, 0.94966600E+00, 0.25356000E+01, -.38069900E+00, -.24736400E+00, 0.49107100E+00, -.27058900E+00, -.15891200E+01, 0.30586300E+01, 0.83741900E+00, -.10185300E+00, 0.35721900E+00, 0.19423800E+00, -.21961100E+00, 0.25932000E+00, -.12952000E+00, 0.18516900E+00, -.18093900E+01, -.59678500E+00, 0.73957700E-01, 0.50154300E+00, -.32088200E+00, -.31123500E+00, 0.21728000E+00, 0.16937800E+00, -.23505000E-01, -.65171500E-02, 0.20656200E+00, 0.90041300E-01, -.32142400E+00, 0.34969400E+00, -.42266000E+00, 0.63230300E-01, -.17578100E+00, -.26825600E-02, 0.48537600E-01, 0.60242600E+00, -.14042400E+00, -.30844400E+00, 0.15248300E+00, -.68568700E-01, -.11616400E+00, 0.24385600E-01, -.16350500E+00, -.48942300E+00, -.32234900E+00, 0.27908100E+00, -.10630300E+00, 0.69310800E-01, 0.10081600E+00, 0.65235400E-02, 0.66535000E-01, -.24718100E-01, -.55995200E-01, -.15295500E-01, 0.89153600E-01, -.17321800E+00, -.53997700E-01, -.72660700E-01, -.52342600E-01, -.28648900E+00, 0.76886800E-01, 0.25624700E+00, 0.68158200E-01, 0.54637000E-01, 0.30311900E-01, -.25227200E-01, 0.54210300E-01, 0.90056400E-02, -.54031000E-01, 0.41484300E-01, -.15119100E+01, -.31430500E+00, 0.41516100E+00, -.22956900E+00, -.12885600E+01, 0.13053100E+01, 0.12995900E+01, -.22576200E+00, -.73806000E-01, 0.42550600E+00, -.44341200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.27563300E+01, -.23628900E+01, 0.20211400E+01, 0.19561000E+01, -.15238400E+00, 0.28171300E+01, -.35276000E+01, -.15196000E+01, 0.70401400E+00, -.43258500E+01, 0.16878300E+01, 0.18983600E+01, -.68883900E+00, -.10595000E+01, 0.17815300E+01, -.47754200E+00, -.24310100E+01, 0.48345400E+01, 0.14894500E+00, -.56089900E+00, -.21536500E+01, 0.47984100E+00, -.93503000E+00, 0.18045700E+00, -.31159100E+00, 0.73340500E+00, -.43256200E+00, -.30654400E+00, 0.54341300E+00, 0.10085500E+01, -.87511100E+00, -.56029900E+00, 0.28826700E+00, 0.51448100E+00, -.66142700E+00, -.31197200E+00, 0.56529300E+00, 0.29049600E+00, -.79462900E+00, -.12803200E+00, -.59443300E-01, 0.18113300E-01, 0.12106700E+00, 0.23458800E+00, -.13855400E+00, -.59202200E+00, 0.20870300E+00, 0.38661100E-01, 0.97948400E-01, 0.30795200E+00, 0.18257600E+00, -.48762800E+00, 0.89025300E+00, -.19429500E+00, 0.22446800E+00, -.60020500E+00, -.22312900E-01, -.49745600E-03, -.15754000E+01, -.31248000E+00, -.17435100E-01, -.82585100E+00, -.18663300E+00, -.70013600E+00, 0.22798400E+01, 0.21322600E+01, 0.35295100E+00, -.57429400E+00, 0.10220900E+01, 0.22142200E+01, -.42941000E+00, -.20452100E+01, -.26934600E+00, 0.14348000E+00, -.21612600E+00, 0.29360400E-01, 0.64138400E+00, -.73572100E-01, -.58041500E+00, 0.14502400E+01, 0.49449200E+00, -.86605100E+01, -.11400700E+00, -.81382100E+01, -.13180100E+00, -.12557900E+00, 0.30704900E+00, -.69358800E+01, -.66044300E+00, -.20536200E+00, 0.13411400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.97815100E+01, -.14649200E+02, 0.14505200E+01, -.41130500E+01, 0.10932900E+02, -.38985800E+01, 0.85596200E+01, 0.73018600E+01, -.11215000E+02, 0.18343800E+02, -.62734000E+01, -.26616100E+02, 0.34932700E+01, -.22961200E+01, -.46071200E+01, 0.23038100E+01, 0.23772700E+01, -.75875600E+01, -.37161400E+01, -.32008500E+00, -.10393500E+01, -.10008800E+01, -.25491800E+00, -.39291500E+00, 0.44297200E+00, -.15472600E+01, -.17455100E+01, -.13285500E+01, -.99028800E-01, -.24795400E+01, -.11982800E+01, 0.37304000E+00, -.76030600E+00, 0.12979400E+01, -.41230300E+00, -.58403900E+00, 0.10407800E+01, -.24942500E+00, 0.13361000E+01, -.22905600E+01, -.12886800E+01, 0.70304000E+00, 0.24924000E+00, -.64358600E+00, -.55568300E+00, 0.14653600E+00, -.33308400E+00, 0.57047200E+00, 0.15226000E+01, -.68412900E+00, -.22174300E+00, -.96495100E+00, -.22918500E+01, 0.27667600E+01, -.10135800E+01, 0.50702600E+01, -.68991400E+00, -.37423300E+00, -.21936900E+01, -.60093800E+00, 0.68724300E+00, -.26206300E+01, -.95129900E+00, 0.12455500E+01, 0.45188400E+01, -.46743700E+00, -.22353600E+01, -.29340100E+00, -.95066500E+00, -.33310900E+00, 0.66598000E+00, 0.28988500E+01, 0.21385200E+01, 0.64387100E+01, 0.17478200E+01, 0.70436000E+00, -.21442700E+01, 0.12471200E+01, 0.30477600E+00, -.26479600E+01, 0.71849900E+00, -.31746200E+01, -.36245000E+02, -.12045600E+01, -.20253600E+01, -.11588300E+02, 0.21257100E+01, 0.79522300E+00, 0.19249000E+02, -.36398700E+02, 0.16831600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.10002000E+01, -.24584300E+01, 0.97438600E+00, 0.34788700E-01, 0.46615500E+00, -.10671600E+01, 0.20622900E+00, 0.26524800E+00, -.10037000E+00, 0.90416500E+00, -.50232900E+00, 0.50941700E-01, -.51545200E-01, 0.40781200E+00, -.17455200E+00, 0.13287200E+00, 0.37105500E+00, -.17639800E+01, 0.17192700E-02, 0.13202200E+00, -.95603800E+00, -.51262600E+00, 0.70941800E-01, 0.13008600E-01, -.91845600E-01, -.56694000E-01, 0.78159800E+00, 0.11741500E+00, -.34050900E+00, -.29010500E+00, 0.26810400E+00, 0.69745600E-01, 0.31217600E+00, -.56050800E-01, 0.32220400E+00, 0.30126500E+00, -.85550800E-01, -.35985700E-01, 0.83464500E-01, 0.93690900E-02, 0.78120700E-01, -.47751300E-01, 0.17287200E-01, 0.31883000E-01, 0.12648600E-01, 0.92854100E-01, -.16315200E-01, 0.61838900E-01, -.53180600E-01, -.43283300E-01, 0.74224400E-03, -.36370800E-01, -.17045400E+00, 0.10178900E+00, 0.10754800E+00, 0.18121700E+00, 0.96001800E-02, -.75026200E-01, 0.97979700E-01, 0.12247100E-01, -.55267300E-01, 0.41167700E-01, 0.43514200E-01, 0.44839600E-01, 0.14539800E+00, -.23312400E+00, -.17308200E-01, -.34802700E-01, 0.14099400E-01, -.39443800E-01, -.36371600E-02, -.20514300E-01, 0.27574600E-01, 0.53157700E-01, 0.18616100E-01, -.64270300E-02, 0.22284400E-01, 0.74633400E-02, -.81271900E-01, -.23589500E-01, 0.56400900E-01, 0.95987400E-02, 0.87210300E-03, 0.29010200E+00, -.33201300E-01, 0.61380900E-01, -.33169700E-01, 0.41968300E-01, -.52157700E-01, -.37398300E-02, -.82436200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.15611800E+01, 0.20837100E+01, 0.23119300E+00, 0.10330800E+01, -.11989300E+01, -.10405300E+01, -.20747400E+01, -.20283300E+01, 0.14854900E+01, -.27325900E+01, 0.89606700E+00, 0.25910700E+01, -.22227400E+00, 0.46827600E+00, 0.36056800E+00, -.29006100E+00, -.12662600E+01, 0.33678900E+01, 0.25946000E+00, -.19663400E+00, 0.25441900E+01, 0.62742600E+00, 0.96964000E-01, 0.16337900E+00, 0.12759000E+00, -.42061200E+00, -.17699500E+01, -.10447000E+00, -.29891400E+00, 0.52314900E+00, -.36010200E+00, -.94448200E+00, 0.72304700E-01, 0.22355600E+00, 0.90375100E-02, -.55624700E+00, -.20702100E+00, 0.11038300E+00, -.35978900E+00, 0.57131400E+00, -.26176000E+00, -.17062300E+00, -.17388200E+00, 0.16355700E+00, -.26656400E+00, 0.13850400E+01, -.25442700E+00, -.26760100E+00, 0.10404600E+00, -.84040800E-01, -.24711900E+00, -.27770100E+00, -.48393500E+00, -.20030500E+00, 0.22111500E+00, 0.41242100E+00, -.72990000E-01, -.98353100E-01, 0.63377700E+00, 0.90474700E-01, -.43965100E-01, 0.33300800E+00, 0.31368400E-01, 0.28724600E+00, 0.69339700E+00, -.12507700E+01, -.97739000E-01, -.40102900E-01, -.81149500E-01, -.34523900E+00, 0.15611100E-01, 0.32503300E+00, -.92391500E-01, 0.17646400E-01, 0.31670800E-01, -.51938300E-01, 0.22148800E-02, -.45230800E-01, -.58350800E-01, -.17335600E+00, 0.89141600E+00, 0.28140600E-02, -.14001700E-01, 0.20703700E+00, -.36929400E+00, 0.13447200E+01, -.12909200E+00, -.10476300E+00, 0.92976000E-01, -.19316700E-01, 0.87967600E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.60828900E+01, -.10451000E+02, 0.85216600E+00, -.33130300E+01, 0.79576000E+01, -.54362600E+01, 0.52284900E+01, 0.66900100E+01, -.92649600E+01, 0.16073500E+02, -.43531600E+01, -.13486400E+02, 0.28790300E+01, -.82472400E+00, -.31941800E+01, 0.14085500E+01, 0.45312700E+01, -.14202900E+02, -.27299100E+01, 0.45678000E+00, -.24408100E+01, -.98417100E+00, 0.96679400E-01, -.10767800E+01, 0.21411000E+00, -.54771800E-02, 0.73477600E+01, 0.21927200E+01, 0.12608900E+01, -.21975800E+01, 0.21453000E+01, 0.58462600E+00, -.79192500E+00, -.11081200E+01, 0.77276100E+00, 0.19448300E+01, 0.29284500E+01, 0.21258700E+00, -.65495400E-04, -.19079500E+01, 0.15846800E+01, -.30418700E+01, 0.54620700E+00, 0.15781200E+00, -.24829300E+00, -.23537000E+01, 0.81893400E+00, -.10851900E+01, -.85016600E+00, 0.20805700E+00, 0.58084600E+00, 0.12377200E+00, 0.60348400E+00, -.52004600E+00, -.37307500E-02, -.16177300E+00, -.53002600E+00, 0.10018600E+01, -.19211500E+01, -.27955100E+00, 0.57961300E+00, -.14758800E+01, -.17162100E+00, -.28514700E+01, -.26674800E+01, 0.28774100E+01, 0.20369400E+01, -.25133300E+00, 0.63384400E+00, 0.15326700E+01, 0.56951500E-01, 0.20902700E+00, 0.62766900E+00, 0.35030500E+01, 0.14469800E+00, 0.14130100E+00, -.25496500E-01, -.29584000E+00, 0.82714700E+00, -.15139000E+01, 0.15804000E+01, -.38002300E+00, 0.13424200E+00, 0.30283600E+01, -.24840500E+01, 0.54840000E+01, -.73776200E+00, -.31968400E-01, -.31711700E+01, 0.10292300E+01, -.65443900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.23713100E+01, -.34982300E+01, 0.43871100E+00, -.69372800E+00, 0.28267000E+01, -.10806900E+01, 0.21954700E+01, 0.20231700E+01, -.26422300E+01, 0.45228300E+01, -.17133100E+01, -.44961600E+01, 0.51091400E+00, -.46238600E-01, -.59649800E+00, 0.39187000E+00, 0.21897800E+01, -.39856100E+01, -.11629500E+01, 0.13096700E+00, -.91787900E+00, -.11150100E+00, 0.17484400E+00, -.45588700E+00, 0.37987400E+00, -.26219200E+00, 0.27980400E+01, 0.98037800E+00, 0.75757500E-01, -.65501300E+00, 0.48526900E+00, 0.82936900E+00, -.60366400E+00, -.62147600E+00, -.11301200E+00, -.34091800E-01, -.28291500E+00, -.15382400E+00, 0.77923400E+00, -.35947000E+00, 0.83580000E+00, 0.68098700E-01, 0.32706000E+00, -.25270100E-01, 0.33252900E-01, -.12194200E+01, 0.30815300E+00, 0.96389100E-01, -.35957400E+00, 0.11804500E+00, 0.28927900E+00, 0.51687100E-01, 0.67010000E-01, 0.38779200E+00, 0.26860300E+00, -.88116600E-01, 0.11773700E+00, -.62447800E-01, -.16820900E+00, -.89904400E-02, -.63214200E-01, 0.47164000E-01, 0.59437700E-01, -.34912100E-01, -.17106100E+00, 0.25117100E+00, 0.84890500E-01, 0.75852400E-01, 0.12365200E+00, 0.32746800E+00, -.82190900E-01, -.35986100E+00, -.59008300E-01, -.14871300E+00, -.17205700E-01, 0.36902800E-01, -.59630000E-01, 0.25881400E-01, 0.12351700E-01, -.52974500E-01, -.13723300E+01, -.82117600E-02, 0.44936000E-02, -.11252900E+00, 0.44214100E+00, -.90941900E-01, 0.28841500E+00, 0.64823600E-01, -.21131000E+00, 0.13944100E+00, -.56129700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.66662400E+00, -.18018000E+01, 0.99228000E+00, 0.53392200E-02, 0.36563300E+00, 0.28009200E+00, -.12540900E+01, -.76651500E+00, -.12081200E+00, -.68250100E+00, 0.44180500E+00, -.21678900E+00, 0.19091200E+00, 0.16796900E+00, -.30065300E-01, 0.12689900E-01, -.97722100E+00, 0.23334200E+01, 0.27366700E+00, -.16150000E+00, 0.21972300E+00, 0.17477400E+00, -.19870100E+00, 0.84974000E-01, -.13738500E+00, 0.24728900E+00, -.37558100E+00, -.15693700E+00, 0.23280800E+00, 0.40413100E+00, -.16459100E+00, -.55926700E+00, 0.95717700E-04, 0.15361300E+00, -.16429000E+00, -.73736400E-01, 0.22217900E+00, 0.18562600E+00, 0.12451000E-01, 0.18042600E+00, 0.45207400E-01, 0.50454600E-01, -.13012000E+00, 0.15936800E+00, -.22745900E+00, 0.69800300E-03, -.35627900E-01, 0.46730200E+00, 0.21460900E-01, -.10786100E-01, -.32208000E-02, -.20626200E+00, 0.41722400E+00, -.11041600E+00, 0.12991800E+00, -.18761600E+00, 0.48826000E-01, -.23039500E-02, 0.18395000E+00, 0.15907100E-01, -.56990300E-01, 0.86413700E-01, 0.59377200E-02, -.38960400E-01, 0.32342400E+00, 0.13445600E+00, 0.10774800E+00, 0.60249100E-01, 0.64649000E-01, 0.18690200E+00, -.71763400E-01, -.38074100E+00, -.57806000E-01, 0.40398300E-02, -.61761400E-01, 0.87171000E-02, 0.82723200E-01, -.15349600E-01, -.98641500E-01, 0.16772500E+00, 0.37610800E-01, 0.13553100E+00, -.15138600E-01, 0.12135500E+00, -.82696700E-02, -.18697800E-01, -.54422100E-02, 0.31132000E+00, 0.13003800E-01, -.58680400E-02, -.75622100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { -.17867300E+01, -.28952500E+01, 0.16910300E+00, -.82534400E+00, 0.11509800E+01, 0.11907300E+01, 0.21973200E+01, 0.15563800E+01, -.17445900E+01, 0.32540900E+01, -.77419700E+00, -.31718300E+01, 0.40013600E+00, -.27273800E+00, -.33807300E+00, 0.30215000E+00, 0.21863900E+01, -.38912000E+01, -.75891800E+00, 0.22100800E+00, -.15006500E+01, -.13422200E+00, 0.13606100E+00, -.43752000E+00, 0.42334100E-02, 0.12204900E+00, 0.19390000E+01, 0.46682000E+00, 0.22949100E+00, -.50655700E+00, 0.29713600E+00, 0.28286800E+00, -.58856400E+00, -.50018800E+00, -.78996800E-01, 0.24584800E+00, -.24937600E+00, -.12216200E+00, 0.63350600E+00, -.70124100E-01, 0.58943700E+00, -.58264100E-01, 0.21456900E+00, 0.60838500E-01, 0.80297400E-02, -.12510100E+01, 0.20625700E+00, 0.16409200E+00, -.26902300E+00, 0.12633700E+00, 0.17291100E+00, 0.13300000E+00, 0.94545900E-01, 0.50566200E+00, 0.52837200E+00, -.11420000E+00, 0.14217800E+00, 0.33598300E-01, -.31231400E+00, -.34990500E-01, -.22365900E-01, -.10233700E+00, 0.29502200E-01, -.83635800E-01, -.24168400E+00, 0.40120500E+00, 0.14985300E+00, 0.44785500E-01, 0.10748600E+00, 0.34327200E+00, -.43132800E-01, -.26908800E+00, 0.29512900E-01, 0.18444200E+00, -.29539700E-01, 0.45709400E-01, -.82256900E-01, 0.19818300E-01, 0.36110500E-01, -.14896100E+00, -.10540300E+01, -.45756000E-01, 0.17972400E-01, -.15979700E+00, -.94793600E+00, 0.17305200E+00, 0.40639300E+00, -.27816800E+00, 0.55826400E+00, -.18844200E+00, 0.11630600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.74615600E+01, 0.10809800E+02, -.12472100E+01, 0.18331400E+01, -.67984100E+01, -.34026300E+01, -.78375000E+01, -.56886200E+01, 0.76989400E+01, -.12256300E+02, 0.43826200E+01, 0.87830600E+01, -.57748300E+00, -.31702100E+00, -.64967800E-01, -.13470900E+01, -.83485500E+01, 0.10827600E+02, -.53676200E-01, -.16069500E+01, 0.74700400E+01, 0.12504000E+01, -.75112000E+00, 0.20533100E+01, 0.76197800E-01, -.81157500E+00, -.10876700E+00, -.20383300E+01, -.97141400E+00, 0.97601400E+00, -.16818200E+00, -.60588500E+01, 0.18155400E+00, 0.10665700E+01, -.15025400E-01, -.17219800E+01, 0.25568000E+00, 0.10134600E+01, -.32680500E+01, 0.19110900E+01, -.69934800E+00, -.10204100E+01, -.15756300E+01, -.38657700E+00, 0.31479800E+00, 0.11724700E+01, -.36214400E+00, -.17938100E+01, 0.14311600E+01, 0.31759200E-01, -.13673200E+00, 0.48771300E+00, 0.46277700E+00, -.13147300E+01, -.63026300E+00, -.83699700E+00, 0.30567500E+00, -.34332500E+00, -.88970600E+00, 0.67629500E-01, -.40363000E+00, 0.30854200E+00, 0.34436400E+00, 0.13932000E+01, -.49507100E+01, -.26818400E+01, -.93240200E-01, 0.60868100E+00, -.70309600E+00, 0.29000500E+01, -.10066600E+01, -.44989300E+01, 0.82633700E+00, 0.56027500E+01, 0.53736900E+00, 0.27955500E+00, -.10626000E+01, 0.31903900E+00, -.39791800E+00, -.48110200E+01, 0.73406700E+00, -.16879200E+01, 0.59814200E+00, 0.53300500E+00, 0.15996000E+00, 0.25483200E+00, 0.17241400E+00, 0.24636300E+01, 0.16724800E+01, 0.48962200E+01, -.75210900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.93194800E+00, -.11218000E+00, 0.21674000E+00, 0.11804100E+00, 0.26789500E+00, 0.18660400E+01, -.17346500E+00, -.42161600E-01, 0.21382500E+00, -.46620600E+00, 0.49092100E+00, -.18673900E+00, 0.24722200E-01, 0.88589400E-01, 0.20702400E+00, 0.93422400E-01, -.50445500E+00, 0.12220700E+01, 0.36505600E+00, -.18404300E-01, -.34414300E+00, 0.41139500E-01, -.55950800E-01, 0.39869900E-01, -.60111100E-01, 0.18256700E+00, 0.10875200E+00, 0.15851600E+00, 0.49665300E-01, 0.28418700E+00, 0.22246500E+00, -.97294300E-01, 0.16884000E+00, -.17213400E+00, 0.75839700E-01, -.35861600E-01, 0.25398200E+00, 0.16609200E+00, 0.26507200E+00, 0.54183300E+00, 0.17619300E+00, 0.13118800E+00, -.10461700E+00, 0.34748100E-01, 0.25765000E-01, 0.22109200E+00, -.40487000E-01, 0.38597700E+00, -.21983300E-01, -.11702700E+00, 0.12949600E-01, -.74998000E-01, 0.15782100E+00, -.62110900E+00, -.10319900E+00, -.29810600E+00, 0.19022800E-01, -.11010900E-02, 0.38397300E+00, 0.41153400E-01, 0.79857100E-02, 0.85128200E-01, 0.24661800E-02, -.12472700E+00, 0.78596600E-01, -.10097700E+00, 0.55507000E-01, 0.94658000E-02, -.74819100E-01, -.22600900E+00, -.42115100E-02, -.15576000E+00, -.42449900E-01, -.36094800E+00, -.32928600E-01, -.87888100E-02, 0.73542000E-01, 0.98505500E-03, -.84819900E-02, 0.18833500E+00, 0.13964600E+00, 0.75703300E-01, -.28062400E-01, -.13765400E+00, 0.44716100E+00, -.10192000E+00, 0.75424700E-01, 0.23470200E+00, 0.40925700E+00, 0.25844400E-01, -.79981100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }, { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 } }
    };







    static double bending_lu_parameters[5][251][251] = {
        {
            { 0.31124900E+06, -.15516100E+06, -.14837500E+06, 0.16185500E+05, -.14292900E+05, -.11685400E+06, -.56170100E+05, -.13478800E+06, -.22718600E+05, 0.13533400E+06, -.66724600E+05, -.67394800E+05, 0.22303900E+05, 0.71944700E+04, -.61300200E+05, -.49903800E+05, -.66045700E+05, 0.13232700E+04, -.26183400E+05, 0.13193700E+05, 0.18297500E+05, 0.72653800E+05, 0.91571400E+05, -.63254100E+05, -.13356600E+06, -.23954500E+06, 0.79865600E+05, -.13032800E+06, 0.60006700E+05, 0.63728800E+05, -.65680700E+05, -.62516500E+05, 0.95491000E+05, 0.11462500E+06, 0.19503100E+06, -.41872100E+05, 0.28334500E+06, -.14116200E+06, -.13268800E+06, 0.23457900E+05, -.18203400E+03, -.11593800E+06, -.68220900E+05, -.15395600E+06, -.10674100E+05, -.49628800E+05, 0.21786200E+05, 0.11636300E+05, -.79645900E+05, -.12014600E+06, 0.94509900E+05, 0.13748900E+06, 0.30909100E+06, -.90314400E+05, -.61392800E+04, 0.48195000E+03, 0.34015300E+04, -.41507900E+05, -.41490500E+05, 0.35920000E+05, 0.66477600E+05, 0.92412100E+05, -.37860800E+05, -.72455600E+05, 0.34950000E+05, 0.35402100E+05, -.98745600E+04, -.14843700E+05, 0.36303800E+05, 0.29643900E+05, 0.86086200E+05, -.10417300E+05, -.34246500E+05, 0.18002400E+05, 0.21804500E+05, 0.26763700E+05, 0.47108600E+05, -.18643100E+05, -.51510400E+05, -.11567900E+06, 0.42263300E+05, 0.26421400E+06, -.13067700E+06, -.12875500E+06, 0.13054900E+05, -.12633500E+03, -.10210800E+06, -.66321400E+05, -.17934400E+06, -.15807200E+05, 0.54360000E+05, -.27391400E+05, -.43221400E+05, -.11951600E+06, -.15624000E+06, 0.10174800E+06, 0.22679500E+06, 0.42582400E+06, -.13151100E+06, -.27095200E+06, 0.13163300E+06, 0.12298500E+06, -.10795900E+06, -.11220600E+06, 0.19110900E+06, 0.22356200E+06, 0.44291500E+06, -.83149300E+05, -.13769700E+06, 0.68603200E+05, 0.67452500E+05, -.29052800E+04, -.37095300E+03, 0.47410400E+05, 0.69626600E+04, 0.72302900E+05, 0.93889000E+04, -.13496600E+06, 0.65781400E+05, 0.61817000E+05, -.22572000E+05, -.17108600E+05, 0.65743100E+05, 0.56024000E+05, 0.12206800E+06, -.72770700E+04, -.73626600E+04, 0.14557000E+04, 0.30923600E+04, -.25377600E+05, -.46784700E+05, 0.26630600E+05, 0.39305800E+05, 0.13304900E+06, -.34441800E+05, -.25965000E+06, 0.12663300E+06, 0.12526500E+06, -.15430200E+05, -.21286400E+04, 0.97744700E+05, 0.47079200E+05, 0.13866900E+06, 0.20614300E+05, 0.67934200E+05, -.34208300E+05, -.40343900E+05, -.42185600E+05, -.62933200E+05, 0.20721200E+05, 0.75454700E+05, 0.15397800E+06, -.57999300E+05, 0.17508500E+06, -.87237800E+05, -.82427800E+05, -.56022400E+04, -.12292200E+05, -.51683600E+05, 0.58955300E+04, -.62363100E+05, -.22521200E+05, 0.48558000E+05, -.23223400E+05, -.76468300E+04, 0.11903600E+06, 0.15682500E+06, -.13308200E+06, -.22623200E+06, -.45068600E+06, 0.11853800E+06, 0.37790500E+06, -.18721100E+06, -.17979900E+06, 0.64160500E+05, 0.37644400E+05, -.17746500E+06, -.14410600E+06, -.25806500E+06, 0.12720200E+05, 0.20732300E+06, -.10043300E+06, -.10125400E+06, 0.20688600E+05, 0.42400400E+04, -.86518900E+05, -.60865900E+05, -.95633100E+05, -.12249400E+05, -.11600800E+06, 0.58631300E+05, 0.67157000E+05, 0.59099600E+05, 0.96461300E+05, -.25886700E+05, -.11342000E+06, -.21132000E+06, 0.87109900E+05, -.23828800E+05, 0.99167600E+05, 0.25095500E+05, -.30605900E+05, 0.65991300E+04, -.94607300E+05, -.15641700E+06, -.19599100E+05, 0.17087000E+05, -.30611900E+05, 0.42074500E+05, 0.15364700E+04, 0.89047000E+05, -.13408600E+06, -.69136700E+05, 0.17878800E+06, -.10222400E+06, 0.10333900E+06, -.14395700E+06, 0.89299100E+04, -.35411400E+05, -.69598500E+05, 0.94474200E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22924300E+00, 0.86054900E+03, 0.95777600E+03, 0.12803300E+05, 0.21461100E+05, -.12673600E+05, -.25651100E+05, -.29495300E+05, 0.14142100E+05, 0.12651100E+06, -.52348500E+05, -.63236400E+05, 0.15801500E+05, 0.32983900E+05, -.54463100E+05, -.32617300E+05, -.59688400E+05, 0.89792000E+04, -.18572100E+06, 0.93705900E+05, 0.92218400E+05, 0.50283700E+05, 0.77566300E+05, 0.13240000E+05, -.74222500E+05, -.62912900E+05, 0.69540800E+05, -.14773500E+06, 0.26229800E+04, 0.74065800E+05, -.61623100E+05, -.12315200E+06, 0.92896700E+05, 0.79488900E+05, 0.14159900E+06, -.63525700E+05, -.27834000E+05, 0.15716900E+05, 0.14962400E+05, 0.18124700E+05, 0.33190500E+05, -.81926800E+04, -.31116300E+05, -.36120400E+05, 0.24333900E+05, 0.81355400E+05, -.81618300E+05, -.40606100E+05, -.82130800E+05, -.17211200E+06, 0.50379000E+05, 0.12193600E+06, 0.15769200E+06, -.12104900E+06, -.45874100E+05, -.13877700E+05, 0.23124100E+05, -.31050300E+05, -.56590600E+05, 0.35775200E+05, 0.35661400E+05, 0.62116000E+05, -.32177600E+05, -.13888000E+05, -.99418000E+04, 0.77953600E+04, -.18117200E+05, -.44034100E+05, 0.21049200E+05, 0.25288700E+05, 0.44341800E+05, -.28012200E+05, -.59444600E+05, 0.42222900E+05, 0.29695400E+05, 0.25504100E+05, 0.55092000E+05, -.54259700E+04, -.34967800E+05, -.46133000E+05, 0.42974300E+05, 0.55549500E+05, -.12345600E+05, -.29124200E+05, 0.28876700E+05, 0.69123500E+05, -.48452000E+05, -.55170300E+05, -.82074400E+05, 0.39454800E+05, 0.32591100E+06, -.16459200E+06, -.16318900E+06, -.87095800E+05, -.13562700E+06, -.23081300E+05, 0.13197700E+06, 0.11306700E+06, -.12121600E+06, 0.47523900E+05, -.72479100E+05, -.23005900E+05, -.98348900E+05, -.19341600E+06, 0.74198500E+05, 0.14881500E+06, 0.19334100E+06, -.13202900E+06, 0.67832600E+05, -.34989000E+05, -.34083200E+05, -.11474800E+05, -.24707700E+05, -.10056300E+05, 0.13866300E+05, 0.13958200E+05, -.21666200E+05, -.32085400E+05, -.55592600E+04, 0.15696100E+05, -.26300500E+05, -.54144000E+05, 0.32805100E+05, 0.38714900E+05, 0.60363900E+05, -.31637100E+05, 0.54899900E+05, -.58966400E+05, -.26316100E+05, -.36887800E+05, -.84002000E+05, 0.14900700E+05, 0.45272300E+05, 0.67158500E+05, -.60089900E+05, -.11028400E+06, 0.14113300E+05, 0.54585400E+05, -.33929100E+05, -.73568300E+05, 0.61825400E+05, 0.45395200E+05, 0.88364300E+05, -.34130000E+05, 0.14534500E+06, -.76381700E+05, -.72735000E+05, -.31782400E+05, -.56833500E+05, -.16541600E+05, 0.43314500E+05, 0.39538400E+05, -.52425500E+05, -.42261600E+05, 0.22264200E+05, 0.21832100E+05, 0.79693600E+04, 0.17297900E+05, 0.55307700E+04, -.83108200E+04, -.10157500E+05, 0.14260200E+05, -.22411800E+06, 0.12390800E+06, 0.11214100E+06, 0.95192400E+05, 0.16324300E+06, -.18274800E+05, -.15430200E+06, -.15905200E+06, 0.12882000E+06, 0.16359600E+06, -.64473600E+05, -.81282100E+05, 0.52703800E+05, 0.10190100E+06, -.10275900E+06, -.10389100E+06, -.15060100E+06, 0.49888000E+05, 0.17504900E+06, -.44858300E+05, -.87226800E+05, 0.26323800E+05, 0.60375900E+05, -.74875100E+05, -.34582400E+05, -.83584900E+05, 0.19530500E+05, -.15757800E+06, 0.88276800E+05, 0.78690400E+05, 0.44379300E+05, 0.90757100E+05, 0.49561500E+04, -.68643100E+05, -.71744700E+05, 0.76293000E+05, 0.14928700E+05, 0.15099400E+06, 0.10973200E+06, 0.38204500E+05, -.42775400E+05, -.14528100E+06, -.26888400E+05, 0.33288600E+05, 0.49950500E+05, 0.12716000E+05, 0.31477700E+05, 0.47736000E+05, 0.14112100E+05, -.14661700E+06, -.70101300E+05, 0.62679000E+05, -.86316400E+05, 0.61746200E+05, -.15117300E+06, 0.67829500E+05, -.10724700E+06, -.87814500E+05, 0.42641300E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10685900E+00, 0.68947000E-03, -.55159200E+04, 0.55290100E+05, 0.20411400E+05, -.38185800E+05, -.96063300E+05, -.53081200E+05, 0.28424800E+05, 0.97276700E+05, -.48549200E+05, -.48912600E+05, 0.33419600E+05, 0.29313300E+04, -.52160800E+05, -.60025600E+05, -.54656500E+05, 0.23918800E+04, -.14742100E+06, 0.73541200E+05, 0.64956500E+05, 0.63087700E+05, 0.53591300E+05, -.11251300E+04, -.10062800E+06, -.27659900E+05, 0.56618500E+05, -.22621700E+05, 0.11395800E+05, 0.13536100E+05, -.73205000E+05, -.32645100E+05, 0.56708900E+05, 0.12103200E+06, 0.76931400E+05, -.30759200E+05, -.39263900E+05, 0.19582100E+05, 0.12213000E+05, 0.60660700E+05, 0.27513500E+05, -.29231300E+05, -.10277400E+06, -.51346100E+05, 0.35407600E+05, 0.35221000E+06, -.17559900E+06, -.15976800E+06, -.86520500E+05, -.88109500E+05, -.49031300E+05, 0.12094900E+06, 0.18493500E+04, -.94551600E+05, -.37528500E+05, 0.18767700E+05, 0.19070700E+05, -.37886800E+05, -.11835000E+05, 0.36178200E+05, 0.63139900E+05, 0.46673000E+05, -.15041300E+05, 0.10994100E+06, -.54787600E+05, -.50629400E+05, -.20369500E+05, -.23186600E+05, -.19936600E+05, 0.27272700E+05, -.78430500E+04, -.28729200E+05, -.15187100E+06, 0.75710400E+05, 0.69823200E+05, 0.23698400E+05, 0.30604800E+05, 0.30531600E+05, -.29495400E+05, 0.14488600E+05, 0.36099500E+05, -.89543400E+05, 0.44588300E+05, 0.35855200E+05, 0.52047700E+05, 0.38154300E+05, -.10612200E+05, -.80040200E+05, -.21764600E+05, 0.40400300E+05, 0.28113700E+06, -.14023200E+06, -.12148700E+06, -.11124700E+06, -.96910500E+05, -.55214400E+04, 0.17282300E+06, 0.39568300E+05, -.99492000E+05, 0.22851400E+06, -.11387800E+06, -.96170300E+05, -.14269400E+06, -.97597700E+05, 0.28992000E+05, 0.22094600E+06, 0.80371100E+05, -.10903600E+06, 0.15435700E+06, -.77011100E+05, -.76033000E+05, -.20905400E+05, -.26618300E+05, -.33246500E+05, 0.29722300E+05, -.10491100E+05, -.30309500E+05, 0.43436000E+05, -.21618600E+05, -.16012700E+05, -.41309100E+05, -.24712300E+05, 0.14973000E+05, 0.64951800E+05, 0.27239400E+05, -.27053000E+05, 0.22529100E+06, -.11231900E+06, -.10780300E+06, -.32067600E+05, -.45595100E+05, -.46302300E+05, 0.40407100E+05, -.20392700E+05, -.50646300E+05, 0.63296400E+05, -.31502300E+05, -.27963400E+05, -.48071900E+05, -.31801300E+05, 0.13381600E+05, 0.76817300E+05, 0.29896300E+05, -.26824400E+05, 0.15272800E+06, -.76170900E+05, -.68595400E+05, -.38115400E+05, -.38288200E+05, -.20239000E+05, 0.53396900E+05, -.29569600E+03, -.44321800E+05, -.13716400E+06, 0.68418300E+05, 0.64763000E+05, 0.19442300E+05, 0.23389800E+05, 0.29673600E+05, -.25907600E+05, 0.12903800E+05, 0.26634500E+05, -.33136000E+06, 0.16527700E+06, 0.14559000E+06, 0.12588200E+06, 0.10579900E+06, 0.14133200E+05, -.19141300E+06, -.42171700E+05, 0.10606800E+06, 0.53250800E+05, -.26594000E+05, -.35491900E+05, 0.10452200E+06, 0.40631400E+05, -.87897600E+05, -.17639500E+06, -.11339400E+06, 0.43702500E+05, 0.76660300E+05, -.38319100E+05, -.40238400E+05, 0.37445600E+05, 0.85981300E+04, -.49615200E+05, -.67068500E+05, -.53832600E+05, 0.15427600E+04, -.21415800E+06, 0.10677400E+06, 0.95466800E+05, 0.47299200E+05, 0.50757600E+05, 0.32463900E+05, -.63827000E+05, 0.64840200E+04, 0.57227900E+05, 0.51616200E+05, 0.10682700E+06, 0.88370500E+05, -.49635900E+05, -.57950400E+05, -.10278700E+06, -.40247200E+05, 0.63525700E+05, 0.93097300E+04, -.21764500E+05, 0.28679300E+05, -.49364200E+05, 0.93942800E+04, -.13163900E+06, -.55578000E+05, 0.50592700E+05, -.10106000E+06, 0.13028800E+05, -.13286600E+06, -.60097000E+04, -.68686700E+05, -.12411100E+06, 0.77781600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10367100E+01, 0.55775400E+00, 0.17490900E+01, -.16979500E+06, -.59097700E+05, 0.13270200E+06, 0.34420700E+06, 0.23907600E+06, -.94091000E+05, -.23992800E+06, 0.12099700E+06, 0.11990400E+06, -.10825200E+06, -.13948400E+04, 0.14808100E+06, 0.20242700E+06, 0.16858200E+06, -.16796200E+05, 0.76180100E+06, -.38013100E+06, -.38828400E+06, -.24813900E+06, -.26558300E+06, -.29572300E+05, 0.45411900E+06, 0.33103000E+06, -.27958700E+06, -.30121200E+06, 0.14261200E+06, 0.15511900E+06, 0.26424500E+06, 0.14796500E+06, -.96528300E+05, -.46657000E+06, -.33813800E+06, 0.16571500E+06, 0.22667200E+06, -.11299000E+06, -.11360600E+06, -.19815800E+06, -.10536100E+06, 0.86829000E+05, 0.39222300E+06, 0.25321700E+06, -.14027300E+06, -.16249100E+07, 0.80647500E+06, 0.82496100E+06, 0.31398100E+06, 0.36449700E+06, 0.26540200E+06, -.52011900E+06, -.25619500E+06, 0.40285700E+06, -.14625800E+06, 0.69029600E+05, 0.73559200E+05, 0.15195300E+06, 0.88223800E+05, -.66530400E+05, -.26550700E+06, -.19885000E+06, 0.11237800E+06, -.37774600E+06, 0.18646100E+06, 0.19158500E+06, 0.61899900E+05, 0.67221400E+05, 0.69251300E+05, -.11489200E+06, -.54119000E+05, 0.94867000E+05, 0.63430300E+06, -.31493900E+06, -.31861000E+06, -.91889300E+05, -.12971100E+06, -.12343000E+06, 0.15658600E+06, 0.83751900E+05, -.15500700E+06, 0.13010600E+06, -.63124900E+05, -.75646900E+05, -.12004400E+06, -.43884300E+05, 0.43518900E+05, 0.25724900E+06, 0.21241000E+06, -.63090200E+05, -.13927700E+07, 0.69494500E+06, 0.70564300E+06, 0.42343100E+06, 0.46220700E+06, 0.86476500E+05, -.77346600E+06, -.57639000E+06, 0.47215400E+06, -.10828700E+07, 0.53511700E+06, 0.55611400E+06, 0.47645000E+06, 0.35511500E+06, -.21424500E+05, -.86820500E+06, -.60648600E+06, 0.42322000E+06, -.63873900E+06, 0.31858100E+06, 0.31915700E+06, 0.77757100E+05, 0.11079000E+06, 0.13243400E+06, -.14383900E+06, -.17329700E+05, 0.12719400E+06, -.20099700E+06, 0.97964000E+05, 0.10349800E+06, 0.12910100E+06, 0.76208400E+05, -.33655800E+05, -.24290900E+06, -.17475300E+06, 0.93849500E+05, -.91687800E+06, 0.45404900E+06, 0.46478600E+06, 0.10780900E+06, 0.16721600E+06, 0.20144300E+06, -.18445900E+06, -.65969100E+05, 0.19035400E+06, -.24454400E+06, 0.11756700E+06, 0.12187500E+06, 0.14201100E+06, 0.80745200E+05, -.28181600E+05, -.26706300E+06, -.16762600E+06, 0.73834400E+05, -.70761000E+06, 0.35267800E+06, 0.35708700E+06, 0.14823200E+06, 0.18253000E+06, 0.99381500E+05, -.26167800E+06, -.17963000E+06, 0.20521600E+06, 0.47819500E+06, -.23846900E+06, -.23877700E+06, -.57443300E+05, -.76435200E+05, -.10164700E+06, 0.10608800E+06, 0.15130400E+04, -.89074500E+05, 0.17173900E+07, -.85586200E+06, -.87270000E+06, -.47311700E+06, -.49524300E+06, -.16592700E+06, 0.83043700E+06, 0.54916400E+06, -.50388700E+06, 0.13253500E+06, -.64312600E+05, -.76874600E+05, -.34509300E+06, -.14692100E+06, 0.20536500E+06, 0.63640100E+06, 0.45658200E+06, -.18930600E+06, -.21941900E+06, 0.11403900E+06, 0.10956600E+06, -.11290300E+06, -.57258300E+04, 0.15175200E+06, 0.22948100E+06, 0.18471500E+06, 0.38222700E+04, 0.10103500E+07, -.50295900E+06, -.51338200E+06, -.18669700E+06, -.24000900E+06, -.16401100E+06, 0.32601400E+06, 0.21539700E+06, -.26851600E+06, -.28100100E+06, -.40448800E+06, -.36273000E+06, 0.30971400E+06, 0.26038600E+06, 0.38042800E+06, 0.34810100E+06, -.27001500E+06, -.15164800E+06, 0.13505000E+05, -.27330800E+06, 0.26243500E+06, -.21103600E+06, 0.48620700E+06, 0.27079800E+06, -.35224200E+06, 0.43971200E+06, -.36760400E+05, 0.51076100E+06, 0.51436900E+05, 0.27896000E+06, 0.51180100E+06, -.13086500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.82641800E-01, 0.31724200E+00, -.33584400E-01, -.16818000E-01, 0.58574500E+04, -.12815300E+04, -.34901100E+04, -.43600500E+04, -.27793000E+03, 0.45055800E+05, -.22395000E+05, -.22531700E+05, 0.30218200E+04, 0.12827800E+05, -.18111200E+05, -.85268200E+04, -.19408500E+05, 0.46885300E+03, 0.37085200E+04, -.19753500E+04, -.20930800E+04, 0.25758400E+04, 0.49154300E+04, -.38387500E+04, -.97586100E+04, -.88049600E+04, -.85684100E+03, -.62125200E+05, 0.35223300E+05, 0.31122700E+05, -.64217900E+04, -.20811600E+05, 0.27164700E+05, 0.18163500E+05, 0.32941100E+05, -.34312300E+04, 0.46035100E+03, -.26435800E+03, -.26121200E+03, 0.71373300E+03, 0.75578500E+04, -.21206600E+04, -.50104200E+04, -.66980000E+04, 0.14148800E+04, -.68177200E+05, 0.36544400E+05, 0.34415900E+05, -.50007200E+04, -.24109100E+05, 0.30647600E+05, 0.23820900E+05, 0.39430900E+05, -.68737400E+04, -.14208200E+05, 0.94740700E+04, 0.71294900E+04, -.25959300E+04, -.86336700E+04, 0.69865600E+04, 0.52996900E+04, 0.10382600E+05, -.85008500E+03, -.22803000E+05, 0.11754900E+05, 0.11563400E+05, -.43489000E+03, -.69849800E+04, 0.88557200E+04, 0.40113500E+04, 0.10781600E+05, -.71144500E+03, 0.16761300E+05, -.84615400E+04, -.84829600E+04, 0.32800600E+03, 0.59000200E+04, -.67291700E+04, -.40921900E+04, -.93128300E+04, 0.94565700E+03, 0.53216600E+05, -.26417300E+05, -.26915400E+05, 0.13641300E+04, 0.13340500E+05, -.21705500E+05, -.14604400E+05, -.24281900E+05, 0.10057200E+04, -.89380000E+04, 0.46739900E+04, 0.47521700E+04, -.49422300E+04, -.84748000E+04, 0.83004100E+04, 0.19297800E+05, 0.17561500E+05, 0.65164000E+02, -.78929300E+05, 0.41668600E+05, 0.39895100E+05, -.45828600E+04, -.28463200E+05, 0.34253500E+05, 0.26017400E+05, 0.43913900E+05, -.24197100E+04, 0.51918700E+04, -.26067900E+04, -.25967900E+04, -.11591900E+04, -.42002600E+04, 0.66698100E+02, 0.51846200E+04, 0.40722700E+04, -.24085200E+04, -.27082600E+05, 0.14741300E+05, 0.13615400E+05, -.17127300E+04, -.92311300E+04, 0.11665500E+05, 0.82608500E+04, 0.14468300E+05, -.88274600E+03, -.21940300E+05, 0.12845900E+05, 0.11165400E+05, -.10373000E+04, -.99832600E+04, 0.97849700E+04, 0.62797800E+04, 0.14653600E+05, -.38304800E+04, -.50181000E+05, 0.27378800E+05, 0.25090400E+05, -.40696900E+04, -.13230800E+05, 0.21495500E+05, 0.14820700E+05, 0.25220000E+05, -.25644400E+04, 0.18635100E+04, -.71535000E+03, -.80064900E+03, -.24237800E+03, -.37514300E+04, 0.36136300E+03, 0.35562300E+04, 0.43452800E+04, -.53180800E+03, -.12603000E+04, 0.61998800E+03, 0.63460200E+03, 0.91899400E+03, 0.31298700E+04, -.84073000E+03, -.40929200E+04, -.34531200E+04, 0.13407000E+04, 0.46905400E+05, -.24255300E+05, -.23805400E+05, 0.81876400E+04, 0.19756000E+05, -.25362600E+05, -.30253800E+05, -.37094500E+05, 0.52372600E+04, 0.89107200E+05, -.44685800E+05, -.44694200E+05, 0.77226400E+04, 0.29537200E+05, -.38840900E+05, -.26092700E+05, -.45541200E+05, 0.30598900E+04, 0.55971300E+05, -.30490300E+05, -.27991100E+05, 0.34059400E+04, 0.12723700E+05, -.22921100E+05, -.13629300E+05, -.24635900E+05, 0.15837500E+04, 0.18169800E+05, -.89910400E+04, -.93169300E+04, 0.56275900E+03, 0.89669600E+04, -.89572700E+04, -.10009800E+05, -.14008500E+05, 0.21783700E+04, -.15342200E+05, 0.26008600E+05, 0.74250400E+04, 0.16060300E+05, 0.80872600E+04, -.25453100E+05, -.25789600E+04, -.13464800E+05, 0.24843300E+04, 0.19353600E+04, -.35652300E+04, 0.17326700E+05, -.23280800E+04, -.22038200E+05, -.48852800E+04, 0.10598000E+05, -.46613600E+04, 0.16846800E+05, -.22752300E+05, 0.14531600E+05, -.11294100E+05, -.23707700E+04, 0.11318300E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.57191300E+00, -.11158400E-01, -.10399200E+01, 0.20722900E+00, -.14183700E+01, 0.30751100E+05, 0.92196900E+05, 0.21469500E+05, -.74997400E+04, 0.28038700E+05, -.13621800E+05, -.14056800E+05, 0.90241400E+04, 0.16466300E+05, -.26579900E+04, 0.24128500E+05, -.59476000E+04, 0.17484900E+04, -.21155300E+06, 0.10538600E+06, 0.10432600E+06, 0.47841900E+05, 0.75389900E+05, 0.49850800E+05, 0.90091100E+04, -.74076600E+05, 0.66919100E+05, -.40290000E+05, 0.24098200E+05, 0.19589800E+05, -.44910900E+05, -.60975600E+05, 0.26110100E+05, 0.17563100E+04, 0.95441500E+05, -.33485500E+05, -.21294900E+05, 0.10601300E+05, 0.10237200E+05, 0.86909800E+04, 0.14400600E+05, 0.30886300E+05, 0.83095300E+05, 0.66151400E+04, 0.47305800E+04, 0.71124800E+05, -.33032800E+05, -.34387300E+05, -.72875600E+05, -.10870100E+06, 0.85989000E+04, 0.13762100E+05, 0.16275600E+06, -.81806900E+05, 0.12002200E+04, 0.17336700E+04, -.31417400E+03, -.28387300E+05, -.35552700E+05, 0.13277500E+05, 0.15153400E+05, 0.51176500E+05, -.21850600E+05, 0.48897300E+05, -.24276700E+05, -.22510500E+05, -.10018600E+05, -.23399800E+05, -.17901100E+05, -.18758100E+05, 0.22105000E+05, -.16002000E+05, -.11033700E+06, 0.55208500E+05, 0.53725600E+05, 0.24719000E+05, 0.45036200E+05, 0.22479400E+05, -.70776800E+04, -.51409300E+05, 0.38806600E+05, -.49791000E+05, 0.25372300E+05, 0.23345900E+05, 0.15599600E+04, 0.18614000E+05, 0.42025700E+05, 0.72231300E+05, -.17148100E+05, 0.73556300E+04, 0.36708400E+06, -.18286700E+06, -.18138500E+06, -.82621100E+05, -.12598300E+06, -.87270700E+05, -.84464700E+04, 0.14246600E+06, -.11532800E+06, 0.17840600E+06, -.87060500E+05, -.87004700E+05, -.71527200E+05, -.11637300E+06, -.52194600E+05, -.58395600E+05, 0.13014000E+06, -.82660400E+05, -.86872000E+05, 0.43299900E+05, 0.43529700E+05, -.10811400E+05, -.57351500E+04, 0.23622200E+05, -.26084100E+05, 0.39007100E+05, 0.24932800E+04, 0.18461300E+05, -.80568100E+04, -.90368100E+04, -.14378300E+05, -.24200200E+05, -.11307900E+05, -.28537300E+05, 0.29452700E+05, -.13174300E+05, -.21458000E+05, 0.12522400E+05, 0.12015200E+05, -.27447100E+05, -.42092300E+05, 0.20868100E+05, 0.17276600E+05, 0.97934500E+05, -.28459100E+05, -.64838900E+05, 0.34549800E+05, 0.32639800E+05, -.12515900E+05, -.16955900E+05, 0.76572600E+04, -.48086900E+05, 0.38052400E+05, -.37296400E+04, 0.12224000E+06, -.60782500E+05, -.59916800E+05, -.33689900E+05, -.52419700E+05, -.20324200E+05, 0.16749600E+05, 0.75413000E+05, -.46080900E+05, 0.11851400E+06, -.59119100E+05, -.59296400E+05, 0.50273400E+04, -.35053900E+04, -.30438700E+05, 0.28528300E+05, -.35055400E+05, -.11744000E+05, -.27843500E+06, 0.13801100E+06, 0.13786800E+06, 0.94009400E+05, 0.13211900E+06, 0.58702400E+05, 0.10029100E+05, -.16922600E+06, 0.11472900E+06, 0.40021400E+05, -.19887400E+05, -.18433800E+05, 0.36578600E+05, 0.51780500E+05, 0.22725400E+04, 0.72321300E+05, -.53533700E+05, 0.19410900E+05, -.24017100E+05, 0.95210700E+04, 0.11978600E+05, 0.56974300E+04, 0.18499100E+05, 0.25982600E+05, 0.62653100E+05, 0.18436500E+05, 0.88387200E+04, -.23173800E+06, 0.11593900E+06, 0.11477500E+06, 0.46975300E+05, 0.82357100E+05, 0.49896800E+05, -.14249900E+05, -.85717800E+05, 0.75241300E+05, 0.53874800E+05, 0.84487900E+05, 0.79958800E+05, -.11016700E+05, -.62611800E+05, -.71158600E+05, -.42376300E+05, 0.56482200E+05, 0.41576700E+05, 0.49773700E+04, 0.40536700E+05, 0.23912000E+05, 0.49913000E+05, -.46602200E+05, -.48548500E+05, 0.50004100E+05, -.32375100E+05, 0.21946400E+05, -.49732300E+05, 0.52573100E+05, -.85272100E+05, -.22271900E+05, 0.32811700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.35928000E+00, 0.35725100E-01, 0.52287100E+00, -.37210700E-02, -.47821900E+00, 0.11494200E+00, -.50404100E+04, 0.11816500E+05, -.42869100E+04, 0.51871100E+05, -.25946800E+05, -.25905400E+05, 0.12486400E+05, 0.58304200E+04, -.22813800E+05, -.19851700E+05, -.19990200E+05, -.44907700E+04, 0.21062000E+06, -.10509500E+06, -.10321700E+06, -.27289200E+05, -.56417000E+05, -.39155700E+05, 0.28623200E+05, 0.45025700E+05, -.64666200E+05, -.18625900E+06, 0.93761100E+05, 0.92711300E+05, -.64232300E+04, 0.19007600E+05, 0.54460700E+05, 0.13338900E+05, 0.61332300E+04, 0.37126700E+05, 0.29680700E+05, -.14816400E+05, -.14571000E+05, -.47295700E+04, -.81189300E+04, -.48329000E+04, 0.22497100E+04, 0.17552800E+05, -.12355100E+05, -.29469800E+06, 0.14759200E+06, 0.14467500E+06, 0.38275200E+05, 0.70857000E+05, 0.57672700E+05, -.38075300E+05, -.50746900E+05, 0.82587900E+05, -.10315900E+06, 0.51842900E+05, 0.51321400E+05, -.18275400E+04, 0.13103300E+05, 0.28199600E+05, 0.23199600E+04, 0.13654200E+04, 0.22619400E+05, -.54583200E+05, 0.27264300E+05, 0.25573300E+05, 0.99660800E+04, 0.12905800E+05, 0.96629100E+04, -.11547400E+05, -.15852900E+05, 0.15680900E+05, 0.10713800E+06, -.53457600E+05, -.52370400E+05, -.20337800E+05, -.30776700E+05, -.16762300E+05, 0.25517200E+05, 0.30394300E+05, -.32985900E+05, 0.70523600E+05, -.35314700E+05, -.32494400E+05, -.31904100E+04, -.85798900E+04, -.19356800E+05, -.17477900E+04, 0.17464800E+05, -.16318200E+05, -.37475000E+06, 0.18699000E+06, 0.18428400E+06, 0.45985300E+05, 0.97718000E+05, 0.72233900E+05, -.48785300E+05, -.80915200E+05, 0.11125100E+06, -.33430400E+06, 0.16737400E+06, 0.16344300E+06, 0.29828600E+05, 0.69257900E+05, 0.73329200E+05, -.26240000E+05, -.51579400E+05, 0.90849000E+05, -.13680900E+05, 0.68357700E+04, 0.67902900E+04, 0.77149700E+04, 0.88317300E+04, -.66497600E+03, -.48150300E+04, -.17724000E+05, 0.82429900E+04, -.74967600E+05, 0.37683700E+05, 0.36900400E+05, 0.20457100E+04, 0.10678300E+05, 0.19587700E+05, 0.62206400E+03, -.83019900E+04, 0.17605700E+05, -.11540400E+06, 0.57998800E+05, 0.55748500E+05, 0.21621200E+05, 0.32957800E+05, 0.18345100E+05, -.27006700E+05, -.35173800E+05, 0.34802500E+05, -.70237100E+05, 0.35590900E+05, 0.34994000E+05, -.66390300E+04, 0.16110400E+04, 0.24830100E+05, 0.16060800E+05, 0.23313400E+04, 0.10595600E+05, -.13888000E+06, 0.69333000E+05, 0.68122100E+05, 0.24422200E+05, 0.41519500E+05, 0.21772900E+05, -.31178000E+05, -.41533500E+05, 0.44273200E+05, -.69831400E+04, 0.34743300E+04, 0.34662400E+04, -.36057200E+04, -.25929100E+04, 0.37348900E+04, -.83495000E+03, 0.13129200E+05, -.19891100E+04, 0.39994600E+06, -.19968500E+06, -.19677100E+06, -.40937300E+05, -.92797700E+05, -.84484100E+05, 0.38550200E+05, 0.68903900E+05, -.10948200E+06, 0.17163400E+06, -.85755900E+05, -.85225000E+05, 0.13305800E+05, -.93498300E+04, -.57037500E+05, -.30029900E+05, -.15229300E+05, -.32002500E+05, 0.52785400E+05, -.26918300E+05, -.26361600E+05, 0.11808600E+05, 0.64495300E+04, -.23009800E+05, -.21351700E+05, -.17925100E+05, -.38384000E+04, 0.20599300E+06, -.10285400E+06, -.10099200E+06, -.35883800E+05, -.59200700E+05, -.33548500E+05, 0.44332700E+05, 0.54290000E+05, -.63491800E+05, -.81387000E+05, -.44638800E+05, -.57721200E+05, 0.26547400E+05, 0.59138900E+05, 0.40079400E+05, 0.38334900E+05, -.60521400E+05, -.64858100E+05, -.32937200E+05, -.70963100E+05, 0.12205900E+05, -.47741500E+05, 0.43969800E+05, 0.47073500E+05, -.33605300E+05, 0.57696500E+05, 0.80302300E+04, 0.47933300E+05, -.14473100E+05, 0.51790600E+05, 0.56911500E+05, 0.12160300E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.96532100E+00, 0.46268200E+00, 0.69877600E+00, 0.39054200E+00, -.56478500E-01, 0.86700600E-01, 0.30874600E+00, -.19190800E+05, 0.98184600E+03, -.29256900E+05, 0.14649400E+05, 0.14608500E+05, -.55251600E+04, 0.54512600E+03, 0.13101300E+05, 0.14012100E+05, 0.83303300E+04, 0.47085200E+04, -.98157900E+05, 0.48999500E+05, 0.51775500E+05, 0.44826000E+04, 0.16924600E+05, 0.27050300E+05, -.13996400E+05, -.45996100E+05, 0.20717400E+05, 0.96881300E+05, -.48941100E+05, -.51356700E+05, 0.31663000E+04, -.15308300E+05, -.31204000E+05, -.30041500E+04, 0.19479000E+05, -.20833400E+05, -.31199700E+05, 0.15569100E+05, 0.15227900E+05, 0.51817100E+04, 0.86620800E+04, 0.47044800E+04, -.99522900E+04, -.26360300E+05, 0.96754000E+04, 0.12409200E+06, -.62551200E+05, -.67360900E+05, -.85101400E+04, -.29659100E+05, -.34437000E+05, 0.22923500E+05, 0.72003400E+05, -.30182000E+05, 0.75838400E+05, -.38137300E+05, -.37948000E+05, -.31161800E+04, -.14745000E+05, -.18477600E+05, 0.59112000E+04, 0.82569100E+04, -.17954900E+05, 0.78364300E+04, -.39892300E+04, -.40687100E+04, -.17949700E+03, -.15513000E+04, -.39835700E+04, 0.34904100E+04, 0.22478000E+05, -.10700000E+04, -.37653800E+05, 0.18807100E+05, 0.18425400E+05, 0.41988300E+04, 0.84006600E+04, 0.99832200E+04, -.13033300E+05, -.32770200E+05, 0.80393700E+04, 0.44022100E+05, -.21749800E+05, -.17125500E+05, -.18273900E+05, -.21114300E+05, 0.69864900E+04, 0.16546100E+05, -.34582300E+05, -.19674200E+05, 0.17268200E+06, -.86196100E+05, -.90097100E+05, -.43977300E+04, -.24634600E+05, -.52763800E+05, 0.22453700E+05, 0.85002100E+05, -.31566600E+05, 0.10585000E+06, -.53396000E+05, -.58720800E+05, 0.50769800E+04, -.12947000E+05, -.41094100E+05, 0.82605800E+04, 0.81882300E+05, -.18252800E+05, 0.26236400E+05, -.13092100E+05, -.13082800E+05, -.64410100E+04, -.10309600E+05, -.20775400E+04, 0.14453500E+05, 0.24106100E+05, -.89178900E+04, 0.21879000E+05, -.11080100E+05, -.12226600E+05, 0.34434300E+04, -.10615400E+04, -.10320900E+05, -.16129100E+04, 0.19986900E+05, -.28578500E+04, 0.29481900E+05, -.15040800E+05, -.17625800E+05, -.25743700E+04, -.10132900E+05, -.92005800E+04, 0.16495200E+05, 0.48325500E+05, -.71525300E+04, 0.10453500E+05, -.55332200E+04, -.51504400E+04, 0.70230700E+04, 0.14446100E+04, -.83246000E+04, -.93204500E+04, 0.19995200E+05, -.84930100E+03, 0.61824700E+05, -.30868000E+05, -.31717500E+05, -.58393600E+04, -.12755200E+05, -.15328400E+05, 0.19685600E+05, 0.43007600E+05, -.13076000E+05, 0.41442700E+04, -.20715100E+04, -.22659000E+04, 0.21889700E+04, 0.26848600E+04, -.33578500E+04, -.65048500E+04, -.19693400E+05, 0.11418500E+04, -.21359400E+06, 0.10671700E+06, 0.11334900E+06, 0.75927400E+04, 0.33596700E+05, 0.64488800E+05, -.21198700E+05, -.83766300E+05, 0.40887000E+05, -.10348600E+06, 0.51756000E+05, 0.57817300E+05, -.85394900E+04, 0.96539500E+04, 0.41494000E+05, 0.19559700E+05, -.12058100E+05, 0.17898500E+05, -.11959400E+05, 0.63818100E+04, 0.59628200E+04, -.69436100E+04, -.20185000E+04, 0.87397100E+04, 0.14004800E+05, 0.19906800E+04, 0.18521600E+04, -.88515700E+05, 0.44207400E+05, 0.47598200E+05, 0.67499600E+04, 0.17441800E+05, 0.25108300E+05, -.24294800E+05, -.54813400E+05, 0.17921300E+05, 0.31246700E+05, 0.18282200E+05, 0.23106800E+05, -.40189000E+05, -.20124700E+05, -.12652000E+05, -.50722100E+05, 0.16626200E+05, 0.31762500E+05, 0.18566300E+05, 0.44735200E+05, -.22676300E+05, 0.47861300E+05, -.14175700E+05, -.22441500E+05, 0.40985700E+05, -.25444300E+05, -.64794000E+04, -.20508600E+05, -.16323000E+04, -.20215000E+05, -.19506400E+05, -.68281800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22545800E+00, 0.14025800E+00, -.24203500E+00, -.10468500E+00, -.13061200E+00, -.47864900E-01, -.38328700E+00, 0.49419600E-02, 0.11543100E+05, 0.30468800E+05, -.15061700E+05, -.15252100E+05, 0.28038400E+04, 0.56651300E+04, -.12599400E+05, -.58871700E+04, -.13374300E+05, 0.11620700E+05, 0.11608600E+05, -.58759000E+04, -.73054000E+04, -.39763800E+04, -.51175700E+04, -.91262200E+03, 0.54151500E+04, 0.62248500E+04, 0.40900700E+04, -.41584900E+05, 0.22859600E+05, 0.21399500E+05, -.78101400E+03, -.93869000E+04, 0.14985500E+05, 0.25220000E+04, 0.12946000E+05, -.12949300E+05, 0.32622000E+04, -.16407400E+04, -.17609300E+04, -.10628000E+04, 0.64169100E+03, -.22132200E+03, 0.17354200E+04, 0.26694700E+03, 0.90374900E+04, -.66221600E+05, 0.34360600E+05, 0.35359600E+05, 0.48239700E+04, -.85743300E+04, 0.21724600E+05, 0.84542700E+03, 0.13169700E+05, -.62963400E+04, -.27573100E+05, 0.14947100E+05, 0.13917700E+05, -.31694800E+04, -.20941200E+04, 0.11141800E+05, 0.63353500E+04, 0.10505900E+05, -.88738200E+04, -.31704600E+05, 0.15875900E+05, 0.16706700E+05, -.78720400E+03, -.21912400E+04, 0.11682400E+05, 0.33974100E+04, 0.89305400E+04, -.45804300E+04, 0.32227900E+05, -.16001300E+05, -.16647700E+05, -.82240900E+03, 0.29174300E+03, -.10715500E+05, -.12544700E+04, -.55807700E+04, 0.14835500E+04, 0.21976000E+05, -.10783100E+05, -.13031400E+05, -.82038600E+03, 0.88992300E+04, -.94444300E+04, -.13179800E+04, -.54049000E+04, 0.11926600E+05, -.11458700E+05, 0.58561400E+04, 0.76550600E+04, 0.83244100E+04, 0.70455100E+04, -.18973500E+04, -.13224800E+05, -.15561300E+05, -.40050200E+04, -.75891600E+05, 0.38975800E+05, 0.40766300E+05, 0.15075900E+04, -.81835400E+04, 0.27167900E+05, 0.45716200E+04, 0.16584000E+05, -.23022400E+05, 0.17580700E+04, -.89703200E+03, -.89214900E+03, 0.23138700E+04, -.28900300E+02, -.14742200E+04, -.70967200E+03, -.16319000E+04, -.39293300E+03, -.19922000E+05, 0.10562300E+05, 0.10480300E+05, 0.24594600E+03, -.35202100E+04, 0.72753300E+04, 0.11767400E+04, 0.51771300E+04, -.74231500E+04, -.27378300E+05, 0.14633000E+05, 0.14981000E+05, 0.14797900E+04, -.44805800E+04, 0.97166200E+04, 0.26045200E+03, 0.56075200E+04, -.13142500E+04, -.90477200E+04, 0.56997200E+04, 0.45067500E+04, 0.40811200E+04, -.67713000E+04, 0.52401900E+03, -.82060600E+04, -.56632000E+03, -.52635400E+04, -.18084400E+05, 0.91321400E+04, 0.98223100E+04, 0.15661800E+04, 0.22685100E+04, 0.54005800E+04, -.44773700E+03, -.33756700E+03, -.18014800E+04, -.30958100E+04, 0.15502900E+04, 0.15909100E+04, -.20249900E+04, 0.25302400E+02, 0.18051000E+04, 0.76462900E+03, 0.17880300E+04, 0.44701200E+03, 0.31833600E+05, -.16347300E+05, -.18432700E+05, -.10008200E+05, 0.61412500E+03, -.50125600E+04, 0.13619600E+05, 0.80178900E+04, 0.45139300E+04, 0.56600100E+05, -.28254600E+05, -.29654300E+05, 0.28199500E+04, 0.10904900E+05, -.22637800E+05, -.86133500E+04, -.21208400E+05, 0.25780600E+05, 0.75634200E+04, -.50960200E+04, -.38107400E+04, -.29964900E+04, 0.76745400E+04, -.41297700E+03, 0.75227900E+04, -.95696000E+03, 0.72188800E+04, 0.32698000E+05, -.16200200E+05, -.17895500E+05, -.34023700E+04, 0.29125900E+03, -.10292000E+05, 0.49017800E+03, -.18313000E+04, 0.24573800E+04, -.16278400E+05, -.40130900E+03, 0.73703900E+04, 0.13917400E+05, 0.11629000E+05, 0.30137800E+04, 0.53463200E+04, -.10468300E+05, 0.45919700E+04, 0.79421800E+04, -.12330900E+05, 0.11141600E+05, -.70561200E+04, -.63174700E+04, -.22568600E+04, -.10158600E+04, -.60060900E+04, 0.10077000E+05, -.67622100E+04, 0.38158500E+04, -.25414200E+04, -.27170600E+04, 0.76471000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11615600E+01, -.11457100E+00, 0.19377100E+00, -.24555500E+00, 0.25104200E+01, -.20249200E+00, 0.14149100E+00, -.46781900E+00, 0.15488300E+00, -.61710100E+05, 0.30362200E+05, 0.30974400E+05, -.63863100E+04, -.15872600E+05, 0.23439200E+05, 0.53357700E+04, 0.24068200E+05, -.34801200E+04, -.87244900E+05, 0.44019700E+05, 0.54664500E+05, 0.18121000E+05, 0.26692900E+05, 0.14191800E+05, -.22384500E+05, 0.59932300E+04, 0.28650100E+05, 0.10654100E+06, -.65958800E+05, -.57375800E+05, -.15876900E+04, 0.34965500E+04, -.33766200E+05, 0.24672600E+04, -.33261900E+05, -.94302400E+04, -.14231300E+05, 0.72027700E+04, 0.79902900E+04, 0.13407500E+04, 0.39346900E+03, 0.42751800E+04, -.10369900E+04, 0.30273500E+04, 0.16100900E+04, 0.21491700E+06, -.11567100E+06, -.12370600E+06, -.32795600E+05, -.31807900E+05, -.47235600E+05, 0.42226000E+05, -.23809700E+05, -.46222400E+05, 0.36664700E+05, -.25424300E+05, -.19322100E+05, 0.25989300E+04, 0.38166200E+04, -.14059700E+05, -.44999300E+04, -.16533900E+05, -.88552800E+03, 0.73750900E+05, -.37409900E+05, -.43552300E+05, -.88165400E+04, -.61801300E+04, -.16241900E+05, 0.14931500E+05, -.10721700E+05, -.12659900E+05, -.93578400E+05, 0.46450300E+05, 0.50492000E+05, 0.14387200E+05, 0.14483800E+05, 0.18292000E+05, -.20776800E+05, 0.10344300E+05, 0.20743900E+05, -.97574300E+05, 0.48170200E+05, 0.64222900E+05, 0.10447800E+05, 0.99504300E+04, 0.22780500E+05, -.20154700E+05, 0.18834800E+05, 0.18521500E+05, 0.16660000E+06, -.83935300E+05, -.96621000E+05, -.34392400E+05, -.49678900E+05, -.27627000E+05, 0.40287900E+05, -.14664700E+05, -.53190100E+05, 0.25709000E+06, -.13554000E+06, -.14913700E+06, -.29817700E+05, -.33216800E+05, -.60141600E+05, 0.41549900E+05, -.38257700E+05, -.51682000E+05, -.15402400E+05, 0.77625300E+04, 0.76728900E+04, -.32360200E+04, 0.30413000E+04, 0.47119200E+04, 0.36132600E+04, 0.36811300E+04, 0.17186000E+04, 0.64285700E+05, -.35852300E+05, -.35800500E+05, -.58694700E+04, -.41725500E+04, -.16671200E+05, 0.82728100E+04, -.13775200E+05, -.10306800E+05, 0.11146000E+06, -.61537700E+05, -.65408900E+05, -.17873900E+05, -.14053200E+05, -.25075800E+05, 0.19506100E+05, -.15613500E+05, -.22550400E+05, 0.73418000E+05, -.43811400E+05, -.36821900E+05, -.69977500E+04, 0.16924800E+04, -.20279000E+05, 0.76716100E+04, -.19182300E+05, -.75660300E+04, 0.82375200E+05, -.41769600E+05, -.46744900E+05, -.15514300E+05, -.19939000E+05, -.15156700E+05, 0.18172100E+05, -.91758700E+04, -.23065200E+05, 0.11891700E+05, -.59395900E+04, -.62402200E+04, 0.24464800E+04, -.30666800E+04, -.35891200E+04, -.31815400E+04, -.24338400E+04, -.13582600E+04, -.20003800E+06, 0.10268500E+06, 0.11802700E+06, 0.30685800E+05, 0.38098200E+05, 0.42747400E+05, -.38153400E+05, 0.27213300E+05, 0.47808000E+05, -.12417400E+06, 0.62528400E+05, 0.71152800E+05, -.65703300E+04, -.21180200E+05, 0.45330400E+05, 0.24436000E+04, 0.42497800E+05, -.96054800E+03, -.46872900E+05, 0.31395800E+05, 0.23601600E+05, -.12667700E+04, -.10628300E+05, 0.17119600E+05, 0.46223400E+03, 0.18786600E+05, -.22173500E+04, -.11919700E+06, 0.59050500E+05, 0.70672400E+05, 0.20873400E+05, 0.23698700E+05, 0.23734500E+05, -.27679100E+05, 0.13741300E+05, 0.29952800E+05, 0.50909000E+05, 0.15060800E+05, 0.28217400E+05, -.12300200E+05, -.40758700E+05, -.14905900E+05, -.15507300E+04, 0.46570000E+05, 0.20615300E+05, -.30203600E+04, 0.35696200E+05, -.18463400E+05, 0.50341400E+04, -.20451100E+05, -.20039000E+05, 0.12560600E+05, -.30076600E+05, -.19946900E+05, -.20738300E+05, -.11819100E+04, -.24055900E+05, -.39555300E+05, -.21131700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.31786500E+00, 0.27666600E+00, 0.76510200E+00, 0.66639400E-01, -.67949100E+00, 0.40332200E-01, 0.82823300E+00, 0.10626900E+00, -.72439300E+00, -.32644600E+00, -.34844500E+03, 0.33053600E+02, 0.12715800E+04, -.78620500E+03, -.90638800E+03, -.36720600E+04, -.12216900E+04, 0.64275800E+03, -.14642800E+05, 0.75959500E+04, 0.10242200E+05, 0.92161400E+04, 0.99903700E+04, -.21225200E+04, -.12029900E+05, -.43417400E+04, 0.98733000E+04, -.68160100E+04, -.28670400E+04, 0.23980700E+04, -.95603500E+04, -.89621300E+04, 0.66155200E+04, 0.10439800E+05, 0.75048800E+04, -.51430900E+04, -.14974200E+04, 0.80060300E+03, 0.99272400E+03, 0.15298300E+03, 0.54464200E+03, 0.41228600E+03, -.15117800E+03, 0.87952100E+02, 0.45543800E+02, 0.29449700E+05, -.19077000E+05, -.18941200E+05, -.17029700E+05, -.19068700E+05, 0.11956300E+04, 0.19139200E+05, 0.73959200E+04, -.18476900E+05, -.66531800E+04, -.38660000E+02, 0.30546600E+04, -.31658800E+04, -.35032900E+04, 0.32220000E+04, 0.29771300E+04, 0.32164100E+04, -.13020300E+04, 0.13369900E+05, -.63525100E+04, -.85255800E+04, -.38892700E+04, -.36234400E+04, -.10948700E+04, 0.52554000E+04, 0.17560900E+02, -.60809000E+04, -.21544500E+05, 0.10083600E+05, 0.11782200E+05, 0.54697000E+04, 0.61101600E+04, 0.22497000E+04, -.68263500E+04, 0.51527300E+03, 0.85097300E+04, -.15253600E+05, 0.69993100E+04, 0.11705000E+05, 0.76036800E+04, 0.78913000E+04, -.15842100E+04, -.12134700E+05, -.18241900E+04, 0.94973300E+04, 0.32532400E+05, -.16713800E+05, -.19713500E+05, -.17320600E+05, -.19272100E+05, 0.22766900E+04, 0.20853500E+05, 0.53780100E+04, -.18177200E+05, 0.34457300E+05, -.20700500E+05, -.22631700E+05, -.19034300E+05, -.20818900E+05, 0.23590800E+04, 0.24075600E+05, 0.77644000E+04, -.21420800E+05, -.36270600E+04, 0.18576000E+04, 0.17979000E+04, -.90185400E+03, 0.12576900E+04, 0.97513500E+03, 0.50073800E+03, 0.69159300E+03, 0.27148900E+03, 0.47047500E+04, -.43078200E+04, -.32966800E+04, -.52230400E+04, -.48188200E+04, 0.16318000E+04, 0.61547600E+04, 0.23142100E+04, -.47551700E+04, 0.23326100E+05, -.14638700E+05, -.14217600E+05, -.79295600E+04, -.83556900E+04, -.28693900E+04, 0.61697200E+04, -.67754900E+03, -.93530800E+04, -.26165600E+04, -.24018200E+04, 0.12653200E+04, -.85972400E+04, -.45577100E+04, 0.42371500E+04, 0.72942000E+04, 0.44776700E+04, -.34547400E+04, 0.20564000E+05, -.10617600E+05, -.11752700E+05, -.59672600E+04, -.75857300E+04, -.18325800E+04, 0.67159800E+04, -.49774700E+03, -.83615900E+04, 0.24218300E+04, -.12125300E+04, -.12830500E+04, 0.64495600E+03, -.12792900E+04, -.63876300E+03, -.59496200E+03, -.35155700E+03, -.20968800E+03, -.27425900E+05, 0.15284200E+05, 0.18370900E+05, 0.18019300E+05, 0.19211900E+05, -.30945600E+04, -.21548900E+05, -.68535400E+04, 0.17236700E+05, 0.61212000E+03, -.14335300E+03, 0.19319200E+04, 0.56701800E+04, 0.22257000E+04, -.34061200E+04, -.10889500E+05, -.46604100E+04, 0.33161500E+04, 0.10505800E+05, -.11330800E+04, -.52098400E+04, 0.59667200E+04, 0.21946200E+04, -.51893900E+04, -.52545200E+04, -.50998600E+04, 0.65858200E+03, -.29013200E+05, 0.14090300E+05, 0.17393500E+05, 0.87027600E+04, 0.10116500E+05, 0.25177300E+04, -.10770300E+05, 0.29325200E+03, 0.12092000E+05, 0.64332200E+04, 0.12235600E+05, 0.13214700E+05, 0.24996200E+04, -.96516900E+04, -.12221600E+05, -.98191500E+03, 0.10125800E+05, 0.19388000E+04, -.57854500E+04, 0.36055700E+04, 0.46095800E+03, -.17211300E+04, -.15553600E+05, -.83140600E+04, 0.91989100E+04, -.13108100E+05, 0.31799300E+04, -.15814700E+05, 0.38683400E+04, -.11713800E+05, -.15093300E+05, 0.25842800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.56132500E+00, 0.44100500E+00, -.75872400E-01, 0.29062200E+00, -.23699100E+01, 0.30358000E+00, -.24370500E+00, -.10168900E+01, -.24919600E+00, -.66853200E+00, -.62096800E+00, 0.24930200E+03, -.61874300E+04, 0.51242300E+04, 0.39420000E+04, 0.14425900E+05, 0.32082200E+04, 0.46500800E+04, 0.50239000E+04, -.22436500E+04, 0.16071100E+05, -.87221200E+04, -.13328300E+05, 0.48397000E+04, 0.13725900E+05, 0.38950300E+05, -.88609700E+04, -.39680800E+05, 0.14636900E+05, 0.15525600E+05, 0.59624700E+04, -.13218200E+05, 0.97397000E+04, -.15130200E+05, -.70346300E+04, -.71222400E+04, 0.93610300E+04, -.46106000E+04, -.24884800E+04, -.44637600E+02, -.84831500E+03, -.26376800E+04, -.22592800E+04, -.12934900E+04, -.16303700E+04, -.33530700E+05, 0.12764800E+05, -.89938800E+04, -.64831800E+04, -.26420100E+05, 0.18503000E+05, 0.84515900E+04, -.63496800E+04, -.16777500E+05, -.26977200E+05, 0.10773100E+05, 0.11618100E+05, 0.65387800E+04, 0.67750500E+03, 0.23713600E+04, -.13490100E+05, -.82003900E+04, 0.38321500E+04, 0.32494600E+03, -.15694500E+03, -.13370300E+05, -.27444600E+04, -.88533800E+04, 0.36544100E+04, 0.48440200E+04, -.12887100E+04, -.60966900E+04, -.40646900E+04, 0.16930400E+04, 0.97933400E+04, 0.43037800E+04, 0.74178400E+04, -.36429600E+04, -.61224100E+04, 0.98150600E+04, 0.54721200E+04, 0.31158100E+04, -.14692000E+04, 0.23030100E+05, 0.75817800E+03, 0.16927500E+05, -.10136100E+05, -.87316000E+04, 0.57878500E+04, 0.14336200E+05, 0.19080100E+05, -.99216100E+04, -.31070000E+05, 0.88099800E+04, 0.15872900E+05, -.11840400E+05, -.21265800E+05, -.72847100E+05, 0.72106300E+04, -.11303500E+05, 0.22187400E+04, -.27977300E+05, 0.44194600E+03, -.23266600E+05, 0.10352900E+05, -.97051200E+03, -.24751500E+05, -.17356900E+05, -.23062900E+05, 0.11527200E+05, 0.11391700E+05, -.20789400E+04, 0.19647200E+04, 0.70424000E+04, 0.85280600E+04, 0.58378000E+04, 0.36190800E+04, -.51354300E+04, 0.93916000E+03, -.29785400E+04, -.17453200E+03, -.76426300E+04, 0.30532300E+04, -.77692200E+03, -.44294700E+04, -.57648800E+04, -.17133700E+05, 0.59807900E+04, -.69563000E+04, -.83051700E+04, -.16547600E+05, 0.13815500E+05, 0.87336000E+04, 0.77270400E+03, -.96079100E+04, -.88597400E+04, 0.13640400E+04, 0.40201300E+04, -.25297400E+04, -.12223500E+05, 0.38607300E+04, -.14940900E+04, 0.17868300E+04, -.97902100E+04, -.29698200E+04, 0.11691000E+04, -.85803300E+04, -.67851100E+03, 0.16704200E+04, 0.20514500E+04, 0.87922200E+03, -.20751500E+05, 0.19464900E+04, 0.17205300E+05, -.85861000E+04, -.89542000E+04, 0.22243400E+04, -.93343900E+03, -.55962200E+04, -.77694000E+04, -.49546000E+04, -.22798200E+04, -.13952600E+05, 0.83009100E+04, 0.34083100E+05, -.74646600E+04, -.41092600E+04, 0.98189500E+04, 0.21257200E+05, 0.62134800E+05, 0.59962000E+03, 0.34125200E+04, -.12620600E+04, 0.78723400E+04, -.12536900E+05, 0.94717600E+04, 0.62748800E+04, 0.26649200E+05, 0.15826300E+05, 0.89101700E+04, 0.26160800E+05, -.96242000E+04, -.12755500E+05, -.27718900E+04, 0.72667000E+04, -.63620400E+04, 0.59915400E+04, -.54199200E+04, 0.51452700E+04, 0.19108000E+05, -.95871700E+04, 0.80824700E+04, -.39174600E+03, 0.13240700E+04, -.84147300E+04, -.39360800E+04, 0.24040800E+05, -.70289500E+03, -.10953000E+05, 0.42542200E+04, 0.57924700E+04, 0.19661900E+05, 0.53590100E+04, -.43272500E+04, 0.29334900E+05, -.50287200E+04, 0.10771700E+04, -.92875900E+04, -.78082200E+04, 0.47823100E+04, -.21344900E+05, -.99729700E+04, 0.22168400E+04, -.51409000E+04, 0.53511000E+03, 0.12759200E+03, -.98161300E+04, 0.83320500E+04, -.75179200E+04, 0.44732200E+04, -.15281300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.30119300E+00, 0.10427000E+00, 0.18440100E+01, -.19138600E-01, 0.13694700E+01, 0.13965900E+00, -.66658900E+00, -.82879500E+00, -.37840600E+00, -.33877900E+00, 0.14420100E+01, -.11190300E+00, 0.17341000E+05, -.66597900E+04, -.34487700E+04, -.13154100E+05, -.23587600E+04, -.45596300E+04, 0.25307500E+05, -.12704500E+05, -.24767800E+05, 0.13328800E+05, 0.18800800E+04, -.23879800E+05, -.19233200E+05, -.56027900E+04, -.10581500E+04, -.18700200E+05, 0.75885200E+04, 0.21484100E+05, -.39750600E+05, -.22420200E+03, 0.31520100E+05, 0.42082300E+05, 0.13777100E+05, 0.14958700E+04, -.34351800E+04, 0.17257100E+04, 0.25936600E+04, -.70927200E+03, -.14886000E+04, 0.30968600E+04, 0.16308100E+04, 0.25458900E+04, -.19619500E+04, 0.51197300E+05, -.26100800E+05, -.32378100E+04, -.19592000E+05, 0.56794300E+04, 0.10421500E+05, 0.19786400E+05, -.10524900E+05, -.57264100E+03, -.37315800E+05, 0.17219500E+05, 0.19195800E+05, -.19448700E+05, 0.11694200E+04, 0.19134600E+05, 0.23940600E+05, 0.14471300E+05, 0.39133400E+04, 0.12128700E+05, -.71329500E+04, -.37319900E+04, 0.12870300E+04, 0.64096800E+04, -.44804600E+04, -.36795300E+04, -.55593600E+04, 0.27169600E+04, -.41231600E+04, 0.28632800E+04, 0.14846300E+03, -.23820500E+04, -.77102700E+04, 0.14418600E+04, 0.31663900E+04, 0.73643000E+04, -.49120600E+04, -.52475300E+05, 0.26226100E+05, 0.58544200E+04, 0.12632400E+05, -.24103100E+04, -.18260900E+04, -.12545600E+04, 0.16016300E+05, 0.50511400E+04, -.39832300E+05, 0.20013900E+05, 0.42434300E+05, -.25769100E+05, -.46300100E+04, 0.45016400E+05, 0.35272600E+05, 0.89166000E+04, 0.75913300E+03, 0.25527700E+05, -.13418100E+05, 0.13046300E+05, -.34954400E+05, 0.51282800E+04, 0.24095700E+05, 0.32097200E+05, -.28219200E+04, -.54790700E+03, -.72555500E+04, 0.36327000E+04, 0.33506400E+04, 0.54679600E+04, 0.25689100E+04, 0.15963800E+04, 0.31379900E+04, 0.26386700E+04, 0.32081300E+04, 0.54304000E+04, -.29539000E+04, 0.31385600E+04, -.10552500E+05, 0.20303400E+04, 0.65667900E+04, 0.98891800E+04, 0.90415700E+02, 0.76674500E+03, 0.37920800E+05, -.19428200E+05, -.53271900E+04, -.49888300E+04, 0.39908900E+03, 0.33801800E+04, 0.73387600E+04, -.70892000E+04, -.47672600E+04, -.46644800E+04, 0.17761400E+04, 0.18591400E+04, -.95555900E+04, 0.61089100E+04, 0.38137100E+04, 0.12358700E+05, 0.35827500E+04, 0.76288200E+04, -.39973100E+04, 0.19935600E+04, 0.74226400E+04, -.26867800E+04, 0.19207700E+04, 0.77110500E+04, 0.56402700E+04, -.25965600E+04, 0.11639200E+04, 0.13658200E+05, -.68178100E+04, -.61000900E+04, -.48104600E+04, -.27997400E+04, -.34730600E+04, -.24952000E+04, -.45117100E+04, -.37093500E+04, 0.82188500E+04, -.41528800E+04, -.34846200E+05, 0.33642300E+05, 0.13447700E+04, -.43059400E+05, -.37744800E+05, -.23380600E+04, -.97287000E+03, -.27759000E+05, 0.13824400E+05, -.11082600E+05, 0.49052200E+05, -.78920200E+03, -.28798100E+05, -.44135300E+05, -.48116600E+04, 0.54714400E+04, -.12191300E+05, 0.67760400E+04, 0.60098200E+04, 0.10054800E+05, -.59717500E+04, 0.37847900E+04, -.61490400E+04, 0.56295600E+04, -.62171400E+04, -.23176300E+05, 0.11488800E+05, -.39707400E+04, 0.35714000E+04, -.57146200E+04, -.60753200E+04, -.13546600E+04, 0.15976100E+05, -.79928500E+03, 0.41085900E+04, 0.65341700E+03, 0.53688700E+04, -.13362600E+05, -.99902600E+04, -.44790600E+03, -.51634900E+04, 0.15997100E+05, -.10049900E+05, -.66999900E+04, -.10081900E+05, -.15645100E+05, -.60204700E+04, 0.12367800E+04, 0.37190700E+03, 0.48856200E+04, -.14692100E+04, 0.40576800E+04, 0.54229400E+02, -.12649700E+05, 0.35771700E+04, -.78994600E+04, 0.26422900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12278300E+00, -.28059600E+00, -.27211500E+00, 0.12791100E+00, 0.18315400E+00, -.16236200E+00, -.32031200E+00, 0.27045200E+00, -.83680100E-01, -.21881200E+00, -.50579500E+00, 0.28043200E+00, -.14489000E+00, -.29391300E+04, -.21658200E+04, -.86216100E+04, -.22257000E+04, -.98177500E+03, 0.23418200E+05, -.11693500E+05, -.13431600E+05, 0.36729500E+04, 0.58994000E+03, -.10715200E+05, -.67023200E+04, -.10728600E+05, -.73212600E+03, 0.84719700E+04, -.39853100E+04, -.28860700E+04, 0.32669800E+04, 0.58147900E+04, -.11763500E+04, 0.55578600E+04, -.27709100E+04, 0.36353600E+04, -.41941200E+04, 0.20872700E+04, 0.21602900E+04, -.58733900E+03, -.39136600E+03, 0.21845200E+04, 0.24115800E+04, 0.26835500E+04, -.20900900E+03, 0.58347600E+04, -.27904800E+04, 0.11570100E+03, -.27775500E+04, 0.71659100E+04, 0.13894100E+03, 0.61968100E+04, -.79467300E+03, 0.33274900E+04, 0.57570500E+04, -.26250300E+04, -.27952700E+04, 0.39187100E+04, 0.35659500E+04, -.27045200E+04, -.57985000E+03, -.39126500E+04, 0.17155200E+04, 0.52584200E+04, -.27020500E+04, -.20045700E+04, -.12027800E+04, 0.18050900E+04, -.10768800E+04, 0.29880500E+04, 0.38442100E+03, -.83711500E+03, -.31849400E+04, 0.17365400E+04, 0.12150700E+04, 0.68725700E+03, -.22052700E+04, 0.11839200E+04, -.11718300E+04, -.51067800E+03, 0.32129800E+03, 0.60947700E+04, -.29809000E+04, -.58680100E+04, 0.35907500E+04, -.22193500E+04, -.48976500E+04, -.80494400E+04, -.64918200E+04, -.11942200E+04, -.42912300E+05, 0.21433200E+05, 0.24377300E+05, -.49541600E+04, 0.36417300E+03, 0.18098300E+05, 0.10023300E+05, 0.18144100E+05, 0.35245300E+04, -.43162400E+04, 0.22261900E+04, 0.57188300E+04, -.16986600E+04, 0.73521100E+04, 0.40423800E+04, 0.98228400E+04, 0.47017700E+04, 0.33275600E+04, 0.72105700E+04, -.35986800E+04, -.36096500E+04, -.96855600E+03, 0.10016100E+04, -.28046000E+04, -.40781500E+04, -.34272300E+04, -.66720300E+03, 0.15942700E+03, -.49404300E+02, 0.64868500E+03, -.21755300E+03, 0.24565500E+04, 0.79032900E+03, 0.30654900E+04, 0.90601700E+03, 0.11193600E+04, 0.86001500E+04, -.42193000E+04, -.24388700E+04, 0.45604200E+03, 0.69720700E+04, -.40937600E+04, -.11563500E+04, -.51438700E+04, 0.28777000E+04, 0.15737100E+04, -.74899500E+03, -.77595800E+03, -.11217500E+04, 0.32707600E+04, 0.37922300E+03, 0.44734100E+04, 0.86176000E+03, 0.28578900E+04, -.49366900E+04, 0.24802000E+04, 0.32895900E+04, 0.21889300E+03, 0.24623700E+04, 0.73834300E+03, -.15556000E+04, 0.10568700E+04, 0.11370700E+04, -.94530900E+04, 0.47155800E+04, 0.48143800E+04, 0.87563800E+03, -.63069400E+03, 0.31370400E+04, 0.28525300E+04, 0.27559000E+04, 0.10926400E+04, 0.26054700E+05, -.13077900E+05, -.16910700E+05, 0.49950100E+04, -.20299000E+04, -.13672700E+05, -.12111200E+05, -.12561200E+05, -.39966000E+04, 0.35865400E+04, -.18295800E+04, -.44646200E+04, 0.19780100E+04, -.45821000E+04, -.79130100E+04, -.17145000E+05, -.56907400E+04, -.27087600E+04, -.33497800E+04, 0.16245200E+04, 0.16698500E+04, 0.16534400E+04, -.11924300E+04, -.95947000E+03, -.62077300E+04, -.14197800E+04, -.15888300E+04, 0.27302200E+04, -.13337000E+04, -.33912200E+04, 0.22324800E+04, -.29043100E+04, -.15657300E+04, -.10268500E+04, -.18880600E+04, -.72440400E+03, -.80278900E+03, -.41666600E+04, -.55773100E+04, -.43943200E+04, 0.28939700E+04, 0.41497000E+04, -.66549000E+04, -.35417900E+04, -.59240500E+04, -.68669100E+04, -.36948900E+03, -.38139400E+04, 0.23304500E+04, 0.36232100E+04, 0.79204000E+03, 0.53850800E+04, -.15589500E+03, -.10959800E+04, 0.37965900E+04, -.55481300E+04, 0.58695300E+04, -.23037800E+04, 0.18290300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.27346600E+00, -.87751300E-01, 0.56187400E+00, -.58285900E+00, 0.51489600E+01, -.35122000E+00, -.10043100E+01, -.16062600E+01, -.42667900E+00, 0.47211800E+00, 0.11672400E+01, -.48077800E+00, 0.10575500E+01, -.10059800E+01, -.54592500E+04, -.18816000E+05, -.63682600E+04, 0.22592500E+04, -.28974000E+05, 0.14606100E+05, 0.20999900E+05, 0.11029100E+04, 0.12133500E+05, 0.48912300E+04, -.11814400E+05, -.63279900E+04, 0.94934700E+04, 0.20736300E+04, -.38321200E+04, -.66685500E+04, 0.34015800E+04, -.22088200E+05, 0.11943300E+05, 0.46963300E+05, 0.23839900E+05, -.15420400E+05, -.61608300E+04, 0.30859900E+04, 0.27003600E+04, -.21200600E+04, -.46683400E+02, 0.19954800E+04, 0.10479700E+04, 0.22313700E+04, 0.40982000E+03, -.16672000E+05, 0.59696100E+04, -.33199500E+04, 0.65335300E+04, -.36024400E+05, 0.19370400E+05, 0.48873700E+05, 0.34391000E+05, -.24271300E+05, 0.25085500E+05, -.13766200E+05, -.12863500E+05, 0.19565500E+04, -.65165800E+04, -.10650100E+04, 0.19290700E+05, 0.50457200E+04, -.74104700E+04, -.20125300E+05, 0.99668200E+04, 0.82338500E+04, 0.36523400E+04, -.17406000E+04, 0.61627800E+04, -.51411000E+03, 0.71262800E+03, -.27786600E+03, 0.13797100E+05, -.69132000E+04, -.58214600E+04, -.23248200E+04, 0.49067900E+04, -.62106200E+04, -.11190400E+04, -.14586400E+04, 0.34371700E+04, 0.50893500E+05, -.25077700E+05, -.14736000E+05, 0.22532600E+03, 0.24311900E+05, -.20386600E+05, -.23306700E+05, -.22698600E+05, 0.11882400E+05, 0.46632100E+05, -.23516000E+05, -.34310400E+05, -.18615200E+04, -.21927200E+05, -.78800700E+04, 0.18815700E+05, 0.91847400E+04, -.15930800E+05, -.14393000E+05, 0.50560700E+04, -.63147200E+04, 0.12496100E+04, -.38374800E+05, 0.20716900E+05, 0.51301500E+05, 0.33459800E+05, -.26641200E+05, 0.93499600E+04, -.46463200E+04, -.46187100E+04, 0.48299300E+04, 0.72474400E+02, -.26315800E+04, -.21732300E+04, -.11324000E+04, -.17473400E+04, -.39604200E+04, 0.10468300E+04, -.93792200E+03, 0.59207800E+03, -.94274100E+04, 0.54151700E+04, 0.14612200E+05, 0.81365500E+04, -.65576100E+04, 0.16372700E+05, -.96519100E+04, -.15290300E+05, 0.51902100E+04, -.11634700E+05, -.12133800E+04, 0.15005900E+05, 0.70364900E+04, -.10169300E+05, -.33394400E+04, -.11793300E+03, 0.17427600E+04, -.27651500E+03, -.88439000E+04, 0.80691400E+04, 0.17109600E+05, 0.77832500E+04, -.51032900E+04, 0.22300600E+05, -.11275800E+05, -.13987600E+05, 0.52492700E+03, -.84998300E+04, -.28251900E+04, 0.69111100E+04, 0.15374500E+04, -.84507700E+04, -.35581100E+04, 0.17577200E+04, 0.14306700E+04, -.47732000E+04, -.17988200E+04, 0.10993500E+04, 0.18090700E+04, 0.10669300E+04, 0.47384900E+03, -.85721300E+03, 0.11346800E+04, 0.15846500E+05, -.74451600E+04, 0.18520200E+05, -.35047900E+04, -.27242900E+05, -.18063800E+05, 0.10041100E+05, 0.17044600E+05, -.82484300E+04, 0.32961200E+04, -.76023300E+04, 0.72926800E+04, -.91791000E+04, -.39758500E+05, -.22086400E+05, 0.31039500E+04, 0.28584900E+04, 0.62427800E+03, -.14027900E+04, 0.32303100E+04, 0.77407400E+04, -.56463200E+04, -.14336600E+05, -.54002500E+04, 0.32363700E+04, 0.54416900E+04, -.26550400E+04, 0.51546200E+04, -.17851000E+04, 0.19111500E+05, -.58867800E+04, -.13774400E+05, -.11992600E+05, 0.13110600E+05, -.19263300E+04, 0.17364800E+05, 0.18117200E+05, 0.17435600E+05, 0.29373000E+04, -.17563100E+05, -.22903100E+04, -.82757000E+04, 0.26777600E+05, 0.30144700E+05, 0.10611000E+05, 0.15721300E+05, -.84777400E+03, -.15892900E+05, -.13466300E+05, 0.12078800E+05, -.19732100E+05, 0.98757100E+04, -.17488600E+05, 0.13836600E+05, -.15002200E+05, -.25647100E+05, -.10823700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.95050800E+00, 0.17578400E+00, -.85454300E+00, -.46691800E+00, 0.41696100E+01, -.13760800E-01, -.23251600E+01, -.12633600E+01, 0.29842300E-01, 0.85830600E+00, 0.10294100E+01, -.77420900E+00, 0.52098700E+00, 0.90066200E-01, -.82459600E+00, 0.20619000E+04, -.54431800E+03, 0.40762400E+04, 0.85373700E+05, -.42484100E+05, -.29920500E+05, -.44210900E+05, -.47189500E+05, 0.86522700E+04, 0.49179600E+05, 0.46103800E+05, -.45474700E+05, -.62866500E+05, 0.29757000E+05, 0.20615300E+05, 0.24103300E+05, 0.62722600E+04, 0.54286800E+04, -.60050000E+04, -.27863300E+04, 0.92967900E+04, 0.13533700E+05, -.67471200E+04, -.74331500E+04, -.40025000E+04, -.32417400E+04, -.30336100E+04, 0.26394900E+04, 0.18784300E+04, -.34804600E+04, -.19887400E+06, 0.97913400E+05, 0.76844100E+05, 0.64788000E+05, 0.38561800E+05, 0.20988500E+05, -.45655700E+05, -.19367000E+05, 0.50860000E+05, -.14136800E+05, 0.62534500E+04, 0.64243400E+04, 0.80957300E+04, 0.40398700E+04, 0.36283400E+04, 0.31719300E+04, -.34165700E+04, 0.29518100E+04, -.79033100E+05, 0.39115200E+05, 0.35652400E+05, 0.17031800E+05, 0.14638800E+05, 0.12030000E+05, -.25854400E+05, -.89293100E+04, 0.19283800E+05, 0.11413300E+06, -.56728400E+05, -.54793800E+05, -.24392800E+05, -.25915200E+05, -.17874600E+05, 0.33019700E+05, 0.17958200E+05, -.30922900E+05, 0.93085800E+05, -.46168900E+05, -.25489900E+05, -.25125600E+05, -.10149700E+05, -.28670900E+04, 0.32555300E+05, 0.86050000E+04, -.18592500E+05, -.15686900E+06, 0.78068300E+05, 0.56708700E+05, 0.77747200E+05, 0.83445400E+05, -.15126200E+05, -.89148800E+05, -.83822800E+05, 0.81284000E+05, -.21381400E+06, 0.10544700E+06, 0.80529800E+05, 0.64248200E+05, 0.48531300E+05, 0.19292000E+05, -.61321200E+05, -.33054000E+05, 0.57336200E+05, 0.15350300E+05, -.76443600E+04, -.75994700E+04, 0.87565200E+04, -.34635100E+04, -.40138800E+04, -.11966000E+04, -.27878200E+04, -.19467800E+04, -.40784900E+05, 0.19874600E+05, 0.14804900E+05, 0.13897500E+05, 0.77847100E+04, 0.22844800E+04, -.13576100E+05, -.70536200E+04, 0.95860000E+04, -.97625600E+05, 0.47869800E+05, 0.34867200E+05, 0.29480800E+05, 0.15860400E+05, 0.12653100E+05, -.15953100E+05, -.25810500E+04, 0.24661400E+05, -.10866400E+05, 0.45470400E+04, 0.54839000E+04, 0.12305900E+05, 0.12677800E+03, -.52751600E+03, -.13258900E+05, -.76010100E+04, 0.95243600E+01, -.88654800E+05, 0.44137800E+05, 0.38545100E+05, 0.27732300E+05, 0.29973500E+05, 0.86320600E+04, -.26413700E+05, -.23471800E+05, 0.32015900E+05, -.11796900E+05, 0.58684700E+04, 0.52221900E+04, -.67156500E+04, 0.35091300E+04, 0.23624000E+04, 0.32800800E+03, 0.11592800E+04, 0.23508200E+04, 0.20758100E+06, -.10311600E+06, -.74083300E+05, -.87177800E+05, -.84719600E+05, 0.73034300E+04, 0.94609000E+05, 0.72423400E+05, -.86132600E+05, 0.45795200E+05, -.22633600E+05, -.10039700E+04, -.28903900E+05, -.16435100E+05, 0.15843800E+05, 0.28651400E+05, 0.10807400E+05, -.15837600E+05, -.96297600E+04, 0.58501200E+04, 0.48557000E+04, -.18609400E+04, 0.43381600E+04, 0.61598500E+04, 0.12392300E+05, 0.69528000E+04, 0.53541400E+04, 0.16000600E+06, -.79755400E+05, -.64667300E+05, -.44469700E+05, -.41860300E+05, -.13443300E+05, 0.48027400E+05, 0.31537100E+05, -.49419100E+05, -.52564700E+05, -.41123000E+05, -.38020400E+05, 0.22964600E+05, 0.47250900E+05, 0.40397800E+05, 0.30593600E+05, -.51636900E+05, -.13153900E+05, 0.21442200E+05, -.34021900E+05, 0.15193700E+05, -.21183700E+05, 0.47033600E+05, 0.31223700E+05, -.35331300E+05, 0.40528500E+05, -.51092400E+04, 0.45933800E+05, -.26463000E+04, 0.35262500E+05, 0.44433400E+05, -.86333900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.85319900E+00, 0.76274900E-01, -.11235500E+01, -.56382600E-01, -.64510500E+00, 0.28110400E+00, -.13563700E+01, -.31964800E-02, -.29927600E+00, -.72664000E-01, -.21155400E+00, -.56696600E-01, 0.95720500E-01, -.12108400E+01, -.51700700E+00, -.28995700E+00, -.13512800E+04, 0.29049600E+04, 0.22103900E+05, -.10914900E+05, -.52090200E+04, -.11856600E+05, -.86731400E+04, 0.80004300E+03, 0.79965600E+04, 0.16387900E+05, -.87545100E+04, -.41591500E+05, 0.19075000E+05, 0.15710600E+05, 0.94619700E+04, -.12883900E+05, 0.12410100E+05, 0.10554900E+05, 0.97988100E+04, -.58836000E+04, 0.10547100E+05, -.52517200E+04, -.56328500E+04, -.24794200E+04, -.12679300E+04, -.24069500E+04, 0.19497800E+04, 0.55974900E+03, -.20248700E+04, -.74279900E+05, 0.35532000E+05, 0.26776700E+05, 0.14761000E+05, -.10700900E+05, 0.17473900E+05, 0.31009800E+04, 0.25075100E+04, -.16168100E+04, -.94142400E+04, 0.40709700E+04, 0.44017900E+04, 0.63639200E+04, -.28360400E+04, 0.32672900E+04, 0.29953700E+04, 0.21554100E+03, -.16620100E+04, -.33217000E+05, 0.16431500E+05, 0.14970100E+05, 0.36258300E+04, 0.11485200E+04, 0.72080600E+04, -.83174700E+04, -.35681100E+04, 0.23794700E+04, 0.43251600E+05, -.21437900E+05, -.20710700E+05, -.60884900E+04, -.41357700E+04, -.92854700E+04, 0.10459900E+05, 0.87955600E+04, -.54511700E+04, 0.35525200E+05, -.17542600E+05, -.80683800E+04, -.23135800E+03, 0.11603800E+05, -.84455500E+04, -.22395600E+04, -.22723700E+04, 0.58241900E+04, -.35950900E+05, 0.17752600E+05, 0.81444100E+04, 0.21281000E+05, 0.15319400E+05, -.36457900E+04, -.18741800E+05, -.35754300E+05, 0.16150300E+05, -.70592200E+05, 0.33874800E+05, 0.23215500E+05, 0.13401900E+05, -.83759100E+04, 0.15820700E+05, -.13219300E+04, -.57187500E+04, -.19581300E+04, 0.25359100E+04, -.12566900E+04, -.12315400E+04, 0.42964200E+04, -.22482500E+03, -.75391100E+03, -.17671000E+03, -.17617300E+04, -.61754200E+03, -.16295200E+05, 0.75220500E+04, 0.55420100E+04, 0.27190800E+04, -.34373200E+04, 0.37735200E+04, 0.21304800E+03, -.76053000E+03, -.18028100E+04, -.24298800E+05, 0.11188600E+05, 0.57127600E+04, 0.63607400E+04, -.41890500E+04, 0.53932900E+04, 0.14589000E+04, -.17800500E+04, -.91981100E+03, -.13636500E+05, 0.56487100E+04, 0.68590200E+04, 0.20276200E+03, -.64395000E+04, 0.60408000E+04, 0.16540000E+04, 0.23015400E+04, -.42624000E+04, -.20797400E+05, 0.10271500E+05, 0.78723100E+04, 0.78571700E+04, 0.49867900E+04, 0.28177000E+04, -.56465800E+04, -.13131400E+05, 0.50782300E+04, -.56373200E+04, 0.28057000E+04, 0.25082500E+04, -.32645200E+04, 0.58137300E+03, 0.11173100E+04, -.10710000E+04, 0.12639700E+04, 0.14298300E+04, 0.71916300E+05, -.35388800E+05, -.22124400E+05, -.27058600E+05, -.16695000E+05, -.73372800E+03, 0.26348600E+05, 0.31188000E+05, -.20222000E+05, 0.23721500E+05, -.11660400E+05, -.12821600E+04, -.11660000E+05, -.20947100E+04, 0.42456500E+04, 0.69667900E+04, 0.10269400E+04, -.23647200E+04, 0.10885800E+05, -.41289400E+04, -.54247700E+04, 0.35687500E+04, 0.57108100E+04, -.37851200E+04, 0.55800500E+03, -.44281200E+04, 0.33111400E+04, 0.51634600E+05, -.25723000E+05, -.18749900E+05, -.11281500E+05, -.56879700E+04, -.68385800E+04, 0.11353200E+05, 0.15552800E+05, -.84351000E+04, -.19417200E+05, -.39723900E+04, -.25639000E+04, 0.23214200E+05, 0.15324900E+05, 0.36112100E+04, 0.17891400E+05, -.19521900E+05, -.12611700E+04, 0.99740300E+04, -.13692900E+05, 0.17225500E+05, -.14141200E+05, 0.33127400E+04, 0.44342600E+04, -.10407500E+05, 0.40396700E+04, 0.45705500E+04, 0.25207600E+04, 0.87402000E+04, 0.16319300E+04, 0.48269200E+04, -.28159000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22512900E+01, -.16100300E+00, -.16797300E+01, -.53232500E+00, -.62064700E+00, 0.73885300E+00, -.16717900E+01, -.13203600E+01, 0.30724600E+00, 0.56971300E+00, -.16086400E+00, -.16205400E+00, 0.55373200E+00, -.18051500E+01, -.28597600E+00, 0.75048100E+00, 0.15078400E+01, -.58846600E+04, -.15159600E+06, 0.75458500E+05, 0.60314100E+05, 0.55936800E+05, 0.70550700E+05, 0.54441400E+03, -.65062400E+05, -.86387400E+05, 0.68866500E+05, 0.16325600E+06, -.78333900E+05, -.69358300E+05, -.28565800E+05, 0.34114100E+04, -.38899400E+05, -.11921300E+05, 0.12349700E+04, -.10730200E+05, -.28205300E+05, 0.14062000E+05, 0.14916400E+05, 0.61463200E+04, 0.67845900E+04, 0.56072900E+04, -.51962900E+04, -.76387000E+04, 0.76650500E+04, 0.27257300E+06, -.13327500E+06, -.10953200E+06, -.65044900E+05, -.17064200E+05, -.50324500E+05, 0.19126600E+05, 0.36887400E+05, -.41302200E+05, 0.72312600E+05, -.34552200E+05, -.35334100E+05, -.14632900E+05, -.11505700E+05, -.16715200E+05, 0.78106500E+02, 0.14714200E+05, -.12937200E+05, 0.96580500E+05, -.47643600E+05, -.43046900E+05, -.17294000E+05, -.13079600E+05, -.18235000E+05, 0.21195400E+05, 0.97844900E+04, -.18241900E+05, -.15645400E+06, 0.77710100E+05, 0.75864200E+05, 0.29827300E+05, 0.33922100E+05, 0.27067600E+05, -.36707500E+05, -.34118200E+05, 0.39353300E+05, -.14408600E+06, 0.71338200E+05, 0.46608100E+05, 0.22675900E+05, -.11655800E+05, 0.28411600E+05, -.48037400E+04, 0.13074400E+05, 0.56179000E+04, 0.28277100E+06, -.14079200E+06, -.11738400E+06, -.10024800E+06, -.12825300E+06, -.17815500E+04, 0.12353500E+06, 0.15924400E+06, -.12682800E+06, 0.30422300E+06, -.14930200E+06, -.12074700E+06, -.67586600E+05, -.36064400E+05, -.51359000E+05, 0.38277800E+05, 0.53981000E+05, -.53917000E+05, -.72851500E+04, 0.36107900E+04, 0.36781100E+04, -.94559400E+04, 0.62504000E+03, 0.22479900E+04, 0.14992900E+03, 0.89982400E+04, -.40996400E+03, 0.69562300E+05, -.33787200E+05, -.28327000E+05, -.14665000E+05, -.42669900E+04, -.12398200E+05, 0.62611600E+04, 0.77458100E+04, -.87348300E+04, 0.11331600E+06, -.54909700E+05, -.40185000E+05, -.30453300E+05, -.12513600E+05, -.18697600E+05, 0.10432100E+05, 0.18517800E+05, -.23116200E+05, 0.26739500E+05, -.11581300E+05, -.13264700E+05, -.85411900E+04, 0.79442600E+04, -.82275200E+04, 0.10329700E+04, 0.13825300E+04, 0.40189500E+04, 0.13973700E+06, -.69567700E+05, -.63283600E+05, -.37629800E+05, -.48483900E+05, -.15271300E+05, 0.40008100E+05, 0.54969700E+05, -.49589900E+05, 0.20106600E+05, -.10003400E+05, -.92809200E+04, 0.58476700E+04, -.41986800E+04, -.37684900E+04, 0.40293500E+04, -.29443800E+04, -.38607100E+04, -.35125000E+06, 0.17447100E+06, 0.14131600E+06, 0.10823100E+06, 0.12034700E+06, 0.16315600E+05, -.12215300E+06, -.13972000E+06, 0.12697000E+06, -.93673500E+05, 0.46414900E+05, 0.21708600E+05, 0.31798700E+05, 0.15466100E+05, -.22990500E+04, -.21819200E+05, -.16782700E+05, 0.17354700E+05, -.11487800E+05, 0.35988100E+04, 0.57317300E+04, -.10728100E+04, -.11225300E+05, 0.35403400E+04, -.20154600E+04, 0.36565700E+04, -.83090400E+04, -.25954800E+06, 0.12941300E+06, 0.11189700E+06, 0.58619300E+05, 0.59595700E+05, 0.33843900E+05, -.58066800E+05, -.65690400E+05, 0.70136700E+05, 0.92459000E+05, 0.52277800E+05, 0.47955900E+05, -.47729100E+05, -.75529300E+05, -.50740700E+05, -.61071400E+05, 0.80378800E+05, 0.27456000E+05, -.16246000E+05, 0.60300300E+05, -.29042600E+05, 0.51451600E+05, -.52642800E+05, -.44132000E+05, 0.47991100E+05, -.51280600E+05, -.50902100E+03, -.52563600E+05, -.10707000E+04, -.45172600E+05, -.53375400E+05, 0.42429700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12387900E+01, -.13051800E+00, 0.13762400E+01, 0.57261200E+00, 0.47056900E+00, 0.93865700E-02, -.23096500E+00, 0.53170900E+00, -.15000400E+00, 0.43866500E+00, -.35647700E+00, 0.43341200E+00, 0.40160500E+00, 0.61997300E+00, -.21387200E+00, 0.23834600E-01, 0.52416900E+00, 0.38081600E+00, 0.18418900E+06, -.91956100E+05, -.83949800E+05, -.55576800E+05, -.78431300E+05, -.61670800E+04, 0.65083700E+05, 0.67740800E+05, -.78870900E+05, -.80578900E+05, 0.43989900E+05, 0.32323100E+05, 0.25689600E+05, 0.36972500E+05, -.70265900E+03, -.21847000E+05, -.25872000E+05, 0.37438100E+05, 0.13800400E+05, -.69188600E+04, -.74858800E+04, -.36307200E+04, -.50667400E+04, -.31065200E+04, 0.18771400E+04, 0.22733300E+04, -.50902700E+04, -.26888400E+06, 0.13660800E+06, 0.11994000E+06, 0.82221800E+05, 0.10722000E+06, 0.11316600E+05, -.86000000E+05, -.82109800E+05, 0.11011500E+06, -.31162800E+05, 0.17679700E+05, 0.15136600E+05, 0.87486800E+04, 0.16312800E+05, 0.31193100E+04, -.55074700E+04, -.11335600E+05, 0.15249900E+05, -.62933700E+05, 0.31928500E+05, 0.29287700E+05, 0.17883000E+05, 0.22990400E+05, 0.58205300E+04, -.20333700E+05, -.20401200E+05, 0.23386800E+05, 0.12608400E+06, -.63172800E+05, -.61049800E+05, -.32445400E+05, -.45766500E+05, -.12185800E+05, 0.37616400E+05, 0.36451000E+05, -.46667100E+05, 0.83578200E+05, -.41661300E+05, -.28076100E+05, -.27674900E+05, -.30572100E+05, 0.42196000E+04, 0.29936100E+05, 0.28983900E+05, -.33460300E+05, -.31936300E+06, 0.15942000E+06, 0.14324100E+06, 0.97113700E+05, 0.13622300E+06, 0.77078800E+04, -.11328300E+06, -.12064000E+06, 0.13728300E+06, -.29788400E+06, 0.15080100E+06, 0.13183900E+06, 0.85416900E+05, 0.11727800E+06, 0.14275200E+05, -.90398600E+05, -.91863800E+05, 0.11982800E+06, 0.94464900E+04, -.47329200E+04, -.46358100E+04, 0.24507700E+04, -.29886900E+04, -.14324600E+04, 0.28666400E+03, 0.14290900E+04, -.18678200E+04, -.45914200E+05, 0.23982400E+05, 0.19155400E+05, 0.15027400E+05, 0.19674100E+05, 0.20444300E+03, -.15325900E+05, -.18214700E+05, 0.19990900E+05, -.11190800E+06, 0.57513700E+05, 0.46373200E+05, 0.38072300E+05, 0.46418200E+05, 0.13815900E+04, -.36232900E+05, -.39310600E+05, 0.48127500E+05, -.28612900E+04, 0.35261700E+04, 0.15560000E+04, 0.70399100E+04, 0.67492300E+04, -.25188900E+04, -.59110300E+04, -.13823300E+05, 0.58834500E+04, -.13585600E+06, 0.67933500E+05, 0.63955600E+05, 0.37771800E+05, 0.53653800E+05, 0.96189400E+04, -.41496800E+05, -.45214100E+05, 0.54247900E+05, -.12200800E+05, 0.60875500E+04, 0.56434600E+04, -.27386700E+03, 0.51594500E+04, 0.12019400E+04, -.16716900E+04, -.25308500E+04, 0.39562200E+04, 0.32018800E+06, -.16041300E+06, -.13922900E+06, -.95470900E+05, -.13043400E+06, -.78037900E+04, 0.10768900E+06, 0.10738900E+06, -.13324900E+06, 0.64197800E+05, -.32235800E+05, -.16453900E+05, -.22878500E+05, -.25317000E+05, 0.96404300E+04, 0.24256100E+05, 0.15685100E+05, -.28631400E+05, -.66765700E+04, 0.97065100E+03, 0.33724300E+04, -.16467300E+04, -.27243700E+04, 0.27055100E+04, 0.19194200E+04, 0.31933700E+04, -.12714700E+04, 0.21838900E+06, -.10884600E+06, -.98828000E+05, -.59259000E+05, -.81060200E+05, -.13448600E+05, 0.66299000E+05, 0.62411400E+05, -.83834400E+05, -.70672300E+05, -.70653500E+05, -.70561700E+05, 0.71412600E+04, 0.63389300E+05, 0.69724500E+05, 0.37714500E+05, -.65895100E+05, -.47335500E+05, -.26610400E+04, -.55517500E+05, -.29071100E+04, -.32401500E+05, 0.71718600E+05, 0.55391600E+05, -.54516800E+05, 0.69059400E+05, -.21526600E+05, 0.70702900E+05, -.25061000E+05, 0.65125700E+05, 0.69940000E+05, -.16054300E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.84297600E+00, -.14499100E+00, 0.89072600E+00, 0.50837300E+00, -.24324500E+01, 0.27413200E+00, -.85113300E-01, -.63149300E+00, -.14985200E+00, -.98980800E+00, -.28856000E-01, 0.84996900E+00, 0.16611500E+00, 0.65304100E+00, 0.43349800E+00, -.11921600E+00, -.48954200E+00, 0.97102700E-01, 0.68214500E+00, 0.15127000E+03, 0.62341100E+04, 0.37342100E+04, 0.27545900E+04, 0.39442000E+04, -.30566100E+04, -.18258800E+05, 0.28370100E+04, -.22408600E+05, 0.68665100E+04, 0.59011000E+04, 0.37121000E+03, -.36986100E+04, 0.50689200E+03, -.36060100E+04, 0.94463900E+04, -.13629400E+04, -.72530800E+04, 0.36478500E+04, 0.32674000E+04, 0.21244400E+04, 0.21965400E+04, 0.16204800E+04, 0.53086500E+03, 0.95470800E+03, 0.30294100E+04, -.72674100E+04, 0.53568900E+03, -.75725300E+04, -.60807300E+04, -.61000100E+04, -.78308400E+04, 0.81570500E+04, 0.32578800E+05, -.59314200E+04, -.78240000E+04, 0.15243700E+04, 0.36370900E+04, -.54144500E+03, -.33830700E+04, 0.14312100E+04, -.24382500E+04, 0.74254700E+03, -.13675300E+04, 0.11925800E+04, -.11390100E+04, -.20426100E+04, -.11085600E+04, -.62835500E+03, -.24070700E+04, 0.31958100E+04, 0.93283500E+04, -.38822500E+03, -.72901200E+04, 0.38682000E+04, 0.38734100E+04, 0.15995400E+04, 0.70714900E+03, 0.53811100E+04, -.37830100E+04, -.11635800E+05, 0.15026400E+04, 0.39002500E+05, -.19281800E+05, -.91650500E+04, -.10286700E+05, -.14274800E+05, 0.61689900E+04, 0.79245700E+04, -.16775500E+05, -.14330300E+05, -.20220800E+05, 0.98368600E+04, 0.14758900E+04, -.11619500E+04, 0.39516700E+04, -.73653800E+04, 0.24873800E+04, 0.33585900E+05, 0.28864000E+04, -.19456400E+05, 0.69618600E+04, -.31250300E+04, 0.28256900E+04, 0.29487900E+04, -.13120400E+05, -.14713800E+04, 0.33735700E+05, 0.37260500E+04, 0.12621500E+05, -.62712800E+04, -.62377200E+04, -.22509700E+04, -.20230400E+03, -.47668500E+04, -.11168000E+05, -.65609000E+04, -.28849100E+04, -.10570500E+05, 0.40467200E+04, 0.25533700E+04, 0.12764400E+04, 0.15988600E+04, -.17563900E+04, -.24397000E+04, 0.71329900E+04, 0.20058700E+04, -.29630400E+05, 0.12790800E+05, 0.84805200E+04, 0.29906100E+04, 0.80038100E+04, -.33002300E+04, -.10577400E+04, 0.16752200E+05, 0.77139500E+04, -.13122700E+05, 0.42118400E+04, 0.66915300E+04, -.55984400E+03, 0.28399500E+03, 0.17011100E+04, -.57784000E+04, 0.62783200E+04, -.34723800E+03, -.88481500E+03, 0.24287400E+03, -.19320000E+04, 0.69742200E+02, 0.21703400E+04, -.63169300E+04, -.12403700E+04, 0.10775300E+05, 0.13977300E+04, -.13621100E+05, 0.67840700E+04, 0.64636000E+04, 0.16155700E+04, -.30085600E+03, 0.51946000E+04, 0.10651200E+05, 0.62879600E+04, 0.24928100E+04, 0.10705000E+05, -.43875100E+04, 0.84146900E+04, 0.18695000E+04, -.13215800E+04, 0.11825100E+05, -.40877700E+04, -.29440700E+05, 0.13580100E+03, 0.13091200E+05, -.61544600E+04, 0.47523400E+04, -.39162200E+04, -.50039300E+04, 0.73405000E+04, 0.66466300E+04, -.34253700E+04, -.52426700E+04, 0.41964700E+04, 0.59218000E+03, -.20755200E+04, 0.24515200E+04, 0.51158200E+04, -.27021100E+04, 0.29256000E+04, -.38514100E+04, 0.44498300E+04, 0.18547100E+04, -.96769500E+03, 0.64521200E+04, -.64018800E+03, -.33115400E+04, 0.10810100E+05, 0.85209800E+03, -.17130100E+05, -.22078300E+04, -.64849800E+04, -.44020300E+03, -.66329900E+03, -.12203200E+05, 0.32102000E+04, 0.72286800E+03, -.17935300E+05, -.43155700E+04, -.84776700E+04, -.12906600E+05, 0.49627700E+04, -.65946300E+04, 0.12409900E+05, 0.35008100E+04, -.47947700E+03, 0.18584900E+05, -.82139500E+03, -.26905700E+04, 0.41747300E+04, -.32496000E+04, -.50372500E+03, 0.21671500E+04, 0.39694900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.75771100E+00, -.21021500E+00, 0.22165000E-01, -.93201700E-01, -.80578400E+00, 0.17524700E+00, 0.38700500E+00, 0.31716000E-02, -.42064800E+00, -.11639700E+00, -.48346600E-01, -.16321900E-01, -.68022400E-01, -.41762700E+00, 0.18338000E+00, -.11808100E+00, 0.18242200E+00, -.15933000E-01, 0.20910400E-01, 0.35672200E+00, -.47559700E+04, 0.29186800E+04, 0.26635600E+04, -.60633200E+04, -.36020400E+04, 0.44434400E+04, 0.14310500E+04, 0.20499100E+05, -.92592900E+04, -.59022900E+04, -.21699400E+04, 0.25994700E+04, -.23097500E+04, -.23875400E+04, -.69895000E+04, -.64242600E+02, 0.36542000E+03, -.18048900E+03, 0.12162000E+03, -.86775300E+03, -.67824600E+03, 0.49521000E+03, 0.40869600E+03, 0.36255200E+03, -.12314000E+04, 0.23558200E+05, -.11379800E+05, -.30438200E+04, -.30076400E+04, 0.16406500E+04, 0.19442100E+04, -.30874200E+04, -.17382300E+05, -.70994500E+03, 0.55927300E+04, -.20203700E+04, -.26069100E+04, 0.15269000E+03, 0.13600200E+04, -.17840200E+04, -.11011200E+04, -.35509700E+03, -.62736400E+02, 0.21757200E+05, -.97517800E+04, -.10022000E+05, -.10462100E+04, 0.17070800E+04, -.62876900E+04, -.42411000E+04, -.12829000E+05, -.57251200E+03, -.18808000E+05, 0.84264100E+04, 0.91126400E+04, 0.63088900E+03, -.14116500E+04, 0.46080600E+04, 0.44350200E+04, 0.14135600E+05, 0.27991200E+03, -.38994500E+05, 0.19298700E+05, 0.11842200E+05, 0.90699200E+04, 0.80052500E+04, -.93784300E+03, -.44353200E+04, 0.13138500E+05, 0.97038100E+04, 0.11004300E+05, -.54873000E+04, 0.17515400E+04, -.70669400E+04, -.87033200E+04, 0.10894100E+05, 0.70811800E+04, -.96691800E+04, -.65661200E+04, 0.31596800E+05, -.15291600E+05, -.59816800E+04, -.69719300E+04, -.44797600E+04, 0.46651500E+04, 0.14762700E+04, -.19042700E+05, -.67011300E+04, -.57090700E+04, 0.28362100E+04, 0.27556900E+04, 0.14147800E+03, 0.45374400E+03, 0.19064200E+04, 0.43113300E+04, 0.30384900E+04, 0.16608000E+04, 0.10529800E+05, -.51433600E+04, -.30999100E+04, -.21059800E+04, -.14632500E+04, 0.35624300E+03, 0.89901400E+03, -.43522900E+04, -.19916900E+04, 0.25205100E+05, -.12298500E+05, -.78169000E+04, -.53612300E+04, -.62498300E+04, 0.13874100E+04, 0.19825000E+04, -.83971400E+04, -.69650500E+04, 0.88532000E+04, -.42054500E+04, -.46279200E+04, -.97698400E+03, 0.17787300E+03, -.16213100E+04, 0.17362400E+04, -.36544500E+04, 0.35588100E+03, 0.72886300E+04, -.36274500E+04, -.17756200E+04, -.21530100E+04, -.35546500E+04, 0.28843900E+04, 0.17205100E+04, -.51983900E+04, -.33208800E+04, 0.76175600E+04, -.37893900E+04, -.35294700E+04, 0.20224000E+03, -.44400100E+03, -.24058900E+04, -.37769000E+04, -.28524300E+04, -.17118300E+04, -.18161000E+05, 0.89990600E+04, -.18727400E+04, 0.56403700E+04, 0.63152600E+04, -.97142500E+04, -.45983200E+04, 0.12220000E+05, 0.58573500E+04, -.14651700E+05, 0.72216400E+04, -.19654500E+04, 0.50925200E+04, 0.37782100E+04, -.56124200E+04, -.53249000E+04, 0.19250600E+04, 0.54663900E+04, -.40448200E+04, 0.17110600E+04, 0.19915800E+04, -.79630700E+03, -.24969600E+04, 0.20189700E+04, -.46629600E+03, 0.26563300E+04, -.24888800E+04, -.18780100E+05, 0.93461400E+04, 0.36214500E+04, 0.37546500E+04, 0.50477600E+04, -.39490000E+04, -.28259200E+04, 0.10589700E+05, 0.54607800E+04, 0.84884300E+04, 0.30518500E+04, 0.32682200E+04, 0.56912600E+04, -.63536200E+04, -.30908500E+04, 0.87922900E+04, 0.77308200E+04, 0.13798900E+04, 0.18686600E+04, -.11866700E+04, 0.30086600E+04, -.60292200E+04, -.35379200E+04, -.15810600E+04, -.85882000E+04, -.13642500E+04, 0.11507500E+04, -.36049100E+04, 0.18994500E+04, -.19725500E+04, -.32066100E+04, -.23998900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36052300E+01, -.22759900E+00, 0.15116800E+01, 0.31726400E+00, 0.17980300E+01, -.45342900E+00, 0.14026900E+01, 0.42587300E+00, -.13547600E+01, 0.40996400E+00, -.17230300E+00, 0.25580900E-01, 0.24370200E+00, 0.14577200E+01, 0.30191600E+00, 0.19373000E+00, -.70633200E+00, -.15114900E+00, 0.14903400E+00, -.79820400E-01, -.44329500E+00, 0.27237600E+05, 0.29462800E+05, -.22990200E+05, -.38036200E+05, -.53074300E+05, 0.24341900E+05, 0.43173000E+05, -.19540600E+05, -.22193400E+05, -.75901100E+04, -.13369500E+04, -.12605200E+05, -.73985700E+04, 0.29072800E+04, -.51824200E+04, -.91302600E+04, 0.45495200E+04, 0.44923800E+04, -.21020500E+03, 0.20384800E+04, 0.30559000E+04, 0.31594900E+04, 0.21943800E+04, 0.61087900E+03, 0.94658700E+05, -.46064200E+05, -.47381400E+05, -.29103300E+05, -.80701800E+04, -.19454500E+05, -.14786500E+04, 0.54803800E+04, -.18479200E+05, 0.17950400E+05, -.76467900E+04, -.89737500E+04, -.21680100E+04, -.61502300E+04, -.39742900E+04, -.23151700E+04, 0.56101800E+04, -.69133800E+04, 0.44147700E+05, -.20949700E+05, -.21814900E+05, -.87170900E+04, -.31723200E+04, -.86198700E+04, 0.21991200E+04, -.59303100E+04, -.94374300E+04, -.68468800E+05, 0.33307600E+05, 0.34355900E+05, 0.14025500E+05, 0.13736800E+05, 0.11071500E+05, -.65539200E+04, -.99997500E+03, 0.19075000E+05, -.61944600E+05, 0.30638400E+05, 0.31412400E+05, 0.17613600E+05, 0.52339400E+04, 0.97909700E+04, -.36682300E+04, 0.59904900E+04, 0.10341900E+05, 0.17589400E+05, -.87786700E+04, -.99663900E+04, -.49050700E+05, -.56049500E+05, 0.36333600E+05, 0.64972300E+05, 0.87994000E+05, -.46040100E+05, 0.10820900E+06, -.52785600E+05, -.54355400E+05, -.32082300E+05, -.24881100E+05, -.14862100E+05, 0.81644700E+04, 0.13441200E+05, -.31033400E+05, 0.87979300E+04, -.44118700E+04, -.43586700E+04, -.45025300E+04, 0.17311900E+04, -.34597300E+04, -.53666900E+04, -.37802300E+04, -.55168200E+03, 0.24087900E+05, -.11611600E+05, -.12196400E+05, -.74728000E+04, -.41485300E+04, -.37645300E+04, 0.42415600E+03, 0.13282300E+04, -.56223400E+04, 0.52814000E+05, -.25558400E+05, -.26867200E+05, -.14035900E+05, -.83610900E+04, -.10738900E+05, -.18537700E+04, -.20415700E+04, -.12937700E+05, 0.79417500E+04, -.31341900E+04, -.39108300E+04, -.93105000E+04, 0.10954100E+04, 0.12600900E+04, 0.18259600E+04, 0.22285600E+04, -.10621000E+04, 0.50495800E+05, -.25157900E+05, -.25359200E+05, -.15120900E+05, -.22752700E+05, -.31249900E+04, 0.93817400E+04, 0.14711100E+05, -.22341700E+05, -.86883400E+04, 0.43584100E+04, 0.43217600E+04, 0.37693000E+04, -.21363500E+04, 0.36605400E+04, 0.48219800E+04, 0.38844800E+04, 0.21623600E+03, -.63903700E+05, 0.31692800E+05, 0.32895000E+05, 0.44302400E+05, 0.42784700E+05, -.11064700E+05, -.41299200E+05, -.58093700E+05, 0.39481700E+05, -.11836300E+05, 0.58015000E+04, 0.67901500E+04, 0.97845400E+04, -.64054600E+03, 0.17123000E+04, -.37765600E+04, -.74707300E+04, 0.45264800E+04, -.39441600E+04, 0.91448300E+03, 0.19770000E+04, 0.37683500E+04, -.29453300E+04, -.35531000E+03, -.19389500E+04, -.10105400E+04, -.22882500E+04, -.96955400E+05, 0.48371000E+05, 0.48806200E+05, 0.25793000E+05, 0.27617500E+05, 0.11697900E+05, -.14511600E+05, -.15130800E+05, 0.31349300E+05, 0.31864300E+05, 0.21072700E+05, 0.21544800E+05, -.43570200E+04, -.27700400E+05, -.21092300E+05, -.12882300E+05, 0.28630700E+05, 0.22069800E+04, -.15418100E+05, 0.16126500E+05, -.42793800E+03, 0.11586800E+05, -.19448700E+05, -.17260500E+05, 0.11133600E+05, -.20985700E+05, 0.35044500E+04, -.18495600E+05, 0.46120800E+04, -.20070300E+05, -.22299000E+05, 0.66695500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.61153000E+00, -.52183500E+00, 0.29015100E+00, 0.25950300E+00, -.26242500E+01, -.41414100E-01, 0.24394200E+01, 0.14708700E+01, 0.95660700E-01, -.51394300E+00, -.14299600E+00, 0.10416700E+01, -.21190100E+00, 0.13595600E+01, 0.40577700E+00, -.12340800E+00, -.56864000E+00, 0.43163500E+00, 0.83618400E+00, 0.53206000E+00, 0.11183700E+01, -.47721600E+00, 0.16037500E+05, -.11295100E+05, -.18538800E+05, -.60044100E+05, 0.13033500E+05, 0.45561400E+04, -.72447000E+03, -.19235400E+04, 0.30014500E+03, -.20138600E+05, 0.80960700E+04, 0.17923500E+05, 0.32501400E+05, -.17741400E+05, 0.54533500E+04, -.27336700E+04, -.26491700E+04, -.22440300E+04, 0.39722500E+03, -.11035000E+04, 0.38070300E+04, 0.65102800E+03, -.48145400E+03, -.44332600E+05, 0.22737400E+05, 0.22373000E+05, 0.10937000E+05, -.94355600E+04, 0.18444600E+05, 0.11517900E+05, 0.58462900E+05, -.56417800E+04, 0.22729000E+05, -.10167400E+05, -.11354700E+05, -.25576200E+04, -.13859900E+05, 0.13177000E+03, 0.98984500E+04, 0.13264700E+05, -.14276300E+05, -.67124300E+05, 0.34125800E+05, 0.32997900E+05, 0.12430900E+05, 0.14507900E+05, 0.13258000E+05, -.90498900E+04, 0.16366400E+05, 0.15905000E+05, 0.47293600E+05, -.23999900E+05, -.22877800E+05, -.86124300E+04, -.52721400E+04, -.11639200E+05, 0.31392500E+04, -.30519600E+05, -.68148200E+04, 0.10066000E+06, -.50176200E+05, -.50543100E+05, -.18392400E+05, -.17365900E+05, -.19164900E+05, 0.84804900E+04, -.36372800E+05, -.22991300E+05, -.29306600E+05, 0.14628100E+05, 0.13535700E+05, 0.69874700E+04, -.17833700E+05, 0.22419900E+05, 0.25158100E+05, 0.10786500E+06, -.12501200E+05, -.71230600E+05, 0.36175200E+05, 0.35771200E+05, 0.17971700E+05, -.28858700E+04, 0.20976700E+05, 0.35444200E+04, 0.73298400E+05, 0.26453800E+04, 0.21757800E+05, -.10860800E+05, -.10910800E+05, 0.22247200E+04, -.10803800E+04, -.70840100E+04, -.64143800E+04, -.10974500E+05, -.24816900E+04, -.25173000E+05, 0.12861300E+05, 0.12689900E+05, 0.58012500E+04, 0.18947800E+04, 0.57736700E+04, -.17721500E+04, 0.16192100E+05, 0.35539800E+04, -.42513000E+05, 0.21742200E+05, 0.21138900E+05, 0.13035300E+05, 0.83699800E+04, 0.82124600E+04, -.27571900E+04, 0.26323400E+05, 0.88988500E+04, -.33048600E+05, 0.17059500E+05, 0.16454400E+05, 0.79262900E+04, 0.71328500E+04, 0.65268400E+04, -.49519800E+04, 0.11230900E+05, 0.78116200E+04, -.13012700E+05, 0.65447700E+04, 0.61877900E+04, 0.63899400E+04, -.29736300E+04, 0.49088500E+04, 0.92574700E+03, 0.35980900E+05, -.17444600E+04, -.23037400E+05, 0.11489300E+05, 0.11539000E+05, -.24618500E+04, 0.21780300E+03, 0.76898400E+04, 0.50372800E+04, 0.99358700E+04, 0.18201800E+04, 0.42912200E+05, -.21596500E+05, -.21525600E+05, -.93349800E+04, 0.12285200E+05, -.21902100E+05, -.13018000E+05, -.91193900E+05, 0.74342700E+04, 0.13686900E+05, -.69318100E+04, -.79680400E+04, -.15038900E+04, 0.45081300E+04, -.75639600E+04, -.61873400E+04, -.18308900E+05, 0.48144300E+04, 0.28946000E+04, -.20845600E+04, -.14492200E+04, 0.12185500E+04, 0.19991100E+04, -.12717200E+04, 0.52241900E+03, -.32654900E+04, 0.73133100E+03, 0.21166900E+05, -.10531000E+05, -.10779300E+05, -.48392900E+04, 0.78838200E+04, -.95339200E+04, -.48763100E+04, -.53361500E+05, 0.52503900E+04, -.88823700E+04, 0.24767500E+04, 0.57916100E+03, 0.40177800E+04, 0.97805200E+04, -.27068500E+04, -.29088300E+05, -.13581600E+05, 0.12857200E+05, 0.23679900E+05, 0.10851400E+05, 0.13543200E+05, 0.23488100E+05, 0.32556000E+04, -.66239500E+04, 0.23375200E+05, -.38128100E+04, 0.15968600E+05, 0.46087100E+04, 0.44545500E+04, -.11713800E+03, 0.48435700E+03, 0.12084500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12713600E+01, 0.17442800E+00, -.10724500E+01, -.61042400E+00, 0.26700500E+01, -.62982700E-01, -.23704200E+01, -.10240400E+01, 0.15914100E+01, 0.58893400E+00, 0.80784600E+00, -.65494500E+00, 0.49364500E+00, -.40005200E+00, -.46828300E+00, 0.71338800E-01, 0.11514100E+00, 0.42502400E+00, 0.54193700E+00, 0.14992000E+01, -.31732700E-01, -.57678900E+00, 0.61715700E+00, -.68591500E+04, 0.39041700E+04, 0.45953000E+05, -.21183500E+04, 0.16833800E+04, -.47381200E+03, -.50901500E+03, 0.36452400E+04, -.26421800E+04, 0.59348400E+04, 0.51341800E+04, -.17835300E+05, 0.13536600E+04, 0.12153700E+05, -.60589100E+04, -.60330100E+04, -.43734300E+04, -.42110600E+04, -.21395200E+04, 0.92620200E+03, 0.21742200E+04, -.51186000E+04, 0.46993200E+05, -.22980900E+05, -.23172200E+05, -.65523200E+04, -.27130300E+05, 0.10730500E+05, -.46572600E+03, -.56043200E+05, -.19269200E+05, -.83121500E+04, 0.44065500E+04, 0.41071900E+04, 0.70295000E+04, 0.69052600E+04, 0.10767600E+04, -.53960200E+03, -.86446400E+04, 0.66202800E+04, 0.24625100E+05, -.12081700E+05, -.12738300E+05, -.60069000E+04, -.10021000E+05, -.22572000E+03, -.82457900E+04, -.23907500E+05, -.98212600E+04, -.14866000E+05, 0.72718300E+04, 0.77683700E+04, 0.62910400E+04, 0.10534300E+05, -.61613200E+04, 0.10266700E+05, 0.36677900E+05, 0.86281700E+04, -.95625500E+05, 0.47603500E+05, 0.47926700E+05, 0.32232100E+05, 0.51031400E+05, -.72183300E+04, -.18797300E+05, 0.29114700E+05, 0.45453900E+05, 0.43441300E+05, -.21677500E+05, -.22109500E+05, -.11194400E+05, -.17667100E+05, 0.10737500E+05, -.59319600E+04, -.90943700E+05, -.12257200E+05, 0.83385900E+05, -.41249700E+05, -.41616500E+05, -.26428700E+05, -.48567700E+05, 0.18520800E+05, 0.11557900E+05, -.68306200E+05, -.40304000E+05, -.20491400E+05, 0.10208500E+05, 0.10179900E+05, 0.58835400E+04, 0.13016100E+04, 0.68882800E+04, 0.14680700E+05, 0.75644100E+04, 0.49055500E+04, 0.21617700E+05, -.10749800E+05, -.10721000E+05, -.59316900E+04, -.11620600E+05, 0.31131600E+04, 0.45710700E+04, -.14587800E+05, -.96004000E+04, 0.73143400E+05, -.36377200E+05, -.36860700E+05, -.16229200E+05, -.35763700E+05, 0.50420800E+04, 0.96928800E+04, -.27714800E+05, -.30467300E+05, 0.24156900E+05, -.11968100E+05, -.12241700E+05, -.51658900E+04, -.11547400E+05, 0.11368400E+04, 0.10636500E+05, -.86596300E+04, -.79210700E+04, 0.18249700E+05, -.91241700E+04, -.92863100E+04, -.61189600E+04, -.12402300E+05, 0.89532500E+04, 0.52973400E+03, -.35620600E+05, -.97177400E+04, 0.21505000E+05, -.10710700E+05, -.10726300E+05, -.39282100E+04, 0.22405600E+03, -.80574300E+04, -.14930900E+05, -.93969400E+04, -.35451000E+04, -.12367600E+05, 0.61035100E+04, 0.61189100E+04, -.13693700E+04, 0.53649100E+04, -.10280400E+05, 0.22485100E+05, 0.89419000E+05, -.11030200E+04, -.27464000E+04, 0.13288900E+04, 0.37815200E+03, -.21041000E+04, 0.33054200E+04, -.24694000E+04, -.53850800E+03, 0.13005000E+05, 0.14536500E+03, -.14281300E+04, 0.50840500E+03, 0.69844600E+03, 0.22462700E+03, -.19241800E+04, 0.15680500E+04, -.37736200E+04, 0.41228100E+04, -.34406500E+04, -.16874200E+05, 0.84753100E+04, 0.83270700E+04, 0.87979700E+04, 0.19004300E+05, -.14545800E+05, 0.34326300E+04, 0.53322100E+05, 0.13652300E+05, 0.11260800E+05, 0.11827000E+05, 0.12569900E+05, 0.40335700E+05, -.10353700E+05, -.12566100E+05, 0.53527500E+05, 0.11107600E+05, 0.11234600E+05, 0.88885200E+04, -.12505200E+05, 0.23489900E+05, -.37200200E+05, -.15642400E+05, -.35031400E+04, -.39529100E+05, -.50490500E+04, 0.68118700E+04, -.16851100E+05, 0.19564100E+05, -.12494300E+05, -.11676700E+05, -.45105700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.50416000E+00, 0.46283700E-01, -.13907900E+01, 0.15908100E-01, -.48911100E+01, 0.10402700E+01, 0.22130500E+01, 0.13860200E+01, 0.25401100E+00, -.19520500E+00, -.73418700E+00, 0.73994100E+00, -.42572400E+00, 0.63005900E+00, -.55293400E+00, 0.34530900E+00, 0.16617700E+00, 0.55924500E+00, 0.92197600E+00, -.42165000E+00, -.84941300E+00, -.56279300E-01, 0.65881600E+00, -.24661500E+00, 0.11421800E+05, 0.16785800E+05, -.26164800E+04, -.86951100E+03, 0.19005800E+04, 0.12215100E+04, 0.42451500E+04, 0.62502600E+04, -.52617600E+02, -.58282600E+04, -.97838400E+04, 0.28397900E+04, 0.44239200E+04, -.22217100E+04, -.21609400E+04, -.17335900E+04, -.16072700E+04, 0.25792900E+03, 0.33378800E+04, 0.38399600E+04, -.20404800E+04, 0.13613200E+05, -.63782600E+04, -.56058300E+04, 0.10155000E+04, -.47968100E+04, 0.29208400E+04, -.76182900E+04, -.14780300E+05, -.38261600E+04, -.67695100E+04, 0.43706000E+04, 0.32525500E+04, 0.38255600E+04, 0.54053500E+04, 0.63712700E+03, -.13639700E+04, -.54067900E+04, 0.26384800E+04, 0.16958700E+05, -.78029500E+04, -.95862300E+04, -.63880500E+03, -.16647100E+04, -.69111000E+04, -.13917500E+05, -.14828700E+05, 0.14876500E+03, -.86491000E+04, 0.37725800E+04, 0.45607100E+04, 0.16158000E+01, 0.42073300E+03, 0.38455800E+04, 0.15481700E+05, 0.19474600E+05, -.16101400E+04, -.32816400E+05, 0.16496300E+05, 0.17254000E+05, 0.77070300E+04, 0.11067400E+05, 0.40127700E+04, 0.14125100E+05, 0.12247700E+05, 0.76017600E+04, -.90854500E+04, 0.45393000E+04, 0.49531500E+04, 0.42334900E+03, 0.50337900E+03, 0.41783500E+04, -.21903500E+05, -.29839600E+05, 0.44473200E+04, 0.24084600E+05, -.11524900E+05, -.11629800E+05, -.49329900E+04, -.10566200E+05, 0.16945900E+04, -.16230000E+05, -.22507900E+05, -.73423000E+04, 0.65067700E+04, -.32471300E+04, -.34600900E+04, 0.42568800E+04, 0.63858000E+03, -.28601800E+04, -.40046900E+04, -.54796300E+04, 0.84456700E+03, 0.39198100E+04, -.16214200E+04, -.15799100E+04, 0.53306100E+02, -.12099700E+04, -.28366400E+03, -.58514900E+04, -.56162000E+04, -.25886000E+03, 0.66592200E+04, -.28163500E+04, -.39131100E+04, -.16176900E+04, -.70761500E+04, 0.53142000E+04, 0.91098500E+03, -.33196700E+04, -.53411300E+04, 0.19842600E+04, -.36754700E+03, -.14323500E+04, 0.27567300E+04, -.10758900E+04, -.20840900E+03, -.58552200E+04, -.21063200E+04, -.37485000E+03, -.73058000E+04, 0.37075000E+04, 0.34876800E+04, 0.34611700E+03, -.72412700E+03, 0.40678300E+04, -.71198700E+04, -.10905400E+05, 0.10082900E+04, -.88019500E+04, 0.43795600E+04, 0.44610800E+04, -.29205000E+04, -.15365200E+03, 0.28941700E+04, 0.25513500E+04, 0.32367500E+04, 0.19290100E+03, 0.31578000E+05, -.15934400E+05, -.16931200E+05, -.10079100E+05, -.85898400E+04, -.90448500E+04, 0.23178000E+05, 0.29089500E+05, -.10185800E+05, 0.36266100E+04, -.19202300E+04, -.48090000E+04, -.24809200E+04, -.26569800E+04, -.24693600E+04, 0.46437200E+04, 0.61180300E+04, -.72656900E+03, -.91444900E+04, 0.39291900E+04, 0.45062400E+04, -.62371900E+03, 0.20602200E+04, 0.40492200E+04, 0.70109300E+04, 0.41748800E+04, 0.70350300E+03, 0.17409500E+04, -.86204400E+03, -.13452100E+04, -.44568600E+03, 0.24297200E+04, -.29661100E+04, 0.15530800E+05, 0.21329500E+05, -.90594000E+03, 0.17008900E+02, -.32355400E+04, -.31546300E+04, 0.13784800E+05, 0.83170200E+03, 0.29215100E+04, 0.18315600E+05, 0.44278800E+03, -.37652300E+04, -.18858100E+04, -.81747900E+04, 0.99842200E+04, -.11086000E+05, 0.10138500E+05, 0.41579300E+04, -.16437400E+05, 0.78376300E+04, 0.46042200E+03, 0.10548700E+05, 0.54183000E+04, 0.30930400E+04, 0.80691400E+04, -.62920000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11147400E+01, -.42095300E+00, -.13143800E+01, 0.20653600E+00, -.63279500E+01, 0.10489900E-01, 0.65203400E+01, 0.26671400E+01, 0.64455100E+00, -.99850900E-01, -.35423900E+01, 0.15980100E+01, -.19202300E+01, 0.14666900E+01, 0.70756900E+00, -.45469700E+00, 0.38386000E+00, 0.64850200E+00, 0.21576500E+01, -.10238500E+01, 0.38949300E+01, 0.57981500E-01, 0.28777100E+00, -.23126600E+00, -.52733000E+00, -.81950500E+05, 0.56572900E+04, -.71665700E+05, 0.26315100E+05, 0.39998600E+05, -.52061500E+04, -.29995100E+05, 0.36508400E+05, 0.26561600E+05, 0.58371500E+05, -.26629800E+05, -.10643400E+05, 0.53476000E+04, 0.60134400E+04, 0.34773400E+04, 0.42608700E+04, 0.44050200E+04, 0.41307300E+04, 0.16141700E+04, 0.55723200E+04, -.13844400E+06, 0.63923200E+05, 0.69463000E+05, 0.44827600E+03, -.21431100E+05, 0.49339100E+05, 0.54298900E+05, 0.17169800E+06, -.13901400E+05, -.17223700E+05, 0.21293500E+04, 0.87894500E+04, -.60020600E+04, -.14216900E+05, 0.97028300E+04, 0.90160900E+04, 0.12618400E+05, -.11777600E+05, -.10174800E+06, 0.45295400E+05, 0.50009100E+05, 0.78132400E+04, -.64323300E+03, 0.24771900E+05, 0.11694400E+05, 0.71117100E+05, 0.12036300E+05, 0.75271200E+05, -.33224500E+05, -.39687400E+05, -.29187300E+04, 0.41097100E+04, -.17950100E+05, -.19880700E+05, -.90804400E+05, -.52803300E+04, 0.22738700E+06, -.11267700E+06, -.11581800E+06, -.44667900E+05, -.45686900E+05, -.35933900E+05, 0.25003100E+05, -.95550100E+05, -.53107500E+05, -.80090400E+05, 0.39990300E+05, 0.50109700E+05, 0.13627100E+05, 0.27266200E+05, 0.11306800E+05, -.29395000E+04, 0.16165000E+06, 0.15054000E+05, -.19241900E+06, 0.90830900E+05, 0.97814800E+05, 0.25171400E+05, 0.14569500E+05, 0.35814600E+05, 0.10866600E+05, 0.18576700E+06, 0.22757800E+05, 0.47084200E+05, -.23398200E+05, -.23659300E+05, 0.14570700E+03, 0.89433500E+03, -.18598400E+05, -.30146600E+05, -.28425600E+05, -.61490000E+04, -.67792700E+05, 0.31968600E+05, 0.34993300E+05, 0.10621400E+05, 0.80425700E+04, 0.12520100E+05, -.52265300E+04, 0.39961500E+05, 0.10572800E+05, -.16717300E+06, 0.79898100E+05, 0.87093400E+05, 0.21178400E+05, 0.32801600E+05, 0.31729500E+05, 0.68093700E+04, 0.90187100E+05, 0.34928500E+05, -.92041800E+05, 0.42214000E+05, 0.45815300E+05, 0.17704500E+05, 0.13876600E+05, 0.14057200E+05, -.23099000E+05, 0.32281900E+05, 0.13525500E+05, -.53087800E+05, 0.26306600E+05, 0.27496100E+05, 0.78110000E+04, 0.16374700E+05, 0.24182100E+04, -.17710600E+04, 0.70309700E+05, 0.15883100E+05, -.52016400E+05, 0.25881500E+05, 0.26088100E+05, -.30673800E+04, -.30890200E+04, 0.20315300E+05, 0.27985000E+05, 0.26190000E+05, 0.48161400E+04, 0.68453200E+05, -.33191100E+05, -.42678600E+05, -.85591400E+03, -.31920800E+04, -.25833800E+05, -.27854400E+05, -.16379100E+06, 0.59369100E+04, 0.24154400E+05, -.11522000E+05, -.19281000E+05, 0.47081500E+04, 0.68303200E+04, -.22926200E+05, -.11567400E+05, -.29217500E+05, 0.12039100E+05, 0.17227400E+05, -.39651100E+04, -.86319300E+04, 0.46123100E+03, 0.16048900E+05, -.67595000E+04, 0.12670500E+05, -.94997400E+04, 0.13558400E+05, 0.68244400E+05, -.34191200E+05, -.36599200E+05, -.46899100E+04, -.63953100E+04, -.11161900E+05, -.90929200E+04, -.10970400E+06, -.83286400E+04, -.39721500E+05, -.60661900E+04, -.10233700E+05, -.37969000E+05, 0.32343600E+05, 0.72684700E+04, -.80798500E+05, -.36079500E+05, 0.16446400E+04, -.31756500E+04, 0.12142900E+05, -.12996500E+05, 0.52643000E+05, 0.22600100E+05, -.31342100E+04, 0.82634900E+05, -.88839200E+03, 0.20640300E+05, 0.25666900E+05, -.12414200E+05, 0.11626300E+05, 0.16457100E+05, 0.35055500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12711600E+00, -.20221100E-01, 0.35931100E+00, -.35463000E+00, 0.47138200E+01, -.57751500E+00, -.22501200E+00, -.63393000E+00, -.10461200E+01, 0.86512000E+00, 0.37285500E+00, -.65896000E+00, 0.25428400E+00, -.39739100E+00, 0.16723200E+00, 0.39719400E+00, 0.98584900E-02, -.30295500E+00, -.73333700E+00, -.75079500E+00, -.39439000E+00, 0.31530100E+00, -.39568900E+00, -.32937200E+00, -.27658700E+00, -.74503200E-01, -.18644400E+04, 0.74252200E+04, -.30094400E+04, -.35440000E+04, 0.25046300E+02, 0.34811400E+04, -.35889800E+04, -.28528200E+04, -.22040400E+04, 0.34933700E+04, -.47501100E+04, 0.23638100E+04, 0.24221000E+04, -.98277700E+03, 0.17241100E+03, 0.22228600E+04, 0.25882000E+04, 0.24441300E+04, -.13192700E+04, 0.15353700E+05, -.73715000E+04, -.72898500E+04, 0.14459600E+04, 0.46695600E+04, -.61869400E+04, -.63301300E+04, -.63062300E+04, 0.58142000E+04, 0.23206600E+04, -.70814200E+03, -.11975700E+04, -.48121400E+03, 0.77021800E+03, -.38484400E+03, -.33340900E+01, 0.10995600E+03, -.12075600E+04, 0.57635400E+04, -.25497700E+04, -.33293600E+04, 0.21866300E+03, 0.16297900E+04, -.26299300E+04, -.27232900E+04, -.35687500E+04, 0.70508300E+03, -.58058400E+04, 0.26278100E+04, 0.33034100E+04, -.98380900E+03, -.21552800E+04, 0.32648600E+04, 0.37318100E+04, 0.44090900E+04, -.18125300E+04, -.50365800E+04, 0.25525000E+04, 0.27510400E+04, -.78585000E+03, -.41775400E+04, 0.37802600E+04, 0.50704600E+04, 0.34549900E+04, -.59413700E+04, -.20411500E+04, 0.10129800E+04, 0.29205100E+03, 0.10460300E+04, 0.78404400E+03, -.48712700E+03, -.11596300E+04, 0.32313600E+03, 0.54916500E+04, 0.84540500E+04, -.39267900E+04, -.41341500E+04, 0.98113500E+03, 0.48123400E+04, -.38280500E+04, -.50361300E+04, -.41573100E+04, 0.58208500E+04, 0.21364500E+04, -.10667700E+04, -.11261400E+04, -.74632800E+03, -.96630300E+03, 0.12203900E+03, 0.88950100E+03, 0.58129200E+03, -.61656300E+03, 0.33515900E+04, -.15065000E+04, -.15528100E+04, -.35474000E+02, 0.81734300E+03, -.12441100E+04, -.10129400E+04, -.73305800E+03, 0.14422600E+04, 0.73770300E+04, -.34263900E+04, -.39837400E+04, 0.62549900E+03, 0.21620500E+03, -.23718500E+04, -.16528800E+04, -.14160000E+04, 0.90312700E+03, -.30070200E+04, 0.18185800E+04, 0.13636100E+04, -.18636500E+04, -.12608800E+04, 0.34107700E+04, 0.51304500E+04, 0.45896900E+04, 0.15417000E+04, 0.64897000E+03, -.30020600E+03, -.61127400E+03, 0.79436800E+03, 0.60920900E+03, -.53216400E+03, -.11875600E+04, -.30627400E+03, 0.10958300E+04, -.11030500E+04, 0.54575000E+03, 0.56619100E+03, 0.79980300E+03, 0.59317900E+03, -.34892400E+03, -.10268900E+04, -.62538600E+03, 0.49743900E+03, 0.87408500E+03, -.52091500E+03, -.60092900E+03, -.20698600E+04, -.32724600E+04, 0.12355900E+04, 0.28384800E+04, 0.10741100E+04, -.85465700E+04, -.18521400E+04, 0.88009300E+03, -.32626700E+03, 0.17555700E+04, -.70332200E+03, -.43980300E+02, -.15349500E+04, -.14651600E+04, -.14003500E+03, 0.34278900E+04, -.20498700E+04, -.17315800E+04, 0.83360500E+03, 0.51557200E+03, -.20485100E+04, -.25130600E+04, -.24044100E+04, -.29465200E+04, -.56052500E+04, 0.28133700E+04, 0.27307500E+04, -.15285000E+04, -.23047200E+04, 0.30780900E+04, 0.38200400E+04, 0.31858600E+04, -.35888100E+04, 0.17198900E+04, -.15759500E+04, -.16393900E+04, -.25750100E+04, -.89493200E+03, 0.13870900E+04, 0.27939800E+02, 0.15253600E+04, -.29354400E+04, -.22510100E+04, 0.66113200E+03, -.19289500E+04, 0.12060800E+04, 0.15101600E+04, 0.16326900E+04, -.35648200E+04, 0.51351400E+04, -.23670100E+04, 0.15393300E+04, -.73332900E+03, 0.20511200E+04, 0.32589500E+04, -.21159800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.27614200E+01, 0.13816500E+01, -.29327700E+01, -.82497000E+00, -.36845400E+01, 0.37897400E+00, -.17754000E+01, 0.20105900E+00, 0.32741500E+00, 0.16985200E+00, -.13871700E+01, -.70742100E+00, 0.43961900E+00, -.76827100E+00, 0.23614400E+00, -.18529800E+00, -.60754000E+00, -.54783300E+00, -.10314000E+01, -.43216600E+00, -.17698100E+01, 0.74032900E-01, 0.38819100E+00, -.28600000E-01, 0.34031500E+00, -.46409900E+00, -.10414100E+01, 0.51235000E+05, -.21256600E+05, -.24551700E+05, 0.27698800E+04, 0.18198800E+05, -.19209900E+05, -.85842400E+04, -.14805000E+05, 0.52462700E+04, -.60835900E+04, 0.30200700E+04, 0.32788700E+04, -.18849400E+02, 0.11125900E+04, 0.14565800E+04, -.17392000E+04, -.34992700E+04, -.22638000E+03, -.15648500E+04, 0.24194400E+04, 0.10449400E+04, 0.66362700E+04, 0.22599600E+05, -.34027100E+04, -.66519500E+04, -.31852800E+04, 0.11340000E+05, 0.27578700E+05, -.11032300E+05, -.13802400E+05, 0.14264900E+04, 0.39020600E+04, -.94250100E+04, -.96187000E+03, -.16802700E+04, -.62719600E+03, 0.26544900E+05, -.11593100E+05, -.13984600E+05, -.78458600E+03, 0.41532400E+04, -.89097800E+04, -.39843700E+04, -.12437400E+05, -.10535800E+04, -.24697100E+05, 0.11057900E+05, 0.12517800E+05, 0.95864300E+03, -.24167900E+04, 0.78828600E+04, 0.27074900E+04, 0.10412700E+05, 0.12449300E+04, -.36972100E+05, 0.18040800E+05, 0.18412200E+05, 0.36679000E+04, -.57612900E+04, 0.71441700E+04, 0.16554000E+04, 0.20866900E+05, 0.24414200E+04, 0.18942500E+05, -.94403700E+04, -.85705200E+04, -.39123200E+04, -.70188600E+04, -.94138500E+03, 0.67970200E+04, -.10929300E+04, -.68766300E+04, 0.18149300E+05, -.69289100E+04, -.89503600E+04, 0.25207800E+04, 0.17085000E+05, -.55617100E+04, -.43835400E+04, -.11206200E+05, 0.64139000E+04, -.68040400E+03, 0.33621900E+03, 0.26134600E+03, -.11978900E+04, -.85224900E+03, 0.33045100E+03, -.14439700E+04, 0.61187500E+04, -.68570400E+02, 0.17015200E+05, -.74711300E+04, -.82280100E+04, -.36206100E+03, 0.42849900E+04, -.47469800E+04, -.12280900E+04, -.65076600E+04, 0.41023900E+03, 0.16021400E+05, -.62900000E+04, -.78194900E+04, 0.54707800E+02, 0.80168500E+04, -.50182700E+04, -.30887200E+04, -.52317900E+04, 0.23942000E+04, 0.26494900E+05, -.11197700E+05, -.13478300E+05, -.31347700E+03, 0.13494600E+05, -.95638400E+04, -.40420200E+04, -.12726000E+05, 0.34942300E+04, 0.12056300E+05, -.58788600E+04, -.62733100E+04, -.20074200E+04, -.38575800E+04, -.79818600E+03, 0.42255000E+04, 0.57150600E+03, -.32267000E+04, 0.15471300E+05, -.77265800E+04, -.77032200E+04, 0.47660400E+03, -.64912300E+03, -.40912900E+04, 0.38330600E+04, -.45421700E+04, -.21713700E+04, -.13698500E+05, 0.64944600E+04, 0.53485300E+04, 0.31085900E+04, 0.66480400E+04, -.43071000E+04, -.16080700E+05, -.81550700E+04, 0.83860900E+04, -.96457900E+04, 0.45853000E+04, 0.20439000E+04, 0.24072300E+04, -.55095200E+03, -.96600100E+03, -.49324900E+04, -.25947600E+04, 0.52846000E+04, -.31754400E+05, 0.13643300E+05, 0.15861100E+05, -.73448000E+03, -.14189600E+05, 0.11878100E+05, 0.45706100E+04, 0.13836400E+05, -.40974500E+04, -.26623800E+05, 0.13047200E+05, 0.12910100E+05, 0.26696900E+04, 0.10826500E+04, 0.39911300E+04, -.41070400E+04, 0.35503500E+04, 0.41843800E+04, 0.13912200E+05, -.19573100E+04, -.16852100E+04, -.61076200E+04, -.68460400E+04, 0.22807600E+04, -.61422800E+04, 0.79105700E+04, 0.99602400E+03, -.36460200E+03, 0.42678800E+04, -.64996000E+04, 0.34259000E+04, 0.52927000E+04, -.29518500E+03, 0.11747600E+04, -.34729000E+04, -.62924400E+04, 0.46568900E+04, -.63456400E+04, 0.28120700E+04, -.25866800E+04, -.75104000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.38067200E+00, 0.53622500E-01, 0.10216600E+00, -.10998600E+00, 0.11799100E+01, 0.11698900E-01, -.10756100E+01, -.30357300E+00, -.20089800E+00, -.50033600E-01, 0.61205100E+00, -.12032500E+00, 0.24853600E+00, 0.35865000E+00, -.27575400E+00, 0.16992800E+00, -.20559500E+00, -.16843600E+00, -.99977300E-02, 0.23125600E+00, -.34357900E+00, 0.23125900E-02, 0.86172000E-01, -.11368900E-01, 0.99814800E-01, -.73170100E-01, 0.25720800E+00, 0.85227700E-01, -.10022600E+04, -.20422700E+03, -.17755300E+04, -.25206300E+04, 0.30858700E+03, 0.29790400E+03, 0.16513800E+04, -.56153200E+03, 0.38758100E+01, 0.68637300E+01, -.31594300E+01, 0.61577500E+03, -.71108300E+02, -.48151800E+03, -.14253200E+04, -.14341800E+04, 0.37751700E+03, -.74011800E+04, 0.34063900E+04, 0.33902300E+04, -.81818500E+03, 0.43541600E+03, 0.21509500E+04, 0.48970600E+03, -.19120800E+03, 0.21975100E+04, 0.93335200E+03, -.11623900E+04, -.44372100E+03, -.12470300E+04, -.15730600E+04, 0.14946900E+03, 0.34814500E+03, 0.21785700E+04, -.29033100E+03, 0.40736600E+04, -.24234600E+04, -.18044300E+04, -.12668400E+04, -.16161800E+04, 0.55761700E+03, 0.33931000E+04, -.30708100E+03, -.15071200E+04, -.57518100E+04, 0.31571400E+04, 0.29333400E+04, 0.17241900E+04, 0.23134500E+04, -.51106300E+03, -.38236500E+04, -.35313000E+03, 0.22087100E+04, -.78343200E+04, 0.38771000E+04, 0.37706100E+04, 0.21737400E+04, 0.37426200E+04, -.43122800E+03, -.42671000E+04, 0.29834800E+04, 0.40008500E+04, 0.95254400E+04, -.47599800E+04, -.51969900E+04, -.18224200E+04, -.31125400E+04, -.11969700E+04, 0.16057400E+04, -.10335500E+04, -.31498300E+04, 0.89273600E+03, -.81360900E+03, -.62523800E+03, -.16724000E+04, -.20419600E+04, 0.16123300E+04, 0.28588300E+04, -.15511200E+04, -.11625100E+04, -.25696000E+04, 0.12804500E+04, 0.13332300E+04, -.15406600E+04, -.34486600E+03, 0.12440800E+04, 0.25972600E+04, 0.25545800E+04, 0.26525100E+03, 0.18970600E+04, -.11719100E+04, -.10636300E+04, -.92012900E+03, -.13185800E+04, 0.32175000E+03, 0.15722000E+04, -.29990500E+03, -.11208000E+04, 0.25366000E+04, -.16198700E+04, -.12604300E+04, -.20516400E+04, -.18853300E+04, 0.38966100E+03, 0.99556800E+03, -.12319400E+04, -.97894500E+03, 0.54355100E+04, -.31384900E+04, -.26350300E+04, -.96724900E+03, -.17931400E+04, -.12937200E+04, 0.72954700E+03, -.23617500E+04, -.12640000E+04, 0.52275900E+04, -.26507200E+04, -.26565200E+04, -.17459500E+04, -.20206600E+04, 0.52330500E+02, 0.21362300E+04, 0.51132700E+02, -.19612200E+04, 0.23216500E+04, -.11498700E+04, -.11744100E+04, 0.15211800E+04, 0.42191500E+03, -.98687700E+03, -.19547300E+04, -.13830100E+04, -.29287700E+03, -.14566100E+05, 0.73745200E+04, 0.77708100E+04, 0.30061800E+04, 0.44686300E+04, 0.25358200E+04, -.31175600E+04, 0.23408800E+03, 0.39178700E+04, -.26053700E+04, 0.13650400E+04, 0.19918000E+04, 0.17348300E+03, 0.10287100E+04, 0.14700800E+04, 0.26905400E+03, 0.31373200E+02, -.62333700E+03, 0.10804600E+04, -.10297200E+03, -.52354200E+03, -.66883800E+03, 0.14081600E+03, -.28775100E+03, -.80368400E+03, 0.12641500E+03, 0.21146600E+03, -.69795600E+04, 0.35047000E+04, 0.36764500E+04, 0.22138800E+04, 0.32630000E+04, -.59676900E+03, -.46600000E+04, -.12276900E+04, 0.31406800E+04, 0.24653300E+04, 0.29978500E+04, 0.29541400E+04, 0.82297800E+03, -.28711000E+04, -.29147400E+04, 0.67983700E+03, 0.24937000E+04, 0.19621800E+04, -.21863800E+03, 0.10890300E+04, 0.65431000E+03, -.87453100E+03, -.50406900E+04, -.20707300E+04, 0.86359900E+03, -.26723300E+04, 0.10860100E+04, -.49605300E+04, 0.16414600E+04, -.31685300E+04, -.36593400E+04, 0.20675200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.55859300E+00, -.92277000E+00, 0.53335700E+00, 0.25338500E+00, -.13039000E+01, 0.53542700E-01, 0.12138900E+01, 0.25821300E+00, 0.25062800E+00, -.31956000E+00, -.46405300E+00, 0.36225000E+00, -.50502200E+00, 0.84602700E+00, 0.13136500E+00, -.28721400E+00, -.21457500E+00, -.98603500E-01, 0.22090100E+00, 0.80879600E+00, 0.17735900E+01, -.15694700E+00, -.15850200E+00, 0.79601500E-01, 0.19619000E+00, 0.23780100E+00, -.37867400E+00, 0.61085200E-01, -.16672200E+01, -.14970200E+04, -.48129400E+04, -.18470700E+04, -.31809900E+03, 0.29247300E+04, 0.21865400E+04, 0.30551900E+04, 0.14841100E+04, -.74109300E+03, -.89932700E+03, 0.12740100E+03, -.89358500E+03, -.10670800E+04, -.11209700E+04, -.15785500E+04, -.10274400E+04, -.11334700E+04, 0.86462900E+03, -.43789200E+03, -.12115700E+04, 0.27042500E+04, -.20131300E+04, -.72649900E+04, -.10245800E+05, 0.80357700E+04, -.18047900E+03, 0.24921300E+03, 0.16774100E+03, -.45217800E+04, -.22163900E+03, 0.18656200E+04, 0.31129600E+04, 0.36286800E+04, 0.59017600E+03, -.10597900E+05, 0.52296200E+04, 0.64512700E+04, -.14002400E+04, -.41689500E+04, 0.89278700E+04, 0.11171100E+05, 0.85015500E+04, -.32106300E+04, 0.24843100E+04, -.10658600E+04, -.93488000E+03, 0.35400100E+04, 0.70956400E+04, -.79400500E+04, -.11933300E+05, -.10608100E+05, 0.56745700E+04, -.11233200E+05, 0.56165900E+04, 0.52388700E+04, 0.22676400E+04, 0.66608000E+04, 0.59085600E+03, -.74307900E+04, 0.29266300E+04, 0.45390100E+04, 0.20488100E+05, -.10234000E+05, -.13000100E+05, -.43621200E+04, -.70542200E+04, -.34420000E+04, 0.32210200E+04, -.12731800E+04, -.51819600E+04, 0.71994500E+04, -.34883700E+04, -.41583200E+04, -.52140600E+04, -.34551300E+04, 0.11409800E+04, 0.43390500E+04, -.58774200E+04, -.30187500E+03, -.82976200E+04, 0.41294100E+04, 0.43518800E+04, -.26044400E+04, -.73484700E+03, 0.42995300E+04, 0.89681900E+04, 0.65797100E+04, 0.99471700E+03, 0.40730000E+04, -.21084700E+04, -.25503200E+04, -.20667800E+04, -.22012900E+04, 0.28150200E+03, 0.36122500E+04, -.55283500E+03, -.12176400E+04, 0.10583300E+05, -.53382200E+04, -.55088000E+04, -.23542700E+04, -.38874500E+04, -.21053800E+04, -.15830500E+04, -.74377500E+04, -.11898000E+04, 0.53485800E+04, -.28114400E+04, -.22630400E+04, -.35246900E+04, -.61249900E+04, 0.19527700E+04, 0.87978600E+04, 0.13181500E+03, -.18108600E+04, 0.10078500E+05, -.50497300E+04, -.52057500E+04, -.38775900E+04, -.41550800E+04, 0.48922600E+03, 0.35574800E+04, 0.18306400E+03, -.40505700E+04, 0.29106500E+04, -.14412100E+04, -.15249700E+04, 0.26603300E+04, 0.16347900E+04, -.27064000E+04, -.89213100E+04, -.45477400E+04, -.37274600E+02, -.29361400E+05, 0.14621100E+05, 0.17292600E+05, 0.80878800E+04, 0.67170700E+04, 0.83550300E+04, -.12902700E+04, 0.13736100E+04, 0.19240500E+04, 0.17657100E+04, -.86961800E+03, 0.27790900E+04, 0.60471200E+03, -.20798300E+03, 0.42841400E+04, 0.12439000E+04, -.91464100E+03, -.45508000E+04, 0.10451400E+05, -.51564200E+04, -.51653600E+04, -.12524100E+04, 0.80603300E+03, -.41168000E+04, -.63696900E+04, -.41453100E+04, -.22683500E+04, -.97108300E+04, 0.49510600E+04, 0.57434600E+04, 0.42716200E+04, 0.54311900E+04, -.89064700E+03, -.63616900E+04, -.40453200E+04, 0.39625100E+04, 0.52657400E+04, 0.47970500E+04, 0.48009800E+04, -.58884700E+03, -.63737000E+04, -.49871000E+04, 0.22929900E+04, 0.67297200E+04, 0.77646100E+04, 0.29081300E+04, 0.31713100E+04, -.69648300E+03, -.11842000E+04, -.11543300E+05, -.35301300E+04, -.27987700E+04, -.26372900E+04, 0.18626800E+04, -.11709400E+05, 0.28883000E+04, -.56066300E+04, -.63490900E+04, 0.15307000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.29048300E+01, 0.26311500E+00, -.38697200E+01, -.13697500E+01, 0.80209700E+01, -.26734800E+00, -.81336400E+01, -.37765700E+01, 0.47870100E+00, 0.22680300E+00, 0.20300900E+01, -.13907900E+01, 0.19722400E+01, -.14949000E+01, -.25968000E+00, 0.15457700E+01, 0.66868700E+00, 0.22825800E+00, -.10245600E+00, 0.25502900E+00, -.88725700E+00, -.46815000E+00, 0.16802900E+00, 0.16249200E+00, -.54004200E+00, -.36215900E+00, -.89646100E+00, 0.38421800E+00, 0.19704600E+00, -.16255300E+01, -.94990200E+04, 0.28514300E+04, -.14469800E+04, -.23834800E+04, -.47859100E+04, 0.55587000E+04, 0.93923800E+03, -.48085700E+03, -.40063500E+03, 0.75355300E+02, -.12182600E+04, 0.26468500E+03, 0.20046000E+04, 0.31204200E+04, -.14800600E+04, 0.44719200E+05, -.22213200E+05, -.22259800E+05, -.27641300E+04, 0.65574200E+03, -.14369300E+05, -.27596700E+04, -.12483600E+05, 0.21974500E+04, -.15540400E+05, 0.80341400E+04, 0.77280300E+04, -.79041600E+04, 0.41200900E+04, 0.50192900E+04, -.68364100E+03, -.16181900E+04, 0.40967700E+04, -.17695000E+05, 0.86090100E+04, 0.82624900E+04, 0.45196600E+04, 0.39579700E+03, 0.86333900E+04, 0.12085000E+05, 0.11359000E+05, 0.17453600E+04, 0.25561700E+04, -.90024200E+03, -.16945900E+03, -.19874600E+04, 0.22365800E+04, -.45841000E+04, -.13291500E+05, -.10474100E+05, 0.13825300E+04, 0.47165500E+03, 0.15020900E+03, -.54076900E+02, -.10922900E+05, -.42666600E+04, 0.43438600E+04, 0.62108600E+03, -.11764500E+04, -.65349500E+04, -.67694300E+04, 0.33684600E+04, 0.92752100E+03, 0.60813600E+03, 0.13816800E+04, 0.31856200E+03, 0.39773500E+03, -.65213300E+03, 0.33813000E+04, 0.30044400E+05, -.15206300E+05, -.15244500E+05, 0.74835100E+03, 0.46469600E+03, -.10476300E+05, 0.28702100E+04, -.65345300E+04, 0.20946700E+04, -.65877400E+04, 0.32825100E+04, 0.32529500E+04, -.46216700E+04, 0.20904600E+04, 0.30911400E+04, 0.74328500E+04, 0.25718200E+03, 0.11099500E+04, 0.44016200E+04, -.22679900E+04, -.22100300E+04, -.31320200E+03, -.64650200E+03, -.99134400E+03, 0.23433600E+04, -.29489300E+03, 0.32607700E+03, 0.16062800E+05, -.81582800E+04, -.86576900E+04, 0.19609700E+03, -.28453400E+04, -.51066200E+04, 0.16507800E+04, -.47669300E+04, -.14489000E+04, -.86492300E+04, 0.41260100E+04, 0.41952200E+04, -.35527100E+04, -.91888100E+04, 0.73842300E+04, 0.12356300E+05, 0.92769700E+04, -.19296500E+04, 0.57855600E+04, -.28860100E+04, -.35061200E+04, -.70759500E+03, -.12615800E+03, -.19431100E+04, 0.99292300E+03, -.30064600E+04, -.82718400E+03, -.97476100E+04, 0.48582700E+04, 0.48874700E+04, 0.48048800E+04, -.77803100E+03, 0.15006300E+04, -.88562200E+04, 0.20405200E+03, 0.11977000E+04, -.16497000E+05, 0.81234700E+04, 0.91319500E+04, 0.50797800E+04, -.29877900E+04, 0.61405200E+04, -.10213400E+03, 0.65354500E+04, -.56453300E+04, -.44626800E+04, 0.21956400E+04, 0.13653200E+04, 0.47032400E+04, -.22022300E+04, 0.27150100E+04, -.13651600E+03, 0.30490500E+04, -.34196300E+04, 0.27649700E+05, -.13608700E+05, -.13827200E+05, -.25378900E+04, 0.66689600E+04, -.11138600E+05, -.87998600E+04, -.12371300E+05, -.13730500E+04, -.79236600E+04, 0.41632400E+04, 0.41660800E+04, -.30429800E+04, -.29692000E+03, 0.25089700E+04, -.42218800E+04, -.17541100E+03, -.83438800E+03, 0.36218200E+04, 0.15112500E+03, 0.10115000E+04, -.44073000E+04, -.56009800E+04, -.53027100E+03, 0.80418800E+02, 0.99748900E+04, 0.15027100E+05, 0.14994800E+05, 0.77828100E+04, -.44192300E+04, 0.14603000E+04, -.77981300E+04, -.17564100E+03, -.34368800E+04, 0.20745200E+04, -.29891000E+04, -.73407500E+04, -.14900800E+04, -.99740700E+03, -.50965300E+03, -.49683200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22417900E+00, 0.48283500E-02, 0.29059300E-01, -.19092300E+00, 0.31321800E+01, -.39191200E+00, -.18353100E+01, -.77620300E+00, 0.66592800E+00, 0.64269900E+00, 0.52610900E+00, -.86276000E+00, 0.16343500E+00, -.49420000E+00, -.25558700E+00, 0.80993100E-01, -.26774500E+00, -.26647700E+00, -.47188300E+00, 0.62712000E+00, -.65177400E-01, -.43142400E-01, -.29376400E+00, 0.42575900E+00, -.51634500E+00, -.31310400E-01, 0.42398800E-02, -.13475100E-02, -.16758400E+01, 0.35882500E+00, 0.22746600E+00, -.45786800E+04, 0.73042300E+03, 0.63540200E+03, 0.43200400E+04, -.21104700E+04, -.17528100E+04, 0.87639600E+03, 0.88727900E+03, 0.79874900E+03, 0.41045100E+03, -.82124600E+02, -.21585500E+04, -.22029100E+04, 0.87214400E+03, -.24121100E+05, 0.12030500E+05, 0.12060200E+05, -.14797500E+04, 0.18337500E+04, 0.73777400E+04, 0.29282600E+04, 0.44383500E+04, 0.45884900E+04, 0.64507600E+04, -.32819100E+04, -.32383000E+04, 0.70321500E+03, -.40227000E+04, -.13306200E+04, 0.12758300E+04, 0.41142500E+04, -.21577700E+04, 0.13421200E+05, -.65301400E+04, -.66252600E+04, -.42853900E+04, -.33723400E+04, -.15952100E+04, 0.39549700E+04, -.39227700E+04, -.36060900E+04, -.10744500E+05, 0.51503900E+04, 0.52270400E+04, 0.36380900E+04, 0.27579600E+04, 0.93693000E+03, -.34692000E+04, 0.37086600E+04, 0.28045900E+04, -.13173100E+05, 0.65012800E+04, 0.67141000E+04, 0.66080300E+04, 0.51931100E+04, -.66014100E+03, -.32979600E+04, 0.64899300E+04, 0.61415300E+04, 0.11582700E+05, -.57820300E+04, -.56279000E+04, -.20003600E+04, -.38365500E+04, -.13191600E+04, 0.16194600E+04, -.85672500E+03, -.39741600E+04, -.53216100E+04, 0.27020800E+04, 0.26075600E+04, -.28583200E+04, -.15138400E+04, 0.38579800E+04, 0.21962100E+04, -.11780900E+04, -.49991700E+03, 0.86266300E+03, -.43067100E+03, -.43242000E+03, -.13941200E+04, -.11428800E+04, 0.56267100E+02, -.51525600E+03, 0.24248600E+04, -.95052400E+02, 0.21748800E+04, -.10726200E+04, -.10950400E+04, -.14491300E+04, -.16197400E+04, 0.46969800E+03, 0.10369800E+04, -.48327700E+03, -.14374100E+04, -.28896500E+04, 0.14759900E+04, 0.13652500E+04, -.32964900E+04, -.80975200E+03, 0.24237200E+04, 0.19068200E+04, 0.56045100E+03, 0.46623400E+03, 0.97447600E+04, -.48270500E+04, -.49028400E+04, -.95209500E+03, -.65541400E+03, -.35399400E+04, -.31156200E+04, -.51985800E+04, -.14237900E+04, 0.62323800E+04, -.31116500E+04, -.31172200E+04, -.21846400E+04, -.26759000E+04, 0.29358900E+03, 0.31044900E+04, 0.85405700E+03, -.21515200E+04, 0.34974800E+04, -.17432700E+04, -.17510400E+04, 0.12525400E+04, 0.72561300E+03, -.95129900E+03, 0.18647300E+04, -.87795500E+03, -.64597600E+03, -.14827100E+05, 0.74217700E+04, 0.73979800E+04, 0.24637300E+04, 0.65628100E+04, 0.12807300E+04, -.61554700E+04, -.18223300E+04, 0.56241400E+04, -.49377300E+04, 0.24693200E+04, 0.23932500E+04, -.11952900E+03, 0.20274200E+04, 0.12118700E+04, 0.26077300E+03, -.75663400E+03, 0.49031300E+03, -.65376300E+04, 0.32208300E+04, 0.32664600E+04, 0.33959200E+03, -.53975900E+03, 0.26057200E+04, 0.27834100E+04, 0.35152200E+04, 0.12036800E+04, -.11653200E+05, 0.57857300E+04, 0.58855000E+04, 0.42943200E+04, 0.38768000E+04, -.94958100E+02, -.45236600E+04, 0.27595700E+03, 0.37702500E+04, 0.28813300E+04, 0.39952500E+04, 0.37271900E+04, 0.20499700E+04, -.28828400E+04, -.37679100E+04, 0.23227900E+03, 0.73582400E+03, -.40464600E+04, -.80535000E+04, -.13883000E+04, 0.18827400E+04, -.14602500E+04, -.37812000E+04, -.24479000E+04, 0.34178600E+04, -.31277700E+04, 0.17216800E+04, -.34264600E+04, 0.23717300E+04, -.38150000E+04, -.38427000E+04, 0.12126800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14644200E+01, -.10390200E+00, -.19095100E+01, -.42321900E+00, -.22718500E+00, 0.13480000E+00, -.15325400E+01, 0.26359700E+00, -.39942600E+00, 0.61872100E-01, 0.42360200E+00, -.53326600E+00, 0.21866600E+00, -.17559700E+01, 0.93240600E-01, -.61753500E+00, 0.81915400E+00, -.59200400E-01, -.20906200E-01, -.53100100E+00, -.42563000E+00, 0.14075900E+00, 0.10318100E+00, -.76819600E-01, 0.82200800E+00, 0.22042300E-01, -.94294800E+00, 0.12847800E+00, 0.12067700E+01, 0.57756700E-01, -.19982400E+00, -.64512700E+00, -.23924200E+04, -.68973000E+04, -.16614000E+04, 0.16736600E+04, -.75087600E+04, 0.37451700E+04, 0.37950400E+04, 0.21743100E+03, 0.71733100E+03, 0.26410100E+04, 0.15563100E+04, 0.13849700E+04, 0.13573900E+03, 0.16165000E+05, -.80315200E+04, -.81422200E+04, -.53043400E+04, -.11479900E+04, -.50508300E+04, -.24635200E+04, -.11098000E+04, 0.39007300E+02, -.26130200E+04, 0.13343200E+04, 0.13171600E+04, 0.27574800E+03, -.12249100E+03, -.44713100E+03, -.42975700E+04, -.60999900E+03, -.30860400E+03, 0.48536600E+04, -.23472300E+04, -.24409500E+04, -.25495900E+04, -.12352400E+04, 0.66456100E+03, 0.65212500E+04, 0.31764300E+04, -.20325200E+04, -.81857700E+04, 0.40279800E+04, 0.41544000E+04, 0.21520800E+04, 0.72417000E+03, 0.12246900E+04, -.48584400E+04, -.15833100E+04, 0.14592100E+04, -.56894400E+04, 0.28648800E+04, 0.28377500E+04, 0.67763500E+03, -.18016700E+04, 0.18529000E+04, -.29144400E+04, -.98425500E+03, -.23081100E+04, 0.18434400E+04, -.92483700E+03, -.10940400E+04, 0.20342300E+03, 0.85190900E+02, -.12197300E+04, 0.10407500E+04, 0.67043800E+03, 0.13222100E+04, 0.13625800E+05, -.67942600E+04, -.68837800E+04, -.30108700E+04, -.39675700E+03, -.42727600E+04, -.76456700E+02, 0.28467200E+03, -.78587000E+02, 0.23653300E+04, -.11776700E+04, -.11710600E+04, -.26398400E+04, -.75926900E+03, -.34960600E+03, -.14549600E+04, 0.14590700E+04, -.11135000E+04, 0.33725500E+04, -.16847400E+04, -.16791800E+04, -.79930600E+03, -.45082900E+03, -.97878200E+03, 0.14114600E+03, 0.41237900E+03, -.88721000E+02, 0.65162500E+04, -.32641900E+04, -.32349900E+04, -.34363800E+04, -.11479400E+04, -.23601600E+04, -.45145800E+03, 0.37285700E+03, -.58062200E+03, -.17294400E+04, 0.85969800E+03, 0.87017100E+03, -.25859100E+04, -.27254900E+04, 0.25565500E+04, 0.36789300E+04, 0.40651800E+04, -.47653300E+03, 0.54688200E+04, -.27307500E+04, -.28482100E+04, -.11320300E+04, -.26674200E+03, -.21096200E+04, -.19492400E+03, -.11059400E+03, -.51694600E+03, -.47313900E+02, 0.21125900E+02, 0.17637800E+02, 0.21873500E+04, 0.47016100E+03, -.16826600E+03, 0.17192200E+04, -.10262600E+04, 0.73295700E+03, -.12003300E+05, 0.59865700E+04, 0.59304800E+04, 0.25475600E+04, 0.69176300E+03, 0.40920400E+04, -.16165500E+04, 0.11691100E+03, -.18517800E+04, -.50041200E+04, 0.24957800E+04, 0.22319400E+04, 0.16934500E+04, -.21489700E+03, 0.16097100E+04, 0.24061100E+02, -.18171700E+03, -.13802400E+03, 0.57680000E+04, -.28728200E+04, -.28805500E+04, 0.76379900E+03, 0.20621900E+04, -.34081100E+04, -.28968100E+04, -.38095600E+04, -.85761200E+03, -.10468900E+05, 0.52399700E+04, 0.52796700E+04, 0.19191600E+04, -.68027800E+03, 0.34558500E+04, -.16457600E+04, -.12663500E+02, -.62917000E+03, 0.24351000E+04, 0.14849400E+04, 0.14522900E+04, -.22828200E+04, -.25738100E+04, -.14009700E+04, -.11685500E+04, 0.28925200E+04, -.38785300E+04, -.75662500E+04, 0.23376400E+04, -.20469000E+04, 0.15381800E+04, -.23964800E+04, -.52768500E+03, 0.85796100E+03, 0.76948800E+03, -.22109300E+04, -.25230300E+04, -.35613100E+03, -.11811900E+04, -.61413400E+03, -.40505600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15056200E+01, -.72850300E-01, -.12766600E+01, -.73279100E+00, 0.30252700E+01, 0.29848100E+00, -.23031400E+01, -.10811500E+01, -.36965600E+00, 0.82109500E+00, 0.74926000E+00, -.12503300E+01, 0.29889800E+00, -.15326900E+01, -.39998100E+00, 0.27617500E+00, 0.36003700E+00, -.30768200E+00, -.68149300E+00, 0.43219100E+00, 0.36242100E+00, 0.36263600E-01, -.32862400E+00, -.42661100E+00, 0.32259200E+00, -.30633100E+00, -.38900500E+00, -.16556000E+00, -.16198900E+00, -.69262900E+00, 0.12218900E+00, 0.66554200E+00, 0.15268900E+00, 0.48770400E+04, -.10196300E+04, 0.22248200E+04, 0.26877200E+03, -.13297600E+03, -.49017300E+02, -.11483000E+04, -.58325600E+03, 0.13586800E+03, 0.10578400E+04, -.70461200E+02, -.15584400E+04, 0.71952700E+04, -.33449400E+04, -.39589600E+04, 0.32314300E+04, -.41345600E+04, -.22789600E+04, -.65308000E+04, -.49519800E+04, -.74293400E+03, -.60047400E+03, 0.40310900E+03, 0.39610200E+03, -.11256700E+04, 0.26105300E+04, 0.89723700E+03, 0.20612500E+04, -.14213700E+04, 0.15506100E+04, -.18251400E+05, 0.86709100E+04, 0.95738100E+04, 0.15278000E+04, -.22321100E+04, 0.75424300E+04, 0.16187000E+04, 0.99718300E+04, -.14529500E+04, 0.90638600E+04, -.39956900E+04, -.44395500E+04, 0.10677100E+04, 0.59131500E+04, -.60624300E+04, -.31374400E+04, -.11830900E+05, 0.42952900E+04, 0.31656100E+04, -.15713000E+04, -.25635300E+04, -.56419400E+03, 0.68433100E+04, -.27359300E+04, -.44487500E+04, -.40422900E+04, 0.34532600E+04, 0.18245600E+05, -.91070800E+04, -.95919600E+04, -.37081700E+04, -.55979800E+04, -.38522500E+04, 0.19598100E+04, -.17818000E+04, -.37249300E+04, 0.66497000E+04, -.32151200E+04, -.30525000E+04, -.17133800E+04, -.80308700E+04, 0.20823200E+04, 0.27376800E+04, 0.46686100E+03, -.47503200E+04, -.37304500E+04, 0.18577200E+04, 0.19681800E+04, 0.37712200E+03, -.91175400E+03, 0.21241400E+04, 0.63460400E+04, 0.36644400E+04, -.12695900E+02, 0.26287600E+04, -.13397500E+04, -.13304400E+04, -.28036000E+03, -.19394700E+04, 0.13419800E+03, 0.19640300E+04, -.69921600E+02, -.10977100E+04, 0.88521000E+04, -.44595500E+04, -.37881100E+04, 0.10889600E+04, -.51709000E+04, -.14709700E+04, -.22206100E+04, -.32639900E+04, -.32871400E+04, 0.33531000E+03, -.21541500E+03, 0.44897200E+02, -.14664400E+04, -.32520800E+04, 0.33099500E+04, 0.84564700E+04, 0.27618100E+04, -.70665400E+03, 0.58117200E+04, -.29152400E+04, -.30273400E+04, -.13936500E+04, -.31492300E+04, -.17031000E+03, 0.17016000E+03, -.29281700E+03, -.25917500E+04, 0.26539700E+04, -.13183700E+04, -.13508500E+04, -.70047400E+03, 0.13668900E+04, -.21994700E+04, -.71422300E+04, -.38437000E+04, 0.44920100E+03, -.14508100E+05, 0.72046300E+04, 0.69965100E+04, 0.29484000E+04, 0.27111800E+04, 0.61072600E+04, 0.57939600E+04, 0.22964500E+04, -.11387900E+04, 0.50860500E+04, -.25325700E+04, -.24512000E+04, -.27809000E+03, -.32124300E+02, 0.11812100E+04, 0.59516100E+02, -.50357900E+03, -.17516800E+04, 0.51788100E+04, -.25803200E+04, -.25547700E+04, -.52775800E+02, -.88686200E+03, -.23271900E+04, -.57395200E+04, -.24217500E+04, -.29367800E+04, -.21275000E+03, 0.16232800E+03, 0.28993500E+02, 0.16785900E+04, 0.53498600E+04, -.12874600E+04, -.53876100E+03, -.39710300E+04, 0.31971600E+04, 0.27455700E+04, 0.36310100E+04, 0.37575300E+04, 0.16017600E+04, -.26517500E+04, -.38466300E+04, 0.36001100E+04, 0.31911200E+04, 0.12633300E+05, 0.10682000E+05, 0.31624600E+04, 0.18958700E+04, -.83417400E+03, -.68371500E+04, -.28313900E+04, -.66444600E+04, -.21502100E+04, 0.22244000E+04, -.77366900E+04, 0.40750900E+04, -.40107000E+04, -.46708400E+04, 0.15777000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10429200E+01, 0.54250300E+00, 0.14297600E+01, 0.27260300E+00, -.16036900E+01, 0.12599800E+00, 0.15949800E+01, 0.45005200E+00, 0.34871600E+00, 0.63224900E-01, -.86384500E+00, 0.37756400E+00, 0.10853800E+00, -.37749100E+00, 0.32859100E+00, -.23692500E+00, 0.68037300E+00, 0.43566900E+00, 0.41123300E+00, 0.60374900E-01, 0.79325000E-02, 0.10135800E+00, -.43459700E-01, 0.74026300E-01, -.16866400E+00, 0.13488000E+00, 0.46238300E-01, 0.37342500E-02, 0.12234700E+00, 0.11676800E+00, 0.15603500E+00, 0.10527800E+00, -.27424300E+00, -.13579300E+00, 0.29147400E+04, 0.91675400E+02, -.13344500E+04, 0.66803600E+03, 0.64010000E+03, -.50970200E+03, 0.34426500E+03, 0.32005200E+03, 0.16824300E+03, -.73817600E+02, -.43894900E+03, -.61850500E+04, 0.30449300E+04, 0.33833100E+04, 0.10709700E+04, 0.20736300E+04, 0.92598700E+03, -.38744100E+04, -.51814900E+04, 0.14549800E+04, 0.23621500E+04, -.13490400E+04, -.12012700E+04, -.20457100E+03, -.18548600E+04, 0.22375900E+02, 0.70533800E+03, 0.34572500E+04, -.20027100E+04, 0.52041300E+04, -.24209900E+04, -.28031500E+04, 0.98235300E+02, 0.27485400E+04, -.29414000E+04, -.35293900E+04, -.48911400E+04, 0.60860600E+03, -.23088800E+04, 0.88573000E+03, 0.12213700E+04, -.96266900E+03, -.31963600E+04, 0.24371600E+04, 0.42862600E+04, 0.46114200E+04, -.16064000E+04, 0.14774800E+04, -.82088600E+03, -.57484100E+03, 0.96475700E+03, -.15478900E+04, -.82339400E+03, -.18022000E+04, -.54369500E+03, -.68167600E+03, 0.46786300E+03, -.23942900E+03, -.30255200E+03, 0.37650400E+03, -.10872100E+03, -.40339900E+03, -.40901100E+03, 0.22499300E+04, 0.47852900E+03, -.94165200E+04, 0.47499100E+04, 0.48366700E+04, 0.59609300E+02, 0.25379100E+04, 0.31107000E+04, -.11022900E+04, -.13996500E+04, 0.13818600E+04, 0.64238800E+03, -.31899100E+03, -.35716300E+03, 0.10508100E+03, -.86958400E+03, 0.73142600E+02, 0.86097200E+03, 0.69206800E+03, -.40223800E+03, -.16092700E+04, 0.86357100E+03, 0.87798400E+03, -.14094700E+03, 0.75649700E+03, 0.45133200E+03, 0.41976900E+02, 0.62644000E+03, 0.47797000E+03, 0.28521700E+04, -.13327000E+04, -.15278400E+04, -.35885600E+02, 0.74086200E+03, -.13237600E+04, -.27249400E+04, -.25603000E+04, 0.15279900E+03, 0.78350000E+03, -.25605900E+03, -.44439500E+03, -.14662600E+04, 0.22399600E+04, -.14121500E+03, 0.95171500E+03, -.75412100E+02, 0.13268400E+04, -.29470900E+04, 0.14727400E+04, 0.14552600E+04, 0.93203600E+03, 0.81546100E+03, 0.57376400E+03, -.10390400E+04, 0.14895200E+04, 0.76820000E+03, 0.26893200E+04, -.13422400E+04, -.13367100E+04, -.11875900E+03, 0.59225200E+03, -.89468700E+03, -.36607900E+03, -.45415900E+03, -.12778100E+03, 0.84176200E+04, -.41716400E+04, -.43578600E+04, -.11875600E+04, 0.78550700E+02, -.22832800E+04, 0.92458900E+03, -.43408400E+04, -.13220200E+04, 0.46270100E+04, -.22982100E+04, -.26956000E+04, 0.35734700E+03, 0.68161600E+03, -.19567400E+04, -.18480900E+04, -.32724600E+04, 0.12572200E+04, -.18328600E+04, 0.78864600E+03, 0.90259900E+03, 0.16291400E+04, -.25254100E+04, 0.27516000E+03, -.19207600E+04, 0.35168800E+03, -.15785100E+04, 0.30447700E+04, -.15729600E+04, -.16115200E+04, -.10223500E+04, -.12958200E+04, -.57185400E+03, 0.56126600E+03, -.97750000E+03, -.84716200E+03, -.16676100E+04, -.79592300E+03, -.11421600E+04, -.29328400E+03, 0.16641700E+04, 0.70594200E+03, 0.48853000E+02, -.24052900E+04, -.34303600E+04, -.18981500E+04, -.13245400E+04, -.11908500E+02, 0.17342500E+03, 0.27667700E+03, 0.55884900E+03, -.77207500E+03, 0.54735800E+03, 0.45824600E+03, 0.30695500E+03, -.54215300E+03, 0.13221200E+04, 0.81316300E+02, 0.68932100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.55375700E+00, 0.44414300E+00, -.45312000E+00, -.16830100E+00, 0.20593400E+00, 0.20422500E-01, -.12089800E+01, -.51244000E+00, 0.39836500E+00, -.18663300E+00, 0.49195000E+00, -.57493000E-01, 0.22687100E+00, -.14532900E+00, -.56381700E-01, 0.21906400E+00, -.95445800E-01, 0.46617200E-01, 0.82068700E-01, 0.22817000E+00, -.21014800E+00, -.33496100E-01, 0.15464100E-01, 0.48213200E-01, 0.82340800E-01, -.43024200E-01, -.28517000E+00, -.22622800E-01, -.12776200E+00, -.11287300E+00, 0.84620600E-01, 0.12355300E+00, 0.87336800E-01, 0.10642500E+00, -.16917200E-01, -.14283200E+04, 0.38769500E+04, -.19348300E+04, -.19410600E+04, 0.63846200E+03, -.12690900E+03, -.17428300E+04, -.14950000E+04, -.16799800E+04, 0.53813300E+03, -.25445500E+04, 0.12487600E+04, 0.12759800E+04, -.89982500E+03, -.88214500E+03, 0.16209700E+04, 0.31906600E+04, 0.18795600E+04, -.21526000E+04, 0.10194600E+03, -.82421400E+02, -.51247300E+02, 0.18240200E+03, -.21990200E+03, -.29043000E+03, -.82423200E+03, -.24421000E+03, 0.49168900E+03, 0.36294500E+04, -.18214200E+04, -.18326700E+04, -.34398500E+03, -.55179100E+01, -.88456800E+03, 0.81363900E+03, -.79095900E+03, 0.52580900E+02, -.28431700E+04, 0.14120200E+04, 0.14157400E+04, 0.30839400E+03, -.58899400E+02, 0.68287300E+03, -.83720000E+03, 0.70280200E+03, -.54202900E+02, 0.69692700E+03, -.35027700E+03, -.32660600E+03, 0.14546100E+03, 0.34845700E+03, -.11127200E+04, -.29240800E+04, -.93371900E+03, 0.18068000E+04, -.88372200E+03, 0.44065500E+03, 0.49003800E+03, -.21466800E+03, -.96639600E+01, 0.45649400E+03, 0.49044500E+03, 0.28731200E+03, -.85964600E+03, -.95611200E+03, 0.47464900E+03, 0.46740900E+03, -.46233500E+02, -.36535600E+03, 0.87410600E+03, 0.25377300E+04, 0.10395100E+04, -.11814500E+04, 0.13346300E+02, -.54228400E+01, -.85534900E+01, -.34836800E+03, 0.33492400E+03, -.14304700E+03, 0.98043000E+02, -.39453400E+03, -.72368700E+02, -.14700000E+03, 0.88308100E+02, 0.75454500E+02, -.75908200E+02, 0.56512900E+02, 0.27762400E+03, 0.81529800E+03, 0.24662200E+03, -.55210500E+03, 0.15069400E+04, -.73643400E+03, -.75766100E+03, -.61353000E+03, 0.48191100E+03, -.40054100E+03, 0.67241000E+03, -.38593400E+03, -.33519700E+03, 0.57723100E+04, -.28508900E+04, -.28878500E+04, 0.19406600E+03, 0.80302100E+03, -.24863100E+04, -.14397800E+04, -.24776700E+04, -.16406400E+04, 0.81861400E+02, -.37532700E+02, -.31581300E+02, -.19815200E+03, 0.25660000E+02, 0.55693000E+02, 0.40072000E+03, 0.14266500E+02, 0.26882500E+03, -.15534200E+04, 0.77368200E+03, 0.77698800E+03, 0.32123000E+03, -.20780700E+03, 0.72469600E+03, 0.23133100E+03, 0.87539400E+03, 0.19005200E+03, 0.23817300E+04, -.11846100E+04, -.12046600E+04, 0.96497600E+03, 0.13405800E+04, -.16479600E+04, -.22094100E+04, -.16674800E+04, 0.32178400E+04, -.75256300E+03, 0.38031200E+03, 0.38030100E+03, -.44159600E+02, 0.64291500E+03, 0.13753500E+03, -.11280300E+03, 0.19327500E+03, 0.90431500E+03, -.17120100E+04, 0.83471200E+03, 0.85527200E+03, -.46106700E+03, -.10739700E+04, 0.72148200E+03, 0.23996400E+03, 0.69041900E+03, 0.18480900E+04, 0.42981100E+03, -.22644700E+03, -.21763800E+03, 0.31705800E+03, 0.37261900E+03, -.83003600E+03, -.22921600E+04, -.82649200E+03, 0.75357800E+03, -.16117200E+03, 0.26455900E+03, 0.44545500E+03, 0.10936900E+03, 0.22801200E+03, -.20576600E+03, -.81585900E+03, -.20419400E+03, -.16760300E+03, -.72183100E+03, 0.39187200E+03, 0.23016300E+02, 0.17246000E+02, -.80900200E+03, -.48993900E+03, 0.18909800E+04, -.34563200E+04, 0.24100600E+03, -.77581900E+03, -.47047400E+03, -.38256100E+03, -.24629000E+04, -.12870100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.39333600E+01, 0.45235000E+00, -.41957900E+01, -.14619500E+01, 0.44048800E+01, 0.48564300E+00, -.20034000E+01, 0.41156900E+00, 0.61988300E+00, 0.11288000E+01, 0.20725600E+01, -.21405300E+01, 0.22543800E+00, -.11842100E+01, -.43985600E+00, 0.57613500E+00, -.55187200E+00, -.28259500E+00, -.14856500E+01, -.12450100E+01, -.13906400E+01, 0.13526300E-02, 0.54336300E+00, 0.83510800E-01, 0.14695900E+01, -.26052400E+00, -.24337100E+01, 0.14785100E-01, 0.12936100E+01, -.32582700E+00, 0.18136300E+00, 0.86132800E+00, 0.74103800E+00, 0.26196600E+00, 0.24149200E+00, -.59793400E+00, -.18839400E+05, 0.93991900E+04, 0.94675600E+04, -.12253400E+04, 0.19872400E+04, 0.73330200E+04, 0.55866800E+04, 0.44417600E+04, 0.73239100E+02, 0.98792500E+04, -.49299000E+04, -.53145100E+04, 0.12298900E+04, -.10682700E+04, -.54769700E+04, -.69792500E+04, -.16000400E+04, -.21535700E+04, -.15090500E+04, 0.74830000E+03, 0.80922500E+03, 0.53170500E+02, 0.13359100E+04, -.30963200E+03, -.16247200E+04, -.79614500E+03, -.20638300E+04, -.32287700E+04, 0.13340200E+04, 0.16545200E+04, 0.27859900E+03, 0.11200100E+04, 0.79028300E+02, -.63296500E+03, 0.19999100E+04, -.10298300E+04, -.14391100E+03, 0.36627700E+03, 0.30099100E+03, -.10187100E+04, -.14676800E+04, 0.20313300E+04, 0.30034900E+04, -.63114600E+03, 0.37908200E+03, 0.88162000E+03, -.43309900E+03, -.87927900E+03, 0.36267400E+03, 0.64816200E+03, -.10455900E+04, -.46388200E+04, -.32164600E+04, -.15945400E+04, 0.35896400E+04, -.17917400E+04, -.20924900E+04, -.35865400E+03, -.41950900E+03, -.11959800E+04, 0.25500700E+04, -.52791700E+03, 0.17495600E+04, -.19287800E+04, 0.96054200E+03, 0.83598000E+03, -.11378700E+03, 0.31551000E+03, -.66582200E+02, 0.18277200E+04, 0.38434000E+04, -.13086800E+04, 0.60752700E+04, -.30244800E+04, -.29849200E+04, -.17290200E+04, -.24116500E+04, -.16935800E+04, -.75885100E+04, 0.24380800E+04, -.41914100E+04, 0.24057700E+04, -.11842500E+04, -.12598300E+04, -.71783600E+03, -.97176600E+03, -.24188600E+03, 0.10828100E+04, 0.97801900E+03, -.86667000E+03, 0.31605600E+04, -.15696200E+04, -.13113900E+04, 0.12266400E+04, 0.30237100E+03, -.34210900E+04, -.32499100E+04, -.18730300E+04, -.14274700E+04, -.14706800E+05, 0.73705100E+04, 0.74662400E+04, -.43217700E+04, -.21292300E+04, 0.94861000E+04, 0.96479400E+04, 0.10514800E+05, 0.72270800E+03, 0.59294800E+04, -.29549300E+04, -.30496700E+04, 0.35376400E+02, 0.10391900E+03, -.31886800E+04, -.25018400E+04, -.15749500E+04, -.17981900E+04, 0.31686100E+04, -.15874900E+04, -.15945400E+04, 0.10283500E+04, 0.11905600E+04, -.97484300E+03, 0.73578900E+04, -.28494100E+04, 0.25010900E+04, -.42844400E+04, 0.21310300E+04, 0.22548900E+04, 0.20935300E+04, 0.23171500E+03, 0.17229600E+04, -.26085600E+04, -.90556200E+03, -.33232300E+04, 0.38695300E+04, -.19283600E+04, -.16378100E+04, 0.34379300E+04, 0.91998500E+03, -.33665500E+04, -.38794400E+04, -.48617700E+04, 0.27425000E+04, 0.71111800E+04, -.35612200E+04, -.35333800E+04, 0.30630900E+04, 0.17968400E+04, -.63284300E+04, -.72176800E+04, -.76947100E+04, -.30666600E+04, -.43242600E+04, 0.21426900E+04, 0.22078200E+04, -.55314600E+03, -.62413900E+03, 0.34406600E+04, 0.27732800E+04, -.11979700E+03, 0.33606200E+02, 0.59511800E+03, 0.29380600E+04, 0.23383800E+04, -.18389500E+04, -.49463000E+03, -.27388100E+04, -.33364200E+03, 0.13738800E+04, 0.12963800E+04, 0.20510600E+04, 0.19194500E+04, -.17095500E+04, 0.11448300E+04, -.27283400E+04, -.10948000E+04, -.28974300E+04, -.22345900E+03, -.23015400E+04, -.43692600E+04, -.20392700E+02, -.14891000E+04, -.16739100E+04, -.55090000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18595200E+01, 0.53352000E+00, -.22838800E+01, -.55258700E+00, -.18730900E+01, 0.10278800E-01, -.99339700E+00, 0.99161300E+00, -.64440500E+00, 0.39859900E-01, -.13181500E+01, -.47560300E+00, 0.30655200E+00, -.15813300E+01, 0.59576200E+00, -.98827700E+00, 0.93871800E+00, -.23560300E+00, -.49890700E+00, -.12820100E+01, -.16568200E+01, 0.44898800E+00, 0.20718400E-02, -.33501800E+00, 0.10782600E+01, -.15143300E+00, -.16892200E+01, 0.52288600E+00, -.11019700E+01, 0.26868500E+00, 0.47712700E+00, 0.62855100E+00, 0.66724200E+00, -.36740200E+00, 0.34310600E+00, -.13855300E-01, 0.70841400E-01, 0.14470400E+02, 0.64098700E+02, -.86374300E+02, 0.17322000E+03, -.37386500E+03, -.74567900E+03, -.17266500E+04, -.55201000E+02, -.31336800E+04, 0.18024800E+04, 0.87938300E+03, 0.29573400E+03, -.34023100E+04, 0.22594100E+04, -.16961900E+04, 0.17477700E+04, -.37732400E+04, 0.39192300E+03, -.34098200E+03, -.78273300E+02, -.62230400E+02, 0.49428400E+02, -.44113300E+03, -.16087400E+04, -.74880500E+02, 0.24255700E+03, 0.31846100E+04, -.13631200E+04, -.10948500E+04, 0.37794100E+03, 0.21556900E+04, -.20021500E+04, -.41719900E+04, -.12961700E+04, 0.38774400E+03, -.44246400E+04, 0.19492100E+04, 0.20430100E+04, 0.26572800E+03, -.64915100E+03, 0.15789800E+04, 0.34870300E+04, -.13487600E+02, 0.66793000E+03, 0.11110300E+04, -.96703300E+03, -.14421100E+04, 0.15984500E+04, 0.27917100E+04, -.36132400E+04, -.72545500E+04, -.34744100E+04, 0.34677200E+04, 0.11713400E+05, -.58483300E+04, -.54354700E+04, -.21618200E+04, -.31896600E+04, -.17684500E+04, 0.14311800E+04, -.48322400E+03, -.32437200E+04, -.52267000E+04, 0.29771600E+04, 0.25560800E+04, -.19503000E+04, -.38023200E+04, 0.56205000E+04, 0.36472600E+04, 0.49002100E+04, -.41014300E+04, -.25725100E+04, 0.12805800E+04, 0.14115800E+04, 0.10964500E+03, -.79193900E+03, 0.11123700E+04, 0.36359900E+04, 0.29319800E+04, -.60747400E+03, -.99225900E+03, 0.50343100E+03, 0.38019100E+03, -.41369000E+03, -.37940000E+03, 0.97501200E+03, 0.14726900E+04, 0.10079600E+04, -.68192800E+03, 0.61866700E+04, -.30349700E+04, -.23634500E+04, -.13756900E+04, -.29338900E+04, -.52729500E+03, -.14551300E+04, -.18103000E+03, -.34372500E+04, -.11818100E+03, 0.12920800E+03, 0.31806400E+03, -.12416900E+04, 0.18793600E+04, 0.46698000E+03, 0.25962800E+04, -.13313300E+03, 0.66108300E+03, 0.64911500E+03, -.35170100E+03, -.21319300E+03, -.65250700E+03, -.10331400E+04, 0.69513600E+03, 0.57194200E+01, 0.13740400E+04, -.11058700E+04, 0.62306000E+04, -.30943100E+04, -.31418100E+04, -.39055700E+03, 0.60043900E+03, -.21272700E+04, -.30829400E+04, -.24665600E+04, 0.42733600E+02, -.16849900E+04, 0.92037200E+03, 0.71775400E+03, 0.17738300E+04, 0.33074500E+04, -.24196000E+03, 0.12453200E+04, -.27347300E+04, 0.29516600E+04, 0.51475300E+04, -.25735300E+04, -.16600700E+04, -.56922300E+03, 0.12196500E+04, -.12061900E+04, -.14135200E+04, -.22763500E+04, 0.69172400E+03, 0.14847300E+04, -.90613300E+03, -.69922600E+03, 0.11417900E+04, -.31686700E+04, -.78188400E+03, -.39303200E+04, -.28516400E+03, -.18238400E+04, 0.24953800E+04, -.13772500E+04, -.12461800E+04, 0.99304300E+03, 0.24609700E+04, -.24552300E+04, -.28843000E+04, -.41161200E+04, 0.26507500E+04, -.95564800E+02, 0.17137200E+04, 0.13545400E+04, 0.86787000E+03, -.34545000E+02, -.16625300E+04, 0.28567100E+03, 0.12580800E+03, 0.15079400E+04, 0.11740100E+04, 0.96922800E+03, 0.93492500E+03, -.30373100E+02, -.39571600E+04, -.15582500E+04, -.45422300E+03, -.33564000E+04, 0.19755000E+04, -.47500300E+04, 0.12228000E+04, -.14610500E+04, -.35673800E+04, 0.18658200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13715700E+01, -.12228700E+00, 0.68526000E-01, -.22552900E-01, -.14989500E+01, 0.26831200E+00, 0.41640300E+00, 0.29265200E+00, -.24786700E-01, -.20111700E+00, 0.29199500E+00, 0.11802200E+00, 0.40440000E-01, 0.13995000E+00, -.25291200E+00, -.70425200E-01, 0.12864700E+00, 0.12937500E+00, 0.14890100E+00, -.58570200E-01, -.21209000E+00, -.14297400E+00, 0.23707400E+00, 0.71515700E-01, 0.19412100E+00, -.13361700E+00, -.77139800E-01, -.12684500E+00, 0.72098100E+00, -.42672900E+00, -.26070000E-01, -.29644100E+00, -.14422000E+00, 0.18883700E-02, -.11372300E+00, -.23404500E+00, 0.16156300E+00, -.25852000E+00, 0.45527900E+02, 0.82325100E+01, 0.32207400E+02, -.51358000E+02, -.49314000E+03, -.17362700E+03, -.12296200E+03, -.74314800E+03, 0.27685200E+03, -.51613100E+02, -.26237300E+04, -.87652800E+03, 0.16014000E+04, 0.22628000E+04, 0.28386100E+04, -.11763700E+03, 0.44622600E+03, -.27982600E+03, -.15915200E+03, 0.30705400E+03, -.23545000E+03, -.16206300E+03, 0.26454400E+03, -.10137000E+02, -.71620200E+02, -.22372200E+04, 0.10386600E+04, 0.16086300E+04, -.23140700E+04, -.30533400E+04, 0.29107300E+04, 0.33487800E+04, 0.36695400E+04, -.21907200E+04, 0.10980100E+04, -.49951900E+03, -.91320700E+03, 0.26094400E+04, 0.34370300E+04, -.28709200E+04, -.34541300E+04, -.32292800E+04, 0.23712300E+04, -.59078500E+04, 0.28938200E+04, 0.24561500E+04, 0.36118300E+04, 0.22726200E+04, -.47218400E+03, -.64867400E+03, 0.54972000E+03, 0.23726100E+04, 0.45118000E+04, -.22494700E+04, -.16010300E+04, -.18211300E+04, -.24103000E+04, 0.38921200E+03, 0.12441100E+04, 0.46554100E+03, -.20951900E+04, 0.58588800E+04, -.29199800E+04, -.29239100E+04, -.42480100E+04, -.28442500E+04, 0.98555000E+03, 0.14573600E+04, 0.14068900E+04, -.23841800E+04, 0.10761300E+04, -.52968000E+03, -.45827900E+03, 0.97651300E+02, 0.13028000E+03, -.44748800E+03, 0.75420400E+03, -.68014400E+03, 0.26598900E+03, 0.11045800E+04, -.51643600E+03, -.61358300E+03, -.87554300E+03, -.43932900E+03, 0.17849800E+03, 0.19577900E+03, 0.13286700E+03, -.40711200E+03, 0.33272900E+04, -.16396700E+04, -.11662200E+04, -.23745500E+04, -.15182400E+04, 0.53567200E+03, 0.82101000E+03, 0.12323100E+04, -.11304700E+04, 0.84350100E+03, -.34741500E+03, -.26829700E+03, -.61499500E+03, 0.11177300E+03, -.16387200E+02, -.58391200E+01, -.10965100E+03, -.34456800E+03, 0.23885600E+04, -.11837100E+04, -.10664300E+04, -.15846400E+04, -.16671000E+04, 0.65027300E+03, 0.12940000E+04, 0.59825500E+03, -.10981100E+04, -.14686500E+03, 0.66272200E+02, 0.52220800E+02, -.23137600E+03, -.26062300E+03, 0.22128600E+03, -.40938400E+03, 0.62137000E+03, -.34951200E+03, -.20925100E+04, 0.10711800E+04, 0.77013000E+03, 0.22835400E+04, 0.24844700E+04, -.11026200E+04, -.21068800E+04, -.19529900E+04, 0.16262600E+04, 0.17371700E+03, -.83736100E+02, 0.42681800E+03, 0.32382400E+01, -.32737700E+03, 0.14936200E+03, -.35574100E+03, -.22524800E+03, -.11629300E+03, -.21639700E+03, 0.67590700E+02, 0.13278200E+03, 0.36481100E+03, -.55321100E+03, 0.22417100E+03, 0.11958500E+03, 0.80246200E+03, 0.14900900E+03, -.60139700E+04, 0.29327000E+04, 0.30160000E+04, 0.31931800E+04, 0.19271100E+04, -.32502800E+02, -.12693600E+04, 0.72786400E+03, 0.15354500E+04, 0.17394600E+04, 0.12600000E+04, 0.11876200E+04, 0.58389500E+03, -.16532000E+04, -.12703100E+04, -.34689300E+03, 0.14495100E+04, -.17159600E+04, -.47191200E+04, -.58947100E+03, 0.59956000E+03, -.32610400E+03, -.11439900E+04, -.10020200E+04, 0.15221000E+04, -.16515400E+04, 0.10349900E+04, -.93182300E+03, 0.74518400E+03, -.11874700E+04, -.14999400E+04, 0.15716900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21409800E+01, 0.55779200E+00, 0.21903100E+01, 0.69566900E+00, 0.17755500E-01, -.28274500E+00, 0.24178100E+01, 0.14677300E+01, -.11752700E+01, -.49955000E-01, -.15684100E+00, 0.64825700E+00, -.17161000E+00, 0.16451400E+01, -.10252700E+00, -.34088800E+00, 0.14386400E+00, -.10339300E+00, 0.44622600E+00, -.10039700E+01, -.41124400E+00, 0.16742300E+00, -.70964500E-01, -.41871600E+00, 0.53450800E+00, 0.30622200E-01, -.36326500E+00, 0.97002900E-01, 0.63822300E+00, 0.20067300E+00, 0.46457100E-02, -.57233900E+00, -.44531400E-01, -.23616600E+00, 0.28372600E+00, -.29103500E-01, 0.29989400E+00, -.14112600E+00, 0.50131500E+00, -.45822500E+03, 0.25223300E+02, 0.30876200E+03, 0.11009900E+04, 0.15876400E+04, -.46227400E+03, 0.88548100E+04, -.44458100E+04, -.43030900E+04, 0.15820900E+04, -.68852400E+03, -.30078500E+04, -.17209200E+04, -.28983200E+04, -.10790800E+04, -.82212500E+03, 0.38311700E+03, 0.38304800E+03, -.24093100E+03, -.11412100E+02, 0.52624300E+03, 0.40599500E+03, -.19255200E+03, -.27752800E+03, 0.24869000E+04, -.88452600E+03, -.13493100E+04, 0.37103000E+03, 0.89027100E+03, -.15740200E+04, -.27703000E+04, -.25392100E+04, 0.45326200E+03, -.12857000E+04, 0.25151300E+03, 0.77865100E+03, -.85169100E+03, -.14293700E+04, 0.15268200E+04, 0.32416500E+04, 0.35591800E+04, -.10437100E+04, -.97014800E+03, 0.49017100E+03, 0.67392200E+03, -.38594500E+03, 0.83885800E+03, 0.80649600E+03, 0.31829400E+04, 0.43895600E+03, -.16645300E+03, -.47045900E+04, 0.23415700E+04, 0.19062400E+04, 0.39900500E+03, 0.79467100E+03, 0.11274300E+04, -.12506400E+04, 0.36568800E+03, 0.12371500E+04, 0.44690300E+04, -.22464800E+04, -.22850000E+04, 0.88653100E+03, -.12293600E+04, -.16552600E+04, -.29806000E+04, -.21818200E+04, -.50350200E+03, 0.22296100E+04, -.11124100E+04, -.11352000E+04, 0.75899900E+03, 0.21589000E+03, -.71688200E+03, -.28713300E+03, -.20654800E+04, -.47775800E+03, 0.60803900E+02, -.32043800E+02, -.41952300E+02, 0.24037500E+03, -.34058500E+03, -.14033000E+03, -.99062500E+03, 0.49947900E+02, 0.41328200E+02, 0.31729100E+04, -.15999600E+04, -.18635500E+04, 0.54515100E+03, -.17978800E+04, -.39584200E+03, -.78211700E+02, 0.28856400E+02, -.16576600E+04, -.74518800E+04, 0.37158200E+04, 0.36545900E+04, -.10189000E+03, -.78403200E+03, 0.31848000E+04, 0.12358600E+04, 0.42988400E+04, 0.21188200E+03, -.55844300E+03, 0.27700400E+03, 0.18453200E+03, 0.71572900E+03, -.79777700E+01, -.60348100E+02, -.14848000E+04, -.98713800E+03, 0.14162300E+03, -.31344700E+04, 0.15617400E+04, 0.15743500E+04, -.73883200E+03, -.52028700E+03, 0.10361600E+04, 0.32149400E+02, 0.13781700E+04, 0.54947600E+03, 0.53858700E+04, -.26759200E+04, -.24146300E+04, -.20449500E+04, -.28920200E+04, -.31916200E+03, 0.38059400E+04, 0.20976400E+04, -.28988900E+04, -.27952400E+03, 0.14165300E+03, -.34931300E+02, -.16382200E+03, -.67472000E+03, 0.28531200E+03, 0.17482400E+03, 0.73278400E+02, 0.42876300E+02, 0.34893000E+04, -.17298900E+04, -.17507200E+04, 0.39882700E+03, 0.10866500E+04, -.14298000E+04, -.54008400E+03, -.16934000E+04, -.57135000E+03, -.49949600E+03, 0.25358800E+03, 0.31378700E+03, -.12236400E+04, 0.47056500E+03, 0.64165700E+03, 0.27700300E+04, 0.27889500E+04, -.24022900E+03, -.38067300E+03, -.40061700E+03, -.27438400E+03, 0.92344800E+03, 0.31256100E+03, 0.23614300E+03, 0.19899900E+04, -.53515900E+02, 0.41645300E+03, 0.15903900E+04, -.46114700E+03, 0.91579400E+03, -.66814400E+03, 0.10117100E+04, 0.49611800E+03, -.31001300E+04, 0.11265000E+04, -.19626200E+03, 0.90007800E+03, 0.58462400E+03, 0.38494400E+03, 0.15632800E+04, -.83132600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.30805300E+00, -.50038000E-01, -.80214300E+00, 0.35400700E+00, -.22307500E+01, 0.10271300E+01, 0.44750800E+00, -.16468400E+00, 0.14287000E+00, -.92912600E-01, -.25952900E+00, 0.25862800E+00, -.11077900E+00, 0.35549100E+00, 0.59273100E-01, 0.14774200E+00, -.25560500E+00, 0.13551300E-01, 0.77604400E-01, -.55287700E-03, 0.29184000E+00, 0.15490600E+00, -.51244000E-01, -.92368100E-03, -.10817900E+00, 0.12147300E+00, 0.51588600E+00, -.13313600E+00, -.91646400E+00, 0.24356300E+00, -.34342800E-01, 0.13973000E+00, -.26011900E+00, -.21599000E+00, -.19787000E-01, -.54836800E+00, -.72893000E-02, 0.14721100E+00, 0.24177200E+00, 0.11999800E+00, -.21553100E+03, 0.15069800E+03, 0.67012000E+03, -.24192500E+03, -.26367400E+03, -.43327000E+04, 0.21932800E+04, 0.20809000E+04, -.48469900E+03, -.52500600E+03, 0.19834200E+04, 0.30748900E+04, 0.29327200E+04, -.31018400E+03, -.62007300E+03, 0.33186800E+03, 0.31117600E+03, -.37168700E+02, 0.42313700E+03, -.13055400E+02, -.11850500E+04, 0.42130600E+02, 0.37091800E+03, 0.12661400E+04, -.75862800E+03, -.62893200E+03, 0.28420800E+03, 0.65485000E+03, -.19892000E+03, 0.24998100E+04, 0.44933600E+03, -.73277000E+02, -.22613900E+04, 0.12781100E+04, 0.11631600E+04, -.11678100E+03, -.33026400E+03, 0.51708500E+03, -.28110700E+04, -.11785100E+04, 0.25630300E+03, 0.32741200E+04, -.16210600E+04, -.16965800E+04, -.16639400E+04, -.61896000E+03, -.66230600E+03, -.51042500E+04, -.69721100E+03, 0.30676500E+02, 0.20029200E+04, -.99817300E+03, -.10281700E+04, 0.42034300E+03, 0.23680300E+03, -.90097400E+03, 0.10879300E+04, -.95523200E+03, 0.12753700E+03, -.56271100E+04, 0.28143200E+04, 0.27688300E+04, 0.14628600E+04, 0.13064100E+04, 0.11469800E+04, 0.44103300E+04, 0.21488000E+04, 0.65834800E+03, -.37006400E+04, 0.18448400E+04, 0.18540900E+04, -.10130200E+04, 0.29198100E+03, 0.13280100E+04, 0.10318300E+04, 0.26321900E+04, 0.83824800E+03, 0.26252400E+03, -.13326600E+03, -.15181200E+03, 0.24067900E+03, 0.14875000E+03, -.33527300E+02, 0.14241300E+04, -.48521600E+02, -.16145700E+03, 0.23260200E+03, -.10533800E+03, -.91583600E+02, -.51173600E+02, 0.14098900E+04, -.74536500E+03, 0.60749300E+03, -.69457000E+03, 0.90262300E+03, 0.48335400E+04, -.24156700E+04, -.24061900E+04, -.15230900E+03, 0.63653100E+03, -.16806400E+04, 0.10410600E+04, -.19135100E+04, 0.10515700E+03, 0.91356600E+03, -.45751500E+03, -.45389900E+03, -.16670100E+03, 0.34703400E+03, -.45393100E+03, 0.10061100E+04, 0.55376900E+02, 0.83936600E+02, 0.30195400E+04, -.15037300E+04, -.15095900E+04, 0.11063100E+04, 0.95785400E+02, -.11756400E+04, -.11932600E+04, -.21960400E+04, -.58854800E+03, -.32537800E+04, 0.16156300E+04, 0.17211400E+04, 0.88509000E+03, 0.16858700E+04, -.51491400E+01, -.36515800E+04, -.97996000E+03, 0.11714900E+04, -.24692100E+03, 0.12833100E+03, 0.27679100E+03, 0.43056200E+03, 0.84766700E+03, -.55215800E+03, -.16883000E+04, -.91889600E+03, 0.56925400E+03, -.19033800E+04, 0.94588900E+03, 0.95490800E+03, -.74043500E+03, -.11371800E+04, 0.81763200E+03, -.80755400E+03, 0.64149500E+03, -.26623400E+03, 0.13606600E+04, -.66436000E+03, -.65287700E+03, -.35581400E+03, -.16318100E+03, -.57860800E+03, -.40601000E+04, -.25111700E+04, 0.21251000E+03, -.27147900E+03, 0.43316500E+03, 0.39287000E+03, -.74217900E+03, 0.38265700E+03, -.39722400E+03, -.17144600E+04, -.27617400E+03, 0.15965800E+04, 0.13998800E+04, 0.15831200E+04, -.79245100E+03, 0.58011400E+03, -.13094700E+04, -.43087800E+03, 0.24075700E+04, -.96136300E+03, -.26000100E+03, -.13735600E+04, -.43561900E+03, -.27396700E+03, -.15634900E+04, -.73136200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.54285200E+01, 0.77161000E+00, -.56761700E+01, -.22099600E+01, 0.66137600E+01, 0.20621500E+00, -.45792600E+01, -.87695000E+00, 0.10372800E+00, 0.24077100E+00, 0.51871700E+01, -.25845400E+01, 0.73690700E+00, -.15860800E+01, -.83782800E+00, 0.10018100E+01, -.35882800E+00, -.15126400E+00, -.14778000E+01, -.29437900E+01, -.49661300E+01, 0.25286500E+00, 0.60041900E+00, 0.14390200E+00, 0.17531800E+01, -.35031100E+00, -.94646900E+00, -.18626200E+00, 0.10906800E+01, -.13909600E+01, 0.41272100E+00, 0.18399200E+01, 0.74025000E-01, -.36877100E+00, -.13869600E+01, 0.60730800E+00, 0.89228800E+00, -.23684400E+01, 0.48148400E+01, -.13823800E+01, 0.17891200E+01, -.11031600E+04, -.40931900E+03, -.36296800E+04, -.19957500E+03, 0.13572000E+05, -.63595700E+04, -.70993600E+04, 0.14775800E+05, -.15573700E+05, -.29702200E+04, -.14439600E+05, -.11578300E+05, -.16820200E+05, -.35638800E+04, 0.18052300E+04, 0.18820800E+04, -.42742000E+04, 0.37287900E+04, 0.61759100E+03, -.59945000E+04, -.84588400E+02, 0.82977000E+03, 0.32907100E+05, -.13731400E+05, -.17002900E+05, 0.13859500E+05, 0.24949400E+05, -.24834200E+05, -.30836800E+05, -.25044300E+05, 0.14591400E+05, -.33973600E+05, 0.14277300E+05, 0.18032900E+05, -.12243200E+05, -.20745300E+05, 0.23405800E+05, 0.28603000E+05, 0.19545200E+05, -.10621500E+05, 0.36053400E+05, -.18731300E+05, -.18623800E+05, -.16220200E+05, 0.50794300E+04, -.11815000E+05, -.22171100E+05, -.20889700E+05, 0.40067600E+03, 0.16074200E+05, -.80410200E+04, -.96829900E+04, 0.15759200E+04, 0.13214100E+04, -.73040100E+04, -.25508000E+04, -.14205900E+04, -.26905600E+03, -.32490200E+05, 0.16808000E+05, 0.15980600E+05, 0.13959000E+05, -.92280500E+04, 0.14108200E+05, 0.75857200E+04, 0.10822800E+05, -.82313900E+04, -.22640900E+05, 0.11277500E+05, 0.11379900E+05, 0.15245100E+04, -.17954800E+04, 0.88423000E+04, 0.12803800E+05, 0.12935100E+05, -.98950200E+03, -.10100200E+05, 0.48265600E+04, 0.48987200E+04, 0.42703000E+04, -.55816800E+03, 0.29596900E+04, 0.39958300E+04, 0.45116700E+04, -.10896400E+03, 0.93300300E+04, -.48623100E+04, -.46190500E+04, 0.59165000E+04, -.10252300E+05, -.20061400E+04, -.54490000E+04, -.25914200E+04, -.10913800E+05, -.19159700E+05, 0.92438100E+04, 0.97264800E+04, 0.41516600E+04, 0.42848100E+04, 0.69655200E+04, 0.12227600E+05, 0.72775900E+04, 0.67376800E+04, -.84787600E+04, 0.41268300E+04, 0.40603900E+04, 0.48765400E+04, 0.37396900E+04, -.55409400E+03, -.66572700E+04, 0.25664400E+04, 0.41712000E+03, 0.28646400E+05, -.14258500E+05, -.14311300E+05, -.17642900E+04, 0.16160900E+04, -.10383100E+05, -.12059200E+05, -.11418600E+05, -.22581800E+03, -.77435400E+04, 0.40576900E+04, 0.49240600E+04, -.80350700E+04, -.44782000E+04, 0.10275700E+05, 0.20870700E+05, 0.46511700E+04, -.16217100E+04, 0.20665000E+05, -.10352000E+05, -.94862800E+04, -.32752700E+04, 0.52594500E+04, -.51468700E+04, -.30814900E+04, -.78769100E+04, 0.67079600E+03, 0.10288700E+05, -.50677500E+04, -.51119900E+04, -.33774000E+04, -.57505700E+04, -.46863400E+04, -.15814000E+05, -.59664800E+04, -.98208100E+04, 0.38247000E+05, -.19180700E+05, -.19134600E+05, -.13631800E+05, 0.46224000E+04, -.10232200E+05, -.61985100E+04, -.20073200E+05, 0.33511900E+04, -.92523300E+04, 0.71520700E+03, -.79951700E+03, 0.12043500E+04, 0.82963800E+04, -.73592100E+03, 0.59172200E+04, -.55069300E+04, 0.18869400E+05, 0.32072300E+05, 0.10743800E+05, 0.16282400E+04, 0.11687800E+04, -.88005900E+04, -.13327800E+04, -.11597600E+05, -.53473300E+03, 0.32784800E+04, -.11929200E+05, 0.30391200E+04, -.68514700E+02, -.21624300E+04, -.22007400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.28932200E-01, 0.22489100E-01, 0.11367100E+01, -.30124400E-02, 0.55329700E+00, -.67252300E-02, -.32734700E+00, 0.18634000E+00, -.66594700E-01, 0.65834600E-01, 0.27402200E+00, -.23944000E+00, 0.99007700E-01, -.10024900E+00, -.72255900E-01, 0.36440600E-01, 0.62740100E-02, -.58365200E-01, -.18725800E+00, -.67047500E-01, -.47730500E+00, -.94354300E-03, -.43670100E-01, -.10019000E+00, 0.18092800E+00, -.90664900E-01, -.25515300E+00, 0.86109800E-01, 0.28825100E+00, -.23405400E-01, 0.59939300E-01, 0.26126400E+00, -.14163600E-01, -.38411000E-01, -.13295000E+00, 0.66765000E-02, 0.44363000E-01, 0.65492400E-01, -.55047100E+00, -.20333300E+00, -.66628600E+00, -.85917000E-01, 0.58778600E+03, 0.75915300E+02, -.27664700E+03, 0.70648400E+04, -.34776800E+04, -.36321000E+04, 0.61273600E+03, -.28000400E+04, -.14966500E+04, -.17022700E+04, -.30608500E+04, -.28345200E+04, -.11507800E+04, 0.57437500E+03, 0.60416400E+03, -.40191300E+03, 0.63816000E+03, 0.27353800E+03, -.12923400E+04, -.16891100E+03, 0.20110000E+03, 0.18702600E+04, -.69954600E+03, -.86218200E+03, 0.99456200E+03, 0.20599300E+04, -.14071400E+04, -.16972400E+04, -.71579200E+03, 0.84428700E+03, -.32278500E+04, 0.13808100E+04, 0.16292700E+04, -.65161300E+03, -.12946000E+04, 0.15775800E+04, 0.15661500E+04, 0.31330500E+03, -.30611300E+03, 0.32348000E+04, -.16834300E+04, -.18673700E+04, -.10634000E+04, 0.14334400E+04, -.17001700E+04, -.46741200E+04, -.36411300E+04, 0.68905700E+03, 0.35000800E+04, -.17484600E+04, -.17359200E+04, -.51048700E+03, -.74118600E+03, -.79824100E+03, 0.35894400E+03, 0.51533700E+03, -.46874600E+03, 0.74040000E+03, -.30622700E+03, -.31945200E+03, 0.31337500E+03, -.23762600E+04, 0.11710700E+04, 0.19853200E+04, 0.76827100E+03, -.20199500E+04, -.25676200E+04, 0.12801600E+04, 0.13088900E+04, -.22615500E+02, -.10790000E+03, 0.10751100E+04, 0.26789900E+04, 0.13263700E+04, -.13340900E+02, -.11026200E+03, 0.41238600E+02, 0.36271000E+02, 0.18654100E+03, -.34246000E+03, 0.24864700E+03, 0.95760000E+03, 0.71951100E+03, -.27107000E+03, 0.67745300E+04, -.33943100E+04, -.32148800E+04, -.22659100E+03, -.20410600E+04, -.15221100E+04, -.10322200E+04, -.15829200E+04, -.22816200E+04, -.11384600E+04, 0.55262800E+03, 0.63351200E+03, -.29689700E+03, 0.35553700E+02, 0.11632000E+04, 0.33574100E+04, 0.18793300E+04, 0.32548700E+03, 0.52511100E+03, -.27163500E+03, -.22140400E+03, 0.11757100E+03, -.23343700E+02, -.24788300E+03, -.91988500E+03, 0.18991500E+03, -.18420300E+03, 0.25782200E+04, -.12836300E+04, -.12920800E+04, -.94629600E+02, 0.13281500E+03, -.10683500E+04, -.27653500E+04, -.13633200E+04, 0.12707300E+02, -.17760400E+04, 0.90489700E+03, 0.88186600E+03, 0.34281800E+03, 0.35293100E+03, 0.97014900E+03, 0.23232500E+04, -.45493200E+03, -.21400200E+03, 0.19225000E+04, -.95756800E+03, -.71733200E+03, 0.65767200E+02, 0.70516800E+03, -.52674900E+03, -.12469000E+04, -.12894900E+04, 0.39486700E+03, 0.23429200E+04, -.11730500E+04, -.11625000E+04, -.22302300E+03, -.10286800E+04, -.10601100E+04, -.34430700E+04, -.13930200E+04, -.14395500E+04, 0.19598800E+04, -.98869600E+03, -.10234600E+04, -.67429500E+03, 0.11653000E+04, -.87023900E+03, -.15622400E+04, -.22094900E+04, 0.76512900E+03, -.41081500E+03, 0.79251100E+03, 0.72240900E+03, 0.42330900E+02, 0.38439000E+03, -.84723400E+03, 0.88608100E+03, 0.68831400E+02, 0.24762900E+04, 0.29737000E+04, 0.18397100E+04, 0.19214500E+03, 0.15636300E+03, -.22593900E+04, -.66523400E+03, -.17591000E+04, -.10850900E+04, 0.40733000E+03, -.26157400E+04, 0.64966200E+03, -.65219700E+03, -.17090000E+04, 0.18620900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.29297100E+01, 0.49505400E+00, 0.12997500E+01, 0.53377900E+00, 0.28406200E+01, 0.37532600E-01, 0.37220800E+00, -.49686800E+00, -.89534800E-01, 0.74591500E+00, -.25400900E+00, 0.12308100E+00, -.76675600E-01, 0.89169000E-01, 0.41158200E-01, -.10672900E+00, 0.57633700E+00, -.10531900E+00, 0.87766200E+00, 0.66174600E+00, 0.27022900E+01, 0.14240400E+00, -.42185200E+00, -.43030000E+00, 0.23269900E+00, 0.33332800E+00, -.56628900E+00, -.27248000E+00, 0.73263100E+00, 0.79930100E+00, -.40412300E+00, -.13490700E+01, 0.33063500E+00, 0.46721000E+00, 0.24810000E+00, 0.46114500E+00, -.45809000E-01, -.30227500E+00, 0.72939100E+00, 0.21290700E+00, 0.62497900E-01, -.14190200E+00, -.22270900E+00, -.19433500E+04, -.34261500E+03, -.10697200E+05, 0.52186300E+04, 0.57654400E+04, -.11349500E+04, -.49247500E+04, 0.75466700E+04, 0.10287900E+05, 0.19139700E+05, -.41736300E+04, -.11520200E+03, -.18228100E+03, -.16927200E+02, 0.50505800E+03, -.30359300E+03, -.61270800E+03, -.20115800E+04, -.86881100E+03, 0.28416400E+03, 0.13011300E+05, -.62162200E+04, -.71153400E+04, 0.24610400E+03, 0.29127000E+04, -.53081400E+04, -.23698600E+04, -.64976700E+04, 0.44305700E+03, -.11120100E+05, 0.51511800E+04, 0.60419800E+04, -.73308800E+03, -.31299200E+04, 0.48783500E+04, 0.19352300E+04, 0.67489300E+04, -.10060800E+04, 0.48209300E+04, -.25803000E+04, -.17476600E+04, -.13620300E+04, -.33420200E+02, -.25338100E+04, -.53430800E+04, 0.15841200E+04, 0.83171700E+03, 0.25784200E+04, -.13001300E+04, -.22748000E+04, 0.12957900E+04, 0.88206000E+03, -.18488000E+04, -.34391300E+03, -.55122600E+04, 0.87387800E+03, -.14361000E+05, 0.72464400E+04, 0.70095000E+04, 0.15421800E+04, -.86257700E+03, 0.63094700E+04, 0.68799400E+04, 0.11549500E+05, -.37873600E+03, -.46280100E+04, 0.23170900E+04, 0.22285800E+04, -.26305400E+03, 0.23040200E+03, 0.16702000E+04, 0.91912900E+03, 0.43823900E+04, 0.72691100E+03, -.52011400E+03, 0.34114800E+03, 0.32563500E+03, 0.11646400E+03, -.20339300E+03, 0.66174500E+03, 0.16085200E+04, 0.21800300E+03, -.28590200E+03, 0.28043300E+03, -.26694100E+02, -.77382900E+03, -.66568400E+03, -.24786200E+03, 0.93364500E+03, 0.35180400E+04, 0.57055100E+04, -.72349500E+03, -.10139000E+03, 0.23760900E+03, -.15125400E+03, -.54740300E+03, 0.31840700E+04, -.62630600E+01, 0.88901900E+03, -.10005300E+04, 0.17631000E+04, 0.11770400E+04, -.58560000E+03, -.89639400E+03, 0.18349600E+03, -.39512000E+03, -.43512300E+01, 0.17401000E+04, -.42355000E+03, -.38621500E+02, 0.10131800E+05, -.50609100E+04, -.50467900E+04, -.22358300E+02, -.72067400E+03, -.31013600E+04, -.29292500E+03, -.36322500E+04, -.15512900E+04, 0.48237500E+04, -.23359200E+04, -.20741800E+04, -.14861600E+04, 0.17912100E+04, -.28100200E+04, -.42223300E+04, 0.17674800E+03, 0.65461900E+03, 0.32525100E+04, -.16191500E+04, -.25620700E+04, 0.27257100E+03, 0.22872100E+04, -.27524500E+04, -.35716100E+04, -.33253600E+04, 0.18667600E+04, -.39239200E+04, 0.17904200E+04, 0.19358200E+04, 0.58246500E+03, -.30581000E+04, 0.16619400E+04, 0.22943800E+03, 0.22724900E+04, -.16027900E+04, 0.64960800E+03, -.44076700E+03, -.22186700E+03, -.88828700E+03, 0.13868300E+04, -.13916100E+04, -.50938400E+04, -.12136800E+04, 0.13680500E+04, -.98462100E+03, 0.13035400E+04, 0.50963800E+03, 0.16866600E+04, 0.96797700E+03, -.11203400E+04, -.29006300E+04, -.10351900E+04, 0.25568700E+03, 0.63963200E+03, 0.48222100E+03, 0.12010200E+04, 0.75527300E+01, -.75089600E+03, -.48855900E+03, 0.47994700E+04, -.12642500E+04, 0.77158600E+03, -.13185200E+04, 0.69760000E+03, -.36800700E+03, -.96708500E+03, -.14203600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.88369200E+00, 0.26396700E+00, 0.52347200E+00, 0.26643100E+00, 0.47483300E+00, -.32158200E+00, -.63170900E-01, 0.37381200E+00, 0.59677800E+00, -.60602600E-01, 0.24703000E+00, 0.11831500E-02, -.25010600E-01, 0.77290400E+00, -.27270600E+00, -.11580100E+00, -.34350200E+00, -.72336400E-01, 0.25983800E+00, -.17327500E+00, -.10019700E+01, -.63485300E-01, 0.44214400E-01, 0.30117700E+00, -.20011800E+00, 0.49716300E-01, 0.21418900E+00, 0.30090300E-01, 0.28845400E+00, -.22109500E+00, 0.57271500E-01, -.70672300E-01, -.13862100E+00, -.22856900E+00, -.18932100E+00, -.28108800E+00, 0.22121000E-01, -.12826200E+00, -.83723200E+00, -.13863000E+00, -.35631000E+00, 0.47355000E-01, -.46785200E+00, 0.78775400E-01, -.37419900E+03, 0.47056400E+04, -.24407100E+04, -.27465100E+04, -.39148400E+04, -.22690900E+04, 0.29323300E+03, 0.10438100E+04, -.21412000E+03, -.11102600E+04, -.44489300E+03, 0.15452400E+03, 0.32247300E+03, 0.45038700E+02, 0.18110000E+03, 0.18663600E+03, -.27384800E+03, 0.22397800E+03, 0.64870000E+01, -.52431000E+04, 0.25553600E+04, 0.32101100E+04, -.25794100E+04, -.33350500E+04, 0.45293000E+04, 0.52442300E+04, 0.69836600E+04, -.25317800E+04, 0.14889100E+04, -.72471100E+03, -.12789800E+04, 0.32706800E+04, 0.42569000E+04, -.37709800E+04, -.52157600E+04, -.62758800E+04, 0.30660900E+04, -.53113200E+04, 0.25940700E+04, 0.19179000E+04, 0.36636500E+04, 0.30769300E+04, -.10722200E+04, -.38447300E+04, -.20063500E+04, 0.28833900E+04, 0.85794600E+04, -.42772600E+04, -.30982300E+04, -.27870900E+04, -.36287400E+04, -.20438600E+03, 0.23047100E+04, 0.14264900E+04, -.30494600E+04, 0.97688200E+04, -.48670200E+04, -.46487600E+04, -.56582500E+04, -.43612500E+04, 0.69871300E+03, 0.29169000E+04, 0.91739900E+03, -.38862700E+04, -.12056500E+03, 0.67593900E+02, 0.15662400E+03, -.17045500E+03, 0.16077100E+03, 0.11942000E+03, 0.30277500E+04, 0.12555200E+03, 0.54429000E+03, 0.17426700E+04, -.82974400E+03, -.90242100E+03, -.11007000E+04, -.67015600E+03, 0.16988200E+03, 0.98638000E+03, 0.61354000E+03, -.69283100E+03, 0.87716800E+04, -.43509400E+04, -.35970400E+04, -.32495600E+04, -.26257400E+04, -.78786800E+03, 0.32731700E+02, -.34465300E+03, -.22717300E+04, 0.19265500E+04, -.87678900E+03, -.72333300E+03, -.11132600E+04, -.51525100E+03, 0.23114200E+03, 0.23679400E+04, 0.91631300E+03, -.76045400E+03, 0.40158800E+04, -.19944600E+04, -.16755900E+04, -.22174800E+04, -.20443700E+04, 0.37518100E+03, 0.12784100E+04, 0.10661900E+04, -.15037500E+04, 0.28874100E+02, -.21632200E+02, -.37558200E+02, -.93669700E+02, -.13855400E+03, -.64650300E+02, -.28002200E+04, -.12013300E+03, -.43077100E+03, -.65912100E+04, 0.33160400E+04, 0.27094600E+04, 0.41684100E+04, 0.37673900E+04, -.29911200E+02, -.16902100E+04, -.31332100E+04, 0.21558400E+04, 0.37650500E+03, -.17954100E+03, 0.65497100E+03, 0.32364600E+03, -.13776100E+03, 0.20570000E+03, -.11991800E+04, -.82033800E+03, -.20839200E+02, 0.18590400E+04, -.97545100E+03, -.90250000E+03, 0.14157600E+03, -.10064200E+04, -.54590200E+03, -.21520100E+04, -.19285600E+03, -.29633000E+03, -.73428600E+04, 0.35926700E+04, 0.34909100E+04, 0.41054900E+04, 0.26695500E+04, 0.13911000E+02, -.28315000E+04, -.91077700E+03, 0.19944800E+04, 0.22779200E+04, 0.20539500E+04, 0.20381400E+04, -.69444700E+02, -.21179800E+04, -.21087400E+04, -.22911800E+03, 0.21543700E+04, -.10414100E+04, -.51946600E+04, 0.66052600E+03, 0.14399800E+03, 0.85894300E+01, -.31872700E+04, -.17212100E+04, 0.10683100E+04, -.29486800E+04, 0.11578600E+04, -.30673000E+04, 0.95749600E+03, -.19515700E+04, -.33506400E+04, 0.21638500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.28249000E+01, 0.22267200E+00, -.22637100E+01, -.59017800E+00, 0.26984800E+00, 0.47542800E+00, -.52923800E-01, 0.66815300E+00, 0.38461500E+00, 0.76550400E-02, 0.56127000E+00, -.89871500E+00, 0.18343500E-01, -.88093000E+00, 0.56737200E+00, 0.45859900E+00, -.12557000E+01, -.25843100E+00, -.20837300E+01, -.34957600E+00, -.16898200E+01, 0.42627500E-01, 0.39132400E+00, 0.18516500E-01, 0.13452600E+00, -.34780900E+00, 0.12788800E+00, 0.46131600E-03, -.44617600E+00, 0.10830400E+00, 0.55640000E-01, 0.89578100E+00, -.16098700E+00, -.10157100E+00, 0.52262500E+00, -.57836500E+00, 0.29706900E+00, 0.46784000E+00, 0.29281700E+00, 0.25341500E+00, 0.95575900E+00, 0.11280800E+00, -.71793500E-01, -.59631900E+00, -.33601200E+00, -.57299500E+04, 0.29319000E+04, 0.31478100E+04, -.58225500E+03, 0.17224200E+04, 0.21561100E+04, 0.34503000E+04, 0.56918900E+04, 0.19054300E+04, 0.45377100E+03, -.19259700E+03, -.28912100E+03, 0.76845300E+03, -.22917800E+03, -.31293200E+03, 0.34935700E+02, -.61821000E+03, -.15870200E+03, 0.15157400E+04, -.10655200E+04, -.11081000E+04, -.13584300E+04, -.23601900E+04, 0.81613800E+03, 0.25513900E+04, -.44112900E+03, -.16849000E+04, -.13564100E+04, 0.10144700E+04, 0.94701100E+03, 0.10242000E+04, 0.17326100E+04, -.53121800E+03, -.22337400E+04, 0.14004400E+04, 0.11687200E+04, -.32083200E+04, 0.16396500E+04, 0.21639400E+04, 0.13330800E+04, -.12496600E+03, 0.47277400E+03, 0.13064500E+04, 0.36184400E+04, 0.27370900E+03, -.27878000E+04, 0.13898400E+04, 0.81325300E+03, 0.49782900E+03, 0.44721700E+03, 0.49247500E+03, -.54093100E+03, -.20039100E+04, 0.62769600E+03, -.22808800E+04, 0.11375000E+04, 0.10108200E+04, 0.27715500E+03, 0.18380800E+04, 0.24766000E+03, 0.12732200E+04, 0.97227300E+03, 0.17109200E+04, -.90936600E+03, 0.45190400E+03, 0.39137100E+03, -.51393400E+03, 0.22707400E+03, 0.59468800E+03, -.14095600E+04, 0.12419200E+04, 0.43602700E+03, 0.97256600E+03, -.49595700E+03, -.44195800E+03, -.36075400E+03, -.18191800E+03, 0.13097800E+02, 0.91901000E+02, -.53554600E+03, -.19817100E+03, -.18819800E+04, 0.97489900E+03, 0.42906600E+03, -.24723400E+03, 0.15822500E+04, 0.58617100E+03, 0.15984900E+04, 0.52194200E+03, 0.13593000E+04, 0.31770400E+03, -.18300500E+03, -.31422600E+03, -.38542400E+03, -.12202800E+03, 0.42277900E+02, -.10702000E+04, -.58186600E+02, -.14604700E+03, 0.14618300E+04, -.72969300E+03, -.92573700E+03, -.34361500E+03, -.54366800E+03, 0.91690400E+02, 0.11657600E+04, -.10686300E+04, -.37028100E+03, 0.96234200E+03, -.47816000E+03, -.46949100E+03, 0.47839400E+03, -.30811700E+03, -.55069200E+03, 0.12744500E+04, -.12488800E+04, -.44060000E+03, 0.22490300E+04, -.11477700E+04, -.91809300E+03, -.30029200E+03, 0.95338700E+03, -.19548500E+04, -.38507000E+04, 0.73613900E+03, 0.24613700E+03, -.90169400E+03, 0.45223700E+03, -.21627700E+03, 0.74481600E+03, 0.29118400E+03, -.58526000E+03, -.83505800E+03, -.50197300E+03, 0.32714200E+03, -.69674200E+03, 0.34667500E+03, 0.32793700E+03, 0.35550200E+03, 0.50912400E+03, 0.33599900E+03, 0.21479600E+04, -.34374300E+02, 0.50697800E+03, -.40329600E+04, 0.20569000E+04, 0.21023700E+04, 0.82171700E+03, -.21641300E+03, 0.65626400E+03, -.17285300E+03, 0.29545200E+04, 0.51650500E+02, 0.75556900E+03, 0.37621900E+03, 0.19305000E+03, 0.81433600E+03, -.66057100E+03, -.36811800E+03, -.91488500E+03, 0.44271800E+03, -.12617300E+04, -.24814100E+04, -.11121700E+04, 0.52948300E+03, -.50433000E+03, 0.36811800E+03, 0.51860300E+02, 0.19064300E+04, 0.30647000E+02, -.21173200E+03, 0.39060400E+03, 0.47109100E+02, -.82464000E+02, 0.49388300E+03, -.61924200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.27410600E+01, -.13382900E+01, 0.32768200E+01, 0.11166200E+01, -.34933200E+01, 0.46593200E+00, 0.43875900E+01, 0.76355700E-01, 0.76735400E+00, -.84828800E+00, -.13740600E+01, 0.13945500E+01, -.98512200E+00, 0.49957200E+00, 0.29243700E+00, -.85613800E+00, -.53622100E+00, -.36236300E+00, 0.57501900E+00, 0.25113700E+01, 0.42259700E+01, -.19993900E+00, -.32173700E+00, -.92296500E-01, -.43090300E+00, 0.39869900E+00, -.13557400E+00, -.74589900E+00, -.35900600E+01, 0.15033100E+01, 0.13665600E+00, 0.13118900E+01, -.28362600E+00, 0.19307000E+00, 0.59378100E+00, -.15120000E+01, -.32402100E+00, -.17374500E+00, 0.21154300E+01, 0.16516700E+01, 0.27605200E-01, 0.24242400E+00, 0.19318500E+00, 0.13941800E+01, -.23047900E+01, 0.21452100E-01, 0.30339300E+03, -.11560200E+04, -.71406100E+04, 0.10945700E+05, -.54225000E+04, -.12885300E+05, -.20099800E+05, 0.99944500E+04, 0.32482000E+03, 0.27102800E+03, 0.10076000E+03, 0.14954100E+04, -.77820000E+03, 0.42113900E+03, 0.12259400E+04, 0.19219800E+04, -.96600600E+02, -.42350000E+05, 0.18636100E+05, 0.22727300E+05, -.52870700E+04, -.13172400E+05, 0.20896300E+05, 0.16107600E+05, 0.27563700E+05, -.69888400E+04, 0.30563100E+05, -.12496400E+05, -.16597300E+05, 0.72664000E+04, 0.15255600E+05, -.18136000E+05, -.16077800E+05, -.28519200E+05, 0.87155000E+04, -.16182900E+05, 0.84521900E+04, 0.60271800E+04, 0.10049900E+05, -.27018500E+04, 0.36554300E+04, -.15653300E+04, 0.22306200E+03, 0.10695200E+04, 0.17769500E+05, -.88254000E+04, -.56909000E+04, -.65128000E+04, -.83031900E+04, -.11246800E+03, 0.74152900E+04, 0.70812100E+04, -.74139100E+04, 0.20579800E+05, -.10397000E+05, -.96194700E+04, -.11212400E+05, 0.45944100E+04, -.65294900E+04, -.29058500E+04, -.12448900E+05, 0.12892100E+04, 0.59287300E+04, -.29610000E+04, -.27163300E+04, -.18407900E+04, -.69783100E+03, -.18972100E+04, 0.22343200E+04, -.12932600E+04, -.44867200E+03, 0.56320700E+04, -.28685100E+04, -.28657400E+04, -.32259000E+04, 0.50089000E+03, -.11697900E+04, 0.94059000E+03, -.80253500E+03, -.77763200E+03, 0.86495500E+04, -.43634800E+04, -.21116600E+04, -.38229200E+04, 0.41899200E+04, -.47513900E+04, -.74349200E+04, -.11726900E+05, 0.32390500E+04, 0.18426700E+05, -.93695700E+04, -.85478600E+04, -.54888200E+04, -.42021700E+04, -.43462800E+04, 0.25910400E+04, -.42584700E+04, -.59826000E+04, 0.68253100E+04, -.33787000E+04, -.25385700E+04, -.42230300E+04, -.22882600E+04, -.84433500E+02, 0.20498100E+04, 0.25030300E+04, -.16973000E+04, -.11857000E+05, 0.59186100E+04, 0.58638600E+04, 0.16323000E+04, 0.19316800E+04, 0.31556900E+04, -.29971900E+04, 0.14527300E+04, 0.16665200E+04, -.16190900E+05, 0.78676400E+04, 0.63753200E+04, 0.13385700E+05, 0.95704300E+04, 0.93310100E+02, -.72907300E+04, -.11615400E+05, 0.74747200E+04, -.72587400E+04, 0.36258700E+04, 0.58622700E+04, 0.22098900E+04, -.23584400E+04, 0.38806700E+04, 0.16290800E+04, 0.34233500E+04, -.40844100E+03, 0.47631400E+04, -.21932500E+04, -.23090400E+04, 0.29578200E+04, 0.38310600E+02, -.22303200E+04, -.34085100E+04, -.23653400E+04, 0.37640300E+04, -.16073000E+05, 0.82070200E+04, 0.75275900E+04, 0.10135700E+05, -.28873600E+04, 0.43665900E+04, 0.93146700E+03, -.74909100E+03, -.76299700E+03, 0.64492100E+04, 0.15515300E+04, 0.29603800E+04, -.48357400E+04, -.58729900E+04, -.15776000E+04, -.17262400E+04, 0.48864500E+04, -.56615400E+04, -.14060300E+05, -.16775200E+04, -.40402000E+04, 0.15255600E+04, -.50535800E+04, -.19560600E+04, 0.38700500E+03, -.60235600E+04, -.85615100E+03, -.46858000E+04, -.21073100E+04, -.25202900E+04, -.76926300E+04, 0.61905800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.19685600E+00, 0.82937100E-01, 0.13073800E+01, 0.98343400E-01, 0.21718000E+01, -.12529400E+00, -.29317400E+01, -.14389500E+01, -.54639600E+00, -.54784500E+00, 0.13830000E+01, -.96677200E+00, 0.76526500E+00, -.78984500E+00, -.13305500E+00, -.30505100E+00, 0.82472800E+00, -.32255200E+00, -.69741600E+00, 0.79731300E+00, 0.23470800E+00, 0.24899400E+00, -.85693500E+00, 0.55208000E+00, 0.11554300E+00, 0.87868400E-01, -.88698700E+00, 0.24815900E+00, 0.72611700E+00, 0.97716600E+00, -.66502700E-01, -.65290100E+00, -.95459100E-01, -.62128900E+00, 0.85517500E-01, -.48023300E+00, 0.17233300E+00, -.28745700E+00, 0.14541300E+01, 0.82954700E-01, -.95190100E+00, -.16145200E+00, 0.18997300E+01, 0.55992000E+00, -.10656200E+01, 0.59641300E-01, -.22474800E+00, -.89025800E+03, -.26341700E+04, 0.45654400E+04, -.31985000E+04, -.84667900E+04, -.13669200E+05, 0.44526700E+04, -.32254900E+03, 0.32056800E+03, 0.34249500E+03, -.27437300E+03, -.47604000E+02, 0.53532500E+03, 0.91087200E+03, 0.14020400E+04, -.27827300E+03, -.17848100E+05, 0.85399600E+04, 0.10118700E+05, -.10875600E+04, -.29975300E+04, 0.75544600E+04, 0.52960700E+04, 0.12566800E+05, -.11732900E+04, 0.10857600E+05, -.49859500E+04, -.65347800E+04, 0.22812900E+04, 0.44056900E+04, -.60061400E+04, -.56287200E+04, -.13872300E+05, 0.25875900E+04, -.39995500E+04, 0.21597700E+04, 0.28788400E+03, 0.29855300E+04, -.16666100E+04, 0.19075100E+04, -.45832500E+03, -.34588600E+04, -.59299900E+03, 0.11218900E+05, -.55757600E+04, -.30059600E+04, -.32055400E+04, -.36499100E+04, -.10544900E+04, 0.35269700E+04, 0.46591400E+04, -.38263200E+04, 0.10181300E+05, -.51911100E+04, -.45671900E+04, -.49325000E+04, 0.14858400E+04, -.37538000E+04, -.16721600E+04, -.63798900E+04, -.26972700E+03, -.16599700E+03, 0.80324700E+02, 0.26221100E+03, -.26932200E+03, -.18407700E+03, 0.51108600E+02, 0.12447100E+04, -.48628600E+02, 0.16012300E+03, 0.12768400E+04, -.66568600E+03, -.66810300E+03, -.10082400E+04, 0.53425900E+03, -.62738100E+03, 0.22638600E+03, 0.25927200E+03, -.25004900E+02, -.14847400E+03, 0.11767600E+02, 0.18826700E+04, -.12548600E+04, 0.17694700E+04, -.12684400E+04, -.37908000E+04, -.54758600E+04, 0.16400400E+04, 0.52795000E+04, -.27179900E+04, -.21489000E+04, -.12978000E+04, -.20344300E+04, -.14554100E+04, 0.12199500E+04, -.10343100E+04, -.19592400E+04, 0.19323700E+04, -.95065700E+03, -.29921600E+03, -.18892200E+04, -.17981100E+03, -.32534700E+03, 0.76940200E+03, 0.25259900E+04, -.61019200E+03, -.42050900E+04, 0.20972400E+04, 0.20561900E+04, 0.33798000E+03, 0.10750800E+04, 0.90931400E+03, -.17728700E+04, 0.23745300E+03, 0.70396600E+03, -.14221400E+05, 0.70356000E+04, 0.57777300E+04, 0.68397000E+04, 0.39892400E+04, 0.31478400E+04, -.18675200E+04, -.57863500E+04, 0.38770900E+04, -.22802900E+04, 0.11467600E+04, 0.28622800E+04, 0.33332300E+03, -.12389500E+04, 0.20488100E+04, 0.15180600E+04, 0.15919500E+04, -.77313200E+03, 0.36502600E+04, -.17070600E+04, -.17707300E+04, 0.54268900E+03, 0.78191100E+03, -.14498300E+04, -.16910700E+04, -.18311400E+04, 0.13986100E+04, -.23812000E+04, 0.12465300E+04, 0.84892100E+03, 0.37677100E+04, -.19664300E+04, 0.15526400E+04, 0.78695400E+03, -.41711900E+04, -.10211100E+04, 0.22768500E+04, 0.33847200E+03, 0.10164200E+04, -.38331300E+04, -.20801900E+04, -.36116300E+03, -.87936800E+03, 0.19705400E+04, -.26383100E+04, -.53926100E+04, 0.45422400E+03, -.31080800E+04, 0.16908900E+04, -.24524900E+04, -.93646200E+03, 0.26324700E+03, -.19355000E+04, -.47591700E+03, -.23160500E+04, -.14395000E+04, -.10270500E+04, -.26381300E+04, 0.35690400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11730100E+01, 0.10412800E+00, -.76998400E+00, -.39140000E+00, -.10327100E+00, -.11384900E+00, -.37802500E-01, -.85854600E-01, 0.25326300E+00, -.41872500E+00, 0.40178000E+00, -.31075800E+00, -.10821500E+00, -.44517600E+00, 0.33252800E+00, -.24122000E-01, 0.23722000E-01, 0.60769200E-01, -.81658100E+00, 0.96301300E-01, -.80520100E+00, -.46481400E-01, 0.71858500E-01, 0.14003400E+00, 0.16047300E+00, 0.40713500E-01, 0.36719300E+00, 0.19784100E+00, 0.59197900E-01, 0.38726300E+00, 0.79425200E-01, 0.71610500E-01, -.13335100E-01, -.24178600E+00, 0.19756100E+00, 0.74574400E+00, -.78995800E-01, 0.43404100E+00, -.63523400E+00, 0.47628000E-01, -.71377100E+00, -.54153000E-01, 0.74893300E+00, 0.34584100E-01, -.71444900E+00, -.43693400E+00, -.60333000E-01, 0.37686900E+00, -.17056600E+04, -.90976000E+03, 0.15302500E+04, 0.45027500E+04, 0.42944500E+04, 0.45521500E+02, 0.51307900E+03, -.22591700E+03, -.26480800E+03, 0.23083600E+03, 0.26348900E+03, -.28488400E+03, 0.13838800E+03, -.28405400E+03, 0.43783600E+02, 0.14619600E+04, -.77357500E+03, -.74132300E+03, -.18922600E+04, -.28338200E+04, 0.19031600E+04, 0.53529300E+04, 0.14916600E+04, -.21082800E+04, -.14954800E+04, 0.80448700E+03, 0.74088300E+03, 0.18098900E+04, 0.25185200E+04, -.16337400E+04, -.48454900E+04, -.17233400E+03, 0.17281400E+04, -.25334800E+04, 0.12646200E+04, 0.15026100E+04, 0.10806500E+04, 0.20645100E+04, -.82245600E+03, -.14122600E+04, 0.77980700E+03, 0.17708800E+04, -.17847400E+04, 0.89089000E+03, 0.88705300E+03, -.87228700E+02, -.22843400E+03, 0.92205500E+03, 0.22347600E+03, -.27574800E+03, 0.26514200E+02, 0.18473600E+04, -.92884700E+03, -.10433600E+04, -.99873900E+03, -.11601200E+04, 0.50450900E+03, 0.27184600E+04, 0.14099200E+04, -.85475000E+03, -.61043800E+02, 0.29857200E+02, 0.26185000E+02, -.59482600E+03, 0.12877800E+03, 0.18838100E+03, -.35394700E+03, 0.57566300E+03, 0.72318100E+03, 0.88270400E+03, -.45429400E+03, -.46839300E+03, -.22894500E+03, -.43418200E+03, 0.15127500E+03, 0.41772800E+03, 0.46566900E+01, -.37442400E+03, 0.23990400E+04, -.11868100E+04, -.13891400E+04, -.13637000E+04, -.28920600E+03, 0.17760700E+03, 0.18398900E+04, 0.80972100E+03, 0.73821600E+02, 0.38179400E+04, -.19301900E+04, -.19405200E+04, 0.59453700E+03, -.34155000E+02, -.14456700E+04, -.13965800E+04, -.11939700E+04, -.14143500E+03, 0.21658800E+04, -.10820500E+04, -.10791000E+04, -.87282200E+03, -.10711400E+04, 0.19342500E+03, 0.11614500E+04, -.35634100E+03, -.75164600E+03, -.12554000E+03, 0.63532200E+02, 0.63435700E+02, 0.52762300E+03, -.22433700E+03, 0.14692800E+02, 0.52601600E+03, -.13424100E+03, -.74542400E+03, -.17668500E+03, 0.92247400E+02, 0.21769400E+03, -.62793700E+02, 0.10136100E+04, -.12085600E+04, -.30074400E+04, 0.22198000E+03, 0.13733900E+03, -.46580400E+03, 0.24226200E+03, 0.25020700E+03, 0.40396800E+03, 0.17032100E+03, -.45369700E+03, -.95601900E+03, -.76620500E+03, -.21247100E+02, -.37502500E+04, 0.18898000E+04, 0.18725500E+04, -.10219400E+04, -.14721200E+03, 0.16829000E+04, 0.16764500E+04, 0.15592900E+04, 0.41947600E+03, -.47044600E+04, 0.23584500E+04, 0.23975000E+04, 0.14222700E+04, 0.15694900E+04, -.11361600E+03, -.21808900E+04, 0.16277800E+04, 0.11489100E+04, 0.76482800E+03, 0.74102300E+03, 0.52753400E+03, 0.90404100E+03, -.68815200E+03, -.73758300E+03, -.45719300E+03, 0.61621700E+03, 0.20738000E+03, -.20913300E+04, 0.12546500E+03, 0.76344800E+03, -.50158800E+03, -.67203300E+02, -.49514400E+03, 0.16812800E+04, -.41741900E+03, 0.38015600E+03, 0.35265200E+03, 0.53805400E+03, -.47201800E+03, -.52142900E+03, -.31731000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10953700E+00, -.47570600E-01, 0.16680800E+00, -.35266900E+00, 0.17043500E+01, -.46599000E-01, -.22424800E+00, -.56137300E+00, 0.45462300E+00, 0.36858400E+00, 0.31834700E+00, -.31902300E+00, 0.51399900E+00, -.80460700E+00, 0.42878300E+00, 0.62663900E-01, 0.14433300E+00, 0.22918300E+00, 0.27972300E+00, 0.38924100E+00, 0.81248100E-01, -.67886900E-01, 0.11322900E+00, 0.15493600E+00, 0.52254400E-01, -.14083900E-02, -.61085500E-01, -.76992700E-02, -.65620300E+00, 0.14397500E+00, 0.82403500E-01, 0.25242900E+00, -.68505700E-01, 0.11730800E+00, 0.31332400E+00, 0.73479900E-01, 0.17008200E-01, -.83063100E-01, 0.23262000E+00, -.86041100E-01, -.11306100E+00, -.77626700E-02, -.17653100E+00, 0.18942400E-01, -.79233600E-02, 0.29716900E-01, 0.15848100E+00, -.14547300E+00, -.59243300E+00, -.21211400E+04, 0.14499300E+04, 0.37214400E+04, 0.34328300E+04, -.15120900E+04, 0.18210900E+03, -.71127100E+02, -.10279000E+03, -.38519300E+03, 0.34224000E+03, -.81971000E+02, 0.26158100E+03, -.56557700E+02, -.34682600E+02, 0.62364600E+04, -.27758600E+04, -.32187100E+04, -.52491800E+02, 0.66466700E+03, -.18935400E+04, 0.37942600E+03, -.26066200E+04, 0.12271800E+03, -.50437300E+04, 0.21849000E+04, 0.25533400E+04, -.12759500E+03, -.92076600E+03, 0.16910600E+04, -.21240800E+03, 0.32088400E+04, -.36143400E+03, 0.61437100E+03, -.34785400E+03, -.85420000E+02, -.77616400E+03, 0.19095800E+04, -.10773100E+04, -.10929300E+04, -.49766400E+03, 0.12880800E+04, -.17499900E+04, 0.87196200E+03, 0.86251500E+03, 0.46160200E+03, 0.60287300E+03, 0.33316400E+03, -.51108200E+03, -.74146900E+03, 0.49698800E+03, -.13398500E+04, 0.68661900E+03, 0.51356400E+03, 0.58590300E+03, -.17716500E+04, 0.13420700E+04, 0.25770900E+04, 0.21461200E+04, -.14953300E+04, -.13170600E+04, 0.65447600E+03, 0.64734100E+03, -.16083700E+03, 0.13605600E+03, 0.57189000E+03, -.25029700E+03, 0.71472700E+03, 0.49033600E+03, -.60079500E+03, 0.27196900E+03, 0.27820700E+03, 0.32130500E+03, -.33083300E+03, 0.35008200E+03, 0.29491400E+03, 0.32353300E+03, -.19491500E+03, -.37692600E+03, 0.17023400E+03, 0.29881900E+02, -.40977900E+03, -.10798800E+04, 0.10017900E+04, 0.21198300E+04, 0.16893300E+04, -.68208000E+03, -.79135200E+03, 0.34694300E+03, 0.35741900E+03, 0.11035200E+04, 0.34692300E+03, -.15913800E+03, -.10570500E+04, 0.29765500E+02, 0.78706000E+03, 0.28024900E+03, -.14796000E+03, -.15431300E+03, -.16162900E+03, -.26938000E+03, 0.14713400E+03, 0.63025300E+03, -.14648900E+03, -.42119300E+03, 0.10221100E+04, -.50683200E+03, -.50809900E+03, 0.24847900E+03, -.24051400E+03, -.34965800E+03, 0.41513100E+03, -.32833000E+03, -.53491700E+03, -.50537500E+03, 0.27371700E+03, 0.39564900E+03, -.11650300E+04, -.29341900E+03, 0.30300500E+02, -.96152600E+03, 0.14885900E+04, -.31818500E+03, 0.13360200E+04, -.66481000E+03, -.67110000E+03, -.22613000E+03, 0.38243800E+03, -.82235500E+03, -.71474600E+03, -.99304000E+03, -.37823500E+02, -.15719300E+04, 0.81195100E+03, 0.78268700E+03, -.11613600E+04, 0.17109700E+03, 0.77842600E+03, 0.11038100E+04, 0.64701400E+03, -.24898000E+03, 0.82036400E+03, -.40665000E+03, -.35069600E+03, -.54011300E+03, 0.14665800E+04, -.11255200E+04, -.18783100E+04, -.23142700E+03, 0.10338700E+04, -.46805000E+03, 0.35308700E+03, 0.45984400E+02, 0.78687600E+03, 0.41876400E+03, -.35304700E+03, 0.43987200E+02, -.28023800E+03, 0.13491300E+04, 0.13772400E+04, 0.66748100E+03, 0.67751200E+03, -.36613200E+03, -.38461200E+02, -.28456000E+03, 0.10810800E+04, 0.30951200E+03, 0.53668900E+03, 0.15383400E+03, 0.54368500E+03, -.13091700E+03, 0.48058400E+03, -.66466700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.62923800E+01, 0.89291500E+00, -.63268400E+01, -.26192300E+01, 0.92305000E+01, 0.14720800E+00, -.58800100E+01, -.71024900E+00, 0.43925600E+00, 0.10495900E+01, 0.45929400E+01, -.33112500E+01, 0.11873400E+01, -.16460900E+01, -.86119200E+00, 0.13451400E+01, -.96827300E+00, -.44697500E+00, -.19492700E+01, -.11701100E+01, -.31471600E+01, -.57420600E-01, 0.89485900E+00, 0.11750100E+00, 0.20886000E+01, -.69628000E+00, -.31294100E+01, -.49986300E-01, 0.29889600E+01, -.12811500E+01, 0.47825300E+00, 0.11391600E+01, 0.54676100E+00, 0.39191400E+00, 0.42339400E+00, -.51955800E+00, 0.14896200E+01, 0.27040700E+01, -.28363900E+01, -.19800000E+01, 0.28898200E+01, -.71881800E+00, -.15887000E+01, -.20062300E+01, 0.49072000E+01, -.40977500E+00, -.15361200E+01, -.17241000E+01, -.24684000E+01, -.62098400E+01, 0.30030200E+04, 0.10767700E+05, 0.44010400E+04, 0.44529600E+04, 0.93196800E+03, 0.70030000E+03, -.53228000E+03, -.21289600E+04, 0.23770800E+04, 0.33652800E+03, 0.49475900E+04, 0.62513300E+03, -.19125900E+04, 0.14698000E+05, -.65573300E+04, -.78699500E+04, -.26983800E+04, -.58477000E+04, 0.35194600E+03, 0.12421700E+05, -.10214000E+04, -.26311600E+04, -.17328000E+05, 0.83266100E+04, 0.86326300E+04, 0.28203800E+04, 0.46285600E+04, 0.13648300E+04, -.11320200E+05, 0.53154900E+04, 0.24833800E+04, -.63141100E+04, 0.39318900E+04, 0.45783600E+04, -.13498300E+04, 0.86886900E+04, -.12766600E+04, 0.35407700E+04, 0.37802400E+03, 0.27772500E+04, -.97305800E+04, 0.48873500E+04, 0.55347900E+04, 0.84161200E+03, 0.15311100E+04, 0.28631500E+04, -.12684300E+04, 0.64968200E+03, 0.14968600E+04, 0.55212200E+04, -.34041400E+04, -.35952700E+04, 0.12573700E+04, -.40359400E+04, -.10173600E+03, 0.81577000E+04, 0.85278200E+03, -.24649000E+04, -.12756900E+05, 0.63384000E+04, 0.63017700E+04, -.36977000E+03, 0.16776700E+04, 0.56886700E+04, -.27776800E+04, 0.56337400E+04, 0.46198900E+04, -.68258200E+03, -.14527900E+03, 0.30577700E+03, 0.93976800E+03, -.20432900E+04, 0.10602200E+04, 0.19421100E+03, 0.11508300E+04, -.61146300E+03, -.93363600E+04, 0.41682700E+04, 0.39021900E+04, -.20343800E+04, -.21298100E+04, 0.63811000E+04, 0.97205700E+04, 0.31320500E+04, 0.14273600E+04, -.92205700E+04, 0.35443400E+04, 0.44070100E+04, 0.74591400E+04, -.36029000E+04, 0.19155800E+04, -.57359000E+04, 0.34479700E+04, 0.30237700E+04, 0.62570600E+04, -.31469200E+04, -.31327900E+04, -.30599500E+04, -.27115200E+04, 0.32414900E+03, 0.53264200E+04, 0.19910800E+03, -.38840700E+04, 0.33171000E+04, -.16496000E+04, -.16518000E+04, 0.71280600E+03, -.16619000E+04, -.23371100E+04, 0.27988100E+04, -.23876800E+04, -.38237000E+04, -.17244400E+05, 0.84286700E+04, 0.87900300E+04, -.30522400E+04, 0.44798200E+02, 0.27350500E+04, -.10388000E+05, 0.45532400E+04, -.12125400E+04, 0.35555200E+04, -.17521500E+04, -.21235100E+04, 0.68463200E+03, -.18435700E+03, -.32679600E+04, -.22166700E+04, -.41647800E+04, -.18601400E+04, -.30942500E+04, 0.25590000E+04, 0.15199200E+04, -.80005300E+04, 0.65460300E+04, 0.25898600E+04, 0.97926300E+04, 0.10097200E+02, 0.31325400E+03, -.75863100E+04, 0.43555200E+04, 0.40367200E+04, 0.11351900E+04, 0.57787100E+04, -.16127200E+04, -.52661800E+04, 0.10198500E+04, 0.31955200E+04, 0.13498000E+04, 0.20875600E+04, 0.61425800E+03, 0.16757200E+04, -.13475300E+04, -.21078900E+04, 0.33661100E+03, 0.21776300E+04, 0.51074000E+04, 0.52483700E+03, 0.29716100E+04, 0.14721400E+04, -.11991500E+04, 0.38708600E+03, -.15087100E+04, 0.50653700E+04, 0.47727700E+04, 0.15382800E+04, 0.19941500E+04, 0.18909700E+04, -.10995900E+04, 0.57138600E+04, -.18364200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.53823100E+01, 0.28868000E-01, 0.55262200E+01, 0.25438100E+01, -.93225900E+01, -.15520700E+00, 0.86081400E+01, 0.29934200E+01, -.45004700E+00, -.22010700E+01, -.29005800E+01, 0.39029600E+01, -.13269100E+01, 0.32338100E+01, 0.20537800E+01, -.17377900E+01, -.69795600E-01, 0.46484300E+00, 0.22921100E+01, -.22845800E+00, 0.66323000E+01, 0.41144400E+00, -.28868400E+00, -.37773900E+00, -.41554700E+00, 0.15136900E+01, -.24514100E+00, -.18927800E+00, -.64244800E+00, 0.27088500E+01, -.72008900E+00, -.12053800E+01, -.20631800E-01, -.58456600E-01, 0.17536700E+01, 0.15584400E+01, -.68491700E-01, -.22635600E+00, -.37110700E+00, -.14528400E+01, 0.11978200E+01, -.51875100E+00, -.23417500E+00, -.45422000E-03, -.11781700E-01, -.51516900E+00, -.12694800E+00, -.19913800E+00, -.25639700E+01, 0.41747700E+01, 0.56914600E+00, -.77278800E+04, 0.19782400E+04, -.29597700E+04, -.21496600E+04, 0.34227400E+03, 0.11245800E+04, 0.22032600E+04, -.14360700E+04, -.65439000E+02, -.45338900E+04, -.22159700E+04, 0.15967500E+04, -.17968200E+05, 0.84148500E+04, 0.95259200E+04, 0.19194700E+04, 0.17011800E+04, 0.21872000E+04, -.98854300E+04, 0.61671500E+04, 0.15847400E+04, 0.12663700E+05, -.60673500E+04, -.63279500E+04, -.76563500E+03, 0.19596100E+03, -.21702700E+04, 0.74313600E+04, -.87054100E+04, 0.21535000E+03, 0.86148100E+04, -.49312000E+04, -.51862000E+04, 0.80141200E+02, -.88200000E+04, 0.17813300E+04, 0.35217000E+04, -.23320100E+04, -.65478800E+04, 0.37444800E+04, -.18920000E+04, -.26207500E+04, -.73215200E+03, -.97962300E+03, -.80164800E+03, 0.44393400E+03, 0.36180800E+04, -.76914900E+03, 0.23019300E+04, -.66878700E+03, -.55244300E+03, -.11358600E+04, 0.14700900E+04, -.69857800E+03, -.91384700E+04, 0.28951100E+04, 0.26377500E+04, 0.22577600E+04, -.11005600E+04, -.10578200E+04, 0.26019500E+04, 0.69651900E+03, -.19116800E+04, 0.43653500E+04, -.31579600E+04, -.23275300E+04, -.12489700E+04, 0.91363500E+03, 0.60164400E+03, -.16577800E+03, 0.17677900E+04, -.69571800E+03, -.18492900E+04, 0.61862200E+03, 0.16466200E+04, 0.48149400E+04, -.20709500E+04, -.21060500E+04, 0.17488600E+04, 0.12558600E+04, -.26544600E+04, -.78443200E+04, 0.16855100E+04, -.17147800E+04, -.17032400E+05, 0.91499500E+04, 0.86482100E+04, -.33473200E+04, 0.35824800E+04, 0.68397300E+04, 0.66698000E+04, 0.67474600E+04, 0.58780300E+03, -.52286600E+04, 0.26217300E+04, 0.26131200E+04, 0.25763500E+04, 0.16643400E+04, 0.49949900E+03, -.41401700E+04, 0.25574500E+04, 0.28668800E+04, 0.66790700E+04, -.33449600E+04, -.33466400E+04, -.36161100E+04, -.13719700E+04, -.10805400E+04, -.41909900E+04, 0.43912000E+03, 0.13963900E+04, 0.18770900E+05, -.92203700E+04, -.92519800E+04, -.12814600E+03, -.13171700E+04, -.42534200E+04, 0.82150200E+04, -.10001600E+05, -.46806400E+03, -.45096800E+04, 0.22337200E+04, 0.26135100E+04, -.14869600E+04, -.98188700E+03, 0.36711700E+04, 0.16538600E+04, 0.27864400E+04, 0.36497400E+03, 0.10691200E+05, -.59642600E+04, -.53242700E+04, 0.61980900E+04, -.38326100E+04, -.40942900E+04, -.74215800E+04, -.18740400E+04, -.24243100E+04, 0.57465400E+03, -.69610300E+03, -.43201700E+03, -.14911900E+03, -.49158900E+04, 0.30607700E+04, 0.67424000E+04, -.79587800E+03, -.37158900E+04, -.73296500E+03, -.24128600E+04, -.15985700E+04, -.99147700E+03, 0.64260000E+03, 0.24296400E+04, -.18165800E+04, -.94148400E+03, -.42394400E+04, -.29636100E+04, -.16512500E+04, -.57660900E+03, 0.25820700E+04, 0.17836500E+04, 0.17119100E+04, -.26909800E+04, -.14970000E+04, -.72470500E+03, -.19498000E+03, -.14424900E+04, 0.18178900E+04, 0.52628700E+02, 0.22642600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11507300E+01, 0.56613000E+00, 0.73054900E+00, 0.70170200E+00, -.15907900E+00, 0.46226900E-01, -.41079800E+00, -.19458200E+01, 0.10314900E+00, 0.10918900E+00, -.88585500E+00, 0.11362500E+01, 0.46433200E-01, 0.43292500E+00, -.17360900E+00, 0.22245600E+00, 0.23442400E+00, 0.25916800E+00, 0.63394400E+00, 0.44258100E+00, 0.86440000E+00, -.20609500E+00, 0.21994400E+00, 0.13152700E+00, -.26476100E+00, 0.52773400E-01, -.74110400E-01, -.37892600E-01, 0.71090000E+00, -.40572800E+00, 0.61712900E-01, -.89196800E+00, 0.15773300E+00, 0.12233400E+00, 0.27207200E+00, -.17360900E+00, -.65672300E-01, -.30406700E+00, 0.67829100E+00, -.76863000E+00, -.24043100E+00, -.12965400E+00, 0.55229500E+00, 0.14570200E+00, -.12332100E+00, 0.10631200E-01, -.57712100E-01, -.80266300E-01, -.37084400E+00, -.42017600E+00, 0.34041900E-01, -.10873000E+00, 0.29203100E+04, 0.11134200E+03, 0.47422300E+03, -.35878400E+03, -.23331200E+03, 0.94555800E+02, -.29128100E+03, -.92319500E+02, 0.12334400E+03, -.32003200E+03, 0.46485000E+02, 0.30658800E+04, -.12575600E+04, -.15637400E+04, -.73194300E+03, -.18855600E+03, -.12283700E+04, -.93714700E+03, -.67370100E+03, -.17175500E+03, -.12429800E+04, 0.27037100E+03, 0.79547200E+03, 0.19293100E+03, -.66876800E+03, 0.11049400E+04, 0.14429100E+04, 0.11980500E+04, -.64997600E+03, 0.59816300E+03, -.42981100E+03, -.31294300E+03, -.28102400E+03, -.10785900E+04, 0.75478400E+03, 0.20857100E+04, 0.59801600E+03, -.81347500E+03, -.22766800E+04, 0.11284800E+04, 0.67128300E+03, 0.43477100E+03, 0.86541200E+03, 0.28698500E+03, -.50438200E+03, -.12726900E+03, 0.73323200E+03, -.11029700E+04, 0.63958800E+03, 0.51087100E+03, 0.36189900E+03, 0.77524200E+03, -.41103000E+03, -.15769500E+04, 0.14767900E+04, 0.10168600E+04, 0.97259500E+03, -.48268000E+03, -.47784000E+03, 0.20290000E+03, -.12528700E+03, -.29306800E+03, -.41927300E+03, 0.66383100E+02, -.33499900E+03, -.56406000E+03, 0.30595900E+03, 0.23860600E+03, 0.95097700E+02, 0.23903500E+03, -.66860100E+02, -.56666200E+03, 0.24698700E+03, 0.27879700E+03, -.16917200E+04, 0.85996000E+03, 0.67611600E+03, 0.35788000E+03, 0.13851700E+03, 0.36606100E+03, -.19719600E+03, 0.19699800E+04, 0.28963000E+03, -.28806400E+04, 0.15013700E+04, 0.14311900E+04, 0.22500000E+03, 0.29354500E+03, 0.67881200E+03, -.78012400E+03, 0.11849500E+04, 0.11403100E+03, -.75683700E+03, 0.37397100E+03, 0.32085200E+03, 0.36839200E+03, 0.33505200E+03, 0.21105400E+02, -.29331400E+03, 0.32000400E+03, 0.51037900E+03, -.11094200E+02, 0.43724700E+01, 0.89818100E+01, -.37269400E+03, -.13174400E+03, 0.10286500E+03, 0.55814800E+03, -.32349800E+02, 0.18409000E+03, 0.23445900E+04, -.11298900E+04, -.83084000E+03, -.93476200E+03, -.14558600E+04, -.73054800E+02, 0.90056000E+03, 0.26335500E+03, -.10523400E+04, -.14673000E+04, 0.73075800E+03, 0.84929800E+03, -.26094200E+03, -.23598000E+03, 0.56005500E+03, 0.31763900E+03, 0.84374900E+02, -.20663100E+03, -.51944700E+03, 0.19323600E+03, 0.26328800E+03, 0.28727900E+03, -.95474100E+02, 0.37917600E+03, 0.83744800E+03, 0.56890300E+03, 0.10037500E+03, -.40722600E+03, 0.13747700E+03, 0.23990600E+03, -.24004600E+03, -.64289000E+03, 0.70314000E+03, 0.12077900E+04, 0.59422300E+03, -.80975600E+03, -.45472800E+03, -.67534300E+03, -.69721700E+03, -.29730100E+03, 0.37667700E+03, 0.68106600E+03, -.59403700E+03, -.41763900E+03, -.21375400E+04, -.26296600E+04, -.58802200E+03, -.36673500E+03, 0.35893000E+03, 0.11974000E+04, 0.54274900E+03, 0.72026700E+02, 0.47412900E+03, -.32163800E+03, 0.95719300E+03, -.43669000E+03, 0.69066200E+03, 0.10632300E+04, -.11859000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21596300E+01, 0.16423900E+00, -.14328900E+01, -.34615500E+00, -.68849500E+00, 0.34674100E+00, -.69671600E+00, -.52373500E+00, 0.47485300E+00, -.37074900E-01, 0.12594000E-01, -.12420000E+00, -.28207800E+00, -.10858000E+01, -.18512700E+00, 0.13363700E+00, 0.26017200E+00, -.67544400E-01, -.19500700E+00, -.43826600E+00, 0.94965100E+00, -.45478700E+00, -.22301300E+00, -.42318000E+00, 0.18522400E+00, 0.56510600E-01, -.35934800E+00, -.14145800E+00, -.63424700E-01, 0.33367300E-01, -.11511500E+00, -.19399000E+00, 0.33125100E+00, 0.24152200E+00, 0.27286800E+00, 0.54460200E+00, 0.14056700E+00, -.50448300E-01, 0.25064700E-01, -.35908000E+00, -.41771100E+00, -.13515100E+00, 0.34206600E+00, -.11995200E+00, -.46841800E-02, -.14777600E+00, 0.35182500E-01, -.22466900E+00, 0.50835100E+00, 0.62996400E+00, -.36839700E-01, 0.14525400E+00, -.45950200E+00, -.86481400E+03, -.30679900E+03, 0.24364200E+03, 0.13919400E+03, -.25824400E+03, -.61558700E+01, 0.14745800E+03, 0.11538000E+03, 0.23027100E+02, 0.12057100E+03, 0.70325700E+03, -.13274000E+03, -.27030300E+03, 0.11043400E+04, 0.17950900E+04, -.16548600E+04, -.22625200E+04, -.50312100E+03, 0.14308800E+04, -.41382800E+03, 0.13608800E+02, 0.57486600E+02, -.11824000E+04, -.19869200E+04, 0.15618000E+04, 0.19069800E+04, -.22364900E+03, -.14132500E+04, 0.41685900E+04, -.20628000E+04, -.19789500E+04, -.20174900E+04, -.22505500E+04, 0.70321700E+03, 0.13500400E+04, -.17687700E+04, -.19635200E+04, -.36336700E+04, 0.18157400E+04, 0.20377300E+04, 0.78738500E+03, 0.15416500E+04, 0.32650100E+03, -.12593800E+03, 0.17728700E+04, 0.11333800E+04, -.13057900E+04, 0.62511000E+03, 0.60657500E+03, 0.10626300E+04, 0.10753000E+04, -.87007500E+03, -.34909800E+03, 0.86169000E+03, 0.60943900E+03, -.31741900E+04, 0.15820800E+04, 0.15840200E+04, -.12682000E+03, 0.52529700E+03, 0.11207300E+04, 0.46790200E+03, 0.11423700E+04, 0.28376300E+03, -.13534800E+04, 0.62497200E+03, 0.65866900E+03, 0.49572000E+03, 0.59035100E+03, -.17765400E+03, -.39327500E+03, 0.45790600E+03, 0.54316400E+03, -.39980500E+04, 0.19272200E+04, 0.19287000E+04, 0.62023600E+03, 0.73111900E+03, 0.60075500E+03, 0.40603700E+02, 0.12249900E+04, 0.40245800E+03, -.51798400E+04, 0.24802300E+04, 0.25655800E+04, 0.36018800E+03, 0.83847900E+03, 0.10155800E+04, -.38089400E+03, 0.14622400E+04, 0.10428800E+04, -.19535100E+04, 0.96935600E+03, 0.10228800E+04, 0.58832500E+03, 0.12669500E+04, -.28350200E+03, -.14862500E+03, 0.11056400E+04, 0.83692800E+03, 0.19812900E+04, -.98811600E+03, -.99072100E+03, 0.18672200E+03, -.38081900E+03, -.82954500E+03, -.68263100E+03, -.10129400E+04, -.72503000E+02, 0.56966800E+03, -.28544000E+03, -.26974100E+03, -.55923100E+02, -.13379800E+04, 0.13681100E+03, -.92394900E+03, -.17723900E+04, -.14685000E+03, -.77291300E+03, 0.38037900E+03, 0.44134100E+03, -.23157700E+03, -.22405200E+03, 0.20766200E+03, -.88929200E+02, 0.17515900E+03, -.22936100E+01, 0.19757000E+04, -.89019500E+03, -.98984400E+03, -.12159300E+03, 0.23308000E+03, -.40044500E+03, 0.52321500E+03, -.43947700E+03, -.41491500E+03, 0.44635100E+04, -.21990600E+04, -.21888800E+04, -.13155400E+04, -.15873900E+04, -.11399200E+03, 0.21586900E+03, -.25975100E+04, -.11657300E+04, -.10029600E+04, -.92431300E+03, -.84679900E+03, -.14783300E+04, 0.92592000E+03, 0.92364800E+03, -.12376100E+04, -.86471200E+03, -.11994400E+03, 0.11388700E+04, 0.57270100E+03, -.13286700E+04, 0.11144900E+04, 0.59364100E+03, 0.48938700E+03, 0.14323500E+04, 0.92221700E+03, -.51490300E+03, 0.33766400E+03, -.12056600E+04, 0.80371900E+03, 0.16476100E+04, 0.27536700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.16878200E+01, 0.45704400E+00, 0.22633200E+01, 0.69653000E+00, -.47329300E+01, 0.18904100E+00, 0.37161700E+01, 0.79465200E+00, 0.26151200E+00, -.42809000E+00, -.16610000E+01, 0.89627600E+00, -.61113100E+00, 0.12061200E+00, 0.42740200E+00, -.71921000E+00, -.41516300E+00, -.25153300E+00, 0.98234000E-02, -.21096800E+00, 0.21949600E+00, 0.23559100E+00, -.22167400E+00, -.17435300E+00, -.55820500E+00, 0.11716400E+00, 0.44750700E+00, -.15597600E+00, -.10089100E+01, 0.19446400E+00, -.77692300E-01, 0.26771500E+00, -.65326500E+00, -.71573000E-01, 0.48036200E+00, -.88521600E+00, -.20098600E+00, 0.45656200E-01, 0.93721500E+00, 0.45918100E+00, 0.97311600E+00, 0.86025200E-01, -.17015300E+00, 0.91427500E-01, -.58228600E+00, -.52895800E+00, 0.31545800E+00, -.63297000E+00, 0.22220700E+00, -.69333600E+00, 0.69045300E-01, -.42843100E-01, 0.75760800E+00, 0.16700800E+00, -.12926700E+04, 0.63823100E+03, 0.64495700E+03, 0.10984500E+03, 0.54770400E+02, 0.48725400E+03, 0.27554300E+03, 0.40273200E+01, -.13671900E+03, -.30216200E+04, 0.14244300E+04, 0.15380300E+04, 0.12570900E+04, 0.14803500E+04, 0.68406300E+02, -.11894400E+04, -.12247600E+03, 0.10205900E+04, 0.66505200E+02, 0.61996300E+02, -.17738800E+03, -.98333800E+03, -.83002700E+03, 0.53383000E+03, 0.86418500E+03, 0.14136300E+03, -.37467300E+03, -.13643100E+03, 0.13687500E+03, -.51963700E+02, -.16410600E+03, -.15586200E+04, 0.10262300E+04, 0.20699900E+04, 0.39652800E+03, -.12037700E+04, 0.36173700E+03, -.17732700E+03, 0.21303800E+03, 0.37881700E+03, 0.40092400E+03, -.66554600E+03, -.80170900E+03, -.98805500E+03, 0.43123600E+03, 0.14743800E+04, -.77675600E+03, -.62725200E+03, 0.20373200E+03, 0.46497000E+03, -.40320400E+03, 0.37699300E+03, 0.11737000E+03, -.20099700E+03, -.96184500E+02, 0.46373200E+02, 0.41149100E+02, -.25308200E+03, -.46850500E+02, 0.26452200E+03, -.53522800E+03, 0.74663200E+02, -.31633600E+03, -.34060500E+02, 0.31378000E+02, 0.78879600E+02, 0.22578300E+02, 0.13242500E+03, 0.36476300E+02, 0.14512500E+03, 0.58699600E+02, -.20621800E+02, -.15973900E+04, 0.84324900E+03, 0.10390900E+04, 0.45540100E+03, 0.28528500E+03, 0.46800000E+03, 0.98183400E+03, 0.14042100E+03, 0.18852600E+03, -.21747500E+04, 0.11061400E+04, 0.11069100E+04, -.68859100E+03, -.11589600E+04, 0.13670900E+04, 0.12436000E+04, 0.11904800E+04, -.58644800E+03, -.23833300E+03, 0.12574700E+03, 0.14857700E+03, 0.22435100E+03, 0.36384000E+03, -.31237900E+02, 0.35836400E+03, -.78125200E+02, 0.33049300E+01, -.18396200E+04, 0.91752500E+03, 0.91599600E+03, 0.48664100E+03, 0.19919400E+03, 0.29505400E+03, 0.44826500E+03, 0.18269700E+03, 0.51713400E+03, -.15126600E+04, 0.73310600E+03, 0.37620800E+03, 0.16467100E+03, 0.96455300E+02, 0.10505500E+04, 0.35125100E+03, 0.10758000E+04, -.31995000E+02, -.70375600E+02, 0.40528000E+02, -.12266900E+03, 0.26713400E+03, 0.87985900E+01, 0.26095300E+03, 0.73987700E+03, 0.38107400E+03, 0.30312800E+03, 0.56397300E+04, -.28426500E+04, -.28225300E+04, 0.68172000E+03, 0.15476800E+04, -.25894600E+04, -.72396600E+03, -.29386500E+04, 0.71986400E+03, 0.28803900E+03, -.11292700E+03, -.19546400E+03, -.66222200E+03, -.10356300E+04, 0.49538500E+03, 0.11454900E+04, 0.16342700E+03, -.53517600E+03, 0.17116600E+03, -.23278800E+03, 0.69494300E+01, -.44336800E+03, -.48159900E+02, 0.23131200E+03, -.34457700E+03, 0.10769800E+03, 0.20415300E+03, 0.16884000E+04, -.79043900E+01, -.35159300E+03, 0.40434400E+03, -.85058900E+03, 0.14184500E+02, 0.55338300E+03, -.28244800E+03, -.26241700E+03, -.88415600E+03, -.25818100E+03, 0.40166200E+02, 0.18877500E+02, -.24429000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11216700E+01, 0.17269600E+00, -.15443800E+01, -.16335000E+00, -.18170500E+01, 0.75913900E+00, -.14766700E+01, -.38953900E+00, 0.10752700E+01, 0.83861800E-01, 0.10396200E+00, -.13746800E+00, 0.59087800E-01, -.52579000E+00, -.70801900E+00, 0.16781500E+00, 0.44815900E+00, 0.17231500E+00, 0.39973900E+00, 0.82594900E-01, 0.21830800E+00, -.10075300E+00, 0.15114900E+00, 0.17243700E+00, 0.22750700E+00, 0.70101300E-01, -.50460200E+00, -.11295000E-01, -.23907600E+00, -.81493700E-01, -.75093600E-01, 0.88195000E-01, 0.53348300E-01, 0.77876500E-01, -.48487800E+00, -.89607500E-01, -.10294200E-01, -.62739400E-01, -.34897200E+00, -.11750000E+00, 0.13733300E+00, -.34953100E-01, -.34339400E-01, 0.16995800E-01, 0.50318600E+00, -.13821900E+00, -.10046900E-01, -.11568600E+00, -.40192300E+00, 0.36125400E-01, 0.97103800E-01, -.80165700E-01, 0.22617700E+00, 0.62936000E+00, 0.11268700E+00, -.18159000E+03, 0.77829300E+01, 0.44343400E+03, -.33865100E+03, -.20402000E+03, -.69960800E+03, -.20178400E+03, 0.14740700E+03, -.22480800E+04, 0.87942000E+03, 0.11031700E+04, 0.16785000E+03, 0.11910400E+03, 0.63749600E+03, -.73742600E+02, -.68349500E+02, 0.45581600E+02, 0.22885600E+04, -.95875200E+03, -.10070100E+04, -.11463000E+03, 0.16884400E+03, -.82888400E+03, -.35577500E+02, -.76083700E+02, 0.79914500E+02, 0.38547200E+03, -.30105100E+03, -.37295200E+03, 0.48104700E+03, -.60522100E+03, -.31936400E+03, -.72488200E+03, 0.51307000E+03, -.29041600E+03, 0.80132100E+03, -.40465900E+03, -.69382500E+03, 0.97462800E+02, -.26210900E+03, -.16664000E+03, 0.20123100E+02, -.77525600E+03, -.17416100E+02, -.38271100E+03, 0.28577200E+03, 0.27921200E+03, -.90818400E+02, 0.34219300E+03, 0.26880500E+03, -.37545400E+03, -.34807300E+03, 0.67774900E+03, 0.26043100E+04, -.12958700E+04, -.12978100E+04, 0.22509700E+03, -.42062600E+03, -.10811200E+04, -.96908000E+03, -.10988800E+04, -.46589700E+03, 0.59972900E+03, -.21455500E+03, -.29152100E+03, -.17249800E+03, 0.10183500E+03, -.13162800E+03, -.40647700E+02, -.40667800E+03, 0.75958900E+02, 0.20389900E+04, -.91285400E+03, -.94708500E+03, 0.23285900E+03, 0.71924200E+03, -.93915500E+03, -.76905600E+03, -.97680200E+03, 0.43354300E+03, 0.39719700E+04, -.17995400E+04, -.19633900E+04, -.70842700E+03, 0.50711700E+03, -.10427000E+04, 0.99820500E+02, -.13696900E+04, -.38227800E+03, -.20970800E+03, 0.10976300E+03, 0.59698800E+02, 0.42646300E+03, -.48806400E+02, 0.57425000E+02, -.53106500E+03, -.66404400E+03, 0.41671600E+03, -.45500900E+03, 0.22689700E+03, 0.22855100E+03, -.30008100E+03, 0.34427100E+03, 0.38264000E+03, 0.95572700E+03, 0.54887900E+03, 0.24037500E+03, 0.40769500E+04, -.20121300E+04, -.19923200E+04, -.48836400E+03, 0.25261000E+03, -.11105900E+04, 0.66380200E+03, 0.23434300E+02, -.42779800E+03, 0.67856900E+02, -.35894000E+02, -.32482800E+02, -.28403100E+02, 0.31087800E+03, 0.34709100E+02, 0.17843500E+03, 0.22202100E+03, 0.26942600E+03, -.34846000E+04, 0.15625200E+04, 0.17455700E+04, 0.92219700E+03, -.10568600E+04, 0.10621800E+04, -.20620700E+02, 0.11583300E+04, 0.90253200E+02, -.44041800E+03, 0.13654400E+03, 0.18974400E+03, -.37550300E+02, -.46398500E+03, 0.26595300E+03, 0.81178800E+03, 0.15032200E+04, -.47441000E+03, -.21034700E+02, -.62180800E+02, -.40789900E+02, 0.66646400E+03, 0.39401700E+02, 0.67720900E+02, 0.32571500E+03, -.18891500E+03, -.61345900E+03, -.22161600E+03, -.57671100E+03, 0.60328000E+03, -.32873700E+03, 0.83602000E+03, 0.29486200E+03, -.86052300E+03, -.10582600E+03, -.10128600E+03, 0.87391400E+03, 0.23038200E+03, 0.12124600E+03, -.54444000E+03, -.18683400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24537700E+01, 0.11966200E+00, 0.38833800E+01, 0.17833300E+01, -.58399900E+01, -.65634700E+00, 0.52868200E+01, 0.48744300E+01, 0.82791200E+00, -.14883600E+01, -.55083400E+00, 0.78635500E+00, -.68364700E+00, 0.20404700E+01, 0.94165300E+00, -.91930400E+00, -.60134400E+00, 0.52157700E+00, 0.80039300E+00, -.89279300E+00, -.95909900E+00, -.15858500E+00, 0.64403700E+00, 0.59911500E+00, -.96572600E+00, 0.39293400E+00, 0.73162900E+00, 0.28081200E+00, -.12836500E+00, 0.86058600E+00, -.35721000E+00, -.67579300E+00, -.65676200E+00, -.17327000E+01, -.10414500E+00, -.90192200E+00, -.57314800E-01, 0.32621100E-01, 0.11066400E+01, 0.10459100E+01, 0.10158200E+01, 0.23065700E+00, -.25335100E+00, -.34728000E+00, -.10071000E+01, -.97309400E+00, 0.44051200E+00, -.86705300E+00, 0.81779000E+00, -.91401300E+00, -.56051000E-01, 0.57948200E-02, -.22826300E+00, -.16367100E+01, 0.11438600E+01, -.88066300E+00, -.91752000E+02, -.77739900E+03, 0.42859600E+02, 0.10602900E+03, 0.58094300E+03, -.43025800E+02, -.63882700E+02, -.22693200E+04, 0.16009200E+04, 0.17115000E+04, 0.23565800E+04, 0.32723800E+04, -.20992000E+04, -.31137100E+04, 0.79899500E+03, 0.37094000E+04, -.15815100E+04, 0.26540600E+03, 0.23755200E+03, -.23812000E+04, -.33760400E+04, 0.34070100E+04, 0.24525200E+04, -.13034600E+04, -.31901300E+04, 0.12467800E+05, -.62550800E+04, -.66850800E+04, -.54507000E+04, -.60364700E+04, 0.14804200E+04, 0.48899200E+04, -.44911200E+04, -.63893900E+04, -.83618000E+04, 0.41740600E+04, 0.47172800E+04, 0.22720900E+04, 0.39284200E+04, 0.43584700E+03, -.76996500E+03, 0.38569500E+04, 0.31328600E+04, -.20126400E+04, 0.10130700E+04, 0.13634200E+04, 0.28894000E+04, 0.28139100E+04, -.30150500E+04, -.19343800E+04, 0.14469300E+04, 0.28216400E+04, -.52258000E+04, 0.26046500E+04, 0.25864800E+04, -.11306100E+03, 0.71207200E+03, 0.20468800E+04, 0.30505200E+03, 0.24320200E+04, 0.98344700E+03, -.30344500E+04, 0.14774400E+04, 0.15652100E+04, 0.12628600E+04, 0.13981100E+04, -.54498300E+03, -.12723700E+04, 0.11827500E+04, 0.15824900E+04, -.97082800E+04, 0.47839800E+04, 0.50618800E+04, 0.17796200E+04, 0.21705100E+04, 0.14964900E+04, 0.49993100E+03, 0.29882000E+04, 0.23401400E+04, -.85870900E+04, 0.42098300E+04, 0.42296200E+04, 0.18448000E+04, 0.10668600E+04, 0.11464900E+04, -.19020700E+04, 0.29242200E+04, 0.21130200E+04, -.42104500E+04, 0.20946900E+04, 0.21542200E+04, 0.16584800E+04, 0.28562700E+04, -.86226400E+03, -.35430200E+03, 0.26112300E+04, 0.22912100E+04, 0.27768400E+04, -.13852600E+04, -.13894600E+04, 0.84028800E+01, -.44505800E+03, -.14640800E+04, -.87110700E+03, -.21532900E+04, -.49904000E+03, 0.56925500E+03, -.27562200E+03, -.52308200E+03, -.13865600E+04, -.37313400E+04, 0.13890000E+04, -.82273600E+03, -.29717800E+04, -.22208300E+04, -.13732400E+04, 0.67046600E+03, 0.65440800E+03, -.19284200E+03, -.28092300E+03, 0.94201100E+02, -.62360500E+01, 0.41595000E+02, -.61208600E+03, 0.60638000E+03, -.23920000E+03, -.30932500E+03, -.86066300E+03, 0.10009100E+04, 0.76146100E+03, 0.31656200E+04, 0.29222100E+03, -.40191600E+03, 0.84428800E+04, -.42040900E+04, -.41137000E+04, -.32096400E+04, -.40776300E+04, 0.82708200E+03, 0.16795200E+04, -.48701300E+04, -.40113000E+04, -.23718700E+04, -.23045700E+04, -.24449600E+04, -.33332500E+04, 0.22028400E+04, 0.23023300E+04, -.27850000E+04, -.19523000E+04, -.15855900E+04, 0.11492700E+04, 0.11619100E+04, -.28491800E+04, 0.27469900E+04, 0.28601800E+04, 0.15915300E+04, 0.27782400E+04, 0.35644600E+04, -.14283500E+04, 0.26266600E+04, -.24828000E+04, 0.22937800E+04, 0.47908600E+04, -.32895500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.29166300E+01, 0.90854300E-01, -.47797300E+01, -.22526500E+01, 0.92793100E+01, 0.61795600E+00, -.88197800E+01, -.71859700E+01, -.86633800E+00, 0.18149500E+01, 0.14996600E+01, -.13272600E+01, 0.14219300E+01, -.28248400E+01, -.14516700E+01, 0.14276000E+01, 0.98490600E+00, -.52571100E+00, -.98715100E+00, 0.15913100E+01, -.17700300E+00, 0.85040000E-01, -.73022000E+00, -.10998200E+00, 0.77421600E+00, -.57190500E+00, -.24046300E+00, -.80038000E-01, 0.97637100E+00, -.10361100E+01, 0.47986900E+00, 0.64356000E-01, 0.73773700E+00, 0.12426400E+01, -.35110400E+00, 0.10895100E+01, 0.25343400E-01, -.16296400E-01, 0.18325300E+01, -.45771800E+00, -.11178300E+00, -.11163700E+00, 0.69064700E+00, 0.29201900E+00, -.70007400E+00, 0.92153000E+00, -.41331000E+00, 0.30200000E+00, -.54083100E-01, -.21565600E+01, -.11185500E+00, 0.74641500E-01, -.19828500E+01, -.21153600E+01, -.56813700E+00, -.10224500E+01, -.65999100E+00, -.20174100E+04, 0.89830700E+02, 0.58008500E+03, 0.23522400E+04, 0.83485400E+03, -.26764100E+03, 0.70414000E+04, -.18631900E+04, -.37736700E+04, 0.23546000E+04, 0.53512800E+04, -.60672200E+04, -.43493200E+04, -.28906300E+03, 0.49945900E+04, -.99859300E+04, 0.31998600E+04, 0.57672700E+04, -.21138000E+04, -.57644400E+04, 0.70107500E+04, 0.36295200E+04, -.18076100E+03, -.46083500E+04, 0.16524900E+05, -.84029600E+04, -.85733900E+04, -.86805900E+04, -.67197600E+04, 0.23072400E+04, 0.72875200E+04, -.68836900E+04, -.73154400E+04, -.12973100E+05, 0.64611700E+04, 0.49829100E+04, 0.35979600E+04, 0.61659000E+04, 0.67529300E+03, -.98618700E+03, 0.59310800E+04, 0.45992200E+04, -.30481100E+04, 0.15907200E+04, 0.14445200E+04, 0.36058200E+04, 0.28555000E+04, -.39846000E+04, -.20542900E+04, 0.27550200E+04, 0.23543300E+04, -.90057800E+04, 0.44833800E+04, 0.45080600E+04, 0.57061200E+03, 0.10331200E+04, 0.32186800E+04, -.11575100E+04, 0.40413200E+04, 0.20197200E+04, -.50299800E+04, 0.24056100E+04, 0.24336300E+04, 0.19570200E+04, 0.18244900E+04, -.70152400E+03, -.23150700E+04, 0.20770500E+04, 0.20472200E+04, -.20280400E+05, 0.99374700E+04, 0.97556900E+04, 0.28838300E+04, 0.33193200E+04, 0.37134400E+04, 0.75793100E+01, 0.53826200E+04, 0.43071800E+04, -.12243400E+05, 0.59179400E+04, 0.61059200E+04, 0.44872700E+04, 0.25204400E+04, 0.59118800E+02, -.70088700E+04, 0.31893500E+04, 0.40161200E+04, -.52371500E+04, 0.25836200E+04, 0.23955400E+04, 0.14870800E+04, 0.36246300E+04, -.99788600E+03, 0.34914700E+03, 0.46622600E+04, 0.24861600E+04, 0.57911700E+04, -.28824300E+04, -.28810200E+04, -.86783900E+03, -.70830700E+03, -.23852900E+04, 0.37903600E+03, -.33929200E+04, -.13282100E+04, -.50756600E+04, 0.26034700E+04, 0.34267800E+04, -.20227200E+04, -.53475000E+04, 0.32664900E+04, -.29025200E+04, -.43533800E+04, -.19681000E+04, -.25578000E+04, 0.12662900E+04, 0.14911000E+04, -.14092300E+04, -.66160300E+03, 0.31391000E+03, -.31132700E+02, -.67536100E+03, -.12657200E+04, -.63746700E+04, 0.33397300E+04, 0.31971100E+04, -.24395200E+04, 0.78035100E+03, 0.45254100E+04, 0.78337200E+04, 0.38588500E+04, -.74062100E+03, 0.11482800E+05, -.57356400E+04, -.56795400E+04, -.34052400E+04, -.37948500E+04, 0.30653900E+03, 0.94631100E+03, -.86521100E+04, -.41111200E+04, -.35210900E+04, -.31294600E+04, -.35251400E+04, -.50728700E+04, 0.32141000E+04, 0.31260700E+04, -.39188800E+04, -.28115500E+04, -.28765900E+04, -.21478100E+04, 0.22095100E+04, -.47474500E+04, 0.38584200E+04, 0.51602200E+04, 0.19235600E+04, 0.42318300E+04, 0.55884500E+04, -.17190000E+04, 0.49168400E+04, -.37028000E+04, 0.31521600E+04, 0.77182500E+04, 0.10191400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.55483700E+01, 0.16251300E+01, 0.66523000E+01, 0.22349300E+01, -.52293100E+01, -.10205700E+01, 0.99543900E+01, 0.44411900E+01, -.16361000E+01, 0.12890600E+00, -.38538100E+01, 0.20404000E+01, -.21176100E+01, 0.24715500E+01, 0.23343800E+00, -.14749900E+01, 0.14880400E+01, 0.43499700E+00, 0.14356800E+00, -.21227400E+01, 0.75937400E+00, 0.21697200E+00, -.80040300E+00, -.32055100E+00, -.15007500E+01, 0.56646600E+00, 0.85290800E+00, 0.20689400E+00, -.37045800E+01, 0.98776100E+00, 0.38112500E+00, 0.77867100E+00, -.13280800E+01, -.55342400E+00, 0.82351500E+00, 0.65951200E+00, 0.88154200E-01, 0.58743900E+00, -.10449900E+01, 0.18212800E+01, -.11072100E+01, 0.16159400E+00, -.67644400E+00, -.48782000E+00, -.19074500E+01, -.20929000E+01, 0.19918200E-01, 0.36955500E-01, 0.52517700E+01, -.76729600E+00, -.42359800E+00, 0.35192500E+00, 0.22320800E+00, -.47549600E+00, 0.11945000E+01, -.37145100E+01, -.39267100E+00, -.90475700E-01, -.12328200E+04, 0.16858000E+03, 0.91809500E+03, 0.59644000E+03, -.55974600E+03, -.33330000E+04, 0.14955500E+04, 0.15551600E+04, 0.36889300E+04, 0.53675200E+04, -.31767700E+04, -.76209100E+04, -.43624400E+04, 0.47125500E+04, 0.32697000E+04, -.14688400E+04, -.14306500E+04, -.40839000E+04, -.52230100E+04, 0.29730500E+04, 0.70006500E+04, 0.36495900E+04, -.45176800E+04, 0.62167200E+04, -.30077000E+04, -.39344700E+04, -.22384200E+04, -.63444700E+04, 0.18403900E+04, 0.51063000E+04, 0.28433000E+03, -.50897000E+04, -.26501800E+04, 0.13234500E+04, 0.12254400E+04, 0.24082800E+04, 0.28169500E+04, -.12696800E+04, -.18744600E+04, -.26230000E+04, 0.25759000E+04, -.44946000E+04, 0.22106300E+04, 0.26432100E+04, 0.17321400E+04, 0.34090200E+04, -.68390800E+03, -.16188000E+04, 0.11159900E+03, 0.29771700E+04, 0.35762600E+03, -.17593300E+03, -.19580400E+03, 0.36677800E+03, -.84728100E+03, 0.14337200E+03, -.25066400E+04, 0.11350000E+04, -.22990200E+03, -.15780400E+04, 0.82638000E+03, 0.93691700E+03, 0.42380000E+03, 0.12623700E+04, -.36389200E+03, -.91057300E+03, -.26561800E+03, 0.11342900E+04, -.54164200E+04, 0.26942000E+04, 0.33608400E+04, 0.18193900E+04, 0.22185200E+04, 0.42858400E+03, 0.91077800E+03, 0.94623600E+03, 0.23444300E+04, 0.19410200E+04, -.90702500E+03, -.89486500E+03, -.83029300E+03, 0.81242400E+03, -.14172700E+04, -.22157800E+04, -.11863600E+04, 0.63281300E+03, -.44485300E+04, 0.22276100E+04, 0.21161100E+04, 0.22469300E+04, 0.23556300E+04, -.20088600E+03, -.34786000E+03, -.27143300E+03, 0.24192200E+04, 0.57154100E+03, -.29028200E+03, -.28506300E+03, 0.31107600E+02, 0.95916600E+03, -.61595200E+03, 0.19291400E+04, -.17996000E+04, 0.25668300E+03, 0.58987600E+04, -.29769100E+04, -.34822500E+04, -.23330500E+04, -.22744600E+04, 0.28967400E+03, 0.97528700E+03, 0.27283300E+04, -.27015400E+04, 0.99855700E+03, -.51388900E+03, -.82608300E+03, -.26895500E+03, 0.58006100E+03, -.56734000E+03, 0.60744100E+03, 0.37873400E+03, 0.22181300E+03, -.37034200E+04, 0.18322100E+04, 0.18547700E+04, 0.17636700E+04, -.10361200E+02, 0.15450700E+04, 0.38571100E+04, 0.10277300E+04, 0.64228400E+03, 0.91102600E+04, -.45333100E+04, -.46990800E+04, -.37299700E+04, -.50412700E+04, 0.53964000E+03, 0.42754300E+04, 0.43122700E+03, -.44990200E+04, -.20698500E+04, -.19474200E+04, -.21789100E+04, -.95758000E+03, 0.19439600E+04, 0.19532000E+04, -.80275700E+03, -.22015300E+04, -.32107300E+04, 0.22864600E+04, -.16386400E+04, -.91978600E+03, 0.72998500E+03, 0.31114800E+04, 0.19399800E+04, 0.42576400E+03, 0.29600600E+04, -.11144300E+04, 0.29481600E+04, -.13332900E+04, 0.21360900E+04, 0.31899600E+04, -.97704700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.48304400E+00, 0.76889500E-01, 0.86473900E+00, -.17614400E+00, 0.45780200E+01, -.35262000E-01, -.45266600E+01, -.24010700E+01, -.35123400E+00, 0.19747100E+00, 0.14692900E+01, -.11229900E+01, 0.13579400E+01, -.11466300E+01, -.24833600E+00, 0.38454500E+00, 0.18993300E+00, -.27644900E+00, -.12982000E+01, 0.10703800E+01, -.24938500E+01, 0.20797800E+00, -.62947000E+00, 0.31391100E+00, -.18658700E+00, -.47479300E+00, 0.55998800E+00, 0.18893800E+00, -.12144200E+01, 0.11822100E+00, 0.15497200E+00, 0.20396400E+00, -.60504600E+00, -.21696500E+00, 0.26265700E+00, -.91929400E+00, -.40849100E+00, 0.30039400E+00, 0.15466600E+01, 0.63681900E+00, 0.14811300E+01, 0.20689500E+00, -.18253100E+00, -.27621900E+00, -.16767500E+01, 0.61375400E-01, 0.10747200E-02, 0.18691800E+00, -.66572900E+00, -.10253100E+01, 0.12966500E+00, -.12249100E+00, 0.75846400E+00, -.16372700E+01, 0.37352300E+00, -.26575700E+00, -.11091300E+00, 0.11331300E+00, 0.19845700E-01, -.13485300E+03, -.55410600E+03, -.17075600E+03, 0.46290600E+03, -.82317900E+04, 0.41335200E+04, 0.42045500E+04, 0.24145300E+03, -.34471700E+01, 0.32334200E+04, 0.28554900E+04, 0.43076000E+04, 0.31924800E+03, 0.65605600E+04, -.33073700E+04, -.34312300E+04, -.27234200E+03, -.54900400E+02, -.25248700E+04, -.25685000E+04, -.39519200E+04, -.44641800E+03, 0.61412800E+04, -.30946400E+04, -.29411800E+04, -.18022900E+04, -.20996200E+04, -.79563400E+03, -.92387900E+03, -.23414200E+04, -.18787900E+04, -.37236300E+04, 0.18572700E+04, 0.21474800E+04, 0.29789800E+03, 0.77527300E+03, 0.69822000E+03, 0.37148000E+03, 0.26247400E+04, 0.11057500E+04, -.18394000E+04, 0.93731700E+03, 0.92385700E+03, 0.13200800E+04, 0.12995600E+04, -.47559000E+03, -.55970800E+03, 0.62550900E+03, 0.16267800E+04, 0.10179900E+04, -.50496000E+03, -.50713400E+03, -.78763500E+03, 0.43790900E+02, -.19548600E+03, 0.20388100E+04, 0.12324900E+03, -.25929100E+03, -.70667100E+03, 0.34997900E+03, 0.35908200E+03, 0.26995400E+03, 0.43935600E+03, -.37390100E+02, 0.16284300E+03, 0.53504000E+03, 0.40699200E+03, 0.19273900E+04, -.97497500E+03, -.99604000E+03, 0.39127000E+03, 0.53885700E+03, -.11651700E+04, -.70170300E+03, 0.81981100E+01, 0.23718400E+03, -.81760500E+03, 0.40505400E+03, 0.40775600E+03, -.41070500E+03, 0.62540900E+02, 0.43549700E+03, 0.15997400E+04, 0.12178400E+04, -.32215400E+03, -.14417400E+04, 0.71943600E+03, 0.77854100E+03, 0.77724800E+03, 0.96128100E+03, -.31123800E+03, -.77550000E+03, 0.81519700E+03, 0.12191200E+04, -.12591600E+04, 0.62555200E+03, 0.62540200E+03, 0.56244000E+03, -.74172200E+02, 0.25147900E+03, -.19881400E+04, -.12436200E+02, 0.31006600E+03, 0.50323900E+04, -.24984000E+04, -.26650700E+04, 0.13048800E+03, -.11936500E+04, -.12835500E+04, 0.32276200E+03, -.26534800E+04, -.13729000E+04, -.11488200E+04, 0.57531200E+03, 0.54877400E+03, 0.37862900E+03, 0.12877200E+03, 0.12183500E+03, -.56389400E+03, 0.23139700E+03, 0.20005900E+03, 0.24656600E+04, -.12229100E+04, -.12350500E+04, 0.12852200E+03, -.40133400E+03, -.85888000E+03, -.15542600E+04, -.67262400E+03, -.20625600E+02, 0.23516400E+04, -.11921600E+04, -.11893000E+04, -.84690100E+03, -.13711800E+04, 0.13526100E+03, -.41554300E+03, -.13082300E+04, -.15447100E+04, -.91075000E+03, -.72647200E+03, -.63625700E+03, -.96631100E+03, 0.85280500E+03, 0.72754900E+03, -.10620000E+04, -.89737000E+03, 0.24830700E+03, 0.40206300E+03, 0.55709300E+03, -.74081900E+03, 0.93005300E+03, -.11957500E+03, 0.46537200E+03, 0.49096800E+03, -.21796400E+03, -.41620300E+03, -.26739200E+03, -.82102000E+03, 0.73201600E+03, -.91692100E+02, -.10032400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10674100E+01, -.12779600E-01, -.20501200E+01, 0.35969000E+00, -.63781300E+01, 0.11343900E+01, -.67640000E-01, 0.91515100E+00, -.33285800E+00, -.94359100E+00, -.16290100E+01, 0.58096000E+00, -.71235200E+00, -.12355700E+01, -.99115400E+00, -.64506800E+00, 0.16193000E+01, -.73079600E-01, -.97112400E-01, 0.10404400E+01, -.55320700E+00, -.12151500E+00, -.47060800E-01, 0.38733900E-01, 0.17605200E+00, -.18923700E+00, -.30499200E+00, 0.14557700E+00, 0.37099500E+00, 0.10868700E+00, 0.35119700E+00, 0.32410500E+00, -.34212100E+00, 0.92617800E-01, 0.48273600E+00, -.23468600E+00, -.10896000E+00, -.49378000E-02, 0.36516100E+00, 0.24737100E+00, -.56777800E+00, -.37768000E-01, 0.88255800E+00, 0.51665400E+00, -.11018800E+01, 0.43052300E-01, -.36012600E-01, 0.62884900E+00, 0.13395300E-01, -.93655700E+00, 0.21490700E-01, -.64386500E-01, 0.46367500E+00, -.98904400E+00, -.50670600E+00, -.33948900E+00, 0.34137600E-01, 0.29806700E-02, -.24311300E+00, 0.24507900E+00, 0.53582300E+03, 0.37732100E+02, -.12238000E+03, 0.92862300E+03, -.41484900E+03, -.50514200E+03, 0.12913700E+04, 0.19272100E+04, -.17633400E+04, -.25006700E+04, -.25777200E+04, 0.17468700E+04, -.98767300E+03, 0.45342100E+03, 0.37623100E+03, -.12616700E+04, -.17407800E+04, 0.15360500E+04, 0.23010000E+04, 0.22885200E+04, -.13860300E+04, 0.33642200E+03, -.17128200E+03, -.15883500E+03, -.55696700E+03, -.14452800E+04, 0.92494800E+03, 0.22608400E+04, 0.59784600E+03, -.14402900E+04, -.15502700E+04, 0.77522500E+03, 0.12057600E+04, 0.67214100E+03, 0.99823100E+03, -.17387200E+03, -.60634600E+03, -.71677800E+03, 0.75332100E+03, -.75206400E+03, 0.38111400E+03, 0.38626200E+03, 0.57379500E+03, 0.10370400E+04, -.35949900E+03, -.59726700E+03, -.18926600E+03, 0.73227000E+03, -.47532900E+03, 0.23808800E+03, 0.22885500E+03, 0.17776500E+03, -.18707600E+03, 0.21246400E+03, -.15957400E+04, 0.45178400E+03, -.17412300E+03, -.56991100E+03, 0.28447500E+03, 0.33024400E+03, 0.21662800E+03, 0.37289200E+03, -.83464000E+02, -.36875000E+03, -.17658300E+03, 0.35758300E+03, -.32184900E+04, 0.16081600E+04, 0.17652700E+04, 0.68310400E+03, 0.52860000E+03, 0.79535600E+03, 0.10969900E+04, 0.57595500E+03, 0.53617100E+03, -.28490100E+04, 0.14218100E+04, 0.14335300E+04, 0.13570700E+03, -.11808100E+03, 0.80666200E+03, -.25630200E+03, 0.66553900E+03, 0.38291600E+03, -.15971000E+04, 0.79716900E+03, 0.83968900E+03, 0.53789500E+03, 0.81174500E+03, 0.43787500E+02, 0.12374700E+02, -.97563300E+02, 0.45841900E+03, -.42489000E+03, 0.21126000E+03, 0.20979000E+03, 0.10327400E+03, 0.26617000E+03, 0.10971900E+02, 0.13685900E+04, -.42074900E+03, 0.31598800E+03, -.50061700E+03, 0.25232700E+03, -.72534500E+02, -.39809500E+03, -.99077600E+03, 0.91645200E+03, 0.48488700E+03, 0.20955800E+04, -.50843000E+03, -.28776900E+03, 0.14089900E+03, 0.11528900E+02, -.56188200E+02, -.16548600E+03, 0.44529400E+03, 0.18546300E+04, 0.95993300E+03, -.20284900E+03, 0.10110400E+04, -.50892500E+03, -.50882900E+03, 0.15250800E+03, 0.97373800E+03, -.55329200E+03, 0.10768100E+04, -.92906700E+03, 0.28906000E+03, 0.29246500E+04, -.14620700E+04, -.14970500E+04, -.12107000E+04, -.14063100E+04, -.18552600E+02, 0.16259000E+04, 0.19310900E+03, -.11592200E+04, -.45197300E+03, -.87661600E+03, -.70377800E+03, -.49048500E+03, 0.43464200E+03, 0.87541800E+03, -.91962600E+02, -.48013200E+03, -.88112000E+03, 0.10704100E+04, -.36530300E+03, -.46911300E+03, 0.17105800E+03, 0.11837800E+04, 0.56446000E+03, 0.41554000E+03, 0.11253400E+04, -.39118200E+03, 0.10527800E+04, -.50094800E+03, 0.58440100E+03, 0.15139100E+04, -.34438600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24353500E+01, 0.10500600E+01, 0.31016700E+01, 0.74491500E+00, -.14851200E+01, 0.43568700E-01, 0.36496300E+01, 0.15334500E+01, -.40253600E+00, 0.51673600E-01, -.12127100E+01, 0.79602600E+00, -.60145000E-01, 0.50190100E+00, 0.57425500E+00, -.62290300E+00, 0.68279400E+00, 0.31758500E+00, 0.45056900E+00, -.31880600E+00, -.30171300E+00, 0.13723300E+00, 0.54626000E-02, -.18192800E+00, 0.19707200E+00, 0.12819800E+00, -.30419600E+00, 0.19182100E-01, -.11251400E+00, 0.63688200E+00, 0.10889100E+00, 0.23146600E+00, -.11681600E+00, -.24484200E-01, 0.15095000E+01, 0.72247000E+00, 0.94840900E-01, 0.97190400E-01, 0.44422500E+00, 0.77314700E+00, 0.50166000E+00, -.20541300E-01, 0.73901700E-01, -.23994100E+00, -.96067400E+00, 0.10458200E+00, -.18569600E+00, 0.29593100E+00, 0.20627000E+00, 0.35539400E-01, 0.27636300E-02, 0.85691000E-01, 0.42109800E+00, -.33231700E+00, -.39154700E+00, -.42776100E+00, -.25624300E+00, -.11672900E+00, -.41812600E-02, -.38283500E+00, 0.83656300E-01, -.18975800E+03, 0.13749700E+03, -.72804900E+04, 0.35147600E+04, 0.37802600E+04, 0.14327900E+04, 0.10999700E+04, 0.14158100E+04, -.10822800E+04, 0.18157800E+04, 0.15005700E+04, 0.32749700E+04, -.15268300E+04, -.18616600E+04, -.10425900E+04, -.32219300E+03, -.55016100E+03, 0.44490200E+03, -.17209200E+04, -.68349400E+03, 0.37730100E+04, -.18730200E+04, -.20443800E+04, -.10532800E+04, -.19838500E+04, 0.34660300E+03, 0.12769300E+04, -.87722500E+03, -.16767800E+04, -.15730700E+04, 0.78774600E+03, 0.13055500E+04, 0.29497600E+03, 0.62002500E+03, -.33508300E+02, -.42204900E+00, 0.11394300E+04, 0.62984400E+03, -.29846800E+03, 0.14729800E+03, 0.31517900E+03, 0.40259900E+03, 0.57876000E+03, -.70398800E+03, -.59378300E+03, 0.42904400E+03, 0.57119800E+03, -.84954300E+03, 0.42496200E+03, 0.42384400E+03, -.13613300E+03, 0.12950800E+03, 0.26252600E+03, 0.39245500E+03, 0.20615300E+03, 0.50596400E+03, -.22365500E+03, 0.12171900E+03, 0.17654700E+03, 0.57229200E+02, 0.31188100E+03, -.22565300E+03, -.23750500E+03, 0.92697300E+02, 0.27788900E+03, -.93848800E+03, 0.47097100E+03, 0.71370200E+03, 0.47291300E+03, 0.50025600E+03, -.15114200E+03, -.16980800E+02, 0.47425400E+03, 0.64834300E+03, 0.25474400E+04, -.12547500E+04, -.12437400E+04, -.23952500E+03, 0.32946000E+03, -.12656700E+04, -.80607900E+03, -.11144600E+04, 0.28252500E+02, -.54266000E+03, 0.27424500E+03, 0.33909700E+03, 0.35642700E+03, 0.44780200E+03, -.28096600E+03, -.13229900E+03, 0.52095700E+03, 0.59046300E+03, 0.47887200E+03, -.24013800E+03, -.24598700E+03, 0.14938600E+03, 0.39231600E+02, -.27658000E+03, -.63532300E+03, -.32560700E+03, -.36540400E+03, 0.12475200E+04, -.63200400E+03, -.10913200E+04, 0.37105700E+03, -.36670500E+03, -.24054400E+03, -.24184300E+03, -.13872000E+04, -.41816800E+03, 0.36516900E+03, -.18775200E+03, -.32352900E+03, 0.37340300E+03, 0.12330900E+03, -.35457600E+03, -.46604000E+03, -.14056300E+03, 0.12621100E+03, -.17826600E+04, 0.87861800E+03, 0.88912500E+03, 0.22749800E+03, -.27894900E+03, 0.97593400E+03, 0.96584500E+03, 0.10414800E+04, 0.26299300E+03, 0.13373400E+04, -.67291900E+03, -.74503900E+03, -.58760100E+03, -.88487000E+03, 0.39264400E+03, 0.45994600E+03, -.85352200E+03, -.79696300E+03, -.33257400E+03, -.14841400E+03, -.22064400E+03, -.68427800E+03, 0.32016200E+03, 0.15016100E+03, -.69154200E+03, -.30611200E+03, 0.22484300E+03, 0.18329200E+04, -.57944900E+02, -.47761600E+03, 0.62808400E+03, 0.38719800E+03, 0.26965300E+03, 0.39307400E+03, 0.47544800E+03, -.26824800E+03, 0.58334900E+03, -.45980400E+03, 0.27127600E+03, 0.29110100E+03, 0.39076700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.67768900E+00, -.42941900E+00, 0.76365500E+00, 0.39343000E+00, -.16990400E+01, 0.10421300E+00, 0.20340200E+01, 0.64748700E+00, -.10266700E+01, -.55991200E+00, -.43274500E+00, 0.45686300E+00, -.50332400E+00, 0.10047800E+01, 0.10776200E+00, -.12976900E+00, -.35621000E+00, -.34188100E+00, -.26485600E+00, -.12288600E+00, 0.83871900E+00, 0.12214500E+00, -.34138600E+00, -.35376300E+00, 0.10235400E+00, 0.91781600E-01, -.48965600E+00, 0.30792600E-01, -.77483700E+00, 0.52665700E+00, 0.16837400E+00, 0.27258600E+00, -.14490400E+00, 0.87540700E-01, 0.21120300E+00, -.25263000E+00, -.11297800E+00, 0.10062600E+00, 0.20551800E+00, -.55225200E-01, -.58918000E+00, -.15635900E+00, 0.13716300E+01, 0.45476800E+00, -.15220800E+01, -.21250800E+00, -.23236600E+00, 0.97449000E+00, 0.13111500E+01, 0.64854000E-01, -.82308100E-01, 0.96447000E-01, 0.26523500E+00, 0.39090400E+00, -.27755100E+00, -.42530500E+00, -.26835300E+00, -.99685600E-01, 0.16237600E+00, -.22260800E+00, 0.28209400E+00, 0.11203000E+00, 0.36066500E+03, -.33219900E+04, 0.14141300E+04, 0.16722200E+04, -.60772500E+03, -.12460600E+04, 0.18571900E+04, 0.16510300E+04, 0.27069400E+04, -.59066200E+03, 0.13785400E+04, -.44926500E+03, -.62868600E+03, 0.80309700E+03, 0.13800700E+04, -.12265400E+04, -.14637800E+04, -.21381500E+04, 0.71324800E+03, 0.30146700E+03, -.14232600E+03, -.11561600E+03, 0.43672600E+02, 0.25121600E+03, -.44128000E+03, -.47317600E+03, -.59786300E+03, 0.34260700E+03, -.19023400E+03, 0.95168300E+02, -.92874300E+02, -.51573000E+03, -.52207000E+03, 0.48602600E+03, 0.79097000E+03, 0.11839900E+04, -.28039900E+03, 0.92155100E+03, -.47019700E+03, -.46663700E+03, -.32287200E+03, -.59200900E+03, 0.16141800E+03, 0.39672400E+03, 0.40994200E+03, -.20109000E+03, 0.19524800E+04, -.97142700E+03, -.97358800E+03, -.20269700E+03, -.22991000E+02, -.63742200E+03, -.55431400E+02, -.59046900E+03, -.53852800E+03, 0.43879400E+02, -.20932700E+02, -.35733600E+02, -.14928400E+03, -.22597000E+03, 0.18717300E+03, 0.26099600E+03, 0.43210900E+03, -.17394300E+03, 0.68186500E+03, -.33382200E+03, -.44567100E+03, -.60793500E+02, -.20859500E+03, -.16940900E+03, -.25692300E+03, -.79400100E+02, -.27539700E+03, -.23407400E+04, 0.11668900E+04, 0.11636400E+04, -.52121800E+03, -.58080700E+03, 0.14358500E+04, 0.14109300E+04, 0.19499700E+04, -.68453300E+03, 0.86543300E+03, -.42830100E+03, -.45547700E+03, -.22160500E+03, -.33912100E+03, -.80313800E+02, 0.98960900E-01, 0.31757600E+03, -.79012600E+02, -.17757200E+04, 0.88257500E+03, 0.88799600E+03, -.19803100E+02, -.12348100E+03, 0.66131400E+03, 0.26984200E+03, 0.66703700E+03, 0.48219000E+03, 0.98809700E+03, -.50264000E+03, -.37616700E+03, 0.64484400E+03, 0.26359200E+03, -.73592000E+03, -.79673500E+03, -.17158100E+04, 0.11107200E+03, -.55668800E+03, 0.27533100E+03, 0.29839200E+03, 0.16971200E+03, 0.13229000E+03, 0.10511900E+03, -.28467200E+03, -.28107200E+03, 0.22537400E+03, 0.24213400E+04, -.12064100E+04, -.12103200E+04, 0.30284400E+03, 0.28322400E+03, -.12274900E+04, -.12576400E+04, -.12186000E+04, 0.38038500E+03, -.16878900E+04, 0.84242100E+03, 0.85508500E+03, 0.57310400E+03, 0.62657300E+03, 0.12072500E+03, -.52498600E+03, -.30308100E+03, 0.29681100E+03, 0.21305100E+03, 0.44166600E+03, 0.39561400E+03, -.57767200E+02, -.21770200E+03, -.44289500E+03, -.16995700E+03, 0.14100000E+03, 0.21901700E+03, -.95280100E+03, 0.32565200E+03, -.25642600E+02, 0.15406100E+03, -.66002400E+03, -.30390700E+03, 0.50784800E+02, -.12410200E+04, 0.17753700E+03, -.82045100E+03, 0.70271700E+02, -.32902800E+03, -.90213100E+03, 0.24555300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11397400E+00, -.32112900E+00, -.48557900E+00, 0.12149700E+00, -.11040800E+01, -.96335200E-01, 0.67337400E+00, 0.77427700E+00, 0.76383800E+00, -.25470000E-01, -.12881200E+01, 0.26718900E+00, -.32156200E+00, 0.27934700E+00, 0.27508900E+00, -.26923200E+00, -.67428400E-01, 0.10545800E+00, 0.21311100E+00, -.82939500E-01, 0.59729600E+00, -.10475300E+00, 0.17307100E+00, -.32474000E-01, 0.60567200E-01, 0.91165500E-01, -.45684500E+00, -.26895400E-01, 0.20419500E+00, -.40346200E-01, -.99658000E-01, -.29615100E+00, 0.30080900E-01, -.21177900E-01, 0.62869200E-01, -.34434700E+00, 0.11513400E-01, -.14801000E+00, -.19405900E+00, 0.28318000E-01, 0.44101000E-01, 0.50602800E-01, -.33803500E+00, 0.90990500E-01, 0.46226300E+00, 0.10489200E+00, 0.12355600E-01, -.10564200E+00, -.24332100E+00, -.46565800E+00, 0.10534900E+00, 0.13178100E-01, -.13871800E-01, 0.22472200E+00, -.67746200E-01, 0.52834100E+00, 0.10391400E+00, 0.10897000E-01, -.98833000E-01, -.25424500E+00, 0.10469700E+00, -.25613200E+00, 0.27150300E+00, -.29671100E+04, 0.15226200E+04, 0.15612800E+04, 0.93086500E+02, 0.89193000E+02, 0.11903100E+04, 0.10532500E+04, 0.12344600E+04, -.83200400E+01, 0.25643700E+04, -.13196400E+04, -.14792900E+04, -.14444400E+03, -.84962600E+02, -.10107500E+04, -.89419100E+03, -.11946800E+04, -.43149800E+02, 0.15853600E+04, -.78747600E+03, -.75634100E+03, -.29503600E+03, -.72603900E+03, -.26898400E+03, -.10440300E+03, -.70141800E+03, -.44434400E+03, -.51136500E+03, 0.25583300E+03, 0.69322500E+03, 0.90583500E+02, 0.13541000E+03, -.15921500E+02, -.58206100E+02, 0.40065100E+03, 0.26074200E+03, -.83626400E+03, 0.42090600E+03, 0.44193100E+03, 0.35702100E+03, 0.57830600E+03, 0.13198200E+03, 0.63989200E+02, 0.40031800E+03, 0.19455100E+03, 0.12306400E+04, -.61384300E+03, -.61561700E+03, -.60263000E+03, -.27576300E+03, -.24390000E+03, 0.66661700E+03, -.67805800E+02, -.21083600E+03, -.34273800E+03, 0.17629800E+03, 0.19256400E+03, 0.11939200E+03, 0.24872800E+03, 0.57223400E+02, 0.15510500E+03, 0.12856600E+03, 0.10577300E+03, 0.62474500E+03, -.31687000E+03, -.21273500E+03, 0.45423400E+02, 0.28008100E+02, -.26230900E+03, 0.11552400E+03, 0.10856600E+03, 0.25261000E+02, 0.15774500E+04, -.77744500E+03, -.78074000E+03, 0.20550500E+02, -.16129600E+03, -.60089000E+03, 0.18212700E+03, -.55917800E+03, -.28067100E+03, -.95112800E+03, 0.47579400E+03, 0.54634500E+03, 0.29873400E+03, 0.43150800E+03, 0.80202200E+02, -.62484100E+02, 0.27599400E+03, 0.35516500E+03, -.18417300E+04, 0.91903900E+03, 0.91712900E+03, 0.63655700E+03, 0.32287400E+03, 0.42861200E+03, -.65273000E+03, 0.23316000E+03, 0.27518900E+03, 0.92936000E+03, -.46068100E+03, -.71792200E+03, -.12056000E+03, -.28824400E+03, -.79122800E+02, 0.33156200E+03, -.18732500E+03, -.43611100E+03, -.40061900E+03, 0.20137800E+03, 0.15960000E+03, 0.24097100E+03, -.49270100E+02, 0.71505100E+02, -.56101500E+02, 0.27021500E+03, 0.49170600E+02, 0.13110000E+04, -.65912300E+03, -.65752200E+03, 0.36660500E+02, 0.15513400E+03, -.55551900E+03, -.54483800E+03, -.50341700E+03, 0.29796800E+03, 0.14248200E+04, -.71653800E+03, -.73735100E+03, -.41134400E+03, -.76671600E+03, -.11629500E+03, 0.49782400E+02, -.37423800E+03, -.56805500E+03, -.31359300E+03, -.45125500E+03, -.32194800E+03, -.35142900E+03, 0.32899400E+03, 0.45115800E+03, -.38431500E+03, -.33587600E+03, 0.15510300E+03, 0.44902100E+03, 0.40261300E+02, -.25860000E+03, 0.30778800E+03, -.23309200E+03, 0.14181800E+03, 0.31357200E+03, -.52992000E+02, -.50136600E+02, -.12962400E+03, -.31883700E+03, 0.36774100E+03, -.16542200E+03, -.22378900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.49983000E+00, 0.12693200E+00, 0.38254500E+00, -.70024500E-01, 0.23665700E+01, -.43248900E-01, -.26297500E+01, -.92944500E+00, 0.41836100E-03, 0.13607600E+00, 0.93064100E+00, -.69298500E+00, 0.61822200E+00, -.64571700E+00, -.22365800E+00, 0.15645600E+00, 0.79713600E-01, -.18204700E+00, -.93922400E+00, 0.12607600E+00, -.26585200E+01, 0.26985100E+00, -.38960200E+00, 0.41952100E+00, 0.35464900E+00, -.20467400E+00, 0.31821300E+00, 0.29687900E+00, -.20513500E+00, 0.43627300E+00, 0.16837300E+00, 0.50841300E+00, -.18555200E+00, -.69748200E+00, -.30094200E+00, -.13193300E+00, -.30978600E-01, 0.38644300E+00, -.11055900E+01, 0.63468600E+00, 0.19635500E+00, 0.20549300E+00, -.76380000E+00, 0.11927000E-02, 0.75545100E+00, 0.79022100E+00, -.12733900E+00, 0.43184100E+00, -.12093300E+01, -.24706500E+00, 0.14229300E+00, 0.46088800E-01, -.77010000E+00, -.10158800E+01, -.51727800E+00, 0.22911800E+00, 0.47574700E-01, -.58555400E-02, -.23259400E+00, -.31258600E-01, 0.25807900E+00, -.47216700E-01, 0.70001400E+00, -.10079200E+01, 0.41564200E+03, 0.52484700E+03, -.21895600E+03, 0.78213900E+03, 0.16341800E+03, 0.15870600E+04, 0.67498600E+03, -.24712300E+03, -.70518200E+03, -.73541700E+02, -.37430500E+03, 0.56160200E+03, -.11875600E+03, -.31137600E+03, -.17516900E+04, -.14311200E+04, 0.61158700E+03, 0.28141900E+04, -.14151000E+04, -.17130600E+04, -.73762900E+03, -.13139900E+04, -.11693500E+03, -.39836300E+03, -.15248300E+04, -.53027500E+03, -.52036800E+03, 0.25993000E+03, 0.14207500E+04, 0.19936000E+03, 0.33986900E+03, -.25005400E+03, -.68061500E+02, 0.12999500E+04, 0.42878800E+03, -.85739000E+03, 0.45045300E+03, 0.73885200E+03, 0.51827700E+03, 0.88498800E+03, -.14034200E+03, 0.29202300E+03, 0.10142300E+04, -.18448400E+02, 0.13419900E+04, -.67139900E+03, -.64807300E+03, -.10199600E+04, -.59750200E+03, -.22148100E+03, 0.85020800E+03, 0.17766700E+03, 0.79096300E+02, -.25073200E+03, 0.12577600E+03, 0.16740900E+03, 0.27512600E+03, 0.56788300E+03, -.19272900E+03, 0.17023500E+02, 0.40840900E+02, 0.20572300E+03, 0.12778200E+03, -.11074900E+03, 0.36922300E+03, 0.14938400E+03, 0.63462800E+03, -.57237800E+03, -.36963800E+03, 0.13171200E+03, 0.88001500E+03, 0.86370900E+04, -.43051700E+04, -.42647700E+04, 0.33967000E+03, 0.49164400E+03, -.38004600E+04, -.20642300E+04, -.38684400E+04, -.35014100E+03, -.15739000E+04, 0.78178700E+03, 0.10201900E+04, 0.41015200E+03, 0.72763400E+03, 0.11208400E+03, 0.21693700E+01, 0.84257700E+03, 0.72137100E+03, -.22685600E+04, 0.11346600E+04, 0.11224900E+04, 0.11368200E+04, 0.89160200E+03, 0.41188300E+03, -.10279700E+04, 0.34908000E+02, 0.13285200E+03, 0.32693000E+03, -.14061200E+03, -.82558400E+03, -.13814500E+03, -.26673700E+03, 0.18941900E+03, 0.91837300E+02, -.10585700E+04, -.41696200E+03, -.12591300E+04, 0.64217500E+03, 0.71527900E+03, 0.25745300E+03, -.10827800E+03, 0.26694800E+03, -.29065900E+03, 0.51948400E+03, 0.11928200E+03, -.37253800E+04, 0.18716000E+04, 0.18645300E+04, -.15320700E+03, -.76989100E+03, 0.17133300E+04, 0.98448500E+03, 0.18772100E+04, 0.58144700E+03, 0.23381400E+04, -.11818500E+04, -.12487900E+04, -.40505300E+03, -.11042900E+04, -.24406400E+03, -.21308300E+03, -.12010200E+04, -.68867700E+03, -.45357400E+03, -.76022000E+03, -.45231300E+03, -.89353500E+03, 0.51177700E+03, 0.76154000E+03, -.96213500E+03, -.51975400E+03, -.16942300E+03, -.19502500E+03, 0.27777200E+03, -.60243000E+03, 0.79359100E+03, 0.12220100E+03, 0.17488100E+03, 0.60035700E+03, 0.27262400E+03, -.86196200E+02, 0.53302800E+03, -.62983300E+03, 0.57328600E+03, -.37337000E+03, 0.16786800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.22161000E+01, 0.24177800E+00, 0.25887400E+01, 0.13283200E+01, -.60424200E+01, 0.31037400E-01, 0.40303300E+01, 0.20708800E+01, -.24719800E+00, -.14942500E+01, -.13435200E+01, 0.21584800E+01, -.54519800E+00, 0.16563400E+01, 0.90469900E+00, -.76151800E+00, -.20731300E+00, 0.33788900E+00, 0.71340100E+00, -.55561100E+00, 0.17859100E+01, 0.12336300E+00, 0.85425800E-01, -.91567200E-01, -.14163800E+00, 0.56562000E+00, 0.36697600E-01, 0.28624500E-02, -.42805200E+00, 0.10360700E+01, -.24017400E+00, -.13512000E+00, -.31657000E+00, -.38925900E+00, 0.30706600E+00, 0.20210900E+00, -.11138800E-01, 0.99375100E-01, -.14768600E+01, -.17727100E+00, 0.66029500E+00, -.13160300E-01, -.12260000E+01, -.19151200E+00, 0.14428100E+01, 0.40782000E+00, -.11520000E+00, 0.11988700E+00, -.24814000E+01, 0.18112000E+01, 0.46606500E+00, 0.23811700E+00, 0.68667000E+00, 0.12444500E+01, -.93856700E-01, 0.20639400E+01, 0.59889000E+00, -.53159800E+00, -.31524800E+00, -.60214400E+00, 0.39732500E+00, -.13265700E+01, 0.15600500E+01, 0.21250800E+01, 0.55141200E+00, -.75065000E+03, 0.13149600E+04, 0.96478100E+03, -.84198400E+03, -.25208500E+04, -.17857400E+04, 0.10106300E+04, -.15318800E+04, 0.74091100E+03, 0.20277300E+04, -.85627300E+03, -.18138400E+03, 0.87918500E+03, 0.15736900E+04, 0.17941900E+04, -.37982400E+03, -.43817400E+03, 0.23278400E+03, 0.29014900E+03, 0.75414200E+02, 0.94753000E+03, -.52736500E+02, -.91287400E+02, 0.16588300E+04, 0.77979200E+03, -.12483600E+04, 0.61469600E+03, -.14257200E+04, 0.44748500E+03, 0.35141000E+03, 0.45448600E+03, -.23987600E+03, -.75579700E+03, 0.22427100E+03, 0.39054700E+03, -.19849200E+03, -.49231400E+03, -.51040600E+03, -.90188900E+03, -.29795200E+03, -.41988200E+03, -.10025500E+04, -.36238500E+03, -.39962800E+04, 0.19930800E+04, 0.19690400E+04, 0.11145400E+04, 0.61614900E+03, 0.78197000E+03, -.66737300E+03, 0.25718700E+03, 0.15718100E+04, 0.12937000E+04, -.63582800E+03, -.69853400E+03, -.36918800E+03, -.38747400E+03, -.39975600E+03, -.49384900E+03, -.75288300E+03, -.24693200E+03, -.14670500E+04, 0.72484700E+03, 0.17085100E+03, 0.25711700E+03, 0.53784000E+03, 0.24826900E+03, -.11769100E+04, -.61933100E+03, 0.95129100E+03, 0.76214700E+04, -.37800100E+04, -.38582500E+04, -.18815800E+03, 0.14426000E+04, -.34093200E+04, -.33613600E+04, -.39615600E+04, 0.60353900E+03, 0.19796300E+04, -.99329500E+03, -.13688300E+04, -.55934700E+03, -.99708500E+03, -.22604400E+03, -.11479800E+02, -.71492300E+03, -.50350800E+03, 0.56519700E+04, -.28187700E+04, -.28062000E+04, -.11298400E+04, -.44027600E+03, -.14585000E+04, 0.32205300E+03, -.84436900E+03, -.16479100E+04, -.27308300E+03, 0.13428900E+03, 0.11447300E+04, 0.36881900E+03, 0.72329800E+03, -.61170000E+03, -.66332300E+03, 0.18033500E+02, 0.73959900E+03, 0.20276000E+04, -.10080300E+04, -.11028200E+04, -.22951700E+03, 0.26203300E+03, -.10164600E+04, -.93778700E+03, -.86614300E+03, 0.16074700E+03, -.10778600E+05, 0.53723400E+04, 0.53922700E+04, -.24750700E+03, -.20796800E+04, 0.48237400E+04, 0.30775000E+04, 0.50659300E+04, -.56754400E+03, -.28665800E+04, 0.14366600E+04, 0.15028000E+04, 0.92678800E+03, 0.19272100E+04, 0.68326700E+02, -.76229700E+03, 0.82167600E+03, 0.16359300E+04, 0.53582300E+03, 0.11210700E+04, 0.74437000E+03, 0.97708800E+03, -.53471700E+03, -.11138200E+04, 0.89432600E+03, 0.53395600E+03, 0.11738100E+04, 0.16579000E+04, -.54102700E+03, 0.64105300E+03, -.84018600E+03, 0.96097400E+03, -.20439600E+03, -.11503600E+04, 0.71101500E+03, 0.49978100E+02, 0.13556900E+04, 0.63572300E+03, -.74052800E+03, -.15618100E+03, -.58914000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.72142200E+00, -.31105900E+00, 0.27567100E-01, 0.25927100E+00, -.32276700E+01, -.18750500E-01, 0.37594100E+01, 0.19113400E+01, 0.28016800E+00, -.20615300E+00, -.17171400E+01, 0.10801000E+01, -.71308000E+00, 0.12824400E+01, 0.61975900E+00, -.22478900E+00, -.26143100E+00, 0.40782600E+00, 0.88776000E+00, -.59162000E+00, 0.27191800E+00, 0.18453100E-03, 0.46002100E+00, -.37280200E+00, 0.26435400E-01, 0.20315400E+00, 0.33308400E+00, -.68585700E-01, -.37346000E+00, -.11053400E+00, 0.33921900E-01, 0.25591100E+00, -.28735900E+00, 0.80036900E-01, 0.35386100E+00, -.13778400E+00, -.82041600E-01, 0.25925600E+00, -.40218800E+00, -.75466900E-01, 0.86029400E+00, 0.84055800E-01, -.89141700E+00, -.30675100E+00, 0.51606800E+00, 0.16284500E+00, 0.13406100E+00, -.76716700E+00, -.88011400E+00, -.28437500E+00, 0.22251100E-01, -.61212800E-01, -.88900200E-01, -.97736600E+00, -.19434200E+00, -.45767300E+00, 0.73343900E-01, 0.51454800E-01, -.43722200E-01, 0.43143900E+00, 0.42627000E+00, 0.70220600E+00, -.39887500E+00, -.22013700E+01, 0.72677100E+00, 0.30935800E+00, -.15757500E+04, -.19206300E+04, 0.16161900E+04, 0.32310000E+04, 0.21230600E+04, -.18143600E+04, 0.22475400E+04, -.11006600E+04, -.11818300E+04, 0.88444100E+03, 0.71027900E+03, -.15282800E+04, -.19158000E+04, -.13777400E+04, 0.68940800E+03, -.14562500E+04, 0.72467700E+03, 0.11122500E+04, 0.10000500E+04, 0.83357800E+03, -.76087300E+03, -.43586300E+03, -.98251000E+03, 0.73469400E+03, 0.26865500E+03, -.13375900E+03, -.85957400E+02, -.45860100E+03, -.59998000E+03, 0.28438300E+03, 0.54701700E+02, 0.37825300E+03, -.25399000E+03, 0.52915700E+03, -.27337200E+03, -.48676000E+03, -.35880000E+03, -.24052000E+03, 0.98224600E+03, 0.10688900E+04, 0.76590200E+03, -.52445900E+03, 0.46186000E+04, -.23046700E+04, -.23049800E+04, -.77023700E+03, -.61604400E+03, -.10573700E+04, 0.55793500E+02, -.89383100E+03, -.17559300E+04, -.92672000E+03, 0.45535400E+03, 0.39554500E+03, 0.64869800E+02, -.83966800E+02, 0.66140500E+03, 0.62730900E+03, 0.80815400E+03, -.12597600E+03, 0.41914600E+03, -.17985700E+03, -.49284600E+03, -.18883400E+03, -.64955200E+03, 0.35320400E+03, 0.54549000E+03, 0.22062500E+03, -.95232100E+03, -.80835100E+04, 0.40187100E+04, 0.40048400E+04, 0.18696400E+02, -.16957000E+04, 0.40004100E+04, 0.35604200E+04, 0.44452000E+04, -.86806600E+03, -.64974700E+03, 0.32778100E+03, 0.36782200E+03, -.47780700E+02, 0.12461500E+03, 0.44929000E+03, 0.14465900E+03, 0.39454400E+03, -.21119000E+03, -.57251800E+04, 0.28559900E+04, 0.28636700E+04, 0.72642100E+03, 0.29646400E+03, 0.16646200E+04, 0.53343800E+03, 0.16049700E+04, 0.16677700E+04, 0.67655300E+03, -.33543600E+03, -.81094600E+02, -.25002500E+03, -.24418600E+03, 0.59058900E+02, 0.39829300E+03, -.31171800E+02, -.46724000E+03, -.16082700E+04, 0.80458700E+03, 0.94897600E+03, 0.14724400E+02, -.24768000E+03, 0.82670400E+03, 0.57992500E+03, 0.35631900E+03, -.29591600E+02, 0.10467600E+05, -.52255400E+04, -.52353200E+04, 0.26766600E+03, 0.20532100E+04, -.49437200E+04, -.35806800E+04, -.51548400E+04, 0.59587200E+03, 0.22574300E+03, -.10555800E+03, -.44354300E+02, 0.68410500E+02, -.37188500E+03, -.28288600E+03, 0.28285000E+03, 0.15552600E+02, -.33959400E+03, -.11628200E+03, -.45791700E+03, -.19622800E+03, -.13042400E+03, 0.92711800E+02, 0.45308500E+03, -.15958600E+03, -.93127600E+02, -.28055400E+03, -.19117800E+04, 0.28686600E+03, -.14862800E+03, 0.14540000E+03, -.13872400E+04, -.20145900E+03, 0.56804900E+03, -.14233300E+04, 0.33968900E+03, -.17331800E+04, -.11355300E+03, 0.23207300E+03, -.57058800E+03, 0.29210800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24877300E+01, -.81358600E+00, 0.19451600E+01, 0.11099000E+01, -.28046600E+01, -.35459900E+00, 0.36938200E+01, 0.18723000E+01, 0.98417900E+00, -.10787000E+01, 0.71422800E+00, 0.23081600E+01, -.35475900E+00, 0.26763800E+01, 0.46430300E+00, 0.18732800E+00, -.10414600E+01, 0.11811100E+01, 0.20507000E+01, 0.91401000E+00, 0.11599000E+01, -.97098700E+00, 0.16205800E+01, 0.33352000E+00, -.18241300E+00, 0.17343200E+00, 0.59408900E+00, -.47811600E+00, -.61679700E+00, -.28318200E-01, -.14140300E+00, 0.66724600E-02, 0.30649600E-01, -.13566900E+00, -.15473100E+00, 0.34167000E+00, 0.87384400E-01, -.17650600E+00, -.56230700E+00, -.17561500E-01, 0.94950700E+00, 0.19199900E+00, -.17373200E+01, -.66381900E+00, 0.17872200E+01, 0.57694800E+00, -.48516600E-02, -.64460100E+00, -.72940700E+00, -.10368400E+01, 0.15095800E+00, -.91471700E-01, 0.85913100E-01, 0.47416500E+00, -.72775400E+00, 0.12639700E+01, 0.78402400E-01, 0.94103200E-01, -.30328200E+00, -.10523700E+01, -.37046900E+00, 0.12214900E+00, -.13497400E+00, 0.39741600E+01, 0.66634900E+00, 0.84309500E+00, -.85594100E-01, -.12661600E+04, -.25838100E+03, -.24349300E+04, -.20066000E+04, 0.43668300E+03, 0.20751800E+02, 0.47496700E+02, -.19573400E+03, -.52850900E+03, 0.40341800E+03, 0.72781400E+03, 0.29072600E+04, 0.31502700E+04, -.67351300E+03, -.71888800E+04, 0.35988200E+04, 0.36038500E+04, 0.24009500E+04, 0.23872900E+04, 0.59347900E+03, 0.53128900E+03, 0.30151000E+04, 0.88999100E+03, 0.21394400E+04, -.10625600E+04, -.78184100E+03, -.11140900E+04, -.11641500E+04, 0.16593700E+03, 0.98641500E+02, -.23111300E+04, -.11029000E+04, 0.15484200E+04, -.80895600E+03, -.73013300E+03, -.92808000E+03, -.12431200E+04, 0.52612400E+03, -.56562800E+03, -.17364900E+04, 0.42590900E+03, -.38789200E+03, 0.19459300E+03, 0.18943300E+03, 0.10308200E+04, 0.75863300E+03, 0.23050100E+03, -.23453200E+03, -.71351300E+02, -.12529200E+04, 0.28210000E+03, -.17011800E+03, -.10139600E+03, -.53811100E+03, -.10270600E+04, 0.56099600E+03, 0.43292700E+03, 0.50201500E+01, -.36585600E+03, 0.35808100E+04, -.17270100E+04, -.16156400E+04, -.92523700E+03, -.22309000E+04, 0.34443300E+03, 0.19512200E+04, -.32582400E+03, -.30010000E+04, -.20959200E+05, 0.10394400E+05, 0.10478200E+05, -.15479900E+04, -.23885500E+04, 0.98434100E+04, 0.71953300E+04, 0.98109000E+04, -.81381100E+01, 0.20783300E+04, -.10326600E+04, -.10399800E+04, -.57863200E+03, -.93473000E+03, -.12328000E+03, -.18831800E+03, -.16943300E+04, -.10946700E+04, -.26960700E+03, 0.12932700E+03, 0.13181400E+03, -.93568400E+03, -.13371900E+04, 0.21526500E+03, 0.71369100E+03, 0.35658100E+03, 0.10714600E+04, -.20213400E+02, -.72891000E+01, -.19816700E+03, 0.87506500E+03, 0.16296000E+03, 0.23488800E+02, 0.81536700E+03, 0.29953600E+04, 0.14087500E+03, 0.17564900E+04, -.88794100E+03, -.99932900E+03, -.22123900E+03, 0.86322300E+02, 0.10024400E+03, 0.13180200E+04, -.23552000E+03, -.30900400E+03, 0.15555600E+05, -.77257000E+04, -.77811200E+04, 0.50236500E+03, 0.28049000E+04, -.69883200E+04, -.42427000E+04, -.73817800E+04, -.89902100E+03, -.32736000E+04, 0.16745300E+04, 0.16401100E+04, 0.29337700E+03, 0.12804000E+04, 0.41906400E+03, 0.92857000E+03, 0.25670400E+04, 0.57456100E+03, 0.93239300E+03, 0.11505100E+04, 0.81382900E+03, 0.13105900E+04, -.10075600E+04, -.11621200E+04, 0.16344000E+04, 0.10141000E+04, -.73751400E+03, 0.27047100E+03, -.62718500E+03, 0.11500300E+04, -.13071800E+04, -.18280100E+04, -.35587200E+03, -.85455200E+03, -.12050200E+04, 0.24611300E+03, -.29568100E+04, 0.11885800E+04, -.10835800E+04, 0.38904200E+03, -.28921900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.32831700E+00, -.13679800E+00, -.36331600E+00, 0.28928500E-01, -.13742100E+01, 0.36274700E-01, 0.15095500E+01, 0.47962900E+00, -.13241900E+00, -.16407600E+00, -.48223400E+00, 0.91995700E+00, -.15489100E+00, 0.84340400E+00, 0.23929200E+00, 0.15620000E+00, -.30572300E+00, 0.31495800E+00, 0.58046400E+00, -.33716200E+00, 0.32798100E+00, -.25127600E+00, 0.62039500E+00, -.29910000E+00, 0.92344700E-01, -.35314600E-01, 0.23171200E-01, -.60326700E-01, 0.28065400E+00, -.60281200E+00, 0.15053700E+00, 0.54310600E-01, 0.15625300E-01, 0.23771500E+00, -.32412000E-01, 0.20193800E+00, 0.28486600E-01, 0.85951800E-01, -.58355600E+00, -.21046900E+00, -.55085800E-01, 0.39690200E-01, -.47574300E+00, -.14418100E+00, 0.52140500E+00, 0.33769100E-01, 0.39793900E-01, -.21523300E+00, 0.44818900E+00, -.20855200E+00, -.34135300E-01, -.56202700E-02, 0.13343000E+00, 0.33749400E+00, -.51798400E-01, -.62734600E-01, -.97357700E-01, 0.33135400E-01, 0.45954600E-01, 0.23433700E+00, 0.27599800E+00, -.34738900E-01, -.30574700E+00, 0.27815500E+00, -.42179300E+00, -.27091500E-01, -.34227400E-01, 0.24552800E+00, 0.38070400E+03, 0.11210300E+04, 0.33234500E+03, -.46901100E+03, -.97038600E+03, 0.48003100E+03, 0.56261400E+03, 0.53283100E+03, 0.78636500E+03, -.51387400E+03, -.15272200E+04, -.84015000E+03, 0.10023700E+04, 0.49758100E+03, -.22854900E+03, -.37922700E+03, 0.17599600E+03, 0.41501100E+03, -.54062000E+03, -.90282400E+03, -.35462700E+03, 0.82248100E+03, 0.66119900E+03, -.33186000E+03, -.53785100E+03, -.23594200E+01, -.26735500E+03, -.28760600E+02, 0.18848100E+03, 0.19962800E+03, -.19745100E+03, 0.68619100E+02, -.35779200E+02, -.19639300E+01, -.43577300E+03, -.38281800E+03, 0.39303800E+03, 0.60384100E+03, 0.56715900E+03, -.82184700E+03, 0.13948400E+04, -.69789200E+03, -.69375600E+03, -.21757700E+03, -.40635400E+03, -.56542800E+03, -.47195800E+03, -.57121200E+03, 0.22641400E+03, 0.44881500E+03, -.20785200E+03, -.23757200E+03, -.64170500E+02, 0.56946600E+02, -.12100500E+03, 0.81237100E+01, -.19133700E+03, -.13912900E+03, -.24336200E+03, 0.11861000E+03, 0.12598200E+03, -.13894600E+02, 0.43885800E+03, -.18238300E+03, -.81317500E+03, -.32601300E+03, 0.74724100E+03, 0.87226600E+04, -.43198100E+04, -.43547500E+04, 0.34252900E+03, 0.65103700E+03, -.36246100E+04, -.23911500E+04, -.39180400E+04, -.25269200E+03, 0.17846300E+03, -.89583600E+02, -.10912100E+03, -.18656200E+03, -.25292200E+03, 0.14284800E+03, 0.14552800E+03, 0.16949800E+03, -.82797700E+02, -.73025800E+03, 0.36735900E+03, 0.36753500E+03, 0.22022100E+03, 0.57533200E+03, 0.30371200E+03, 0.37983200E+03, 0.42555400E+03, -.23081800E+03, -.51688200E+03, 0.25748900E+03, 0.37290900E+03, -.11867900E+02, 0.63702300E+03, -.18181500E+03, -.56720400E+03, -.70375600E+03, 0.38866500E+03, -.85957700E+02, 0.49939300E+02, 0.10915600E+03, 0.91197700E+01, 0.13034900E+02, -.19238800E+03, -.65539600E+03, -.20069000E+03, 0.13784200E+03, -.63095400E+04, 0.31264900E+04, 0.31576700E+04, -.16259100E+03, -.10896500E+04, 0.25601100E+04, 0.12204100E+04, 0.27370200E+04, 0.35182500E+03, -.51572400E+03, 0.25542700E+03, 0.25992600E+03, 0.57507300E+03, 0.52278400E+03, -.29875300E+03, -.58077800E+03, -.28994800E+03, 0.65453000E+03, 0.16615800E+03, 0.18794500E+03, 0.21894600E+03, 0.15736400E+03, -.11419500E+03, -.18462200E+03, -.83229000E+02, 0.10845200E+03, 0.87183800E+03, 0.30328000E+03, -.11207400E+02, 0.14159300E+03, -.13192700E+02, 0.29562200E+03, -.21606100E+03, -.18092000E+03, -.70219400E+02, 0.21671100E+03, 0.74716800E+03, 0.93581400E+02, -.11793500E+03, -.86692100E+03, 0.28788900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13846700E+01, 0.17861300E+00, 0.13250700E+01, 0.67142300E+00, -.18454400E+01, -.40854900E+00, 0.13111100E+01, 0.77050400E+00, 0.51920400E+00, -.69939200E+00, -.25613300E+00, 0.12917000E+01, 0.41649200E-01, 0.17054900E+01, 0.27448500E+00, -.29643900E-01, -.57255800E+00, 0.47025500E+00, 0.72870600E+00, -.39263300E+00, -.16647100E+01, -.14901800E+00, 0.58220500E+00, 0.31467700E+00, -.20122300E+00, 0.60069200E-02, 0.68700500E+00, -.33406000E-01, 0.56683900E+00, -.23681000E+00, 0.51631200E-01, -.31294000E+00, -.18647700E+00, -.36681000E+00, 0.34549900E+00, 0.52262500E+00, 0.78641100E-01, 0.25772200E-01, -.49425900E+00, -.46060900E+00, 0.81146700E+00, 0.21068000E-01, -.12804900E+01, -.50489400E+00, 0.13302200E+01, 0.40346200E+00, -.57166000E-01, -.44391200E+00, -.16868400E+01, 0.95134300E+00, 0.24951500E+00, 0.13657900E+00, 0.34328000E+00, -.33808300E+00, -.39306700E+00, 0.38456200E+00, 0.12333800E+00, -.89758900E-01, -.15445400E+00, -.17612000E+00, 0.27464700E-02, -.23937000E-01, -.14802600E+00, 0.89258100E+00, 0.10179200E+00, 0.10202400E+00, -.97642700E-01, -.68485000E-01, 0.97528800E-01, -.10799800E+04, -.11016800E+04, 0.24304900E+03, -.12207000E+04, 0.60250300E+03, 0.60117500E+03, -.47983300E+02, 0.59024800E+02, 0.41358100E+03, 0.10686100E+04, 0.14537600E+04, -.82905300E+02, -.28884100E+04, 0.14466200E+04, 0.14022800E+04, 0.13273100E+04, 0.13085600E+04, -.13736400E+01, 0.21675000E+03, 0.13564200E+04, 0.86255200E+03, 0.60405700E+03, -.30094200E+03, -.32295000E+03, -.51886000E+03, -.53058000E+03, 0.26796000E+03, -.95680400E+01, -.66982700E+03, -.44944700E+03, 0.46163700E+03, -.24329300E+03, -.21190000E+03, -.78955100E+03, -.70644300E+03, 0.44736900E+03, -.13114300E+03, -.49635900E+03, -.24012000E+03, -.23074700E+02, 0.11005900E+02, 0.12532000E+02, 0.29007200E+03, 0.16708400E+03, 0.21362500E+02, -.34648600E+02, -.15903300E+03, -.23745400E+03, 0.32190800E+03, -.17209400E+03, -.15938900E+03, -.36452000E+03, -.43414200E+03, 0.18730800E+03, 0.10933900E+03, -.13190500E+03, -.25218000E+03, 0.10248200E+04, -.51168500E+03, -.48876900E+03, -.45891500E+03, -.10263200E+04, 0.38498500E+03, 0.74389800E+03, -.46513800E+01, -.10189200E+04, -.39106500E+04, 0.19273400E+04, 0.19557700E+04, -.66531500E+03, -.71566800E+03, 0.20087800E+04, 0.13999700E+04, 0.17246900E+04, -.23243900E+03, 0.92652200E+03, -.46233700E+03, -.47197400E+03, -.48119300E+03, -.54026700E+03, 0.12477900E+03, 0.90064900E+02, -.51950400E+03, -.50038000E+03, -.23307200E+03, 0.11557200E+03, 0.11675100E+03, -.22413800E+03, -.25933000E+03, 0.88107300E+02, 0.94529400E+02, 0.23517000E+03, 0.22655000E+03, -.75416800E+03, 0.37260200E+03, 0.38868400E+03, 0.75645700E+03, 0.23523800E+03, 0.24920500E+02, 0.27722700E+03, 0.10162800E+04, 0.24925100E+03, 0.48114700E+03, -.23742000E+03, -.23546300E+03, -.40872300E+02, 0.23686800E+02, 0.21413000E+02, 0.22482200E+03, -.43333200E+02, -.55176200E+02, 0.30766000E+04, -.15156900E+04, -.15379100E+04, 0.26242800E+03, 0.67010800E+03, -.13434400E+04, -.63554700E+03, -.13608400E+04, -.73335000E+01, -.15586300E+04, 0.78951200E+03, 0.78553800E+03, 0.52403000E+03, 0.10309500E+04, -.90623100E+02, 0.16339000E+03, 0.86079100E+03, 0.70433700E+03, 0.47627900E+03, 0.62348600E+03, 0.56824500E+03, 0.48268100E+03, -.50792600E+03, -.62602000E+03, 0.72571900E+03, 0.50307200E+03, -.45981000E+03, -.16607600E+03, -.53682500E+03, 0.40831700E+03, -.64148400E+03, -.76299500E+03, -.27707000E+03, -.36569100E+03, -.54955100E+03, 0.28674600E+03, -.95753400E+03, 0.50566200E+03, -.62030400E+03, -.27437500E+03, 0.20722900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12155600E+01, 0.24363700E+00, -.10550400E+01, -.60310900E+00, 0.54273900E+01, 0.74693300E-02, -.30627600E+01, -.13877500E+01, 0.18019500E+00, 0.12094600E+01, 0.13452000E+01, -.11545500E+01, 0.66462700E+00, -.12137900E+00, -.10553700E+01, 0.11819000E+01, 0.84102800E-01, -.12974100E-01, -.74844900E-01, -.84677600E-01, -.23553500E+00, -.10619300E-01, -.35292700E-01, -.85378200E-01, 0.91838000E-01, -.81811900E-01, -.28776800E+00, -.16891000E-02, 0.12799000E+00, -.17896400E+00, 0.12297200E-01, 0.24116000E+00, 0.38461200E-01, 0.93258400E-01, -.18070900E+00, -.16646800E+00, 0.17912000E+00, -.23219300E-01, -.20921600E+00, 0.27824300E+00, -.10691400E+01, -.64951700E-02, 0.45221400E+00, 0.17434400E+00, -.37076800E+00, -.71650600E-01, 0.14445400E-01, 0.25901700E+00, 0.13102900E+01, 0.26382000E+00, -.22708200E+00, 0.33810100E-01, -.90423500E+00, -.31642800E+00, 0.14265100E+00, -.84535500E+00, 0.17719700E-01, 0.58920400E-01, 0.16415500E+00, 0.15641100E+00, -.46677100E+00, -.32026500E+00, 0.23278600E+00, -.54409200E+00, 0.13280900E-02, 0.12730000E+00, -.51581800E+00, -.17549300E+00, -.37113100E+00, -.28680600E+00, -.60074800E+03, 0.10395200E+03, 0.10859400E+04, -.51695500E+03, -.73439800E+03, -.36567700E+03, -.49482000E+03, -.92203000E+02, 0.44633600E+03, 0.47655300E+03, -.43839600E+03, -.91061700E+03, 0.45692600E+03, 0.67210300E+03, 0.50997100E+03, -.29221000E+03, 0.70854200E+02, 0.34753500E+03, 0.11110000E+03, -.24938100E+03, 0.30177100E+03, -.14880400E+03, 0.22536200E+03, -.57245600E+02, -.33192200E+02, -.12610300E+03, -.26574200E+03, -.55451100E+03, 0.20973900E+02, -.93278900E+03, 0.46015400E+03, 0.35130200E+03, 0.99995500E+02, 0.62339700E+03, 0.65958200E+03, 0.27702400E+03, 0.33363300E+03, 0.27734700E+03, 0.27476000E+04, -.13707800E+04, -.13742200E+04, -.54799800E+03, -.55291800E+03, -.55507900E+03, 0.28078900E+03, -.22029100E+03, -.11136800E+04, -.77714200E+03, 0.38563900E+03, 0.37319600E+03, 0.13014400E+03, 0.20393600E+03, 0.31117600E+03, 0.36823100E+03, 0.21203400E+03, 0.13373200E+03, 0.50150900E+02, -.11400600E+02, -.55105800E+02, -.63376500E+01, -.47584100E+03, 0.34586900E+03, 0.10406800E+04, 0.31973500E+03, -.66571600E+03, -.50570800E+04, 0.25159000E+04, 0.25119700E+04, -.77267300E+02, -.11165800E+04, 0.23401500E+04, 0.25113700E+04, 0.23190200E+04, -.43046700E+03, -.16369200E+04, 0.82020700E+03, 0.88310100E+03, 0.28245700E+03, 0.62209700E+03, 0.39177100E+03, 0.66118700E+02, 0.11936400E+03, 0.25069700E+03, -.41848400E+04, 0.20874200E+04, 0.20912500E+04, 0.74876600E+03, 0.45007000E+03, 0.11052400E+04, -.54274000E+02, 0.69037900E+03, 0.11993800E+04, -.46459100E+03, 0.22949000E+03, 0.17609700E+03, -.17419800E+03, -.49346800E+03, 0.71185200E+03, 0.90746800E+03, 0.14210200E+04, -.45203000E+03, -.13197500E+04, 0.65131500E+03, 0.69148800E+03, -.45954800E+02, -.26286000E+03, 0.92692800E+03, 0.12071900E+04, 0.98588800E+03, -.23128700E+03, 0.70764100E+04, -.35338200E+04, -.35409100E+04, 0.15493500E+03, 0.15267400E+04, -.32042800E+04, -.19697600E+04, -.34046600E+04, 0.49196000E+03, 0.21860500E+04, -.10891200E+04, -.10630700E+04, -.68652400E+03, -.10261500E+04, -.32684700E+03, 0.71994200E+03, -.16503200E+03, -.84038200E+03, -.27703700E+03, -.78344400E+03, -.45191300E+03, -.33605400E+03, 0.26523800E+03, 0.77870700E+03, -.13987600E+03, -.26614400E+03, -.55591300E+03, -.48433100E+02, -.79829200E+02, -.34672600E+03, 0.12563100E+03, -.52637300E+03, 0.16352900E+03, 0.55884100E+03, -.36199200E+03, 0.54089300E+02, -.78598400E+03, -.28406400E+03, 0.39780300E+03, 0.96847600E+02, 0.23012600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.55424100E-01, 0.92727200E-01, 0.12202200E+01, -.10435100E+01, 0.12984300E+02, -.15962000E+01, -.66753400E+01, -.42937200E+01, 0.23288100E+00, 0.16665700E+01, 0.23476700E+01, -.20548900E+01, 0.19674100E+01, -.19858000E+01, 0.27271200E+00, 0.78277100E+00, -.77791800E+00, -.73048100E+00, -.24047700E+01, 0.55511100E+00, -.29609700E+01, -.26936000E+00, -.45413400E+00, 0.43042500E+00, -.15321200E+01, -.95870000E+00, 0.14767500E+01, -.75514000E-01, -.98846800E+00, -.13526700E+01, 0.31121100E+00, 0.46090700E+00, -.46724400E+00, 0.45125500E+00, -.30637700E+00, 0.37124400E+00, -.73396900E-01, 0.52182000E-01, 0.56211600E+00, -.29788600E-01, 0.17074000E+01, 0.67290700E-01, -.22590100E+01, -.10032600E+01, 0.92212500E+00, 0.23995800E+00, 0.34285600E+00, -.15692100E+01, -.40767300E+01, 0.23122900E+01, 0.41720400E+00, 0.15558700E+00, -.35188600E-02, -.79270600E+00, -.19082200E+00, 0.13477400E+01, -.23956300E+00, 0.45625500E-01, -.43165400E-01, -.10792700E+01, 0.24063600E-01, 0.14634800E+01, 0.70139800E+00, -.15924200E+01, 0.25604800E+01, 0.99661500E+00, 0.14672500E+01, -.31780700E+00, -.19409900E+01, -.14879000E+00, -.37791200E+00, 0.46535300E+03, 0.33139500E+03, -.17748900E+03, -.19525500E+03, -.42315600E+03, -.60010400E+03, 0.35247200E+03, 0.37444900E+03, 0.39461200E+03, -.89413000E+03, -.74941300E+03, 0.36391900E+03, 0.20124800E+03, 0.32385900E+03, -.22859200E+02, 0.93717400E+02, 0.53625300E+02, 0.25262400E+03, 0.91587000E+02, -.51007800E+03, 0.25677200E+03, 0.22422500E+03, -.25167700E+02, 0.27378900E+03, 0.89687700E+02, -.16219400E+03, -.59411200E+03, -.66582500E+02, -.82524400E+03, 0.39142400E+03, 0.53787500E+03, -.60240300E+02, 0.19982700E+03, 0.33401400E+03, 0.12678000E+04, 0.84109600E+02, 0.10256300E+03, -.21512400E+04, 0.10717100E+04, 0.10740500E+04, 0.11384500E+03, 0.16521000E+03, 0.81226100E+03, -.70713300E+02, 0.13833400E+04, -.46724800E+02, -.47910500E+03, 0.21159700E+03, 0.28010200E+03, -.10579800E+03, -.79680500E+02, 0.24771600E+03, 0.31891900E+03, 0.36731700E+03, -.10660800E+03, -.11695100E+03, 0.78143200E+02, 0.23931300E+03, -.26217500E+03, -.30264400E+03, 0.32886300E+03, 0.34809200E+03, -.73639600E+02, -.50884300E+03, -.53476800E+04, 0.26139300E+04, 0.26838900E+04, -.40470200E+02, -.26659900E+03, 0.19480400E+04, 0.86384000E+03, 0.26864200E+04, 0.13579300E+03, -.10767500E+02, 0.36532300E+01, -.43959500E+02, -.11038100E+03, 0.12043300E+03, -.26302300E+02, 0.21822100E+03, 0.35607100E+01, -.20574500E+03, 0.15017900E+04, -.74924000E+03, -.75214200E+03, -.14753400E+03, -.17888200E+03, -.58402000E+03, 0.28807500E+02, -.12930500E+04, 0.13506300E+03, -.15142600E+04, 0.74380100E+03, 0.64733200E+03, 0.36628100E+03, -.65473900E+02, 0.45089400E+03, -.73383400E+03, 0.10681900E+04, 0.61247500E+03, 0.12211800E+03, -.63611600E+02, -.16140500E+03, 0.36574900E+02, 0.86576300E+02, -.32852600E+02, 0.14249300E+03, -.16394000E+03, -.48688400E+02, 0.31404500E+04, -.15412200E+04, -.15706000E+04, -.17807400E+02, 0.58052100E+03, -.12782800E+04, -.65871800E+03, -.17612400E+04, -.63147600E+02, 0.20641700E+03, -.75779300E+02, -.10923300E+03, -.13255300E+03, -.45492300E+02, -.14930700E+02, -.23106200E+03, -.36154800E+03, -.59624600E+02, -.32428600E+02, 0.28382100E+02, 0.43234100E+02, -.23878700E+03, -.19271200E+02, -.32595500E+02, -.10005100E+03, 0.16903700E+02, -.95405500E+03, -.69393600E+03, -.95110900E+02, -.27141600E+03, -.47638100E+01, -.52470700E+03, -.13928800E+03, 0.33984400E+03, -.63673600E+03, 0.10609200E+02, -.99621700E+03, -.17387300E+03, -.10260900E+03, 0.28588500E+02, 0.16801000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.91816700E+00, -.10873900E+01, 0.76721700E+00, 0.44428600E+00, -.30668900E+01, 0.23796300E-01, 0.29342600E+01, 0.19433800E+01, 0.60740800E-01, -.38675200E+00, -.76611400E+00, 0.41408900E+00, -.64158200E+00, 0.59539200E+00, 0.56326800E+00, -.51743600E+00, -.32379700E+00, -.19419600E-01, 0.34189800E-01, -.46158700E+00, 0.10199000E+01, 0.11852600E+00, 0.71961400E-01, -.31620700E+00, 0.36962400E+00, 0.20495000E+00, -.12132600E+01, 0.40432600E-01, 0.37331800E+00, 0.51230800E+00, -.22163400E+00, -.58874600E+00, 0.21899900E+00, -.32157700E-01, 0.70302700E+00, -.64210400E+00, 0.91344400E-01, -.26357000E+00, 0.52733000E+00, 0.29975500E+00, -.19028800E+00, -.30146800E-01, 0.58355100E+00, 0.28032900E+00, -.62722000E+00, -.58748400E-01, 0.15172800E+00, 0.17000000E-01, 0.36542500E+00, 0.62512600E-01, 0.46897300E-01, 0.45457600E-01, 0.12713600E+00, 0.76958200E+00, -.71145000E-01, 0.39209800E+00, -.54430900E-01, -.30130900E-01, -.12048100E+00, -.32476500E+00, 0.21218500E+00, 0.35985900E+00, -.22394000E+00, 0.41473700E+00, -.63023500E-01, 0.81936700E-01, 0.43118500E+00, -.22046100E+00, -.58192900E+00, -.22685500E+00, 0.66119100E+00, 0.16994800E+00, -.24825600E+04, 0.12206100E+04, 0.14504900E+04, 0.57526300E+03, 0.79330200E+03, 0.39591700E+03, -.41375800E+03, 0.14093300E+03, 0.68926000E+03, -.10815300E+03, 0.97486600E+02, -.36515300E+03, -.20700100E+03, 0.44629800E+03, 0.66205400E+02, -.15698800E+03, 0.45980800E+03, 0.13963300E+03, -.27376600E+03, 0.13337300E+03, -.37877800E+03, 0.30891700E+02, 0.46828300E+02, 0.14396200E+03, 0.12282400E+03, -.87955000E+02, 0.11072800E+03, 0.11900100E+04, -.61069000E+03, -.38246900E+03, -.23068200E+03, -.70379000E+03, -.45428500E+03, -.38868000E+03, -.43712900E+03, -.14529200E+03, -.90756700E+03, 0.45414600E+03, 0.45576900E+03, 0.23588700E+03, 0.47769500E+03, 0.72424600E+02, -.44049700E+03, -.28787600E+03, 0.55825400E+03, 0.82453500E+03, -.40321600E+03, -.38168000E+03, -.20453600E+03, -.30782400E+03, -.20853300E+03, -.17911700E+03, -.27060900E+03, -.15913400E+03, 0.24719600E+03, -.15777500E+03, 0.26100300E+02, -.14965800E+03, 0.69099700E+01, -.13263900E+03, -.27911400E+03, -.25548000E+03, 0.14643300E+03, 0.23902000E+04, -.11808300E+04, -.11672900E+04, -.42825300E+03, 0.24512600E+03, -.72748100E+03, -.73512000E+03, -.93817700E+03, -.41340100E+02, 0.15800300E+04, -.78858200E+03, -.89259400E+03, -.27973600E+03, -.57534400E+03, -.34482900E+03, -.48562900E+02, -.39545900E+03, -.21762300E+03, 0.16452200E+04, -.82344300E+03, -.82045900E+03, -.32661600E+03, -.41264400E+03, -.35856500E+03, 0.33439000E+03, 0.51889900E+02, -.59947900E+03, 0.31325100E+03, -.16304200E+03, -.96826900E+02, 0.33778800E+03, 0.29996500E+03, -.43349100E+03, -.53225900E+03, -.57329800E+03, 0.73299400E+02, 0.12231100E+04, -.60739500E+03, -.65534600E+03, 0.15642300E+03, 0.24729500E+03, -.70637400E+03, -.83897300E+03, -.82442200E+03, 0.13568700E+03, -.27311400E+04, 0.13756300E+04, 0.13703000E+04, -.17699100E+01, -.47105900E+03, 0.11735200E+04, 0.80489700E+03, 0.13059300E+04, -.14132100E+03, -.27267100E+04, 0.13677800E+04, 0.13289500E+04, 0.69376900E+03, 0.11288600E+04, 0.40711500E+03, -.51586600E+03, 0.50547700E+03, 0.80229100E+03, 0.41432400E+03, 0.85974100E+03, 0.55196500E+03, 0.36254000E+03, -.38438800E+03, -.85797300E+03, 0.32733600E+03, 0.38973900E+03, 0.28321000E+03, -.19218400E+03, 0.87493600E+01, 0.34112800E+03, -.25045100E+03, -.19815900E+01, -.18076600E+03, -.51167700E+03, 0.74192800E+01, -.39722200E+02, 0.18313300E+03, 0.39848800E+03, -.52478600E+03, -.24601800E+03, -.93125900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.29627700E+01, 0.78738500E+00, -.22245600E+01, -.14048200E+01, 0.67232100E+01, 0.24090900E+00, -.74057300E+01, -.36836500E+01, -.95217400E+00, 0.11908700E+01, 0.91893000E+00, -.21348000E+01, 0.15630000E+01, -.25343400E+01, -.75869100E+00, 0.65544800E+00, 0.76778500E+00, -.78804700E+00, -.22543200E+01, -.49019700E+00, -.49986900E+01, 0.76965900E+00, -.10434000E+01, 0.11184800E+00, 0.67271100E+00, -.68631100E+00, 0.53402300E+00, 0.68365500E+00, 0.10190600E+01, -.70442100E+00, 0.68758200E+00, 0.84034200E+00, -.23584500E+00, -.51009300E+00, -.60843000E+00, 0.93296600E-01, -.82112200E-01, 0.83785100E+00, -.15500800E+01, 0.69585600E+00, -.81882100E-01, 0.27037100E+00, -.10098600E+01, 0.23863300E+00, 0.86496700E+00, 0.10466400E+01, -.21120300E-01, 0.47796000E+00, -.17194300E+01, 0.30285800E+00, 0.12384500E+00, 0.16392700E+00, -.13735400E+01, -.24248200E+01, -.15931500E-01, -.90523500E+00, 0.11864300E+00, 0.11659900E+00, -.14499300E+00, 0.15766700E+01, 0.92225000E+00, -.45138200E+00, 0.44537400E+00, -.43877600E+01, 0.74828200E-01, -.10863200E+01, -.37795200E+00, -.46430600E+00, 0.16427800E+01, 0.43871800E+00, -.30938300E+00, -.23199400E+00, -.12365700E+00, 0.88787300E+02, 0.63704500E+02, -.15349500E+03, -.77555200E+02, 0.92014200E+02, -.48869600E+02, -.13714400E+03, -.10515700E+03, 0.49519600E+03, -.24755400E+03, -.26735100E+03, 0.49616100E+02, -.18933700E+03, -.80050200E+02, 0.77841500E+02, -.19691400E+03, 0.44990900E+02, 0.24435200E+03, -.12283700E+03, -.27055100E+03, 0.12693500E+03, 0.56558200E+02, -.10160500E+03, -.22957300E+02, -.60122000E+02, -.69742700E+02, -.24579000E+03, 0.12775900E+03, 0.10662400E+03, -.54110500E+02, 0.14191300E+03, 0.99708400E+02, 0.34579700E+03, 0.25542000E+03, -.18252300E+03, 0.69390300E+02, -.34311400E+02, -.32406900E+02, 0.79383500E+01, -.16402600E+03, -.10232100E+03, -.40975300E+03, -.80789500E+02, 0.15558700E+03, -.14466000E+03, 0.81161400E+02, 0.54112000E+02, 0.56226500E+02, 0.14008800E+03, -.15830400E+02, -.40958600E+02, 0.24164000E+02, 0.38507500E+02, -.10252600E+04, 0.51685700E+03, 0.46735000E+03, 0.91717900E+02, 0.29255800E+03, 0.20643100E+03, -.25879500E+03, 0.13621300E+03, 0.41081000E+03, 0.25351800E+04, -.12454400E+04, -.12691000E+04, 0.43737400E+03, 0.39051700E+03, -.13143800E+04, -.11449200E+04, -.13126600E+04, 0.38836000E+02, -.33807600E+03, 0.16837100E+03, 0.15817900E+03, 0.12672700E+02, 0.61171400E+02, 0.14423100E+03, 0.16086200E+03, 0.23042000E+03, 0.23185800E+02, 0.18909300E+03, -.93673900E+02, -.92792700E+02, -.36856400E+02, 0.22183300E+03, 0.94133600E+01, 0.37383300E+03, 0.10917600E+02, -.15411800E+03, -.67653500E+03, 0.33932100E+03, 0.45821600E+03, -.29389100E+03, 0.98037000E+02, 0.20803800E+03, -.16919000E+03, -.54358500E+02, 0.25555000E+03, -.28789400E+03, 0.14595200E+03, 0.20556000E+03, -.78113500E+02, -.49876600E+02, 0.10948300E+03, 0.89830500E+02, 0.69194700E+02, -.11852800E+02, -.24550500E+04, 0.12117600E+04, 0.12291200E+04, -.80407500E+02, -.30785100E+03, 0.10425200E+04, 0.62084100E+03, 0.10282700E+04, 0.23308300E+03, 0.22370300E+03, -.11751400E+03, -.10180400E+03, -.14400800E+02, -.16698800E+03, -.22214700E+02, 0.71679200E+01, -.25150900E+03, -.39414000E+02, -.94133700E+02, -.21680900E+03, -.14314700E+03, -.84751400E+02, 0.99773300E+02, 0.21839400E+03, -.15383700E+03, -.10164200E+03, -.16475700E+03, -.12309600E+03, -.77221600E+02, -.11445900E+03, 0.92879800E+02, 0.47768000E+03, 0.32633100E+02, 0.12586500E+03, 0.10553500E+03, 0.46024900E+02, 0.63545100E+03, -.13622400E+03, 0.16273400E+03, -.57345700E+02, 0.74701600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13638000E+01, 0.67507600E+00, -.91228100E+00, -.63956400E+00, 0.83099700E+01, -.14638900E+00, -.59987800E+01, -.31080400E+01, -.30718600E+00, 0.81091000E-02, 0.32743600E+01, -.63295600E+00, 0.16845700E+01, -.19536500E+00, -.69233700E+00, 0.11392200E+01, -.13469400E+00, -.45174600E-02, 0.18828500E+00, 0.38840100E+00, -.35113800E-01, -.33016800E+00, 0.15323600E+00, 0.17556500E-01, -.22108900E+00, -.17484200E+00, 0.92045200E+00, -.22992200E+00, 0.22155800E+01, -.90001600E+00, -.25334900E+00, -.67115300E+00, 0.22660800E-01, 0.15549400E+00, -.73807400E+00, 0.33250000E+00, -.10220800E+00, -.24389700E+00, 0.38498500E-01, -.54685400E+00, 0.28474900E+00, -.70419600E-01, 0.15933700E+00, -.83592700E-01, 0.48537100E+00, 0.57852000E+00, -.36215000E+00, 0.39950100E+00, -.25923200E+00, -.22807400E+00, -.96573300E-01, -.65253000E-01, -.44893400E+00, -.32551700E+00, 0.34035700E+00, -.26534900E+00, -.11221300E+00, 0.22375600E+00, -.17927000E-01, 0.40914600E+00, -.40699600E+00, -.40227300E+00, 0.36562600E+00, 0.15886100E+00, -.81940800E+00, -.76519100E+00, -.34217600E+00, 0.48985300E+00, 0.10507800E+01, 0.10924200E+00, 0.30819500E-01, -.32492400E+00, -.67568100E+00, -.45840000E+00, 0.34613500E+03, 0.29110400E+03, 0.51019300E+03, -.30241200E+03, -.66667700E+03, -.39344100E+03, 0.26282200E+03, 0.17498500E+04, -.92806800E+03, -.11325700E+04, -.62450400E+03, 0.24980200E+03, -.79394200E+02, -.26213600E+03, 0.17010600E+03, 0.19405900E+03, -.14665800E+04, 0.72551200E+03, 0.23262500E+02, 0.33163500E+03, 0.35635600E+03, 0.41044600E+03, 0.20624100E+03, 0.76497000E+03, 0.21964700E+03, 0.31006200E+03, -.92428300E+02, -.58202700E+02, -.10763200E+03, -.38127100E+03, -.93321000E+03, -.76400700E+03, -.60887500E+03, -.79227800E+02, -.41452000E+04, 0.20717300E+04, 0.20778500E+04, 0.64716400E+03, 0.39987900E+03, 0.79525500E+03, -.50846400E+03, 0.33183400E+03, 0.19126200E+04, 0.10397800E+04, -.49488500E+03, -.53928700E+03, -.87564200E+02, -.16869300E+02, -.63453700E+03, -.81953200E+03, -.74583300E+03, 0.38554200E+02, -.15541500E+04, 0.71335800E+03, 0.68706200E+03, 0.19948000E+03, 0.10381600E+04, -.15713600E+03, -.15416100E+04, -.30679200E+03, 0.16123100E+04, 0.12672200E+05, -.62652600E+04, -.63203500E+04, 0.59209600E+03, 0.23179100E+04, -.60062700E+04, -.55638900E+04, -.66579500E+04, 0.80173200E+03, 0.11582200E+04, -.58606000E+03, -.66638800E+03, -.25971300E+03, -.62129000E+03, -.22800300E+03, -.84509900E+02, -.14534900E+03, -.49151700E+02, 0.61046600E+04, -.30452900E+04, -.30480300E+04, -.82314900E+03, -.65184800E+02, -.16622600E+04, -.99640900E+02, -.10638400E+04, -.19391600E+04, 0.53044700E+03, -.23884500E+03, 0.22238800E+02, -.55203900E+02, 0.59074400E+03, -.78035300E+03, -.85936200E+03, -.14283700E+04, 0.62040700E+03, 0.16650900E+04, -.83141300E+03, -.75272700E+03, -.28963400E+03, 0.35604300E+03, -.94437600E+03, -.93688300E+03, -.68927300E+03, 0.10007900E+03, -.14919600E+05, 0.74342000E+04, 0.74661000E+04, -.40291400E+03, -.27946100E+04, 0.67996600E+04, 0.45434800E+04, 0.72261600E+04, -.45308900E+03, -.14286900E+04, 0.65734800E+03, 0.69593500E+03, 0.78402500E+03, 0.10605000E+04, 0.97433900E+02, -.67139000E+03, 0.27129200E+03, 0.90098900E+03, 0.17493600E+03, 0.63112200E+03, 0.31383500E+03, 0.53173300E+03, -.17677400E+03, -.62114600E+03, 0.31943500E+03, 0.17379300E+03, 0.32930000E+03, 0.11141400E+02, -.31176800E+03, 0.48478700E+03, -.32153200E+03, 0.17679700E+04, 0.76120200E+02, -.86071000E+03, 0.14687900E+04, -.42913800E+02, 0.24747800E+04, 0.32336300E+03, -.29182700E+03, 0.29780500E+03, 0.65031300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15976700E+01, 0.23619700E+00, -.12878900E+01, -.75576900E+00, 0.40668000E+01, -.66545400E-01, -.31218600E+01, -.10519100E+01, 0.14429700E+01, 0.86220200E+00, 0.12204200E+01, -.10676900E+01, 0.66280500E+00, -.56814600E+00, -.63592500E+00, 0.32498000E+00, 0.67602200E-01, 0.39779500E+00, 0.35420900E+00, 0.13786900E+01, -.41698200E+00, -.59179500E+00, 0.59478300E+00, 0.85495600E+00, 0.20008000E+00, -.15549700E+00, -.57124200E+00, -.42744300E-01, 0.21652400E+00, -.31265500E+00, 0.11304000E+00, 0.41280400E+00, 0.37897700E-01, 0.17957800E+00, -.11151700E+00, 0.19739400E+00, 0.26649000E+00, 0.47485700E-01, -.28063700E+00, -.19051500E+00, -.10646400E+01, -.88611600E-01, 0.76642000E+00, 0.49129000E-01, -.72384700E+00, -.32849600E+00, -.12637000E+00, 0.38365500E+00, 0.19056700E+01, 0.13042100E+00, -.24589200E+00, 0.19343300E+00, -.99003800E+00, -.63769700E+00, 0.12076800E+00, -.15456100E+01, -.50989500E-01, 0.89074200E-01, 0.33717000E+00, 0.16088300E+00, -.50954100E+00, -.14767600E+00, -.66148800E-01, -.94880600E+00, -.84867200E-01, 0.55730100E-01, 0.74983200E-01, -.20733300E+00, -.49016700E+00, 0.21415600E+00, 0.55714000E+00, 0.10931600E-01, 0.17517000E+00, 0.54527700E-01, -.39321400E+00, 0.35775400E+03, 0.54427000E+03, -.39368700E+03, -.52180900E+03, -.50458700E+03, 0.37753100E+03, 0.45517900E+03, -.27028700E+03, -.24260100E+03, -.12314400E+03, 0.36276800E+03, -.24568100E+03, -.81701200E+03, 0.10103100E+03, 0.41733000E+03, 0.50571200E+03, -.25409300E+03, -.18646600E+03, -.23020600E+03, -.33474600E+03, 0.10623200E+03, 0.50227100E+03, 0.34194600E+03, -.32141300E+03, -.67853500E+02, 0.77992200E+02, 0.43494300E+02, -.18403300E+03, -.30661000E+03, -.18815700E+03, -.97147300E+02, -.11941300E+03, -.14650500E+03, -.18469800E+04, 0.92307100E+03, 0.92254200E+03, 0.15857700E+03, 0.61456900E+02, 0.38037700E+03, 0.21995900E+03, 0.31738000E+03, 0.99446700E+03, 0.77183200E+03, -.37145700E+03, -.37980200E+03, -.95858600E+02, -.59158600E+01, -.35868000E+03, -.28405700E+03, -.48620100E+03, -.10772100E+02, 0.37948400E+03, -.22101700E+03, -.17717700E+03, -.11330700E+03, 0.32191800E+03, -.37594200E+03, -.75483600E+03, -.46431600E+03, 0.59440700E+03, 0.74958800E+04, -.37064600E+04, -.37421900E+04, 0.13807600E+03, 0.13240400E+04, -.34537600E+04, -.27125600E+04, -.37687700E+04, 0.58848900E+03, 0.64614800E+03, -.32712000E+03, -.30669400E+03, -.20272700E+03, -.41005800E+03, -.84270400E+02, 0.45788800E+02, -.87304400E+02, -.80619300E+02, 0.26572500E+04, -.13242200E+04, -.13290400E+04, -.25369400E+03, 0.15087400E+03, -.81883500E+03, -.67639800E+03, -.81744200E+03, -.94529500E+03, -.74557200E+02, 0.54015200E+02, -.27196000E+02, 0.41316600E+03, 0.78130500E+03, -.62727200E+03, -.87821200E+03, -.90714900E+03, 0.55808100E+03, 0.10000400E+04, -.50324500E+03, -.51190500E+03, -.22414900E+02, 0.16790900E+03, -.54980000E+03, -.59380600E+03, -.25370400E+03, 0.19086200E+02, -.83085600E+04, 0.41304300E+04, 0.41542400E+04, -.16173300E+03, -.18198600E+04, 0.37888600E+04, 0.23851100E+04, 0.39991600E+04, -.50870200E+03, -.48323400E+03, 0.20391000E+03, 0.22518100E+03, 0.56975300E+03, 0.69061300E+03, -.20742300E+03, -.70095800E+03, -.16210800E+03, 0.62951800E+03, 0.28912300E+03, 0.48512300E+03, 0.32456100E+03, 0.33830500E+03, -.24780600E+03, -.48115300E+03, 0.13872900E+03, 0.23763000E+03, 0.39502100E+03, 0.17305500E+03, -.22819800E+02, 0.33598200E+03, -.17910400E+03, 0.65356400E+03, -.11215600E+03, -.40042900E+03, 0.70563500E+03, 0.10977300E+03, 0.10155700E+04, 0.26872600E+03, -.32034800E+03, -.10601900E+03, 0.16329200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.53935800E+01, 0.73277700E+00, -.77080300E+01, -.28429700E+01, 0.72414600E+01, 0.48253200E+00, -.50227900E+01, -.31821200E+01, 0.56155200E-01, 0.79628700E+00, 0.29607800E+01, -.25928500E+01, 0.37032000E+00, -.22449200E+01, -.12506300E+01, 0.84585900E+00, 0.74927000E+00, -.56257400E+00, -.10667500E+01, 0.75706200E-01, 0.14990300E+01, -.26920200E+00, 0.18444800E+00, 0.24586100E+00, 0.10370700E+01, -.46096700E-01, -.26187200E+01, -.56935000E-01, 0.40533700E+01, -.79263900E+00, 0.13762900E+00, -.16130800E+01, 0.97685600E+00, 0.84272900E+00, 0.95558500E+00, 0.42111300E+00, 0.62500400E+00, -.75967100E+00, 0.11008900E+01, -.20091000E+01, 0.57432400E+00, -.44435300E+00, 0.77486800E+00, 0.49728700E+00, 0.12956400E+01, -.20057500E+00, 0.17233100E+00, -.11890700E+01, -.33837400E+01, -.50123800E-01, 0.54072500E+00, 0.55015100E-01, 0.16014600E+01, -.57437800E+00, -.63807200E+00, 0.86033000E+00, 0.37797700E-01, 0.44657100E+00, -.40008000E+00, -.56339700E+00, 0.65062200E+00, 0.17796800E+01, -.18759800E+01, 0.20099000E+00, -.57858200E-01, -.53769500E+00, 0.14565500E+01, -.14383200E-01, 0.62674300E+00, 0.60001600E+00, 0.38512500E+00, 0.55181800E+00, -.10899300E+00, -.99212700E-01, 0.70836800E+00, 0.10916300E+01, -.25848000E+03, 0.18217700E+03, 0.36768800E+03, 0.81784800E+03, -.13221800E+03, -.25055100E+04, 0.13324600E+04, 0.10784700E+04, -.25210300E+03, 0.78976400E+03, 0.85930700E+03, 0.63476300E+03, 0.12921300E+04, -.45382300E+03, -.93297700E+03, 0.46630400E+03, 0.40040500E+03, 0.99397200E+02, 0.19159100E+03, 0.22804600E+03, 0.10648600E+02, -.69771700E+03, 0.37534000E+03, 0.24358800E+04, -.12823100E+04, -.10288800E+04, -.25674100E+00, -.10651200E+04, -.75846700E+03, -.10566000E+04, -.14094900E+04, 0.54330300E+03, -.27985400E+04, 0.13976400E+04, 0.13933800E+04, 0.11366600E+04, 0.15215000E+04, 0.60304500E+03, -.19416700E+04, -.33944500E+03, -.29796000E+03, 0.61484200E+03, -.32161600E+03, -.23693900E+03, -.24755300E+03, -.83252300E+03, 0.14294700E+03, 0.26674700E+02, 0.47548100E+02, -.27046800E+03, 0.75381200E+03, -.34824400E+03, -.14632500E+03, -.23822300E+03, -.79005500E+03, 0.14280600E+03, 0.72215200E+03, 0.35049900E+03, -.11894600E+04, -.13666700E+05, 0.67824800E+04, 0.68536800E+04, -.11942700E+04, -.15609600E+04, 0.68873900E+04, 0.46312500E+04, 0.67297700E+04, -.43510400E+03, 0.26511200E+04, -.13188100E+04, -.13938100E+04, -.11448800E+03, -.56865800E+03, -.86846200E+03, -.56012600E+03, -.13367000E+04, -.37054800E+03, 0.46174900E+04, -.23103400E+04, -.23133800E+04, -.11496700E+04, -.19610200E+04, -.91930700E+03, 0.26019000E+04, 0.24564500E+03, -.12281800E+03, 0.27309700E+04, -.13822300E+04, -.16021200E+04, 0.55978300E+02, -.94082300E+03, -.65530500E+03, 0.72400300E+02, 0.53861900E+03, -.92631000E+03, 0.17700200E+04, -.86414600E+03, -.11002400E+04, 0.35384400E+03, 0.23901300E+03, -.88731000E+03, -.46133100E+03, -.14344200E+04, 0.30778800E+03, 0.94085600E+04, -.46702100E+04, -.47060400E+04, 0.17278400E+03, 0.18765100E+04, -.45575400E+04, -.30251700E+04, -.45123700E+04, -.48109800E+03, -.32315200E+04, 0.16678500E+04, 0.15772600E+04, -.41408400E+02, 0.81572900E+03, 0.97813700E+03, 0.56381400E+03, 0.19195100E+04, 0.46770800E+02, 0.40346200E+03, 0.12015000E+04, 0.64651500E+03, 0.62718600E+03, -.44742400E+03, -.12017000E+04, 0.90444600E+03, 0.48252300E+03, 0.18420000E+03, 0.27309600E+03, 0.18600800E+03, 0.63648200E+03, -.59377600E+03, -.90544100E+03, -.74579300E+02, -.77606200E+03, -.83576800E+03, -.40865000E+03, -.15793700E+04, 0.57755000E+03, -.66068300E+03, 0.35976300E+03, -.75318000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.89674200E+00, 0.17476100E+00, -.90238700E+00, -.49623200E+00, 0.32331600E+01, -.58121400E-01, -.26991600E+01, -.14627500E+01, -.11754900E+00, 0.12719700E+00, 0.13544800E+01, -.43869000E+00, 0.63333200E+00, 0.33800600E+00, -.77984600E+00, 0.72284000E+00, -.21847200E+00, -.13081700E+00, 0.28014500E+00, 0.65453100E+00, -.15160200E+00, -.19633600E+00, 0.21423800E+00, 0.11322700E+00, 0.66178800E-01, -.11189000E+00, 0.38634900E+00, -.14527800E-01, 0.11055600E+01, -.22857100E+00, -.52486200E-01, -.24427900E+00, -.63794700E-01, 0.59895000E-01, -.14080100E+00, -.20988800E+00, -.67440000E-01, -.87446100E-01, 0.31171700E+00, -.20661000E+00, 0.27279600E+00, 0.31060700E-01, -.42810400E+00, 0.11524100E+00, 0.30240200E+00, 0.33827500E+00, -.34002500E-01, 0.46383100E-01, -.88376200E+00, -.40690900E-01, -.15510900E-01, -.90637400E-01, -.11000200E+00, -.98220700E+00, -.31718300E+00, -.31102100E+00, 0.16107300E+00, -.34300700E-02, -.61452800E-01, 0.19394000E+00, 0.12702200E+00, 0.56794500E-01, 0.13227000E+00, -.89198500E+00, 0.37357500E+00, 0.13211000E+00, 0.18829700E+00, 0.18241800E+00, 0.45633900E+00, -.29713100E-01, -.76554700E-01, 0.96090000E-01, -.37114300E+00, -.48900800E-01, -.81648300E-01, 0.19163200E+00, 0.14116900E+00, -.42528500E+02, -.80337900E+02, -.11477900E+03, 0.15468700E+02, 0.51706400E+03, -.28648100E+03, -.99105500E+02, -.22679300E+03, -.14922300E+03, 0.44642300E+02, 0.41591500E+03, -.92132400E+02, -.19523500E+03, -.41041600E+03, 0.20388300E+03, 0.22934200E+03, 0.42188400E+02, 0.82281100E+02, 0.66669700E+02, -.59770100E+02, 0.36788800E+03, 0.13090500E+03, -.25532000E+02, 0.36173600E+02, -.76100800E+02, 0.15704000E+03, 0.17775400E+03, -.22889300E+03, -.47076900E+03, -.11925800E+03, 0.14829000E+03, 0.79046600E+03, -.39325400E+03, -.39450400E+03, -.11198600E+03, -.24720200E+03, -.14748800E+03, 0.39829700E+03, -.13495900E+02, -.10311700E+03, -.77437700E+02, 0.42340300E+02, 0.12579800E+02, 0.87899500E+02, 0.10484100E+03, -.91689800E+02, -.19353900E+03, -.79070500E+02, 0.11085000E+03, -.39869700E+03, 0.18548700E+03, 0.76285000E+02, 0.90853600E+02, 0.61891200E+02, 0.78967900E+02, 0.15941600E+03, 0.13203600E+03, 0.14602800E+03, 0.97902300E+03, -.47830200E+03, -.50161300E+03, 0.14870300E+03, 0.12498000E+03, -.59337000E+03, -.56850200E+03, -.61904100E+03, 0.90802800E+02, -.40007900E+03, 0.19841400E+03, 0.22432100E+03, 0.69520600E+02, 0.10823800E+03, 0.87906500E+02, -.53896800E+01, 0.16090100E+03, 0.13031500E+03, -.11214800E+04, 0.55958300E+03, 0.56126300E+03, 0.84737700E+02, 0.33267700E+03, 0.18796000E+03, -.56731700E+03, 0.19031900E+02, 0.19592100E+03, -.13958200E+02, 0.17682900E+02, 0.91168900E+02, -.10176500E+03, -.58181000E+02, 0.89881400E+02, 0.26255100E+03, -.17457900E+03, -.12283700E+03, -.34598600E+03, 0.16921600E+03, 0.22915100E+03, -.16324000E+03, -.24929000E+02, 0.23384400E+03, 0.23060700E+03, 0.31420700E+03, -.15655500E+03, -.65150300E+03, 0.31937500E+03, 0.32538700E+03, 0.51243600E+02, -.65747400E+02, 0.44581800E+03, 0.71049500E+03, 0.48201800E+03, 0.23996500E+02, 0.51420500E+03, -.27738300E+03, -.24034700E+03, -.75050100E+02, -.11895800E+03, -.72656000E+02, 0.22112100E+03, -.18615700E+03, -.11672500E+03, -.57133100E+02, -.19724600E+03, -.14780200E+03, -.48327500E+02, 0.63404100E+02, 0.19758500E+03, -.20056400E+02, -.66132000E+02, 0.67748800E+02, 0.76511800E+02, -.37751100E+01, -.35287900E+02, 0.64472200E+02, 0.22250300E+03, 0.11446300E+03, 0.10242500E+03, 0.39872300E+03, -.97353600E+01, 0.24545600E+03, -.25459800E+02, 0.11662000E+03, 0.36052200E+03, 0.57046000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.38122500E+01, -.54175200E+00, 0.26155600E+01, 0.18434600E+01, -.17404100E+02, 0.15931600E+00, 0.19048200E+02, 0.10356400E+02, -.83117900E+00, -.14304900E+01, -.56440100E+01, 0.26661600E+01, -.48621500E+01, 0.38526800E+01, 0.18150400E+01, -.28420500E+01, -.12213100E+01, -.63767600E+00, 0.22105400E+01, -.29406200E+01, 0.88293400E+01, 0.91737000E+00, -.66618500E-01, -.13286800E+01, -.45568500E-01, 0.18426600E+01, 0.65203700E+00, -.68297400E+00, -.95520400E+00, 0.28870400E+01, -.14275500E+01, -.76020400E-01, 0.63380600E+00, 0.69744700E+00, 0.70489000E-02, 0.30862800E+01, 0.57388200E+00, -.88411100E-01, -.10662600E+01, -.91426100E+00, -.11803600E+01, -.65409400E+00, 0.34261100E+00, 0.20893100E+00, -.10255200E+01, -.29464600E+01, 0.48222000E+00, -.16593100E+01, 0.49642000E+01, 0.36000100E+01, -.64708000E+00, 0.10870300E+01, -.41245800E+01, 0.12576100E+01, 0.13872700E+01, -.34407700E+01, 0.36680000E-01, 0.64324000E+00, 0.94900300E+00, -.91156700E+00, -.25875300E+00, 0.80676800E+00, -.59055000E+00, -.91548100E+00, -.63974500E+00, 0.58246900E+00, 0.17001100E+01, 0.19231600E+00, 0.13626500E+00, -.98824900E+00, -.43306000E+00, -.24167900E+00, -.82797200E-01, -.76052100E-01, -.48227100E+00, 0.15021000E+01, 0.21700500E+00, -.12884300E+01, -.60133400E+03, -.72830200E+03, 0.64717900E+02, 0.50181300E+03, -.30934900E+03, -.42955300E+03, -.16016300E+03, -.33110700E+03, 0.31354500E+03, 0.11643500E+04, 0.29729100E+03, -.88608600E+02, 0.36752700E+02, -.20057100E+02, -.40747200E+03, 0.52591000E+03, 0.54470700E+03, -.28488700E+03, -.51767000E+03, -.51053500E+03, 0.13189900E+03, -.33822900E+03, 0.19317100E+03, 0.23661200E+03, 0.16850600E+03, 0.48526700E+03, -.50627100E+03, -.39711400E+03, -.28766100E+03, 0.17790300E+02, -.97400800E+03, 0.48726700E+03, 0.49462500E+03, 0.79668300E+03, -.11142200E+03, 0.14789000E+03, -.79392000E+03, 0.69041500E+03, 0.64958200E+03, -.38473500E+03, 0.17584800E+03, 0.16758900E+03, 0.21391400E+03, 0.30807300E+03, -.22245900E+03, -.61958300E+03, -.81972600E+02, 0.20914100E+03, -.22464000E+04, 0.10964700E+04, 0.11851100E+04, -.11344500E+03, 0.33948200E+03, 0.77376900E+03, 0.18465500E+03, 0.29329200E+03, 0.38419400E+03, 0.14901100E+04, -.77149000E+03, -.74808500E+03, 0.15137400E+04, 0.12571700E+04, -.18997900E+04, -.29354500E+04, -.14209800E+04, 0.83351000E+03, -.80021100E+03, 0.39396500E+03, 0.33423200E+03, -.62884500E+02, -.10737200E+00, 0.39326900E+03, 0.37272600E+03, 0.67543200E+03, -.14987600E+03, 0.17258100E+04, -.86154200E+03, -.85844300E+03, -.96384000E+03, 0.27273700E+03, -.50345000E+03, 0.36552700E+03, -.11830400E+04, -.55069300E+03, -.28745900E+04, 0.14411200E+04, 0.17068500E+04, -.93222200E+03, 0.16128100E+03, 0.10503600E+04, 0.25844800E+03, 0.59411300E+03, 0.74718700E+03, -.13912000E+04, 0.67850200E+03, 0.80589400E+03, -.79364700E+03, -.28055300E+03, 0.89524400E+03, 0.13833300E+04, 0.80844400E+03, -.49161000E+03, -.52830500E+04, 0.26538900E+04, 0.26459700E+04, -.29821900E+03, -.45227000E+03, 0.27248700E+04, 0.28504800E+04, 0.24172400E+04, 0.15844800E+03, -.12204500E+03, 0.43740700E+02, 0.10961100E+03, 0.26805200E+03, 0.11146800E+03, 0.14279200E+02, 0.29381600E+03, -.84120100E+03, 0.25526200E+03, -.75653600E+01, -.66299900E+03, -.43492100E+03, 0.24048600E+02, -.20801500E+01, 0.66527400E+03, -.79929100E+02, -.12020400E+02, -.21301800E+03, -.30043100E+03, -.28380600E+03, -.33492400E+02, 0.12591800E+03, 0.20378900E+04, 0.16315700E+03, 0.38290600E+03, 0.85741500E+03, 0.90303400E+02, 0.19947300E+04, -.64808600E+02, 0.31451700E+03, 0.11064700E+04, 0.27582400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13002800E+01, -.12603900E+00, -.16807000E+01, -.31703100E+00, -.87517000E+00, 0.14872100E+00, -.12750800E+01, 0.17506500E+00, -.48430700E+00, -.66921000E-01, 0.27072400E+00, -.40310600E+00, 0.15375500E+00, -.17730600E+01, 0.20697200E+00, -.50646400E+00, 0.10399900E+00, -.29669500E+00, -.27734800E+00, -.58604200E+00, -.62047000E+00, 0.21958200E+00, 0.10963600E+00, -.21636700E+00, 0.47509800E+00, -.99683300E-01, -.60322100E+00, 0.17447900E-01, 0.58064100E+00, -.14089000E+00, -.26353800E+00, -.10657700E+00, 0.70026000E+00, 0.38711100E-01, -.27269500E+00, -.48866200E+00, -.47583500E-01, -.65323400E-01, 0.53195900E+00, 0.22697300E+00, 0.36002000E+00, 0.72906700E-01, -.33796800E-02, 0.11189400E+00, -.36390000E+00, -.18488400E+00, 0.24494500E+00, -.29207400E+00, 0.20878400E+00, -.11739400E+00, -.48468400E-01, -.97579400E-02, -.12108800E+00, -.21311400E+00, 0.37692100E+00, -.31234300E+00, 0.53185500E-01, 0.55493600E-01, -.98621200E-01, 0.17218200E+00, -.31045500E-01, 0.34338100E-02, -.41838200E+00, -.62962300E-03, -.48564800E+00, -.24519100E+00, -.10505900E+00, -.39408700E-01, -.69548800E-01, 0.15668900E+00, -.40766500E+00, -.16160200E+00, 0.14061000E+00, 0.13879100E+00, -.13897500E+00, 0.13180300E+00, 0.56508000E-01, 0.59190800E+00, -.11372900E+00, -.25006400E+03, 0.25423500E+02, -.73908400E+02, 0.53850200E+02, -.11782200E+03, 0.25453800E+03, -.23501300E+03, -.67067400E+02, 0.10359100E+03, -.16724300E+03, 0.44848700E+02, 0.55108000E+03, -.27525400E+03, -.35622500E+03, 0.77015600E+01, -.13115700E+02, -.18859200E+03, -.17582500E+03, -.40000900E+03, -.49614900E+02, -.32310600E+03, 0.15031300E+03, 0.21988400E+03, -.12132600E+03, 0.17791800E+03, 0.40329400E+03, 0.70445800E+03, 0.46883900E+03, -.22382800E+03, 0.76815600E+03, -.38358900E+03, -.38165300E+03, -.32488100E+03, -.33141000E+03, -.70652900E+02, 0.15630900E+03, 0.23647800E+03, -.36127100E+03, -.36306100E+03, 0.18397100E+03, 0.18557500E+03, 0.31024600E+02, 0.12419700E+03, 0.14886600E+03, 0.21831100E+03, 0.17561200E+03, -.83093000E+01, -.52209500E+03, 0.26597700E+03, 0.34393600E+03, 0.37114900E+02, -.22169000E+02, 0.22438200E+03, 0.20899600E+03, 0.38317700E+02, -.27390100E+02, -.59867300E+03, 0.30113300E+03, 0.30693900E+03, 0.38002800E+02, -.36056500E+03, 0.21449400E+03, 0.30127100E+03, 0.34410700E+03, -.21902000E+03, -.64633300E+03, 0.32430700E+03, 0.30435600E+03, 0.29779300E+02, 0.21204800E+03, 0.23584900E+03, 0.27632500E+03, 0.25124900E+03, 0.18207300E+02, -.16183200E+04, 0.80694200E+03, 0.81045300E+03, 0.40545600E+03, 0.33864300E+03, 0.35754200E+03, -.13041900E+03, -.81121900E+01, 0.44422900E+03, -.11417200E+04, 0.56323300E+03, 0.59332600E+03, 0.23187300E+02, 0.91343900E+02, 0.47794300E+03, -.53358000E+02, 0.43721700E+03, 0.15043000E+03, -.64023900E+03, 0.31594300E+03, 0.34041200E+03, -.31172600E+02, -.95888400E+02, 0.37335900E+03, 0.28766300E+03, 0.32854000E+03, -.76695300E+02, 0.18503200E+04, -.92546100E+03, -.92328000E+03, 0.85294000E+02, 0.41664800E+03, -.79032100E+03, -.34910700E+03, -.94522100E+03, 0.31134100E+03, 0.77931400E+03, -.38133900E+03, -.38756400E+03, -.97851000E+02, -.35592400E+03, -.18460800E+03, 0.49712700E+02, -.40814300E+03, -.17077100E+03, -.50321200E+02, -.28661900E+03, -.13365700E+03, -.25904600E+03, 0.69711700E+02, 0.28397400E+03, -.24891700E+03, -.69540300E+02, -.16775500E+03, -.22466600E+03, -.10388400E+02, -.27405400E+03, 0.17660600E+03, -.41014200E+03, -.57830000E+02, 0.33996500E+03, -.32536500E+03, 0.11556600E+03, -.48967800E+03, -.18007300E+03, 0.11936700E+03, -.18114800E+03, 0.14528400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.43308600E+01, 0.89462200E-01, -.23822300E+01, -.64915800E+00, -.45814000E+01, 0.34232000E+00, -.13198300E+01, -.81896300E-01, 0.14365500E+01, -.13003700E+01, -.75317300E+00, 0.23991000E+00, -.17829900E+00, -.17839300E+01, 0.19879200E+00, -.94355500E+00, 0.19789000E+00, -.50350500E-01, -.83164500E+00, 0.16064700E+01, 0.21621700E+00, -.10483600E+01, 0.58259800E+00, 0.66476100E+00, -.83036200E+00, -.40698200E+00, -.54685200E-01, -.57950600E-01, 0.24644500E+00, -.63590700E+00, -.69946900E-01, -.12470900E+00, -.38460900E-01, 0.65372300E+00, 0.37221700E+00, -.13921900E+01, -.23616800E+00, -.52446300E+00, 0.11323000E+01, -.50585900E+00, 0.26813900E+00, -.29345100E-01, 0.16202200E+00, -.77727500E-01, -.88531400E+00, -.23492800E+00, -.66983800E-01, -.84779100E-01, 0.32669700E+00, -.45599400E+00, -.40576400E-01, 0.49320300E-02, 0.86261400E+00, -.16217400E+01, -.16681100E+00, -.11963200E+01, -.33064000E-01, 0.20308200E-01, 0.39348000E+00, -.41871300E+00, 0.40664400E+00, 0.43076000E+00, 0.42150000E+00, -.48802700E+00, 0.13995600E-01, -.11898700E+00, 0.18050600E+00, -.15507900E+00, -.50381800E-01, 0.34025300E+00, 0.21136400E+00, -.25029200E-02, -.53344000E+00, -.46677300E-01, -.13359300E+00, -.89401300E-01, -.51431800E-01, -.10657100E+00, -.84520500E-01, -.26479900E-01, -.85257200E+02, -.18727700E+03, 0.54595600E+02, 0.29887200E+03, -.35290600E+03, -.10375100E+03, 0.37727600E+03, 0.13685000E+03, 0.32456900E+03, 0.70134300E+02, -.34744600E+04, 0.17327800E+04, 0.16928600E+04, 0.20683200E+03, 0.77076800E+03, 0.72276800E+03, -.38747000E+03, 0.98192800E+03, 0.75510600E+03, 0.22905800E+03, -.90507400E+02, -.16747500E+03, 0.47452200E+03, 0.24269100E+03, -.74428400E+03, -.41026600E+03, -.64312500E+03, 0.36645500E+03, -.31539200E+04, 0.15760700E+04, 0.15767700E+04, -.39314100E+03, 0.49525800E+03, 0.12306300E+04, 0.10675900E+04, 0.14647200E+04, 0.48012700E+03, 0.43168600E+03, -.22095200E+03, -.23132600E+03, -.42270200E+02, -.70300600E+02, -.20226700E+03, -.10400100E+03, -.66838100E+02, -.97658400E+02, 0.10975200E+04, -.57344700E+03, -.69550300E+03, -.30969300E+03, -.24396600E+03, -.24810300E+03, 0.18359400E+03, -.11867800E+03, -.27641800E+03, 0.15549900E+03, -.86187900E+02, -.91645200E+02, -.68101700E+03, 0.10433800E+03, -.10956500E+03, -.33267100E+03, 0.25833800E+03, -.23122400E+02, 0.42614200E+03, -.21455900E+03, -.20830600E+03, -.63028800E+02, 0.78790500E+02, -.35009400E+03, -.25319100E+03, -.43945400E+02, 0.14291400E+03, 0.17549000E+04, -.87726900E+03, -.87877000E+03, 0.43738500E+03, -.33681200E+03, -.86929500E+03, -.12687500E+04, -.11541300E+04, -.29218000E+03, 0.50556500E+03, -.24241700E+03, -.18890000E+03, 0.39764600E+03, -.57180800E+03, -.63401400E+02, 0.33530900E+01, 0.17129200E+03, -.28910500E+03, -.23083800E+03, 0.10850700E+03, 0.11622100E+03, 0.13127900E+03, -.17212700E+01, -.15725000E+03, -.50275800E+03, 0.17415300E+00, 0.16317000E+03, 0.10923200E+03, -.44549300E+02, -.56223000E+02, -.15802600E+03, -.27454100E+03, 0.27729000E+03, 0.52910300E+03, 0.18342000E+03, -.18164200E+03, -.45550900E+03, 0.20501500E+03, 0.24323700E+03, -.11596800E+02, 0.27328400E+03, 0.12890900E+03, -.57494800E+03, -.25936900E+03, 0.26316000E+03, 0.12247700E+03, 0.18040200E+03, 0.23030200E+03, -.21410900E+03, -.89590900E+02, -.18022300E+03, -.36764900E+02, 0.75935300E+02, 0.34109700E+03, 0.43772400E+03, 0.17928800E+03, -.17038400E+03, 0.86190200E+02, -.65135800E+03, -.70857700E+02, 0.18646900E+03, -.14351600E+03, -.28658800E+03, -.78409400E+03, -.94481700E+02, -.18755600E+03, 0.33712700E+02, -.18164500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20174000E+01, 0.27541800E+00, -.21386500E+01, -.10102000E+01, 0.24682100E+01, -.15528500E+00, -.14439000E+01, -.27088100E+00, 0.25793100E+00, -.40457900E-01, 0.19109500E+01, -.97322100E+00, 0.11322900E+00, -.26857800E+00, -.30634600E+00, 0.14417700E+00, 0.46540100E-01, -.75053400E-01, -.35452500E+00, -.64058900E+00, -.99604700E+00, -.10085800E-01, 0.29900700E+00, 0.11091900E+00, 0.14032600E+01, 0.46856900E-01, -.13333700E+01, 0.11769100E+00, 0.15555700E+01, 0.57013500E-01, 0.10493700E+00, -.18442400E+00, 0.73034900E+00, -.70091800E-01, -.90352500E-01, 0.67674900E+00, 0.28797800E+00, 0.15229000E+00, -.23378300E+00, 0.14831100E+00, -.27758000E+00, 0.36461400E-02, 0.52711700E+00, 0.26081100E+00, -.13938500E+00, 0.10639500E+00, -.44285800E+00, 0.94702100E+00, 0.10448300E+01, -.12811100E+01, -.86675100E-01, -.25219400E+00, 0.49008200E+00, 0.46270200E+00, -.26457400E+00, 0.25841000E+00, -.84541400E-01, -.81243800E-01, 0.36422600E-01, 0.88573200E-01, 0.49548000E+00, -.64499800E+00, 0.54531800E+00, 0.20466200E+01, -.84293300E+00, -.54866900E+00, -.67010300E+00, 0.40164000E+00, 0.95071800E+00, -.10274800E+00, -.10230100E+01, -.39655200E+00, -.15772100E+00, -.12629600E+00, 0.32148200E+00, -.61786800E+00, -.28307000E+00, 0.40177300E+00, -.10668800E+00, 0.42480800E+00, -.91897400E-01, -.12689000E+04, 0.62959700E+03, 0.77792900E+03, 0.27109300E+03, 0.28670500E+03, 0.29279800E+03, 0.89985900E+02, 0.41314800E+03, 0.92717000E+02, -.11302800E+03, 0.56759400E+02, -.72179400E+02, -.40866000E+02, -.43919100E+02, 0.10034800E+03, 0.88857300E+02, 0.20969300E+03, -.16456600E+02, 0.75029700E+03, -.38661100E+03, -.43182800E+03, -.34383400E+03, -.42759700E+03, 0.59605400E+02, 0.28601900E+03, -.30935500E+02, -.14240800E+03, 0.11440900E+04, -.57229400E+03, -.56892400E+03, 0.38731800E+03, 0.98754600E+02, -.46073500E+03, -.76220000E+03, -.39556900E+03, -.33517900E+03, 0.13701200E+02, -.20708700E+02, -.32599800E+02, -.75406000E+02, -.14379300E+03, 0.66274900E+02, 0.33276000E+02, 0.11203100E+03, -.34557700E+02, -.88536000E+03, 0.45154900E+03, 0.31066500E+03, 0.54834300E+02, -.73301000E+02, 0.30044400E+03, -.10917200E+03, 0.21720900E+03, -.17214600E+03, -.32420200E+04, 0.15906900E+04, 0.16039600E+04, -.16538600E+03, -.28140600E+03, 0.15069200E+04, 0.10151700E+04, 0.16329500E+04, 0.10713600E+02, 0.38923600E+03, -.19462000E+03, -.20883600E+03, -.20945400E+03, -.22202800E+03, -.81497600E+01, -.15541700E+02, 0.98421000E+02, -.19630700E+03, -.10353400E+04, 0.51729100E+03, 0.51747500E+03, -.31216500E+03, -.18919000E+03, 0.48539500E+03, 0.91083600E+03, 0.46405000E+03, 0.31810600E+03, -.45763700E+03, 0.22568900E+03, 0.38565400E+03, 0.16439100E+03, -.86680300E+02, 0.16652600E+03, -.13876800E+03, -.75921700E+02, -.63335700E+02, -.26803800E+03, 0.13876900E+03, 0.17462200E+03, -.11701600E+03, -.17321500E+03, 0.22038200E+03, 0.24846100E+03, -.37337600E+02, -.33196500E+02, 0.15275800E+04, -.74748100E+03, -.76446900E+03, -.64052600E+01, 0.36552000E+03, -.88546800E+03, -.84390600E+03, -.91658800E+03, -.74629000E+02, -.94428600E+03, 0.48314400E+03, 0.50942200E+03, 0.21048500E+03, 0.52025000E+03, 0.47734400E+02, -.12856600E+03, -.91458200E+02, 0.29428800E+03, 0.17190800E+03, 0.16564900E+03, 0.18528400E+03, 0.28342200E+02, -.20366600E+03, -.16809500E+03, 0.67373900E+02, 0.20961400E+03, -.67652500E+02, -.82619300E+02, 0.11200000E+03, 0.19864800E+02, -.51754700E+02, 0.17843600E+03, -.14086300E+03, 0.10628300E+02, -.30061500E+03, 0.95397500E+02, -.29272700E+02, 0.12106800E+03, -.18299800E+03, -.91216400E+02, 0.76915100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.64901400E+01, 0.91416100E+00, -.61355600E+01, -.29894400E+01, 0.19205800E+02, 0.11218500E+00, -.19743000E+02, -.99550900E+01, -.19413300E+00, 0.15909600E+01, 0.72017400E+01, -.41882300E+01, 0.43690600E+01, -.53879300E+01, -.23320000E+01, 0.37035400E+01, 0.70065800E+00, -.21874500E+00, -.28572800E+01, 0.15755700E+01, -.72657400E+01, -.11665300E+01, -.14094100E+00, 0.20527300E+00, -.94361500E-01, -.19130300E+01, 0.20377200E+01, 0.43948200E-01, 0.76518200E+00, -.31256500E+01, 0.65370900E+00, -.25023100E+00, 0.15656200E-01, -.12811800E+00, -.14232100E+01, -.16764100E-01, -.51116300E+00, 0.36098200E+00, 0.31240400E+01, 0.39199300E+00, 0.30910400E+01, 0.59245600E+00, -.20171400E+01, -.13128500E+01, 0.45834400E+00, 0.28189400E+01, 0.56972200E+00, -.11361700E+01, -.54498800E+01, -.84151100E+00, 0.30531100E-01, -.85295900E+00, -.82566300E-02, -.27865800E+01, -.11265100E+00, 0.36804800E+01, 0.18381200E+00, 0.11065400E+01, -.12276800E+01, 0.50026300E+00, -.14906500E+01, -.19885600E+01, -.44343100E+00, 0.36986100E+01, -.10081900E+01, -.15796200E+01, -.25278800E+01, 0.31121700E+00, 0.20468300E+01, 0.19347100E+01, 0.11880000E+01, -.20562800E+00, -.16959300E+01, -.99080800E+00, 0.11982000E+01, -.25752100E+01, -.32410900E+00, -.15308700E+01, -.13125000E+00, -.74562400E+01, -.85068700E+00, 0.17571300E+01, 0.30497100E+03, -.10779000E+04, 0.76793500E+03, 0.13349500E+03, -.31615400E+03, 0.12266000E+03, 0.23236200E+01, 0.12199500E+04, -.35578600E+04, 0.18280000E+04, 0.19126600E+04, -.23606400E+03, 0.83343100E+03, 0.59800800E+03, -.13346000E+04, -.98554300E+03, 0.91165500E+03, -.80710000E+03, 0.32090700E+03, 0.95690500E+03, 0.40193400E+03, 0.78592000E+03, -.34400100E+03, 0.20474400E+04, -.29672600E+03, -.22884400E+03, -.10769300E+05, 0.53931800E+04, 0.53773600E+04, -.23278300E+04, -.16206500E+03, 0.49590700E+04, 0.55846600E+04, 0.65684700E+04, 0.14263200E+04, 0.69283100E+03, -.20745600E+03, -.17939000E+03, -.10794000E+03, 0.14073900E+03, -.16675800E+03, 0.54451000E+03, -.31968800E+03, -.38230800E+03, 0.19537900E+04, -.10044700E+04, -.20284800E+03, -.45110400E+03, -.53286000E+03, -.16863600E+03, 0.14546800E+04, -.13669300E+04, -.13589400E+03, 0.55406900E+04, -.25391800E+04, -.26727400E+04, -.90652500E+03, -.24835000E+03, -.25979600E+04, -.16094300E+04, -.20565600E+04, -.14426500E+03, -.36042200E+03, 0.22033000E+03, 0.12157700E+03, -.21784600E+03, 0.32764200E+03, 0.85820800E+02, 0.10822100E+04, -.31457800E+03, 0.20263300E+02, 0.42904900E+04, -.21701300E+04, -.21464000E+04, 0.27186200E+04, 0.79363100E+03, -.32762100E+04, -.66075000E+04, -.54033300E+04, -.59070500E+03, -.23798200E+04, 0.10633400E+04, 0.46514900E+03, 0.20171000E+04, 0.58724500E+03, 0.46859900E+03, -.14578700E+04, 0.23550300E+04, 0.67078800E+03, 0.30148400E+03, -.17150100E+03, -.47153100E+03, 0.69562200E+03, 0.25399600E+03, -.27760300E+03, -.90952600E+03, 0.71437000E+03, -.15034800E+03, 0.17445700E+04, -.92755800E+03, -.86629600E+03, -.32782800E+03, -.45950900E+03, 0.80795800E+03, 0.30477900E+04, -.15215900E+03, -.87422400E+02, 0.26019700E+04, -.12709200E+04, -.14797000E+04, -.62230000E+02, -.65241300E+03, -.56477000E+03, -.89585600E+03, -.37552800E+03, 0.13173100E+03, 0.71935000E+03, 0.29191900E+03, 0.40041800E+03, -.68280400E+03, -.35415700E+03, -.29669900E+03, -.30363000E+03, 0.32250500E+03, 0.61331600E+03, 0.64075400E+03, -.24192400E+03, -.61373800E+03, 0.12774000E+03, -.40657600E+04, -.51120600E+03, 0.62509200E+03, -.48641800E+03, 0.61676300E+02, -.42074100E+04, -.27860800E+03, -.52864700E+03, -.26502900E+03, 0.27659200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.64246900E+01, 0.96618500E+00, -.96091400E+01, -.40630200E+01, 0.19793700E+02, 0.61426500E+00, -.19755900E+02, -.13490200E+02, -.16636200E+00, 0.28741400E+01, 0.49274500E+01, -.22613000E+01, 0.40215800E+01, -.48230400E+01, -.29869200E+01, 0.45400700E+01, 0.88448100E+00, 0.15354300E+00, -.17711000E+01, 0.15015300E+01, -.77649500E+01, -.12593600E+01, 0.35002900E+00, -.20354300E+00, 0.40646200E+00, -.21037000E+01, 0.24071700E+01, -.27840300E+00, 0.34187700E+01, -.50133200E+01, 0.97570600E+00, -.99794200E+00, 0.25233400E+00, 0.73971200E+00, -.11818700E+01, -.21136600E+00, -.52321300E+00, 0.36219900E+00, 0.27688400E+01, -.60517500E+00, 0.21741300E+01, 0.50013700E+00, -.16889500E+01, -.98132700E+00, 0.14863300E+01, 0.36387000E+01, -.77993700E+00, 0.65360200E+00, -.23659800E+01, -.54927800E+01, -.14654500E+00, -.11900200E+01, 0.66124800E+00, -.12535500E+01, -.19208100E+01, 0.12458700E+01, -.52991400E+00, 0.41874100E+00, -.53440300E+00, 0.35299600E+00, -.60693700E+00, -.10682900E+01, 0.24743900E+00, 0.29161100E+01, 0.18478200E+00, -.12791700E+01, -.18136900E+01, 0.56408600E+00, 0.17696600E+01, 0.16798800E+01, 0.18240200E+01, -.91883400E-03, -.11502700E+01, -.95278200E+00, 0.28317900E+01, -.31456000E+01, 0.94039800E-01, -.36023300E+00, -.72675300E+00, -.70033900E+01, -.12302600E+01, 0.22448700E+01, -.10957100E+00, -.14402100E+04, 0.11002500E+04, 0.12489500E+03, -.10651100E+04, -.95426200E+03, -.32233900E+03, 0.20554200E+04, -.22940000E+04, 0.11473800E+04, 0.91157600E+03, -.74074900E+02, 0.70682200E+03, 0.25418500E+03, -.15783600E+04, -.26394600E+04, 0.57227200E+03, -.33678800E+04, 0.17087500E+04, 0.23401800E+04, 0.47936800E+03, 0.14253100E+04, 0.96220100E+03, 0.34315000E+04, 0.45509200E+03, -.57366700E+03, -.71687000E+04, 0.35831900E+04, 0.35856400E+04, -.25406600E+04, -.91896400E+03, 0.40193300E+04, 0.53330700E+04, 0.66113900E+04, 0.43545700E+03, -.37253600E+03, 0.22919600E+03, 0.33993400E+03, -.88327000E+02, 0.36649400E+03, 0.23123500E+03, 0.88490800E+03, 0.23108600E+03, -.49229800E+03, 0.33130700E+04, -.16284000E+04, -.72440100E+03, -.78258700E+03, -.65097600E+03, -.42781500E+03, 0.14122700E+04, -.21097000E+04, -.79006600E+03, 0.13807200E+04, -.61033700E+03, -.58891600E+03, -.73820100E+03, -.22193800E+03, -.15583200E+04, -.16877300E+04, 0.23992500E+03, 0.16779700E+03, -.18261900E+04, 0.91720000E+03, 0.77854600E+03, 0.16940200E+02, 0.66320000E+03, 0.64334700E+03, 0.13634500E+04, -.59314500E+02, -.15750600E+03, 0.32770600E+03, -.17162700E+03, -.15910300E+03, 0.25809500E+04, 0.13416900E+04, -.21730500E+04, -.64655400E+04, -.54613100E+04, 0.38376600E+03, -.25799800E+04, 0.12695400E+04, 0.80970200E+03, 0.12072600E+04, 0.70407800E+03, 0.72390700E+03, -.14997100E+04, 0.38427500E+04, 0.10369500E+04, -.11990100E+04, 0.55271800E+03, 0.39020900E+03, 0.16718000E+03, -.29370700E+02, 0.51786600E+03, -.30966000E+03, 0.11866400E+04, -.29438300E+03, 0.33036500E+04, -.17229500E+04, -.16414000E+04, 0.38010200E+03, -.48788100E+03, 0.11750100E+03, 0.28600800E+04, -.14469400E+04, -.15699400E+03, 0.37815100E+04, -.19063600E+04, -.20278300E+04, -.18558900E+03, -.89595700E+03, -.11805800E+04, -.12072400E+04, -.10308600E+04, 0.24932200E+03, 0.26374400E+03, -.52960400E+03, -.67613900E+02, -.53413500E+03, -.98503800E+01, 0.52268800E+03, -.50173800E+03, -.37513300E+02, 0.40620500E+03, 0.37677600E+03, -.46943100E+03, -.62233200E+03, 0.14833600E+03, -.39524700E+04, -.56334000E+03, 0.91554400E+03, -.11371800E+04, 0.34054200E+03, -.45155400E+04, -.52305200E+03, -.84237800E+02, -.31902500E+03, 0.22752400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.72823800E+00, 0.12300200E+00, 0.99215300E+00, -.53010400E-01, 0.42160900E+01, -.11427800E+00, -.49722700E+01, -.17848200E+01, -.35806600E+00, -.18210700E+00, 0.21459600E+01, -.93139900E+00, 0.14277700E+01, -.80890000E+00, -.20847600E+00, 0.34991600E+00, 0.72201500E-01, -.16694400E+00, -.14440800E+01, 0.31301700E+00, -.37810300E+01, 0.19209100E+00, -.36330500E+00, 0.41291200E+00, 0.55958100E+00, -.51263400E+00, 0.17109100E+00, 0.32952400E+00, 0.30546500E+00, 0.12464900E+00, 0.28030100E+00, 0.57494600E+00, -.32874800E+00, -.68276500E+00, -.38925200E+00, -.56561500E-01, 0.83618700E-01, 0.41844500E+00, -.59861300E+00, 0.70543200E+00, 0.38404200E+00, 0.21796400E+00, -.65330100E+00, -.61127700E-01, 0.77272800E+00, 0.94539700E+00, -.14669300E+00, 0.49454100E+00, -.16676100E+01, -.47476000E+00, 0.98021800E-01, -.10214300E+00, -.52598900E+00, -.13776600E+01, -.30772600E+00, -.46043000E-01, -.90359300E-01, 0.12752400E+00, -.36556000E+00, 0.75721900E+00, 0.37470400E+00, 0.49788400E+00, -.52144200E+00, -.22635200E+01, 0.40693900E+00, 0.87326100E-03, 0.75917500E+00, 0.24796200E+00, 0.64726900E+00, 0.10784000E+00, 0.12192200E+00, -.19846900E+00, 0.19713800E+00, -.15459300E+00, 0.34360200E+00, 0.26778800E+00, -.35008600E+00, -.61231900E+00, 0.35052100E-01, 0.19643800E+00, -.35639600E+00, -.12397900E+00, 0.41820100E-01, -.12137900E+00, -.30650900E+03, -.66328500E+01, 0.17648500E+03, 0.38252300E+03, 0.31069500E+03, -.13205300E+03, -.16462400E+04, 0.81935900E+03, 0.84118100E+03, 0.11291200E+03, 0.36408300E+03, 0.31871800E+03, -.23013700E+03, 0.11520900E+03, 0.45823600E+03, 0.27838900E+03, -.14291700E+03, -.71755300E+02, 0.30987500E+03, 0.79683400E+02, -.45007100E+03, -.38753300E+03, -.58835700E+03, 0.29032200E+03, -.16238200E+04, 0.81137500E+03, 0.80637400E+03, -.11604900E+03, 0.40368500E+03, 0.68655200E+03, 0.38329400E+03, 0.86571000E+03, 0.61860100E+02, 0.22943500E+03, -.12119500E+03, -.81786500E+02, -.80757300E+02, -.15809000E+03, -.34288500E+02, -.44210400E+02, -.21200200E+02, -.10946200E+03, 0.11090300E+04, -.55422700E+03, -.46403100E+03, -.33680000E+03, -.40465500E+03, -.13502300E+03, 0.53731200E+03, -.90625200E+02, -.48768400E+03, -.27000600E+04, 0.13344000E+04, 0.13587600E+04, -.52454000E+03, -.40067300E+03, 0.12949700E+04, 0.67640500E+03, 0.15280600E+04, -.17324300E+03, 0.50693500E+03, -.25370100E+03, -.27014700E+03, -.18029200E+02, -.70808000E+02, -.21649800E+03, -.85295400E+02, -.24920700E+03, -.36564800E+02, 0.11524600E+04, -.57724600E+03, -.57861800E+03, 0.84912300E+02, -.35371000E+03, -.57885100E+03, -.48421600E+03, -.82054800E+03, 0.11750200E+02, 0.84177100E+03, -.41648100E+03, -.56334600E+03, 0.91720100E+02, -.41037500E+03, -.17447800E+03, 0.30230500E+02, 0.29975600E+03, -.34762400E+03, 0.12255000E+03, -.56938000E+02, -.17046800E+03, 0.16933700E+03, -.38692700E+02, -.19582000E+03, -.35229800E+03, -.14378700E+03, 0.42136000E+02, 0.27154900E+04, -.13521800E+04, -.13592800E+04, 0.14298200E+03, 0.39803600E+03, -.98858200E+03, -.11917200E+03, -.11105900E+04, -.10512300E+03, -.92608200E+03, 0.46680500E+03, 0.43606400E+03, 0.11189200E+03, 0.31316400E+03, 0.22997500E+03, -.85073500E+02, 0.22370400E+03, 0.21688800E+03, 0.16933000E+03, 0.23873000E+03, 0.17963100E+03, 0.49561100E+02, -.14400500E+03, -.23932400E+03, 0.15286200E+03, 0.14549400E+03, 0.23822200E+03, 0.32076400E+03, 0.24751000E+02, 0.86123300E+02, -.73941700E+02, -.67129100E+03, -.52435800E+02, 0.17947800E+02, -.26320700E+03, -.13191000E+03, -.94727900E+03, 0.75256700E+02, -.17474100E+03, 0.16117600E+03, -.14744000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11775200E+00, -.53527400E+00, -.62336200E+00, 0.21815200E+00, -.68118100E+00, -.23389200E+00, 0.55432200E+00, 0.12262200E+01, 0.61433100E+00, 0.27607100E-01, -.17882800E+01, 0.30039800E+00, -.65925500E+00, 0.12192300E+01, 0.14728000E+00, -.86542800E-01, -.71154600E-01, 0.68911600E-01, 0.16074900E+00, -.35964900E-01, 0.13322600E+00, 0.52356800E-01, 0.35634300E-01, -.42434200E-01, -.58517300E-01, 0.42676500E-01, 0.25723100E+00, -.99793100E-01, -.32965400E+00, 0.30071000E-01, -.68391600E-01, 0.13319300E+00, 0.47003500E-01, 0.24781900E+00, 0.28799500E+00, 0.47266000E+00, 0.42648400E-01, -.40184300E-01, -.62099600E-01, -.75999900E-01, 0.17854700E+00, -.32739800E-01, -.43635700E+00, -.89753700E-01, 0.31132900E+00, 0.85499300E-01, 0.87908000E-01, -.28185500E+00, -.76657600E+00, 0.10595800E+01, 0.90897700E-02, 0.45350800E-01, -.21092900E+00, -.20987100E+00, 0.87725600E-01, -.16583000E+00, 0.20602700E-01, 0.72038800E-01, -.40261000E-01, 0.16596300E+00, -.14907600E+00, 0.22673400E+00, -.43273100E+00, -.25527700E+00, -.17428200E+00, -.11715400E+00, 0.13189200E+00, 0.59244900E-01, 0.12156200E+00, 0.21574700E+00, 0.54071000E-01, -.19451100E+00, -.39508300E-01, -.86399100E-01, 0.13515100E+00, 0.15419900E+00, -.15278100E+00, -.51942800E+00, 0.31128400E-01, 0.48153000E-01, 0.23713000E-01, -.38614800E-01, 0.94559200E-02, -.34796400E-01, 0.20243100E+00, -.84884800E+02, 0.47071500E+02, 0.27689000E+03, 0.60551200E+02, -.51630000E+02, -.61576200E+01, 0.33447900E+01, -.16207000E+02, 0.39177300E+02, 0.26717000E+02, -.33808000E+02, -.61082000E+02, -.11394600E+03, 0.19661200E+02, 0.99571300E+02, -.54462700E+02, -.42893600E+02, -.57706300E+02, 0.76994900E+01, 0.39893100E+02, 0.14752200E+03, 0.11592000E+02, -.69416100E+02, 0.53438200E+03, -.26672900E+03, -.26706900E+03, -.32622300E+02, -.10605800E+03, -.13402300E+03, -.31569900E+03, -.55341900E+02, -.23340500E+03, -.12736000E+03, 0.57938600E+02, 0.65384600E+02, -.90918700E+01, -.19535700E+01, 0.59179900E+02, 0.10965500E+01, 0.56349000E+02, -.19789500E+02, -.56227200E+03, 0.27974000E+03, 0.28438400E+03, 0.70108000E+02, -.10148500E+02, 0.20421000E+03, 0.17253600E+03, 0.13222500E+03, 0.88247900E+01, -.73668600E+03, 0.35625600E+03, 0.36754600E+03, -.88486500E+02, -.17447100E+03, 0.31644100E+03, 0.18717200E+02, 0.34522800E+03, -.14923600E+03, -.74483200E+02, 0.36839900E+02, 0.30126200E+02, 0.16485800E+02, 0.66954500E+01, 0.64455100E+02, 0.10187100E+03, 0.31984400E+02, -.33286600E+02, -.45279000E+03, 0.22564900E+03, 0.22621000E+03, 0.17108200E+02, 0.97515700E+02, 0.11973600E+03, 0.32129100E+03, 0.55206700E+02, 0.21947900E+03, -.19713300E+01, -.74609800E+00, 0.56159600E+01, -.48939900E+02, -.62390100E+02, 0.91461500E+02, 0.21780100E+02, 0.14721300E+03, -.59278100E+01, -.21063100E+03, 0.10589800E+03, 0.97306300E+02, 0.11490700E+02, -.20593200E+02, 0.10721000E+03, 0.16138700E+03, 0.54904400E+02, -.18891900E+02, 0.86362800E+03, -.42387600E+03, -.43185000E+03, 0.21328900E+03, 0.26786000E+03, -.40431800E+03, -.27775200E+02, -.44643400E+03, 0.18257200E+03, -.12611400E+02, 0.11307300E+02, 0.95385300E+01, -.24300900E+02, -.35810100E+02, 0.18287000E+02, 0.15417300E+03, 0.98210300E+02, -.41214200E+02, -.14020600E+02, -.59019000E+02, -.22368200E+02, -.13196800E+02, 0.42272400E+01, 0.58895900E+02, 0.11263000E+02, -.11062000E+00, -.62155100E+02, -.74558000E+02, -.56268800E+02, -.14930800E+02, -.82855900E+01, -.72249900E+02, 0.28937900E+01, 0.54363600E+02, -.12743400E+03, 0.31974600E+02, -.14098800E+03, -.26149800E+02, 0.26892000E+02, 0.24496000E+02, 0.22276500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.28840900E+01, -.18114200E-01, -.30469000E+01, -.11414800E+01, 0.24453000E+01, 0.90897500E+00, -.28332100E+01, -.14929100E+01, 0.62224000E+00, 0.18584200E+01, 0.36324200E+00, -.26408700E+01, -.31393700E-01, -.34880800E+01, -.12779400E+01, 0.77618800E+00, 0.13379800E+01, -.48854400E-01, -.99575300E+00, 0.64689200E+00, -.78533300E+00, 0.97722100E-01, -.61950400E+00, 0.26091400E+00, -.11766300E+00, -.23272100E+00, -.92871300E-01, 0.90367600E-01, -.15326900E+01, 0.63905100E-01, 0.21543900E-01, 0.26166800E+00, 0.34812200E+00, 0.23752700E+00, -.43101000E-01, -.50502800E+00, -.23399400E+00, -.13237200E+00, 0.15272400E+01, -.19705200E-01, 0.66289100E-01, -.11045000E+00, 0.22754900E+01, -.28110500E+00, -.22537700E+01, -.78539800E+00, -.32580700E-01, -.10916300E+00, 0.25819900E+01, -.19380400E+01, -.29182700E+00, -.10577100E+00, 0.48665500E+00, 0.92663700E-02, 0.85079800E+00, -.13486700E+01, -.78722500E+00, 0.44226700E+00, 0.45043800E+00, -.12528900E+00, -.46015400E+00, 0.11866600E+01, -.88719400E+00, 0.53548300E+00, -.93320000E+00, -.82084400E+00, -.52125800E+00, -.19535500E+00, -.10903900E+01, -.97414100E+00, 0.44178700E+00, 0.24501100E+00, 0.83657500E+00, 0.53247900E-01, -.13137000E+00, 0.19568100E+00, 0.45794700E-01, -.43988400E+00, 0.13598900E+00, -.76231300E+00, -.58812300E+00, 0.49540000E+00, -.15546300E+00, -.41821800E-01, -.77537500E+00, 0.28556700E+01, 0.28539400E+03, -.10017800E+03, -.14625800E+03, 0.36659400E+03, -.42834400E+04, 0.21435400E+04, 0.22443100E+04, 0.16048700E+03, 0.91756500E+03, 0.82676800E+03, -.77579800E+03, 0.11939300E+04, 0.96036300E+03, -.14486700E+03, 0.97956900E+02, 0.56295900E+02, 0.64173800E+03, 0.55161400E+03, -.89470800E+03, -.22830100E+03, -.50845800E+03, 0.28756800E+03, -.49174700E+04, 0.24578700E+04, 0.24591800E+04, -.90870600E+03, 0.31907500E+03, 0.22011600E+04, 0.32644200E+04, 0.25500000E+04, 0.76559400E+03, 0.38281100E+03, -.15864000E+03, -.20190300E+03, -.41389700E+01, 0.32175800E+02, -.22090400E+03, 0.14989500E+02, -.50775700E+02, -.98379800E+02, 0.18959700E+04, -.94500900E+03, -.96146300E+03, -.25929700E+03, -.31492100E+02, -.62944100E+03, -.17318900E+02, -.65539200E+03, -.43438000E+02, 0.17754400E+04, -.82450700E+03, -.87966700E+03, -.33028200E+03, 0.42507400E+02, -.92043300E+03, -.55105500E+03, -.49837400E+03, 0.12604000E+03, 0.13890900E+03, -.63139600E+02, -.24050000E+02, -.10372800E+03, 0.22224400E+03, -.30946900E+03, -.19476800E+03, -.24100100E+02, 0.13204600E+03, 0.16667100E+04, -.83595600E+03, -.83222000E+03, 0.11053400E+04, -.99796900E+02, -.12858400E+04, -.34880500E+04, -.16407300E+04, -.40345000E+03, 0.32278300E+03, -.16228500E+03, -.19940700E+03, 0.59994000E+03, -.50226300E+03, -.30534000E+02, 0.12184700E+03, 0.23948600E+03, -.28851200E+03, -.12646100E+03, 0.55508400E+02, 0.11712400E+03, 0.16543200E+03, 0.33264200E+02, -.24901000E+03, -.10992900E+04, 0.49824800E+02, 0.12054600E+03, 0.15620700E+03, -.11061400E+03, -.76929400E+02, -.63073900E+03, -.53117600E+03, 0.68103200E+03, 0.85941600E+03, 0.44035100E+03, -.46469100E+03, 0.17458700E+03, -.11608700E+03, -.10557600E+03, 0.26577700E+02, -.36038200E+02, 0.86106700E+02, -.71329700E+03, -.20878500E+03, 0.24663100E+03, 0.89549400E+02, 0.59452700E+02, 0.12121700E+03, -.41688600E+03, -.47094400E+01, -.60629200E+02, -.21634100E+03, -.10329500E+02, 0.25202700E+03, 0.36972000E+03, 0.93489600E+02, -.33051000E+03, 0.20495600E+03, -.15619300E+04, -.91769400E+02, 0.23285700E+03, 0.80415600E+02, -.30800700E+03, -.15687600E+04, -.22441000E+03, -.11052900E+03, 0.61782300E+02, -.10080300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.56391700E+00, -.65375700E-01, 0.35280400E+00, 0.36997900E+00, -.43480900E+01, 0.30205400E+00, 0.29332900E+01, 0.13020300E+01, -.51764800E+00, -.91575800E+00, -.77129200E+00, 0.90135500E+00, -.53297900E+00, 0.80884300E+00, 0.35256600E+00, -.45954300E+00, 0.14512600E+00, 0.14524200E+00, 0.92527900E+00, -.20002800E+00, 0.16891700E+01, 0.39590800E-02, 0.21655200E+00, -.44518100E+00, 0.40873100E+00, 0.22728000E+00, -.36563400E+00, -.14427100E+00, 0.16147700E+01, -.82972200E-01, -.43157400E+00, -.12840800E+01, 0.19199800E+00, 0.33857700E+00, 0.34257800E+00, -.64626100E-01, 0.19873100E-01, -.30356500E+00, 0.77329400E+00, -.41376000E+00, -.33790400E+00, -.15372900E+00, 0.90141500E+00, 0.13390600E+00, -.60229800E+00, -.48618800E+00, 0.40496900E-01, -.37653800E-01, 0.89067400E+00, 0.31009500E+00, -.11399100E+00, -.48586200E-01, 0.61179500E+00, 0.65480300E+00, 0.30403700E+00, -.29870700E+00, 0.30987100E-01, -.94834000E-01, 0.18683900E+00, -.94165600E-01, -.34470800E+00, 0.93343500E-01, -.50603100E+00, 0.16779400E+00, -.56181100E+00, 0.81343400E-02, 0.22524500E+00, -.34676800E+00, -.81669300E+00, 0.11810200E+00, 0.70373600E+00, -.69927900E-01, 0.44392900E+00, 0.51850500E-01, -.93632600E-01, 0.57167000E+00, 0.15744700E+00, -.41562000E+00, -.13865000E+00, -.10056600E+00, 0.40926100E-01, -.29209300E+00, -.60381300E-01, -.20568700E-01, -.56361000E+00, -.11400500E+01, 0.42153300E+00, 0.70346900E+03, 0.34312800E+03, 0.21691800E+02, 0.62247900E+03, -.31031500E+03, -.43960000E+03, 0.73848800E+02, -.60273600E+02, -.19823100E+03, -.98292100E+02, -.54938600E+03, -.13046900E+03, -.11973500E+03, 0.38728900E+02, 0.10492200E+03, -.23912400E+03, -.58272100E+02, 0.22772600E+03, 0.26197500E+03, -.88749200E+02, -.19727300E+03, 0.16626000E+04, -.83113000E+03, -.83239700E+03, 0.36021000E+03, -.24701800E+03, -.56318200E+03, -.11817400E+04, -.12983300E+03, -.47550300E+03, -.31123700E+03, 0.13332500E+03, 0.16849200E+03, -.57549300E+02, -.36345000E+02, 0.12716200E+03, -.10293000E+03, 0.83930700E+02, -.63588500E+02, -.10537700E+04, 0.53919400E+03, 0.56194200E+03, 0.39848100E+02, -.10612700E+03, 0.47160900E+03, 0.42289800E+03, 0.20936400E+03, -.12017700E+03, -.19528900E+04, 0.93142300E+03, 0.97299200E+03, 0.37554900E+02, -.16518000E+03, 0.62035300E+03, -.40573400E+03, 0.84222200E+03, -.15017400E+03, -.12686000E+03, 0.61432000E+02, 0.19691600E+02, -.40522200E+02, -.13126000E+03, 0.22846400E+03, 0.25786400E+03, 0.67597900E+02, -.22066800E+03, -.84431300E+03, 0.42148600E+03, 0.42129700E+03, -.49030400E+03, 0.25099800E+03, 0.28581900E+03, 0.10338500E+04, -.20689400E+03, 0.44417800E+03, -.57064400E+03, 0.27751900E+03, 0.30443000E+03, -.21565900E+03, 0.10273300E+03, 0.30703900E+03, 0.49997400E+01, 0.50838300E+03, 0.28344900E+03, -.39321400E+03, 0.20120200E+03, 0.14085800E+03, -.20914600E+03, -.11151700E+03, 0.31712300E+03, 0.60488000E+03, 0.19452200E+03, -.17199500E+03, 0.86789300E+03, -.41287000E+03, -.43448700E+03, 0.54775200E+03, 0.46522500E+03, -.42870600E+03, 0.43212500E+03, -.59416700E+03, 0.34349300E+03, -.28728800E+03, 0.16846200E+03, 0.15416200E+03, 0.15511900E+03, 0.24878700E+03, -.46607800E+02, 0.43479300E+03, 0.11510000E+03, 0.17971000E+03, 0.40845000E+02, -.95815700E+02, -.27078500E+02, 0.16596800E+03, -.85721100E+02, 0.95297700E+02, 0.16329400E+03, 0.89474000E+02, -.10678900E+03, -.13543200E+03, -.25720000E+03, 0.14088800E+03, -.14924900E+03, 0.35084200E+03, -.26205100E+02, 0.18436100E+02, -.23427400E+03, 0.18124300E+03, 0.57817700E+02, 0.88092000E+02, -.39768900E+01, 0.19597200E+03, 0.14380200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.99317800E+00, 0.17990900E+00, -.12125000E+01, -.65541500E+00, 0.32964700E+01, -.33607900E+00, -.42643500E+00, 0.55017500E+00, 0.20576200E+00, 0.11727500E+01, 0.25391600E+00, -.98764700E+00, -.24491600E-01, -.76919700E+00, -.56133800E+00, 0.19001300E+00, 0.57689600E+00, -.36577300E-01, -.53255700E+00, -.99709800E+00, 0.12235600E-01, -.67027400E-01, 0.88695800E-01, 0.47170800E-01, 0.46058700E-01, -.38971600E-01, -.28967400E+00, -.16783600E-02, 0.32110800E+00, -.17995500E+00, 0.14689000E-01, 0.51684400E-01, 0.14138300E+00, 0.12583700E+00, -.25164600E-01, 0.21073700E+00, 0.13806600E+00, -.11308300E+00, -.21876100E+00, -.13935700E+00, -.30049700E+00, -.11501900E-01, -.38180200E+00, -.59393700E-01, 0.41753100E+00, -.16088900E+00, 0.97632900E-01, -.31943300E+00, -.41224600E+00, 0.58385800E+00, 0.44142500E-01, 0.55798500E-01, -.20376400E+00, 0.94450000E-01, -.18444700E-02, 0.22147300E+00, 0.45338400E-01, -.13888000E-01, -.21463400E-01, -.15495300E+00, -.41449400E+00, 0.24817200E-01, 0.11871300E+00, -.30766800E+00, 0.37185600E+00, 0.22715300E+00, -.22797800E+00, -.12051500E+00, -.35276200E+00, -.32112000E-01, 0.17574600E+00, 0.13176500E+00, -.23110600E+00, 0.11255900E+00, -.16482200E+00, -.59930500E-01, 0.26709900E+00, 0.39532700E+00, -.10130400E-02, 0.23666700E+00, -.13167100E+00, -.26224700E+00, -.33970500E-01, 0.15632500E-01, -.36174900E+00, 0.13797000E+01, 0.65667700E-01, -.40402300E+00, 0.15036500E+03, 0.50773500E+02, -.17453300E+03, 0.87026100E+02, 0.97583200E+02, -.14580500E+02, 0.61320600E+02, 0.28710500E+02, -.50932100E+02, 0.53261400E+02, 0.32256600E+02, -.24202800E+03, 0.12303400E+03, 0.15189600E+03, 0.13627600E+03, 0.16950900E+03, -.96444400E+02, -.28941200E+03, -.17456600E+03, 0.13033100E+03, -.98864700E+02, 0.50131700E+02, 0.46329500E+02, 0.66718400E+02, 0.82864400E+02, 0.55022600E+02, 0.48500300E+03, 0.26312000E+03, 0.15386300E+03, 0.71764200E+02, -.34348400E+02, -.18735700E+02, -.95672600E+00, 0.25261000E+02, -.50341200E+02, -.39384400E+02, -.41783700E+02, 0.16621800E+01, 0.91228400E+03, -.46019200E+03, -.41833500E+03, -.17616400E+03, -.16272000E+03, -.17746700E+03, 0.13163000E+03, -.15054200E+03, -.24563100E+03, -.17132200E+03, 0.88457100E+02, 0.89076100E+02, 0.76291800E+02, 0.14433600E+03, -.47664400E+02, 0.34967000E+02, 0.14116300E+03, 0.15932200E+03, -.72653400E+02, 0.36186900E+02, 0.27455000E+02, -.35259000E+02, 0.86639100E+01, -.46628700E+01, -.70989900E+02, 0.25335400E+02, -.76027700E+01, 0.50910100E+02, -.26308500E+02, -.26532800E+02, -.72627000E+02, -.73534100E+02, -.55279900E+02, -.51527700E+03, -.31138800E+03, -.12329200E+03, -.42400700E+03, 0.21241200E+03, 0.14008900E+03, 0.70187100E+02, 0.26483300E+02, 0.12148300E+03, 0.27626900E+03, 0.22812000E+03, 0.75040600E+02, -.18378800E+03, 0.92278200E+02, 0.32634400E+02, -.56802000E+02, -.91747500E+02, 0.10650900E+03, 0.15751700E+03, 0.20618700E+03, -.54490000E+02, 0.15966200E+03, -.79107200E+02, -.80761800E+02, -.12125100E+03, -.85997700E+02, 0.55424200E+02, 0.24773300E+02, 0.92755100E+01, -.13947300E+03, -.20567700E+03, 0.10036100E+03, 0.87332200E+02, 0.11696600E+03, 0.10303700E+03, -.14857900E+01, -.13069900E+03, -.94083100E+02, 0.14698700E+03, 0.59995600E+02, -.62633100E+02, -.16853000E+02, -.22628600E+02, -.49758400E+02, 0.62125700E+02, 0.54835000E+01, 0.39280800E+02, 0.37783400E+02, 0.63313700E+02, -.51724100E+02, -.98618700E+01, 0.53566500E+01, 0.11482700E+03, -.93474000E+01, 0.37057600E+02, 0.33948100E+02, -.21642000E+02, 0.53291200E+02, 0.21950200E+02, -.19590900E+01, 0.66765200E+02, 0.42016100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.44880200E+00, -.78730300E-01, 0.39561600E+00, 0.29066500E+00, -.16164400E+01, -.74039400E-01, 0.14273200E+01, 0.80244000E+00, 0.20951100E+00, -.13494100E+00, -.54458300E+00, 0.24250300E+00, -.18808500E+00, -.13326100E+00, 0.43473600E+00, -.18203800E+00, -.96795900E-03, 0.23463000E+00, -.15550600E+00, -.30678000E+00, -.44062600E+00, -.67228900E-02, 0.35640700E-01, 0.36601900E-01, -.15911700E-01, 0.50844300E-03, 0.30002200E-02, -.44698400E-01, -.12073600E+01, 0.13613500E+00, 0.34168100E-02, 0.14284300E+00, -.14784600E+00, -.19333700E+00, 0.81163100E-01, -.32616800E-01, -.60805900E-01, 0.17942100E+00, 0.27365700E+00, 0.26423900E+00, 0.68443400E+00, 0.76734100E-01, -.27575700E+00, -.21926200E+00, -.19594600E+00, 0.17267600E+00, -.22834600E-01, 0.58455300E-01, -.41208000E+00, -.11557800E-01, 0.50126700E-01, -.28312100E-01, 0.11912200E+00, -.23675700E+00, -.13841000E+00, 0.11162700E+00, -.79490300E-01, -.36462900E-01, -.50897300E-01, 0.10860300E+00, 0.14252700E+00, 0.15827200E+00, -.10574400E+00, -.31320500E+00, 0.13738800E+00, -.21835800E-01, 0.11357400E+00, 0.82489900E-01, 0.94880200E-01, -.48951200E-01, -.29671000E+00, 0.55033800E-02, 0.12507100E+00, -.41135100E-01, -.57611000E-01, -.32322200E+00, -.12454400E+00, 0.26946800E+00, -.32489800E-01, -.48517700E-01, 0.99701300E-01, 0.17144000E+00, -.33912400E-02, 0.42401000E-01, 0.16300400E-01, -.62714900E+00, 0.14996700E+00, 0.22528900E+00, -.21257900E+00, -.16866600E+03, 0.69479200E+03, -.34737900E+03, -.28998200E+03, -.76322000E+02, -.18651400E+03, -.87916900E+02, 0.26023100E+03, -.23932900E+02, -.15510300E+03, 0.26932600E+03, -.13473500E+03, -.12873600E+03, -.14930800E+03, -.18360300E+03, 0.60525600E+02, -.74292000E+02, 0.93069500E+02, 0.85387400E+00, 0.18873700E+03, -.94563300E+02, -.96012700E+02, 0.20813300E+03, 0.74677100E+02, -.23265800E+03, -.64696400E+03, -.49603800E+03, 0.51656900E+02, 0.80692800E+02, -.42875300E+02, -.29564500E+02, -.68552300E+01, -.29315700E+02, -.11198200E+02, -.27854400E+02, -.63578800E+02, 0.39186800E+02, -.44830700E+03, 0.21614700E+03, 0.24312300E+03, 0.62385500E+02, 0.35086700E+02, 0.12293900E+03, -.49402800E+02, 0.18678000E+03, 0.10685200E+03, 0.38752900E+03, -.19785900E+03, -.19132800E+03, 0.77648500E+02, 0.58543200E+02, -.29168900E+02, 0.11811200E+03, -.30331500E+03, -.14621700E+02, 0.14630200E+03, -.74193500E+02, -.70691500E+02, 0.10798200E+01, -.70245200E+02, -.19643100E+02, -.35679700E+01, -.22134700E+02, 0.22295100E+02, 0.53963800E+03, -.26858500E+03, -.27085500E+03, -.17130100E+03, -.92805100E+02, 0.18104600E+02, 0.72084200E+03, 0.30747500E+03, -.12837900E+03, 0.76118900E+02, -.35951400E+02, -.10071600E+03, -.12669100E+02, 0.78982000E+02, -.11174600E+03, -.12645300E+03, -.30298800E+03, -.14335600E+02, 0.22638800E+03, -.11073900E+03, -.14987900E+03, 0.87622500E+02, 0.40515400E+02, -.93456400E+02, 0.79956800E+02, -.10626200E+03, 0.50157700E+02, -.62633600E+03, 0.31846100E+03, 0.31239500E+03, 0.16037900E+02, 0.13231800E+02, 0.10300800E+03, -.13371600E+03, 0.23448100E+03, 0.45389700E+02, -.12499600E+03, 0.62591300E+02, 0.52086300E+02, 0.75558200E+01, -.10395100E+01, 0.52733400E+02, 0.14809200E+03, 0.78365200E+02, -.95621000E+02, 0.20737300E+02, 0.10276000E+03, 0.50791700E+02, 0.56554300E+02, -.31811100E+02, -.10197800E+03, 0.43106500E+02, 0.37188200E+02, -.51554200E+02, -.71841700E+02, 0.18496600E+02, 0.59692300E+02, -.31087700E+02, 0.31778200E+03, 0.22752200E+02, -.78896700E+02, 0.92793500E+02, 0.25964600E+02, 0.40860800E+03, 0.59422300E+02, -.37282500E+02, -.30457900E+02, 0.41053600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.50236800E+01, 0.48269000E+00, 0.38125100E+01, 0.10038600E+01, 0.23206000E+00, -.71666800E+00, 0.29203200E+01, 0.95410900E+00, -.28627100E-01, -.27319500E+00, -.87316900E+00, 0.91045100E+00, -.34995300E+00, 0.21337800E+01, 0.37421000E+00, -.66841100E+00, -.25955900E+00, -.24777800E+00, 0.78103800E+00, 0.88678800E+00, 0.11191100E+01, -.30596800E-01, -.23122500E+00, -.32290000E-01, -.10227500E+00, 0.15333900E+00, -.34234600E-01, -.10481400E+00, -.32001300E+00, 0.59751600E+00, 0.11951400E+00, -.75745700E+00, -.53479500E+00, 0.45905600E-01, 0.76727600E+00, 0.12807700E+00, -.36509800E-01, 0.71615000E-01, 0.19149300E+01, 0.26243200E+00, 0.10607600E+01, 0.11906100E-01, -.47026600E+00, 0.33775100E+00, -.19200200E+00, 0.28080800E-01, 0.14033100E+00, -.59508300E+00, -.19360900E+01, -.69658400E+00, 0.32642600E+00, -.20317500E+00, 0.10204000E+01, -.25484900E+00, -.53302400E+00, 0.14269800E+01, 0.26343400E-01, -.90778100E-01, -.21382700E+00, -.72290500E+00, 0.12457500E+00, 0.44702700E+00, 0.33504000E+00, 0.17075200E+00, 0.14264500E+01, 0.66313900E+00, 0.47599200E+00, -.14275000E+00, -.34221000E+00, 0.32983400E-01, 0.52572900E+00, 0.50343900E+00, 0.34665500E+00, -.30303300E-01, -.26165900E+00, -.67730700E+00, -.90713500E-01, -.70312300E-01, 0.56247400E-01, -.21811700E+01, 0.29109900E+00, 0.75340800E+00, 0.12192000E+00, 0.19129000E+00, -.43736700E+00, -.31900500E+01, 0.29127000E+00, 0.94450500E+00, 0.18126100E+01, 0.22949100E+01, 0.22948700E+04, -.11517800E+04, -.11217500E+04, -.18175400E+03, -.58993800E+03, -.55736200E+03, 0.38754500E+03, -.89000600E+03, -.56773600E+03, 0.24011200E+02, -.27107100E+02, -.62640700E+02, -.37443300E+03, -.35163000E+03, 0.52452700E+03, 0.82049100E+03, 0.71505200E+03, -.43061800E+03, 0.16266200E+04, -.81656500E+03, -.80852400E+03, -.18865000E+03, -.31497700E+03, -.55588600E+03, -.14176700E+04, -.10931500E+04, -.78275900E+03, -.26591500E+03, 0.12045900E+03, 0.10773500E+03, -.10726500E+03, -.19461200E+03, 0.26503900E+03, 0.28498000E+03, 0.13778300E+03, -.18778100E+03, -.18733900E+04, 0.97275900E+03, 0.89199100E+03, 0.46870600E+03, 0.35764000E+03, 0.32518700E+03, 0.13873200E+03, -.38534600E+02, 0.45011700E+03, -.11125100E+04, 0.53344000E+03, 0.55175800E+03, -.54053200E+03, -.91589500E+03, 0.89814600E+03, 0.38547200E+03, 0.46211200E+03, -.80042800E+03, 0.59956000E+03, -.30167900E+03, -.28107900E+03, 0.29129400E+02, -.13191900E+03, -.33307500E+02, 0.43020500E+03, -.40856000E+03, -.21597800E+03, -.10647400E+04, 0.53631500E+03, 0.53400800E+03, 0.24636600E+02, 0.17028200E+03, 0.47456800E+03, 0.15773500E+04, 0.10588000E+04, 0.58190700E+03, 0.21976500E+03, -.10459500E+03, -.16221800E+02, 0.13772600E+03, 0.48276800E+03, -.11216700E+03, -.80352500E+03, -.11995100E+03, 0.35090200E+03, 0.97564500E+03, -.48222800E+03, -.39334600E+03, 0.12890000E+03, 0.40680000E+03, -.43873200E+03, -.38891200E+03, -.76202800E+03, 0.15880600E+03, 0.22543200E+04, -.11326300E+04, -.11255800E+04, 0.72805100E+03, 0.76212400E+03, -.13032000E+04, -.44229700E+03, -.13249000E+04, 0.60911200E+03, 0.32133300E+03, -.14029000E+03, -.13459600E+03, -.25447000E+03, -.26889900E+03, 0.88312900E+02, 0.38044700E+03, 0.62465300E+03, -.32040700E+03, -.80164900E+02, 0.36743100E+03, 0.16487100E+03, 0.17017100E+03, 0.42914600E+02, -.36743100E+03, 0.83193900E+02, -.16001200E+02, -.13640300E+03, -.20512500E+03, -.30627700E+02, 0.10942800E+03, -.11871100E+03, -.91423600E+03, -.76430900E+02, -.75714200E+02, -.59286700E+03, 0.75360400E+02, -.86708100E+03, 0.56386700E+02, -.15183700E+03, -.41461200E+03, -.16256600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.42076100E+01, -.12095300E-01, -.41241400E+01, -.91408000E+00, -.35682700E+01, 0.30557300E+00, -.27864700E+01, 0.46803100E+00, -.85675900E+00, -.15512000E+01, 0.64598000E+00, -.48796800E+00, 0.47758000E+00, -.29860100E+01, 0.71196800E+00, -.73413400E+00, -.15152700E+00, -.65912900E+00, -.20658600E+01, -.48290900E+00, -.25550400E+01, 0.19206200E-01, 0.42257000E+00, -.51619000E+00, 0.52916100E+00, -.75676700E+00, -.74899900E+00, 0.22568300E+00, 0.23847200E+01, -.11472200E+01, 0.14604800E-01, 0.10081100E+00, 0.63824700E+00, 0.34413900E+00, -.17323200E+00, -.68293700E+00, -.88130200E-01, -.49091600E-01, 0.74196900E+00, 0.10082400E+00, 0.67600700E+00, 0.11643300E+00, -.77652700E+00, 0.26784400E+00, -.60237800E+00, -.55609000E+00, 0.46137600E+00, -.49178200E+00, -.36453300E+00, -.68458700E+00, 0.21963200E+00, 0.40621900E+00, -.10550500E+01, -.19604200E+01, -.42980900E+00, -.67243600E+00, 0.27868400E+00, 0.42375600E+00, -.26704000E+00, -.28781800E+00, 0.67521300E+00, -.28763600E+00, -.44921000E+00, -.67294700E+00, 0.32027900E+00, 0.47480900E-01, 0.94300200E+00, -.31937400E+00, -.67279700E-01, 0.14581300E+01, 0.76436000E+00, 0.66422800E-02, -.60797700E+00, -.24112200E-01, -.25405300E-01, 0.83527400E+00, 0.32558600E+00, -.85148800E+00, -.61776600E-01, -.11342400E+01, 0.10834900E+01, -.10287600E+01, 0.18935400E+00, 0.12547200E+00, -.36582700E+00, -.32470700E+01, -.61329600E+00, 0.52623200E+00, -.80829500E+00, 0.80856400E+00, -.34172500E+00, -.77357300E+01, 0.44317500E+02, -.10147000E+03, -.73961500E+02, -.83063000E+02, -.15215800E+03, -.19297300E+03, 0.14966000E+03, -.30038900E+03, 0.13284800E+03, 0.15927100E+03, 0.21037800E+01, -.75903900E+00, 0.19006900E+03, 0.79697100E+03, 0.20889600E+03, -.44436900E+02, 0.26730900E+04, -.13368300E+04, -.13376500E+04, -.27185200E+03, -.31430200E+03, -.36881800E+03, 0.11852400E+04, 0.30754600E+03, -.86851200E+03, -.26089700E+03, 0.11478000E+03, 0.13517700E+03, -.12421100E+03, -.14275800E+03, 0.22751500E+03, 0.34108800E+03, 0.23709600E+03, -.14361200E+03, 0.51296900E+03, -.21788400E+03, -.21588400E+03, 0.10247400E+03, -.72423100E+02, -.16704200E+03, 0.35185800E+03, -.58363700E+03, -.18104700E+03, -.30499600E+04, 0.14929600E+04, 0.15289900E+04, -.87782200E+03, -.12190100E+04, 0.16430500E+04, 0.14061200E+04, 0.20586900E+04, -.58782200E+03, 0.10174600E+03, -.51870300E+02, -.45023200E+02, -.78402200E+02, -.53258200E+02, 0.77942000E+02, 0.28187200E+03, -.95289700E+02, -.10725900E+03, -.36414900E+04, 0.18189000E+04, 0.18208600E+04, 0.25538800E+03, 0.28378200E+03, 0.68036200E+03, -.11899500E+04, -.79003200E+02, 0.97423400E+03, 0.48492500E+03, -.23557700E+03, -.28330900E+03, 0.29020700E+03, -.33268100E+02, -.45895900E+02, -.18776200E+03, 0.83856400E+02, -.30103400E+03, -.68024500E+03, 0.34646000E+03, 0.33393100E+03, 0.96340900E+00, -.45337800E+02, 0.12958400E+03, -.75524000E+03, 0.28091600E+02, 0.17706600E+02, 0.55260500E+04, -.27693800E+04, -.27630300E+04, 0.57371100E+03, 0.88600600E+03, -.21800600E+04, -.98798800E+03, -.25304400E+04, 0.15660600E+03, 0.18024500E+03, -.69059200E+02, -.95106900E+02, 0.30375400E+02, 0.13772200E+03, -.13151400E+03, -.26994500E+03, 0.17228900E+03, 0.55071300E+02, 0.25638000E+02, 0.11198100E+03, 0.17081700E+03, -.54835900E+02, -.54160300E+02, -.11785000E+03, -.49747300E+02, 0.67935900E+02, 0.55954900E+02, 0.63865100E+02, 0.19876300E+02, -.28619800E+02, -.11604500E+02, -.12840200E+04, -.16089500E+03, 0.12810200E+03, -.63588200E+03, 0.17297300E+03, -.17252000E+04, 0.48507600E+02, -.12281600E+03, -.30994100E+03, 0.32328400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.45367200E+01, 0.15199000E+00, -.71082800E+01, -.28656700E+01, 0.89379800E+01, 0.11968700E+01, -.11105300E+02, -.98188000E+01, -.15597100E+00, 0.22495800E+01, 0.16159200E+01, -.11833700E+01, 0.19000800E+01, -.38571800E+01, -.22992200E+01, 0.22843900E+01, 0.20507600E+01, 0.26940700E+00, -.50048200E+00, 0.16340700E+01, -.32841200E+01, 0.46796600E-01, -.48642500E+00, 0.91778600E+00, 0.10396800E+01, -.55535600E+00, -.19340700E+00, 0.53452400E+00, 0.27817900E+01, -.16250100E+01, 0.93478500E+00, -.69083800E+00, 0.49372600E+00, -.55063200E+00, -.11486000E+01, -.11983300E+01, -.84873500E-01, -.26979000E-01, -.36075100E+01, -.11466000E+01, -.29305600E+01, 0.14661800E+00, 0.75940600E+00, 0.84031200E+00, 0.36527000E+01, 0.22459900E+01, -.86264900E+00, 0.22995700E+01, 0.13367600E+00, -.27193600E+01, 0.24036500E-01, -.56464600E+00, 0.14980100E+01, 0.24146500E+01, -.13630600E+01, 0.17807900E+01, -.67290600E+00, -.39648800E+00, -.17372500E+00, 0.17458300E+00, 0.57959500E+00, -.11059600E+01, 0.78838500E+00, 0.21794600E+01, -.26896300E-01, -.26063100E+00, -.11144600E+01, 0.28816700E-01, 0.39279200E+00, -.42945800E+00, 0.14697100E+01, -.47897100E-01, 0.83440400E+00, -.75171100E-01, 0.30350400E+00, 0.19470100E+00, -.53311400E+00, -.15216100E+01, 0.22065000E+00, -.17235800E+01, -.73518300E+00, 0.19881800E+01, 0.34944300E-01, -.35474400E+00, 0.49979500E+00, -.16084500E+01, -.28881200E+00, -.15527800E+00, -.42874200E+00, -.57642000E+01, 0.83833400E+00, -.61808900E+00, 0.33406000E+03, -.13450200E+03, -.91296700E+02, 0.27124400E+02, -.29848700E+02, -.32751700E+03, 0.11615100E+03, 0.31469200E+03, -.14667400E+03, -.95555000E+02, 0.54618700E+02, -.14006000E+03, -.10460400E+03, 0.59311900E+03, -.33124100E+03, 0.24325100E+02, -.35073900E+04, 0.17526700E+04, 0.17394300E+04, -.85906400E+02, 0.19675800E+03, 0.15001600E+04, 0.11609700E+04, 0.18045200E+04, 0.28718700E+03, 0.36555200E+03, -.17961700E+03, -.11397500E+03, -.85304700E+02, -.15758500E+03, -.40850600E+00, 0.19092600E+03, -.78962700E+02, -.14995200E+03, 0.14039400E+04, -.72298200E+03, -.48506500E+03, -.89168700E+02, -.27495700E+03, -.27878500E+03, 0.29460900E+03, -.38478100E+03, -.12867600E+03, 0.15314900E+03, -.70506300E+02, -.53195000E+02, -.53651700E+03, -.28859200E+03, 0.24803500E+03, 0.19294600E+03, 0.28643200E+03, -.13152100E+03, 0.59867100E+03, -.29993400E+03, -.27822900E+03, 0.76429800E+02, -.16837000E+02, -.20768800E+03, 0.22246400E+03, -.42404300E+03, 0.61084900E+02, 0.35924100E+04, -.17951600E+04, -.18001800E+04, 0.27868000E+03, -.10222400E+03, -.15748700E+04, -.12418900E+04, -.18900100E+04, -.26178200E+03, 0.90269600E+03, -.44633200E+03, -.86102000E+03, 0.34790200E+03, 0.13032900E+02, -.44468100E+03, -.70449200E+03, 0.24739000E+03, -.17866100E+03, 0.32427200E+03, -.16351600E+03, -.37120000E+03, 0.55574500E+03, 0.32465900E+03, -.47630800E+03, -.96514900E+03, -.31892800E+03, 0.25914700E+03, 0.14897000E+04, -.74685100E+03, -.74821000E+03, 0.37953300E+03, -.20710800E+02, -.34845900E+03, 0.38142800E+03, -.50403100E+03, -.33706700E+03, 0.57662400E+03, -.29469500E+03, -.36773800E+03, -.21268800E+03, -.38230500E+03, 0.84279000E+02, 0.19360000E+03, 0.58597300E+03, -.39364500E+03, 0.14885700E+03, 0.43589800E+03, 0.32351600E+03, 0.36763900E+02, -.10055300E+03, -.43574000E+03, 0.12357200E+03, 0.11300100E+03, 0.21598600E+03, 0.22710900E+03, 0.29186700E+02, 0.79892100E+02, -.12871600E+03, -.13317000E+04, -.94286900E+02, -.17693400E+03, -.11332400E+03, -.59226100E+02, -.15937700E+04, 0.50595200E+02, -.27136000E+03, -.26333300E+02, -.22698400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.93145600E-01, -.16327200E+00, -.83044100E+00, -.16247300E-01, -.98202900E+00, 0.73554800E-03, 0.11246300E+01, 0.50643700E+00, 0.23439200E+00, 0.12271000E+00, -.10772900E+01, 0.29710800E+00, -.48261900E+00, 0.36052500E+00, 0.64739400E-01, -.81676300E-01, 0.16304900E-01, 0.40378100E-01, 0.36861600E+00, -.18020800E+00, 0.98007000E+00, -.16699100E-01, 0.84190600E-01, -.14937300E+00, -.11312900E+00, 0.15475300E+00, -.17682000E+00, -.72152900E-01, 0.14548800E+00, -.99767700E-01, -.68218300E-01, -.29930000E+00, 0.15557400E+00, 0.19228300E+00, 0.22606000E+00, -.16669700E+00, -.49343400E-01, -.14741800E+00, 0.30651600E+00, -.98029800E-01, -.17144700E-01, -.40766200E-01, 0.13846900E+00, 0.91999300E-01, -.31541000E+00, -.26686400E+00, 0.23913600E-01, -.59514200E-01, 0.52832800E+00, -.11318000E+00, -.17279400E-01, 0.13855800E-01, 0.20119000E+00, 0.29106600E+00, 0.12913700E+00, 0.13988000E-01, 0.32561400E-02, -.20847200E-01, 0.92425800E-01, -.18699700E+00, -.34130300E-02, -.58773300E-01, 0.13000500E+00, 0.30405800E+00, -.25014100E-02, 0.87825000E-01, 0.10337400E+00, -.61519500E-01, -.32648600E+00, -.42696600E-01, 0.26548000E-01, 0.44263400E-02, 0.13096800E+00, 0.84131600E-03, -.14054600E+00, 0.12478500E+00, 0.21590100E-02, 0.19137400E+00, 0.17082200E-01, -.15005900E-01, 0.20327300E+00, -.10901200E-01, 0.21314300E-01, 0.14583100E-01, 0.16320800E-01, 0.30547700E+00, -.11675800E+00, -.31889800E+00, 0.21360200E+00, -.13298100E+00, 0.20411300E+00, -.15378800E+00, -.11122400E+00, 0.55505200E+02, 0.29138500E+02, -.11935500E+02, -.53888200E+02, -.41371500E+02, 0.46571000E+02, -.47791500E+02, 0.17637100E+02, 0.30810200E+02, -.45228600E+01, -.31457700E+02, 0.28660500E+02, 0.17424400E+03, -.65368400E+02, -.20741400E+02, 0.23336400E+03, -.11722300E+03, -.11794100E+03, 0.15486300E+03, -.26268200E+02, -.47252200E+02, 0.92523800E+02, 0.15263000E+03, -.22515100E+02, -.32614400E+02, 0.99751400E+01, 0.21335100E+02, 0.42452100E+01, -.27600300E+01, 0.12118900E+02, 0.73487800E+01, 0.15727600E+02, 0.30516400E+01, 0.10069500E+03, -.44823400E+02, -.22035200E+02, 0.17858900E+02, 0.25518200E+02, -.43920000E+02, -.12530000E+03, -.55923400E+02, 0.24958500E+02, 0.91233300E+02, -.57689200E+02, -.44426800E+02, 0.48393700E+02, 0.11465100E+01, -.62758800E+02, -.99663500E+02, 0.22827200E+02, 0.20329000E+02, -.50925000E+02, 0.24892200E+02, 0.20103900E+02, 0.63267200E+01, -.15201500E+02, 0.36988000E+02, 0.98767300E+01, 0.16872000E+02, 0.29397500E-01, 0.46906700E+02, -.22907700E+02, -.23602200E+02, -.13467300E+03, 0.37265000E+02, -.50358300E+02, -.10571600E+03, -.24633000E+03, 0.25362700E+02, 0.14147500E+03, -.72728300E+02, -.87647100E+02, -.13657800E+03, -.58407400E+02, -.42742500E+02, -.28135100E+02, -.22662100E+02, -.56740300E+02, -.23441400E+03, 0.11920100E+03, 0.10114400E+03, 0.11160200E+01, -.48728200E+02, 0.46622000E+02, -.14102600E+03, 0.41970500E+02, 0.13560200E+02, -.13010100E+03, 0.68567700E+02, 0.64779200E+02, 0.55024600E+02, -.47851400E+02, 0.82441900E+02, 0.14765500E+01, 0.58021300E+02, -.58846900E+02, 0.35596500E+02, -.99507600E+01, -.20543900E+02, 0.27422700E+02, 0.37378600E+02, -.44131700E+02, -.78805000E+01, 0.11319300E+02, 0.20670000E+02, -.17967400E+02, -.28729100E+02, 0.57664500E+01, 0.33484100E+02, 0.58752300E+01, 0.28516900E+02, 0.10521500E+02, -.35178400E+01, -.44750600E+01, -.69492700E+01, -.10897600E+02, 0.37774000E+02, -.27967200E+02, 0.10302400E+03, -.23269300E+01, -.68400600E+02, 0.26150300E+02, 0.43430200E+02, 0.68578000E+01, 0.10816100E+02, 0.17535800E+02, 0.22898500E+01, 0.16855400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.35793500E+00, -.13620200E+00, -.18623800E+00, 0.64020800E+00, -.78379200E+01, 0.79192400E+00, 0.46013600E+01, 0.26464700E+01, 0.11633400E+00, -.13346600E+01, -.75136400E+00, 0.13221500E+01, -.15529600E+01, 0.11866100E+01, 0.39933300E+00, -.99316700E+00, -.37793400E+00, -.14355900E+00, 0.14053700E+01, -.11901800E+01, 0.21611700E+01, 0.28522300E-01, 0.10009200E+00, -.84918800E+00, 0.21111100E+01, 0.67589100E+00, -.21899600E+01, -.10481600E-01, 0.17758000E+01, 0.12725900E+01, -.33759400E+00, -.28031700E+00, 0.84447100E+00, -.16132600E+00, -.71541900E-01, 0.33678300E+00, 0.47905300E+00, -.39014200E-01, -.57615900E+00, 0.56765900E+00, -.57170100E+00, -.85935700E-01, 0.98442500E+00, 0.68111900E+00, 0.12163900E+01, -.32389900E+00, 0.22244000E+00, -.43584100E+00, 0.91218500E+00, -.83974500E+00, -.15071400E-01, -.12728200E+00, -.96067400E+00, 0.22639400E+01, -.17595100E-01, 0.16065800E+01, 0.50128300E-03, 0.51415500E-01, -.28428300E+00, -.25079500E+00, -.17704600E+00, 0.32907400E+00, -.13126400E+01, -.37708700E+00, -.30813600E+00, -.31132300E+00, 0.94755900E-01, -.17801400E+00, -.26259500E+00, -.74456700E-01, 0.53047500E+00, 0.10431300E+00, 0.79888500E+00, 0.26150700E-01, -.69205500E-01, -.41356900E+00, 0.53401500E-01, -.36811100E+00, -.21737400E-01, -.10969400E+01, 0.82796200E-02, -.15226700E+00, 0.30845300E-01, 0.61985200E-01, -.89295100E+00, -.49211400E+00, -.19273000E+00, -.12417500E+00, 0.14922400E+01, -.95419800E-02, 0.55102200E-01, 0.37191000E+00, 0.27764000E-01, 0.70864900E+00, -.80028200E+02, 0.35067500E+02, 0.17421800E+03, -.97718800E+02, -.48778200E+02, 0.25015800E+03, -.11693200E+03, -.13347400E+03, -.23167400E+03, -.12769300E+03, 0.12710900E+03, 0.45410100E+03, 0.13136800E+03, -.18870500E+03, -.10195300E+04, 0.51005500E+03, 0.51174700E+03, 0.12465800E+02, 0.68621700E+02, 0.20335500E+03, -.96074300E+03, -.22986200E+03, -.66499000E+02, -.51145300E+01, 0.11580500E+02, -.63224200E+01, -.86617700E+02, -.97652500E+02, 0.95110200E+02, 0.10306700E+03, 0.30730900E+02, -.10382400E+03, -.13992300E+04, 0.68824800E+03, 0.67003300E+03, 0.10151200E+03, 0.64618100E+02, 0.35111200E+03, -.46536700E+02, 0.38180600E+03, 0.20773000E+03, -.48911100E+02, 0.43373700E+02, 0.24709900E+02, -.18878300E+03, -.24906600E+03, 0.24763200E+03, -.29606600E+02, -.11019700E+03, -.36586800E+03, 0.46583400E+03, -.23221100E+03, -.22210300E+03, -.41380200E+02, -.96665900E+02, -.65764400E+02, 0.17957000E+03, -.17493700E+03, -.12113600E+03, 0.11024500E+04, -.55109400E+03, -.55117300E+03, -.29514900E+02, -.55185000E+02, -.21416500E+03, 0.99299900E+03, 0.27589700E+03, 0.11950300E+02, 0.13320300E+03, -.62402000E+02, -.41561000E+02, 0.12064800E+03, 0.69577000E+02, -.83942000E+02, -.48409300E+03, -.66928300E+02, 0.89075300E+02, 0.71894600E+03, -.35467500E+03, -.32586300E+03, 0.13197400E+03, 0.16758300E+03, -.32927300E+03, -.15603400E+03, -.44001100E+03, 0.13056100E+03, 0.12222200E+03, -.62535400E+02, -.60311000E+02, 0.20650300E+03, 0.15746100E+03, -.25521700E+03, -.82661400E+02, -.14883000E+03, 0.26422200E+03, -.32875600E+03, 0.15376900E+03, 0.16893800E+03, -.66790200E+01, 0.27283400E+02, 0.10979000E+03, 0.11544900E+03, 0.26300600E+03, 0.24727700E+02, 0.29288100E+01, 0.23200500E+03, 0.11144700E+03, 0.16685000E+02, -.52846900E+01, -.23021600E+03, 0.39180400E+02, 0.18364500E+02, -.68726200E+02, -.62199900E+02, -.17808600E+02, -.11465400E+00, -.70023300E+02, -.41593200E+03, -.45249100E+02, -.24716700E+02, -.30089400E+03, -.16262100E+02, -.34680600E+03, -.28205400E+02, -.10227000E+03, -.22389900E+03, -.73088900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.75806000E+00, 0.26340700E+00, 0.31698900E+00, -.11102800E+01, 0.14493600E+02, -.13184900E+01, -.83192900E+01, -.46809900E+01, -.77104800E+00, 0.24496200E+01, 0.17534700E+01, -.21372200E+01, 0.29344100E+01, -.20023800E+01, -.55826900E+00, 0.22238500E+01, 0.66454200E+00, 0.44420300E+00, -.24053300E+01, 0.78290300E+00, -.44755000E+01, 0.32099500E+00, -.34404900E+00, 0.99769300E+00, -.27637800E+01, -.10602000E+01, 0.32342800E+01, 0.10362200E+00, -.26377300E+01, -.21156300E+01, 0.80440900E+00, 0.11394200E+01, -.14422100E+01, -.29198800E+00, -.63651300E+00, -.23166600E+00, -.47353400E+00, 0.40456000E+00, -.18430100E+01, -.42802500E+00, -.78294300E-01, 0.41965900E+00, -.28420000E+01, -.66338900E+00, 0.80519300E+00, 0.11851900E+01, -.37899400E+00, 0.16178300E+01, -.22447800E+01, 0.20748400E+01, 0.32862900E+00, 0.28772600E-02, 0.23669000E+01, 0.14335600E+00, -.47126400E+00, 0.11262200E+01, 0.39599300E+00, -.88488800E+00, -.13569300E+00, 0.15464000E+00, 0.96286300E+00, -.25155300E+01, 0.33629600E+01, 0.41724700E+01, 0.29553000E+00, 0.49135400E+00, -.13472400E+01, 0.62953200E+00, 0.13720400E+01, -.69932900E-01, -.20358900E+01, -.25416100E+00, -.11482900E+01, 0.34114300E-01, 0.24873600E+00, -.43593300E+00, -.44946400E+00, 0.14502600E+01, -.72170300E-02, 0.19133000E+01, 0.34782400E+00, 0.75424300E+00, 0.30295400E+00, -.22264300E+00, 0.11311700E+01, -.14632400E+01, -.51945100E+00, -.17620900E+00, -.14520000E+01, -.24127600E+00, 0.68099900E+00, 0.18455200E+00, 0.94318600E-01, -.63879200E+00, -.97708700E+00, 0.18755500E+03, 0.37367500E+03, 0.17598800E+03, -.18464700E+03, 0.65556500E+01, -.11672200E+02, -.11039700E+02, -.25352900E+01, 0.92337100E+02, -.15121800E+03, -.86827000E+03, -.31462600E+03, 0.12030100E+03, -.78853900E+03, 0.39224000E+03, 0.39340300E+03, 0.45329300E+03, 0.29889600E+03, -.11168400E+03, -.64219100E+03, -.35218200E+03, 0.60369000E+03, 0.67530200E+02, -.43102000E+02, -.29827900E+02, 0.10414700E+03, 0.16462600E+03, -.18026400E+03, -.33587600E+03, -.10004400E+03, 0.16966800E+03, 0.67998400E+03, -.33640200E+03, -.33219300E+03, -.25436500E+03, -.17777400E+03, -.48638900E+02, -.15244800E+03, 0.36050000E+03, -.23863800E+03, 0.44759500E+03, -.24197400E+03, -.22601500E+03, 0.85201700E+03, 0.10505900E+04, -.68597500E+03, -.75392500E+03, -.60233600E+03, 0.75116400E+03, -.37017000E+03, 0.18392600E+03, 0.17644800E+03, 0.80487200E+02, 0.73106900E+02, 0.15407600E+02, -.29669800E+03, 0.22166500E+03, 0.92860500E+02, 0.19926700E+04, -.99277000E+03, -.99674700E+03, -.48065200E+03, -.36680600E+03, -.26297400E+03, 0.68624100E+03, -.22155000E+01, -.71874200E+03, -.21877200E+03, 0.10492100E+03, 0.10779200E+03, -.41367200E+03, -.27598000E+03, 0.11176500E+02, 0.40551000E+03, 0.13998200E+03, 0.29374500E+02, -.23035500E+03, 0.11504400E+03, 0.95839200E+02, -.49812500E+02, -.30891300E+03, 0.19244300E+03, 0.62909400E+03, 0.29933500E+03, -.66339400E+02, -.36392900E+04, 0.18299100E+04, 0.18185600E+04, -.41552900E+03, -.66106500E+03, 0.14959600E+04, 0.51313000E+03, 0.16847200E+04, -.35096500E+03, -.43346000E+03, 0.22525800E+03, 0.21783900E+03, 0.11883800E+03, 0.27836800E+02, 0.12552800E+03, 0.13169900E+03, -.25239600E+03, 0.59866800E+02, -.74137000E+02, -.31184600E+03, -.21912500E+03, 0.13333300E+02, 0.55168100E+02, 0.31511500E+03, 0.32855500E+02, -.72476200E+02, -.55685200E+02, -.57359900E+02, -.80070900E+02, -.21589100E+02, 0.13740600E+02, 0.14963400E+04, 0.16430600E+03, -.62945100E+02, 0.57540600E+03, -.10972400E+03, 0.16851700E+04, -.92398600E+02, 0.21858600E+03, 0.44552600E+03, 0.60075700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18634600E+01, -.14090900E+00, -.25176900E+01, -.67734800E+00, 0.85513600E-01, 0.66045600E-01, -.19993700E+01, 0.12366000E+00, -.49915800E+00, 0.37930600E-02, 0.80177500E+00, -.68739700E+00, 0.36388100E+00, -.20285000E+01, 0.35415500E+00, -.57551500E+00, 0.67272600E+00, -.66344300E-01, 0.12786100E-02, -.67963600E+00, -.43528300E+00, 0.24535400E+00, 0.12218500E+00, -.20649600E+00, 0.11656000E+01, -.29331200E-01, -.14685000E+01, -.68460900E-02, 0.15692200E+01, -.13156900E+00, -.19420500E+00, -.85850200E+00, 0.12242800E+01, 0.12053900E+00, 0.15446900E+00, 0.35542000E-01, 0.80713400E-01, 0.40138800E-01, 0.21720500E+00, -.63799100E+00, 0.31055400E+00, -.85671200E-01, 0.11385700E-01, -.37467800E-01, 0.89944300E+00, 0.35880700E+00, 0.54248900E-01, -.40202000E+00, -.18142900E+01, 0.65681800E+00, 0.21395700E+00, -.10238900E+00, 0.41310900E+00, 0.75569800E+00, -.15894400E+00, 0.13391400E+01, 0.67376400E-01, -.13611400E+00, -.31044000E+00, 0.14086500E+00, 0.77029400E-01, 0.72485400E-01, -.30914500E+00, -.19993400E+00, 0.23331200E+00, 0.17820000E+00, 0.91218200E-01, -.50265400E-01, -.37555000E+00, -.21029500E+00, -.37219500E+00, 0.10599500E+00, 0.49560100E+00, 0.90247200E-01, -.26333300E+00, -.33611400E+00, -.86383800E-01, 0.71829300E+00, -.90882500E-01, 0.55988100E+00, -.16046000E+00, 0.71959800E-01, -.95291500E-02, -.41005100E-02, 0.20638400E+00, 0.24026000E+00, -.43748900E-01, -.15630200E+00, -.51597900E-01, -.12037300E+00, -.73261500E-01, 0.13046900E+00, -.27388100E+00, 0.13475000E+01, -.11737800E-01, -.23297600E+00, 0.15805500E+03, -.82657100E+02, -.88728900E+02, 0.29775000E+03, -.13264700E+03, -.13444600E+03, -.32696000E+02, -.34872800E+02, -.11684700E+03, -.46941600E+03, -.72900200E+02, 0.15267900E+02, -.25594800E+04, 0.12785300E+04, 0.12708600E+04, -.14893200E+02, 0.26130000E+03, 0.60303400E+03, -.65784400E+03, 0.54965400E+02, 0.51608900E+03, 0.26425900E+03, -.11895900E+03, -.10596400E+03, 0.28929300E+02, 0.34427900E+02, -.12354100E+03, -.14013700E+03, -.15394700E+03, 0.23186700E+02, -.63136800E+02, 0.56405600E+01, 0.30031500E+02, -.11565900E+03, -.71969200E+02, 0.62248400E+02, 0.80136300E+01, 0.29974800E+03, 0.11390800E+02, 0.11175700E+04, -.53028200E+03, -.57585800E+03, 0.29185900E+03, 0.58425600E+03, -.59603800E+03, -.59778800E+03, -.88670700E+03, 0.28357500E+03, 0.13207200E+03, -.67476400E+02, -.93648300E+02, 0.65384900E+02, 0.47307800E+02, -.14197700E+03, -.10197500E+03, -.89699600E+02, 0.66154500E+02, 0.29210900E+04, -.14578200E+04, -.14631700E+04, 0.17468600E+02, -.26953600E+03, -.70751200E+03, 0.67665800E+03, -.14196700E+03, -.59921300E+03, -.25029500E+03, 0.13156100E+03, 0.29944500E+02, 0.45573400E+02, 0.52437100E+02, -.27977800E+02, -.11561900E+03, 0.17424000E+03, 0.19418500E+03, 0.59917200E+03, -.29587500E+03, -.47946700E+03, 0.17097200E+03, 0.13571300E+03, -.27151700E+03, 0.28714400E+03, -.14533700E+03, 0.70764400E+02, -.24923500E+04, 0.12446800E+04, 0.12418200E+04, -.24932300E+03, -.45617800E+03, 0.97783700E+03, 0.61900800E+03, 0.11591400E+04, -.14647100E+03, -.21551200E+02, -.50607000E+01, -.24635000E+00, -.89531000E+02, -.19334400E+03, 0.14037000E+03, 0.20493900E+03, -.85011800E+01, -.13609900E+03, 0.61175200E+02, 0.82268900E+02, -.72314500E+01, 0.16982900E+02, -.18402900E+02, -.78535300E+02, 0.53357900E+02, 0.10436000E+02, 0.31492500E+02, 0.31991100E+02, -.26995000E+01, 0.28165600E+01, -.20415900E+01, 0.26754900E+03, 0.50842100E+02, -.39333100E+02, 0.24496700E+03, -.15518600E+03, 0.52062400E+03, -.28648000E+02, -.21168800E+02, 0.16581600E+03, -.83213100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13138800E+01, 0.31061900E+00, -.40988300E+00, -.46343800E+00, 0.48453500E+01, -.36139900E-01, -.67445900E+01, -.40625800E+01, 0.50692500E+00, -.19954200E+00, 0.16580000E+01, -.12661800E+01, 0.13769300E+01, -.17680400E+01, -.40023900E+00, 0.13375100E+00, 0.10982200E+01, -.38239300E+00, -.71036600E+00, 0.15182600E+01, 0.53566300E+00, 0.77717500E-01, -.10897300E+01, 0.69192900E+00, 0.98010100E-02, 0.25663100E-01, -.23945400E+01, 0.41046900E+00, -.22573700E+00, 0.65648600E+00, 0.46465600E+00, -.68757000E-01, -.25365500E-01, -.26308300E+00, 0.40978200E+00, -.64865700E+00, 0.15209100E+00, -.39445600E+00, 0.69011900E+00, 0.93557400E+00, -.13979900E+01, -.10605800E+00, 0.16808200E+01, 0.10782300E+01, -.11044200E+01, 0.57071800E-01, -.12864200E+00, 0.13314700E+01, 0.37181900E+00, 0.63809600E+00, -.76125800E-01, 0.46597200E-01, -.18646200E+00, -.20375800E+00, -.46071600E+00, -.38998600E+00, -.39103000E+00, -.53586100E-01, -.21534700E-01, -.25814800E+00, 0.82342800E-01, 0.12051000E+01, 0.19490800E+00, -.19876100E+01, 0.51133300E+00, 0.25423700E+00, 0.51471300E+00, -.58012800E+00, -.12115300E+01, -.31316600E+00, 0.12741000E+01, 0.30446400E+00, 0.66120800E+00, 0.16173800E+00, 0.73351100E-01, 0.42306800E+00, 0.29768400E+00, 0.57717800E+00, -.21217800E+00, 0.16473600E+01, -.12147900E+00, -.29050500E+00, 0.10986700E-01, -.12875800E+00, 0.62308200E+00, -.49705900E+00, -.28880800E+00, -.40830800E+00, -.28282600E+00, -.22683800E+01, 0.18509600E+00, -.49377600E+00, 0.24573700E+00, 0.14887800E+00, 0.27974100E-01, 0.64161900E-01, 0.30730800E-01, 0.30298800E+03, 0.85903500E+02, -.21169600E+03, 0.90349000E+02, 0.99183000E+02, 0.63650500E+02, 0.78666200E+02, 0.45484000E+02, -.23173100E+03, 0.53792000E+02, 0.49478800E+02, 0.21587100E+04, -.10793000E+04, -.10781800E+04, 0.24041400E+03, -.12576600E+03, -.70227300E+03, 0.10992200E+03, -.47941900E+03, -.29933300E+03, -.10798100E+03, 0.33102000E+02, 0.47944700E+02, 0.87554200E+01, 0.15830100E+02, 0.30829100E+02, -.17437800E+02, 0.69098900E+02, 0.34853300E+02, 0.43138100E+03, -.21504100E+03, -.22925500E+03, 0.65077100E+02, 0.65595300E+02, -.17865400E+03, -.13421800E+03, -.13939100E+03, -.49712400E+02, -.72145900E+03, 0.31858400E+03, 0.36017500E+03, -.60921500E+02, -.13780100E+03, 0.38466500E+03, 0.53764600E+03, 0.56328300E+03, 0.28259400E+02, -.21894800E+03, 0.10779200E+03, 0.11445900E+03, 0.60234700E+01, 0.17575900E+02, 0.72741100E+02, -.16873300E+03, 0.15095200E+03, 0.29367900E+02, -.18923300E+04, 0.94562600E+03, 0.94686200E+03, -.24262700E+03, 0.99563300E+02, 0.63166400E+03, -.51798100E+02, 0.40961000E+03, 0.30808400E+03, 0.31047000E+03, -.15725500E+03, -.13275600E+03, -.96791200E+02, -.68901600E+02, -.73885000E+01, 0.42959300E+03, -.30256000E+03, -.22831300E+03, -.65175800E+03, 0.33157900E+03, 0.35132500E+03, -.85856900E+02, -.11156900E+03, 0.28633600E+03, 0.16601000E+03, 0.22890400E+03, 0.34861300E+02, 0.79519800E+03, -.36870600E+03, -.39726900E+03, 0.10486100E+03, 0.10728500E+03, -.41144300E+03, -.56611300E+03, -.40312100E+03, -.58852700E+02, -.11663300E+03, 0.75933500E+02, 0.63004400E+02, 0.37748500E+02, 0.88791600E+02, -.32142100E+02, 0.19059000E+02, -.20565100E+02, 0.60059300E+02, -.90447000E+02, -.15961300E+03, -.31745400E+02, -.15073200E+02, 0.32677300E+02, 0.15825500E+03, -.33000800E+02, -.32551000E+02, -.19069100E+02, -.31947400E+02, -.38552800E+02, 0.14907100E+02, 0.31313000E+02, 0.33673300E+03, 0.22200300E+02, -.43492900E+02, 0.24860800E+02, 0.52906900E+02, 0.21605300E+03, 0.34479600E+02, 0.72822100E+02, -.43577300E+02, 0.88394100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.49922200E+01, -.33939400E+00, -.42310900E+01, -.24810600E+01, 0.11268800E+02, 0.82691300E+00, -.10265200E+02, -.59088700E+01, -.15340800E+01, 0.19564800E+01, 0.29115900E+01, -.51047500E+01, 0.11162900E+01, -.61312000E+01, -.13719400E+01, 0.61001300E+00, 0.17279900E+01, -.19502300E+01, -.30338000E+01, 0.27351000E+01, 0.37412500E+01, 0.78838800E+00, -.27547900E+01, 0.88806300E-01, 0.40116400E+00, -.89288800E-01, -.14230900E+01, 0.24413600E+00, -.29456900E+01, 0.18450600E+01, 0.15708400E+00, 0.12715200E+01, 0.65851700E+00, 0.75540200E+00, -.82654800E+00, 0.42955000E+00, -.17102600E+00, 0.62931000E-01, 0.11253400E+01, 0.30887900E+00, -.15343800E+01, -.29503400E+00, 0.27577200E+01, 0.12907800E+01, -.23855200E+01, 0.85774100E-01, -.27233600E+00, 0.16793300E+01, 0.16042200E+00, -.12747100E+00, -.56321200E-01, 0.43573900E-01, -.14688200E+01, 0.89172600E+00, 0.74057000E-01, 0.89116000E+00, -.25603200E+00, 0.21335500E+00, 0.92225200E-03, -.24352000E+00, -.70855500E+00, -.16251100E+01, 0.15323600E+01, 0.78863700E+00, 0.45961600E+00, 0.38824600E-01, -.11390600E+01, 0.12859000E+00, -.69314000E+00, -.12645500E+01, -.29700200E+01, 0.59343000E+00, -.19709300E+01, 0.69029800E+00, -.66026700E+00, 0.23046000E+00, 0.10270000E+01, 0.25472100E+01, -.26134300E+00, 0.29017200E+01, -.27978300E+00, -.15306100E+01, -.21380900E+00, -.25148000E+00, -.12863400E+01, 0.58228000E+01, 0.17166700E+00, -.12556100E+01, 0.22383400E+01, -.17726300E+00, -.10665600E+01, 0.25359200E+00, -.63553600E+00, -.18974300E+01, 0.66454400E+00, -.51701100E+00, 0.15541000E+00, -.18420500E+01, 0.34326300E+03, -.46129500E+03, 0.19576100E+03, 0.21722200E+03, 0.10482800E+03, 0.61180600E+02, 0.46453200E+02, 0.10716400E+03, -.10937100E+02, 0.13979200E+03, 0.21449700E+04, -.10751300E+04, -.10735500E+04, 0.21860600E+03, -.14308500E+03, -.42674400E+03, 0.10889400E+04, 0.45246300E+03, -.27802800E+02, -.21398600E+02, -.29140800E+02, 0.13427900E+02, 0.50574400E+02, 0.65342400E+02, -.53327200E+02, -.21000200E+02, -.24219600E+02, 0.10686500E+03, 0.12925800E+04, -.60944200E+03, -.59884400E+03, 0.16601700E+03, 0.26976100E+02, -.37818900E+03, 0.21477200E+03, -.71498600E+03, -.12187300E+03, -.55110700E+03, 0.19271200E+03, 0.27748000E+03, -.22309300E+03, -.95145800E+02, 0.25768900E+03, 0.64960000E+03, 0.72773000E+03, 0.42098200E+03, -.51364400E+03, 0.25573600E+03, 0.24748800E+03, 0.74108000E+02, 0.45051900E+01, 0.23493300E+03, 0.95008000E+02, 0.26850100E+03, 0.12069100E+03, -.20532100E+04, 0.10277800E+04, 0.10281700E+04, -.71329100E+02, 0.22407500E+03, 0.27266300E+03, -.13788700E+04, -.85126000E+03, 0.19369200E+03, 0.85054300E+03, -.43812000E+03, -.42348300E+03, -.10288600E+03, -.13389600E+03, -.22228200E+03, 0.70112500E+02, -.26876200E+03, -.74234900E+03, -.15233700E+04, 0.75227000E+03, 0.75509200E+03, 0.16273600E+03, -.26646100E+03, 0.60824400E+03, -.60863400E+02, 0.71583200E+03, -.16450800E+01, 0.10333500E+04, -.49381600E+03, -.51685600E+03, 0.48063700E+03, 0.11416700E+03, -.17808200E+03, 0.15129400E+03, -.48121800E+03, -.35473600E+03, 0.80933100E+03, -.36195800E+03, -.40949700E+03, -.31888900E+02, -.34809000E+02, -.23924200E+03, 0.42022600E+02, -.15492100E+03, -.12968600E+03, -.44037300E+02, -.20543000E+03, 0.95584600E+02, -.70992300E+01, -.15440800E+02, 0.20162000E+03, -.37554600E+02, 0.21693400E+02, 0.24909100E+03, 0.17762300E+03, 0.15137500E+02, 0.17199100E+02, 0.15251100E+02, 0.42958600E+03, 0.50581700E+00, 0.97691200E+01, 0.43679600E+03, 0.21624800E+03, 0.16057400E+03, 0.82887700E+02, 0.65651900E+01, 0.24660400E+03, 0.12529900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.74845900E+00, -.26800600E+00, 0.35019600E+00, 0.34103900E+00, -.25362000E+01, -.26203600E-01, 0.28179400E+01, 0.15886100E+01, -.48276400E+00, -.44743300E+00, -.43096700E+00, 0.11338900E+01, -.32457100E+00, 0.11812100E+01, 0.45665500E+00, -.49006000E-01, -.53223500E+00, 0.36155900E+00, 0.75669300E+00, -.42366500E+00, 0.61457900E+00, -.27095800E+00, 0.86706400E+00, -.33130800E+00, 0.24802000E+00, 0.31422000E-01, 0.41692800E+00, -.85280400E-01, 0.10389600E+01, -.31749100E+00, -.13813600E+00, -.36953600E+00, 0.20574100E+00, -.43733700E-01, -.31221200E+00, 0.65812400E+00, 0.25970700E-01, 0.84994100E-01, -.41199100E+00, -.99944900E-01, 0.16073300E+00, 0.82016300E-01, -.80818400E+00, -.16035000E+00, 0.73821800E+00, 0.13028500E+00, 0.21646100E-01, -.16094800E+00, 0.13031900E+00, -.46388600E+00, -.29130300E-02, -.18775500E-01, -.11351500E+00, 0.18897000E+00, 0.32691800E-01, 0.26359900E+00, 0.15638600E+00, 0.96379900E-01, -.99301900E-01, 0.15056500E+00, 0.26831300E+00, -.38881900E+00, -.16920600E+00, 0.10508100E+01, -.68448100E+00, -.29509400E+00, -.16356200E+00, 0.31893000E+00, 0.99245700E+00, 0.16162800E+00, 0.15137900E+00, 0.26472500E+00, -.20575500E+00, -.17597400E+00, 0.52293900E+00, 0.52364400E+00, 0.10379700E-01, -.31079500E+00, -.15873000E+00, -.25274700E-01, -.29579400E+00, -.12262600E+00, 0.71609200E-01, -.13119400E+00, 0.22442600E+00, 0.44659000E+00, -.22518400E+00, -.18509900E+00, -.37299400E+00, -.16458200E+01, -.78674500E-01, 0.37207800E+00, -.10806900E+00, 0.12716200E+01, -.10861800E+00, 0.11467400E+00, 0.45676100E+00, 0.23771400E+00, 0.12565900E+00, 0.24928100E+03, -.11210700E+03, -.13787000E+03, -.57548500E+02, -.45604800E+02, -.45287100E+02, -.19490900E+03, 0.11246900E+03, -.61734300E+02, -.93954000E+03, 0.47007800E+03, 0.47469000E+03, -.11443300E+03, 0.10957800E+03, 0.21831800E+03, -.35279800E+03, -.22685700E+03, 0.13202800E+03, 0.10082900E+03, -.36269200E+02, -.65858000E+02, 0.93129700E+00, -.93900600E+01, -.26973200E+02, -.15915200E+02, -.66175600E+02, -.21361500E+02, -.49934700E+03, 0.24184700E+03, 0.20236500E+03, 0.22142800E+02, 0.36218500E+02, 0.15011300E+03, 0.11555800E+03, 0.15756600E+03, 0.10014000E+03, 0.86464500E+03, -.40367500E+03, -.42572700E+03, -.19135600E+02, 0.25603500E+02, -.27043000E+03, -.15059400E+03, -.58149800E+03, -.14061800E+03, 0.17211200E+03, -.84908200E+02, -.65415900E+02, -.71433100E+01, -.11072400E+02, -.57127000E+02, 0.35833600E+02, -.62916300E+02, -.13758800E+01, 0.74843100E+03, -.37412400E+03, -.37340700E+03, 0.14112800E+03, -.93692200E+02, -.14057300E+03, 0.40538500E+03, 0.35710400E+03, -.16324100E+03, -.14801000E+03, 0.77765500E+02, 0.12242100E+03, 0.71332000E+02, 0.75606700E+02, 0.71145800E+02, 0.32507500E+02, 0.23033600E+02, 0.40123800E+02, 0.53278700E+03, -.26914100E+03, -.18068800E+03, -.11072100E+02, 0.84265700E+02, -.16599300E+03, 0.69408100E+02, -.18615500E+03, 0.41187200E+01, -.32188400E+03, 0.14652800E+03, 0.16311600E+03, -.67579100E+02, 0.35237500E+02, 0.74748900E+02, 0.15228900E+03, 0.15739200E+03, 0.17317400E+03, -.21277100E+01, -.14438400E+02, 0.17042300E+01, -.63690600E+02, -.97571300E+02, 0.70250400E+02, 0.96211000E+02, 0.48735500E+02, -.65551700E+02, 0.33363500E+02, 0.89169800E+02, -.35804700E+00, -.57800600E+01, -.52915100E+01, -.87524800E+02, 0.49412600E+01, 0.58637700E+01, 0.82598700E+02, 0.89864300E+02, 0.28166400E+02, -.15077100E+02, 0.22207100E+02, -.18302200E+03, 0.51473300E+01, 0.59963300E+02, -.30466100E+02, -.58193900E+02, 0.70687900E+01, 0.38622400E+01, -.28247400E+02, -.50011200E+02, -.55327400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.87546700E+00, 0.46769200E+00, -.58194000E+00, -.44779900E+00, 0.44254000E+01, 0.46260300E-01, -.44914300E+01, -.26520000E+01, -.19275600E+00, 0.57980100E+00, 0.75002200E+00, -.88959400E+00, 0.89326400E+00, -.13903400E+01, -.49268900E+00, 0.57080500E+00, 0.44984300E+00, -.26704000E+00, -.12086100E+01, -.31602600E+00, -.34973000E+01, 0.40540200E+00, -.69280100E+00, 0.24112200E+00, 0.42138000E+00, -.32903000E+00, 0.40876400E+00, 0.26043300E+00, 0.21356400E+00, -.20385900E+00, 0.35412500E+00, 0.42576400E+00, -.13829200E+00, -.44986400E+00, -.37682600E+00, 0.18407500E+00, 0.88757300E-02, 0.43538100E+00, -.71806500E+00, 0.58959800E+00, 0.36696100E+00, 0.25716600E+00, -.11406300E+01, -.12135400E+00, 0.84482000E+00, 0.78075700E+00, 0.22313900E-01, -.29725600E-01, -.97376900E+00, -.71303500E+00, 0.89770200E-01, 0.27460500E-01, -.95931200E+00, -.13721000E+01, -.48471200E+00, -.12861200E+00, 0.72705800E-01, 0.15795800E+00, -.20373600E+00, 0.19066800E+00, 0.49611300E+00, 0.10440600E+00, 0.14914200E+00, -.10006300E+01, 0.71918800E+00, -.24532600E-01, 0.10223900E+00, 0.14574100E+00, 0.66469300E+00, -.93181900E-01, 0.28263600E+00, 0.40451300E-01, 0.26576100E+00, 0.95243900E-01, 0.67610000E-02, 0.82807600E-01, -.20091600E+00, -.55448700E+00, -.66084700E-01, -.77432700E+00, -.22585000E+00, 0.43362400E+00, 0.24807700E-02, 0.43728900E-01, 0.44207600E+00, -.10561400E-01, 0.14401100E+00, 0.33630500E+00, -.82978100E+00, 0.13340100E+00, 0.19578200E+00, -.55770300E-01, -.17079600E-01, 0.62944600E+00, -.82827700E+00, 0.88516900E-01, 0.18591000E+00, -.41875900E-02, -.60718700E-01, -.39337000E-01, 0.16140200E+02, -.12696900E+02, -.22174600E+02, 0.65060200E+02, 0.78807600E+01, -.39472900E+02, 0.43791600E+02, 0.30014200E+01, -.63422400E+03, 0.31957400E+03, 0.32039400E+03, 0.57063600E+02, 0.66451800E+02, 0.15232700E+03, -.13597100E+03, -.84600600E+02, 0.34701400E+02, -.14975000E+02, 0.25146400E+02, -.73206600E+01, -.21056900E+02, -.24511400E+02, 0.33611300E+02, 0.45982900E+02, 0.84410100E+01, -.32686000E+02, -.39573700E+03, 0.18235900E+03, 0.16386100E+03, 0.64156900E+01, -.10614300E+02, 0.12170300E+03, 0.59578300E+02, 0.14271800E+03, 0.17485000E+02, -.17444400E+03, 0.12202700E+03, 0.91307800E+02, -.23208200E+02, -.12193000E+03, 0.16849500E+03, 0.16490800E+03, 0.16419600E+02, -.14220800E+03, 0.16846400E+03, -.82528900E+02, -.64582000E+02, -.30040700E+02, 0.81535400E+01, -.38789100E+02, 0.34117700E+02, -.82387700E+02, -.36629200E+02, 0.42645000E+03, -.21537500E+03, -.21223700E+03, -.65467900E+02, -.58246900E+02, -.73573400E+02, 0.17231400E+03, 0.17670200E+03, -.40879000E+02, -.35083300E+03, 0.18095000E+03, 0.21969800E+03, 0.11110700E+03, 0.98964400E+02, 0.13180100E+03, 0.43749100E+02, 0.77272300E+02, 0.90845700E+02, 0.37448800E+03, -.18857600E+03, -.11257600E+03, -.73998000E+02, 0.11742400E+03, -.79861300E+02, 0.93203900E+02, -.12905900E+03, 0.11152100E+02, 0.48968100E+03, -.25447100E+03, -.24301100E+03, -.33254400E+02, 0.12198400E+03, -.24380100E+03, -.10951700E+03, -.20708300E+03, 0.11065400E+03, -.97410100E+02, 0.27787800E+02, 0.51061000E+02, -.20042700E+02, -.44304300E+02, 0.56622200E+02, 0.76286700E+02, 0.65732200E+02, -.52319800E+01, -.13459100E+02, 0.59256700E+02, -.73903100E+01, -.39634500E+02, 0.20221200E+02, -.58621600E+02, -.52196800E+01, -.19081200E+02, -.40907700E+02, -.22159600E+02, -.48637200E+01, -.47107900E+02, 0.57238100E+01, -.22288900E+03, 0.55828500E+01, 0.48381500E+02, -.10845700E+03, -.53197500E+02, -.18397400E+03, -.15312600E+02, -.26466300E+02, -.48517300E+02, -.24443800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12088500E+01, 0.19552500E+00, -.11681700E+01, -.62362500E+00, 0.30244400E+01, -.11024300E+00, -.26168400E+01, -.12159800E+01, -.79493000E-02, -.31291100E-01, 0.15875400E+01, -.52364300E+00, 0.60408200E+00, 0.14525100E+00, -.55303700E+00, 0.43447700E+00, 0.11239800E+00, 0.14086800E-01, 0.27287900E+00, 0.47152500E+00, -.60132500E+00, -.18976500E+00, 0.23784400E+00, 0.19394900E+00, 0.51390000E+00, -.50160300E-01, -.57742600E-01, 0.11602300E+00, 0.14962000E+01, -.93450100E-01, 0.88109500E-02, -.46059900E+00, 0.28699800E+00, -.26586100E-01, -.79305600E-01, 0.57397100E+00, 0.35441500E-01, 0.92943600E-01, -.12772800E+00, 0.65653100E-01, 0.31674400E-01, -.51375600E-02, -.24751100E+00, 0.52092800E-01, 0.98735900E-01, 0.46706200E-01, -.16901300E+00, 0.29806300E+00, 0.21999800E-01, -.38871300E+00, -.60835500E-02, 0.99082400E-02, -.12341000E+00, -.50255000E+00, -.33206500E+00, -.32775600E+00, 0.19447900E-01, 0.48844700E-01, 0.14549600E-01, 0.13356100E-01, 0.23969400E+00, -.27721100E+00, 0.15180800E+00, 0.48497700E+00, 0.21696700E-01, -.87988200E-01, -.54162200E-02, 0.21579300E+00, 0.55628600E+00, 0.18764400E+00, -.10393200E+00, 0.63013000E-01, -.28106000E+00, -.12624500E+00, 0.15699700E+00, 0.16661600E+00, 0.86040500E-01, 0.50639800E+00, -.54516700E-01, -.39305600E+00, -.27929100E-01, 0.12650200E+00, 0.77422600E-02, 0.23075200E-01, -.19110500E+00, -.24663200E+00, 0.46065400E-01, 0.27167800E+00, -.42003200E+00, 0.34609500E+00, -.26632400E+00, 0.28952200E+00, -.37073100E-01, 0.35617000E+00, -.16581700E+00, -.14809800E+00, 0.28455500E+00, -.13725500E+00, 0.13798500E-01, -.67567700E-01, -.23357500E+00, -.15194700E+02, -.25588700E+02, 0.20071500E+01, 0.31012200E+02, -.11006200E+03, 0.93636500E+02, -.40531900E+02, 0.15034600E+03, -.74732800E+02, -.70784100E+02, 0.15159600E+02, -.29417100E+02, -.68045900E+02, -.20884900E+03, -.25435200E+03, -.21808700E+03, -.49713100E+02, 0.26661200E+02, 0.93092700E+01, -.12204900E+02, -.28431100E+02, 0.36863000E+02, 0.23284100E+02, 0.32980300E+02, -.32231900E+02, -.18003300E+03, 0.96062400E+02, 0.58255900E+02, 0.46847700E+02, 0.52537700E+02, 0.14054900E+02, 0.15562200E+02, 0.28164800E+02, 0.41517900E+02, -.51207800E+03, 0.25878500E+03, 0.26122100E+03, -.62134300E+02, -.18512800E+03, 0.29686400E+03, 0.16341800E+03, 0.19158200E+03, -.17904800E+03, 0.58571000E+02, -.28297500E+02, -.11746300E+02, 0.88089000E+01, 0.14705000E+02, -.27105200E+02, -.32157600E+02, -.46410000E+02, -.12860400E+02, -.24060200E+03, 0.11969000E+03, 0.12141300E+03, -.47153700E+02, 0.26725000E+01, 0.12306300E+03, 0.26641000E+03, 0.35835400E+03, 0.19116300E+03, 0.13767400E+03, -.69033000E+02, -.14906200E+02, -.21386400E+02, -.53179200E+02, 0.31987300E+02, 0.11050000E+03, 0.23675400E+02, -.21004600E+01, 0.14353700E+03, -.73319400E+02, 0.13813700E+02, -.47432600E+02, 0.38957400E+02, -.27587200E+02, 0.22833000E+02, -.11531600E+03, 0.60731300E+02, 0.49092200E+03, -.24726300E+03, -.24364400E+03, 0.39078200E+02, 0.12588600E+03, -.28320900E+03, -.14293400E+03, -.23905300E+03, 0.94786700E+02, -.11520100E+03, 0.56049800E+02, 0.62911500E+02, -.30672500E+02, -.38819700E+02, 0.74520200E+02, 0.12411100E+03, 0.85571200E+02, -.38213100E+02, -.30908300E+02, -.33057100E+01, -.39710900E+01, -.29167400E+01, 0.22248100E+02, 0.35928300E+01, 0.46572200E+01, -.20551400E+02, -.41291100E+02, -.44335300E+02, -.98054900E+01, -.95335700E+01, 0.67249100E+01, -.19108400E+03, 0.60854900E+01, -.17375500E+01, -.13145800E+03, -.34465200E+02, -.21729100E+03, -.13382200E+02, 0.16572700E+01, -.47574000E+02, -.18502700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.64126500E+00, -.42096000E+00, -.22673800E+01, 0.19979700E+00, -.57078500E+01, -.43750500E-01, 0.64102600E+01, 0.34372500E+01, 0.68869400E+00, 0.12554000E+00, -.34918200E+01, 0.18769100E+01, -.19385400E+01, 0.21694900E+01, 0.56222200E+00, -.25521400E+00, -.28173300E+00, 0.64174400E+00, 0.22022300E+01, -.11468700E+01, 0.37492700E+01, -.17272200E+00, 0.89099300E+00, -.70969300E+00, -.51635100E+00, 0.69535900E+00, 0.23910700E+00, -.32503600E+00, 0.67944000E+00, -.65088300E+00, -.25155400E+00, 0.30018000E-01, 0.20329400E+00, 0.59263700E+00, -.15067400E-01, 0.12863200E-01, -.98224000E-01, -.14594400E+00, 0.24185800E+00, 0.14883100E+00, 0.27312600E-01, -.18507700E-01, 0.28548000E+00, 0.18230900E+00, -.10226300E+01, -.55135200E+00, 0.16945800E-01, 0.14773500E+00, 0.25131900E+01, -.80201500E+00, -.25191200E+00, -.35263900E-01, 0.15363500E+00, 0.34189900E+00, 0.60787900E+00, -.81433700E+00, -.11592600E+00, 0.81226400E-01, 0.22895600E+00, 0.21966600E+00, -.18992600E+00, -.51979600E+00, -.11662600E+00, 0.10962500E+01, -.15330800E+01, -.67549200E+00, -.37446600E+00, 0.23512000E+00, 0.47536400E+00, 0.27410000E+00, -.63075700E+00, -.69203700E+00, -.59069500E-01, -.11027500E+00, -.30824700E+00, 0.34254700E+00, -.30367900E+00, -.17415500E+00, 0.25083300E+00, 0.11317000E+00, 0.63877300E+00, -.45333900E+00, 0.43362900E-01, -.22226000E-01, -.17051700E-01, -.67119600E-01, 0.46398500E-01, -.39570800E-01, 0.18349200E+00, 0.13562100E+01, -.90987200E-01, 0.28965800E+00, -.25417600E+00, 0.18324200E+01, 0.64410500E+00, -.39374100E-01, 0.72044200E-02, 0.36556500E-01, -.25972000E+00, -.95883100E+00, 0.56047700E+00, 0.22010100E+01, 0.23667400E+03, 0.93918900E+01, -.13067500E+03, 0.34631300E+02, -.85026500E+02, 0.18981100E+03, -.52590100E+03, 0.26086100E+03, 0.25757000E+03, -.32928500E+03, 0.67529600E+02, 0.20587800E+03, 0.36608900E+03, 0.34843600E+03, 0.58760500E+03, 0.18250900E+03, -.96258500E+02, -.70481400E+02, 0.10369800E+03, 0.10798600E+03, -.14629700E+03, -.11553300E+03, -.15515600E+03, 0.13022200E+03, -.34155000E+02, 0.93075300E+01, 0.49881300E+02, 0.88415800E+02, 0.53229600E+02, 0.44139800E+01, -.55498800E+02, -.85941400E+02, 0.94699100E+02, 0.17871100E+04, -.90194800E+03, -.90392500E+03, 0.11486800E+03, 0.62190800E+03, -.94936200E+03, -.47508200E+03, -.90545000E+03, 0.57410400E+03, -.25708700E+03, 0.12607500E+03, 0.96904300E+02, 0.47798800E+02, -.11818400E+02, 0.72124500E+02, 0.67611000E+02, 0.13469800E+03, 0.10572400E+03, 0.68727400E+03, -.34072400E+03, -.34511800E+03, 0.43275900E+03, -.52544400E+02, -.29480700E+03, -.45411900E+03, -.52710700E+03, -.57687600E+03, 0.33979400E+03, -.17050000E+03, -.22792000E+03, 0.33512400E+02, 0.67963000E+02, -.27587300E+03, -.27925700E+03, -.27858600E+03, -.14082500E+03, -.23220500E+03, 0.11195200E+03, -.13168300E+02, 0.19356700E+03, -.10708400E+03, 0.64951700E+02, 0.90625200E+02, 0.27394100E+03, -.14790600E+03, -.17939300E+04, 0.89240500E+03, 0.89410200E+03, -.12884000E+03, -.38947600E+03, 0.90085100E+03, 0.50452200E+03, 0.84213700E+03, -.25941500E+03, 0.68439100E+03, -.33723900E+03, -.34605200E+03, -.10250400E+03, -.97951500E+02, -.20148900E+03, -.25013200E+03, -.19466500E+03, -.96993700E+02, 0.51490000E+02, -.37162000E+02, -.37337200E+02, 0.24377000E+02, -.11283000E+02, 0.37778500E+02, -.24437300E+02, 0.74767500E+01, 0.23508400E+03, 0.20967400E+03, 0.83039600E+02, 0.28977000E+02, 0.23185300E+02, 0.54190900E+03, 0.25887800E+02, -.11548700E+02, 0.52793100E+03, 0.74322200E+02, 0.81571600E+03, 0.10610500E+02, 0.45199300E+02, 0.21523100E+03, -.41475800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10351900E+01, 0.27663100E+00, -.60148800E+00, -.51305800E+00, 0.44675800E+01, 0.22167000E-01, -.48542400E+01, -.26972800E+01, 0.20082900E+00, 0.49956900E+00, 0.11208800E+01, -.97201900E+00, 0.10189900E+01, -.11534400E+01, -.54864600E+00, 0.54562500E+00, 0.41252200E+00, -.20114000E+00, -.11965600E+01, 0.40210000E+00, -.33097100E+01, 0.22993400E+00, -.56519600E+00, 0.48812600E+00, 0.24794000E+00, -.38779000E+00, -.17885200E+00, 0.38520800E+00, -.35097000E+00, -.74758400E-01, 0.53671500E+00, 0.68107400E+00, -.33949700E+00, -.49627200E+00, -.29306400E-01, -.67631100E+00, -.11018300E-01, 0.35200400E+00, -.40411300E+00, 0.63271700E+00, 0.17938200E+00, 0.18840500E+00, -.17593200E+00, 0.37653600E-01, 0.11012100E+00, 0.73595900E+00, -.82846300E-01, 0.24479200E+00, -.88082900E+00, -.95661500E+00, 0.93195100E-01, 0.32758100E-01, -.80254000E+00, -.18741100E+01, -.61996500E+00, -.58267400E+00, -.10972600E+00, 0.14682800E+00, -.13169100E+00, 0.91645500E-01, 0.35881300E+00, 0.59174100E+00, 0.23925400E+00, -.21613200E+01, 0.13091200E+01, 0.11257900E+00, 0.32274700E+00, -.85816900E-01, -.43625600E-02, -.43647600E-01, 0.12866800E+00, -.14816100E+00, 0.25925300E+00, 0.15229500E+00, -.38329400E+00, -.26636700E+00, -.58230600E-01, -.42348500E-01, 0.92061800E-01, -.44504400E+00, -.17097400E+00, 0.27775400E+00, -.90175500E-01, 0.11687200E+00, 0.31061700E+00, 0.11899700E+00, 0.20283500E+00, -.14016900E-01, 0.10596800E+00, 0.59858400E+00, 0.57858700E-01, -.46027600E+00, 0.10128600E+00, -.14402600E+01, -.18196200E+00, -.81149700E-01, -.34552800E+00, -.22226700E+00, -.10669700E-01, -.40255500E+00, -.20402100E-01, -.77523800E+00, -.39959800E+00, -.73796300E+02, 0.42151300E+02, 0.25591400E+03, 0.77842100E+02, -.19439100E+02, -.23058600E+02, 0.11463300E+02, 0.11069700E+02, -.22441900E+02, -.49779800E+02, 0.22970100E+02, -.76297300E+02, 0.48067100E+02, 0.42448300E+01, 0.21006400E+02, -.11422600E+02, -.76852700E+01, -.24472600E+01, -.17462100E+02, 0.49331500E+01, 0.27579900E+02, -.18042800E+02, -.53305400E+01, -.50640900E+03, 0.24743900E+03, 0.25507200E+03, 0.11406300E+03, 0.10587000E+03, 0.85688500E+02, -.14798800E+03, 0.13976900E+02, 0.17573000E+03, 0.72852900E+03, -.36536200E+03, -.36614500E+03, -.93356900E+02, 0.17978500E+01, -.27608800E+03, -.22297600E+03, -.35624900E+03, -.34206900E+02, 0.37739700E+02, -.19421200E+02, -.24526900E+02, -.15749700E+02, -.19377900E+02, 0.50714300E+01, 0.57854500E+02, -.78435800E+00, 0.14089000E+02, 0.57488900E+02, -.28447200E+02, -.29048800E+02, 0.51057900E+02, 0.73565800E+02, -.41247800E+02, 0.56402200E+02, -.79133000E+02, 0.35521400E+01, 0.48407300E+02, -.24768700E+02, -.29253000E+02, 0.70681200E+02, 0.67549000E+02, -.76059700E+02, -.26795600E+03, -.16830900E+03, 0.49562700E+02, -.42138000E+01, 0.14184000E+01, -.14913500E+02, 0.33416100E+02, 0.58732800E+02, -.49353800E+02, -.13133300E+03, -.40174000E+02, 0.40614300E+02, -.50258500E+03, 0.25309800E+03, 0.25091500E+03, 0.48878400E+02, -.75864000E+02, 0.19785200E+03, 0.11053400E+03, 0.20896800E+03, 0.26471500E+02, 0.20213500E+03, -.10089000E+03, -.99275800E+02, -.37440100E+02, 0.11075000E+02, -.73013600E+02, -.69493500E+02, -.48403900E+02, -.48647400E+01, 0.34251100E+01, 0.68171700E+02, 0.61807200E+02, 0.50843500E+01, -.52631700E+01, -.68266200E+02, -.11978600E+02, 0.84651200E+01, 0.91417500E+01, 0.39029400E+01, 0.29089100E+02, 0.78690700E+01, -.86806500E+01, -.31527000E+02, -.26506200E+02, -.43686700E+02, 0.18194900E+02, 0.43021600E+02, -.14076200E+02, 0.89715500E+01, -.44590300E+02, -.74664400E+02, -.45729800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.46073200E+01, 0.99438400E+00, -.35330900E+01, -.16949900E+01, 0.58943600E+01, 0.62653400E+00, -.10279300E+02, -.56744100E+01, -.50402700E+00, 0.81159100E+00, 0.15335700E+00, -.30978400E+01, 0.22373900E+01, -.41173000E+01, -.12971600E+01, 0.50139500E+00, 0.29844400E+01, -.61834500E+00, -.22579700E+01, 0.19793300E+01, -.43034500E+00, 0.22627800E+00, -.16044200E+01, 0.80850800E+00, 0.51229900E-01, -.35317200E+00, -.23111500E+01, 0.13937600E+01, -.78242200E+00, 0.96775800E+00, 0.11506000E+01, -.42030900E+00, -.21170300E-01, -.97137200E+00, 0.74630200E+00, -.11817100E+01, -.13189800E+00, -.22416000E+00, 0.19838500E+01, 0.82213800E+00, -.34676400E+01, -.93658300E-01, 0.36925300E+01, 0.19237900E+01, -.36916300E+01, 0.16907600E+00, -.58207800E+00, 0.37633700E+01, 0.42201000E+01, -.16672900E+01, -.40009800E+00, 0.14850600E+00, 0.19806500E+00, 0.23408400E+00, -.48977600E+00, -.19645400E+01, -.69669500E+00, 0.68177800E-01, 0.61254400E+00, -.56552000E+00, 0.33540300E+00, -.16909000E+00, 0.93228500E+00, 0.17276100E+01, -.79149300E+00, -.33224000E+00, 0.26110700E+00, -.46391200E+00, -.10835100E+01, -.30033600E+00, 0.23645800E+01, 0.19932400E+00, 0.11612200E+01, -.23907900E+00, 0.11923000E+01, 0.17994000E+01, 0.41192600E+00, -.38586400E+00, -.16439300E+00, 0.10878300E-01, -.90473200E-01, 0.62495200E+00, 0.38247300E+00, -.43207100E+00, 0.74510600E-01, -.36072400E+00, -.13278400E+01, -.13823200E+01, -.73590800E-01, -.75313600E+01, 0.42410800E+00, 0.80599500E+00, 0.67994600E-01, 0.27024000E+01, 0.11146000E+01, 0.10672000E+01, -.27064500E+00, 0.12915700E+01, -.45421200E+00, -.13710600E+01, 0.71040100E+00, 0.11732300E+01, 0.21794300E-01, 0.23515800E+01, -.21322300E+03, -.10180500E+04, 0.19732500E+02, 0.65719600E+02, -.39345200E+04, 0.19556700E+04, 0.19639100E+04, -.19001100E+03, 0.47317800E+03, 0.11431700E+04, -.13969700E+03, 0.70840600E+03, 0.10481500E+04, 0.32999800E+03, -.20131600E+03, -.15356800E+03, 0.89044800E+02, 0.12664200E+03, -.27156900E+03, -.34182800E+03, -.28182700E+03, 0.90158800E+02, 0.15727700E+04, -.76814700E+03, -.79151000E+03, -.26742700E+03, -.13517400E+03, -.23569500E+03, 0.74523400E+03, -.39487800E+03, -.19537300E+03, 0.22331300E+04, -.11819800E+04, -.11178500E+04, 0.61621800E+03, 0.10194400E+04, -.13422600E+04, -.12325800E+04, -.14894900E+04, 0.58174400E+03, -.15933700E+03, 0.71973700E+02, 0.74072500E+02, 0.14658400E+03, 0.40561100E+02, -.51832800E+02, -.67286600E+00, 0.97431800E+02, 0.10883900E+03, 0.41754300E+04, -.20754100E+04, -.20878700E+04, 0.33191000E+03, -.35812500E+03, -.13095600E+04, -.81702100E+02, -.90533400E+03, -.10580200E+04, 0.19122100E+03, -.90106400E+02, -.14333000E+03, -.99817200E+02, 0.33442300E+02, -.11649400E+03, 0.17011800E+03, 0.22916000E+03, 0.72108000E+01, 0.71471400E+03, -.36022000E+03, -.42287000E+03, 0.22328800E+03, -.98671400E+01, -.19263500E+03, 0.43363300E+03, 0.43086300E+02, -.14197200E+03, -.33287600E+04, 0.16427000E+04, 0.16629600E+04, -.16343000E+03, -.47190500E+03, 0.16682300E+04, 0.18893800E+04, 0.15445600E+04, -.17865600E+03, 0.90661800E+03, -.43144900E+03, -.47602400E+03, -.17242900E+03, -.45345000E+03, 0.45230100E+02, 0.50823400E+03, -.16914100E+03, -.43811100E+03, 0.91394500E+02, -.17124000E+02, -.84357000E+02, 0.10792500E+03, -.50202400E+02, 0.20964800E+02, 0.78928000E+02, 0.37008400E+02, 0.23865700E+03, 0.18073400E+03, -.21112800E+02, 0.94827900E+02, 0.41419200E+02, 0.43940500E+03, 0.96583800E+02, 0.20213600E+03, 0.60159500E+03, -.10712700E+03, 0.81055300E+03, 0.28304900E+02, 0.44032500E+01, 0.60130500E+03, -.40502100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.92263900E+00, -.13333700E+00, -.19591400E+01, 0.17069900E+00, -.81220100E+01, 0.11667800E+00, 0.80366100E+01, 0.37574400E+01, 0.89647500E+00, -.11395000E+00, -.30383800E+01, 0.14233600E+01, -.27755200E+01, 0.13721000E+01, 0.19884200E+00, -.93397200E+00, -.12955500E+00, 0.15564200E+00, 0.23739800E+01, -.99694300E+00, 0.65142900E+01, -.51319700E+00, 0.84706300E+00, -.51339500E+00, -.43039600E+00, 0.92256600E+00, -.91304200E+00, -.56237600E+00, 0.14187800E+01, -.22946300E+00, -.55702900E+00, -.12093200E+01, 0.12496400E+01, 0.98614400E+00, 0.14286400E+00, 0.11074700E+01, 0.40795000E+00, -.91477500E+00, 0.13191200E+01, -.18295500E+01, -.11769900E+01, -.60838000E+00, 0.19892100E+01, 0.12721000E+00, -.20120400E+00, -.13227800E+01, 0.27490900E+00, -.19668900E+01, 0.28700300E+01, -.87223300E+00, -.58480700E+00, 0.16708100E+00, -.20389700E+01, 0.34453500E+00, 0.43418700E+00, -.21973600E+01, 0.23622300E+00, 0.78224200E+00, 0.43144700E+00, -.17315400E+01, -.57980000E+00, 0.86340600E+00, -.99210200E+00, -.46971400E+00, -.32880000E+00, 0.36110300E+00, 0.95843400E+00, -.37588100E+00, -.11046500E+01, 0.70773600E-01, 0.10166800E+01, 0.10490500E+00, -.17639800E+00, 0.32202100E-01, -.18347900E+00, 0.12347400E+01, 0.85421800E+00, -.11028700E+01, 0.14680100E+00, -.66692100E+00, -.48738700E+00, -.87512900E+00, -.31703300E+00, 0.11542300E+00, -.10178100E+01, 0.31308500E+01, 0.77969700E+00, 0.39033000E+00, 0.32883400E+00, -.28788100E+00, -.98683100E+00, 0.15878000E+00, -.58444000E+00, -.17717700E+00, 0.49305900E+00, -.55268000E+00, 0.37336400E-01, -.39488300E+00, 0.28272700E+00, 0.71217100E+00, 0.17723600E+00, -.29608200E+01, 0.24542800E+00, 0.69514100E+00, -.34936500E+00, -.94213700E+03, 0.11623000E+03, -.67168200E+02, -.12466900E+04, 0.62067000E+03, 0.62837600E+03, -.11566600E+03, 0.15272100E+02, 0.43752300E+03, 0.19224400E+03, -.23909600E+02, -.44079300E+03, 0.25251100E+02, -.22720400E+02, -.29331100E+02, -.10498600E+02, -.73665500E+02, 0.12864000E+02, -.12285900E+02, 0.34437000E+02, -.99428500E+02, 0.18447900E+04, -.90143400E+03, -.92449700E+03, -.10817700E+03, -.46208100E+02, -.56309700E+03, 0.31032400E+03, -.42999700E+03, -.18509000E+03, -.15567200E+04, 0.75686000E+03, 0.79648500E+03, -.23757700E+02, -.33335100E+03, 0.79789200E+03, 0.44419900E+03, 0.67116800E+03, -.32239900E+03, 0.10330200E+03, -.51661400E+02, -.19801800E+02, 0.16225800E+03, 0.16527300E+03, -.19999100E+03, -.27999800E+03, -.24912800E+03, 0.79649600E+02, 0.69740800E+03, -.34720400E+03, -.34644900E+03, 0.10767100E+03, -.63882500E+02, -.21405700E+03, -.56862300E+02, 0.40444700E+03, 0.40600100E+03, 0.57378700E+03, -.28572100E+03, -.24401500E+03, -.10371900E+03, -.19203000E+03, 0.39259400E+02, 0.56959100E+03, 0.39074800E+03, 0.23428800E+02, 0.73985100E+03, -.37568900E+03, -.23352700E+03, -.18301700E+02, 0.23493700E+03, -.21187200E+03, -.46833600E+01, -.37594300E+03, 0.20716700E+03, 0.12729300E+04, -.63969300E+03, -.63311800E+03, -.66162300E+01, 0.13888400E+03, -.57603400E+03, 0.17926300E+02, -.50167200E+03, -.63082000E+02, -.10086800E+03, 0.55949200E+02, 0.37781200E+02, -.21093400E+03, -.41972700E+03, 0.35426700E+03, 0.63811900E+03, 0.41631800E+03, -.39417900E+03, -.59142700E+02, 0.10377700E+02, -.32314100E+02, 0.43377500E+02, 0.56749800E+02, -.10290500E+02, 0.90952700E+02, -.61262200E+02, -.96964900E+02, -.11676400E+03, -.65420300E+02, 0.33863700E+02, 0.19133600E+02, -.88297700E+03, 0.64175900E+02, -.91186400E+02, -.22782500E+03, -.23981200E+03, -.10184900E+04, -.80315900E+01, -.19978100E+02, 0.10510500E+03, -.12821100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10231900E+02, -.24779900E+01, 0.89789900E+01, 0.47330900E+01, -.21450900E+02, 0.53422100E+00, 0.25047500E+02, 0.10631600E+02, 0.13879200E+01, -.21149100E+01, -.74720800E+01, 0.60014500E+01, -.60621900E+01, 0.48678600E+01, 0.32489200E+01, -.36649600E+01, 0.65571000E+00, 0.16104000E+01, 0.59157500E+01, -.11527800E+01, 0.13699900E+02, 0.11552100E+01, -.71933500E+00, -.73871000E+00, -.76172700E+00, 0.36758200E+01, -.47608100E+00, -.13092900E+01, -.32659500E+01, 0.47213600E+01, -.12623500E+01, 0.11857600E+01, -.11586900E+00, -.12915800E+00, 0.16532600E+01, -.30566300E+00, 0.41200200E-01, 0.19051700E+00, -.28727900E+01, -.82629600E+00, -.13071000E+00, -.37840300E+00, 0.32225300E+00, 0.42560400E+00, 0.25017500E+00, -.10281900E+01, 0.15072300E+01, -.21159200E+01, -.30579000E+01, 0.85082300E+01, 0.66053100E-01, 0.86115900E+00, -.86922100E+00, -.19802900E+01, 0.40979500E+00, -.29923400E+01, 0.74454100E+00, -.43234200E+00, 0.28029600E+00, 0.39251300E+01, 0.10656100E+01, 0.28255300E+01, -.40693100E+01, -.13638500E+02, 0.25076800E+01, 0.16256200E+01, 0.29669900E+01, 0.67657800E-01, 0.29784100E+00, -.12519800E+01, -.14120600E+01, 0.57611100E+00, 0.79887000E-01, 0.77029000E+00, -.25086200E+01, 0.14234900E+01, 0.52017300E+00, 0.35663200E+01, 0.30470100E+00, 0.38424200E+01, -.92785900E+00, -.20039300E+01, 0.12262100E+00, -.48073100E+00, 0.19340700E+01, 0.43496400E+01, -.71595800E+00, -.25741200E+01, -.29032800E+01, -.33787700E+01, 0.12632300E+00, -.12864200E+00, -.37904700E-01, 0.79466400E+01, -.21519300E+01, 0.19805500E+01, 0.23934700E+01, 0.12173700E+01, -.42840800E+00, -.90235900E+00, 0.27340600E+01, -.29878300E+01, -.18311900E+01, 0.23973200E+01, -.73695300E+00, 0.74120200E+00, 0.10318700E+04, -.16019500E+02, 0.76210000E+03, -.38327700E+03, -.36340000E+03, -.17427100E+04, 0.19126900E+03, -.62207700E+03, -.19774400E+04, -.16145800E+04, 0.12813900E+04, 0.47872200E+03, -.23401200E+03, -.26392900E+03, 0.84834600E+02, 0.22300600E+03, -.29973900E+03, -.21706500E+03, -.49183800E+03, 0.17006200E+03, -.32293000E+04, 0.15710200E+04, 0.15203500E+04, -.18928000E+02, 0.34658900E+03, 0.10958600E+04, 0.10722800E+04, 0.36474500E+03, 0.54220300E+03, 0.84741800E+04, -.42290500E+04, -.42091300E+04, 0.23362900E+03, 0.86523600E+03, -.35148300E+04, -.15802700E+04, -.44247700E+04, -.19553600E+02, -.27943500E+03, 0.14146100E+03, 0.17206700E+03, -.11816300E+03, -.18438200E+03, 0.27309000E+03, 0.55266700E+03, 0.26762000E+03, 0.44303600E+02, -.19709400E+04, 0.98770800E+03, 0.98712700E+03, 0.19624500E+04, -.15958900E+02, 0.91965300E+03, 0.17201000E+04, 0.18697100E+04, -.12252300E+04, -.11030200E+04, 0.54738400E+03, 0.63558400E+03, 0.10053900E+03, 0.62002400E+03, 0.15315300E+03, -.50077000E+03, -.33655200E+03, -.17502400E+03, 0.31481100E+03, -.21673600E+03, 0.39190200E+02, 0.17538100E+03, -.50377400E+02, 0.79593600E+02, 0.86297300E+03, 0.27631700E+03, -.45043300E+03, -.45385400E+04, 0.22690200E+04, 0.22756300E+04, -.30847200E+03, 0.43429300E+03, 0.17763100E+04, 0.15187500E+04, 0.14686200E+04, 0.14074700E+04, 0.88856700E+03, -.48097800E+03, -.44621200E+03, -.13125100E+03, -.36614000E+02, -.31397800E+03, -.53549900E+03, -.37946300E+03, 0.18874300E+01, 0.18933400E+03, 0.84583600E+02, -.29637500E+02, 0.61657200E+02, -.92255100E+02, -.81173000E+02, -.13459700E+03, 0.94295400E+02, 0.41696800E+03, 0.38182600E+03, 0.15689500E+03, 0.44017000E+02, 0.15035500E+03, 0.12389500E+04, -.14729200E+02, 0.79888800E+03, 0.51436200E+03, 0.21502200E+03, 0.28081400E+04, 0.14291700E+03, -.22574100E+02, -.28940900E+03, -.16651400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.77968200E+00, -.13183200E+00, 0.20857600E+00, 0.57986400E+00, -.76957900E+01, 0.65673500E+00, 0.53639900E+01, 0.22766900E+01, -.16639800E+00, -.10893700E+01, -.15771800E+01, 0.12338600E+01, -.13685600E+01, 0.15143900E+01, 0.10525900E+00, -.75914100E+00, -.51355900E-02, 0.10386100E+00, 0.15012400E+01, 0.18633200E-01, 0.23838700E+01, 0.96611400E-01, 0.19210400E+00, -.26479300E+00, 0.71989600E+00, 0.55876200E+00, -.74607000E+00, -.10963300E+00, 0.21028000E+00, 0.82782200E+00, -.33571100E+00, -.77332000E+00, 0.17800600E+00, 0.82467000E-01, 0.39485500E+00, -.47660200E+00, 0.22338500E-01, -.19399800E+00, 0.50993700E+00, -.49712500E+00, -.96038400E+00, -.14259000E+00, 0.14059500E+01, 0.46345000E+00, -.58417200E+00, -.48030200E+00, -.11860100E+00, 0.30682200E+00, 0.22196900E+01, -.13392400E+01, -.10934400E+00, -.11025000E+00, 0.66136000E+00, 0.14668800E+01, 0.22418000E+00, 0.11103900E+00, 0.20020700E+00, -.15495700E+00, 0.22059400E+00, -.12349700E+00, -.55654600E-01, -.82694800E+00, -.44291900E-01, 0.18850300E+01, -.62420300E+00, 0.27510800E-01, -.63570300E+00, -.13977500E+00, 0.71849300E-01, -.95255000E-01, 0.57749500E+00, -.12911200E+00, 0.28667600E+00, 0.97754000E-01, -.48369300E+00, -.57360800E-01, 0.12984500E+00, -.22124400E+00, 0.10951700E-01, -.11873000E+01, 0.74859100E-01, 0.20731600E+00, -.78294700E-01, 0.10196800E+00, -.11375900E+01, -.14030200E+01, 0.46917600E+00, 0.10271600E+01, 0.34335300E+00, 0.54977000E+00, 0.12304700E+00, 0.69432800E-01, 0.20806000E-02, -.26191800E+00, -.36887100E-01, -.11608100E+00, -.10442700E+00, -.42540300E+00, 0.35998500E-01, 0.44836700E+00, -.19952100E+00, -.98869900E+00, -.12979800E+00, -.63841900E+00, -.25054100E+00, 0.21120500E+00, -.67819900E-01, 0.47433800E+02, -.66277100E+03, 0.32970100E+03, 0.33110700E+03, -.43122900E+02, 0.10806600E+03, 0.12527700E+03, -.55099000E+03, -.18795300E+02, 0.21058800E+03, 0.88753700E+02, -.53942400E+02, -.39527400E+02, -.35602000E+01, -.51519700E+01, -.30185000E+02, -.47153800E+02, -.48784900E+02, 0.49846600E+01, -.37083500E+03, 0.16731200E+03, 0.17278500E+03, 0.91918900E-01, 0.14089600E+02, 0.13850100E+03, 0.40063900E+02, 0.15635300E+03, 0.56691200E+02, 0.56093400E+03, -.29863500E+03, -.28311400E+03, -.17300100E+02, 0.20117400E+03, -.21848700E+03, -.22335800E+03, -.32472300E+03, 0.89836700E+02, 0.97234400E+02, -.50968100E+02, -.55655300E+02, 0.25350900E+02, -.17478600E+02, -.26980500E+02, -.96146800E+01, -.27677800E+01, 0.16327200E+02, 0.10397600E+04, -.51754100E+03, -.52050600E+03, 0.77511500E+02, -.10561900E+03, -.24618900E+03, 0.52922300E+03, -.80038900E+02, -.25838100E+03, 0.26105800E+03, -.12854800E+03, -.14315300E+03, -.99091200E+01, 0.30088900E+02, -.12158000E+03, -.15617200E+03, -.13264600E+03, -.37592100E+02, 0.13423300E+03, -.69359400E+02, -.98035800E+02, 0.12953900E+03, 0.87676000E+02, -.10107600E+03, 0.51837700E+02, -.12300200E+03, 0.50288000E+02, -.93242300E+03, 0.47536800E+03, 0.46544900E+03, 0.56476300E+02, -.49083700E+02, 0.32275600E+03, 0.25684000E+03, 0.33411000E+03, 0.49771200E+02, 0.84453700E+02, -.41904500E+02, -.42812500E+02, -.62002200E+02, -.75130700E+02, 0.36028500E+02, 0.23624700E+03, 0.52145300E+02, -.92924100E+02, -.84615800E+01, 0.75374800E+02, 0.41899500E+02, 0.28606900E+02, 0.14597100E+01, -.74061200E+02, 0.25550800E+02, 0.18967000E+01, 0.27971000E+02, 0.82628300E+01, -.43324300E+01, 0.30392400E+02, -.17232100E+02, 0.18764400E+03, 0.12623900E+02, 0.45012100E+01, 0.90868900E+02, -.16843300E+02, 0.31249000E+03, 0.10426800E+02, -.26530100E+02, 0.24915400E+02, -.10336500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.58709300E+01, -.26407100E+01, 0.67040400E+01, 0.24386500E+01, -.48457800E+01, 0.65110900E+00, 0.10475800E+02, 0.25837000E+01, 0.81285900E+00, -.10092300E+01, -.15861500E+01, 0.22300300E+01, -.24900600E+01, 0.13614900E+01, 0.77848000E+00, -.14303900E+01, -.83252500E+00, -.19070600E+00, 0.16834000E+01, 0.26830100E+01, 0.72345100E+01, -.19330400E-01, -.56102400E+00, -.51140400E+00, -.30762600E+00, 0.10152600E+01, -.29543200E+00, -.18706800E+01, -.41162100E+01, 0.23730400E+01, -.44466000E+00, 0.19395900E+01, 0.23867000E+00, 0.11371400E+01, 0.14034000E+01, -.14955400E+01, -.19977000E+00, -.47525800E+00, 0.28492500E+01, 0.16119100E+01, 0.33687400E+00, 0.11731000E-01, 0.90373500E+00, 0.14124000E+01, -.36056500E+01, -.45840600E+00, 0.13367200E+01, -.58686300E+00, -.10039100E+01, 0.21951700E+01, 0.83972800E-01, 0.12410500E+00, 0.30510400E-01, -.23331200E+00, -.12205700E+01, 0.79268100E+00, 0.15566300E-01, -.11327600E+00, -.19273000E+00, -.13322500E+01, -.86931700E-01, 0.13942700E+01, 0.10437000E+00, 0.11614100E+01, 0.74755400E+00, 0.97907200E+00, -.48308800E+00, -.32112700E+00, -.10120600E+01, -.49864900E+00, -.10169400E+01, 0.75151500E+00, -.19714200E+00, 0.98508100E+00, -.19265700E+01, -.31682400E+00, 0.78414100E+00, 0.30517800E+01, -.12216500E+00, 0.11890200E+01, 0.35797300E+00, -.72079000E+00, -.75546200E-01, -.42139400E-01, -.12435800E+01, 0.17579100E+01, 0.54668800E+00, 0.38227500E+00, -.28888100E+00, 0.22193800E+01, -.92046900E+00, 0.94700700E+00, -.61539500E+00, -.62698300E+00, -.13279500E+00, 0.88795200E-02, -.38326900E-01, -.11296700E+01, 0.28670500E+00, 0.15082200E+01, -.14320700E+01, 0.91917700E+00, 0.85759500E+00, -.17499700E+01, -.50734700E+00, -.20098400E-01, -.99309300E-01, 0.13411400E+01, -.38496800E+04, 0.19240300E+04, 0.19229600E+04, 0.21731000E+03, 0.33085700E+03, 0.11649800E+04, 0.28785700E+03, 0.85562900E+03, 0.47247400E+03, 0.28809900E+02, -.46138400E+02, -.23847900E+02, -.96382300E+02, -.15894800E+03, 0.80012500E+02, 0.94030200E+02, 0.71026200E+02, -.13670900E+03, 0.66288900E+03, -.41861800E+03, -.32058100E+03, -.89651500E+02, -.65619200E+02, -.18670100E+03, -.60771700E+02, -.20531100E+03, -.83026500E+02, -.86767100E+03, 0.36908600E+03, 0.43530700E+03, -.62424000E+02, -.19871100E+03, 0.50486100E+03, 0.14507000E+03, 0.41412900E+03, -.13605900E+03, 0.71993000E+03, -.36511800E+03, -.33990100E+03, -.44176100E+02, -.24228500E+02, -.22305900E+03, 0.50353200E+02, -.29662400E+03, -.11719200E+03, 0.33802700E+04, -.16893900E+04, -.16884300E+04, -.24618900E+03, -.29509900E+03, -.10427100E+04, -.34735000E+03, -.80857300E+03, -.43762600E+03, -.73756500E+03, 0.37802000E+03, 0.38273500E+03, 0.40614500E+03, 0.43174700E+03, 0.13584800E+03, -.23990600E+03, 0.10904200E+03, 0.46110400E+03, 0.12911500E+04, -.65258600E+03, -.60007300E+03, 0.49150600E+01, 0.58458200E+03, -.38756500E+03, 0.85928800E+02, -.42351500E+03, 0.20753600E+03, 0.46711800E+03, -.11160700E+03, -.23197800E+03, 0.26922600E+02, -.20646800E+02, -.10636700E+03, 0.24064200E+03, -.82114200E+02, -.12135700E+03, -.45440300E+03, 0.22107600E+03, 0.22255500E+03, -.32224500E+02, -.79102800E+02, 0.23967200E+03, 0.36106400E+02, 0.29543400E+03, -.19706500E+02, -.32003300E+02, 0.36538500E+03, 0.17579400E+03, 0.73023200E+01, 0.12937100E+01, -.36492900E+03, 0.47493500E+02, -.23155200E+00, -.15663100E+03, -.11584200E+03, -.34520200E+02, 0.40878300E+01, -.32687000E+02, -.80089200E+03, -.33264900E+02, -.91674300E+02, -.18729100E+03, -.14832100E+03, -.86805300E+03, 0.49428900E+02, -.26399200E+03, 0.28220800E+01, -.12287500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.44811900E+01, -.75451200E+00, 0.54716500E+01, 0.25625100E+01, -.81511200E+01, 0.34897900E+00, 0.60351300E+01, 0.24547100E+01, 0.13212600E+00, 0.86365600E-01, -.50530300E+01, 0.21667700E+01, -.10832100E+01, 0.45727100E+00, 0.11957400E+01, -.11485100E+01, 0.33947200E+00, 0.40860900E+00, -.72820100E-03, 0.65521700E+00, 0.13268100E+01, 0.33791800E-01, -.68925800E+00, -.41751000E-01, -.24333300E+01, 0.19357500E+00, 0.25120100E+01, 0.94480100E-01, -.45980600E+01, 0.11242500E+01, -.20401000E+00, 0.69131900E+00, -.11335900E+01, -.31473500E+00, 0.31120700E+00, -.64239600E+00, -.87067400E+00, 0.17332400E+00, -.17508300E+00, 0.17472600E+01, -.72457900E+00, 0.10233900E+00, 0.82448600E+00, -.19701900E+00, -.30115200E+01, -.30965500E+00, 0.24317500E+00, 0.72798500E+00, 0.28610600E+01, 0.66663000E+00, -.31832300E+00, 0.25137300E+00, -.89365500E-01, 0.28161900E+00, 0.77519500E+00, -.12669500E+01, -.43806200E+00, -.70490200E-01, 0.32040100E+00, -.21561400E+00, 0.18772700E+00, -.15915400E-01, 0.53115800E+00, 0.80003200E+00, -.53649300E+00, -.11828300E+00, -.34326100E+00, -.24901700E+00, -.80025400E+00, -.21836600E+00, 0.54308100E-02, -.12147500E+00, 0.34576100E+00, 0.50083500E-01, 0.31029600E+00, -.57272400E+00, -.63584400E+00, -.21249900E+01, -.13263500E+00, 0.21391900E+00, 0.26005000E+00, -.57843200E+00, -.15640300E+00, -.98088700E-02, 0.69757500E+00, -.20122400E+01, 0.19197200E+00, 0.11065600E+01, -.28266500E+01, 0.11772700E+00, -.72242300E+00, -.60541500E+00, -.11932600E-01, -.22850200E+01, 0.28281400E+00, -.69904200E+00, 0.15306200E+00, -.60863500E+00, 0.46661300E+00, -.70530300E+00, -.70819000E+00, 0.12594600E+01, 0.24585900E-01, 0.56730400E+00, -.10210800E+00, 0.15678400E+00, -.23845200E-01, 0.22332600E+00, 0.13815700E+00, 0.37855300E+02, 0.97793300E+00, 0.10003600E+03, -.18045800E+02, 0.72883200E+02, 0.53249500E+03, 0.13447600E+03, 0.36258500E+02, -.12397800E+03, 0.66882800E+02, 0.59498300E+02, 0.12560400E+02, 0.24177700E+02, 0.33396400E+02, 0.23628900E+02, 0.60590100E+02, 0.24459500E+02, 0.44492700E+03, -.20124700E+03, -.21389600E+03, -.64094100E+02, -.56369300E+02, -.88242500E+02, 0.32940200E+02, -.13402900E+03, -.12359900E+03, -.83084900E+03, 0.42434700E+03, 0.41784500E+03, 0.12657400E+02, -.32395100E+02, 0.30943800E+03, 0.42119900E+03, 0.48932000E+03, 0.75283200E+02, -.11628000E+03, 0.60094200E+02, 0.60012300E+02, -.17568100E+02, -.73966800E+01, 0.51730800E+02, 0.10941000E+02, 0.40735100E+02, -.36571300E+02, -.35506100E+02, 0.15999900E+02, 0.17409800E+02, -.12291200E+03, 0.21814100E+02, -.26194200E+02, -.36378600E+03, -.84483900E+02, -.15405400E+02, -.82469600E+02, 0.39264900E+02, 0.47655000E+02, -.66877100E+02, 0.51930600E+02, 0.29300500E+02, 0.94763800E+02, -.48377000E+00, -.26709600E+01, -.11151600E+02, 0.40525100E+01, 0.20539400E+02, -.18068900E+03, -.13005900E+03, 0.39462300E+02, -.12908700E+03, 0.53713100E+02, -.19557500E+03, 0.10773500E+04, -.56424000E+03, -.53831000E+03, -.61274000E+02, 0.66405600E+02, -.37834900E+03, -.39536400E+03, -.45636900E+03, -.58353700E+02, -.55021300E+02, 0.27843000E+02, 0.29938000E+02, 0.82386000E+02, 0.83691700E+02, -.59941700E+02, -.16162200E+03, -.74607200E+02, 0.98848300E+02, -.17819800E+01, -.47503800E+02, -.11226400E+03, 0.36788300E+02, -.52362100E+01, 0.46969600E+02, -.19837000E+02, 0.18715100E+01, 0.56910200E+02, 0.86388100E+02, -.54143000E+01, 0.35433500E+02, 0.19032100E+02, -.76490800E+02, -.37939600E+00, 0.37940300E+02, -.42429900E+02, 0.51709700E+02, -.11225300E+03, 0.29207000E+02, 0.75689200E+02, 0.14646900E+02, 0.39981800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.46127700E+01, 0.52505400E-01, 0.67009300E+01, 0.32587400E+01, -.15924800E+02, -.45902900E-02, 0.13797900E+02, 0.93333900E+01, 0.32869400E+00, -.24273800E+01, -.40452300E+01, 0.20652300E+01, -.30034000E+01, 0.23770100E+01, 0.21565500E+01, -.27908000E+01, -.22736300E+00, 0.22160200E+00, 0.10195700E+01, -.11031100E+01, 0.63706900E+01, 0.42946100E+00, -.50288900E+00, -.72361600E+00, -.10881800E+01, 0.14585900E+01, -.11476700E+01, -.21236700E+00, -.40189500E+01, 0.32963300E+01, -.10266000E+01, 0.57726500E+00, -.61888300E+00, 0.11112800E+00, 0.16237800E+01, -.43029700E+00, -.56386300E-01, -.68052400E-01, 0.33505300E+00, 0.79016800E+00, 0.19797400E+01, -.10999500E+00, -.11732000E+01, -.59432100E+00, -.11264400E+01, -.12458300E+01, 0.57228100E+00, -.16587100E+01, -.19495200E+01, 0.26807400E+01, 0.30746700E+00, 0.47253300E+00, -.66844800E-01, -.21174800E+00, 0.76144100E+00, 0.11520700E+00, 0.67406300E-01, -.35025700E-01, 0.94745900E-01, 0.13322200E-01, 0.61842000E+00, 0.13535600E+01, -.30393600E+00, -.24151700E+01, 0.99736200E+00, 0.60551400E+00, 0.11146700E+01, 0.22690400E+00, -.40366800E-01, -.87181300E+00, -.18181500E+01, 0.48475700E+00, -.21127300E+00, 0.17876800E+00, -.10795700E+01, -.94395800E+00, 0.29633700E-01, 0.11180400E+01, 0.25836800E+00, 0.29106900E+00, 0.67973200E+00, -.21993800E+01, -.14227700E+00, 0.97525900E-01, -.22418100E+00, 0.39960100E+01, 0.48353400E+00, -.30376000E+00, -.27906400E+01, 0.52300900E+01, -.19773400E+01, 0.13653600E+01, -.10055400E+01, 0.18985700E+01, -.78116600E-01, -.25735600E+00, 0.71607500E+00, -.82795400E+00, 0.18621500E+00, 0.12949000E+01, 0.48872000E+00, -.97747200E+00, 0.50439300E+00, -.49881700E+00, -.98114500E+00, 0.92865600E+00, 0.26464400E+00, -.12416200E+00, 0.33011400E+00, -.16063700E+00, -.59101700E+01, 0.21617300E+03, -.33392000E+02, 0.22890600E+02, 0.36988900E+03, 0.12356100E+03, 0.14763600E+03, -.19318000E+03, 0.82170000E+02, 0.11628200E+03, 0.79857800E+02, 0.10124900E+03, -.13003300E+02, -.11445800E+03, 0.32266600E+02, 0.11288300E+03, -.45627400E+03, 0.26721800E+03, 0.28395200E+03, 0.10548600E+03, 0.81326000E+02, 0.54122300E+02, -.31342400E+03, 0.10115400E+03, 0.35960600E+02, -.14400000E+04, 0.69756400E+03, 0.70489900E+03, 0.30339900E+03, 0.42050400E+03, 0.23510300E+03, -.87508900E+02, 0.40415100E+03, 0.63437000E+03, -.43153100E+03, 0.21051800E+03, 0.17869300E+03, 0.27616800E+02, 0.22457100E+02, 0.12693200E+03, -.33179300E+02, 0.22873500E+03, -.17768300E+01, 0.32906900E+03, -.15814300E+03, -.16610400E+03, -.27197900E+03, -.64636600E+02, -.91255600E+02, -.30779000E+03, -.17075900E+03, -.18752600E+03, 0.35410900E+03, -.17545100E+03, -.22213800E+03, -.79508900E+02, -.92105700E+02, -.17986500E+03, 0.38212300E+02, -.20430500E+03, -.11919500E+03, -.28313500E+03, 0.16288400E+03, 0.10211300E+02, -.24954300E+02, -.24561100E+03, 0.16780300E+03, 0.29552300E+03, 0.18201300E+03, -.16874300E+03, -.91008500E+03, 0.41240400E+03, 0.45118800E+03, -.10682800E+03, -.44797400E+03, 0.45760500E+03, 0.15416700E+03, 0.54455200E+03, -.51686200E+03, 0.32507900E+03, -.13722500E+03, -.15039200E+03, 0.36551400E+02, 0.56532300E+02, -.18613100E+03, -.85834100E+02, -.25187700E+03, 0.21339000E+02, -.61217400E+02, -.22043900E+03, -.18183600E+03, -.50860600E+01, 0.33604900E+02, 0.22234500E+03, -.25435300E+02, -.37605200E+02, 0.16770600E+02, -.25031200E+02, -.28783300E+02, 0.31463200E+01, 0.16452400E+02, 0.48518400E+03, 0.42905200E+02, -.65340000E+02, 0.38832600E+03, 0.10111500E+03, 0.47255200E+03, -.41237300E+02, 0.16171100E+03, 0.38796100E+03, 0.10031300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.15292900E+00, -.15671200E-01, 0.55691600E+00, -.22320200E+00, 0.31988300E+01, -.51079900E+00, -.12228700E+01, -.85162900E+00, -.26824700E-01, 0.30644300E+00, 0.54742200E+00, -.35103900E+00, 0.49028400E+00, -.26235600E+00, 0.24092200E+00, 0.14186800E+00, -.16413200E+00, -.82316200E-01, -.38496600E+00, 0.21486900E+00, -.47256000E+00, -.65139100E-01, -.94274000E-01, 0.11800000E+00, -.40403300E+00, -.16182300E+00, 0.50453400E+00, -.14206200E-01, -.12922500E+00, -.22877900E+00, 0.11422600E+00, 0.24511300E+00, -.17155300E+00, 0.67991200E-01, -.33651000E-01, 0.34309900E+00, -.94786300E-02, 0.40850900E-01, -.99946500E-01, -.60106200E-01, 0.15209800E+00, 0.12478300E-01, -.38655700E+00, -.13483400E+00, 0.95071500E-01, 0.25035300E-01, 0.10697100E-01, -.13137200E+00, -.41883100E+00, 0.36731000E+00, 0.33129300E-01, 0.87729400E-01, -.21957400E+00, -.52877100E+00, -.14043900E+00, -.23239000E+00, -.38596400E-01, 0.42404400E-01, 0.39510100E-01, -.20699800E+00, -.27668800E-01, 0.34745700E+00, 0.97549000E-01, -.44301900E+00, 0.34409700E+00, 0.90649000E-01, 0.32177400E+00, -.52759000E-01, -.18318500E+00, 0.13633500E+00, -.12546600E+00, 0.13798600E+00, -.18579300E+00, 0.29458300E-01, -.45633300E-01, 0.31305300E+00, 0.56861600E-01, -.11953200E+00, 0.15086300E-01, 0.17937400E+00, 0.12085900E+00, -.14906300E+00, 0.16573000E-01, -.44158100E-01, -.89102200E-01, -.41528000E+00, -.57700400E-01, 0.15650900E+00, -.37100800E-01, -.82685400E-01, -.30087900E-01, 0.88093900E-01, 0.37072400E-01, -.61035700E+00, 0.13121200E+00, 0.24042100E-02, -.13297700E+00, 0.22517900E-01, -.14203100E-02, -.86889400E-01, 0.66912600E-01, -.20972400E+00, 0.14884100E+00, -.15221600E+00, -.76053400E-02, 0.11287600E+00, -.16226500E-01, 0.11097500E-01, -.26827300E-01, 0.11137500E-01, 0.44913900E-01, 0.52449800E+02, 0.24407200E+02, -.13413800E+02, -.44968900E+02, -.33118700E+02, 0.57053000E-01, 0.40388100E+01, -.57524700E+00, -.28842300E+01, -.76655000E+01, -.12854100E+02, 0.81246100E+01, 0.12929700E+02, 0.56698600E+01, -.11487800E+02, -.20588400E+02, 0.45677300E+01, 0.63175800E+01, -.14053500E+02, -.36107600E+02, 0.28219300E+02, 0.17924400E+02, 0.41970900E+02, -.18186500E+02, 0.83722000E+02, -.39444600E+02, -.41859200E+02, -.11525100E+02, -.21931100E+02, -.28683400E+02, -.65505600E+02, -.53352100E+02, -.36625600E+02, 0.65979300E+02, -.32574900E+02, -.31032900E+02, -.13144400E+02, -.15196400E+02, -.10104800E+02, 0.18256800E+02, -.71494900E+01, -.12287000E+02, 0.29604900E+02, -.15411400E+02, -.14750500E+02, -.49464400E+02, -.24581900E+02, 0.36613700E+01, 0.36189200E+02, 0.15232100E+02, -.65826000E+01, -.51425700E+02, 0.25643900E+02, 0.26702300E+02, 0.83276200E+01, 0.84715200E+01, 0.18983400E+02, -.79857700E+01, 0.57016800E+01, 0.23267400E+02, 0.22261300E+02, -.12361700E+02, -.80377500E+01, -.48596900E+01, 0.16006600E+02, -.16525100E+02, -.20304400E+02, -.17194200E+02, 0.27484100E+02, -.11293100E+02, 0.11552000E+02, 0.57259500E+01, 0.14262300E+02, 0.13663400E+02, 0.63696400E+01, 0.33318300E+02, 0.17737100E+02, 0.25062900E+02, -.81480500E+02, 0.37653200E+02, 0.40217100E+02, 0.10029700E+02, 0.19685900E+02, 0.19211900E+02, 0.15926100E+01, -.98370400E+00, 0.23355200E+02, 0.11834500E+01, 0.17295500E+02, 0.18604500E+02, -.19623600E+01, -.22265000E+01, -.17412600E+02, -.30173300E+00, 0.27473700E+01, 0.57433000E+01, 0.11640000E+02, 0.41434100E+01, -.22166400E+01, -.10757100E+01, -.10869700E+02, -.63197400E+01, 0.58737000E+01, -.24353100E+02, -.29398400E+01, -.21476900E+02, -.28245200E-01, -.14304100E+02, -.17565600E+02, -.55513300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11259000E+01, -.18037000E+01, 0.91838500E+00, 0.50247600E+00, -.33865400E+01, 0.10608000E+00, 0.37843600E+01, 0.18899500E+01, 0.43595000E+00, -.16139000E+00, -.11002700E+01, 0.31719700E+00, -.12608100E+01, 0.13687400E+01, 0.19983700E+00, -.26564200E+00, -.29501700E+00, 0.12624000E+00, 0.49837200E+00, 0.50673000E+00, 0.24910800E+01, 0.22421100E-01, -.27516900E+00, -.60166100E-01, 0.36160200E+00, 0.44678000E+00, -.47679400E+00, -.55253700E-01, -.20897400E+01, 0.13283300E+01, -.59818300E-01, -.19542800E+00, 0.94380300E-01, 0.18543600E+00, 0.50351400E+00, 0.37764000E+00, 0.36684900E-01, -.89416000E-01, 0.72049500E-01, -.80762600E+00, -.75353100E+00, -.20608300E+00, 0.11135300E+01, 0.16891100E-01, -.67477900E+00, 0.22776800E-01, -.27673500E+00, 0.61485400E+00, 0.81188300E+00, 0.11722200E+01, -.11839700E+00, 0.12201500E+00, -.91347200E-01, 0.36935700E+00, -.28764000E+00, -.58149400E+00, -.92320700E-01, -.16471900E+00, 0.34287500E+00, -.11700000E+00, -.83543400E-01, 0.68239300E-02, 0.21887900E+00, -.17495100E+00, 0.47405300E-02, 0.21925600E+00, 0.34291000E+00, -.13061000E+00, -.34629500E+00, -.60374200E-01, -.25528600E+00, 0.17655500E+00, 0.55814200E+00, 0.67890500E-01, -.68713000E+00, 0.52889700E+00, 0.19957500E-01, 0.11246600E+01, 0.86637700E-01, 0.53351900E-01, 0.48834100E-02, 0.92869000E-01, -.27865400E-01, -.29070000E-01, -.92322100E-01, 0.12920300E+01, 0.10015400E+00, -.39979900E+00, 0.18126800E+00, -.37410600E+00, 0.21102200E-01, -.13205700E+00, -.12047200E+00, 0.36044700E+00, 0.19953900E+00, 0.11171100E+00, 0.12446900E+00, -.95505600E-01, 0.18165000E-01, -.20084100E+00, -.42970700E+00, 0.21503900E+00, -.13358700E+00, 0.68125600E+00, -.81366900E-02, -.72820000E-01, 0.67113500E-01, -.52308000E+00, 0.27447900E+00, -.40967700E-01, -.20422400E+00, -.68713300E+00, 0.10889400E+03, -.39980800E+02, -.27278200E+03, -.79177000E+02, 0.11465700E+03, -.35162200E+02, 0.16752900E+02, 0.23038200E+02, 0.27702500E+02, 0.26995100E+02, -.55468000E+01, -.37424800E+02, -.54459800E+01, 0.20488000E+02, -.36444900E+03, 0.20035300E+03, 0.17791000E+03, -.79142100E+01, -.75241200E+02, 0.17204300E+03, 0.82394300E+02, 0.21615300E+03, -.50174800E+02, -.21925000E+03, 0.10917500E+03, 0.10816100E+03, 0.11175800E+03, 0.11585500E+03, -.12081800E+02, -.15132300E+03, -.51942200E+02, 0.12658500E+03, -.81312600E+02, 0.40136400E+02, 0.32037400E+02, -.97758700E+01, -.27485600E+02, 0.50047300E+02, 0.43982400E+02, 0.11832500E+03, -.24686700E+02, 0.24975600E+03, -.12268200E+03, -.12576400E+03, 0.40378900E+02, -.16034900E+03, -.16345100E+02, 0.31855000E+03, 0.48215800E+02, -.16686800E+03, 0.71805300E+02, -.37112300E+02, -.48756000E+02, -.69034400E+02, -.11747700E+03, -.41896900E+01, 0.38177300E+02, -.13003800E+02, -.10408400E+03, -.22630800E+03, 0.11853900E+03, 0.83646300E+02, 0.49086400E+02, -.13882800E+03, 0.82246300E+02, 0.13086000E+03, 0.74343300E+02, -.46025400E+02, -.21773600E+03, 0.80681800E+02, 0.10797000E+03, -.54493000E+02, 0.37371300E+02, 0.86428700E+02, 0.82989400E+02, 0.10907500E+03, -.52835500E+01, 0.86582400E+02, -.36387700E+02, -.43442900E+02, 0.10248000E+02, 0.20948200E+02, -.41961500E+02, 0.80942300E+02, -.10700100E+03, 0.92925300E+01, 0.32707100E+01, -.75980900E+02, -.36537200E+02, -.26760600E+02, 0.56763900E+00, 0.76488600E+02, -.13566400E+02, 0.67804400E+00, 0.10633300E+03, 0.89349100E+02, 0.17142100E+02, -.25170700E+02, 0.14648400E+02, 0.24165300E+03, -.20499900E+01, 0.62655100E+02, 0.76899600E+02, 0.41891100E+02, 0.30463700E+03, -.30488500E+02, 0.47142600E+02, 0.87915000E+02, 0.38204800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.27068700E+01, 0.23194700E+00, -.24458600E+01, -.63941100E+00, 0.58507500E+00, 0.52510600E+00, -.49186300E+00, 0.25573000E+00, 0.18904100E+00, -.47610800E-01, 0.47486600E+00, -.87748400E+00, 0.95510100E-01, -.12048900E+01, 0.42504200E+00, 0.24336800E+00, -.95157300E-01, 0.28114000E-02, -.16882200E+01, 0.51744300E-01, -.99132200E+00, -.11897200E+00, 0.21171300E+00, 0.15463800E+00, 0.62620600E-01, -.17254100E+00, 0.70021200E-01, 0.24492100E+00, 0.60359000E+00, 0.29235200E+00, 0.83460500E-01, 0.13389500E+00, 0.72138200E-01, -.50288600E-01, 0.65477800E+00, 0.40548700E+00, 0.48201200E-01, 0.41357600E+00, -.49575900E+00, -.49706300E-01, -.69782700E+00, -.51307700E-01, 0.11876500E+01, 0.53504600E-01, -.10512900E+01, 0.32540100E+00, -.53614400E-01, 0.55420600E+00, 0.12131800E+01, -.64126500E+00, 0.22881200E-01, -.83558200E-02, 0.39527500E+00, 0.82880300E-01, -.15071300E+00, 0.29700600E-01, -.83386400E-02, 0.12912700E+00, -.94697700E-03, -.26916700E+00, 0.34380500E+00, 0.10548100E+00, -.26271300E+00, 0.11823300E+01, -.52091400E+00, -.38337300E+00, 0.24553000E+00, 0.78140500E-01, 0.51435800E+00, 0.31672700E+00, -.15111300E+00, -.48937200E-01, -.14059000E+00, -.30531000E-01, 0.33317300E+00, 0.36864700E+00, 0.20370800E+00, -.40753800E+00, 0.29983200E-01, 0.13627900E-02, 0.20378700E+00, 0.12674900E-01, -.68424700E-02, -.36240900E-01, -.16421000E+00, -.23691500E+00, -.12183800E+00, 0.17192900E-01, 0.41818000E+00, -.38333200E+00, 0.18767700E-02, -.14680800E+00, -.17437100E-01, -.11082700E+01, 0.63174300E+00, -.12890200E+00, -.34963200E+00, -.21797700E+00, 0.13946700E+00, -.49283800E+00, -.23589200E+00, -.11536100E-01, 0.19004000E+00, -.20840900E+00, -.98019000E-02, -.27025900E-01, -.34901700E-01, 0.25336400E+00, -.20566500E-01, 0.28841200E-01, -.46060200E-01, 0.28671300E+00, -.28835600E+00, 0.88575000E+02, 0.27131600E+03, 0.21458200E+03, -.70513900E+02, -.38209400E+02, 0.19058100E+02, 0.17494100E+02, 0.73942900E+01, -.95452100E+00, 0.17048400E+02, 0.19913700E+02, 0.27399800E+02, -.69115200E+01, 0.26778700E+03, -.11890300E+03, -.13403500E+03, -.11774900E+02, -.52444400E+02, -.42687200E+02, 0.11713300E+03, -.68507800E+02, -.62604000E+02, -.49852500E+03, 0.24897100E+03, 0.25014500E+03, 0.71237500E+01, -.74560500E+02, 0.20450100E+03, 0.11091100E+03, 0.29894000E+03, -.25384800E+02, -.29198100E+02, 0.15174200E+02, 0.18175300E+02, 0.65243100E+01, 0.22626300E+02, 0.38735800E+01, 0.20571500E+02, -.16920100E+02, 0.57855500E+01, 0.31680200E+03, -.15827400E+03, -.15802100E+03, 0.22415600E+02, -.35383700E+02, -.17253000E+03, -.20604100E+03, -.29092700E+03, 0.26113800E+02, 0.70664600E+02, -.36160200E+02, -.30867800E+02, -.14249400E+02, -.68531000E+02, 0.30106300E+01, 0.51823000E+02, 0.65760300E+02, -.17013300E+02, -.13083700E+03, 0.64343700E+02, 0.77840500E+02, -.19326600E+02, -.38639500E+02, 0.33139700E+02, -.10353400E+03, 0.22496300E+02, -.19446100E+02, 0.67607400E+03, -.35348700E+03, -.33786100E+03, -.79501500E+01, 0.89312600E+02, -.22700500E+03, -.60192200E+02, -.25872200E+03, -.22899500E+02, 0.21021600E+03, -.10201000E+03, -.10656200E+03, -.33163300E+02, -.71203800E+02, -.27542000E+02, 0.13594500E+02, 0.41875900E+02, -.75861400E+02, -.30966800E+01, -.23847000E+02, -.22973100E+02, -.20945400E+02, 0.74928800E+01, 0.23134100E+02, -.54104800E+01, -.77523600E+01, 0.50777300E+02, 0.52887600E+02, 0.10619000E+01, -.21801000E+02, 0.82928600E+01, -.13862500E+03, 0.48565600E+00, 0.34123300E+02, -.53025900E+02, -.27592000E+01, -.23162700E+03, -.25278900E+02, 0.24134100E+02, 0.42787700E+02, -.58418800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13205800E+01, 0.14005800E+00, -.12786400E+01, -.79457800E+00, 0.66734900E+01, -.19133000E+00, -.51890700E+01, -.26362400E+01, -.15559400E-01, 0.80340100E+00, 0.18698700E+01, -.13019800E+01, 0.11542400E+01, -.15531400E+01, -.49886700E+00, 0.63926700E+00, 0.38488300E+00, -.26383100E+00, -.66573600E+00, 0.12664800E+00, -.55479700E+00, -.12849800E+00, -.24678500E+00, 0.12909100E+00, -.19092200E+00, -.30187900E+00, -.86965300E-02, -.75412500E-01, 0.71164100E+00, -.80660300E+00, 0.95075000E-01, -.29056700E+00, 0.19759300E+00, 0.22818400E+00, -.45420700E+00, -.47610500E-01, -.37231900E-01, -.30253800E+00, 0.53777400E+00, -.11588700E+00, 0.37639200E+00, -.33192700E-01, -.27936300E+00, 0.45313300E-01, 0.31809000E+00, -.26795700E+00, -.55101500E-01, 0.11506900E+00, -.96939200E+00, 0.70669100E+00, 0.20308100E+00, -.38938800E-01, 0.62729000E+00, 0.68017200E+00, 0.75701900E-01, 0.14931200E+01, -.10270200E+00, -.10447200E+00, -.83699400E-01, -.53972700E+00, -.13296500E+00, 0.33505200E+00, 0.33549400E+00, 0.64726600E+00, -.15785400E-01, -.14803300E-01, 0.26714100E+00, -.19166400E+00, -.76970200E+00, 0.26514100E+00, 0.14486300E-02, 0.15422700E+00, 0.26951400E+00, -.19161700E-01, -.40558200E-01, 0.75169600E+00, 0.24621800E+00, 0.25258400E+00, 0.16560800E-01, 0.10036800E+01, 0.40670800E+00, -.62912500E+00, 0.45283200E-01, -.13415200E+00, -.43902400E+00, 0.12618700E+00, 0.36194600E-01, 0.47350000E-01, 0.11904900E+01, -.24407300E+00, 0.22392700E+00, -.12032600E-01, -.15262400E-01, -.59090000E+00, 0.64124000E+00, 0.19908200E+00, -.39493700E+00, 0.23776900E+00, -.10315400E+00, -.13141800E+01, 0.56371000E-01, 0.93140800E+00, 0.15931200E+00, 0.55174500E+00, 0.32248000E+00, 0.92765500E-01, -.80986500E-01, 0.69683600E+00, -.25686700E+00, 0.44603200E-01, 0.14122600E-01, -.23719000E+00, 0.48195000E+00, 0.46682300E+00, 0.50060900E+03, 0.12115100E+02, 0.70218800E+02, 0.58479800E+02, -.15226400E+02, -.35677100E+02, -.16392200E+02, -.46479300E+01, -.81578800E+01, 0.66081200E+02, -.31327000E+02, -.73854900E+01, 0.27448900E+03, -.15755800E+03, -.12984700E+03, -.96060000E+01, -.51949600E+02, -.85366200E+02, 0.52436500E+02, -.73667400E+02, -.21388800E+02, 0.10635200E+04, -.50496200E+03, -.52916100E+03, -.67926900E+02, -.13079900E+03, -.36695200E+03, 0.41179300E+01, -.41298000E+03, -.18591100E+03, 0.38884600E+02, -.17279100E+02, -.86480600E+01, -.46514200E+02, 0.10999800E+02, -.16050700E+02, 0.32931800E+02, -.94799000E+02, 0.21253600E+02, -.73684700E+03, 0.36510200E+03, 0.36921800E+03, -.68691700E+01, 0.69345000E+02, 0.19228200E+03, -.58597300E+03, 0.90740900E+02, 0.29007600E+02, -.59735200E+03, 0.30016500E+03, 0.31217000E+03, 0.15179300E+03, 0.13544800E+03, 0.16350100E+03, 0.69121500E+02, 0.68413400E+02, 0.12817900E+03, 0.27961300E+03, -.14051400E+03, -.10409900E+03, -.12554000E+03, 0.72477700E+01, -.53827400E+02, -.92821000E+02, 0.64154800E+02, -.21130800E+02, 0.41171400E+03, -.16133800E+03, -.20438300E+03, -.53763900E+02, -.21234400E+02, -.10602200E+03, -.16011100E+03, -.98409400E+02, 0.63959900E+02, -.14663700E+03, 0.60649800E+02, 0.72303500E+02, 0.41709100E+02, 0.85652100E+02, -.86173900E+01, -.35436400E+03, -.39157000E+02, 0.14216900E+03, 0.37136300E+02, 0.57985200E+02, 0.14610400E+02, -.28184400E+02, -.17089300E+02, -.59015800E+02, -.30979500E+02, 0.12544600E+02, -.31517200E+02, 0.18124000E+02, 0.28370200E+02, -.30979700E+02, 0.10407200E+02, -.20113600E+03, -.21776900E+02, 0.25209000E+02, -.77767300E+02, -.46291700E+01, -.19173500E+03, 0.19964600E+02, -.41481700E+02, -.15910400E+03, -.27687600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18676200E+01, -.60339400E+00, -.21959500E+01, -.56102100E+00, -.11485800E+00, 0.58628300E+00, -.21001800E+01, -.76078600E+00, 0.10645900E+01, 0.33353400E+00, 0.51562500E+00, -.71313500E+00, 0.27652300E+00, -.13911800E+01, 0.10076100E-01, 0.38663100E+00, -.74054300E+00, -.15442500E+00, -.37946800E+00, -.12402600E+00, -.46189100E+00, 0.71393800E-01, 0.23425900E+00, 0.53236000E-01, 0.56394500E-01, -.15463700E+00, -.77399600E-01, -.15917600E+00, -.46077200E+00, -.40214000E+00, -.24089300E+00, 0.78203300E+00, 0.26682700E+00, 0.18450300E+00, -.89659700E+00, -.64072200E+00, -.27484800E-01, 0.49065600E-01, -.24822000E+00, -.33978300E+00, 0.81712000E+00, 0.13688900E-01, -.51253800E+00, -.17574700E+00, 0.62383600E+00, -.25271300E+00, 0.44682000E+00, -.95457100E+00, -.14979700E+01, 0.14024500E+01, 0.11106500E+00, 0.78050200E-01, -.39584900E+00, -.14655100E+00, 0.27047600E+00, 0.49535700E+00, 0.18526000E+00, 0.36684100E-01, -.16328700E+00, 0.36294700E+00, -.36431500E+00, 0.62865800E-01, -.37994900E+00, -.12402100E+01, 0.33791300E+00, 0.26604000E+00, -.19033700E+00, -.91142500E-01, -.37159000E+00, 0.37414200E-02, -.26116700E+00, 0.17452700E+00, -.28937100E+00, 0.25633100E+00, -.44869900E+00, 0.18206500E+00, 0.29506900E+00, 0.10209900E+01, -.13158900E+00, 0.11130900E+01, -.33399100E+00, -.58987300E+00, -.38564400E-01, -.31485500E-01, -.12136700E+00, 0.10365000E+01, 0.25331900E+00, -.68337100E-01, 0.25386700E-02, 0.33862700E+00, -.21338800E+00, 0.18911100E+00, -.12951700E+00, 0.13889900E+01, -.44103300E+00, 0.22990700E+00, 0.45336600E+00, 0.79747900E-02, -.71446800E-01, 0.28385400E+00, 0.22601300E+00, 0.66432700E+00, -.14660000E+00, 0.52732300E+00, 0.36466200E-01, -.88375700E-01, 0.42325300E-01, 0.24363200E+00, -.27713600E-01, 0.13325700E-01, -.17800700E-01, -.15909100E+01, 0.30129700E+00, -.16737500E+00, 0.26608600E+00, 0.62885300E+02, -.28031800E+02, -.21684100E+02, 0.92219600E+01, 0.71294700E+01, -.30170600E+02, -.41849700E+02, 0.34265100E+02, 0.41174400E+02, 0.43626700E+02, -.28138600E+02, 0.33912200E+03, -.17863200E+03, -.16528600E+03, -.33514800E+02, -.19634200E+02, -.91672300E+02, -.31750900E+02, -.12305400E+03, -.70938300E+02, -.53501600E+03, 0.26212600E+03, 0.26856900E+03, -.12155800E+03, -.13729000E+03, 0.29951700E+03, 0.26369100E+03, 0.36162100E+03, -.62457300E+02, 0.13723800E+03, -.67823000E+02, -.62428800E+02, 0.50403500E+01, -.77936300E+01, -.34537200E+02, -.20084500E+02, -.60823000E+02, -.22945900E+02, 0.77355100E+02, -.40026000E+02, -.37973300E+02, -.37115900E+02, -.13783700E+02, -.28627500E+02, -.26451600E+02, -.12052900E+03, 0.23925800E+02, -.16853800E+02, 0.71420400E+01, 0.15903300E+02, 0.33033200E+02, 0.72073500E+02, 0.37853200E+01, -.57251700E+02, 0.18979200E+02, 0.24739400E+02, 0.98667300E+01, -.10643100E+02, 0.13797600E+02, 0.32854900E+02, 0.13653800E+03, -.88972900E+01, -.45420800E+02, -.41722500E+02, 0.68025900E+02, 0.45127100E+03, -.21859100E+03, -.22508900E+03, 0.75885800E+02, 0.12224200E+03, -.20106200E+03, -.12799100E+03, -.20215200E+03, 0.57750600E+02, -.16070700E+03, 0.77771900E+02, 0.79961200E+02, -.42350900E+00, -.80178000E+01, 0.61626800E+02, 0.28570500E+02, 0.13801500E+03, -.10302000E+02, -.17799200E+02, 0.71023200E+02, 0.71606200E+02, 0.20510000E+02, 0.46812500E+00, -.71613200E+02, 0.15520400E+02, 0.18985900E+01, -.59139600E+02, -.58994600E+02, -.20994800E+02, 0.20405700E+02, -.14467600E+02, -.94761800E+02, -.50021200E+01, -.39839800E+02, -.86312700E+02, -.21061300E+02, -.14499500E+03, 0.27141400E+02, -.59174100E+02, -.61016200E+02, -.23426800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.44805200E+01, -.69362700E+00, 0.58888100E+01, 0.26978400E+01, -.84433200E+01, 0.29365700E+00, 0.62207300E+01, 0.29747600E+01, 0.13362900E+00, -.89390800E-02, -.50862400E+01, 0.22095200E+01, -.99687800E+00, 0.65650700E+00, 0.13231200E+01, -.11883800E+01, 0.21950100E+00, 0.45391900E+00, -.16262500E+00, 0.42814400E+00, 0.44360100E+00, 0.69774700E-01, -.60734600E+00, -.63368100E-01, -.23270400E+01, 0.10674300E+00, 0.26509300E+01, 0.16726100E+00, -.49496900E+01, 0.12359600E+01, -.14770200E+00, 0.10413500E+01, -.12875100E+01, -.52405200E+00, 0.23028500E+00, -.57388300E+00, -.84654600E+00, 0.46719900E+00, 0.41177800E+00, 0.20783000E+01, -.40260800E+00, 0.15522200E+00, 0.97218500E+00, -.33964900E+00, -.36545700E+01, -.43177700E+00, 0.22157100E+00, 0.83797500E+00, 0.31948900E+01, 0.47711400E+00, -.34110800E+00, 0.24060700E+00, -.20381000E+00, -.53564800E-01, 0.94886500E+00, -.15394500E+01, -.51439300E+00, -.35021300E-01, 0.35931100E+00, 0.11266200E-01, 0.12464500E+00, -.58154800E-01, 0.42501500E+00, 0.50399400E+00, -.66459400E+00, -.22936400E+00, -.45572900E+00, -.17943200E+00, -.76927300E+00, -.39428000E+00, -.24823400E+00, -.13566300E+00, 0.46016800E+00, 0.18830600E-01, 0.63560300E-01, -.73458700E+00, -.84149500E+00, -.18508700E+01, -.85950600E-01, -.12249100E+00, 0.50269700E+00, -.76507700E+00, -.83350400E-01, -.54851900E-01, 0.51415600E+00, -.27943700E+01, 0.26861900E+00, 0.14930400E+01, -.32701300E+01, 0.93969400E+00, -.81234000E+00, -.24747100E-01, -.23782900E+00, -.11710700E+01, 0.45497700E+00, -.41226800E+00, 0.34019700E+00, -.85517200E+00, 0.46873600E+00, -.19618000E+00, -.64011400E+00, 0.10102400E+01, 0.19096100E+00, 0.59217300E+00, -.23309300E+00, 0.35373300E+00, 0.14029600E-01, 0.38588700E+00, 0.23355000E+00, 0.60354200E-02, -.43492200E+00, 0.43619300E+01, -.11288600E+01, 0.90860900E+00, 0.46606500E+00, 0.48957000E+00, 0.29627900E+03, -.24017400E+03, 0.10572700E+03, 0.14315800E+03, 0.13247300E+03, 0.18323300E+03, -.47211800E+02, -.20290000E+03, 0.58407200E+01, 0.17718700E+03, -.71429200E+03, 0.44572700E+03, 0.39270200E+03, 0.98487400E+02, 0.17519700E+03, 0.14306700E+03, -.24888300E+03, 0.12683700E+03, 0.55086400E+02, -.19968500E+04, 0.97803000E+03, 0.98776400E+03, 0.42206200E+03, 0.60457400E+03, 0.42772300E+03, 0.31871400E+03, 0.65409200E+03, 0.83647300E+03, -.76272200E+03, 0.37592700E+03, 0.33436000E+03, 0.65429200E+02, 0.26019800E+02, 0.22383100E+03, -.86571700E+02, 0.38587100E+03, -.56590500E+01, 0.55371100E+03, -.26728900E+03, -.28045800E+03, -.46258700E+02, -.11386400E+03, -.78855400E+02, 0.29938600E+03, 0.51638900E+02, -.35919200E+03, 0.75065200E+03, -.37580500E+03, -.42145700E+03, -.29071300E+03, -.22671100E+03, -.26584300E+03, 0.13547000E+03, -.27781400E+03, -.35004800E+03, -.56818600E+03, 0.31445500E+03, 0.14719900E+03, -.12071500E+02, -.50540100E+03, 0.29860400E+03, 0.46515300E+03, 0.27928000E+03, -.42526400E+03, -.68494800E+03, 0.22411600E+03, 0.33831700E+03, -.23527300E+03, -.29530300E+03, 0.27720600E+03, -.22098400E+03, 0.24444700E+03, -.46006700E+03, 0.58355000E+03, -.25063300E+03, -.27576000E+03, 0.58708900E+02, 0.40761900E+02, -.28582900E+03, 0.55151300E+02, -.38387700E+03, -.13295500E+02, -.44915500E+02, -.36276900E+03, -.33123600E+03, 0.32758400E+02, 0.25872700E+02, 0.36628600E+03, -.30673300E+02, -.30167500E+02, 0.11713200E+03, 0.45441300E+02, -.27863100E+02, 0.40311200E+02, 0.37475000E+02, 0.82555000E+03, 0.63973300E+02, 0.15658200E+02, 0.46941500E+03, 0.16216300E+03, 0.10028800E+04, -.36293700E+02, 0.29570800E+03, 0.43558300E+03, 0.18439900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10484400E+01, 0.23703000E+00, 0.19830800E+01, -.25299600E+00, 0.80527500E+01, 0.23246600E-03, -.73728500E+01, -.32937200E+01, -.12695000E+01, 0.72615200E-01, 0.35235700E+01, -.16430600E+01, 0.25708500E+01, -.13515400E+01, -.39992800E+00, 0.83878300E+00, 0.29760200E+00, -.34164500E+00, -.22847800E+01, 0.41881000E+00, -.47391300E+01, 0.48339300E+00, -.95319700E+00, 0.18166100E+00, 0.23509200E+00, -.72149100E+00, 0.33853000E-01, 0.47528600E+00, -.12806200E+01, 0.37005000E+00, 0.52721700E+00, 0.11679200E+01, -.85376700E+00, -.68712900E+00, -.19232700E-01, -.55670800E+00, -.12345100E+00, 0.62523500E+00, -.34147600E+00, 0.92304500E+00, 0.26126200E+00, 0.18926200E+00, 0.37330700E+00, -.67351000E-01, -.59121200E+00, 0.74221000E+00, -.11491200E+00, 0.88925800E+00, -.15493600E+01, 0.22009000E+00, 0.92734100E-01, -.12469600E+00, 0.38537300E+00, -.16288600E+01, -.22134100E+00, -.50858400E+00, -.33677100E+00, -.33852800E-01, -.24293400E+00, 0.15354000E+01, 0.53959000E+00, 0.96799200E+00, -.75123200E+00, -.34914100E+01, 0.32207400E+00, -.44610700E+00, 0.44083400E+00, 0.45610300E-01, 0.52621500E+00, 0.96287600E-01, 0.40208700E+00, -.57474100E-01, 0.28014200E+00, -.16141800E+00, 0.52166200E+00, -.15696800E+00, -.33299000E+00, -.98322100E+00, -.12627800E+00, 0.20439000E+00, -.27547800E+00, -.25411100E+00, 0.71524200E-01, -.15171600E+00, 0.21193300E+00, -.22432100E+01, 0.71698900E-01, 0.11704300E+01, -.10955000E+01, 0.46976900E-02, -.41846100E+00, 0.69742500E+00, 0.46630200E+00, -.25714400E+01, 0.55189200E-02, 0.33044500E+00, 0.20406000E+00, 0.43726300E+00, -.13600200E+00, 0.45684200E-03, -.29942500E+00, 0.29066700E+00, -.31127500E+00, 0.11566800E+01, -.79144200E-01, 0.98067100E-01, 0.43629200E-01, -.13050000E+00, -.66542900E-01, -.26327600E-01, 0.14939600E+00, -.12451300E+01, 0.10278800E+00, -.45091200E+00, -.19531500E-01, 0.69472700E+00, 0.47922200E+00, 0.12903900E+03, -.55139300E+02, -.75781300E+02, -.23682900E+02, -.40387200E+02, -.66295800E+01, 0.69652500E+02, -.44867300E+02, -.51541700E+02, 0.80791100E+02, -.87771100E+02, -.62777800E+02, -.48823200E+02, -.15729300E+03, 0.89512000E+02, 0.28436500E+03, 0.91108400E+02, -.48701200E+02, 0.19337500E+04, -.95167800E+03, -.96102100E+03, 0.17881000E+02, -.13373100E+03, -.68653100E+03, -.48174600E+03, -.83149800E+03, -.37789300E+03, 0.28071300E+03, -.13747200E+03, -.11568500E+03, -.58603800E+02, -.15871000E+02, -.57742700E+02, 0.12412500E+03, -.11854000E+03, 0.65737100E+01, -.88614700E+02, 0.39816800E+02, 0.45901300E+02, 0.90484200E+02, 0.65718400E+02, -.22681900E+02, -.11666600E+03, -.75161500E+02, 0.93711800E+01, -.70898800E+03, 0.35510800E+03, 0.37475000E+03, 0.24919100E+03, 0.16102000E+03, 0.21135900E+03, 0.54929000E-01, 0.19002900E+03, 0.19722700E+03, 0.33539300E+03, -.18421100E+03, -.99965800E+02, -.24722900E+02, 0.17928500E+03, -.13919300E+03, -.12986500E+03, -.62460600E+02, 0.56505800E+02, -.14939200E+02, 0.71019000E+02, 0.95548400E+01, 0.26497500E+02, 0.13424400E+03, 0.49901800E+02, 0.27304400E+03, 0.52231400E+02, 0.29599700E+03, -.23994100E+02, -.11164400E+02, 0.16814600E+01, -.27598600E+02, -.18035900E+02, 0.34572900E+02, -.80646400E+02, 0.42995500E+02, 0.17736700E+02, 0.42241900E+02, 0.14838600E+03, 0.89990800E+02, -.65056600E+02, -.95544400E+01, -.14936800E+03, -.78626800E+01, 0.10927100E+02, 0.39738600E+02, 0.82075800E+02, 0.42984700E+02, -.70417200E+02, 0.24844800E+01, -.23697500E+03, -.27112300E+02, 0.91571900E+02, -.15460000E+03, -.46940400E+02, -.22901200E+03, -.24597000E+01, -.98313600E+02, -.16867800E+03, -.64962400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36490400E+01, -.10300500E+01, 0.32261400E+01, 0.14066400E+01, -.50238800E+01, -.28993300E-01, 0.68084400E+01, 0.24608800E+01, 0.40303200E+00, -.78800000E+00, -.16523900E+01, 0.18405700E+01, -.16047500E+01, 0.18633100E+01, 0.67339800E+00, -.87351600E+00, -.63695000E+00, 0.15395300E+00, 0.13163600E+01, 0.52431600E+00, 0.35559700E+01, -.58242600E-01, 0.33922500E-01, -.23892200E+00, -.41240000E+00, 0.60814800E+00, -.40156200E-01, -.71946200E+00, -.58460200E+00, 0.72505200E+00, -.38866200E+00, -.17941700E+00, -.17041500E+00, 0.35294800E+00, 0.81758300E+00, -.74978700E+00, -.71608000E-01, -.46907300E+00, 0.11757100E+01, 0.13333900E+00, 0.35179900E+00, -.61269200E-01, 0.29940700E+00, 0.39802100E+00, -.11166000E+01, -.47732400E+00, 0.51581000E+00, -.58125300E+00, -.48090900E+00, 0.10216400E+01, 0.53601700E-01, 0.48034000E-01, 0.47084300E+00, -.23976200E+00, -.26741600E+00, 0.76212700E-02, 0.15736300E+00, -.12328400E+00, -.52989600E-01, -.27485900E+00, 0.14829500E+00, 0.10282600E+01, -.42785200E+00, -.11120100E+01, 0.56735300E+00, 0.51758800E+00, 0.71615300E+00, -.26155300E+00, -.56262100E+00, -.90516100E-01, -.13724100E-01, 0.40643700E+00, 0.35642700E+00, 0.33417400E+00, -.78900800E+00, 0.41151500E+00, 0.41110000E+00, 0.13011300E+01, -.81451500E-01, 0.73390100E+00, 0.23995300E+00, -.56844700E+00, -.55068900E-01, -.46438600E-02, -.30931200E+00, -.11189700E+00, 0.46852600E-01, 0.19965500E+00, -.27292400E+00, 0.42073700E+00, -.26168100E+00, -.30542800E-01, -.12950500E+00, -.19418300E+00, 0.13842300E+00, -.67380000E-01, -.12316800E-01, -.38564300E+00, 0.14485000E+00, -.56237400E+00, 0.47174400E+00, 0.35207700E+00, 0.22193700E+00, 0.42969200E+00, -.10175300E+00, 0.31154700E+00, 0.23734500E-02, 0.17329200E+00, -.27234200E-01, 0.17405100E-01, 0.14460400E+00, 0.11159600E+00, 0.10451300E+01, -.81909100E-01, 0.46886000E+00, 0.72214200E+00, -.28244700E-01, -.13408400E+00, 0.34555500E+02, -.36429100E+01, -.15509400E+02, -.61444200E+01, 0.86943600E+01, -.64288200E+01, 0.14751700E+02, -.92107800E+01, 0.18986100E+03, -.11014800E+03, -.10640000E+03, -.37706700E+02, 0.36226400E+02, -.61441300E+02, -.36614500E+02, -.11115100E+03, -.19393500E+01, 0.50376000E+02, -.30723600E+02, -.25675800E+02, 0.36376600E+01, -.11333800E+02, 0.18876000E+02, 0.27989600E+02, 0.68499200E+02, -.55596500E+02, 0.47937000E+02, -.23544800E+02, -.18013600E+02, -.12158000E+02, -.13766100E+02, -.10569500E+02, -.31836100E+01, -.32788300E+02, -.15975100E+02, 0.19179100E+02, -.11282900E+02, -.91904200E+01, -.11513400E+02, 0.98300900E+01, -.43086600E+01, 0.32653600E+02, -.15974700E+01, 0.22137900E+00, -.34709200E+02, 0.17860100E+02, 0.25924700E+02, 0.12636100E+02, 0.71044900E+02, 0.15936300E+02, 0.47729300E+02, 0.39625600E+02, 0.58173600E+02, 0.20910500E+03, -.11285500E+03, -.89557500E+02, -.55702100E+02, 0.34995100E+02, -.57648800E+02, 0.12561400E+02, -.54402000E+02, -.21595100E+02, 0.15569600E+03, -.42064600E+02, -.77435800E+02, 0.38447400E+01, 0.40025500E+01, -.73959200E+02, -.66670100E+02, -.12306900E+03, 0.22911700E+02, -.13968400E+03, 0.63867300E+02, 0.70307200E+02, 0.39223800E+02, 0.39879600E+02, 0.12589600E+02, -.90338700E+02, 0.21325500E+02, 0.42088600E+02, -.23939800E+01, 0.24413400E+02, -.17313400E+02, 0.26905300E+02, -.14425200E+00, -.24271500E+02, 0.37950500E+01, -.11616700E+01, 0.74114700E+01, 0.31257800E+02, -.13171500E+02, 0.25162400E+02, -.23142500E+01, -.37353400E+02, 0.20636700E+01, -.36765500E+00, -.59424200E+02, -.83645100E+01, -.36332100E+02, 0.22319700E+02, -.82196700E+00, -.23593600E+02, -.86580700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11203900E+02, -.15489400E+01, 0.97299200E+01, 0.49633200E+01, -.33274400E+02, -.76653800E-01, 0.34788000E+02, 0.16662600E+02, -.18658300E+00, -.25980100E+01, -.12583900E+02, 0.63421500E+01, -.82514300E+01, 0.84063700E+01, 0.38286000E+01, -.61518700E+01, -.18867800E+01, -.53063400E+00, 0.42202600E+01, -.25212000E+01, 0.15221800E+02, 0.18924900E+01, -.23053400E+00, -.10731800E+01, -.54149300E+00, 0.32519200E+01, -.38616000E+01, -.42796300E+00, -.39192700E+01, 0.55030500E+01, -.14347100E+01, -.46284600E+00, 0.44180300E+00, 0.87025000E+00, 0.32364700E+01, -.58876700E-01, 0.57557200E+00, -.11670100E+01, 0.12280600E+01, -.12571200E+01, -.29626400E+01, -.11801200E+01, 0.55596600E+01, 0.14840200E+01, -.55758800E+01, -.61513600E+01, 0.15663600E+01, -.29098600E+01, 0.77804700E+01, 0.38270600E+01, -.60602700E+00, 0.13212800E+01, -.24750600E+00, 0.97840700E+00, 0.27435500E+01, -.58643300E+01, 0.29263800E+00, 0.34018500E+00, 0.15089700E+01, -.52449200E+00, 0.11703200E+01, 0.41276100E+01, -.30798600E+01, -.67524400E+01, -.34624200E+00, 0.16223100E+01, 0.51085500E+01, -.12127300E+01, -.21175600E+01, -.80011600E+00, 0.34259700E+00, 0.27639100E+00, 0.19005500E+01, 0.87750700E+00, -.22882800E+01, 0.48340400E+01, 0.11896200E+01, -.14378200E+01, 0.87524400E+00, 0.56878900E+01, 0.69861800E+00, -.25293100E+01, -.18290400E-01, -.51588900E+00, 0.33402400E+00, 0.12377100E+01, -.55123200E+00, -.10276600E+01, 0.42789900E+00, -.25868400E+01, -.30137900E+00, -.54866100E+01, 0.39856400E+00, -.61801700E+01, 0.97649400E+00, -.32504600E+01, -.35211600E+00, -.14885700E+01, 0.19068600E+01, -.80351600E+01, -.30369800E+01, 0.44121400E+01, -.22100000E+01, -.67602600E-01, -.79032600E+00, 0.61661200E+00, 0.61225400E+00, 0.64635400E+00, -.12802100E+01, -.22635600E+00, 0.20806800E+01, 0.10844100E+02, 0.26152700E+01, 0.51498500E+01, 0.27587500E+01, -.78753400E+01, -.12645300E+01, -.39335600E+01, -.19927900E+01, -.66932400E+02, -.46346400E+03, -.51888000E+03, 0.38715600E+03, 0.47807000E+03, 0.45003900E+03, -.46219900E+03, 0.44182500E+04, -.24971500E+04, -.22477500E+04, -.64276400E+03, -.16376600E+03, -.10026300E+04, -.87074400E+02, -.18784100E+04, -.83016300E+03, -.33585600E+03, 0.11692400E+02, 0.19913300E+03, -.93484800E+03, -.16609500E+04, 0.14266100E+04, 0.22913700E+04, 0.20592100E+04, -.18535200E+04, 0.22480600E+04, -.11346100E+04, -.98800900E+03, -.25606600E+03, -.22152600E+03, -.48418000E+03, 0.13603700E+03, -.83553000E+03, -.41917100E+03, -.43898300E+03, 0.20615700E+03, 0.22816700E+03, 0.64136000E+01, 0.23147400E+03, 0.86601300E+02, 0.21114400E+03, -.32365800E+02, 0.88283500E+02, -.32926400E+04, 0.17103300E+04, 0.17544700E+04, 0.12922700E+04, 0.18553600E+04, 0.92413200E+03, -.31659200E+02, 0.10733300E+04, 0.10334400E+04, 0.24694900E+04, -.12974700E+04, -.87082400E+03, -.36222000E+03, 0.18648700E+04, -.94028000E+03, -.97074400E+03, -.11179100E+04, 0.49855300E+02, 0.75586900E+04, -.34528900E+04, -.37675400E+04, 0.75733200E+03, 0.19686700E+04, -.32827900E+04, -.21156300E+04, -.38974000E+04, 0.15683300E+04, -.24599600E+04, 0.11647900E+04, 0.11829100E+04, 0.36421100E+03, 0.33492500E+03, 0.56903100E+03, -.48968100E+03, 0.10670100E+04, 0.43046300E+03, -.39339900E+02, 0.13380600E+04, 0.62460900E+03, 0.19195800E+03, -.62754200E+02, -.13418600E+04, 0.14022800E+03, 0.82107000E+02, -.24464500E+03, 0.53168700E+02, -.20191800E+03, 0.16773700E+03, -.11021500E+03, -.19920900E+04, -.15314200E+03, -.11422200E+03, -.17052300E+04, -.29770100E+03, -.19784300E+04, 0.50323500E+03, -.77319700E+03, -.13293900E+04, -.24317100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.38844700E+01, -.98093500E+00, 0.26537700E+01, 0.18554800E+01, -.15026800E+02, 0.16740200E+00, 0.17399100E+02, 0.95247800E+01, -.21027100E+01, -.12696200E+01, -.48889000E+01, 0.30190800E+01, -.39030500E+01, 0.40321200E+01, 0.17524900E+01, -.16726400E+01, -.69758600E+00, 0.45099800E+00, 0.23477900E+01, -.30803300E+01, 0.58386000E+01, 0.72019200E+00, 0.32543300E+00, -.13818800E+01, -.18969600E+00, 0.15381000E+01, 0.15402600E+01, -.42501600E+00, -.83675900E+00, 0.17455300E+01, -.77835500E+00, 0.61451000E+00, -.15272100E+00, -.22617200E+00, -.26126900E+00, 0.69609400E+00, -.12933600E+00, 0.56793500E+00, -.22005700E+01, -.88430100E+00, -.54424100E+00, -.16262300E+00, 0.31972400E+00, 0.12097300E+00, -.21393700E-01, -.33195200E+00, -.26440700E+00, 0.86227800E+00, 0.22316600E+01, 0.60772900E+00, -.12619700E+00, 0.10024900E+00, 0.33131500E+00, 0.25171700E+01, 0.96641700E-01, 0.53680700E+00, 0.33438500E+00, -.42436900E+00, 0.21988600E+00, 0.31839000E+00, 0.30794800E+00, -.24039300E+01, 0.11041000E+01, 0.38288500E+01, -.17613100E+01, -.41496600E+00, -.16235500E+01, 0.10452800E+01, 0.29402500E+01, 0.31100700E+00, -.26887000E+01, -.10721200E+01, -.12711100E+01, 0.61666800E-01, -.71152500E+00, -.11330600E+01, -.37124800E+00, 0.36390800E+00, 0.47882900E+00, -.14100300E+01, 0.47760700E+00, 0.26047400E+00, -.23735700E-01, 0.15042500E+00, -.62564600E+00, -.10067500E+01, 0.30170700E+00, 0.72550800E+00, -.13158400E+00, 0.26896000E+01, -.22491200E+00, 0.47906800E+00, -.51044600E-01, -.52848900E+00, 0.56110400E+00, 0.17225700E+00, 0.16966200E-01, -.10090800E+01, -.18409000E+00, -.24000900E+01, 0.15807400E+01, 0.26653000E+01, 0.10408700E+01, 0.12796800E+00, -.15040700E+00, -.59665500E-01, 0.20736600E-01, 0.16255300E+01, -.24272500E+00, 0.83882500E-02, -.31722000E+00, -.20780600E+01, 0.81325700E-01, 0.15133800E+01, 0.13205100E+01, -.47497400E-01, -.90143500E-01, -.15744800E+01, -.12555100E+00, 0.24547500E+00, 0.11665600E+03, 0.99910900E+02, -.70570900E+02, -.70797600E+02, -.10415300E+03, 0.69141000E+02, -.89744300E+03, 0.47125700E+03, 0.43758000E+03, 0.43604900E+02, -.18830000E+03, 0.36857900E+03, 0.38602600E+03, 0.52456900E+03, 0.32339500E+02, 0.14856400E+04, -.71619200E+03, -.74079100E+03, 0.43071000E+03, 0.33380800E+03, -.93967200E+03, -.12175500E+04, -.12109300E+04, 0.14366600E+03, -.29575300E+03, 0.15150500E+03, 0.15082200E+03, -.31552700E+01, -.10944900E+02, 0.12049100E+03, 0.20760400E+03, 0.19030600E+03, 0.47035000E+02, -.38899200E+02, 0.19672600E+02, 0.19458300E+02, 0.10105800E+03, -.30028500E+02, -.13051500E+02, -.16485100E+03, 0.53580100E+01, -.35493200E+02, 0.58928700E+02, -.44016500E+02, -.31396200E+02, -.74507600E+02, -.28654500E+03, 0.48787700E+02, 0.15079000E+03, 0.91805300E+02, -.57551400E+02, -.18695900E+03, 0.92533700E+02, 0.99414400E+02, 0.59910000E+02, -.25523100E+03, 0.16680900E+03, 0.42324600E+03, 0.24936200E+03, -.20351600E+02, -.16165700E+04, 0.79395800E+03, 0.80785400E+03, -.12400600E+03, -.27917900E+03, 0.79881300E+03, 0.97910100E+03, 0.93652700E+03, -.10898700E+03, 0.49354800E+03, -.24773700E+03, -.25129900E+03, -.76717000E+02, -.76628000E+02, -.11936700E+03, 0.96289700E+01, -.22127700E+03, -.79285100E+02, 0.21027200E+02, -.25827500E+03, -.12595300E+03, -.11158400E+03, 0.24759000E+02, 0.25893000E+03, -.31717300E+02, -.28533700E+02, 0.20795500E+03, 0.17229900E+03, 0.84104700E+02, -.11524600E+03, 0.30103300E+02, 0.29956500E+03, 0.23126300E+02, 0.17301100E+03, 0.29538100E+03, 0.70520400E+02, 0.31511700E+03, -.12516200E+03, 0.12017700E+03, 0.31850500E+03, -.16251800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37317600E+01, 0.28752900E+00, 0.48183700E+01, 0.12878100E+01, -.13634200E+00, -.10270500E+00, 0.39639400E+01, -.49064000E+00, 0.98910000E+00, 0.51221600E-01, -.17238800E+01, 0.14633700E+01, -.75070200E+00, 0.40601500E+01, -.75308400E+00, 0.11783000E+01, -.13040700E+01, 0.13629600E+00, 0.68851300E-01, 0.13683200E+01, 0.11738800E+01, -.51114200E+00, -.24740000E+00, 0.30391500E+00, -.23027000E+01, 0.46190100E-01, 0.28080600E+01, -.73771300E-01, -.29731300E+01, 0.28809800E+00, 0.27991700E+00, 0.14818100E+01, -.23795500E+01, -.10501000E+00, -.30163200E+00, 0.13192100E-01, -.11390300E+00, -.21498700E+00, -.83226100E+00, 0.13135300E+01, -.76055000E+00, 0.15656000E+00, -.53622900E+00, 0.18793400E+00, -.11687900E+01, -.70355000E+00, -.57994200E-01, 0.81657800E+00, 0.28000000E+01, -.19863500E+00, -.26959900E+00, 0.23162300E+00, -.31628300E+00, -.55954700E+00, 0.20610500E+00, -.15288500E+01, -.16881500E+00, 0.26312800E-01, 0.52119200E+00, -.52877900E+00, -.19760800E+00, -.39103800E+00, 0.10273900E+01, 0.12971900E+01, -.36186700E+00, -.21778100E+00, -.62756700E+00, 0.10436600E+00, 0.64732500E+00, 0.13180600E+00, 0.50497400E+00, -.69332900E-01, -.80140500E+00, -.13045900E+00, 0.34894700E+00, 0.56659700E-01, 0.15102700E-01, -.62616800E+00, 0.15971500E+00, -.11047300E+01, 0.43135600E+00, -.20780900E+00, 0.93403000E-01, -.51374200E-01, -.35881100E+00, -.27717700E+00, 0.46740000E-01, 0.89639100E-01, 0.33695100E+00, 0.72135700E+00, -.59773700E-01, 0.53440600E+00, -.35322700E+00, -.87683600E-01, 0.53236400E+00, -.27814300E+00, -.56640600E-01, -.26981900E+00, 0.10201800E+00, -.14986500E+00, -.70830700E+00, 0.25485700E+00, 0.33898800E+00, -.10345800E+01, 0.18750200E-01, -.82200400E-01, -.13677500E+00, 0.76248200E+00, 0.19435800E+00, 0.67184800E-01, 0.21631300E-01, -.49851600E-01, 0.40742700E+00, 0.35938700E+00, 0.42911600E+00, -.18086400E+01, -.22304700E+00, -.42615600E+00, 0.13473200E+00, 0.10253500E+00, 0.46156200E-01, -.27393200E+02, 0.10929200E+02, 0.37269100E+02, 0.21626100E+02, -.58347700E+01, 0.88775500E+01, 0.18323300E+02, 0.14809700E+01, 0.32928800E+02, -.30344500E+02, 0.68746900E+01, 0.38853200E+02, 0.65445100E+02, -.20200300E+02, -.43009000E+03, 0.23130100E+03, 0.21514400E+03, -.98506500E+02, -.67109600E+02, 0.23532700E+03, 0.27056000E+03, 0.26697900E+03, 0.24711600E+02, 0.51480700E+02, -.19428900E+02, -.24535000E+02, 0.58388800E+02, 0.35553800E+02, -.42553800E+02, -.39824500E+02, -.70288700E+02, 0.34755000E+02, 0.34420300E+03, -.17514600E+03, -.17183500E+03, -.37545500E+02, -.48158400E+02, -.94207400E+02, -.14702100E+02, -.72299500E+02, -.51585300E+02, 0.29185600E+03, -.16369700E+03, -.14749500E+03, -.82294100E+01, -.49042100E+02, -.96900900E+02, -.68676300E+02, -.43083700E+02, -.82998800E+02, -.22236300E+03, 0.83873200E+02, 0.11121400E+03, 0.15135300E+03, 0.10789000E+03, 0.47515500E+02, 0.12888100E+02, 0.32518400E+01, 0.13908600E+03, -.11467500E+02, -.40996500E+02, 0.51042400E+01, 0.64734900E+02, 0.12233200E+03, -.19618000E+02, -.12913900E+02, 0.62692700E+01, 0.69293000E+02, 0.73171100E+02, -.41650000E+02, -.37097900E+02, -.11953800E+03, -.15482300E+03, 0.92118900E+02, 0.16756200E+03, 0.24456500E+03, -.17455500E+03, -.49906400E+02, 0.20118000E+02, 0.80094500E+02, -.47693800E+01, 0.24047800E+02, -.20128900E+02, 0.24222500E+02, -.21673400E+02, -.65266100E+02, -.92113200E+02, -.21318700E+02, -.42090200E+01, -.23470500E+02, 0.40171800E+02, 0.19072400E+02, -.43866100E+02, 0.21760300E+02, -.36711200E+02, 0.33818700E+02, -.11762300E+02, -.30062100E+02, -.21743100E+02, -.65423200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.61971900E+01, -.75199000E+00, 0.61330300E+01, 0.24997000E+01, -.12029300E+02, -.66779200E+00, 0.11145100E+02, 0.41178300E+01, -.16441000E+01, -.28487600E+01, -.35989600E+01, 0.40899000E+01, -.15964800E+01, 0.51767700E+01, 0.20895600E+01, -.23042900E+01, -.86125800E+00, -.26357100E-01, 0.20022700E+01, -.34216300E+00, 0.58354400E+01, 0.11877400E+01, -.14106600E+00, 0.57642000E+00, -.83364500E+00, 0.16092700E+01, -.24776500E+00, 0.44012700E+00, -.28444700E+00, 0.28507200E+01, -.46167300E+00, -.18575300E+01, -.29861700E+00, -.15898400E+01, 0.66030400E+00, -.25369800E+00, -.14295700E+00, -.33686800E+00, -.14364700E+01, -.12623400E+01, -.57424600E+00, -.29398400E+00, 0.54941800E+00, 0.71843100E+00, -.12150200E+00, -.15951100E+01, 0.14445800E+00, 0.75346400E+00, -.10117400E+01, 0.30356600E+01, 0.64565700E+00, 0.49207700E+00, 0.40097400E+01, 0.30097200E+01, 0.17578200E+01, 0.23618700E+01, 0.15599400E+01, -.11251000E+01, -.21804800E+00, -.43233500E+00, 0.61513800E+00, -.34889800E+01, 0.25829500E+01, 0.56318600E+01, -.69933200E+00, 0.17431800E+01, -.35545600E+00, -.91640900E-02, 0.14154300E+00, -.44197000E+00, -.29271600E+00, -.40796700E+00, 0.61369200E+00, 0.34771300E+00, -.80721100E+00, 0.25917300E+01, 0.52259000E+00, 0.44061100E+00, 0.51510400E+00, 0.28454100E+01, -.36073300E+00, 0.22872400E-01, 0.19855700E+00, -.41439500E+00, -.46132500E+00, -.14712000E+01, -.71939500E-02, -.84488300E-01, 0.32806300E+01, -.22018800E+01, 0.75829300E+00, 0.13056600E+00, 0.24920700E+00, 0.10997600E+01, 0.12376700E+01, 0.75972800E+00, -.65116400E+00, 0.59741200E+00, -.44054100E+00, -.14475300E+01, -.82807600E+00, 0.28539100E+01, 0.16007500E-01, 0.18972700E+01, 0.79962700E+00, -.31012400E+00, -.97975200E-01, 0.85305200E+00, -.37089200E-01, 0.12074900E+00, 0.21304500E+00, -.54719500E+01, 0.92127700E+00, 0.33856400E-01, 0.49208600E+00, -.12234000E+01, -.44192100E+00, -.90873900E-01, 0.85688400E+00, 0.83537100E-01, 0.12753200E+00, 0.15945100E+01, 0.20328200E+02, 0.60041100E+02, -.12861300E+02, -.74578000E+01, 0.14375200E+03, -.81565700E+02, -.91273300E+02, 0.58693000E+02, 0.67371700E+02, -.10288600E+03, -.14156800E+03, -.13015200E+03, 0.17764400E+02, 0.23405200E+03, -.79920200E+02, -.12089200E+03, -.71544700E+02, -.11978700E+03, -.24075100E+02, 0.19024100E+03, -.10755800E+03, -.10697800E+03, 0.79316400E+01, -.45708200E+01, -.48811300E+01, -.25299700E+02, -.29889900E+01, 0.19192600E+02, -.28439100E+01, -.10395500E+01, -.90787300E+01, -.38075800E+03, 0.18982500E+03, 0.18986000E+03, -.37808300E+01, 0.43155600E+02, 0.12073600E+03, 0.17804300E+02, 0.66327200E+02, 0.57760600E+02, -.49396100E+03, 0.25984300E+03, 0.24444000E+03, -.21212700E+02, 0.85889300E+02, 0.15881700E+03, -.15762100E+02, 0.11515500E+03, 0.62146300E+01, -.73720300E+02, 0.65085600E+02, 0.20174100E+02, -.12957300E+03, 0.88430500E+01, -.26719500E+02, -.26211600E+03, 0.15110800E+02, -.11438500E+03, 0.76663300E+03, -.36003300E+03, -.38276200E+03, -.48349000E+02, 0.66092200E+02, -.32937600E+03, -.38122700E+03, -.32827100E+03, 0.27442700E+02, 0.22127800E+03, -.11481300E+03, -.10841500E+03, -.50064600E+01, -.15810200E+02, -.94940200E+02, -.57324000E+01, -.72290100E+02, 0.22421400E+02, 0.47209300E+02, 0.38613200E+02, -.25258200E+02, 0.18749900E+01, -.15827900E+02, -.39160800E+02, -.15202700E+02, 0.15512300E+02, 0.23890000E+02, 0.21255300E+02, 0.21809000E+02, 0.58013800E+00, 0.11431400E+02, -.15061300E+03, -.18182900E+02, -.46521000E+02, -.76598700E+02, 0.17636900E+02, -.15427800E+03, 0.38221900E+02, 0.24961300E+01, -.12052600E+03, 0.32944900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.29460000E+01, 0.42225200E+00, 0.34962600E+01, 0.13105600E+01, -.34238900E+01, -.29117800E+00, 0.46062500E+01, 0.20112400E+01, -.12089500E+01, -.58260000E+00, -.14636900E+01, 0.13159200E+01, -.64874200E+00, 0.14757200E+01, 0.62550700E+00, -.64017500E+00, 0.95872700E-01, 0.54532900E-01, 0.26170800E+00, -.99795900E+00, -.66366600E-01, 0.43658400E+00, -.37132800E+00, -.38081100E+00, -.32222600E+00, 0.22961000E+00, 0.25529400E+00, 0.11756300E+00, -.12835500E+01, 0.63259900E+00, 0.81883800E-01, 0.89129900E-01, -.70277400E+00, -.48618200E+00, 0.59104800E+00, -.33327000E+00, 0.14461500E+00, 0.27053600E+00, 0.79305000E-01, 0.45740400E+00, 0.13270900E+01, 0.15552700E-01, -.99818700E+00, -.43391700E+00, 0.61826900E+00, -.90294100E+00, 0.56562100E+00, -.15919200E+01, -.19987200E+01, 0.88637800E+00, 0.41430900E+00, 0.25743400E+00, 0.41880600E+00, -.75230300E+00, 0.27449400E+00, 0.16377900E+00, 0.10898300E+00, 0.70657200E-01, -.19114600E+00, 0.25796800E+00, 0.12102500E+00, 0.11556000E+01, -.16676200E+01, -.26149700E+01, 0.11327000E+01, 0.46551000E+00, 0.12855200E+01, -.30658800E+00, -.74340800E+00, 0.41016900E+00, 0.17854700E+00, 0.66122300E+00, 0.48623100E+00, 0.25874100E+00, -.57232200E+00, 0.82101300E+00, 0.44316900E+00, 0.67431800E+00, -.10074500E+00, 0.45060000E+00, -.32049700E+00, -.97288700E+00, -.23661300E-01, -.71665100E-01, 0.12266000E+00, 0.51818700E+00, -.65989700E-01, -.23265900E+00, -.20064500E+00, -.38147000E+00, -.38843000E+00, 0.13815700E+00, 0.20380500E-01, 0.43558000E+00, -.10414000E+00, 0.68047700E-01, 0.38190400E+00, -.91702400E-01, 0.48290200E-01, -.36009200E+00, 0.17361500E+00, 0.10876200E+01, -.11563100E+00, 0.84332200E+00, 0.70393600E-01, -.66697100E-01, 0.10871200E+00, -.43138300E+00, 0.82454100E-02, -.41807200E-01, 0.36995600E-01, -.12909700E+00, 0.11884500E+00, -.28917100E+00, -.73589700E-01, 0.85638600E+00, 0.11282300E+00, 0.41374200E+00, 0.16982600E-01, -.31925100E-01, -.70760800E-01, 0.69849600E-01, 0.24403700E+00, -.30300200E+02, -.84372800E+01, -.17227200E+01, -.39288600E+02, 0.34448100E+02, 0.17766700E+02, -.14889400E+02, 0.60921100E+02, -.13870200E+02, -.38155500E+02, -.36232300E+02, 0.60570400E+02, 0.41242100E+02, -.29301100E+02, -.20592600E+02, 0.15171500E+02, 0.20445600E+02, -.35880300E+02, -.16716900E+03, -.88379700E+02, 0.18296200E+02, 0.17445500E+02, -.10381300E+02, -.88064300E+01, -.11147900E+02, -.17881200E+02, -.31055000E+01, -.75417500E+01, 0.55362000E+01, -.18303800E+02, -.11622800E+03, 0.60672700E+02, 0.58041500E+02, 0.38723300E+01, -.75127000E+00, 0.37141600E+02, 0.78711400E+01, 0.38409800E+02, 0.85911500E+01, 0.77493600E+02, -.37228300E+02, -.38467800E+02, -.46115200E+02, 0.61591900E+01, -.20142000E+02, -.34251400E+01, -.31337800E+02, 0.36110700E+02, 0.14781200E+03, -.65988900E+02, -.73839100E+02, -.24241700E+02, -.25563200E+02, -.44990600E+02, -.40277700E+01, -.56468900E+02, 0.38445200E+01, -.31175500E+03, 0.14358400E+03, 0.15551300E+03, -.26289800E+02, -.92572900E+02, 0.12597200E+03, 0.11794300E+03, 0.13507800E+03, -.48039900E+02, -.11000200E+03, 0.63306800E+02, 0.54955000E+02, 0.38784800E+02, 0.41162100E+02, 0.16890500E+02, -.72496000E+01, -.32294600E+02, 0.53798200E+02, 0.32938500E+01, -.84652700E+01, -.20012800E+02, 0.20630900E+02, -.41712300E+01, 0.84226400E+01, 0.18891100E+01, 0.38126000E+01, 0.28212900E+02, 0.38014800E+02, -.11089700E+01, 0.21241800E+02, 0.12430700E+01, 0.88419100E+01, 0.21830400E+01, -.97874400E+00, 0.28881900E+02, -.69374200E+00, 0.11890300E+02, 0.39314300E+01, 0.12249900E+02, 0.42377300E+02, 0.68373500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.58746000E+01, 0.10465800E+01, 0.81823800E+01, 0.31831900E+01, -.15576800E+02, 0.28848800E+00, 0.15384800E+02, 0.71570900E+01, -.16408300E+00, -.12224800E+01, -.56875100E+01, 0.26674200E+01, -.32298100E+01, 0.22800700E+01, 0.15110100E+01, -.31489900E+01, -.84100100E+00, -.73193500E+00, 0.67455100E-01, -.22090800E+01, 0.36221500E+01, 0.64609000E+00, -.74420700E+00, -.15515500E+01, -.71357200E+00, 0.70223200E+00, -.14753300E+01, -.66071900E+00, -.41037700E+01, 0.13997700E+01, -.55769200E+00, 0.18023800E+01, -.63791800E+00, 0.17274600E+01, 0.23389300E+01, -.99674100E+00, 0.57591800E-01, 0.27203100E-01, 0.23579300E+01, 0.13973600E+01, 0.11165500E+01, -.18943500E+00, 0.31698400E+00, -.15802400E+00, -.42836000E+01, -.32403700E+01, 0.83731700E+00, -.13829400E+01, 0.32459000E+01, 0.23787300E+01, -.41510100E-01, 0.57602700E+00, 0.15807100E+01, 0.29297100E+00, 0.79652500E+00, -.22142900E+01, -.58790700E+00, -.33888300E+00, 0.92178600E+00, -.80745700E+00, 0.32641200E+00, 0.14944100E+01, -.37195500E+00, -.41366800E+00, 0.65759200E+00, 0.10973700E+01, 0.27936400E+00, -.45765200E+00, -.11629900E+01, 0.23944400E+00, -.77834700E+00, 0.60390300E+00, 0.20215500E+00, 0.71181800E+00, -.19812500E+01, -.22517200E+00, 0.52928200E+00, 0.41956000E+01, -.34430100E+00, 0.62598900E+00, 0.80355100E+00, -.31018100E+00, -.73009800E-02, 0.14688500E+00, -.10343600E+01, 0.84857500E+00, 0.39742600E+00, -.13098600E-01, -.51494400E-02, 0.22127300E+01, 0.36700800E-01, 0.33939000E+00, -.10826800E+01, 0.47073700E+01, -.10545200E+01, 0.29572100E+00, 0.88162400E+00, -.15871000E+01, 0.39413900E+00, 0.97396100E+00, 0.14087300E+00, -.87126900E+00, -.32980700E+00, 0.37896600E-01, -.76308400E+00, 0.31968600E+00, 0.19412000E+00, 0.10980600E+01, 0.95371200E+00, -.12571400E+00, -.54937300E-01, 0.95876600E+00, 0.19768100E+01, 0.64666900E+00, 0.36396800E+00, -.29151100E+00, -.20321200E+00, -.98042900E-01, -.71627900E-01, -.38059800E-01, -.72932400E+00, -.12117900E+01, 0.15714300E+00, -.41036400E+00, 0.55868800E+02, 0.22394100E+02, 0.43150400E+03, -.11064100E+03, -.18786400E+03, -.80354000E+01, 0.32020400E+02, -.97915600E+02, 0.20343700E+03, -.15648300E+03, -.13098300E+02, -.67399300E+03, 0.35759100E+03, 0.34044300E+03, -.49377900E+01, 0.11229800E+03, 0.34746500E+03, 0.42352900E+03, 0.52998800E+03, 0.12037400E+03, 0.11172100E+02, 0.39220500E+01, -.53890500E+01, 0.94599600E+02, -.10299300E+02, -.24752400E+02, -.69732900E+02, -.21958900E+02, 0.24385100E+02, 0.86681000E+03, -.43311500E+03, -.43284700E+03, -.93881800E+02, -.41697000E+02, -.25997000E+03, -.58303400E+01, -.17365800E+03, -.96094000E+02, 0.13365200E+04, -.70223400E+03, -.66808900E+03, -.77532800E+02, -.17794200E+03, -.43266400E+03, 0.84924800E+01, -.29069300E+03, -.16850900E+03, -.13083700E+02, -.21666800E+02, 0.19295000E+02, 0.35090100E+03, -.23261900E+01, -.26538600E+02, 0.11010700E+03, -.91774600E+02, 0.17543500E+03, -.25499600E+03, -.13892200E+02, 0.12576200E+03, 0.14399000E+03, 0.55440600E+02, 0.37253400E+02, -.38292900E+02, -.32898600E+02, 0.37263800E+02, -.20892400E+03, 0.12061600E+03, 0.10464000E+03, -.67050300E+02, -.11861200E+03, 0.15830300E+03, 0.64567600E+02, 0.36610100E+03, -.19297500E+03, -.80533600E+02, -.41767600E+02, 0.42815000E+02, 0.38782200E+02, 0.33847600E+02, 0.43183300E+02, 0.37055200E+02, -.29924700E+02, -.10562700E+03, -.16255100E+03, -.54801400E+02, 0.41043900E+02, -.36531400E+02, 0.20637600E+03, 0.44556300E+02, -.12490600E+01, 0.87138700E+01, -.27073700E+02, 0.19943400E+03, -.45526900E+02, 0.36549300E+02, 0.11333900E+02, -.95747700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23298700E+01, -.33783700E+00, 0.28590600E+01, 0.12936100E+01, -.32784100E+01, 0.86870500E-01, 0.18499300E+01, 0.59605500E+00, -.23564100E+00, -.19394100E+00, -.21475800E+01, 0.12465800E+01, -.12341500E+00, 0.50215200E+00, 0.45354100E+00, -.32380200E+00, 0.19104700E+00, 0.21104100E+00, 0.29200500E+00, 0.71239200E+00, 0.38469000E+00, 0.63960100E-02, -.35059500E+00, -.34259600E-01, -.15057500E+01, 0.57783100E-02, 0.20657700E+01, 0.37417600E-01, -.19666800E+01, 0.36345000E+00, -.90137300E-01, 0.13094200E+00, -.94240100E+00, -.25962500E+00, 0.14513300E+00, -.24949200E+00, -.58145400E+00, 0.15781700E+00, 0.25061400E+00, 0.36681200E+00, 0.49965500E+00, 0.40907500E-01, -.65183500E-01, -.38110100E+00, -.54195100E+00, -.74339500E-01, 0.30266000E+00, -.52935800E+00, -.29609800E+00, 0.66109100E+00, 0.49213200E-01, 0.19620200E+00, -.25536000E+00, -.72364600E+00, 0.37249100E+00, -.56043500E+00, -.33547200E-01, 0.11472500E+00, 0.68350900E-03, -.14864100E-02, -.92248000E-01, 0.71825400E+00, -.54156400E+00, -.17111400E+01, 0.41598400E+00, 0.21089100E+00, 0.71335800E+00, -.24697200E+00, -.53035200E+00, 0.39582100E-01, 0.69577000E+00, 0.20823800E+00, 0.14150800E+00, -.17991400E-01, -.26273100E-01, 0.41427900E+00, -.83526000E-02, -.99611200E+00, 0.10398300E+00, -.31303000E+00, 0.25651200E+00, -.78234700E+00, 0.12174800E-01, -.39331400E-01, 0.44819300E+00, -.12269800E+01, -.20038100E-01, 0.35246500E+00, -.11541400E+01, 0.16379100E+00, -.11995100E+00, -.33097400E-01, 0.21450100E-01, -.56792900E+00, -.12949900E-01, -.58750900E-01, 0.47522100E-01, -.55619900E-01, 0.92808700E-01, 0.92547600E-01, -.19479700E+00, 0.52983100E-02, -.64147900E-01, 0.34378700E+00, -.20029300E-01, 0.56990500E-01, -.39641200E-02, -.13531200E+00, 0.17977800E-01, -.21971100E-02, 0.13011400E-01, 0.86327900E+00, -.27794300E+00, -.11471300E+00, -.51019600E-01, -.64245900E+00, 0.15919800E+00, -.42795500E-01, 0.20721400E-01, 0.71508100E-01, 0.13825100E+00, 0.18173900E+00, -.44015000E-01, -.22925100E+00, -.22410200E+00, 0.80108800E+01, 0.68003800E+02, -.77335600E+01, -.26578900E+02, 0.80280200E+01, 0.45013000E+02, -.47514400E+02, -.34186200E+02, -.39884200E+02, 0.37668300E+02, -.17104100E+03, 0.94123000E+02, 0.85769500E+02, -.44805200E+02, -.43475400E+01, 0.97220300E+02, 0.11329600E+03, 0.93184900E+02, 0.38728500E+02, -.19713000E+02, 0.11665300E+02, 0.85161000E+01, 0.21386800E+02, 0.13091000E+01, -.55787100E+01, -.47178800E+02, -.12371900E+02, 0.63217100E+01, 0.20684900E+02, -.99281300E+01, -.10066500E+02, -.35419000E+02, 0.19179500E+01, -.61662800E+01, -.99219200E+01, -.30452900E+02, 0.10577300E+02, 0.29679000E+03, -.15497700E+03, -.14550700E+03, -.80454200E+02, -.46470800E+02, -.85757800E+02, -.33666800E+02, -.11283400E+03, -.36215300E+02, -.57658600E+02, 0.30201200E+02, 0.32312900E+02, 0.50799900E+02, -.28416000E+02, 0.13306800E+02, -.12081700E+02, 0.59317000E+01, 0.48974500E+02, -.17460600E+03, 0.54240800E+02, 0.87046500E+02, 0.94443500E+01, -.34535300E+02, 0.43757700E+02, -.50904600E+02, 0.61533000E+02, -.26431100E+02, -.76073600E+02, 0.43608800E+02, 0.39957300E+02, -.20946700E+01, -.90316100E+01, 0.38180300E+02, 0.25665400E+02, 0.58660200E+02, -.64930600E+01, -.12624800E+02, -.19501800E+02, 0.14002400E+02, 0.22983900E+02, 0.85128100E+00, 0.19215600E+02, 0.44982300E+01, 0.75617800E-02, -.37751400E+02, -.49219800E+02, -.84360700E+01, 0.24835600E+02, -.64436600E+01, 0.57760900E+02, 0.83367600E+01, -.29570600E+02, 0.25543800E+02, -.26849800E+01, 0.46526700E+02, -.28519000E+01, 0.84117400E+01, -.11684100E+02, -.73412800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17088200E+01, -.54081700E+00, 0.14262300E+01, 0.90672800E+00, -.70249100E+01, 0.97102300E-01, 0.73396600E+01, 0.41366400E+01, 0.17739100E+00, -.58939900E+00, -.21630600E+01, 0.14811400E+01, -.16267400E+01, 0.20199300E+01, 0.86422500E+00, -.76588300E+00, -.79137800E+00, 0.29120600E+00, 0.11359100E+01, -.66643500E+00, 0.19464300E+01, 0.19187000E+00, 0.40827200E+00, -.40172200E+00, -.10053000E+00, 0.61160100E+00, 0.89127300E+00, -.21183100E+00, -.13197600E+01, 0.11208800E+01, -.42641600E+00, 0.63257200E+00, -.21007400E+00, -.10257700E+00, 0.14594100E+00, -.18027500E-01, -.20119800E+00, 0.35273900E+00, -.85442700E+00, -.18836500E+00, 0.11751700E+01, 0.52566400E-01, -.12206800E+01, -.33083400E+00, 0.78192500E+00, 0.30746600E+00, 0.16364900E+00, -.85562200E+00, -.16159600E+01, 0.28413600E+00, 0.86762000E-01, -.20393900E-01, -.41930900E+00, -.46352800E+00, -.52052800E-01, 0.32252200E+00, 0.22735400E+00, 0.44558300E-01, -.14901300E+00, 0.37446400E+00, 0.32679400E+00, 0.71179300E-01, 0.13144000E+00, -.12966400E+01, 0.44716000E+00, 0.18687300E+00, 0.45662600E-01, 0.47745700E+00, 0.11435300E+01, -.35379900E+00, -.14015300E+01, -.16915100E+00, -.10558200E+01, 0.76618500E-01, -.10885600E+00, -.13149200E+01, -.19780700E+00, 0.42040800E+00, 0.84292000E-01, -.18042000E+00, 0.10980000E+00, -.74063700E-01, -.64540500E-01, 0.10273900E+00, 0.31142800E+00, 0.13081900E+01, -.32162200E-01, -.42804400E+00, -.73138900E+00, 0.14997200E+01, -.44896600E+00, 0.72838400E-01, -.21447000E+00, -.39181500E+00, -.71833000E-02, -.22641800E+00, 0.44264700E-02, -.38913400E+00, 0.12036200E+00, 0.52272800E+00, 0.28659800E+00, -.60012600E+00, 0.47074600E+00, -.10795200E+01, -.35332100E+00, 0.59802900E-01, 0.79251900E-02, -.23794700E+00, 0.16449000E+00, -.50544100E-01, -.68608700E-01, 0.93275200E+00, -.53331500E+00, 0.36811900E+00, -.34122700E+00, 0.99406400E-01, 0.51354300E-01, -.11247400E+00, -.11203400E+00, -.24341300E-01, 0.14792600E+00, -.58082100E-02, -.23343200E+00, 0.23100200E+00, -.84269300E-01, -.13203600E-01, 0.19860000E+03, -.94121700E+02, -.10439600E+03, -.20267000E+01, 0.72791400E+02, -.78122200E+02, 0.13419900E+02, -.15902700E+03, 0.36839600E+02, -.28756500E+02, 0.13634500E+02, 0.13520400E+02, -.12074900E+02, 0.45895700E+01, 0.39463700E+02, 0.12523800E+03, 0.92473400E+02, -.19307200E+02, -.27612000E+02, 0.12547900E+02, 0.13553400E+02, 0.23361200E+02, 0.69849200E+01, 0.63279900E+01, -.20404800E+02, -.15920300E+02, 0.83791500E+01, 0.23052400E+02, -.10549300E+02, -.11721000E+02, -.15791100E+02, 0.22951600E+02, -.50735900E+01, 0.11409200E+02, 0.95322500E+01, 0.86707200E+01, 0.14161400E+03, -.65632700E+02, -.72564200E+02, -.39768700E+02, 0.33383700E+02, -.52868500E+02, 0.13761900E+02, -.14972000E+02, 0.13212700E+02, 0.19067000E+02, -.40322900E+01, -.15151500E+02, -.12309600E+02, 0.26784300E+02, -.21940200E+02, -.48713300E+02, -.34044500E+02, -.13212300E+02, 0.30356900E+03, -.15011300E+03, -.15163700E+03, 0.45889000E+02, 0.50826300E+02, -.13215600E+03, -.11744600E+03, -.19744200E+03, 0.14795200E+02, 0.86042400E+02, -.40499000E+02, -.42333100E+02, -.24697900E+02, -.54347700E+02, -.70521200E+01, 0.47747500E+02, 0.58970500E+02, -.63324300E+02, -.22540100E+01, 0.75886700E+01, -.12209100E+02, 0.42586900E+02, 0.88429100E+00, -.71264900E+01, 0.17845200E+02, -.11838300E+01, -.13208300E+02, -.22334200E+02, -.15054400E+02, 0.41401900E+02, -.90521400E+01, -.20421900E+02, 0.90953500E+01, -.62471400E+01, -.21889800E+02, 0.19652000E+00, -.19200000E+02, 0.23181200E+02, 0.76652000E+01, -.13655200E+02, -.49653700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.46446800E+01, -.15268100E+01, 0.45431300E+01, 0.24678100E+01, -.11050300E+02, 0.37712000E+00, 0.11823200E+02, 0.58982900E+01, 0.79862000E+00, -.17019400E+01, -.28920000E+01, 0.33735900E+01, -.26797100E+01, 0.28343400E+01, 0.15826100E+01, -.13532400E+01, -.69172800E+00, 0.92115800E+00, 0.22957500E+01, -.49761800E-01, 0.48041700E+01, 0.17352600E+00, 0.27943700E+00, -.58310400E+00, -.15910400E+00, 0.12522600E+01, 0.25158500E+00, -.97293300E+00, -.22346600E+01, 0.19676500E+01, -.70477300E+00, 0.99212300E+00, -.24463700E+00, 0.18498300E+00, 0.91573500E+00, -.53696400E+00, -.87358600E-01, 0.11456000E+00, -.11852800E+01, 0.72773700E-01, 0.19438600E+01, 0.10724300E+00, -.19163700E+01, -.45282800E+00, 0.13566300E+01, 0.70471500E+00, 0.59808700E+00, -.18534900E+01, -.40968200E+01, 0.16109900E+01, 0.28763900E+00, 0.38633000E-01, -.63269800E+00, -.90333700E+00, -.42574300E+00, 0.10851800E+01, 0.50575800E+00, -.91678100E-02, -.48880300E+00, 0.34236700E+00, 0.78962300E+00, 0.11871100E+01, -.40628400E+00, -.34345000E+01, 0.14439600E+01, 0.90556300E+00, 0.14153400E+01, 0.26461600E+00, 0.68432000E+00, -.51286900E+00, -.12671000E+01, 0.20180200E+00, -.63115000E+00, 0.25942600E+00, -.58434900E+00, -.93386700E+00, -.60620200E-01, 0.57321800E+00, 0.12941900E+00, 0.30036000E+00, 0.66622700E-01, -.83567600E+00, -.50960700E-01, 0.17683300E-01, 0.59798600E+00, 0.31447100E+01, -.86015900E-01, -.93538700E+00, -.18879100E+01, 0.19434000E+01, -.11708300E+01, 0.55873900E+00, -.37102000E+00, 0.35233300E-01, -.60014600E+00, -.24040000E+00, 0.55306500E+00, -.39403900E+00, 0.17406100E+00, 0.10393700E+01, -.12623400E+00, -.47171700E+00, 0.15179000E+00, -.98700000E+00, -.64996800E+00, 0.62031600E-01, 0.18972800E+00, -.58805700E+00, 0.61619200E+00, -.13601700E+00, 0.11694600E+00, 0.89141200E+00, -.85158600E+00, -.80281500E-01, -.56435600E+00, -.15001200E+00, 0.22133100E+00, -.19753300E+00, 0.22028000E+00, -.16747900E-01, 0.27780600E+00, 0.31909300E+00, 0.19140300E-01, 0.50964400E-01, -.17499300E+00, -.11010700E-01, 0.42895800E+00, 0.90496800E+02, 0.10037600E+01, -.45633100E+02, -.73847600E+02, 0.48908400E+02, 0.13712400E+03, 0.57066700E+02, -.39282800E+02, 0.30379600E+03, -.14551000E+03, -.14879200E+03, 0.22826500E+02, 0.33752100E+02, -.14880300E+03, -.15765400E+03, -.18589100E+03, -.72940000E+01, 0.40284800E+02, -.18850900E+02, -.18082300E+02, -.13228100E+02, -.26909000E+02, 0.68807600E+01, 0.39312700E+02, 0.37467700E+02, -.18786500E+02, -.75990000E+02, 0.40008400E+02, 0.38172500E+02, 0.60652100E+02, 0.38122800E+02, 0.80597500E-02, -.42210600E+02, -.70025000E+01, 0.17142100E+02, 0.36877900E+02, -.20961100E+02, -.19310800E+02, 0.23528700E+02, 0.11109000E+02, -.35542600E+02, -.45323700E+02, -.57946800E+02, 0.13167900E+02, 0.18093400E+03, -.90796500E+02, -.79831900E+02, 0.43996000E+02, -.23625900E+02, -.76412500E+02, -.96782900E+02, -.78571200E+02, -.16296800E+02, -.17345100E+03, 0.65306300E+02, 0.87215400E+02, -.14337500E+02, -.15021200E+02, 0.87809300E+02, 0.15078600E+03, 0.10969000E+03, 0.34351500E+02, -.10545600E+03, 0.63978900E+02, 0.47850300E+02, 0.26724200E+02, 0.53058400E+02, 0.15737500E+02, 0.25204900E+02, -.43647300E+02, 0.54454400E+02, 0.12713700E+02, 0.30901900E+02, 0.44351000E+01, -.61551200E+01, -.74352700E+01, -.31173800E+02, -.59188700E+01, 0.99897100E+01, 0.59250000E+02, 0.67393600E+02, 0.16774300E+02, -.53878000E+01, 0.58187800E+01, -.41073400E+02, -.10427400E+02, 0.50800400E+02, 0.97112400E+00, 0.16999600E+02, -.33721500E+02, -.64056600E+01, -.51071800E+01, 0.10454400E+02, 0.63845100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24264500E+01, 0.38423700E+00, 0.33089500E+01, 0.11957400E+01, -.29374300E+01, -.29766500E+00, 0.26338500E+01, 0.12805400E+01, -.20526700E+00, -.82058900E+00, -.73232800E+00, 0.82838300E+00, -.31213200E+00, 0.78943600E+00, 0.63014600E+00, -.68842400E+00, -.32012800E+00, -.13426800E+00, -.15363800E+00, -.28000800E+00, 0.21507800E+00, 0.19242700E+00, -.25198700E+00, 0.12441900E+00, -.45372800E+00, 0.22210500E+00, 0.22829300E+00, 0.14241100E+00, -.15686400E+01, 0.88172300E+00, -.13224400E-01, 0.48161700E+00, -.53296900E+00, -.47858700E+00, 0.92875900E-01, -.80086200E-01, -.69891200E-01, 0.20530800E+00, -.44136400E+00, 0.71891600E+00, 0.79254200E+00, 0.13255200E+00, -.11667400E+01, -.14427100E+00, 0.16900800E+00, -.20274800E+00, 0.22543500E+00, -.35198500E+00, -.11966600E+01, 0.91498400E+00, 0.17889600E+00, 0.13502700E+00, 0.28378600E-01, -.48516300E+00, 0.60840800E-02, 0.31493900E+00, 0.58111300E-01, -.11626900E+00, -.52968800E-01, -.16337300E+00, 0.11505700E+00, 0.42073900E+00, 0.18727500E+00, -.93547400E+00, 0.88894700E+00, 0.43821200E+00, 0.41281700E+00, -.83019500E-02, -.16294800E+00, -.85868400E-01, -.25424700E+00, 0.26900300E+00, -.21848800E-01, 0.11907700E+00, -.23914700E+00, -.65176000E-01, 0.23946400E-01, 0.53399200E+00, -.25689100E-01, 0.42473200E+00, -.91514900E-01, -.57555900E-01, 0.22264400E-02, -.27594700E-01, 0.30350100E+00, -.43817300E+00, -.38474100E-01, -.55568400E-01, 0.11383800E+00, 0.29901800E+00, -.93655400E-01, -.11199400E+00, 0.86842400E-01, -.53863200E+00, 0.16091900E+00, -.26165700E-01, -.14534700E+00, 0.40969400E-01, -.56070200E-01, -.86953200E+00, 0.17620100E+00, 0.10353900E+01, 0.25838700E+00, 0.35265500E+00, 0.11033200E+00, 0.10013200E-01, 0.15085800E-01, -.97741600E-02, 0.42844700E-01, 0.64935000E-02, -.76401900E-01, -.31109800E-01, 0.10293700E+00, 0.13077700E+00, 0.19607900E+00, 0.48289200E+00, 0.18603400E+00, 0.71681000E-01, 0.19170400E+00, 0.17447300E-01, 0.22439600E+00, 0.25093400E-01, 0.14943800E+00, 0.35081900E-01, -.24647800E-01, 0.47345600E+00, -.81493900E-01, -.59249500E-03, -.16618900E+02, 0.70467900E+01, 0.22706200E+02, -.78766400E+01, -.15548000E+02, -.16797300E+02, 0.88152100E+01, 0.51672900E+02, -.24058400E+02, -.27719800E+02, -.27093000E+02, -.52258700E+01, -.14822000E+02, 0.25619800E+02, 0.18963100E+02, -.22431000E+02, -.38481000E+02, 0.18814200E+02, 0.19466600E+02, 0.15399800E+02, 0.17549500E+02, 0.48493000E+01, -.86643500E+01, -.25572600E+02, 0.21498900E+02, 0.15387100E+02, -.75220800E+01, -.80695700E+01, -.34553400E+01, -.11422400E+02, 0.54307300E+01, 0.21292700E+02, 0.39132600E+02, -.14473300E+02, -.57605900E+02, 0.30817900E+02, 0.27114600E+02, -.17258700E+02, 0.22705000E+02, 0.13866300E+02, 0.22951000E+02, 0.53209400E+02, -.51960600E+01, 0.20179900E+01, -.29547500E+01, -.96837800E+01, -.39907400E+02, 0.91865000E+01, -.12698900E+02, -.28692800E+02, -.19618800E+02, -.18859500E+02, 0.14132600E+03, -.73764300E+02, -.70899900E+02, 0.34918000E+01, 0.24822200E+02, -.56222300E+02, -.51651500E+02, -.84334300E+02, 0.26099900E+02, 0.79695900E+02, -.40984500E+02, -.39138700E+02, -.37501000E+02, -.43869000E+02, -.45395400E+01, 0.33134200E+02, 0.46900600E+02, -.48858100E+02, -.16336700E+01, 0.10561400E+02, -.12514700E+02, 0.19673300E+02, -.10598900E+00, -.10177300E+02, 0.27112200E+01, -.99136400E+00, 0.20026400E+02, 0.25452300E+02, -.39447000E+01, 0.17702100E+02, -.23945200E+01, -.12254600E+02, 0.26036600E+01, -.63123600E-01, -.16880000E+02, 0.47328400E+01, -.43119800E+01, 0.20610000E+02, 0.68816600E+01, -.12907400E+02, -.52630900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.27490100E+01, 0.55483500E+00, 0.37620200E+01, 0.14143500E+01, -.89674700E+01, 0.33384700E+00, 0.71596500E+01, 0.23201100E+01, 0.34658900E+00, -.69039300E+00, -.31817600E+01, 0.12637100E+01, -.16774100E+01, 0.46596300E+00, 0.50301100E+00, -.16569800E+01, -.57192500E+00, -.69955100E+00, -.19670400E+00, -.58386600E+00, 0.12224700E+01, 0.42631100E+00, -.60705100E+00, -.31330100E+00, -.83169300E+00, 0.38327400E+00, 0.10684500E-01, -.95799500E-01, -.17505900E+01, 0.65693900E+00, -.19504400E+00, 0.40874700E+00, -.74693000E+00, -.78571800E-01, 0.58649800E+00, -.18919500E+01, -.29003200E+00, 0.38111700E-01, 0.16904400E+01, 0.11698800E+01, 0.65185300E+00, 0.14392100E+00, 0.45347000E+00, 0.41936500E+00, -.23678500E+01, -.15207500E+01, 0.49996000E+00, -.50014800E+00, 0.25292300E+01, -.17055600E+01, -.54753400E-01, 0.35299600E-01, 0.98143100E+00, 0.63773000E-02, 0.16236500E+01, -.80736800E+00, -.15214000E+00, 0.77117400E-01, 0.34920500E+00, 0.10049400E+00, 0.33411000E+00, -.44239700E+00, 0.28542400E+00, 0.49294200E+00, -.13364900E+00, 0.21020100E+00, -.18186600E+00, -.11728900E+00, -.22100200E+00, -.11751600E-01, -.14500200E+00, -.45040800E-01, 0.56652200E-02, 0.15638500E+00, -.47119500E+00, -.96263200E-01, -.10009300E+00, -.34080800E-01, 0.10574100E+00, 0.10815000E-01, 0.47424800E+00, -.11626500E+00, 0.60833700E-01, -.72254800E-01, -.13735500E+00, -.10129200E+01, 0.10467100E+00, 0.21045100E+00, 0.32575100E+00, 0.57436100E+00, 0.23768600E+00, 0.11612500E+00, -.33366500E+00, 0.74706000E+00, 0.19000600E+00, 0.55130700E-02, -.29228500E+00, -.36819000E+00, 0.15353900E+00, 0.82135800E+00, -.34727800E+00, -.12555800E+01, 0.18308800E-01, 0.87867300E-02, -.21716200E+00, 0.27426900E+00, -.68724300E-01, 0.58798100E+00, 0.93603100E-01, 0.65698400E-02, 0.42108800E+00, -.30337000E+01, 0.30973100E+00, -.15630800E+00, 0.48193800E-02, -.14029500E+01, -.37421500E+00, -.78109200E-01, 0.15955700E+00, 0.70619300E-01, -.12921100E+00, 0.56759200E+00, 0.33082100E+00, -.24837100E+00, 0.10749000E+00, -.25197200E+00, -.28590700E+00, 0.27588900E-01, 0.96767900E+00, -.78826800E+02, -.11319300E+03, 0.79558000E+02, 0.12347400E+03, 0.12045700E+03, -.41662900E+02, 0.16063300E+03, -.85228900E+02, -.80895900E+02, 0.89223400E+02, 0.47688700E+02, -.10946700E+03, -.20661700E+03, -.17774000E+03, 0.29427000E+02, 0.68442800E+02, -.33621300E+02, -.36052000E+02, -.23411500E+02, -.40449100E+02, -.45106400E+01, 0.37178800E+02, 0.45762200E+02, -.35729200E+02, 0.17689700E+03, -.88456200E+02, -.88194000E+02, -.43148800E+01, 0.15964800E+01, -.61347400E+02, -.14796400E+02, -.90340300E+02, -.67838500E+01, 0.17803400E+03, -.93167800E+02, -.82994300E+02, -.41239000E+02, -.56953100E+02, -.44869400E+02, -.33866300E+02, -.11078100E+03, 0.22689900E+02, -.43590300E+02, 0.23469100E+02, 0.27977800E+02, 0.84106500E+02, -.13685900E+02, 0.20462900E+02, 0.44785800E+02, 0.32761400E+02, 0.64060400E+02, -.46727300E+03, 0.23402100E+03, 0.23349000E+03, -.99639000E+01, -.48087500E+02, 0.20758000E+03, 0.19676000E+03, 0.26738200E+03, -.19048400E+02, -.20125700E+03, 0.10185300E+03, 0.10486000E+03, 0.64386900E+02, 0.78384600E+02, 0.32158700E+02, -.49916300E+02, -.76885100E+02, 0.87122500E+02, 0.96953000E+00, -.27614900E+02, 0.24994900E+02, -.10628100E+02, -.17993500E+01, 0.27433700E+02, -.44385900E+01, 0.38239400E+01, -.72207400E+01, -.88138000E+01, 0.10178900E+02, -.86922100E+01, 0.38190500E+01, 0.52014900E+02, -.48300500E+01, 0.48479400E+02, 0.35155400E+02, 0.66571400E+00, 0.41560800E+02, -.32869900E+02, -.70325200E+01, 0.26491800E+02, 0.16119500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.96224700E+00, 0.54574700E+00, -.25861400E+00, -.35969400E+00, 0.56128900E+01, -.17100600E-02, -.57304900E+01, -.38116200E+01, -.21655700E+00, 0.17266300E+00, 0.90954300E+00, -.12548000E+01, 0.10724700E+01, -.19345200E+01, -.15684100E+00, 0.37817500E-01, 0.10040800E+01, -.63029700E+00, -.79086300E+00, 0.10089300E+01, 0.67960900E+00, 0.33470200E+00, -.12145500E+01, 0.44303800E+00, 0.35630700E+00, 0.12133400E+00, -.17093100E+01, 0.38154600E+00, -.20112800E+00, 0.96656200E+00, 0.30601900E+00, -.11691800E-01, 0.26561600E+00, -.25564400E+00, 0.83676900E-01, -.89875300E-01, 0.22086700E+00, -.18803100E+00, 0.72462400E-01, 0.75910900E+00, -.11806200E+01, -.86858100E-01, 0.96862700E+00, 0.87713400E+00, -.12222800E+00, 0.53912700E+00, -.13605600E+00, 0.11061800E+01, -.62562300E+00, 0.92239400E+00, -.16195700E-01, 0.54690700E-01, -.73398400E+00, -.12451600E+00, -.60766600E+00, 0.21578400E+00, -.25691700E+00, 0.68742500E-01, -.21940100E+00, -.72669900E-01, 0.14234800E+00, 0.71255400E+00, -.23221800E+00, -.75219200E+00, 0.41344200E-01, 0.11578100E-01, 0.18705600E+00, -.40241900E+00, -.59917200E+00, 0.10176100E+00, 0.82356700E+00, 0.11551500E+00, 0.33535400E+00, 0.11217100E+00, 0.39303600E+00, 0.35341000E+00, 0.20439100E+00, -.16443600E+00, -.23367400E+00, 0.12593800E+01, -.17383900E+00, -.24136300E+00, 0.55909200E-01, -.15923200E+00, 0.52053700E+00, -.87738400E+00, -.35435300E+00, 0.15091800E+00, -.14975700E+01, -.19649700E+01, -.27444900E+00, 0.14363600E+00, 0.13774900E+00, 0.28857500E+00, -.24831600E+00, 0.99190600E-01, 0.43353200E+00, 0.64583700E+00, -.72700300E-01, -.85753600E+00, 0.72873200E+00, 0.11231700E+01, 0.12773900E+00, 0.40330700E+00, -.50581700E-02, 0.14527700E+00, 0.79396600E-01, 0.27814800E-02, -.19208900E-01, -.12294100E-01, -.12667000E-01, -.84877900E+00, -.92836700E-01, 0.21424600E+00, 0.21667100E+00, 0.22118900E+00, 0.28136200E+00, 0.26318800E+00, 0.13442100E-01, 0.22458900E-01, 0.33262700E-01, -.17747000E+00, 0.17823000E+00, 0.74749000E-02, 0.19944500E+00, -.67149600E+00, 0.78994400E-01, 0.32148800E-01, 0.17392900E+00, -.84968900E-01, -.45962200E+02, 0.17057000E+02, -.98986000E+00, 0.74989400E+02, -.33398500E+01, 0.16660600E+03, -.82770300E+02, -.82677100E+02, -.42735400E+02, 0.33197600E+02, -.10352900E+03, -.20155400E+03, -.15200300E+03, 0.27941300E+02, 0.19002100E+02, -.84908700E+01, -.93478800E+01, 0.14292500E+02, -.11508300E+02, -.37062900E+01, 0.17504800E+02, 0.18073400E+02, 0.12479600E+01, 0.41244300E+02, -.21016400E+02, -.20260100E+02, -.86960200E+00, -.10522200E+02, -.14750100E+02, -.38722700E+02, -.35856900E+02, -.88298900E+01, 0.21188900E+03, -.11174200E+03, -.10391500E+03, -.49642000E+02, -.70332700E+02, -.36706000E+02, -.26012900E+02, -.48890000E+02, -.28025500E+02, -.69614100E+02, 0.32142900E+02, 0.39581900E+02, 0.80772800E+02, -.42922300E+01, 0.26234600E+02, 0.36856900E+02, 0.25820500E+02, 0.71617100E+02, -.42003000E+03, 0.20457700E+03, 0.21011500E+03, 0.56797800E+02, -.74242600E+02, 0.18535100E+03, 0.19301700E+03, 0.23968400E+03, -.20157600E+02, -.88853500E+02, 0.45666200E+02, 0.43802300E+02, -.64590800E+01, -.79445700E+01, 0.50667800E+02, 0.62210200E+02, 0.15700000E+02, -.93933600E+01, -.12809600E+02, -.24596300E+02, 0.28909900E+02, -.48230200E+01, 0.55466900E+01, 0.24313700E+02, -.62980300E+01, -.41258200E+01, 0.17554700E+02, 0.89641200E+01, 0.60115100E+01, -.38133900E+01, 0.12774600E+01, 0.29976300E+02, 0.33368400E+01, -.13948500E+02, 0.41138300E+02, 0.24316800E+00, 0.24588500E+02, -.23164500E+02, -.56473400E+01, 0.19024200E+02, -.15264500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.27598700E+01, 0.15069800E+00, -.24853100E+01, -.12359300E+01, 0.59493200E+01, 0.45648500E+00, -.47200400E+01, -.17874900E+01, 0.17177800E+00, 0.17398600E+01, 0.16850000E+01, -.23917800E+01, 0.80871900E+00, -.24291700E+01, -.11830200E+01, 0.11090500E+01, 0.73448200E+00, 0.25256100E-01, -.89546700E+00, 0.51126200E+00, -.27771900E+01, -.77645600E-01, -.11547200E+00, -.14720200E-01, 0.33588900E+00, -.73528300E+00, 0.97466000E-01, -.12839900E+00, 0.13332300E+00, -.13836000E+01, 0.35487900E+00, 0.86439200E+00, -.21452800E-01, 0.59649200E+00, -.29026000E+00, -.21027100E+00, 0.13619900E+00, 0.83558700E-01, 0.94186700E+00, -.27160400E+00, -.26139400E+00, -.20096800E-01, 0.12003400E+01, -.24666600E+00, -.35865000E+00, -.12926900E+00, 0.91243700E-01, -.49621100E+00, 0.47762200E+00, -.13237100E+01, -.13469400E+00, -.23612100E+00, -.21253700E+00, -.85295200E+00, 0.11766400E+00, -.68535000E+00, -.94992600E-01, 0.26609300E+00, -.24759000E-01, 0.50340000E+00, -.37424100E+00, 0.63779800E+00, -.12951400E+01, -.74255300E+00, -.38405600E+00, -.21189400E-02, 0.74282200E-01, -.26643000E+00, -.91781700E+00, -.60341300E+00, 0.79885600E+00, 0.86916500E-01, 0.98559500E+00, 0.16124300E+00, -.66002400E+00, 0.54557300E+00, -.28390900E+00, -.98824900E+00, 0.25893300E+00, -.82840000E+00, -.48224400E+00, 0.25382500E+00, -.71184500E-01, -.42828300E-01, 0.14968200E+00, 0.64736700E+00, 0.94309200E+00, 0.79167400E+00, -.63353400E+00, 0.13582800E+01, 0.25246500E+00, 0.15723500E+00, -.22158400E-01, -.70021100E+00, -.76872100E+00, 0.17852400E+00, 0.12388600E+00, 0.55766300E-01, -.29900400E-01, 0.18291200E+01, 0.19112200E+00, -.17507500E+01, -.40243900E-02, 0.72522400E-01, -.15934800E+00, -.68539600E-02, -.20410100E+00, -.72824400E-01, -.10866400E+00, -.12248900E-01, -.35885000E+00, -.85086900E+00, -.91668400E-02, -.80373500E+00, -.82405700E-01, 0.76980700E+00, 0.80462400E-01, 0.45775600E+00, -.42625200E+00, -.61112000E-01, -.17916900E+00, 0.47988700E-02, -.42382500E+00, 0.56970200E+00, 0.10075600E+00, -.88565800E+00, 0.67528300E+00, -.80494900E-01, -.46401800E+00, 0.97351800E-01, -.11700900E+00, -.34613000E+02, -.97754500E+02, 0.88468000E+02, 0.84714500E+01, 0.16892800E+03, -.87290300E+02, -.85648800E+02, 0.36933300E+02, -.13100100E+02, -.98947600E+02, -.18365000E+03, -.13414400E+03, 0.17463800E+02, 0.38166500E+02, -.20812400E+02, -.19634300E+02, 0.10741500E+01, -.87077200E+01, -.19430300E+02, -.17234300E+01, -.99888400E+01, -.11276300E+02, -.13858700E+03, 0.70383700E+02, 0.69599200E+02, -.11454900E+02, -.16629000E+02, 0.46420700E+02, -.27016200E+01, 0.16366700E+02, 0.13060000E+02, -.17286100E+03, 0.92663300E+02, 0.90529900E+02, -.97156300E+02, -.19382900E+02, 0.68478900E+02, -.33770000E+02, 0.18342600E+02, -.10154900E+01, -.74986900E+02, 0.48972400E+02, 0.39469000E+02, -.27282300E+02, -.17327400E+02, 0.14525000E+02, -.55744000E+02, 0.16999400E+02, -.21326300E+01, -.31734200E+03, 0.16972500E+03, 0.15883600E+03, -.29177000E+02, -.93965400E+02, 0.14170100E+03, 0.86021400E+02, 0.18440300E+03, -.73625500E+02, -.15485200E+03, 0.77432000E+02, 0.79646800E+02, -.43065400E+00, 0.90944000E+01, 0.78380400E+02, 0.24006900E+02, 0.19938800E+02, 0.30001700E+02, 0.78349700E+01, -.45615400E+01, -.68585500E+01, -.29231900E+01, -.68570100E+01, 0.40320600E+01, -.16489200E+02, 0.41922100E+01, 0.16131800E+02, 0.15238100E+02, 0.14047300E+02, -.18366600E+01, 0.12297700E+02, -.89525800E+00, -.39323200E+01, -.31804800E+02, 0.43318000E+02, -.67328900E+01, -.83137400E+01, 0.12631100E+01, 0.27186500E+01, 0.12929700E+02, -.14810600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.16311600E+01, 0.26252000E+00, -.98340100E+00, -.12552600E+01, 0.13697200E+02, -.78700000E+00, -.78361100E+01, -.40789400E+01, 0.12640800E-01, 0.20879800E+01, 0.33612700E+01, -.23887600E+01, 0.20484400E+01, -.23123900E+01, -.17839700E+00, 0.10230900E+01, -.11591800E+01, -.99211600E+00, -.21578000E+01, -.79875100E+00, -.34273000E+01, -.12233500E+00, -.55602700E-01, -.43525800E+00, -.33426700E+00, -.10691600E+01, 0.90022200E+00, -.36851700E+00, 0.85863700E+00, -.16916100E+01, -.37832400E+00, -.13322600E+00, 0.30600000E+00, 0.84393400E+00, -.94166900E+00, 0.44455800E+00, -.16573700E-01, -.31021900E+00, 0.17451300E+01, 0.46594600E+00, 0.25665900E+01, -.23514700E-01, -.23399700E+01, -.69405000E+00, 0.73921700E-01, -.10909100E+01, 0.77900800E+00, -.22211100E+01, -.33292400E+01, 0.39157100E+01, 0.24392300E+00, 0.33076300E+00, -.84530300E+00, -.14635100E+01, 0.65408900E+00, 0.50965400E-01, -.30076900E+00, 0.23165200E+00, -.23084900E-01, 0.22620700E-01, -.69562800E+00, 0.21381100E+01, -.76345200E+00, -.42701700E+01, 0.18494800E+01, 0.67048900E+00, 0.17017300E+01, -.27556500E+00, -.23259900E+01, 0.70633500E-01, -.57209300E+00, 0.66209800E+00, 0.11475200E+00, -.11167700E-01, -.46953500E+00, 0.10725900E+01, 0.48958000E+00, 0.19708200E+01, -.10762000E+00, 0.27836900E+01, 0.15200000E+00, -.15465300E+01, -.16536000E-01, -.94779100E-01, -.32801000E+00, -.58184100E-02, 0.39828700E+00, 0.49133600E+00, 0.20072200E+00, 0.12950400E+01, -.29660400E+00, 0.37534100E+00, -.18538100E+00, 0.30950500E+01, -.25901800E-02, 0.58631100E+00, 0.45722300E+00, 0.48447100E+00, -.47109600E+00, -.51640700E+00, 0.47558800E+00, 0.32690300E+01, 0.21147600E+00, 0.65630400E+00, 0.45257200E+00, -.24400900E+00, 0.12099000E-01, 0.87339200E+00, -.35477200E+00, 0.98747000E-01, 0.26322800E+00, -.32803900E+01, 0.89145700E+00, 0.13912700E+00, 0.99273300E+00, 0.18799500E+01, -.14857900E+00, 0.46064500E+00, -.41143700E-01, -.86608500E-01, -.42300200E+00, -.26179900E+00, 0.64821900E-01, -.28093700E-01, -.30604800E+00, 0.31241300E+00, -.44501500E+00, 0.12172100E-02, -.15871900E+00, -.97573300E+00, -.35033800E+00, -.62317300E+00, -.88973600E+02, 0.61402100E+02, 0.58365800E+02, 0.34018200E+03, -.17711900E+03, -.17234600E+03, 0.56050100E+02, 0.52350500E+02, -.17400800E+03, -.30767500E+03, -.21963000E+03, 0.19576200E+02, 0.33464600E+02, -.13674600E+02, -.19474000E+02, 0.34585000E+02, -.19330500E+02, -.11506100E+02, 0.10658700E+02, 0.15489900E+02, -.27454800E+00, 0.31568100E+03, -.15916300E+03, -.15739800E+03, -.70813700E+02, -.35097400E+02, -.88783600E+02, -.32845400E+02, -.10044300E+03, -.32394800E+02, 0.53240500E+03, -.28076400E+03, -.26016600E+03, -.11803500E+03, -.15954500E+03, -.10938400E+03, -.24953500E+01, -.11507800E+03, -.36612100E+02, -.23593800E+03, 0.10817900E+03, 0.11817900E+03, 0.19292000E+03, 0.40367700E+01, 0.81751600E+02, 0.14971000E+03, 0.80181200E+02, 0.13412100E+03, -.73079200E+03, 0.34857300E+03, 0.36427600E+03, 0.12785000E+03, -.10910600E+03, 0.30502300E+03, 0.25548600E+03, 0.34532300E+03, -.66272000E+02, -.14819200E+03, 0.72890300E+02, 0.81261900E+02, -.10916000E+02, -.61367200E+02, 0.10041900E+03, 0.54686300E+02, 0.94234800E+02, -.66659800E+02, -.51442600E+02, -.82961700E+02, 0.38233200E+02, -.10599500E+02, 0.24582900E+02, 0.83162300E+02, 0.12354100E+02, -.22668600E+02, -.63716700E+02, -.10032800E+03, -.24432600E+02, -.88026200E+01, -.17341500E+02, 0.11862300E+03, 0.24853200E+02, -.56147000E+02, 0.75842200E+02, -.19388600E+02, 0.10065200E+03, -.57205600E+02, 0.85953100E+01, 0.30762900E+02, -.44548800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20232100E+01, 0.43914800E+00, -.14745000E+01, -.90547600E+00, 0.52798400E+01, -.28581200E+00, -.69412300E+01, -.28685000E+01, 0.21819300E+01, -.19348300E+00, 0.29728000E+01, -.54346600E+00, 0.17915600E+01, -.11278100E+01, -.27882700E+00, 0.29987500E+00, 0.25023600E+00, 0.35399500E+00, 0.69089500E+00, 0.84196200E+00, 0.28583100E+00, -.50270800E+00, 0.44762500E+00, 0.46144100E+00, 0.58707600E-01, -.41798900E-01, -.13085000E+00, -.14097300E+00, 0.16656900E+01, -.78457900E+00, -.37002200E+00, -.10278000E+01, 0.56231000E+00, 0.14885400E+00, -.64625900E+00, 0.19149500E+00, -.79136200E-01, -.44265700E+00, 0.21891100E+00, 0.33187200E+00, 0.38697900E+00, 0.12129800E+00, -.76812500E+00, -.14727600E-01, 0.11234500E+01, 0.29731900E+00, -.18017700E-01, -.26360400E+00, -.13005200E+00, -.95489700E+00, -.31839800E-01, -.20302900E+00, -.54175900E+00, 0.11066600E+01, 0.81851300E+00, 0.11618200E+01, -.78786100E-01, 0.23203400E+00, -.21633300E+00, 0.53595700E-01, -.41048000E+00, -.91608300E+00, 0.34984400E+00, 0.12331900E+01, -.69412500E+00, -.57203900E+00, -.54406000E+00, 0.31630400E+00, 0.54013800E+00, 0.28880800E-01, 0.59803100E+00, -.53080400E+00, -.39212500E+00, -.57464200E+00, 0.12863600E+01, -.11122100E+01, -.27986600E+00, -.13388100E+01, 0.82440400E-01, -.76370100E+00, 0.38440200E+00, -.27534800E+00, 0.38781400E-01, 0.11441300E+00, -.21687300E+00, -.57059300E+00, -.22165200E+00, -.11660100E+00, 0.45236000E+00, 0.71106700E+00, -.17255700E+00, 0.24257400E+00, -.21873500E-01, 0.20712900E+00, 0.31225100E+00, -.23410600E+00, -.15729200E+00, -.12880000E+00, 0.68227800E-01, 0.96903700E-02, -.42899200E+00, -.42380900E+00, -.17742500E-01, -.47213500E+00, -.15789600E+00, 0.33920600E+00, 0.25403400E-02, 0.19217800E+00, -.10170300E+00, -.57191100E-02, 0.22432100E+00, 0.96019700E+00, -.17501500E+00, -.33398900E+00, -.85485400E-01, -.11365100E+01, -.30938800E+00, -.64777700E+00, -.41163700E-01, 0.44665700E-01, 0.16976400E+00, 0.18914800E+00, -.95842900E-02, -.20686500E+00, -.10117300E+00, 0.81394400E+00, -.29228900E+00, -.26727800E+00, 0.91302300E+00, 0.60559500E+00, 0.20997000E-01, 0.86543900E-01, 0.94749000E-01, -.59077800E+02, -.19329000E+02, -.15203900E+03, 0.67666500E+02, 0.76516000E+02, -.14728800E+02, -.32109800E+02, 0.10665100E+03, 0.22119700E+03, 0.14329100E+03, -.47113100E+02, -.90730300E+01, 0.25318300E+01, 0.55627200E+01, -.33463300E+02, 0.21421600E+02, -.51128800E+00, 0.68835500E+01, -.45631100E+01, 0.28094500E+01, -.56921200E+02, 0.28688300E+02, 0.28010100E+02, 0.52436000E+02, 0.33148300E+02, 0.63210600E+01, 0.28142700E+02, -.11423700E+02, 0.11493500E+02, -.27082100E+03, 0.14341300E+03, 0.13079600E+03, 0.13921100E+03, 0.93950400E+02, 0.31818900E+02, -.60783500E+01, 0.30293300E+02, 0.63684400E+02, 0.20589700E+03, -.10253900E+03, -.10755000E+03, -.10005300E+03, -.82259500E+01, -.74130000E+02, -.57713700E+02, -.52299600E+02, -.33381100E+02, 0.55672800E+03, -.24950900E+03, -.27772300E+03, -.52968900E+02, 0.61507200E+02, -.23985200E+03, -.23532000E+03, -.25487500E+03, 0.42631000E+02, 0.15380400E+03, -.75981400E+02, -.79703300E+02, 0.59528400E+01, 0.26978100E+02, -.86964300E+02, -.12652500E+03, -.88369900E+02, 0.33175900E+02, 0.14006400E+02, 0.47635500E+02, -.19526600E+02, -.24342500E+02, -.16482300E+01, -.47302500E+02, -.96220200E+01, 0.53625600E+00, 0.16398300E+02, 0.40299100E+02, 0.53997900E+01, -.26200500E+02, 0.79876400E+01, -.72160900E+02, -.93875500E+01, 0.28745400E+02, -.67500800E+02, -.23107200E+01, -.65364500E+02, 0.40246600E+01, -.12073400E+01, -.30793500E+02, 0.20316600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36058500E+01, 0.87804000E+00, 0.48519500E+01, 0.15954000E+01, -.70938000E+01, 0.57729300E-01, 0.69668000E+01, 0.21197100E+01, -.70170900E+00, -.12096400E+01, -.24234900E+01, 0.20789900E+01, -.91177100E+00, 0.13682200E+01, 0.11495700E+01, -.14715500E+01, -.54679700E+00, -.35961500E+00, 0.29727300E+00, -.99424300E+00, 0.15113700E+01, 0.40830900E+00, -.37138800E+00, -.49897400E+00, -.72416800E+00, 0.47347200E+00, -.63216400E-01, -.12374400E+00, -.15646100E+01, 0.78001100E+00, -.16042800E+00, 0.56746200E+00, -.11041400E+01, -.60413400E+00, 0.33689600E+00, -.20477000E+01, -.18787300E+00, 0.31086800E+00, 0.87001000E+00, 0.10840700E+01, 0.58983800E+00, 0.19222200E+00, 0.14101200E+00, 0.46842200E+00, -.10596500E+01, -.95695100E+00, 0.50135000E+00, -.55178800E+00, 0.11270200E+01, -.16838200E+01, -.37510300E-01, -.27371700E+00, 0.88751100E+00, 0.80492700E-01, 0.87190200E+00, 0.27159300E-01, 0.21786100E+00, -.19029000E+00, -.42607700E-01, 0.56616100E+00, 0.50958000E+00, 0.14610300E+00, 0.74662300E-01, -.16382600E+01, 0.50674400E+00, 0.45961400E+00, 0.24264900E+00, 0.20419800E+00, 0.54456300E+00, -.65297400E+00, -.57292400E+00, -.58146200E-01, -.61893100E-01, 0.23033700E+00, -.48921700E+00, -.97518400E+00, -.76550400E-01, 0.10732800E+01, 0.57350300E-01, 0.80203900E+00, 0.50174300E+00, 0.31023900E-01, 0.29596000E-01, 0.59286000E-01, 0.84156500E+00, -.18137300E+01, -.35032700E+00, -.37993400E+00, 0.15517200E+00, 0.80703200E+00, 0.62730700E+00, -.79680400E+00, 0.52816300E-01, -.31546000E+00, -.12316200E+00, -.11100500E+00, -.57561900E+00, -.10776100E+00, 0.15037600E+00, 0.31695200E+00, 0.62654600E+00, -.16046700E+01, 0.14311500E+00, -.59636400E+00, -.18316400E+00, 0.10951700E+00, -.11080300E+00, 0.24414100E+00, -.20926400E+00, -.25740200E-01, 0.12109300E+00, -.13094100E+01, -.77990400E+00, -.33971100E+00, -.19985400E+00, 0.90485300E+00, 0.17444700E+00, 0.67974600E+00, -.84388400E-01, -.81460800E-01, -.84388000E-01, -.55929800E+00, -.27646100E+00, -.14166200E+00, -.73189200E-01, -.31342900E+00, 0.74253800E+00, 0.28263500E+00, 0.56332200E+00, -.13227300E+00, 0.45644700E+00, 0.28610600E+00, 0.65170200E+00, 0.22508100E+00, -.39800100E+02, -.35496400E+03, 0.19244300E+03, 0.17671200E+03, 0.12190800E+02, -.34140100E+02, 0.14059800E+03, 0.12729200E+03, 0.12222600E+03, 0.26755400E+02, -.24862600E+02, 0.13027700E+02, 0.12880500E+02, -.27088300E+02, -.29144300E+01, 0.13100500E+02, 0.21757000E+01, 0.33264600E+01, -.90112800E+01, -.13680700E+03, 0.68579200E+02, 0.68094800E+02, -.93299500E+00, -.31137500E+02, 0.53479800E+02, 0.33564200E+02, 0.66555500E+02, 0.93246700E+00, -.34134000E+03, 0.17166800E+03, 0.16733000E+03, -.25337100E+02, 0.21705600E+02, 0.12061200E+03, 0.33791500E+02, 0.12995500E+03, -.12434300E+02, -.18468800E+03, 0.94884500E+02, 0.85432500E+02, -.11558800E+03, -.29204900E+02, 0.99992700E+02, 0.56915300E+02, 0.11419600E+03, -.17852200E+02, 0.18525900E+02, -.31915800E+02, -.97486400E+01, -.92254100E+02, 0.37010000E+02, -.90584700E+01, -.45704000E+02, -.50193000E+01, 0.16587400E+02, 0.38330200E+02, -.20148300E+02, -.20251700E+02, 0.19188000E+02, 0.46745600E+02, -.46959800E+02, -.83800700E+02, -.40094600E+02, 0.54327000E+02, 0.28543700E+02, -.19041700E+02, 0.33974700E+01, 0.21730800E+01, -.19008100E+02, 0.18582600E+02, -.10060400E+02, 0.17097500E+02, 0.63779100E+02, 0.84266100E+02, 0.13917100E+02, 0.14895100E+01, 0.96762300E+01, 0.42344300E+02, -.14960600E+02, 0.10752600E+02, -.10849500E+02, 0.12097500E+02, 0.45880900E+02, 0.25528400E+02, -.92344500E+01, -.74738600E+01, 0.15927800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10882000E+02, -.13525600E+01, 0.11392600E+02, 0.44492000E+01, -.13809000E+02, -.42290700E+00, 0.94621600E+01, 0.19563900E+01, -.25386800E+00, -.44341200E+00, -.79122700E+01, 0.48286800E+01, -.18795100E+01, 0.26546000E+01, 0.14134600E+01, -.17504200E+01, 0.10632100E+00, 0.46659200E+00, 0.32694400E+01, 0.88932700E+00, 0.45723000E+01, 0.59455100E+00, -.15790700E+01, -.69722800E+00, -.32907700E+01, 0.86371700E+00, 0.36737000E+01, -.36955700E+00, -.80178100E+01, 0.13718300E+01, -.61530200E+00, 0.10814500E+01, -.10577900E+01, -.26125100E+00, -.16622300E+01, -.15480500E+01, -.13505100E+01, -.14222900E+00, -.15544600E+01, 0.20774700E+01, -.31589100E+01, 0.35553900E+00, -.28672500E+00, 0.13941600E+00, -.19091400E+01, -.74391200E+00, -.25852600E+00, 0.16910000E+01, 0.80215300E+01, 0.12970200E+00, -.12257400E+01, -.10601400E+00, -.20371700E+01, 0.38510100E+01, 0.15176000E+01, -.12071000E+01, -.39417100E+00, -.82151700E+00, 0.12963100E+01, -.11266400E+00, -.15310700E+01, -.30550100E+01, 0.39399700E+01, 0.18610300E+01, -.17258400E+00, 0.11004100E+01, -.32152000E+01, -.38097400E+00, -.21821700E+01, -.12694300E+01, -.26022400E+00, -.75640900E+00, 0.98282900E-01, 0.42184800E+00, -.13274300E+01, -.19434400E+01, -.11836900E+01, -.92239500E+00, 0.99471600E-01, 0.17765300E+00, -.47615200E+00, -.40628700E+00, -.25998900E+00, 0.66617000E-01, -.52095300E+00, 0.42995800E+01, 0.93325800E-01, -.10113900E+01, 0.90124700E+00, -.22542200E+01, -.49340000E+00, -.64830300E+00, 0.69653800E-01, -.13728500E+01, -.28156000E+00, -.98293600E+00, 0.32342200E+00, 0.67900400E-02, 0.16535500E+00, -.38100200E+00, -.86608700E+00, -.21343600E+00, -.46099700E+00, -.13672300E+00, -.22134700E+00, -.19662300E-02, -.45853400E-01, 0.65647700E+00, 0.39289000E-01, -.32895800E-01, -.95336300E+00, 0.29165300E+01, -.18838000E+01, 0.46073800E+00, 0.91567700E+00, 0.35708100E+00, 0.12697100E+01, -.54358900E+00, -.16363200E+00, -.74147800E-01, -.94902000E-01, 0.82298500E+00, -.67501500E-01, 0.68491000E+00, -.31379300E-01, -.29813600E+01, -.82776900E+00, 0.30725900E+00, -.61651100E+00, -.28438500E-01, 0.15659100E+01, 0.11312300E+00, -.29551800E+00, -.78356000E-01, 0.27609800E-01, 0.94680100E+03, -.47825500E+03, -.46583500E+03, 0.22946400E+03, 0.62067500E+02, -.43443900E+03, -.41779000E+03, -.44674800E+03, -.64291800E+02, 0.26012900E+02, -.14461200E+02, -.12748500E+02, -.38578000E+02, -.29569900E+02, 0.34369800E+02, 0.77962100E+02, 0.51087200E+02, -.22449000E+02, -.69303500E+03, 0.34874200E+03, 0.34485300E+03, 0.12923600E+03, 0.84462500E+02, 0.14169600E+03, -.19444500E+03, 0.69752400E+02, 0.98109200E+02, -.44991400E+03, 0.23002400E+03, 0.21976300E+03, 0.90636300E+02, 0.10377200E+03, 0.10526200E+03, 0.24621200E+02, 0.82903400E+02, 0.98474100E+02, 0.25774200E+03, -.12208800E+03, -.11602900E+03, -.48931200E+02, 0.26374800E+02, -.84176500E+02, -.22355700E+02, -.24890700E+02, -.16755400E+02, -.27306800E+03, 0.13293300E+03, 0.13663300E+03, -.14994700E+02, -.64310600E+02, 0.14439300E+03, 0.18233000E+03, 0.15434800E+03, -.27311100E+02, -.16624600E+03, 0.83534100E+02, 0.80811100E+02, 0.45448800E+02, 0.10492200E+03, -.22339000E+02, -.19176800E+03, -.36719900E+02, 0.10740700E+03, -.40773800E+00, 0.38747200E+02, -.20211100E+01, -.25096800E+02, 0.56869100E+01, -.40483000E+02, -.94806200E+01, -.50808300E+01, 0.94704400E+02, 0.11350400E+03, 0.11857600E+02, -.26513700E+02, 0.37976100E+01, -.45779100E+02, -.12860300E+02, 0.14169700E+02, 0.17149600E+02, 0.31802400E+02, -.39870900E+02, 0.94577300E+01, -.22549000E+02, 0.20275000E+02, -.86420400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.48509700E+01, -.16970400E+01, 0.51776700E+01, 0.21262200E+01, -.30173000E+01, 0.98460300E-02, 0.72821800E+01, 0.31695400E+01, -.29540800E+00, -.70820400E+00, -.74747300E+00, 0.18350800E+01, -.14107800E+01, 0.17903300E+01, 0.75006600E+00, -.92836700E+00, 0.16935100E+00, 0.55927700E+00, 0.13049500E+01, -.14662300E+00, 0.30296500E+01, 0.13240300E+00, -.24894600E+00, -.40295800E+00, 0.55210000E-01, 0.73036700E+00, -.81831900E+00, -.80376600E+00, -.15957200E+00, 0.94473200E+00, -.36413500E+00, -.53372400E+00, 0.57540500E-01, -.81463700E-01, 0.10963100E+01, -.17479000E+01, 0.19795200E+00, -.52863600E+00, 0.86065500E+00, 0.11802600E+01, 0.38574200E+00, -.25784600E-02, 0.36080800E+00, 0.35329900E+00, -.11355300E+01, -.64799300E+00, 0.66553300E+00, -.67717600E+00, -.48692800E+00, 0.69347300E+00, 0.23045800E+00, 0.22383300E+00, 0.35878000E+00, -.19043400E+00, -.17230700E+00, 0.34219100E+00, 0.71125400E-02, 0.69630700E-01, -.24825700E+00, -.20807900E+00, 0.41179800E+00, 0.13680000E+01, -.11838200E+01, -.15082900E+01, 0.45264400E+00, 0.28111800E+00, 0.11513800E+01, -.61183800E+00, -.11907700E+01, 0.44084600E+00, 0.10280000E+01, 0.54411900E+00, 0.93135300E+00, 0.30449900E+00, -.37981600E+00, 0.10440100E+01, 0.47199500E+00, -.65771400E-01, -.28456500E+00, 0.10768200E+01, -.36400000E-01, -.12949100E+01, -.67446100E-01, -.12151800E+00, -.20444200E+00, -.24064200E+00, -.10070800E+00, 0.40237400E+00, -.11324300E+01, -.70323300E+00, -.10276300E+01, 0.39056500E+00, 0.88573200E-02, -.68935100E+00, 0.28992000E+00, -.22074200E+00, 0.40386200E+00, -.21208800E+00, 0.10297500E+00, -.11189100E+01, 0.18066700E+00, 0.18742600E+01, 0.10401200E+00, 0.14717000E+01, 0.91944600E-01, 0.31217800E+00, 0.10340400E+00, -.47124900E+00, -.15777700E+00, 0.29220300E-01, 0.26204200E+00, 0.75348500E+00, 0.38945900E+00, -.37422600E+00, 0.33075800E+00, 0.80433000E+00, 0.10826300E+00, -.22422200E+00, 0.50042900E-01, 0.93590700E-01, 0.22448400E+00, 0.38961900E-01, 0.12477600E+00, 0.47347400E+00, -.11939800E+00, 0.43548200E+00, -.33118200E-02, -.14727600E+00, 0.49209600E+00, 0.23565100E+00, 0.12574400E+00, -.63370100E-01, 0.37128200E-01, -.93791100E-01, 0.17944000E+00, -.17144800E+00, 0.39754900E+02, 0.25420900E+01, 0.42430400E+01, -.13926500E+02, 0.45676000E+01, 0.39258200E+02, 0.55333600E+01, -.24194600E+02, 0.21091600E+02, -.86101100E+01, -.93789200E+01, -.98395500E+01, 0.39180100E+01, -.60888500E+01, -.24791800E+01, -.36196100E+01, -.71998300E+01, 0.79594900E+02, -.41895800E+02, -.39975700E+02, 0.46326100E+02, 0.19400900E+02, -.41599300E+02, -.53213700E+01, -.59834300E+02, -.16725200E+01, -.25012200E+01, -.22931400E+01, 0.91316800E+00, 0.74759600E+02, 0.53401200E+02, -.39238600E+02, -.41156300E+02, -.51114000E+02, 0.38401400E+02, 0.20050700E+03, -.11508500E+03, -.91988500E+02, -.14262300E+02, 0.94706000E+01, -.89397800E+02, -.10920300E+03, -.71411700E+02, -.22788700E+02, 0.15758200E+03, -.29567200E+02, -.78183300E+02, -.16830000E+02, 0.12318200E+02, -.64316700E+02, -.70309200E+02, -.59965400E+02, 0.22845600E+02, 0.25257900E+02, -.19054200E+02, -.15497400E+02, 0.11014100E+02, 0.16696000E+02, -.17082300E+02, -.20928100E+02, -.24863700E+02, 0.23584700E+02, 0.24206300E+01, 0.40228700E+02, -.10615800E+02, -.10666400E+02, 0.59524400E+01, -.40340800E+02, -.44429600E+01, -.58797400E+01, 0.18161700E+02, 0.29357000E+02, 0.16497900E+01, -.10603700E+02, 0.43504500E+01, -.52632900E+02, -.79280500E+00, 0.53423900E+01, -.24867100E+02, -.64963700E+01, -.51088600E+02, -.64613500E+01, 0.19304300E+01, -.15885700E+02, 0.63190000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.48356300E+01, 0.41024100E+00, 0.68650900E+01, 0.28129800E+01, -.94036200E+01, -.29004100E+00, 0.10626700E+02, 0.69711700E+01, -.72277700E+00, -.83425100E+00, -.32798900E+01, 0.21893900E+01, -.16925000E+01, 0.27722700E+01, 0.14301000E+01, -.18165400E+01, -.21725300E+00, 0.43430400E+00, -.30677300E-02, -.24420200E+01, -.12748200E+01, 0.43640200E+00, 0.31976200E-01, -.61671100E+00, 0.65019700E-01, 0.31389200E+00, -.78390600E+00, 0.33959600E+00, -.28242600E+01, 0.15586200E+01, -.84639200E-01, 0.10271300E+01, -.99675200E+00, -.10023700E+01, 0.88862100E+00, -.12554300E+01, 0.33737900E+00, 0.70175200E+00, 0.43819100E+00, 0.27634300E+01, 0.10180000E+01, 0.28264800E+00, -.55556700E+00, -.55533600E+00, -.21243700E+01, -.17635500E+01, 0.76652900E+00, -.97228700E+00, 0.15123500E+01, 0.65856800E+00, 0.11230100E+00, 0.34208000E+00, 0.21361500E+00, -.10148400E+01, 0.89100900E+00, -.13595900E+01, -.23566900E+00, -.13327800E-01, 0.17779900E+00, 0.72799700E+00, 0.29621700E+00, 0.12406300E+01, -.16304200E+01, -.33256500E+01, 0.63057700E+00, 0.15438700E+00, 0.94920800E+00, -.33869000E+00, -.86283200E+00, -.61922100E-02, 0.13580400E+00, 0.53863400E+00, 0.10357900E+01, 0.25751700E+00, -.97358300E+00, 0.30701900E+00, -.97746100E-01, 0.81139500E+00, -.15427500E+00, 0.61560900E+00, 0.30970900E+00, -.15297400E+01, 0.10399100E+00, -.17858600E+00, -.87256000E-01, -.17107400E+01, 0.51500400E-01, 0.79834900E+00, -.18359800E+01, 0.15230800E+01, -.84626400E+00, 0.11617300E+01, -.26026600E+00, 0.22318400E+01, 0.12312500E+00, 0.45226000E+00, 0.10637800E+01, -.30256300E+00, -.25958700E-01, -.47406400E+00, 0.44084500E+00, 0.23702400E+01, 0.14526400E+00, 0.12204100E+01, -.79037500E-01, 0.23910000E+00, 0.25264700E+00, -.16724200E+00, -.40618700E-01, -.47320000E-01, 0.20285800E+00, 0.60579700E+00, 0.79763300E-01, -.22800900E+00, 0.31085600E+00, 0.96600400E+00, 0.26775400E+00, 0.21248500E+00, -.52558200E-01, 0.45337500E-01, 0.10319700E+00, 0.21759300E+00, 0.83367500E-01, 0.51882600E+00, -.23881600E+00, 0.86053400E+00, 0.21313900E+00, -.31685700E-03, 0.18097600E+00, -.37606400E+00, -.57056400E-01, -.31408900E+00, 0.57344700E+00, 0.15595200E-01, 0.27250900E+00, -.40158900E+00, -.21173100E+00, 0.59893300E+01, 0.67934400E+02, -.65137500E+01, -.11468300E+02, -.18539000E+00, -.25751000E+02, -.88468900E+01, 0.45367400E+02, -.25265400E+02, -.22311000E+02, -.26296200E+02, -.39806100E+00, -.12641500E+02, 0.47725400E+01, -.59843500E+01, -.18800600E+02, 0.90737400E+02, -.42946800E+02, -.46281800E+02, 0.54714200E+02, 0.15121800E+02, -.51271800E+02, -.11470800E+02, -.79418500E+02, -.53137000E+01, -.11034500E+03, 0.61723600E+02, 0.54055900E+02, 0.12391100E+03, 0.80737700E+02, -.24650100E+02, -.40779700E+02, -.59760700E+02, 0.69803700E+02, 0.30609700E+03, -.14528400E+03, -.14251400E+03, -.21415900E+02, 0.21842600E+02, -.12187500E+03, -.10897200E+03, -.93779000E+02, -.35811700E+02, 0.12943900E+03, -.36981400E+02, -.64144000E+02, -.63685300E+02, -.20811200E+02, -.48646000E+02, -.72812700E+02, -.21033400E+02, -.20434000E+02, 0.16164900E+02, -.32874000E+01, -.98860300E+01, 0.32449900E+02, 0.53470200E+02, -.37942100E+02, -.84049100E+02, -.79409600E+02, 0.70276700E+02, 0.12182800E+02, 0.60095800E+02, -.15272600E+02, -.21056300E+02, 0.26752800E+01, -.59907600E+02, -.12180400E+02, -.30407700E+01, 0.16289200E+02, 0.34560200E+02, 0.93380500E+01, -.21426700E+02, 0.93761600E+01, -.74713000E+02, -.81508500E+01, 0.16495900E+02, -.15988700E+02, -.73008700E+01, -.74265400E+02, -.99659200E+01, -.78632200E+01, -.32801600E+01, 0.14146700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.86333100E+01, 0.64726800E+00, -.12569900E+02, -.45447300E+01, 0.10026700E+02, 0.24013800E+00, -.14090600E+02, -.66094600E+01, -.14028700E+01, 0.38031700E-01, 0.50460200E+01, -.30634400E+01, 0.25633100E+01, -.56487600E+01, -.10624400E+01, 0.12599800E+01, 0.20662000E+01, -.45844800E+00, -.70553900E+00, 0.65530900E+00, -.32053100E+01, 0.71754600E-01, 0.31124100E+00, 0.95947000E+00, 0.14418700E+01, -.59173800E+00, -.51754700E+00, 0.73710000E+00, 0.76170800E+01, -.16596800E+01, 0.27712400E+00, -.28094100E+01, 0.15995500E+01, -.20955600E+01, -.27441900E+01, -.16166800E+00, 0.46783200E-01, 0.68082200E-01, -.12037600E+01, -.12515500E+01, 0.10945900E-01, 0.14498000E+00, -.64389900E+00, 0.96781800E+00, 0.50620300E+01, 0.16318500E+01, -.19116600E+00, 0.47447000E+00, -.49670200E+01, -.23629900E+01, 0.78353500E+00, -.44628200E+00, 0.63172500E+00, 0.17500000E+01, -.23512000E+00, 0.53722400E+01, 0.11241600E+01, -.79613400E-01, -.14394900E+01, 0.27823700E+00, 0.24009900E+00, -.26702600E+01, 0.92175900E+00, 0.28078200E+01, -.18711800E+00, -.80411100E-02, -.95515200E+00, 0.36038400E+00, 0.10729700E+01, -.62335000E+00, -.19073600E+00, -.17297200E+00, -.46074800E+00, -.46332800E-01, -.75962700E-02, 0.55331800E+00, 0.24770000E-01, -.20035600E+01, 0.88281800E+00, -.55411700E+00, 0.59128600E+00, -.10614500E+01, 0.39789300E+00, -.38704400E+00, 0.30513900E+00, -.32511700E+01, -.43337800E+00, 0.10932200E+00, 0.52167500E+00, 0.63878100E+00, 0.70615000E+00, 0.14994200E+01, 0.22494100E+00, 0.34346600E+01, 0.50445100E+00, 0.67447900E+00, 0.59850900E-01, 0.99812600E+00, -.43776500E+00, 0.23218900E+01, 0.12303400E+01, -.90191600E+00, 0.93952000E+00, -.12726100E+01, 0.79076000E-01, 0.14992400E+00, -.23963500E+00, 0.58450000E+00, -.10093900E+01, 0.52525900E-01, 0.14324700E+00, -.42522400E+01, -.25053000E+01, -.15196800E+01, -.28872500E+00, 0.57059200E+00, 0.61471900E-01, 0.11909200E+00, -.18346100E+00, 0.13300600E-01, 0.64126500E+00, 0.12018500E+01, -.24496800E+00, 0.39089000E+00, -.51284800E+00, -.96117600E+00, -.11435300E+01, -.16092000E-01, 0.19598400E+01, -.18198500E+01, 0.13754100E+01, -.73014700E-01, 0.46378800E+00, -.31237000E+00, -.37328800E+00, -.81792400E+00, -.67437700E+00, 0.28054500E+00, 0.48567300E+03, 0.57893700E+02, -.60443600E+02, -.16058800E+03, -.14005500E+03, 0.60339000E+02, 0.12547900E+03, -.70133100E+02, -.68964800E+02, -.11309600E+03, -.46780800E+02, -.47822200E+01, 0.40957100E+02, 0.85282300E+02, -.10409100E+03, -.38147100E+03, 0.19641800E+03, 0.19003000E+03, 0.71040900E+02, 0.72229600E+02, 0.45750800E+02, -.13328500E+03, -.13778100E+03, 0.10710200E+03, -.52797700E+03, 0.29135600E+03, 0.27583300E+03, 0.18005400E+03, 0.41921100E+02, 0.11659200E+03, 0.77912300E+01, -.36747700E+02, 0.14583700E+03, -.16628100E+03, 0.12624100E+03, 0.97690900E+02, -.68860200E+01, 0.38832300E+02, 0.74557200E+02, 0.74107700E+02, 0.15974800E+03, 0.31331300E+02, -.27814900E+03, 0.22703600E+03, 0.14008500E+03, -.15253100E+03, -.88158600E+02, 0.11525700E+03, -.15027200E+02, 0.21804300E+03, -.21216000E+03, -.48664800E+02, 0.34162200E+02, 0.36236100E+02, 0.14786000E+03, 0.22488300E+03, -.13255700E+03, -.43302400E+03, -.27843500E+03, 0.25686500E+03, 0.23077500E+02, -.71493100E+00, 0.35434600E+02, -.10105500E+03, 0.50486400E+01, -.12007700E+01, -.17029800E+02, -.34095200E+01, -.42155800E+02, -.32817200E+02, 0.12185700E+02, -.99177900E+02, 0.13517000E+02, 0.21948000E+02, -.25903900E+02, 0.21690500E+02, 0.54301800E+02, -.16838900E+02, -.12496300E+02, -.62283800E+02, -.51114600E+02, 0.59701400E+02, 0.38536800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.15815800E+01, -.86556000E+00, 0.15858900E+01, 0.80966800E+00, -.42322000E+01, 0.17849300E+00, 0.56691500E+01, 0.27159800E+01, -.93071300E+00, -.33844500E+00, -.15515900E+01, 0.52518500E+00, -.14403000E+01, 0.17053700E+01, 0.23697900E+00, -.41567000E+00, -.65510800E+00, -.26950200E+00, -.29423800E-01, -.15836600E+00, 0.14287100E+01, 0.23108600E+00, -.30175200E+00, -.35493800E+00, 0.85724000E-02, 0.23671000E+00, 0.11230600E+00, -.13983300E+00, -.16269600E+01, 0.10045900E+01, 0.31791500E-01, 0.59273900E+00, -.28581300E+00, 0.36656100E+00, 0.72606400E+00, -.54086900E+00, -.82990200E-01, 0.70136500E-01, 0.46622400E+00, -.73021300E+00, -.67944100E+00, -.31985500E+00, 0.16361300E+01, 0.34618500E+00, -.18961500E+01, -.25123800E+00, -.24899200E+00, 0.96017400E+00, 0.65769900E+00, 0.21773000E+01, -.73111100E-01, 0.23767700E+00, 0.17238600E+00, 0.25671300E+00, -.63647400E+00, -.73689300E+00, -.28727800E+00, -.27808200E+00, 0.28621400E+00, -.50124800E+00, 0.62570300E-03, 0.45254100E+00, 0.10240400E+01, -.23703000E+00, 0.34900300E+00, 0.41956500E+00, -.67834800E-01, -.20563600E+00, -.75758200E+00, -.29589000E+00, -.44948900E+00, 0.20778500E+00, 0.40200800E+00, 0.28439500E+00, -.94938800E+00, 0.38013300E-01, 0.50671300E-02, 0.14390100E+01, 0.25846700E-01, 0.37913100E+00, 0.32204800E+00, 0.11586000E+00, -.34333500E-01, 0.16146300E-01, -.58415900E+00, 0.38421900E-01, 0.43495000E+00, 0.66143000E+00, -.40279400E+00, 0.14688500E+01, -.56990000E-01, 0.27336000E+00, -.13371600E+00, 0.54264800E+00, 0.36959500E+00, 0.34572400E+00, 0.10129000E+00, 0.15197500E-01, -.24241200E+00, -.61431800E+00, 0.74621600E+00, 0.72799000E+00, 0.63831300E+00, -.23717600E+00, 0.47325100E-01, 0.12849900E+00, 0.34991900E-01, -.27106900E+00, 0.20289000E-01, 0.21480100E-01, -.51518700E-01, 0.65772800E+00, 0.97014500E+00, 0.24173800E+00, 0.32744900E-01, 0.55316500E+00, -.19511700E+00, -.49475000E-01, -.49429300E-01, -.14287900E-01, -.96814900E-01, -.26689300E-01, 0.15742000E+00, 0.66978600E+00, 0.27872200E+00, -.74892400E+00, -.86624800E-01, -.21821000E+00, -.80402200E+00, -.42143000E+00, -.55194200E+00, -.28472500E+00, 0.59923800E-01, -.68358900E+00, -.14390300E+00, -.12231500E+00, -.12978000E+00, 0.12924400E+00, -.86091500E-01, -.57977700E+02, 0.45219100E+02, 0.13893400E+03, 0.71454400E+02, -.95787600E+02, -.20442600E+02, 0.81447800E+01, 0.89637800E+01, -.21149100E+02, 0.13783200E+02, 0.20349200E+01, -.10471700E+02, -.11433500E+02, 0.84563800E+01, -.10988500E+03, 0.54751800E+02, 0.54720400E+02, 0.66884000E+01, 0.14802700E+02, 0.31951600E+02, 0.22588000E+02, -.15474800E+02, 0.22470000E+02, -.16042200E+03, 0.89559300E+02, 0.83269700E+02, 0.45678300E+02, 0.37265500E+02, 0.34055400E+02, 0.20220400E+02, -.48520200E+02, 0.56258400E+02, -.90569700E+02, 0.50664400E+02, 0.48805800E+02, -.10105600E+03, -.12236300E+01, 0.41236000E+02, 0.36077300E+02, 0.62326500E+02, 0.36275100E+02, 0.19944700E+03, -.50982200E+02, -.98734500E+02, -.40288800E+02, 0.16430600E+02, -.93104900E+02, -.15060600E+03, -.82912200E+02, 0.69044300E+02, 0.38991900E+02, -.20833500E+02, -.17416400E+02, 0.12482500E+02, 0.43176000E+02, -.36739200E+02, -.96887400E+02, -.36490500E+02, 0.46875300E+02, 0.78393400E+01, 0.50321700E+01, 0.56729900E+01, -.91961400E+01, -.38523700E+00, -.52501800E+01, -.10796700E+02, -.17956900E+01, -.23499700E+02, -.10699000E+02, 0.61060200E+01, -.89090700E+01, 0.80437700E+01, 0.73246400E+00, -.65764000E+01, 0.10439400E+02, -.83523600E+02, -.15054400E+00, -.63629200E+01, 0.10782800E+01, -.64814700E+01, -.61314800E+02, 0.13160900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.34534200E+01, -.86071400E+00, 0.23840900E+01, 0.16548000E+01, -.14037500E+02, 0.21302400E+00, 0.14790000E+02, 0.76364000E+01, -.30544100E+00, -.95597200E+00, -.49808900E+01, 0.25335300E+01, -.34845500E+01, 0.33781000E+01, 0.14541700E+01, -.17756500E+01, -.34442800E-01, 0.70443200E+00, 0.27209100E+01, -.13321700E+01, 0.61557800E+01, 0.63115200E+00, 0.14577800E+00, -.18791500E-01, -.71257100E+00, 0.18188900E+01, 0.16017900E+01, 0.53237400E-01, -.17073200E+01, 0.24287700E+01, -.36746400E+00, 0.11784300E+01, -.56168500E+00, -.93359800E+00, -.32690300E+00, -.61565500E-01, -.14218400E+00, 0.47466500E+00, -.31753500E+01, -.84164100E+00, -.11331300E+01, -.88172200E-01, -.32924200E+00, 0.35618200E+00, 0.11881500E+01, 0.25215400E+00, -.69169700E-01, 0.89315300E+00, -.51353000E+00, 0.25859200E+01, 0.65653400E-01, 0.39254500E+00, -.41292100E+00, 0.30484400E+00, -.28756300E+00, -.14856300E+00, 0.57018200E+00, -.35165100E+00, 0.22819000E-01, 0.72664100E+00, 0.46057500E+00, -.14770300E+01, 0.83402700E+00, 0.78234000E-01, -.51509900E+00, 0.29300400E-01, -.13839900E+01, 0.55380500E+00, 0.25173600E+01, -.19345500E-01, -.17942700E+01, -.68364200E+00, -.20346600E+01, 0.41015500E+00, -.30866000E+00, -.83372400E+00, 0.73841000E-01, 0.48844500E+00, 0.70306600E-01, 0.98537800E+00, 0.10088200E+00, 0.76793300E-01, 0.21094400E-01, -.96197300E-01, 0.51264100E+00, -.84818600E+00, -.65283400E+00, -.19824500E+00, -.14480300E+01, -.21246000E+01, -.55361600E-01, -.23467200E+00, 0.40153300E+00, -.21364600E+01, 0.81792800E-01, 0.38601600E+00, -.15007700E+00, 0.17660400E+00, -.57103200E-01, -.85388600E+00, 0.11044200E+01, -.13101100E+01, 0.27392700E-01, 0.98396000E+00, -.12064800E+00, 0.21195200E+00, 0.57388600E-01, 0.13799100E+00, -.24720500E+00, 0.23573300E-01, -.13826700E+00, 0.37382500E+00, 0.53992900E+00, 0.76185900E+00, 0.61919500E+00, 0.10355700E+01, 0.11684900E+00, -.32240200E+00, -.28192700E+00, 0.88918900E-01, 0.51250000E+00, -.67287200E+00, -.47144600E+00, -.25892900E-01, 0.13081400E+00, 0.20296500E+00, 0.61598600E+00, -.21709000E+00, 0.67422000E-01, 0.50239600E-01, -.78193300E-01, 0.19070400E-01, -.97367300E+00, 0.10680500E+00, -.12718700E+00, -.60334500E-02, 0.35892700E-01, -.37892400E+00, 0.12212900E+00, -.11640400E+01, 0.52122200E+02, 0.11382000E+03, 0.61614900E+02, -.70668200E+02, 0.28546700E+01, 0.18969600E+00, -.34470700E+01, 0.18032100E+02, -.13182900E+01, -.60860100E+01, -.14948600E+02, -.10709600E+02, 0.44101400E+01, 0.24430200E+03, -.12544500E+03, -.12208200E+03, -.53449200E+02, 0.70091300E+01, -.71991800E+02, -.38224700E+00, -.12306900E+03, -.66489900E+01, 0.29416100E+03, -.15128500E+03, -.14190200E+03, -.52342900E+02, -.49845600E+02, -.67345600E+02, 0.15753700E+02, -.12381300E+03, 0.45297700E+01, -.22542700E+03, 0.99360700E+02, 0.11746900E+03, 0.50574900E+02, 0.57589500E+02, 0.11016300E+03, 0.18183700E+03, 0.10874200E+03, 0.12229900E+03, 0.69938000E+01, 0.48851300E+02, -.31537700E+01, 0.77346000E+02, 0.31639300E+02, -.21980300E+02, -.20676400E+02, -.31522600E+02, 0.72574500E+02, -.61517600E+02, 0.23401700E+02, 0.35479900E+02, 0.12601500E+02, -.52399300E+01, 0.39212400E+02, 0.37332000E+02, 0.38051000E+02, -.11194000E+02, -.24083300E+02, -.41446700E+02, 0.36621100E+02, 0.95677200E+01, 0.15853800E+02, 0.41671000E+02, 0.13891900E+02, -.16334300E+02, -.67139300E+02, -.83570300E+02, -.15574300E+02, 0.10476900E+02, -.10289500E+02, 0.67360900E+02, 0.14501400E+02, -.17449000E+02, -.60543700E+02, -.15166600E+02, 0.46574200E+02, -.17805300E+02, -.11167600E+02, -.34855400E+02, -.93092500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.15605700E+01, 0.26342200E+00, 0.11118400E+01, 0.29317600E+00, -.22718000E+00, -.22448800E+00, 0.11670700E+01, 0.29288200E+00, -.12701500E+00, -.13510600E+00, -.20437400E+00, 0.38670500E+00, -.19696100E+00, 0.83159600E+00, -.97052700E-02, -.24443000E+00, -.19666500E+00, -.14401300E+00, 0.41163800E+00, 0.16693600E+00, 0.58671400E+00, -.56882900E-01, -.38487900E-01, -.30872800E-01, -.88239900E-01, 0.46756500E-01, -.90592900E-01, -.93689400E-01, -.38217800E-01, 0.47102700E-01, 0.31766700E-02, -.12817100E+00, -.15649100E+00, 0.90919900E-01, 0.16191700E+00, 0.20492900E+00, 0.85858200E-01, -.12699600E+00, 0.58973600E+00, 0.71144000E-02, 0.68975200E-01, -.56999800E-01, 0.10724600E+00, 0.51801900E-02, -.16916100E+00, -.21519000E+00, 0.49818200E-01, -.25085100E+00, -.11700500E+00, 0.23916900E+00, -.10738400E-01, 0.22805300E-01, 0.14059600E-01, -.25900100E+00, 0.49900500E-01, -.23424300E+00, 0.29863600E-01, -.19080900E-02, 0.71222700E-01, -.14981800E+00, -.19310800E+00, 0.31392300E+00, 0.54652500E-03, -.40404200E+00, 0.22376900E+00, 0.16598600E+00, 0.16526300E+00, -.58875600E-01, -.21730500E+00, -.52806300E-01, -.14919900E+00, 0.15690800E+00, -.13129200E+00, 0.86774800E-01, -.27453500E+00, 0.29986600E+00, 0.17574600E+00, 0.38633000E+00, 0.41212800E-01, 0.23127300E+00, 0.79433800E-01, -.20930700E+00, -.10732600E-02, -.30579900E-01, -.18209600E+00, 0.38252900E+00, 0.34251800E-01, -.73264700E-01, 0.17092800E+00, 0.75960800E-01, 0.34847800E-01, 0.41898200E-01, -.10916100E+00, 0.90867300E-01, -.40894300E-01, 0.50227900E-01, -.57088800E-01, -.93203000E-01, 0.40206900E-01, 0.20502300E+00, 0.11430100E+00, -.56486800E+00, 0.38981600E-01, -.12226200E-01, -.62919800E-01, 0.15583500E+00, -.17697300E-01, 0.81441400E-01, 0.60172300E-01, -.90949900E-02, 0.16693700E-01, 0.21696400E+00, 0.27908100E+00, -.22293600E+00, 0.14519800E+00, -.13491200E-01, 0.42632100E-01, 0.77452400E-01, -.21726600E-02, 0.22574300E-03, -.45806300E-01, -.71816600E-01, -.32171800E-02, 0.24737900E-01, 0.12419800E+00, -.38498700E-01, -.17542500E+00, -.38686500E-01, 0.36936600E+00, 0.93646900E-01, 0.81000700E-01, 0.23094100E+00, 0.72725500E-02, 0.28867000E+00, -.84927800E-01, 0.80530000E-02, 0.12098200E+00, -.13685600E+00, 0.40945300E-01, -.31342800E+00, 0.78355200E-01, 0.12297000E+02, -.10112800E+02, 0.19914400E+01, -.64780300E+01, 0.27262000E+01, 0.25494800E+01, -.30064700E+01, -.33364800E+01, 0.60418400E+01, -.36982800E+01, 0.25324500E+01, 0.44280500E-01, -.12067400E+02, 0.64229600E+01, 0.60375100E+01, -.41223000E-01, 0.36141300E+01, 0.10964600E+01, -.49618200E+01, -.81419700E+01, 0.50303600E+01, -.13549900E+02, 0.92434100E+01, 0.80469500E+01, -.26760700E+01, 0.23038300E+01, 0.90261700E+01, 0.10518300E+02, -.43983800E+01, -.25676200E+01, -.45217100E+02, 0.26792800E+02, 0.22789300E+02, -.11612800E+02, 0.13842200E+01, 0.23344900E+02, 0.80356500E+01, 0.29486200E+02, -.19459000E+01, -.49380300E+02, 0.23268700E+02, 0.24876900E+02, -.20717100E+02, -.64536400E+01, 0.22856100E+02, 0.79767400E+01, 0.33904900E+02, 0.50210700E+01, 0.31915700E+01, -.12619000E+01, -.90079000E+00, 0.10032500E+02, 0.19505600E+02, -.16581100E+02, -.52322200E+01, -.15957200E+02, 0.18930300E+02, 0.45225800E+01, -.31596500E+01, 0.54626400E+01, 0.45764200E+01, -.18596700E+01, 0.30071500E+01, 0.21310500E+00, 0.21865500E+01, 0.13489600E+01, 0.45074800E+01, 0.19964500E+01, 0.50750800E+01, 0.33420800E+00, 0.65287000E+01, -.19754700E+01, -.38653200E+01, -.13843600E+00, 0.55047200E+01, 0.43603600E+01, 0.46492800E+01, -.51877900E+01, -.47902400E+01, 0.74852400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20918100E+01, -.58314300E+00, -.26270000E+01, -.75183600E+00, 0.10107900E+01, 0.59915900E+00, -.27999800E+01, -.10030300E+01, 0.11109700E+01, 0.46314700E+00, 0.78201000E+00, -.89201700E+00, 0.41722500E+00, -.12204200E+01, -.29518100E+00, 0.35227900E+00, -.21288400E+00, -.87324800E-01, -.13470600E+00, 0.29696600E+00, -.45571900E-01, -.11958900E+00, 0.30184300E+00, 0.17998900E+00, 0.50220200E+00, -.95010100E-01, -.49939800E+00, -.13531500E-01, 0.70617700E+00, -.15004500E+00, -.24810100E+00, -.39656400E-01, 0.64271800E+00, 0.18805500E+00, -.62748900E+00, -.34856700E+00, -.48792900E-01, -.23935700E+00, -.18600600E+00, 0.41395300E-02, -.23965700E+00, -.14148400E-01, 0.46312600E+00, 0.27706700E+00, -.12847400E+00, 0.36133300E+00, -.10577600E+00, 0.56676600E+00, 0.28973700E+00, 0.46974500E-01, -.72965000E-01, -.50972800E-01, -.29860500E+00, 0.51217200E+00, -.16556700E+00, 0.63054800E+00, -.21984100E-01, 0.22768700E-01, -.24454300E-01, -.22470500E+00, -.17294700E+00, -.47895300E+00, 0.74114600E+00, 0.12006100E+01, -.51566400E+00, -.21605400E+00, -.75771100E+00, 0.12400500E-01, 0.17679000E+00, -.38546400E-01, 0.25280700E+00, -.17048600E+00, -.30195400E+00, -.34655100E-01, 0.23082500E+00, -.20483800E+00, -.10038300E+00, -.62655300E+00, 0.11110300E-01, -.32537100E+00, 0.36178000E-01, 0.75347300E-01, -.26399900E-02, -.10021700E-01, -.26750800E+00, 0.43528800E-01, 0.17300700E+00, 0.25665800E+00, -.10314100E+00, 0.28271400E+00, -.14635600E+00, 0.22674400E+00, -.72948900E-01, -.12530000E+00, 0.17094100E+00, -.53086800E-01, 0.21272600E-01, -.15899700E+00, 0.44656400E-01, -.32043000E+00, 0.54587800E-02, 0.35754300E+00, 0.15302100E+00, -.17274400E+00, -.10836500E-01, 0.49291500E-01, 0.35421100E-02, 0.24450400E+00, -.37825000E-02, 0.26687600E-01, -.42357100E-01, 0.28750800E+00, -.16048000E+00, 0.11735200E+00, 0.24619600E-01, -.60982400E+00, -.63080300E-01, -.36999400E+00, 0.46943500E-01, 0.67073900E-01, 0.14711600E+00, 0.29722300E+00, 0.79745400E-01, -.13960300E+00, 0.37899300E-01, -.20875400E-01, -.24530000E+00, -.27130300E-01, -.14874100E-01, -.51168800E-01, -.12401100E+00, -.28199700E+00, 0.15209000E+00, -.37778600E+00, 0.94996800E-01, -.79766700E-01, -.19166800E+00, 0.26987100E+00, -.54179200E-01, 0.46224000E+00, -.41038800E-01, 0.15847300E+01, 0.27544100E+02, 0.60824600E+01, 0.19623800E+02, -.97895700E+01, -.80273300E+01, -.41378100E+01, 0.73287100E+01, -.12623400E+02, 0.10219200E+02, -.54295500E+01, -.80768600E+01, -.43108900E+02, 0.21320800E+02, 0.21542400E+02, 0.30188600E+02, 0.78246400E+01, 0.13372700E+02, 0.17729400E+02, 0.23259600E+02, 0.11619900E+01, -.82839600E+02, 0.40029700E+02, 0.38942500E+02, 0.28372400E+02, 0.34254500E+02, 0.64968000E+00, -.31189200E+02, 0.17463500E+02, 0.28423400E+02, 0.19502200E+03, -.10240000E+03, -.96701400E+02, -.10473500E+02, -.11347000E+02, -.87209600E+02, -.66381800E+02, -.94373000E+02, -.34488500E+02, 0.26630900E+03, -.12055100E+03, -.13292100E+03, 0.16025100E+02, 0.23252800E+02, -.10921500E+03, -.86954800E+02, -.14008700E+03, -.27243600E+02, -.12033200E+02, 0.66319400E+01, 0.36057600E+01, -.12150200E+02, -.22444500E+02, 0.22960300E+02, -.13733700E+02, -.15814200E+01, -.13110800E+02, -.68417200E+00, 0.26422700E+02, -.27140700E+02, -.82972500E+01, -.34205800E+00, -.26284900E+02, -.63890100E+01, -.72280900E+00, 0.24639000E+02, 0.29935300E+02, 0.24257700E+01, -.93917600E+01, 0.52447400E+01, -.49191800E+02, -.70329800E+00, 0.15337500E+02, 0.46456300E+01, -.92235500E+01, -.41431100E+02, -.16856900E+01, 0.11837000E+02, 0.10217700E+02, -.90141100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.51434000E+00, -.85513500E-01, -.62370400E+00, 0.90642100E-01, -.30351600E+01, 0.40593300E-01, 0.34250100E+01, 0.13737800E+01, 0.12048700E+00, -.72528400E-01, -.13338500E+01, 0.72130600E+00, -.95633600E+00, 0.80858600E+00, 0.18727700E+00, -.34930800E+00, -.85289200E-01, 0.88296700E-01, 0.10079100E+01, -.31813800E+00, 0.28666200E+01, -.11917100E+00, 0.29779800E+00, -.33879700E+00, -.30132100E+00, 0.37495600E+00, -.38211600E+00, -.27979900E+00, 0.37268600E+00, -.19777200E+00, -.26585800E+00, -.59971700E+00, 0.37095900E+00, 0.64656100E+00, 0.42561100E+00, 0.17567600E-01, -.21741500E-01, -.41548000E+00, 0.10633100E+01, -.67907900E+00, -.38706300E+00, -.22512200E+00, 0.10083900E+01, 0.10311100E+00, -.11366300E+01, -.78964700E+00, 0.47315400E-01, -.24301000E+00, 0.17686000E+01, 0.42152900E-01, -.14507000E+00, 0.11944200E+00, 0.27317600E+00, 0.67680900E+00, 0.34094800E+00, -.55837600E+00, 0.64793700E-01, 0.39601500E-01, 0.32215100E+00, -.50648100E+00, -.24365300E+00, -.37647200E+00, 0.22532400E+00, 0.15757700E+01, -.59660600E+00, 0.32000300E-01, -.31021200E+00, -.21675300E+00, -.47858400E+00, 0.11552700E-01, 0.51231600E+00, -.21815200E-01, 0.12587300E+00, 0.20618700E-01, -.20183100E+00, 0.32787300E+00, 0.23573100E+00, -.65254600E-02, -.64083900E-01, -.46224000E+00, 0.12110300E+00, -.10710000E-01, -.33692500E-01, 0.95469900E-01, -.61993800E+00, 0.24715700E+00, 0.96926600E-01, 0.22093600E+00, -.14801500E+00, -.14168700E+00, -.15156600E+00, 0.18582900E+00, -.18581200E+00, 0.94293000E+00, -.14336400E+00, 0.15830700E-01, 0.24718300E+00, -.14097300E+00, -.28417400E-01, 0.43790200E-01, -.82153600E-01, -.38208200E-01, -.12418600E+00, 0.54828900E+00, -.49713000E-01, 0.18062900E+00, 0.33828700E-01, 0.24900900E+00, 0.73338700E-01, -.19996000E-03, -.72870100E-01, 0.88991400E+00, 0.68762300E-01, 0.25253200E-01, 0.18905800E+00, 0.27930000E+00, 0.12825300E+00, -.10781800E+00, 0.59944300E-01, 0.69001700E-02, 0.63348700E-01, -.21370000E+00, -.28455700E-01, -.17996600E+00, 0.51787400E-01, 0.28023600E+00, -.24829500E+00, 0.11517700E-01, 0.17530700E+00, -.34008100E+00, -.31314500E+00, -.86705800E-01, -.11086900E+00, -.13497500E+00, -.43766200E+00, -.10368600E+00, 0.12368900E+00, 0.41940100E-01, 0.11893000E+00, -.53356300E-01, 0.26555700E-01, -.88725900E+00, -.89845900E+00, 0.20346400E+02, -.10494500E+01, 0.11886100E+01, 0.14715100E+01, -.13804500E+01, 0.10590800E+01, -.45760700E+01, 0.35014900E+01, 0.52382400E+01, -.75335900E+01, -.10946100E+03, 0.54548500E+02, 0.54829200E+02, 0.37176700E+02, 0.11554200E+02, 0.30641200E+02, 0.13034500E+02, 0.28599500E+02, 0.11549500E+02, -.82144400E+02, 0.38425700E+02, 0.40402500E+02, -.11369000E+02, 0.32117100E+02, 0.26010900E+02, -.10732900E+02, 0.20473900E+02, 0.20070300E+02, 0.12931500E+03, -.66670100E+02, -.63531200E+02, -.21911400E+02, -.16294600E+02, -.27734100E+02, -.19466000E+01, -.24203900E+02, -.18925600E+02, 0.77232800E+02, -.53898300E+02, -.38421400E+02, -.28847900E+02, 0.22580200E+02, -.32443500E+02, -.27171900E+02, -.45459600E+02, -.10570300E+02, -.91850300E+02, 0.46845200E+02, 0.43910600E+02, 0.17226200E+02, 0.16989800E+02, 0.22139100E+02, -.20079100E+02, -.34123100E+02, 0.31813400E+02, 0.88223700E+01, 0.78957500E+01, -.84254600E+01, 0.75595900E+01, -.89814500E+01, -.81451100E+01, -.11705100E+02, 0.84223300E+01, 0.63174100E+02, 0.77683700E+02, 0.12049700E+02, 0.75456700E+01, 0.10184700E+02, -.17421200E+02, -.58782500E+01, 0.10095200E+02, 0.13594200E+02, 0.14184500E+01, -.10925700E+02, 0.95487200E+01, -.28102400E+01, 0.58710000E+01, -.34276500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.36275100E+01, 0.45556400E+00, -.38300600E+01, -.15122300E+01, 0.71729500E+01, 0.42471000E+00, -.64998300E+01, -.27249200E+01, 0.58846600E+00, 0.16290900E+01, 0.22252200E+01, -.25375800E+01, 0.83643600E+00, -.32447000E+01, -.12163400E+01, 0.14998400E+01, 0.33637500E+00, -.22480400E+00, -.13697800E+01, -.24507100E+00, -.29231200E+01, -.57290600E+00, -.13386400E+00, -.52107400E+00, 0.50705300E+00, -.83265300E+00, -.49631900E-01, -.19907000E+00, 0.16858300E+00, -.16673100E+01, 0.30665600E+00, 0.87569700E+00, 0.11921800E+00, 0.45469900E+00, -.75851100E+00, -.43589400E+00, 0.68293500E-01, 0.24176200E+00, 0.11930100E+01, 0.10520700E+01, 0.46826600E-01, 0.31584800E+00, -.52390900E-01, -.19128700E+00, -.65479000E-01, 0.10005700E+01, 0.14781700E-01, 0.15805800E-01, 0.16039500E+01, -.25429400E+01, -.43107600E+00, -.47552400E+00, -.17056000E+01, -.27807700E+00, -.69898800E+00, -.26066600E+00, -.20268600E+00, 0.28320800E+00, -.53304600E-01, -.21117600E-02, -.57454000E-01, 0.26414300E+00, -.42739200E+00, -.43984400E+00, 0.69317700E-01, -.71738500E-01, 0.69480500E-01, -.20463900E+00, -.13928400E+00, 0.46262500E+00, 0.12257300E+01, 0.11294400E+00, 0.84322900E-01, -.16864200E+00, 0.56170300E+00, -.82718700E+00, 0.12909600E+00, -.14287600E+00, -.33211000E+00, -.18092800E+01, 0.12526100E-01, 0.23645400E-01, -.19582300E-01, 0.25117300E+00, 0.26246500E+00, -.57099000E+00, -.22078000E+00, -.10115500E-01, -.98802600E+00, -.54737700E+00, -.15984300E+00, 0.73596100E-01, -.25803800E+00, 0.25883100E+00, 0.29169800E-01, 0.10424800E+00, -.53297400E-01, -.17885500E+00, 0.21684200E+00, 0.69400400E+00, 0.21303300E+00, -.19242500E+01, 0.47060900E-02, 0.57648100E+00, -.36636600E+00, 0.66396900E+00, -.18692600E-01, 0.13594600E+00, -.11542700E+00, -.28505100E-01, 0.30186100E+00, -.43844200E+00, -.98278700E-03, -.79780400E+00, -.11356200E+00, 0.10203800E+01, 0.19504500E+00, 0.98331100E+00, -.19023600E+00, -.67602600E-01, -.16608100E+00, -.58653100E+00, -.14537800E+00, 0.24089500E+00, 0.14218000E+00, -.72982900E+00, 0.58523700E+00, 0.12269800E+00, 0.50188600E+00, 0.30688700E-01, -.85659500E-01, 0.63662700E+00, 0.35357900E+00, 0.34493200E+00, 0.22160400E+00, -.26916100E+00, 0.14097100E+00, 0.33433100E+00, 0.65539100E-01, -.33714100E+00, 0.45262300E+00, 0.43727900E+00, 0.76439400E+00, 0.12106500E+01, -.62236600E+02, 0.32583800E+02, 0.30197900E+02, 0.11832700E+02, -.15843700E+01, 0.23978400E+02, -.17199700E+02, -.68478600E+01, 0.23312300E+02, -.40650800E+02, 0.19794700E+02, 0.20113000E+02, -.52444400E+02, -.20314100E+02, 0.24336400E+02, -.21160200E+02, 0.38635100E+02, 0.21502800E+01, 0.12574900E+03, -.66483900E+02, -.65094000E+02, -.46404600E+02, -.86100800E+02, 0.11876100E+02, 0.85733300E+02, 0.37167400E+02, -.76391800E+02, -.35295400E+03, 0.17877300E+03, 0.17108000E+03, 0.36099100E+02, -.52805200E+01, 0.15206500E+03, 0.15406000E+03, 0.14778200E+03, 0.37613800E+02, -.38610100E+03, 0.14916400E+03, 0.19222700E+03, -.22755000E+02, -.19252700E+02, 0.15102300E+03, 0.11453600E+03, 0.18065500E+03, 0.29133100E+02, 0.99132700E+02, -.49297800E+02, -.49246100E+02, -.19199100E+02, -.15521300E+02, -.45945600E+02, 0.14515600E+02, 0.62790400E+02, -.38420200E+02, -.93479300E+01, -.60054100E+02, 0.32535500E+02, 0.11995900E+02, 0.94751000E+00, 0.59773500E+02, 0.15010800E+02, 0.58036800E+00, -.44164100E+02, -.52418400E+02, -.13979000E+02, 0.11432400E+02, -.15831600E+02, 0.10155000E+03, 0.43940700E+01, -.22776000E+02, 0.72326400E+01, 0.17035800E+02, 0.96057300E+02, 0.27358500E+01, -.71979700E+01, -.68046700E+01, 0.30981800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.40814200E+01, -.68411700E+00, 0.33145400E+01, 0.18872200E+01, -.13772800E+02, 0.11920000E+00, 0.13013900E+02, 0.60888300E+01, 0.49668500E+00, -.14325200E+01, -.46280800E+01, 0.27883900E+01, -.32225600E+01, 0.29937500E+01, 0.13782800E+01, -.23376800E+01, -.68484100E+00, -.60986700E-01, 0.16352400E+01, -.69447800E+00, 0.62741100E+01, 0.98694100E-01, 0.12750900E+00, -.55399300E+00, -.33517800E+00, 0.11908200E+01, -.12544200E+01, -.35620600E+00, -.13344000E+01, 0.18076700E+01, -.68653500E+00, -.64881600E+00, 0.13135800E+00, 0.50884700E+00, 0.15022500E+01, -.67144000E+00, -.36058100E-01, -.61731200E+00, 0.11976100E+01, -.46795400E-01, -.50825900E+00, -.25389100E+00, 0.11367900E+01, 0.54055800E+00, -.23607500E+01, -.14478600E+01, 0.44216100E+00, -.31833500E+00, 0.21627100E+01, 0.13758200E+01, -.12764800E+00, 0.30853800E+00, 0.79868800E+00, 0.10218400E+01, 0.23471500E+00, -.83257900E+00, 0.13350000E+00, -.23226000E+00, 0.42738000E+00, -.76063800E+00, 0.28816300E+00, 0.14067800E+00, 0.35908400E+00, 0.97158500E+00, 0.34783400E-01, 0.60474800E+00, 0.17197600E+00, -.32184400E+00, -.42959500E+00, -.54995800E-01, 0.54788500E+00, 0.17380500E+00, 0.32061700E+00, 0.20593300E+00, -.54549400E+00, -.19921000E-02, 0.47658600E+00, 0.10799400E+01, -.15349600E+00, -.38560700E-01, 0.31249000E+00, -.11047100E+00, -.60091100E-01, 0.16701200E+00, -.64936200E+00, -.59653100E+00, -.62199400E-01, 0.28841300E+00, -.21429500E+00, -.69756600E-03, -.31913000E+00, -.10880800E+00, -.12170700E+00, 0.73977700E+00, -.97563300E-02, -.12462400E+00, 0.32485200E+00, -.43559100E+00, 0.83607700E-01, -.14817800E+01, 0.42085800E-01, 0.12029200E+01, -.18614300E+00, 0.85251900E+00, -.18731700E+00, 0.37542600E+00, 0.16836000E+00, 0.69725700E+00, 0.11884300E+00, -.85789000E-02, 0.10907400E+00, 0.10523500E+01, 0.73640100E+00, 0.56313600E+00, 0.58296900E+00, 0.94415700E-01, 0.55025700E-01, -.60336100E+00, 0.15464900E+00, 0.11525000E+00, 0.35277900E+00, -.63551500E+00, 0.64472300E-01, -.55361700E+00, 0.70392400E-01, 0.12636600E+01, -.63229600E+00, -.12181400E-01, 0.12381700E+01, -.52633300E+00, -.30787400E+00, -.42483900E+00, -.55207200E-01, -.30957000E-01, -.51133800E+00, -.26132400E+00, 0.17259600E+00, 0.13611400E+00, 0.15089500E+00, 0.33210200E-01, -.17129700E-01, -.27667400E+01, -.16909500E+01, 0.15357900E+01, -.99160900E-02, 0.37543200E+02, 0.10347100E-01, -.96138800E+01, 0.11330200E+01, 0.47762400E+01, 0.85709600E+01, -.24260300E+01, -.24655500E-01, -.51693300E+02, 0.24953000E+02, 0.25742700E+02, 0.50738100E+01, 0.54802000E+01, 0.10867400E+02, -.10473900E+02, -.19732700E+01, 0.11714900E+02, -.78800900E+02, 0.37894800E+02, 0.39277400E+02, 0.11156500E+00, 0.59113200E+01, 0.24324900E+02, 0.99757800E+00, 0.26747500E+02, 0.43376400E+01, -.43112700E+02, 0.17659500E+02, 0.21600000E+02, -.25485300E+02, 0.53880800E+01, 0.11058800E+02, -.12614300E+02, 0.21053300E+02, -.61374600E+01, 0.73421200E+01, 0.40704400E+01, -.34216600E+01, 0.94421300E+01, -.68929100E+01, 0.36825000E+01, 0.32861400E+01, 0.22044200E+01, -.87198900E+01, 0.27652900E+02, -.16487600E+02, -.13847900E+02, -.26901600E+00, 0.93098000E+01, -.16578900E+02, -.38046500E+02, 0.43555000E+01, 0.51875700E+01, -.30745100E+01, -.44130400E+01, -.57944400E+01, -.54685800E+01, 0.57175200E+01, 0.41603400E+01, 0.50814200E+01, -.57020200E+01, -.59102800E+00, 0.44899400E+01, -.37262900E+01, -.53921400E+01, -.32588500E+01, -.36333300E+00, 0.21850700E+01, -.52830200E+01, 0.61032300E+01, -.97680700E+00, -.31790100E+01, 0.88403100E+00, 0.34186900E+01, 0.57287500E+01, -.43704900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11060100E+02, -.16637700E+01, 0.17027400E+02, 0.72167700E+01, -.34576300E+02, -.11221700E+01, 0.34921600E+02, 0.24106600E+02, -.23777700E+00, -.52712100E+01, -.79549000E+01, 0.45130900E+01, -.67905300E+01, 0.93333100E+01, 0.54728500E+01, -.71800500E+01, -.33594600E+01, -.46194400E+00, 0.21513100E+01, -.40583800E+01, 0.10105100E+02, 0.20480700E+01, 0.30683800E-01, -.84132100E+00, -.48093100E-01, 0.29011700E+01, -.34266700E+01, 0.48501500E-01, -.57186800E+01, 0.70132000E+01, -.16430100E+01, 0.17928800E+01, -.68496200E+00, -.82420700E+00, 0.26787900E+01, 0.74778300E-01, 0.72040000E+00, -.17094100E+00, -.63085600E+01, 0.86333100E+00, -.14158400E+01, -.49985300E+00, -.39651800E+00, 0.51905800E+00, 0.68865100E-01, -.48949000E+01, 0.12399100E+01, -.11667300E+01, 0.18091300E+01, 0.10167100E+02, 0.73214700E+00, 0.18035800E+01, 0.18764400E+01, 0.56033800E+01, 0.21648800E+01, 0.80200100E+00, 0.52218500E+00, -.16587700E+01, 0.49995300E+00, -.53652800E+00, 0.19523600E+01, 0.15355600E+01, 0.44836600E-01, -.30034400E+01, 0.21996900E+00, 0.13839900E+01, 0.25921600E+01, -.20514600E+00, -.22190900E+00, -.12748600E+01, -.26134800E+01, 0.47515100E-01, 0.19819000E+01, 0.85802800E+00, -.35295700E+01, 0.29136600E+01, -.63232600E+00, 0.86943300E+00, 0.11302200E+01, 0.61582600E+01, 0.24245400E+01, -.26751300E+01, 0.38806100E+00, -.98163600E+00, 0.87051800E+00, -.11397600E+01, -.61972600E+00, -.54602000E+00, -.15617300E+01, 0.19506500E+01, -.36334000E+00, 0.10960300E+01, -.17031500E+00, 0.75684900E+01, -.65587500E+00, 0.26956400E+00, 0.25241800E+01, -.53794000E+00, -.15270000E+00, -.20637000E+01, 0.90098700E+00, 0.99332900E+01, 0.32852000E+00, 0.13302500E+00, -.36955800E+00, -.54836800E+00, 0.34072300E+00, 0.14077000E+01, -.21383100E+00, -.11484600E+00, 0.73081300E+00, -.61397800E+01, 0.19368900E+01, 0.70992100E+00, 0.25373800E+01, 0.63358000E+00, 0.11542300E+00, -.57520000E+00, -.68832000E+00, 0.27204200E+00, 0.89973600E-01, 0.41289600E+00, -.45806600E-01, 0.10682300E+01, 0.38100500E+00, -.21717300E+01, 0.83150700E+00, -.20244400E+00, -.82654800E+00, 0.72646500E-01, 0.17287600E+01, 0.37653200E+00, 0.27740900E-01, 0.11991900E+01, -.10006700E+01, -.19752700E+00, 0.66674500E+00, -.10620000E+01, 0.38732900E+00, -.53504300E+00, -.63718600E+00, -.58833600E+00, 0.99679800E+00, 0.13006000E+01, -.46051100E-01, 0.56490400E-01, -.10870900E+02, -.13531500E+02, -.54328700E+02, 0.40462800E+02, -.28066700E+01, -.50631000E+01, -.81353000E+01, -.61085600E+02, 0.28380900E+02, 0.29898600E+02, -.11232800E+03, 0.22654900E+00, 0.18651700E+02, -.54993500E+02, -.52521100E+02, 0.35438900E+02, 0.98347100E+02, -.54279900E+02, -.34272200E+02, -.61101900E+02, 0.61055800E+02, -.19466700E+01, 0.10217500E+02, -.19172600E+03, 0.64918800E+02, -.23672900E+03, 0.12501700E+03, 0.11282600E+03, -.12557600E+03, 0.10033900E+03, 0.19795800E+03, 0.33182600E+03, 0.18826600E+03, 0.15524700E+02, -.74112700E+03, 0.35912800E+03, 0.36944200E+03, -.14164100E+03, -.13053500E+03, 0.33348900E+03, 0.31810500E+03, 0.32730100E+03, 0.26334700E+02, 0.77735600E+02, -.46029900E+02, -.21192600E+02, 0.21934500E+02, 0.78546600E+02, -.84721600E+02, 0.74351800E+02, -.13147800E+02, 0.49437200E+02, 0.25595500E+02, -.46381600E+02, 0.15037600E+02, 0.78799500E+02, -.12526100E+02, 0.45142900E+02, 0.29226300E+02, 0.10470500E+02, -.12240100E+03, -.13063700E+03, 0.53770400E+01, 0.83518000E+02, -.12342500E+02, 0.87820200E+02, -.61020100E+01, -.55621500E+02, -.20795700E+02, 0.41339700E+02, 0.54871200E+02, 0.47724700E+02, -.35595200E+02, 0.89451600E+01, 0.37459100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.56245000E+01, 0.27065000E+00, -.67577000E+01, -.20864600E+01, 0.23993800E+01, 0.37691100E+00, -.54784700E+01, 0.48230600E-01, -.38391000E+00, 0.30804500E+00, 0.20456900E+01, -.26396600E+01, 0.62989000E+00, -.42479500E+01, -.49021000E+00, -.15911200E+00, 0.15345800E+01, -.30210900E+00, -.14791200E+01, -.26749300E+00, -.44302800E+01, 0.91930900E-01, 0.37774500E+00, 0.46695400E+00, 0.16115500E+01, -.65803500E+00, -.86023000E+00, 0.64991300E+00, 0.31218500E+01, -.45524000E+00, 0.28106100E+00, -.41186300E-01, 0.17032100E+01, -.20353800E+00, -.47252700E+00, 0.18888200E+01, 0.21005300E+00, 0.31437100E+00, -.15776500E+01, 0.69449500E-01, 0.29682200E+00, -.24302200E-01, -.79860600E+00, -.31815900E+00, 0.91973300E+00, 0.25394300E+00, -.21584400E+00, 0.29393700E+00, -.14803800E+01, 0.51001200E+00, 0.39341200E+00, 0.53397600E+00, -.63932500E+00, -.79651000E+00, -.78206900E+00, 0.40245500E+00, -.15848300E-01, 0.27027300E+00, -.30911200E+00, -.10539200E+01, 0.39256900E-01, -.42036300E+00, 0.40084500E+00, 0.27431200E+01, -.17627700E+00, -.20031500E+00, -.75346300E+00, -.20812000E+00, -.21327900E+00, 0.76812500E+00, 0.36846900E+00, 0.15326400E+00, -.78158400E+00, 0.79018100E-01, 0.28259800E+00, 0.10706300E+01, 0.37392700E+00, -.11326300E+01, 0.79412900E-01, -.45785300E+00, -.38842000E+00, -.77832700E-01, 0.92662600E-01, -.15866700E+00, -.79924700E+00, 0.86940600E+00, 0.25603000E+00, 0.24334800E+00, 0.52923400E+00, -.33668000E+00, -.33840200E+00, 0.12082300E+01, 0.28522000E-02, 0.64991200E+00, 0.23165300E-01, 0.33356600E+00, 0.27609300E+00, 0.27002400E+00, -.16989600E+00, 0.67864200E+00, -.12426100E+00, 0.81413700E+00, 0.30533700E+00, -.38155800E+00, 0.18949500E+00, -.22439300E+00, 0.59882900E-03, -.27503100E-01, 0.89609500E-01, 0.46551300E-01, -.32744700E-01, 0.29065600E+00, -.20057300E+00, 0.69086900E-01, -.36674200E+00, -.12905100E+01, -.43816000E+00, -.45038500E+00, 0.13382200E+00, 0.43750100E-01, 0.55827200E-01, 0.10720200E+01, 0.30560700E+00, 0.33115900E+00, -.31698400E-01, 0.26472700E-01, 0.24807900E-02, -.75695700E-01, -.78484600E+00, -.44298000E+00, 0.62668500E-03, -.59530600E+00, -.62975900E+00, -.86299700E+00, -.56572400E+00, -.56858500E-01, -.47410800E+00, -.12171900E+00, 0.17304600E+00, 0.78345900E+00, -.33025300E+00, -.64232800E+00, -.19678500E+00, -.96116700E-01, -.38563600E+00, 0.16752600E-01, -.16801600E-03, 0.26362200E+02, 0.47388500E+01, -.87741400E+01, -.22155400E+02, -.17099600E+02, 0.53383300E+01, 0.44087800E+03, -.22054800E+03, -.22053000E+03, -.42838800E+02, -.18999600E+02, -.13055900E+03, 0.10339200E+02, -.11917200E+03, -.48681900E+02, 0.29462000E+03, -.15278800E+03, -.14846000E+03, -.91985500E+01, -.70642000E+02, -.83542000E+02, 0.17847000E+02, -.57055300E+02, -.54609800E+02, -.12988600E+03, 0.60509400E+02, 0.61468800E+02, 0.12831100E+03, 0.91240900E+01, 0.35131000E+02, 0.91405900E+00, 0.22392900E+02, 0.22542600E+02, -.29188400E+02, 0.98450600E+01, 0.13968400E+02, 0.50806100E+02, 0.31949900E+02, 0.51185300E+01, 0.32644400E+01, 0.14870200E+02, 0.17844700E+02, 0.12337000E+02, -.42501300E+01, -.54545800E+01, -.77866000E+01, -.43657700E+02, 0.23439000E+02, 0.72571200E+02, 0.60473100E+02, -.41972200E+02, -.16565400E+02, -.13500700E+02, 0.20360600E+02, -.27723200E+01, 0.60551600E+01, 0.14394100E+02, 0.10720600E+02, -.40089900E+01, -.38321700E+02, -.54392700E+02, -.17054200E+02, -.31102200E+01, -.11152100E+02, 0.27950000E+02, 0.10300600E+02, -.83910100E+01, 0.99489600E+01, -.10052100E+02, 0.20445700E+02, -.21385900E+02, -.14370000E+00, -.69954200E+01, -.44057400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.43423100E+01, 0.70996900E+00, -.31092200E+01, -.20726400E+01, 0.17860800E+02, -.20770300E+00, -.18623900E+02, -.95054900E+01, 0.59532700E+00, 0.13510700E+01, 0.60973900E+01, -.29727500E+01, 0.45925500E+01, -.40910400E+01, -.17289900E+01, 0.25773200E+01, 0.14266100E+01, 0.35731500E+00, -.20680700E+01, 0.20501000E+01, -.61874900E+01, -.71883200E+00, -.28901400E+00, 0.72513600E+00, 0.16177600E+00, -.14641800E+01, -.13114800E+01, 0.47001300E+00, 0.19135100E+01, -.25206500E+01, 0.95760400E+00, -.15715800E+00, -.10767200E+00, -.14498400E+00, -.35035800E+00, -.81444500E+00, -.15303700E+00, -.83323300E-01, 0.94766800E+00, 0.13228900E+01, 0.39256000E+00, 0.43602900E+00, -.24543100E+00, -.10289900E+00, 0.27731100E+00, 0.17199400E+01, -.31309100E+00, 0.70167000E+00, -.11146000E+01, -.42818000E+01, 0.46146600E-01, -.49183000E+00, -.12464300E+00, -.21865000E+01, -.39890600E+00, 0.89102200E-02, -.48756300E+00, 0.57647800E+00, -.57039000E+00, 0.57493100E+00, -.25214300E-01, 0.30189900E+00, -.71264100E+00, -.48241500E+00, -.24148200E+00, -.11405500E+01, -.21771600E+00, -.18802100E+00, -.33788700E+00, 0.88530500E+00, 0.21636500E+01, 0.25231300E-01, 0.15080500E+00, -.49740200E+00, 0.18539600E+01, -.44074700E-01, -.10712200E+00, -.26183000E+01, -.64801700E+00, -.67888900E+00, -.90480700E+00, -.29346100E+00, -.16533200E+00, 0.29617400E-01, 0.15541600E+00, -.35392700E+00, 0.34908800E+00, 0.98583200E+00, -.78677000E+00, -.76155700E+00, -.75661300E+00, -.17027000E-01, 0.31268100E+00, -.35816800E+01, -.19057400E+00, -.64322300E+00, -.78601100E-01, 0.34896000E+00, 0.80410000E-01, 0.76929800E+00, -.11147100E+01, -.12625500E+01, -.40353900E+00, 0.16630200E+00, -.12840400E-01, 0.71446400E-01, -.51265700E-01, -.60183400E+00, -.81574200E-01, 0.13597700E-01, -.50044500E-01, 0.21500600E+01, -.18541100E+01, 0.58910200E-01, -.62498900E+00, -.31575400E+00, 0.42645500E+00, 0.62106100E+00, -.77690700E-01, -.83130600E-01, -.30036800E+00, 0.64621700E+00, -.29087700E+00, -.86996700E-01, -.83593900E+00, 0.17050000E+01, 0.86065300E+00, 0.94871500E-01, -.56736300E+00, 0.39878200E+00, 0.15491600E+01, -.42782600E+00, -.85686400E+00, 0.83132200E-01, -.16966100E+00, 0.49014300E+00, -.18380700E+00, -.34057700E+00, 0.52258700E-01, 0.98879000E+00, -.50540500E+00, -.37233900E+01, -.18866300E+01, 0.23514500E+01, -.15291500E+01, 0.82734300E-01, 0.31447400E-03, 0.92917800E+00, -.46514900E+02, 0.43138700E+02, 0.42850800E+02, 0.51636300E+01, 0.83470100E+01, 0.26280300E+03, -.13219500E+03, -.13154100E+03, -.12147200E+03, -.75284600E+02, -.46494800E+02, 0.53240300E+00, 0.77102200E+02, -.51553400E+02, 0.12452100E+03, -.68032600E+02, -.67776900E+02, -.24401100E+02, -.85202300E+02, -.89958500E+01, 0.10876200E+03, 0.87727600E+02, -.59462600E+02, -.44524500E+03, 0.21745300E+03, 0.21311400E+03, 0.50159600E+02, 0.15694400E+02, 0.15515000E+03, 0.20092000E+03, 0.13793700E+03, -.28025200E+02, -.43221800E+03, 0.17652900E+03, 0.21402300E+03, 0.64077300E+02, -.44736400E+02, 0.20055400E+03, 0.24388900E+03, 0.16686700E+03, 0.14443200E+02, 0.24129100E+03, -.12715800E+03, -.11993200E+03, -.63364200E+02, -.79065300E+02, -.58089500E+02, 0.85162600E+02, 0.17091300E+03, -.14152400E+03, -.12488300E+02, -.67813900E+02, 0.25323600E+01, 0.11904000E+02, 0.55668500E+01, 0.68469700E+02, 0.47751500E+02, -.54444100E+01, -.11592500E+03, -.15228800E+03, -.36563400E+02, 0.98437500E+01, -.36001700E+02, 0.10129800E+03, 0.15828800E+02, -.46015700E+02, 0.24878700E+02, 0.27029200E+02, 0.10339500E+03, 0.57966400E+01, 0.15097100E+02, 0.27792400E+02, -.15943600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13933100E+01, -.93254600E+00, 0.11357600E+01, 0.73064600E+00, -.61560200E+01, 0.64346900E-01, 0.66732300E+01, 0.38658600E+01, 0.28039100E+00, -.52091900E+00, -.17437200E+01, 0.12372500E+01, -.14281600E+01, 0.19759300E+01, 0.90529100E+00, -.84882600E+00, -.47287400E+00, 0.40959800E+00, 0.12194900E+01, -.73150000E+00, 0.19183100E+01, 0.16154700E+00, 0.38812100E+00, -.49545600E+00, 0.24861600E+00, 0.62087000E+00, 0.66973000E-01, -.13639300E+00, -.77273100E+00, 0.10370800E+01, -.38783800E+00, 0.19095300E+00, -.71888900E-01, -.13485600E+00, 0.34461500E+00, -.87161600E-01, -.76281200E-01, 0.32050000E+00, -.69542100E+00, -.71021100E-01, 0.64657700E+00, 0.24154200E-01, -.51703900E+00, -.22306300E+00, 0.29065800E+00, 0.97013900E-01, 0.65030400E-01, -.53351400E+00, 0.89213800E-01, -.23162200E+00, -.56012000E-01, 0.46684600E-01, -.57292000E+00, -.21006200E+00, 0.17910800E+00, -.50429400E+00, 0.13239000E+00, 0.96549800E-01, 0.47272900E-01, 0.60708300E+00, 0.29746200E+00, -.26797900E+00, -.17728600E+00, -.10383000E+01, 0.17317900E-01, -.17283500E-01, 0.96171600E-01, 0.37458300E+00, 0.88240200E+00, -.24128500E+00, -.74713100E+00, -.24566300E+00, -.46458100E+00, -.34679200E-01, -.72217200E-01, -.77401000E+00, -.24860700E+00, 0.34280500E-01, 0.77829400E-01, -.53655300E+00, -.63988500E-01, 0.82891800E-02, -.27912800E-01, 0.70770500E-01, 0.17707000E+00, 0.11845100E+01, 0.93924700E-01, -.19929700E+00, -.10069700E+01, 0.11377300E+01, -.43603000E+00, 0.33541000E+00, -.20592500E+00, 0.12267700E+01, -.44344800E+00, -.10208300E+00, 0.61339100E+00, -.70572400E-01, 0.24307900E-01, 0.92846400E+00, 0.59790300E-01, -.61432300E-01, -.16138400E-01, -.59959000E+00, -.30330500E+00, -.15001400E+00, 0.89677700E-01, -.35875700E+00, 0.27317700E+00, -.75805700E-01, -.14341500E+00, -.12204500E+01, -.38275200E+00, 0.67921700E-01, -.27801400E+00, -.65643600E+00, 0.11004100E+00, -.87925600E-01, -.43214800E-01, 0.20405200E-01, 0.32609200E-01, 0.59596800E+00, -.16879500E+00, 0.13537000E+00, -.22036800E+00, 0.11062400E+00, 0.63572600E+00, 0.14573600E+00, -.55807900E+00, 0.86114500E-01, -.17520800E+00, -.64052700E-01, 0.15978200E+00, -.31375300E+00, 0.20313500E+00, 0.22258300E+00, -.61055100E-01, -.90448900E-01, -.13493900E+00, -.15946500E+00, -.18511000E+00, 0.14039500E+01, 0.27947900E+00, -.15112300E+01, -.39440400E+00, -.15124400E-01, -.40458800E-01, -.40816700E+00, 0.41022300E-01, -.73023800E+01, -.12125700E+02, -.19892000E+01, -.57721800E+01, 0.13759400E+03, -.68529500E+02, -.68729200E+02, 0.14656800E+02, 0.12474600E+02, -.50137300E+02, 0.79659700E+01, -.78214200E+02, -.91678600E+01, 0.10445400E+03, -.53967100E+02, -.51863000E+02, -.42462100E+01, -.60229500E+01, -.28398600E+02, 0.25358800E+01, -.52967100E+02, -.16735000E+01, 0.76349900E+02, -.37349300E+02, -.37371200E+02, 0.14879200E+02, -.15012400E+02, -.99114700E+01, 0.47714900E+01, -.38415700E+01, 0.19883500E+02, -.19289600E+02, 0.10867100E+02, 0.99231400E+01, -.26730600E+02, 0.10742300E+01, 0.16033600E+01, -.15511500E+02, 0.15363200E+02, 0.10762700E+02, -.50686000E+02, 0.30160700E+02, 0.24489600E+02, 0.31507400E+02, 0.38193500E+02, -.67389500E+01, -.27108100E+02, -.58243300E+02, 0.48549200E+02, 0.21698300E+01, 0.63512400E+00, 0.49931400E+01, 0.65296500E+01, -.20666400E+01, -.54928500E+00, -.54438200E+01, 0.24339900E+01, 0.19096900E+02, 0.30948300E+02, 0.47321700E+01, 0.67640100E+01, 0.33721000E+01, 0.15016100E+00, -.21398600E+01, 0.31742400E+01, -.63934900E+01, -.23562600E+01, -.36153000E+01, -.54469800E+01, -.38430900E+01, -.68221900E+01, 0.83404900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.52213000E+01, 0.54858400E+00, -.85212300E+01, -.38359300E+01, 0.17704700E+02, 0.86188400E+00, -.17445300E+02, -.12767400E+02, -.76894500E+00, 0.30385500E+01, 0.39643000E+01, -.20766000E+01, 0.35995000E+01, -.41874700E+01, -.29432900E+01, 0.35684000E+01, 0.18875200E+01, 0.21305200E+00, -.88879200E+00, 0.22011400E+01, -.56023700E+01, -.33653200E+00, -.93943000E-01, 0.64314700E+00, 0.96879200E+00, -.14578900E+01, 0.95302900E+00, 0.16022400E+00, 0.47487000E+01, -.34608500E+01, 0.10670500E+01, -.96341500E+00, 0.47845200E+00, 0.18931500E+00, -.15960100E+01, 0.23282300E+00, 0.96941300E-01, -.76110500E-01, 0.27978200E+01, -.91807900E+00, -.68770500E+00, 0.58425000E-01, 0.20067400E+01, 0.29360600E+00, 0.38200900E+00, 0.16734000E+01, -.56016000E+00, 0.70191700E+00, -.95413800E-01, -.51616800E+01, -.30947600E+00, -.80529400E+00, -.35406400E+00, -.21920200E+01, -.25243000E+00, -.67976600E+00, 0.38883200E-01, 0.70203300E+00, -.36719500E+00, 0.68060500E+00, -.55936500E+00, -.34290400E+00, -.10381000E+01, 0.23183000E+00, -.74022100E+00, -.80028100E+00, -.20819300E+00, 0.13205900E+00, 0.15127600E+00, 0.44366700E-01, 0.10592200E+01, -.18519200E+00, 0.26727400E+00, -.34044200E+00, 0.74047100E+00, 0.12317100E+01, -.14284900E+00, -.23836000E+01, 0.16649200E+00, -.31027600E+01, -.13497700E+01, 0.82975200E+00, 0.74314600E-01, 0.10017300E+00, 0.28764900E+00, 0.11865300E+01, 0.70032800E+00, 0.65675700E+00, -.34440200E+00, -.10147900E+00, 0.61972600E+00, 0.85591000E+00, -.39564800E+00, 0.27204300E+01, -.14141400E+01, 0.45823000E+00, 0.85766600E+00, 0.33058600E+00, -.19403700E+00, 0.29327600E+01, 0.58814900E+00, -.29217500E+01, -.54094900E+00, 0.37109800E+00, -.30479600E+00, 0.19785000E+00, -.11717800E+00, 0.16821900E+00, -.69484900E-01, -.43256000E-02, -.44795100E+00, -.14157000E-01, -.10876500E+00, -.12664200E+01, 0.92648700E-01, 0.14595000E+01, 0.57141300E+00, 0.12861100E+01, -.70839800E+00, -.13983200E+00, -.61967300E+00, -.87740100E+00, -.11290500E+01, -.57736600E-02, 0.18888400E+00, -.11665500E+01, -.19753100E-01, 0.12047100E+00, -.97564400E+00, -.14366500E+01, 0.14272800E+01, 0.65062200E+00, -.10305200E+01, 0.89237000E-01, -.14310200E+01, -.35766700E+00, 0.43142800E+00, -.14943800E+01, 0.89271600E+00, -.76122200E+00, -.46312100E+00, 0.23529900E+00, -.17222000E+01, 0.51536200E+00, -.55250000E+00, 0.16145600E+00, 0.42318400E+00, 0.55583400E+00, 0.56141000E+00, 0.94669000E+00, 0.43341500E+02, 0.40896100E+02, -.15827000E+02, -.26134200E+03, 0.12848000E+03, 0.12979600E+03, 0.92377200E+02, 0.78862100E+01, 0.72797700E+02, 0.14130600E+02, 0.64927000E+02, 0.14368100E+02, -.21089900E+03, 0.92113500E+02, 0.10387300E+03, -.85106700E+02, 0.37288300E+02, 0.52933800E+02, -.70452400E+02, 0.88396500E+02, 0.27007400E+02, 0.28018300E+03, -.16466900E+03, -.14350000E+03, -.24648100E+02, -.55755600E+02, -.86343000E+02, -.56109400E+02, -.63036200E+02, 0.57828200E+02, 0.37744900E+03, -.21294600E+03, -.18911400E+03, 0.67302300E+02, 0.10607000E+03, -.15506800E+03, -.12626100E+03, -.20932200E+03, 0.14445600E+02, -.37840400E+03, 0.18582400E+03, 0.19507500E+03, 0.26158800E+02, 0.19951300E+02, 0.14050500E+03, -.71789800E+02, -.95785700E+01, 0.51742400E+02, 0.57360400E+01, 0.60547700E+01, -.33900700E+01, -.62323000E+01, -.14186200E+02, -.61894800E+01, -.39278200E+02, 0.11834000E+02, 0.16882000E+03, 0.18085400E+03, 0.29192800E+02, -.72321300E+01, 0.29652500E+02, -.13497000E+02, -.11035800E+02, 0.43547400E+02, -.66161800E+01, 0.24501200E+01, 0.25156900E+01, 0.74434800E+01, 0.22892000E+01, -.14649000E+02, -.30386200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.38608800E+01, 0.62600000E+00, -.40483700E+01, -.19872300E+01, 0.61228900E+01, -.42289300E+00, -.47109600E+01, -.16574100E+01, -.67214700E-01, -.48259200E+00, 0.44193600E+01, -.16810500E+01, 0.86250100E+00, -.59177900E-01, -.88360600E+00, 0.73454000E+00, -.82473500E-02, -.24497500E+00, -.26491600E+00, -.68948600E+00, -.22893200E+01, 0.85353600E-02, 0.54897900E+00, 0.13178400E+00, 0.22669100E+01, -.67162500E-01, -.13103000E+01, 0.15915800E+00, 0.36747100E+01, -.30752000E+00, 0.19843800E+00, -.77286700E+00, 0.75881700E+00, -.24885100E+00, -.17524400E+00, 0.11250800E+01, 0.34478300E+00, 0.39044500E+00, 0.30810800E+00, -.81123900E+00, 0.13498600E+01, -.25592000E-01, -.13885600E+00, 0.15626500E-01, 0.16360700E+01, 0.21917000E+00, -.42726500E+00, -.55100500E-01, -.18766000E+01, -.16806900E+01, 0.29442800E+00, -.34934600E+00, 0.69043100E+00, -.87771200E+00, -.61891100E+00, 0.82508300E+00, 0.24395000E+00, 0.94161900E-01, -.28262600E+00, 0.49024300E+00, 0.74301300E+00, 0.16993300E+00, -.62231400E+00, -.41722900E+00, -.50773200E-01, -.37384700E+00, 0.61136900E+00, 0.53006300E+00, 0.15538400E+01, 0.77513900E-01, -.70643600E+00, -.14017600E+00, -.18661100E+00, -.27880700E+00, 0.86688900E-01, 0.33589900E-01, -.35974200E-01, 0.11482000E+01, 0.10938700E+00, -.45198600E+00, 0.67656800E-01, 0.10710500E+01, 0.16541800E+00, -.37429200E-02, 0.33971100E+00, -.85722600E+00, -.19668200E+00, -.33516000E+00, 0.45759200E+00, 0.48859700E+00, 0.59457800E+00, 0.34925600E+00, 0.11941900E-01, 0.15048500E+01, -.35843800E+00, 0.48968600E+00, 0.15932900E-01, 0.40279400E+00, -.22986100E+00, 0.79435600E+00, 0.42796000E+00, -.11168300E+01, -.15985600E+00, -.56125100E-01, 0.33370800E-01, -.18912000E+00, -.22133200E-03, -.40026300E+00, -.62997500E-01, -.43823600E-01, -.81284400E-01, -.11725600E+01, 0.14744600E+00, -.77929200E+00, -.59148600E+00, 0.13255500E-01, -.64586900E-01, 0.57671400E+00, -.91460800E-01, -.29215400E-01, -.35574500E-01, -.14660700E-01, -.21708800E+00, 0.65511400E-01, -.19961900E+00, 0.95799500E+00, -.22292600E+00, -.32104800E-01, -.84484000E-01, -.72657000E+00, -.12522700E+00, -.34348100E-01, -.66937500E-01, -.10440300E+00, -.69372400E+00, -.51155000E-01, 0.77956800E-01, -.54075500E+00, 0.27599800E+00, -.94263000E-01, -.31872900E+00, -.12352500E+01, -.15353600E+01, -.12767800E-01, -.40482800E+00, -.18476800E-01, -.88762700E-01, -.31808100E+00, 0.23580300E-01, 0.78605400E+00, 0.32660300E+00, -.35450100E+02, 0.11875700E+02, 0.71716000E+02, 0.14853600E+01, -.36071500E+02, -.56056300E+02, -.31685800E+02, -.63542000E+01, 0.18362100E+02, 0.19356600E+02, -.17206000E+02, -.51851600E+01, 0.62299800E+01, 0.72868100E+00, 0.13569100E+02, 0.67086800E+01, 0.84580700E+01, 0.48822300E+02, 0.66530400E+01, 0.11043100E+02, -.84399200E+02, 0.50750700E+02, 0.36706300E+02, -.15120100E+02, 0.47675700E+02, 0.49570100E+02, 0.13076100E+03, 0.38979800E+02, 0.19162400E+01, -.14882100E+03, 0.88523500E+02, 0.74142600E+02, -.25759400E+02, -.44038500E+02, 0.66325900E+02, 0.53505200E+02, 0.72509200E+02, -.12484500E+02, 0.16712800E+03, -.82897400E+02, -.83558600E+02, -.42642600E+02, -.51634800E+02, -.35535000E+02, 0.36590800E+01, 0.63894700E+02, -.59442800E+02, -.56883500E+01, -.15678800E+02, -.57290200E+01, 0.11993100E+02, 0.49330900E+01, 0.16472600E+02, 0.14545000E+02, -.62111600E+01, -.48953700E+02, -.50092100E+02, -.11384600E+02, 0.11170400E+02, -.12091700E+02, 0.27841300E+02, 0.60365900E+01, -.13715000E+02, 0.67337600E+01, -.11749300E+00, 0.24408100E+02, 0.78364800E+01, -.19871100E+01, 0.10545700E+02, -.86650100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.59429700E+01, -.52080300E-01, 0.47069800E+01, 0.30115300E+01, -.17845700E+02, -.57190500E+00, 0.17057500E+02, 0.90436200E+01, 0.15689300E+01, -.22276100E+01, -.56878700E+01, 0.47112100E+01, -.34000600E+01, 0.57896900E+01, 0.19054300E+01, -.21294300E+01, -.11624500E+01, 0.12201900E+01, 0.36145500E+01, -.27231500E+01, 0.49242300E+01, -.55754500E+00, 0.16451000E+01, -.88011700E+00, -.13474600E+01, 0.11462800E+01, -.89905300E+00, -.76867200E+00, 0.51978300E+00, 0.61712500E-01, -.10794200E+01, -.22043800E+01, -.19197100E+00, 0.52009000E+00, 0.20860300E+01, -.11516400E+01, 0.15086100E+00, -.11873100E+01, 0.31220600E+01, -.14633300E+01, -.19445400E+00, -.57472600E+00, 0.25736600E+01, -.37040900E+00, -.28524700E+01, -.31047300E+01, 0.77773000E+00, -.17851000E+01, 0.36447200E+01, 0.27231300E+01, -.48559100E+00, -.20765100E+00, 0.37986000E+01, 0.28437600E+01, 0.12820400E+01, -.16463700E+01, -.95312900E-01, -.62404600E+00, 0.85708000E+00, -.19746300E+00, -.62006700E+00, 0.25266800E+01, -.29737200E+01, -.14933000E+01, -.17220200E+01, 0.42609800E+00, 0.22399400E+01, -.10533500E+01, -.24357300E+01, 0.24950400E+00, 0.33686400E+01, -.77605500E-01, 0.22085000E+01, -.28173800E+00, 0.14296000E+00, 0.12426200E+01, 0.29952200E+00, -.15966100E+01, -.37007900E-02, -.15401000E+01, -.20897600E+00, -.39882000E-01, -.53653200E-01, 0.13058200E+00, -.69995700E+00, -.29872200E+01, 0.30064900E+00, 0.15528900E+01, -.11632400E+01, -.21004900E+01, -.22966500E+00, 0.66838200E-01, 0.94613400E+00, -.19502100E+01, -.17662500E+00, 0.50727700E+00, 0.35237300E+00, 0.15356400E+01, -.50000900E+00, -.14273100E+01, -.81301900E+00, 0.16763800E+01, -.92550100E+00, 0.29793300E+01, 0.23294100E+00, -.27340600E+00, 0.18449200E+00, -.55168700E+00, 0.17946500E+00, -.70302400E-01, -.32694400E+00, -.26192800E+01, 0.10319800E+01, 0.15220700E+00, 0.58522400E+00, 0.82648100E+00, 0.32199200E+00, 0.57068900E+00, 0.34806800E-01, -.39843400E-01, -.74418500E-01, -.62752800E-01, -.15272400E+00, -.58965500E+00, -.29309100E+00, 0.41043500E-01, 0.13409800E+01, 0.54698800E+00, -.58094300E+00, 0.69117300E+00, -.20426600E+01, 0.15392400E+01, 0.92947000E+00, 0.14937400E+01, 0.17561800E+00, -.88261000E-02, 0.81713500E+00, 0.20394900E+00, -.45320300E+00, -.12900900E+01, -.30422200E+00, -.49688700E+01, -.40129200E+01, -.34187200E+00, 0.82294700E-01, -.75866200E-01, 0.17121100E+00, -.16787900E+01, 0.76673000E-01, 0.28833100E+01, 0.18099500E+00, -.12764500E+00, -.13775700E+02, -.32730400E+03, 0.17117600E+03, 0.16333900E+03, -.89331600E+01, 0.13331000E+02, 0.98855600E+02, -.73247500E+02, 0.94828300E+02, 0.43056800E+02, 0.26446100E+02, -.10202300E+02, -.99706000E+01, 0.42358700E+02, -.54441700E+02, -.19649200E+02, -.83066300E+01, -.12490200E+02, -.31085300E+02, -.62968900E+02, 0.43676400E+02, 0.41326500E+02, 0.12606100E+03, -.22796600E+02, -.23461100E+02, -.36229300E+02, -.52628100E+02, -.45055600E+02, 0.28743700E+03, -.14440800E+03, -.14314700E+03, 0.12085200E+03, 0.27200200E+02, -.13175600E+03, -.11485600E+03, -.13282500E+03, -.41597000E+02, -.97245500E+02, 0.55964600E+02, 0.48589800E+02, 0.22193900E+02, 0.21078900E+01, 0.27685400E+02, 0.80244100E+02, -.24302000E+02, 0.14628300E+01, 0.94312400E+00, 0.12653500E+02, 0.39474800E+01, -.25079300E+02, -.49954400E+01, -.13382100E+02, -.69853600E+01, 0.70183200E+01, 0.25390600E+02, 0.15172000E+02, 0.11306600E+01, -.25438900E+02, 0.41699500E+00, -.25161100E+02, -.49249400E+01, 0.20928300E+02, 0.67335300E+01, -.36092500E+00, -.26562500E+02, -.17775600E+02, 0.60789400E+00, -.72780500E+01, 0.20896000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12717100E+01, -.28677600E+00, 0.99090000E+00, 0.68759700E+00, -.70385600E+01, 0.26429500E-02, 0.69537200E+01, 0.39625100E+01, 0.27305500E+00, -.74307500E+00, -.20628900E+01, 0.12020900E+01, -.17129500E+01, 0.16973600E+01, 0.75325900E+00, -.12412700E+01, -.54279300E+00, -.63100000E-01, 0.10227100E+01, -.69848500E+00, 0.35611200E+01, 0.85766000E-02, 0.24102100E+00, -.47918800E+00, -.12080100E+00, 0.64080600E+00, -.63913500E+00, -.27313700E+00, -.37229000E+00, 0.78289400E+00, -.51202800E+00, -.28174800E+00, 0.19598500E+00, 0.43222100E+00, 0.69322000E+00, -.10175600E+00, 0.41576500E-01, -.27830200E+00, 0.50522900E+00, -.37873900E+00, -.15069800E+00, -.20498400E+00, 0.70245600E+00, 0.50936600E-01, -.10064100E+01, -.97189900E+00, 0.21759600E+00, -.46612400E+00, 0.13773600E+01, 0.92672100E+00, -.52173200E-01, 0.24561900E+00, 0.26482300E+00, 0.99477800E+00, 0.45203000E+00, -.36436400E+00, 0.11768400E+00, -.68825700E-01, 0.23717900E+00, -.36653700E+00, -.62529800E-01, -.43566100E+00, 0.32455100E+00, 0.13612300E+01, -.44615800E+00, 0.14295900E+00, -.47917200E+00, -.11381000E+00, -.55606600E-02, 0.16146800E-01, 0.26806200E+00, -.95236300E-01, -.17035600E+00, 0.59154500E-01, -.21486500E+00, -.26019300E+00, 0.27376200E+00, 0.55876700E+00, -.65583700E-01, -.11352500E+00, 0.31697500E+00, -.59436100E-01, -.28751100E-02, 0.12991100E+00, -.56386500E+00, -.20473100E+00, 0.36302000E-01, 0.18941100E+00, -.18040500E-01, 0.53875400E+00, -.10249700E-01, 0.13230900E+00, -.16479500E+00, 0.12548400E+01, -.47364200E+00, 0.79337900E-01, 0.33841800E+00, -.27806700E+00, 0.33214700E-01, 0.14064800E+00, 0.27115500E-01, -.15804700E+00, -.31509500E+00, 0.68238200E-01, -.24159800E+00, 0.17268900E+00, 0.69755300E-01, 0.72709100E+00, 0.84574900E-01, -.24294600E-01, 0.14140900E+00, -.20179500E+00, 0.22207900E+00, 0.62155300E-01, 0.27635900E+00, -.36919500E+00, -.10821500E+00, -.37457100E+00, 0.11709700E-01, 0.52468900E-01, 0.77738500E-01, -.26752500E+00, -.58647700E-01, -.41182400E+00, -.12012000E-01, 0.76249900E+00, -.13076200E+00, 0.50838900E-01, 0.15565000E+00, -.30747800E+00, 0.18655100E+00, -.37970100E+00, -.44205300E-01, 0.74616700E-01, -.16514400E+00, -.42865200E-01, 0.28874800E-01, -.48058300E-01, 0.11810300E+00, 0.65430800E-01, -.66086100E-01, -.17051800E+01, -.84425800E+00, 0.97698700E+00, -.11537000E+00, 0.21319500E-02, -.15123100E-01, 0.18715400E+00, -.86504400E-01, -.83660900E+00, -.13360400E+00, 0.17867200E+00, 0.47197700E-01, 0.18015300E+03, -.97320600E+02, -.90056800E+02, 0.10748200E+02, 0.53007000E+01, -.63799300E+02, 0.87249500E+01, -.83101900E+02, -.14239700E+02, 0.51466200E+02, -.29081400E+02, -.26340900E+02, -.19239300E+02, -.45390600E+01, -.15356300E+02, -.83361000E+01, -.20341700E+02, -.69722000E+01, 0.38586300E+02, -.23532200E+02, -.20710700E+02, 0.27427400E+01, -.12668700E+02, -.62179700E+01, -.22974100E+02, 0.10112500E+02, 0.95256800E+01, -.46046700E+02, 0.15528100E+02, 0.23048400E+02, -.11691500E+02, 0.32982300E+01, 0.24136700E+02, 0.20418200E+02, 0.25438600E+02, 0.14665800E+02, -.47096000E+02, 0.24397000E+02, 0.23601800E+02, 0.22559300E+02, 0.31133200E+02, -.19848200E+01, -.34330000E+02, -.18610900E+02, 0.33321500E+02, -.18133300E+01, -.22061900E+01, 0.83441400E+00, 0.30533500E+01, 0.23893200E+01, 0.22021000E+01, 0.12778500E+01, -.21008400E+01, 0.10515700E+02, 0.18807400E+02, -.10504500E+00, 0.33360900E+01, -.34934900E+00, 0.34269000E+01, 0.16695800E+01, -.40026000E+01, -.54273500E+00, -.71371400E+00, -.66474000E+00, -.27234000E+01, 0.14141400E+01, -.34595500E+00, -.20597300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.77387100E+01, -.11065100E+01, 0.81266500E+01, 0.39983100E+01, -.12691600E+02, 0.84028900E+00, 0.96546400E+01, 0.34725300E+01, 0.10109700E+00, 0.98653700E+00, -.90686500E+01, 0.33857100E+01, -.17787300E+01, 0.15294600E+00, 0.17858700E+01, -.15316300E+01, 0.16166900E-01, 0.46283000E+00, 0.46772300E+00, 0.92508100E+00, 0.40500600E+01, 0.90310600E-01, -.11450800E+01, -.32407100E+00, -.45468900E+01, 0.12401800E+00, 0.26913700E+01, -.27778000E+00, -.81016900E+01, 0.57597100E+00, -.29871100E+00, 0.20439600E+01, -.16547600E+01, 0.37260700E+00, 0.82264700E-01, -.22816300E+01, -.66202800E+00, -.43828900E+00, -.93337000E+00, 0.15945100E+01, -.24454000E+01, 0.81941800E-01, 0.12778200E-01, -.28750700E+00, -.29361600E+01, -.68913500E+00, 0.80573800E+00, -.13245900E+00, 0.40505500E+01, 0.30741600E+01, -.59129000E+00, 0.69299600E+00, -.13995000E+01, 0.18700400E+01, 0.15323700E+01, -.17632800E+01, -.49128100E+00, -.20771700E+00, 0.67553700E+00, -.85146100E+00, -.15714800E+01, -.55423600E+00, 0.13304100E+01, 0.75677900E+00, 0.95030400E-01, 0.74770700E+00, -.14371500E+01, -.10086600E+01, -.30151000E+01, -.19475800E+00, 0.12277900E+01, 0.23396400E+00, 0.20646600E+00, 0.55656700E+00, -.26808200E+00, -.24479800E+00, -.66261400E-02, -.23176300E+01, -.18461000E+00, 0.76242900E+00, -.20071900E+00, -.20952600E+01, -.31781600E+00, 0.10786700E-01, -.67654700E+00, 0.19724700E+01, 0.48042400E+00, 0.58294400E+00, -.79840300E+00, -.82398900E+00, -.10843500E+01, -.61467600E+00, -.58206400E-01, -.23274600E+01, 0.50978300E+00, -.86012300E+00, 0.15773700E+00, -.70314000E+00, 0.38953600E+00, -.13836300E+01, -.80228600E+00, 0.21377000E+01, 0.21371100E+00, 0.41655800E-01, -.93588800E-01, 0.26823100E+00, 0.29508700E-01, 0.91999200E+00, 0.17778900E+00, 0.51539000E-01, 0.25234300E-01, 0.19097500E+01, -.66673800E+00, 0.15896700E+01, 0.11553200E+01, -.12290100E+00, 0.23666700E+00, -.10809000E+01, 0.19622200E+00, 0.42828800E-01, 0.50417000E-01, 0.25237500E+00, 0.43209600E+00, -.16155400E+00, 0.32575700E+00, -.19696500E+01, 0.52644200E+00, 0.20009500E+00, -.21123600E+00, 0.13663300E+01, 0.42030800E+00, -.80265200E-01, 0.11431700E+00, 0.23607900E-03, 0.14327300E+01, 0.20734800E+00, -.25865800E+00, 0.10513700E+01, -.56079500E+00, 0.34261000E+00, 0.58017700E+00, 0.28141000E+01, 0.31146600E+01, 0.32109300E-01, 0.63251500E+00, 0.17295700E-02, 0.15779900E+00, 0.67157000E+00, 0.12587700E-01, -.13137700E+01, -.61668200E+00, -.19052400E+01, -.74757100E-01, -.63835300E-01, 0.72143600E+02, 0.82611700E+00, -.40368400E+01, -.28039300E+01, 0.27943200E+01, -.63246000E+00, 0.96335200E+01, -.13669800E+01, -.21736800E+01, 0.44122400E+01, 0.13409000E+01, 0.40625200E+01, -.62811100E+01, -.21624900E+01, -.27788900E+01, -.89364100E+00, -.53953800E+01, -.18558200E+02, 0.18140600E+02, 0.99503900E+01, 0.91746600E+01, -.39751300E+01, -.80535800E+00, -.94704400E+01, -.52685900E+01, -.68872600E+01, 0.17149400E+02, -.15481100E+02, -.87000300E+01, 0.73725200E+01, 0.13648200E+01, -.83534600E+01, -.67633600E+01, -.89758900E+01, -.25033100E+01, 0.38240700E+00, 0.30232900E+01, -.17789300E+00, -.10449600E+01, -.31206600E+01, 0.16362900E+01, 0.91474100E+01, 0.29732000E+01, -.43510600E+01, 0.72194000E+00, 0.24120800E+01, -.20642400E+00, -.28789900E+01, -.86086900E+00, -.24142600E+01, -.77756700E+00, 0.10479400E+01, -.98597800E+00, -.32677700E+01, -.81203000E-01, -.29435200E+01, 0.11233700E+00, -.24743400E+01, -.64131700E+00, 0.21199700E+01, -.23669100E+00, 0.58019000E+00, -.16450200E+01, -.12162800E+01, 0.69714000E+00, -.97230100E+00, 0.18805300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.38365200E+01, 0.59204800E+00, -.54529600E+01, -.24263400E+01, 0.65847400E+01, -.23504200E+00, -.50677100E+01, -.32831100E+01, -.11003500E+00, -.11928800E+00, 0.38665300E+01, -.18260600E+01, 0.50462800E+00, -.71926900E+00, -.12697300E+01, 0.72892000E+00, 0.56488500E+00, -.47060400E+00, 0.16513200E+00, -.99382100E-01, 0.78638000E+00, -.35798600E-01, 0.13757700E+00, 0.50844000E-01, 0.18476400E+01, 0.20903100E+00, -.19759700E+01, -.58570900E-01, 0.41293600E+01, -.35987900E+00, -.13931200E-02, -.18416000E+01, 0.11699800E+01, 0.38827500E+00, 0.94190700E-01, 0.93058500E+00, 0.31043400E+00, -.39416200E+00, 0.54383400E+00, -.15036600E+01, 0.51108800E+00, -.25065000E+00, 0.29387100E+00, 0.54630900E+00, 0.18919700E+01, -.78603400E-01, -.36744600E+00, -.24893600E+00, -.17371000E+01, -.13493600E+01, 0.26674800E+00, -.32255000E+00, 0.10957900E+01, 0.10384300E+00, -.71202300E+00, 0.11417900E+01, 0.12017200E+00, 0.11565100E+00, -.16442400E+00, -.51040900E-01, 0.71809300E+00, 0.54643500E+00, -.60496700E+00, 0.28668300E+00, -.82290400E-01, -.33581600E+00, 0.70701500E+00, 0.35466400E+00, 0.11643600E+01, 0.83185000E-01, -.43547100E+00, 0.22753000E-01, -.15081500E+00, -.20871000E+00, 0.16484600E+00, 0.20464200E+00, 0.28166800E+00, 0.79794100E+00, 0.13840900E+00, -.25981400E+00, -.10467200E-02, 0.84106800E+00, 0.66938000E-01, 0.15728600E-01, 0.22624600E+00, 0.53667600E+00, -.25456900E+00, -.69727200E+00, 0.56049600E+00, -.37200700E+00, 0.35972900E+00, 0.32882200E-01, 0.78259900E-01, 0.61823800E+00, -.41948200E+00, 0.10367200E+00, -.50424100E-01, 0.34038500E+00, -.12800100E+00, 0.60911900E+00, 0.17345700E+00, -.13630800E+01, -.28497800E+00, -.14017500E+00, -.65218900E-01, -.89913900E-01, -.19794700E-01, -.22672600E+00, -.84713600E-01, -.43236900E-01, -.80609900E-01, -.60059500E+00, -.14170300E+00, -.74929100E+00, -.35539500E+00, -.88777300E-01, 0.58655200E-01, 0.23947600E+00, -.98197500E-01, -.10681600E-02, 0.69758700E-01, -.62951700E-03, -.22607300E+00, 0.39333100E-01, -.19518500E+00, 0.53389600E+00, -.73162700E+00, 0.56539100E-01, 0.53918500E+00, -.65658500E+00, 0.24956800E+00, 0.26976700E-02, -.24121200E+00, -.24361700E+00, -.83489000E+00, 0.23924400E-01, 0.11553900E+00, -.53804300E+00, 0.36216900E+00, 0.56287000E-02, -.27193900E+00, -.11245000E+01, -.16455400E+01, 0.38760600E+00, -.50741800E+00, 0.24105800E-01, -.14211500E+00, -.48519900E+00, 0.16963200E+00, 0.84083100E+00, 0.18868100E+00, 0.68776200E+00, 0.83336900E-01, -.52947800E-01, -.37781400E+00, 0.21247200E+01, -.16301500E+00, 0.11959200E+01, -.16129500E+01, 0.94335500E+00, -.89694000E+01, 0.21848500E+01, 0.17610800E+02, -.13021500E+02, -.83269300E+01, -.89873300E+01, -.23324000E+01, -.55662800E+01, -.12142200E+02, -.12235500E+02, -.22322700E+01, 0.22816600E+02, -.15294500E+02, -.12930200E+02, 0.11549800E+01, -.36437400E+01, -.31838100E+00, 0.50518500E+01, 0.17422800E+01, 0.10240500E+02, -.21015100E+02, -.34374700E+01, 0.10094500E+02, -.31898000E+01, 0.27725700E+01, 0.60067900E+01, -.14664200E+01, 0.54164200E+01, 0.36336200E+01, -.95041900E+01, 0.38593400E+01, 0.49050300E+01, -.30718100E+01, -.53973300E+01, 0.73760800E+01, -.90188600E+01, 0.17170000E+02, -.22343700E+01, -.29595400E+01, -.46164100E+01, 0.17340900E+00, -.10510800E+01, 0.86196500E+00, 0.46739500E+01, -.36745000E+00, -.91356600E+00, 0.75216000E+00, 0.41846700E+00, -.63181700E+00, -.76277700E+00, -.21061800E+00, 0.97766800E+01, 0.54622200E+00, 0.67184700E-01, -.54367000E+00, -.39810200E+00, 0.81644300E+01, -.19015800E+01, 0.97190800E+00, -.26319300E+01, -.41527200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12613700E+02, -.15712100E+01, 0.12694600E+02, 0.52706400E+01, -.19115500E+02, -.30484600E+00, 0.12100400E+02, 0.16386700E+01, -.93077100E+00, -.20705100E+01, -.94734100E+01, 0.66563800E+01, -.24598000E+01, 0.33371300E+01, 0.17418200E+01, -.27741400E+01, 0.19348500E+01, 0.86012800E+00, 0.38230700E+01, 0.17357500E+01, 0.56303400E+01, 0.25147400E+00, -.18495100E+01, -.31213000E+00, -.41975700E+01, 0.13846500E+01, 0.63469100E+01, 0.16059700E+00, -.70335100E+01, 0.25277000E+01, -.83402700E+00, -.16137100E+01, -.12755100E+01, -.94658900E+00, -.12177800E+01, 0.10182600E+01, -.29446400E+01, 0.10052000E+00, -.18502100E+01, 0.28236500E+01, -.25483400E+01, 0.18407600E+00, 0.11456000E+01, 0.89292000E+00, -.39949400E+01, -.84740400E+00, -.80192200E+00, 0.36524000E+01, 0.85872600E+01, -.20356400E+01, -.94761300E+00, -.22193500E+00, 0.69991300E+00, 0.34682300E+01, 0.65644800E+00, -.94380700E+00, -.82227300E+00, -.60109200E+00, 0.10596400E+01, -.84028100E+00, 0.68958700E+00, -.24238500E+01, 0.35868400E+01, 0.74953400E+01, -.27179400E+01, -.11464000E+01, -.27622900E+01, 0.60446900E+00, 0.11888800E+01, -.48774000E+00, -.25776300E+01, -.13029500E+01, -.36244300E+00, -.91310900E-01, 0.80337800E+00, -.25046800E+01, -.14126200E+01, -.23507900E+01, -.15373500E+00, 0.18457600E+00, 0.25788200E+00, 0.10753700E+01, -.29134400E+00, 0.71098100E-01, -.16370300E+00, -.31915600E+00, 0.22923300E+00, 0.79468700E+00, -.14052600E+01, -.79930200E+00, -.90411700E+00, -.10176700E+01, 0.14063700E+00, -.45060500E+01, 0.15762900E+01, -.13249700E+01, -.61310300E+00, -.57384300E+00, 0.47306600E+00, -.22142900E+01, -.12715100E+01, 0.16665000E+01, 0.58502400E+00, -.76873600E+00, -.60536200E-01, 0.34389800E-01, -.80654300E-01, 0.69422300E+00, 0.64993800E-01, 0.88799600E-01, -.45707600E+00, 0.40498800E+01, -.28460700E+01, 0.29427200E+01, -.30633800E+00, -.64294800E+00, 0.11659200E+01, 0.35682000E+00, 0.33285100E+00, 0.16461200E-02, -.75114700E-01, 0.10090700E+01, 0.26896300E+00, -.37040700E-01, -.11120500E+00, -.59348100E+00, -.13092300E+01, 0.66839800E-01, -.84721600E-02, 0.20889800E+00, -.38237400E+00, 0.93161300E-02, -.40489300E+00, -.35647100E+00, -.78631000E+00, 0.31622800E+00, 0.27600700E+00, 0.46235800E+00, -.22522200E+00, -.20711100E-01, -.53966500E+00, -.33127000E+01, -.40804700E+01, 0.75447700E-02, -.60777700E+00, -.43985200E-01, -.26738200E+00, -.20999200E+01, 0.63643600E+00, 0.29084300E+01, 0.14646000E+00, 0.93722400E-01, 0.10756300E+01, 0.58313600E+00, -.11615200E+00, -.27200000E+00, -.90422700E+02, -.50883200E+02, 0.47432900E+02, 0.74463900E+02, 0.86083500E+02, -.21837700E+02, -.19490100E+03, 0.96955300E+02, 0.95237800E+02, -.11982000E+03, -.68439100E+01, 0.10163000E+03, 0.61030300E+02, 0.64310300E+02, 0.27417100E+02, -.46955500E+03, 0.22838500E+03, 0.22501200E+03, -.11777300E+03, 0.37770300E+02, 0.21451600E+03, 0.23208400E+03, 0.18943300E+03, 0.83595900E+02, 0.97673300E+02, 0.68879800E+01, -.49296800E+02, -.56753300E+01, 0.45610500E+02, -.45077600E+02, -.92314900E+02, -.77564100E+02, -.13984500E+02, -.21233800E+02, -.69815800E+00, 0.13085400E+02, -.47140700E+02, -.72919000E+02, 0.58612800E+02, -.84788800E+02, 0.12719600E+03, -.47179000E+02, -.87027600E+01, -.73495500E+02, 0.50817300E+01, 0.19386000E+02, -.64267400E+01, 0.74726800E+02, 0.53952000E+01, 0.23175600E+01, -.47854800E+02, -.68767900E+02, -.82990400E+01, 0.17751900E+02, -.21160300E+01, 0.95221700E+02, 0.46654800E+01, -.51816000E+01, 0.12806500E+02, -.75745000E+01, 0.94764400E+02, 0.16750500E+02, -.68820600E+00, -.90115300E+01, -.36855500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10798800E+01, -.21562400E+00, 0.13026400E+01, 0.66795600E+00, -.42138600E+01, 0.42698600E-01, 0.33621200E+01, 0.17648700E+01, 0.93717300E-01, -.34633600E+00, -.16116300E+01, 0.60238400E+00, -.78709600E+00, -.21838300E+00, 0.91807500E+00, -.89797700E+00, 0.80399600E-01, 0.66130200E-01, -.45234900E+00, -.59375100E+00, 0.24013900E-01, 0.21740300E+00, -.22691900E+00, -.68553700E-01, -.16985800E+00, 0.12381800E+00, -.15949900E+00, 0.40230000E-01, -.14280100E+01, 0.42135400E+00, 0.48335300E-01, 0.26622100E+00, -.80264200E-01, -.16109500E+00, 0.30926200E+00, 0.97903500E-01, -.69762000E-01, 0.15338800E+00, 0.47425700E-01, 0.30716300E+00, 0.52675200E+00, 0.96483400E-02, 0.18269200E+00, -.22008400E+00, -.47272600E+00, -.29152700E+00, 0.70426700E-01, -.14497000E+00, 0.12116100E+00, -.11710400E+00, 0.11891800E+00, 0.70909400E-01, 0.59452700E+00, 0.67405400E+00, 0.26930100E+00, 0.40497600E+00, -.19142200E+00, -.12215900E-01, -.42293000E-01, -.83911600E-01, 0.28351300E+00, 0.27548600E+00, -.42240400E+00, 0.67469000E+00, -.36917100E+00, -.20900800E+00, 0.20622700E+00, -.79004800E-01, -.20389800E+00, 0.34399600E-01, -.34547300E+00, -.60345500E-01, 0.56055100E+00, 0.33011700E-01, 0.75835700E-01, -.26982300E+00, -.31498500E+00, -.97701100E+00, -.27361400E-01, -.91928200E-01, 0.66033500E-01, 0.78448400E-01, 0.36454500E-02, 0.52801500E-03, 0.40430300E+00, -.55662400E+00, 0.33261400E-01, 0.20990200E+00, -.85596800E+00, 0.42570400E+00, -.47200300E-01, -.66500700E-01, -.49842700E-01, 0.24901900E+00, -.14492800E+00, -.51555500E-01, 0.90195800E-01, 0.14190500E-01, 0.36966400E-01, 0.20673200E+00, 0.55047100E-01, 0.75453600E-01, -.16841300E-01, 0.63553100E-01, 0.17001300E-01, -.55048400E-01, -.13670100E-01, -.22925600E+00, 0.61132400E-01, -.48071400E-02, -.52695600E-01, -.24488600E-01, 0.19846700E+00, 0.32502200E-02, -.90476700E-02, -.24660400E+00, -.54129600E-02, -.38467500E-01, -.64047400E-02, 0.15195400E-01, -.49444000E-01, 0.63783200E-01, -.44871700E-01, 0.59077700E-01, 0.32497400E-01, 0.23613800E+00, 0.91112900E-01, -.93155100E-01, -.47904800E-01, 0.37462500E-01, -.72359800E-01, 0.13767300E+00, -.12438700E+00, 0.49644100E-01, -.24055400E+00, -.47103500E-02, 0.14029200E+00, -.17203300E+00, 0.26722300E-01, -.26008700E+00, 0.61069800E-01, 0.15547400E+00, 0.16776200E+00, -.14675600E+00, 0.11019600E+00, -.11260900E-01, 0.74030400E-01, -.17221000E+00, -.85004500E-01, 0.29908800E-01, 0.47729700E-01, 0.11047100E+00, -.91629900E-01, -.60693800E-01, -.48828600E-01, -.23097600E-01, 0.14696800E-01, 0.74870100E+01, -.18084000E+01, -.16902700E+01, 0.49345600E+01, 0.45196400E+01, 0.54219200E+01, -.92240900E+00, -.34607300E+01, 0.13041200E+02, -.52779700E+00, -.15811400E+01, 0.68703000E+01, 0.72740300E+01, -.39043000E+01, -.17041200E+02, 0.10997700E+02, 0.77190800E+01, 0.65605800E+01, 0.21303700E+01, -.82747000E+00, -.18552600E+02, -.41946100E+01, -.86314400E+01, -.18421800E+02, 0.97695100E+01, 0.92232000E+01, 0.12665200E+02, -.85475900E+01, 0.70694200E+01, 0.10522800E+02, 0.89669500E+01, -.14295400E+01, 0.17678500E+02, -.84662000E+01, -.91506400E+01, 0.18950400E+01, 0.21621300E+01, -.96934900E+01, 0.96413300E+01, -.22116500E+01, -.21547900E+01, 0.36772100E+00, 0.40969200E+01, -.48894800E+00, -.14868400E+01, 0.87925500E+00, -.39859900E+01, 0.28392800E+01, -.50514600E+00, -.27250300E+01, -.32512400E+01, -.27400900E+01, -.17991000E+01, -.26287500E+01, -.76010500E+01, 0.93223000E+00, -.25926100E+01, 0.21142700E+01, -.70170800E+00, -.68101800E+01, -.57147000E+00, 0.22511100E+00, 0.19361000E+01, 0.21954700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10204900E+01, -.32897900E+00, 0.62310900E+00, 0.43940700E+00, -.32918900E+01, 0.67548600E-01, 0.39777900E+01, 0.20364900E+01, -.62419000E+00, -.24385900E+00, -.12148900E+01, 0.58766100E+00, -.93709900E+00, 0.82376100E+00, 0.34829400E+00, -.42542600E+00, -.27546400E+00, -.70841900E-01, 0.26063900E+00, -.62247200E+00, 0.11998400E+01, 0.15936500E+00, 0.38404300E-01, -.35373100E+00, 0.35301000E-01, 0.25422600E+00, 0.94183200E-01, -.95499500E-01, -.10417900E+00, 0.38969500E+00, -.19753300E+00, -.18296000E+00, 0.39059500E-01, 0.24678900E-01, 0.21626200E+00, -.25195300E+00, -.54346400E-01, -.21403100E-01, 0.10463200E+00, -.32802200E+00, -.51479800E-01, -.71063300E-01, 0.31511900E+00, 0.68039200E-01, -.34429700E+00, -.21426700E+00, 0.20099000E-01, 0.52323300E-01, 0.33700600E+00, 0.27268100E+00, 0.16661300E-01, 0.30788400E-01, 0.39336300E+00, 0.62492800E+00, -.70001400E-02, 0.23209100E+00, 0.85221000E-01, -.13401800E+00, 0.55356800E-01, -.85213000E-01, 0.19215100E+00, -.17611200E+00, 0.16602700E+00, 0.54334300E+00, -.12656900E+00, 0.11550500E+00, 0.62382900E-01, 0.49227600E-01, 0.14690600E+00, -.59291200E-01, -.25949800E+00, -.18523400E-01, 0.14987200E+00, 0.40028800E-01, -.23790200E+00, -.93687100E-02, 0.12831500E-02, 0.37376300E+00, 0.53370100E-01, -.16668000E+00, 0.16433500E+00, 0.65299100E-01, 0.25998800E-01, 0.17648700E-01, -.81352600E-01, -.10151000E+00, -.85687200E-01, -.10217200E+00, -.52817900E-01, 0.11522000E+00, 0.74730900E-01, 0.35005300E-01, -.86313400E-01, 0.64479000E+00, 0.10835000E-01, 0.10834600E+00, 0.58240500E-01, -.20728300E+00, -.27721600E-01, -.47446100E+00, 0.27143300E+00, 0.52320500E+00, 0.43599100E-01, 0.22322500E+00, 0.13378800E-01, 0.11508700E-02, 0.25554500E-01, 0.21643900E+00, -.23151100E-01, -.14513800E-02, 0.42044000E-02, -.28591000E+00, 0.16221900E+00, 0.20647900E+00, 0.21896500E+00, 0.26534700E+00, 0.15221700E-01, -.85935400E-01, 0.47760700E-02, 0.19004200E-01, 0.83890100E-01, -.21293000E+00, 0.32507100E-01, -.56017900E-01, 0.55827800E-01, 0.14217100E+00, -.28104900E-01, -.23166300E-01, 0.93539100E-01, -.46330000E-01, 0.56334700E-01, -.11600500E-01, -.13514900E-01, 0.66146300E-02, -.46218200E-01, 0.11202600E-01, 0.28289500E-01, 0.82715200E-02, 0.90202700E-02, 0.98619000E-01, -.58326000E-01, -.12636600E+01, -.44929600E+00, 0.30832500E+00, -.41146000E-01, -.19474800E-02, -.22599000E-01, 0.99224600E-01, 0.89782000E-02, -.82603700E-01, 0.53059500E-02, 0.19965600E+00, 0.57237800E-01, 0.11778900E-01, -.11041300E+00, 0.83777600E-01, -.10630200E+00, -.12923500E+00, 0.42007100E+01, 0.12303600E+02, 0.56939500E+01, -.36719200E+00, -.36621200E+02, 0.19775000E+02, 0.18266000E+02, -.11597600E+02, 0.10044500E+02, 0.18612000E+02, 0.96134900E+01, 0.18825800E+02, 0.83420000E+01, -.54631800E+02, 0.27240100E+02, 0.26678900E+02, -.25549300E+02, 0.10255300E+02, 0.30152600E+02, 0.26945500E+02, 0.29711900E+02, 0.40752800E+01, 0.10362400E+00, 0.76465400E+01, 0.16637200E+00, -.14959100E+02, 0.80870600E+01, 0.36430200E+01, 0.94018300E+01, -.28934300E+01, 0.53563300E+01, 0.64569300E+01, -.50313200E+01, -.32325200E+01, -.18965100E+01, -.19596900E+01, -.65422300E+00, 0.14886700E-01, -.24046100E+01, -.53794100E+00, 0.15629900E+01, -.67029400E+01, 0.56852400E+00, 0.53382400E+01, -.70683600E+00, 0.66582800E+01, 0.15522200E+01, 0.57187500E-01, 0.31424300E+01, 0.54449300E+01, 0.74007600E+00, 0.53351300E+01, 0.83857300E+00, 0.45754900E+01, 0.98142900E+00, -.39640900E+01, 0.13349400E+01, -.12935400E+01, 0.52915300E+01, 0.51381300E+01, -.28782000E+01, 0.33866100E+01, -.21754600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14008200E+01, -.56846900E+00, 0.13539800E+01, 0.67670600E+00, -.35769400E+01, 0.10584100E-01, 0.40713500E+01, 0.24033300E+01, -.25171400E+00, -.34980500E+00, -.11842300E+01, 0.60339100E+00, -.81364700E+00, 0.91698500E+00, 0.57472900E+00, -.74164800E+00, -.39231700E+00, -.39937000E-01, 0.78305200E-01, -.50440000E+00, 0.97612100E+00, 0.78385000E-01, 0.14831400E+00, -.18539400E+00, 0.86175300E-01, 0.20725300E+00, -.49353400E+00, -.17840000E-01, -.29828900E-01, 0.50949400E+00, -.21375300E+00, -.24565100E+00, -.14306400E+00, -.16531700E+00, 0.46563600E+00, -.14713500E+01, 0.62421600E-01, -.12097300E+00, 0.31330800E+00, 0.53060700E-01, 0.17942200E+00, -.25186100E-01, 0.19773900E+00, 0.16105100E+00, -.41360000E+00, -.28577600E+00, 0.15136400E+00, -.13197100E+00, 0.10606800E+00, 0.37419600E+00, 0.60971000E-01, 0.82051300E-01, 0.98979100E-01, 0.13217500E+00, 0.74667600E-02, 0.40328100E-01, 0.34008800E-01, -.72654000E-01, -.89042300E-02, -.97638500E-01, 0.15890800E+00, 0.54656800E+00, -.28266100E+00, -.10167700E+01, 0.26193000E+00, 0.21099000E+00, 0.78301500E+00, -.18472900E+00, -.50815900E+00, 0.87123300E-03, 0.11288800E+00, 0.15892200E+00, 0.62159500E+00, 0.97751100E-01, -.40823300E+00, 0.55477300E+00, 0.44978800E-02, 0.22342500E+00, 0.10636400E-01, 0.55390500E+00, 0.12519700E+00, -.20775600E+00, -.20829100E-02, -.53144000E-01, 0.13750900E+00, -.28689300E+00, -.10088600E+00, -.79204400E-01, 0.70925900E-02, -.26889400E+00, 0.35459300E-01, -.15847400E+00, 0.68039900E-01, -.20888200E+00, 0.20934000E+00, 0.67937500E-01, -.85999700E-01, 0.13200200E+00, -.51053400E-02, -.34390400E+00, 0.28103100E+00, -.68278500E-01, 0.74660400E-01, 0.15577700E+00, 0.39388900E-01, 0.33168000E-01, 0.31865900E-01, -.39965100E-01, -.78727500E-01, 0.43642500E-02, 0.36082200E-01, 0.35904900E+00, -.96470200E-01, 0.18199000E+00, 0.33853600E-01, 0.11560600E+00, 0.38632400E-01, -.53820400E-01, 0.19591200E-01, 0.19263900E-01, 0.55764400E-01, 0.10498300E+00, 0.28570300E-01, -.67938800E-02, -.10735700E+00, 0.49993400E+00, -.84852200E-01, -.75304700E-01, 0.11810400E+00, 0.18914100E+00, -.10548400E+00, -.12869700E-01, -.45744000E-01, 0.52408800E-01, -.23937900E-01, 0.71001400E-01, -.39090700E-02, 0.23763500E-01, -.78351300E-01, 0.16541700E+00, -.20813100E+00, -.77859700E+00, -.78227600E+00, 0.54345000E+00, -.45770800E+00, -.42232500E-02, 0.83008200E-02, 0.78045300E-01, 0.84887700E-01, 0.70949400E-01, -.61386900E-01, 0.16044300E+00, -.39123600E-02, 0.10394300E-03, -.85478300E-01, -.27059800E-01, 0.12079700E+00, 0.73407900E+00, -.77077200E+00, -.10523200E+02, -.12802800E+02, 0.76916600E+00, 0.18292700E+02, -.89187700E+01, -.90894000E+01, -.18154700E+01, -.11151900E+02, -.21180400E+01, 0.25268500E+01, 0.37806600E+01, -.51421800E+01, -.52229900E+02, 0.23940500E+02, 0.27565500E+02, 0.81149600E+01, 0.27664300E+01, 0.19826400E+02, 0.26611200E+02, 0.21606300E+02, 0.14923200E+02, 0.33042700E+01, 0.86449300E+01, -.13341100E+01, 0.55217700E+01, 0.10458600E+02, -.19362500E+00, 0.35526700E+01, 0.25363500E+00, 0.12338100E+02, -.12816300E+02, 0.57766400E+01, 0.66996200E+01, 0.27628200E+01, 0.61446100E+01, 0.88945300E+00, -.49238300E+01, -.11179100E+02, 0.41684000E+01, -.31596800E+01, -.82756000E+01, 0.61808200E+01, -.24283200E+01, 0.30180600E+01, 0.77957200E+01, 0.20304700E+01, -.33496700E+01, -.58942100E+01, -.47583100E+01, -.63230500E+00, -.24888400E+01, -.68309100E+00, 0.12559900E+02, 0.21509700E+01, -.17415500E+01, -.25542200E+01, -.27632300E+01, 0.99434500E+01, -.38549600E+01, -.13251400E+01, -.25622100E+01, -.19625600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.62428300E+01, 0.86123100E+00, -.91392100E+01, -.34946100E+01, 0.10025000E+02, 0.52685800E+00, -.65182200E+01, -.39376100E+01, 0.34700700E+00, 0.17899200E+01, 0.33055600E+01, -.31497400E+01, 0.60629900E+00, -.25422300E+01, -.15669500E+01, 0.14490100E+01, 0.44620300E-02, -.73760900E+00, -.10654800E+01, -.24901400E+00, 0.20816000E+01, -.18687900E+00, 0.32628500E+00, -.23283000E+00, 0.15405600E+01, -.30955500E+00, -.43565000E+01, -.54642300E+00, 0.41936500E+01, -.16984600E+01, 0.14145300E+00, -.82341700E+00, 0.13520000E+01, 0.18655400E+01, 0.10951100E+01, -.62722700E+00, 0.14789700E+01, -.11379000E+01, 0.29468700E+01, -.27410400E+01, 0.27452200E+00, -.55621500E+00, 0.90924900E+00, 0.19691700E+00, 0.12368500E+01, -.51904500E+00, 0.38329800E+00, -.22456300E+01, -.29494700E+01, 0.91851500E+00, 0.30298000E+00, 0.12423900E+00, 0.35236900E+00, -.40801000E+00, -.18697700E+00, 0.10562800E+00, -.13615600E-01, 0.49931300E+00, -.79643500E-01, -.36320600E+00, -.61725300E+00, 0.18700900E+01, -.21333600E+01, -.26071700E+01, 0.89997200E+00, 0.27354400E+00, 0.13173200E+01, -.55879800E+00, -.12269400E+01, 0.34435200E+00, 0.15641900E+01, 0.91810000E+00, 0.22544300E+00, 0.56478100E-01, -.50904500E+00, 0.14051900E+01, 0.11627200E+01, 0.78559700E+00, 0.94148300E-01, -.10944400E+01, -.25314100E-01, -.11738400E+01, 0.38472800E-01, 0.65659200E-01, -.94013600E+00, 0.19207200E+01, 0.46048300E-01, -.20868500E+00, 0.58316300E-01, 0.12890500E+00, -.25881000E+00, 0.10313000E+01, -.33158400E+00, 0.29555600E+01, -.10483800E+01, 0.49574300E+00, 0.77857200E+00, -.30261000E+00, -.71435900E-01, 0.16207100E+01, 0.43005000E+00, -.20117400E+01, -.64488300E+00, 0.71197300E+00, -.49281600E+00, 0.55956200E+00, 0.19721300E+00, 0.16396100E+00, 0.16307400E+00, -.11698100E+00, 0.48648300E+00, -.33329800E+00, 0.13123500E+01, -.15464900E+01, 0.28728800E+00, 0.43336200E+00, -.44947700E+00, -.49626200E+00, -.15710500E+00, 0.29538700E-01, 0.15237500E+00, -.11221200E+01, -.13902800E+00, -.49917900E+00, 0.24449400E+00, 0.44260700E+00, -.75436500E+00, 0.14451200E+00, 0.17652300E+01, -.76778800E+00, 0.61701900E+00, -.41947000E+00, -.22281300E+00, -.36603500E+00, -.52482600E+00, -.59848000E+00, -.20510900E+00, -.25829800E-01, 0.61058400E+00, 0.47911300E+00, 0.41587600E+00, -.22897000E+00, 0.45299700E-01, 0.30712600E+01, -.34290200E+00, 0.80837100E-01, -.42080600E-01, 0.29122100E+00, 0.36981800E+00, -.99998800E+00, -.57693700E+00, -.70466500E+00, -.72629900E-01, 0.87155800E-01, 0.36320500E+00, -.39466900E+00, -.45202500E+00, 0.37437100E+00, -.17079400E+01, -.23246800E+01, -.70345200E+02, 0.62644000E+01, 0.30511500E+02, -.27202300E+02, -.10174800E+02, -.78304200E+02, -.27638300E+02, 0.20989500E+02, -.16969700E+02, 0.48785200E+01, -.15439500E+02, -.11465500E+03, 0.34043200E+02, 0.53678900E+02, -.25038700E+02, 0.84024600E+01, 0.10058400E+03, 0.13783400E+03, 0.11710200E+03, 0.10964400E+03, -.44641000E+02, 0.28552000E+02, 0.21481700E+02, -.20564900E+02, 0.55188500E+02, 0.16253300E+02, -.54702600E+01, 0.10672400E+02, 0.48121900E+02, -.83541200E+02, 0.32945700E+02, 0.46883200E+02, -.15042300E+02, -.10430700E+02, 0.46372400E+02, -.63079700E+02, 0.40331900E+02, 0.38961900E+01, -.19262000E+02, -.55577500E+02, 0.21253700E+02, -.27912400E+01, 0.97817200E+01, 0.54661900E+02, 0.48035800E+00, -.11750700E+02, -.21248500E+02, -.20052200E+02, 0.23858800E+00, -.15404900E+01, 0.22505300E+01, 0.84663400E+02, 0.81606600E+01, -.58708900E+01, -.65856500E+01, -.10183600E+02, 0.71617300E+02, -.78946900E+01, -.56329800E+01, -.15827800E+02, -.30056500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14187500E+01, -.24338800E+00, 0.16996200E+01, 0.84301500E+00, -.40156800E+01, 0.85322400E-01, 0.33082300E+01, 0.16088900E+01, -.18711600E-01, -.17777300E+00, -.18729600E+01, 0.70923100E+00, -.73511700E+00, -.20092500E-01, 0.73288700E+00, -.60237800E+00, -.12421100E+00, -.29593500E-01, -.45452600E+00, -.52651600E+00, 0.34774900E+00, 0.25575800E+00, -.30264800E+00, -.20371300E+00, -.56174900E+00, 0.91109300E-01, 0.43321500E+00, -.52281700E-01, -.18500500E+01, 0.41516600E+00, -.38715900E-01, 0.39558100E+00, -.40206600E+00, -.16512500E+00, 0.20667300E+00, -.56396200E+00, -.23808200E+00, 0.80073500E-01, 0.39750900E+00, 0.20531400E+00, 0.65802300E+00, 0.53468800E-01, 0.18063600E+00, -.19205100E+00, -.30855200E+00, 0.14218600E+00, 0.14986200E+00, -.24994900E+00, -.56811300E+00, 0.12244800E+00, 0.86342900E-01, -.78821400E-01, 0.58753400E+00, 0.40771100E+00, 0.27578100E+00, 0.59948300E+00, -.71901000E-01, -.73588000E-01, -.11151200E+00, 0.11707600E+00, 0.23517600E+00, 0.44060900E+00, -.24706100E+00, -.33141000E+00, -.10229300E+00, -.19627300E-01, 0.18573700E+00, -.68868200E-01, -.22614600E+00, -.32002600E+00, -.34227400E+00, -.78945200E-01, 0.42130900E+00, 0.75696500E-01, -.66523000E-01, -.50645100E+00, -.33455200E+00, -.58122300E+00, 0.31124700E-01, 0.30170400E+00, 0.58126300E-01, 0.57360800E-01, -.80282100E-02, -.27613000E-01, 0.64577800E+00, -.42099200E+00, -.22257400E-01, -.63734800E-01, -.53310800E+00, -.23138400E-04, 0.20702300E+00, -.39079100E+00, -.13874700E-01, -.18698900E+00, -.57900000E-01, 0.70641000E-01, -.12818400E+00, 0.62157900E-01, 0.88322600E-01, 0.37288200E+00, 0.16481800E+00, -.98968900E+00, -.10926300E+00, 0.17480600E+00, -.43276800E-01, -.40869700E-01, -.10524600E-01, -.16636400E+00, 0.89689000E-01, -.16703100E-01, -.87363900E-01, 0.15814800E-02, 0.61564000E-01, -.37394800E-01, -.17497700E-01, -.74563000E-01, 0.12655800E+00, 0.74878100E-01, -.80199300E-02, 0.14270100E-01, -.33399600E-01, -.50997200E-01, -.96332200E-01, -.94592100E-01, -.29075100E-01, 0.39026800E+00, 0.94535000E-01, 0.13666100E-01, 0.38486300E-01, -.75339000E-01, 0.20253900E-01, 0.11436600E+00, -.37398200E-01, -.51432300E-01, -.11819900E+00, -.21442100E-01, 0.11059700E+00, -.10963300E+00, 0.33215300E-01, -.20285900E+00, -.32607300E-01, -.73137600E-01, 0.23052100E-01, -.29717200E+00, 0.61514900E-01, -.35892900E-02, 0.48835200E-01, -.25392200E+00, -.77946000E-01, 0.10270200E+00, 0.80088400E-01, 0.17945100E+00, -.41290400E-01, 0.43425300E-01, -.82806100E-01, -.42774100E-02, 0.10527100E-01, 0.91281500E+00, -.60115400E-01, -.13106900E+00, 0.54710300E-01, 0.23858300E+01, 0.46975800E+01, -.22115400E+01, -.26881900E+01, -.31281000E+01, -.30941800E+01, -.23963000E+01, -.26566800E+01, 0.11997300E+01, -.19060600E+01, -.36419600E+00, 0.62279300E+00, 0.44718000E+00, 0.98637600E+00, -.40758500E+01, -.34895400E+01, -.88035900E+01, -.44213300E+01, -.36273300E+01, 0.20427100E+02, -.11310700E+02, -.10139200E+02, 0.41021200E+00, 0.30114100E+01, -.75576500E+01, -.49200500E+01, -.10437400E+02, -.23954900E+01, 0.39492000E+01, -.21551700E+01, -.22726400E+01, 0.10400400E+01, -.23611300E-01, -.18876400E+01, -.92302200E+00, -.21532800E+01, -.93068100E+00, -.74070400E+00, 0.20702300E+00, -.26046300E+01, -.21164800E+00, 0.10127500E+01, -.36394400E+00, 0.15305900E+01, -.96597000E+00, -.17730200E+01, -.16380400E+01, -.83103900E+00, -.21542000E+00, -.76383700E+00, -.20101500E+01, 0.68770400E+00, -.81029400E+00, 0.11825100E+01, -.27893500E+00, -.27877000E+01, -.59490900E+00, 0.23834700E+01, 0.14933500E+01, -.61255100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.31100100E+01, -.52030800E+00, 0.24132500E+01, 0.17126700E+01, -.18072400E+02, 0.26777300E-01, 0.17542400E+02, 0.10314900E+02, 0.62395600E+00, -.18050400E+01, -.53103600E+01, 0.27248400E+01, -.46028900E+01, 0.35719700E+01, 0.17996100E+01, -.31055700E+01, -.12552800E+01, -.34605600E+00, 0.22988900E+01, -.22158300E+01, 0.84821500E+01, 0.37734800E+00, 0.23186000E+00, -.94266300E+00, -.25766100E+00, 0.17304000E+01, -.21528100E+01, -.45420300E+00, -.19464000E+01, 0.27061800E+01, -.11794500E+01, 0.28162900E+00, 0.80945900E+00, 0.76536700E+00, 0.98837600E+00, 0.91338500E+00, 0.46909000E+00, -.61926100E+00, -.70059000E-01, 0.53138500E+00, -.80638700E+00, -.52519500E+00, 0.13678000E+01, 0.32959600E+00, -.19464600E+01, -.31340100E+01, 0.84188100E+00, -.21933000E+01, 0.48167400E+01, 0.20212400E+01, -.52950600E+00, 0.86023800E+00, -.28559300E+01, 0.22037600E+00, 0.14355000E+01, -.32906600E+01, -.58227100E-01, 0.56691000E+00, 0.87830700E+00, -.13307800E+01, -.42636600E+00, 0.23403200E+01, -.16972800E+01, -.32967400E+01, -.23702800E+00, 0.56489400E+00, 0.20250100E+01, -.51453200E+00, -.16692200E+01, -.56401000E+00, 0.46045900E+00, 0.25594400E+00, 0.77547600E+00, 0.31882300E+00, -.12734200E+01, 0.21294400E+01, 0.41362800E+00, -.57703400E+00, 0.28400800E+00, 0.20726000E+01, 0.32267700E-01, -.13551900E+01, -.25759700E+00, -.12860300E+00, 0.33550000E+00, 0.36841300E+01, 0.43841200E+00, -.66192500E+00, -.26398200E+00, 0.45270500E+00, -.10769200E+01, -.39605800E+00, -.52847900E+00, 0.11931300E+01, 0.60768200E-01, -.81970200E+00, 0.59925000E+00, -.34840500E-01, 0.62501200E-01, -.89358000E+00, 0.74239500E-01, 0.16047200E+01, 0.23128600E+00, 0.13930800E+01, -.44649500E-01, 0.19501200E+00, 0.11637400E+00, -.65380900E+00, 0.54810700E-01, -.24026300E-01, -.24007300E+00, 0.71673400E+00, -.49438000E+00, 0.39784000E+00, 0.33869400E+00, 0.10480700E+01, 0.60631900E+00, 0.28044500E+00, -.10097500E+00, -.64491700E-02, -.28553700E-02, 0.43265400E+00, 0.11046500E+00, 0.75477800E+00, -.92189200E-02, -.81724300E+00, 0.71719000E+00, -.10845600E-01, 0.11795400E-01, 0.37048400E-01, 0.11800600E+01, -.89858100E-01, -.77633100E+00, -.66475900E+00, -.58453400E+00, 0.37636100E+00, -.11465800E+00, -.60363800E+00, 0.19071900E+00, 0.80381400E+00, -.30267900E+00, 0.61184000E+00, 0.20417800E+00, 0.12872000E+01, -.73120700E+00, 0.85202500E-01, 0.24376200E+00, 0.11372000E+01, 0.60313000E+00, 0.16281300E+01, 0.25095800E+00, 0.92603400E-01, -.21171700E+00, -.18284300E+01, -.21504300E+00, 0.32471500E+00, -.23979000E+00, -.94391000E+00, 0.21040800E+01, -.20918600E+00, -.31933400E+00, 0.30251300E+00, 0.12444400E+03, -.68086600E+02, -.58507400E+02, -.29925200E+02, 0.40909000E+01, -.46070900E+02, -.40238800E+02, -.63032500E+02, -.28446300E+02, 0.13374400E+03, -.78813500E+02, -.63898100E+02, -.69335400E+01, -.24312500E+02, -.65116700E+02, -.73397900E+02, -.65794600E+02, -.78060600E+01, 0.76020400E+02, -.45700500E+02, -.38559300E+02, 0.24430100E+02, 0.48940100E+01, -.37109600E+02, -.33337500E+02, -.42235800E+02, -.38757700E+00, -.19884700E+02, 0.64874500E+01, 0.11050400E+02, -.36500000E+01, -.36115900E+01, 0.11636600E+02, 0.94476000E+00, 0.16420800E+02, -.57212500E+01, -.29614500E+01, 0.90003600E+01, -.12934100E+02, 0.16975600E+02, 0.15789400E+01, -.92438900E+01, -.21055900E+01, -.10410200E+01, 0.14420600E+02, 0.10664100E+02, 0.10313900E+01, 0.17832400E+02, 0.88894600E+00, -.12094900E+02, -.44554200E+00, 0.41561800E+01, -.76311700E+01, 0.16513300E+01, -.11927100E+02, 0.67257100E+01, 0.15380100E+02, -.66804200E+01, -.98607000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13211600E+02, 0.20608800E+01, -.12026800E+02, -.59795100E+01, 0.30267500E+02, -.15363600E+00, -.33430300E+02, -.14253700E+02, 0.19553000E+00, 0.21249700E+01, 0.11812400E+02, -.70623400E+01, 0.76756900E+01, -.88351800E+01, -.34406200E+01, 0.44931800E+01, 0.20737100E+01, 0.16452900E-02, -.42822300E+01, 0.26041200E+01, -.12013900E+02, -.14561600E+01, 0.36541700E+00, 0.17636300E+01, 0.14478200E+00, -.28551600E+01, 0.11431800E+01, 0.71134500E+00, 0.41306800E+01, -.51263500E+01, 0.13368200E+01, 0.12537500E+01, 0.17956700E+00, 0.10017300E+00, -.29570000E+01, 0.14770300E+00, 0.68936300E-01, 0.42632900E+00, -.14787400E+01, -.72260400E+00, 0.26838300E+01, 0.51948900E+00, -.34488900E+01, -.20688700E+01, 0.59101300E+01, 0.36254900E+01, -.15456100E+01, 0.28917100E+00, -.56734800E+01, -.48798000E+01, 0.45448300E+00, -.50130900E+00, -.16053600E+01, -.32568900E+01, -.54226200E+00, 0.20480200E+01, -.33440000E+00, 0.99935600E+00, -.91136800E+00, -.22126500E+00, -.11183100E+01, -.19752000E+01, 0.13500700E+01, 0.35605300E+01, -.13673900E+01, -.22755800E+01, -.30341900E+01, 0.61349700E+00, 0.14806300E+01, 0.17073300E+01, 0.35042600E+00, -.84385100E+00, -.30664000E+01, -.87745100E+00, 0.27849000E+01, -.10525600E+01, -.45685800E+00, -.29161000E+01, -.60151800E+00, -.84980200E+00, -.61258900E+00, 0.78911900E+00, -.22120600E-01, 0.27283400E-01, 0.85458400E-01, 0.32824500E+01, 0.90820700E+00, 0.53841000E-01, 0.13766400E+01, 0.16540500E+01, -.33235000E-01, 0.96984700E+00, -.22138000E+00, -.42570000E+00, -.15027900E+01, -.17415400E+00, -.51514600E-01, 0.92753900E+00, -.40892000E+00, 0.42939400E+01, -.58836600E+00, -.40386400E+01, -.47135900E+00, -.10861000E+01, 0.24832300E+00, -.60886300E+00, -.27056600E+00, -.10739300E+01, 0.47191500E+00, -.53094000E-02, -.50098400E+00, -.27555600E+01, -.21185500E+01, -.12656900E+01, -.12551800E+01, -.98224300E+00, 0.20585900E+00, 0.68290700E+00, 0.42571000E+00, -.26484400E+00, -.59455000E+00, 0.14507700E+01, -.14575900E+00, -.90332600E+00, -.71898500E+00, 0.56455500E+00, 0.12595500E+01, 0.42043600E+00, -.21423700E+01, 0.68501600E+00, 0.29035600E+01, -.84281900E+00, -.16942300E+01, -.71268400E+00, 0.18068200E+00, 0.12262800E+01, -.50769300E+00, -.14085400E+01, -.25830500E-01, 0.10812000E+01, -.57875700E+00, -.50441300E+00, -.81896400E+00, -.29891300E+00, -.26472200E+01, 0.15241500E-01, -.56696800E-01, 0.18085800E+01, 0.90013400E+00, 0.72241800E+00, 0.12000000E+00, 0.49571700E+00, -.45508700E+00, -.97491300E+00, -.27891100E+00, 0.37689300E+00, -.19413300E+00, 0.64993600E+00, -.97695000E-01, 0.54947900E+00, -.62583400E-01, -.35716900E+00, -.48556100E+00, 0.43736300E+02, 0.48002300E+01, -.28128900E+02, -.55923600E+01, -.30458600E+02, -.86761800E+02, -.82393600E+02, -.40334100E+02, 0.15175100E+03, -.66909700E+02, -.70510200E+02, 0.19099300E+02, -.84937000E+02, -.91714000E+02, -.13140100E+03, -.94134000E+02, -.55335000E+02, 0.60913600E+02, -.82005900E+02, -.31281700E+02, -.23763200E+02, 0.98122800E+01, -.28081800E+02, -.45992600E+02, -.34674000E+02, 0.11476200E+02, -.10863300E+03, 0.55542000E+02, 0.54553900E+02, 0.57684900E+01, 0.41077600E+01, 0.38152200E+02, -.16487600E+02, 0.21034100E+02, 0.10515500E+02, 0.86032400E+01, 0.24292500E+02, -.15614100E+02, -.69112100E+00, -.11723500E+02, -.25462000E+02, -.12410100E+02, 0.13125600E+02, 0.15645200E+02, 0.10027700E+02, 0.10971600E+02, 0.66381400E+00, 0.76882100E+01, -.14378900E+02, -.73226300E+01, 0.15590500E+02, -.16981600E+02, 0.91696200E+01, -.13905100E+02, 0.43962600E+01, 0.19867700E+02, -.16716200E+02, 0.20498500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20810300E+01, -.21176300E+00, 0.18604700E+01, 0.89444800E+00, -.56831100E+01, -.83290200E-01, 0.41085300E+01, 0.15229200E+01, -.72015600E-01, -.12427900E+01, -.14366400E+01, 0.16183100E+01, -.81370000E+00, 0.15156000E+01, 0.67243500E+00, -.93292000E+00, -.20661800E+00, 0.35568200E-01, 0.63207800E+00, -.10917300E+00, 0.17718300E+01, 0.70108900E-01, 0.36649700E-01, 0.29864600E+00, -.28306700E+00, 0.55565600E+00, 0.19348700E+00, 0.19626000E+00, -.29693500E+00, 0.11794900E+01, -.17640000E+00, -.62714500E+00, -.19745600E+00, -.78123000E+00, 0.76775700E-01, -.63150200E-01, -.11485600E+00, -.41817900E-01, -.43997200E+00, 0.21794100E+00, 0.27743800E+00, 0.45745700E-01, -.63024200E+00, 0.19597300E+00, 0.17843400E+00, -.81449700E-01, -.18482000E-01, 0.25839400E+00, -.42736800E+00, 0.11858700E+00, 0.16927800E+00, 0.12364800E+00, 0.49704200E+00, 0.42739300E+00, 0.14923900E+00, 0.66562100E+00, 0.17132700E+00, -.14372200E+00, -.60211700E-01, -.42511000E+00, 0.18923700E+00, -.60209500E+00, 0.86808200E+00, 0.12628500E+01, 0.22835900E+00, 0.17883800E+00, -.20588200E+00, 0.14507100E+00, 0.38415500E+00, 0.16656600E-01, -.25922700E+00, 0.11895000E-01, -.29007300E+00, -.56818900E-02, 0.17938900E+00, -.13334000E+00, 0.60013000E-01, 0.74624700E-01, 0.12811400E-01, 0.88422000E-02, -.10370700E+00, 0.10889100E+00, 0.11374400E-01, -.27032700E-01, -.28622500E-01, -.54667500E+00, -.22799600E+00, -.88585100E-01, 0.46242600E+00, -.75048200E+00, -.13994100E+00, 0.39943600E-02, 0.11286300E+00, -.52447200E+00, 0.73290300E+00, -.38490700E-01, -.28157200E+00, -.45470000E-01, -.20676100E-01, -.11121700E+01, 0.15593300E+00, 0.96413700E+00, 0.39610900E+00, 0.96386500E-01, 0.14689800E+00, 0.13778900E+00, 0.24477300E-01, 0.19674900E+00, -.28319400E-01, 0.36939800E-01, 0.50075000E-01, 0.87933700E+00, -.11114200E+00, 0.37018700E+00, 0.10334300E+00, 0.23228100E+00, 0.10907000E+00, 0.91905200E-01, 0.24092100E+00, 0.13636700E-02, 0.16520500E+00, 0.18479500E-01, 0.16086300E+00, 0.55246800E-01, -.82877800E-01, 0.71747500E+00, -.20037600E+00, -.36840400E-01, 0.77990300E+00, -.28932100E+00, -.24225000E+00, -.38663800E+00, 0.14506900E+00, 0.11857800E-01, 0.15278300E-01, -.78077100E-01, -.19015000E-01, 0.11947100E+00, -.36927300E-02, 0.76530700E-01, -.87226000E-01, -.29171400E+00, -.28126200E+00, 0.38161900E+00, 0.39925700E-02, -.40507500E-02, 0.11086700E-01, 0.53083500E-01, 0.78190900E-03, -.66841400E+00, -.15185600E+00, -.25679500E+00, 0.21759200E+00, 0.68309800E+00, 0.17077200E+00, -.12219100E+00, 0.66558100E-02, -.45870900E+00, 0.30691900E+00, -.95443400E+00, 0.28338100E+00, -.30199600E+00, 0.96661500E-01, 0.94559400E-01, -.29868800E+01, 0.10678200E+02, -.10081300E+00, 0.61953200E+01, 0.36252000E+02, 0.16894900E+02, 0.85274300E+01, -.48870000E+02, 0.27705600E+02, 0.24631400E+02, 0.62150300E+01, 0.23375900E+02, 0.21578500E+02, 0.52302200E+02, 0.17610100E+02, 0.26358200E+02, -.28783200E+02, 0.46149300E+02, 0.15128700E+02, 0.74548800E+01, -.12029900E+02, 0.11605300E+02, 0.88955000E+01, 0.19850000E+02, -.52589600E+01, 0.65716300E+01, -.12106900E+01, -.39952300E+01, 0.52263600E+01, 0.79447700E+01, -.97587000E+01, -.11875100E+02, -.24797800E+02, 0.67023900E+01, -.32439400E+01, -.72303700E+01, 0.71728700E+01, 0.88293100E+00, 0.39294900E+01, 0.75995000E+01, 0.25804400E+01, -.42230000E+01, -.77067800E+01, -.47182700E+01, -.21111200E+01, -.21387300E-01, -.24024300E+01, 0.68407700E+01, 0.22724600E+01, -.21778800E+01, 0.44138500E+01, -.35253900E+01, 0.66602900E+01, -.15950700E+01, -.60052700E+01, 0.32227400E+01, -.11166700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.72719800E+00, 0.13081200E+00, -.43745200E+00, -.56404300E+00, 0.50472800E+01, -.31108800E+00, -.38176800E+01, -.18288000E+01, 0.21989000E+00, 0.88800400E+00, 0.91870600E+00, -.98340300E+00, 0.99368500E+00, -.13415900E+01, -.37208000E+00, 0.69265400E+00, 0.52285700E+00, 0.15285800E+00, -.96553800E+00, 0.18023800E+00, -.20929800E+01, -.15033800E+00, -.12549800E+00, 0.47375500E+00, -.81103500E+00, -.43569000E+00, 0.10777500E+01, 0.12056200E+00, -.76071700E+00, -.76315200E+00, 0.42184400E+00, 0.66245600E+00, -.58179700E+00, -.25578300E+00, -.53292000E+00, 0.15274300E+00, -.55978400E-01, 0.14118000E+00, -.82588600E+00, 0.11264800E+00, 0.46401700E+00, 0.16717500E+00, -.16030100E+01, -.30145700E+00, 0.12900800E+01, 0.44237800E+00, 0.38486400E-01, -.22343100E+00, -.22554600E+01, 0.61093000E+00, 0.21861300E+00, -.16922600E-01, -.53509100E-01, -.58383100E+00, -.34447100E+00, 0.80071500E+00, -.30416800E-01, -.10824800E-01, -.20903700E+00, -.13610800E+00, 0.29058300E+00, 0.46535000E+00, 0.21025200E+00, -.89558000E+00, 0.87478000E+00, 0.18987500E+00, 0.57611500E+00, 0.63556500E-01, -.13478700E+00, -.51742400E-01, -.60703300E+00, 0.23093800E+00, -.17213800E+00, 0.28634600E-01, 0.13592500E+00, -.41037900E-01, -.17828100E+00, -.19268700E+00, 0.55427300E-01, 0.56471700E+00, 0.64385400E-01, -.13352000E+00, 0.51426800E-01, -.12479500E+00, 0.48206000E+00, -.36180600E+00, -.24116200E+00, -.15851200E+00, -.26900500E+00, -.23164300E+00, -.13274800E-01, -.20527500E-01, 0.10564600E+00, -.92095700E+00, 0.50491400E+00, 0.58807000E-01, -.36431100E+00, 0.70065000E-01, 0.85208500E-02, -.32621500E+00, 0.16959700E+00, -.18177900E-02, 0.46320300E+00, -.33296700E+00, 0.12752100E+00, 0.69235900E-01, -.79917200E-02, -.54042500E+00, -.10645700E+00, 0.23770700E-01, 0.11252700E+00, 0.14685000E+01, -.40883200E+00, 0.17867900E-01, -.46351100E+00, 0.19101700E+00, -.83597200E-01, 0.73026600E-01, 0.77270900E-01, -.23195600E-01, 0.46784900E-01, 0.87217400E-01, 0.18988300E+00, 0.24617000E+00, 0.74159900E-02, -.24946700E+00, 0.20523700E-01, -.41960000E-01, -.58776200E-01, 0.10670400E+00, -.32464900E+00, -.40763600E-01, 0.35947200E+00, 0.12886400E-01, 0.35561000E+00, -.81828200E-01, -.10910000E+00, 0.32604200E+00, -.16998700E+00, 0.35162600E+00, 0.74424100E-01, 0.97675000E+00, 0.89895700E+00, 0.20174400E+00, 0.22536400E+00, -.35657400E-01, 0.37381100E-01, -.19754500E+00, -.10498900E+00, -.30726200E+00, 0.37221100E-01, 0.67778400E-01, -.10396100E+00, -.29303600E+00, -.41916500E-01, 0.21496000E-01, 0.17675600E+00, 0.14613100E+01, -.10645300E+01, 0.10446700E+01, 0.12509700E-01, -.11860100E+00, -.34769400E-01, 0.36898100E-01, -.38113300E+00, 0.10611100E+02, -.29223400E+01, 0.40668100E+00, 0.12998900E+02, -.64019500E+01, -.12008600E-01, 0.22311100E+02, -.39047600E+01, -.91360800E+01, 0.13910300E+02, 0.51451300E+01, -.65484400E+01, 0.66926700E+01, -.12592600E+02, -.98197400E+01, 0.11967800E+02, 0.77859900E+00, -.58097500E+01, -.13139900E+02, -.11979500E+02, -.80373800E+01, -.74525000E+01, 0.15645300E+01, -.17993000E+02, 0.26699300E+01, 0.35418400E+01, -.18722200E+01, 0.91539400E+01, 0.12443700E+02, -.90537700E+01, 0.20001700E+02, -.35784900E+02, 0.12217000E+02, 0.28121500E+01, 0.39689400E+01, -.13935100E+00, -.46100800E+00, -.11997300E+01, -.36267800E+01, 0.29590600E+00, 0.17896400E+01, -.16083400E+02, -.15818100E+02, 0.21460900E+01, -.31563600E+00, -.26957900E+00, -.12756200E+02, -.18193400E+01, 0.10351600E+01, 0.35456500E+01, 0.14751600E+01, -.12970900E+02, -.63849700E+00, -.39388600E+01, 0.58245400E+01, 0.88060600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.55047100E+01, -.11175800E+01, -.72403500E+01, -.27415800E+01, 0.17914400E+02, -.70853900E+00, -.14327100E+02, -.43465700E+01, -.68989300E+00, 0.12851700E+01, 0.65330000E+01, -.30712300E+01, 0.32549800E+01, -.13465600E+01, -.99470700E+00, 0.31231200E+01, 0.13258300E+01, 0.12243600E+01, 0.25863000E+00, 0.13724000E+01, -.17736700E+01, -.77721400E+00, 0.93156600E+00, 0.87502100E+00, 0.13286100E+01, -.59108300E+00, -.41366900E-01, 0.33904000E+00, 0.30200600E+01, -.10941400E+01, 0.48432800E+00, -.72094300E+00, 0.14340800E+01, -.70148200E-01, -.11691100E+01, 0.34400600E+01, 0.46173100E+00, -.54905100E-01, -.24194400E+01, -.24732600E+01, -.12872400E+01, -.32137300E+00, 0.22585600E+00, -.83532700E+00, 0.34490800E+01, 0.27758400E+01, -.10502400E+01, 0.13860500E+01, -.41135500E+01, 0.27110300E+01, 0.43024000E-01, -.72628100E-01, -.15761300E+01, -.20442700E+00, -.28575800E+01, 0.11627100E+01, -.31855100E-01, 0.94132200E-01, -.61400300E+00, 0.14727700E+00, -.59354800E+00, 0.87902400E+00, -.10633100E+01, -.43795700E+00, -.64087700E+00, -.67187400E+00, 0.20450500E+00, 0.16922600E+00, 0.29505400E+00, -.15120400E+00, 0.71463900E+00, -.10475400E+00, 0.65783300E+00, -.31425800E+00, 0.81096800E+00, 0.51183700E+00, 0.72900000E-01, -.39087400E+00, -.56442000E-01, 0.20454300E-01, -.10463600E+01, 0.28516100E+00, -.95507000E-01, -.32541300E-01, 0.51490000E-01, 0.80907500E+00, -.33901900E-02, 0.15970900E+00, -.20927800E+00, -.19725000E+01, -.64099100E+00, 0.18046700E+00, 0.67670600E+00, -.21845900E+01, 0.76553300E+00, 0.31051500E+00, -.11825000E+00, 0.60078900E+00, -.35602800E+00, -.13012100E+01, 0.13336800E+00, 0.19024700E+01, 0.47364600E+00, 0.10605700E+01, 0.48447400E+00, -.10310500E+00, 0.10670300E+00, -.11908600E+01, -.58630300E-01, -.45000000E-03, -.55133600E-02, 0.35503800E+01, -.23209000E+00, 0.87263600E-02, -.76319100E+00, 0.18133300E+01, -.54926400E-01, 0.31858200E+00, 0.35045500E+00, -.12565000E+00, 0.38048700E+00, -.60198800E+00, 0.22324500E+00, 0.26184000E+00, -.11309800E+00, 0.10636900E+01, 0.50819400E+00, -.38998300E-02, -.11617900E-01, -.14046700E+01, -.16208100E+01, -.30795200E+00, 0.57072300E+00, -.31861700E+00, 0.30305300E+00, -.44281000E+00, -.26663700E+00, 0.84614300E+00, -.12586500E+00, 0.79595300E+00, 0.11876100E+00, -.33210500E+01, -.15864500E+01, 0.31386800E+01, 0.74980500E-02, -.89612700E-01, 0.23604500E+00, -.12593700E+00, -.49980400E+00, -.10613800E+01, -.53778400E+00, -.31441600E+00, 0.32409900E-02, 0.41619400E+00, 0.21673400E+00, -.37840900E+00, 0.19733300E+00, 0.88288400E-01, -.20530700E+01, 0.15058600E+01, -.49262600E+00, 0.17833600E+01, 0.57337100E+00, 0.93707100E-02, -.36542600E+00, 0.81662400E+00, -.96866100E+02, 0.39354400E+02, 0.75575800E+02, 0.12141400E+03, -.57241500E+02, -.23135600E+03, 0.10954900E+03, 0.11216400E+03, 0.93247400E+02, -.13512100E+02, 0.90026600E+02, 0.87419700E+02, 0.11044900E+03, 0.73073900E+02, -.54070800E+02, 0.43209700E+02, 0.26563600E+02, 0.83858700E+02, 0.20413700E+02, 0.11184400E+02, -.18046400E+01, 0.24078000E+02, -.24855300E+01, 0.14535400E+02, -.85001100E+01, -.67480800E+00, -.31020000E+02, -.43150500E+02, 0.24929000E+02, -.28638200E+01, 0.88679200E+02, -.45533600E+02, -.31813100E+02, -.55592300E+02, 0.25500200E+02, -.47043200E+02, 0.15748400E+02, 0.56294500E+02, 0.92580500E+01, -.14727000E+02, -.50331000E+02, -.62995500E+02, -.19855400E+02, -.48113600E+02, -.11596800E+02, 0.66845800E+02, 0.13739100E+02, -.69653900E+01, 0.25257400E+02, -.15213100E+02, 0.66979600E+02, -.33327800E+02, 0.14680900E+01, 0.84224300E+00, -.29063800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.22199900E+01, 0.14042000E+00, 0.23689500E+01, 0.86391000E+00, -.33391300E+01, -.28475300E+00, 0.30276600E+01, 0.91224100E+00, -.24674400E+00, -.92592500E+00, -.94351500E+00, 0.14004500E+01, -.42604900E+00, 0.14703000E+01, 0.57310400E+00, -.56965600E+00, -.45665000E+00, -.28395500E-02, 0.53991600E+00, -.30540300E-01, 0.11256700E+01, 0.36485400E-01, -.25112200E-01, -.84155900E-01, -.43842200E+00, 0.23228300E+00, 0.21347000E+00, -.10176500E+00, -.61041100E+00, 0.34865600E+00, -.41445300E-01, 0.12572000E-02, -.54376700E+00, -.13669300E+00, 0.27115000E+00, -.63442200E-01, -.67396900E-02, 0.38413300E-01, 0.38117600E+00, -.97041500E-01, 0.72908600E+00, -.10534100E-01, -.58432900E+00, -.72533900E-01, 0.22686900E+00, -.38763800E+00, 0.24050700E+00, -.73067800E+00, -.10609000E+01, 0.50324900E+00, 0.16326600E+00, 0.92101800E-01, 0.14753600E+00, -.51463900E+00, 0.52430000E-01, 0.10278400E-01, 0.13718500E+00, -.13517100E-01, -.48634700E-01, -.21104100E-01, -.11419200E-01, 0.46374900E+00, -.33541700E+00, -.12596800E+01, 0.69331200E+00, 0.34099800E+00, 0.59198800E+00, -.44157900E-01, -.11663500E+00, 0.14747500E+00, -.26073900E+00, 0.28898600E+00, -.11158100E+00, 0.14176500E+00, -.45296900E+00, 0.29615200E+00, 0.24418700E+00, 0.68775600E+00, -.10014500E-01, 0.23735100E+00, 0.98761300E-01, -.47544500E+00, -.10076200E-01, -.53966400E-02, -.10668300E+00, -.36404900E+00, -.35550600E-01, 0.11773500E+00, -.72582000E-01, 0.35925400E+00, -.13419900E+00, 0.83947600E-01, -.95963600E-02, -.12428900E+00, 0.12273100E-01, 0.40604300E-01, 0.24213600E-01, -.11419100E+00, 0.27724400E-01, -.19589200E+00, 0.42189400E+00, -.10161400E-01, 0.11949900E+00, 0.20557700E+00, -.52286400E-01, 0.14896700E+00, 0.22770600E-01, 0.14801500E-01, -.15178800E-03, -.17707800E-01, 0.44664400E-01, 0.24444400E-01, 0.40614700E+00, -.11929000E+00, 0.20533400E+00, 0.59320700E+00, 0.80525300E-01, 0.22222200E+00, -.25273400E-01, -.14127900E-01, -.37519800E-01, -.22775900E+00, 0.37491900E-01, 0.39496400E+00, 0.87124200E-01, 0.19050300E+00, -.12953700E+00, -.87049500E-01, 0.45186800E+00, 0.58732100E-02, 0.51697800E-01, 0.82232100E-01, 0.38381400E-01, 0.23972400E+00, -.11112100E-01, 0.14141800E-01, 0.85600400E-01, -.14277300E+00, 0.20852000E-01, -.21670300E+00, 0.73379900E-01, 0.11675500E+01, 0.70526200E+00, -.14162700E+00, 0.17634100E+00, 0.51629500E-02, 0.59956300E-01, 0.10131800E+00, 0.78868800E-02, 0.13971000E-01, 0.71198300E-01, -.73899900E-01, -.18379700E+00, -.32101800E+00, 0.25031900E-01, 0.26926300E-01, 0.51197800E-01, 0.66280900E+00, -.10161200E+01, 0.20724600E+00, 0.12027400E+00, 0.47237100E+00, -.28990100E+00, 0.41759200E-01, -.58440700E+00, -.33678100E+00, -.11637900E+00, 0.11691000E+02, 0.35974100E+02, 0.12911300E+02, 0.88029600E+00, -.39055000E+02, 0.23453100E+02, 0.22808000E+02, 0.51469700E+01, 0.22059200E+02, 0.20713700E+02, 0.44125100E+02, 0.19637700E+02, 0.12072900E+02, -.26620500E+02, 0.43935400E+02, 0.14065500E+02, 0.11935200E+02, -.11797700E+02, 0.12072200E+02, 0.22763000E+02, 0.19330000E+02, -.11581200E+02, -.17629100E+02, 0.10344000E+02, 0.84812000E+01, 0.16328200E+02, 0.21265400E+02, -.80920100E+01, 0.56767000E+01, -.37509400E+02, 0.18076300E+02, -.17469300E+01, -.66748800E+01, 0.59095800E+01, 0.40001100E+01, 0.34934200E+01, 0.69881600E+01, 0.29836800E+01, -.33408400E+01, -.22236900E+01, 0.17186800E+01, -.20373200E+00, 0.41199300E+01, -.16174300E+01, -.59641200E+00, 0.18090700E+01, -.43439100E+01, 0.80653700E+01, -.30898000E+01, -.94899400E+00, 0.17654100E+01, -.66494100E+01, 0.88116800E+01, 0.35224500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17418200E+02, -.11154500E+01, 0.18423900E+02, 0.70234700E+01, -.19218800E+02, 0.56935300E+00, 0.29699200E+02, 0.74460100E+01, 0.32793100E+01, 0.33593300E+01, -.15463200E+02, 0.58748300E+01, -.76223800E+01, 0.86126600E+01, 0.39747500E+00, -.17451000E+01, -.23717100E+01, 0.35096200E+00, 0.26746000E+01, 0.14672900E+01, 0.86817400E+01, 0.38154900E+00, -.17514300E+01, 0.81206300E-02, -.46165300E+01, 0.20568800E+01, 0.29621300E+01, -.43805200E+00, -.16194000E+02, 0.56107100E+01, -.55766900E+00, 0.37680600E+01, -.40979400E+01, -.19742200E+00, 0.19709800E+01, -.42717800E+01, -.79993400E+00, -.44384400E-01, 0.63286200E+00, 0.51573600E+01, -.46120000E+01, 0.51965900E+00, 0.26759700E+01, 0.13327800E+01, -.87176100E+01, -.27990000E+01, 0.13524400E+01, 0.99095100E+00, 0.10705600E+02, 0.96892800E+00, -.16105900E+01, -.80969100E+00, 0.24384200E+01, 0.86056900E+00, 0.17257400E+01, -.44649500E+01, -.25103500E+00, -.16270200E+01, 0.19254400E+01, 0.24802800E+00, -.13700500E+00, 0.13673100E+01, 0.13709700E+01, -.60076900E+00, 0.12012500E+01, 0.21535200E+01, -.16927000E+01, -.63849600E+00, -.30589400E+01, -.38113000E+01, -.27256100E+01, 0.11727000E+01, 0.23534900E+01, 0.18990300E+01, -.36933300E+01, -.22977200E+01, -.22039800E+00, 0.69242800E+01, -.45790600E+00, 0.49063900E+01, -.10247900E+01, 0.10240800E+01, -.66440600E+00, -.13262500E+00, 0.51762800E+00, 0.66285700E+01, 0.15113100E+01, -.93121900E+00, 0.91620100E+00, -.58168300E+00, 0.36350800E+00, -.34234300E+01, -.85952700E+00, -.50715000E+01, 0.80634700E+00, -.11295800E+01, -.15681000E+01, -.21289900E+01, 0.12065900E+01, 0.55458600E+00, -.17356400E+01, -.66875100E+00, 0.60617200E+00, -.31099400E+00, -.40923400E+00, -.33614000E-01, -.65776800E+00, 0.17552200E+01, 0.66566000E+00, 0.53868500E-01, -.67732400E+00, -.35447600E+01, 0.24700200E+01, 0.44216500E+00, 0.22548200E+01, 0.34148500E+01, 0.11107300E+01, 0.15003700E+01, -.84196500E-01, -.11613500E+00, -.84087500E+00, -.10005800E+01, -.73306800E+00, 0.87239100E+00, 0.84314500E+00, -.36509700E+01, 0.55719200E+00, 0.52222600E+00, 0.13105300E+01, 0.12768700E+01, 0.42473000E+00, 0.25122200E+01, 0.91953300E+00, 0.84815300E+00, 0.13343700E+01, 0.21027100E+00, 0.16264500E+01, -.41370300E+00, -.17548900E+00, -.24336200E+01, 0.53313300E+00, 0.50524000E+01, 0.44248100E+01, -.40744800E+01, 0.26116200E+01, 0.73163900E-01, 0.23832900E+00, -.10375700E+01, -.67477200E+00, -.78834200E+00, 0.45376300E+00, -.60052400E+00, -.18639800E+00, 0.83133800E-01, 0.32522500E+00, 0.66927000E-01, -.33316200E+00, -.20257700E+01, 0.14964100E+01, -.43242200E+01, 0.40186100E+00, 0.34196300E+00, -.44506200E+00, 0.13453900E+00, 0.11429900E+01, 0.25478600E+01, -.10647600E+01, 0.24631200E+01, -.82706700E+02, 0.11935200E+03, 0.27084300E+02, -.11751400E+03, 0.17704100E+02, 0.43473500E+02, -.19950000E+02, -.42166900E+01, 0.81324000E+02, 0.80968400E+01, 0.15950300E+03, 0.90937300E+02, -.17030800E+02, -.88445600E+02, 0.63950700E+01, 0.96840000E+02, 0.10658000E+03, 0.15835700E+02, 0.24262400E+02, -.42985300E+02, 0.11416700E+03, 0.65838800E+02, -.63710100E+02, -.27572800E+02, -.58362700E+02, -.88642800E+02, 0.30508500E+02, -.51545000E+02, 0.23648200E+03, -.91448700E+02, -.25926500E+02, -.37430800E+02, 0.23702600E+02, -.26289000E+02, 0.16210200E+02, 0.36080700E+02, 0.73115700E+01, -.20354500E+02, 0.37980500E+02, 0.34166100E+02, -.21914100E+02, -.28509600E+02, -.30704300E+01, 0.95456900E+02, 0.15907300E+02, -.11925900E+02, -.15665800E+02, -.14179400E+02, 0.96342000E+02, -.18038200E+02, 0.16909000E+01, -.33629200E+02, -.51486700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36107500E+01, 0.45166700E-01, 0.55977600E+01, 0.22257200E+01, -.86066700E+01, -.40491100E+00, 0.85068600E+01, 0.59271200E+01, 0.15167200E+00, -.14455300E+01, -.18934500E+01, 0.16143900E+01, -.14469400E+01, 0.25337200E+01, 0.13503800E+01, -.15651300E+01, -.11362600E+01, 0.81353400E-01, 0.23499600E+00, -.11385400E+01, 0.41032500E+00, 0.14395100E+00, 0.20844000E+00, -.34945300E+00, -.32507200E+00, 0.33745400E+00, -.21324100E-02, -.79216000E-01, -.26212300E+01, 0.11910400E+01, -.22907300E+00, 0.12899100E+01, -.84374000E+00, -.22945100E+00, 0.68782200E+00, -.21307700E+00, 0.53551100E-01, 0.43060700E+00, -.69174100E+00, 0.95829300E+00, 0.12512300E+01, 0.13715400E+00, -.13720000E+01, -.55383600E+00, -.36396000E+00, -.96004700E+00, 0.49055500E+00, -.10642000E+01, -.34504000E+00, 0.16246100E+01, 0.14688500E+00, 0.30483400E+00, -.78534600E-01, -.73990700E+00, 0.26452600E+00, -.62813600E+00, 0.13638200E+00, -.19656100E+00, 0.10071600E+00, 0.93811500E-01, 0.12198300E+00, 0.84527500E+00, -.32714700E+00, -.21968700E+01, 0.90880900E+00, 0.55105400E+00, 0.73788000E+00, -.66936300E-01, -.15632100E+00, 0.53840500E-01, -.42951400E+00, 0.27102700E+00, -.24319200E-01, 0.24330100E+00, -.71503200E+00, 0.32714000E-01, 0.10828400E+00, 0.13147700E+01, -.84795600E-01, 0.10936500E+01, 0.21746600E+00, -.44650000E+00, -.24694100E-01, 0.59149900E-02, 0.20877000E+00, -.10400100E+00, 0.31096900E-01, -.10653800E+00, -.14980700E+00, 0.12262500E+01, -.86540400E-01, -.23391800E+00, 0.29019600E-01, -.19527500E+00, -.24457200E+00, 0.31923600E-01, 0.80639200E-01, 0.15518500E-01, -.13761000E-01, -.91823900E+00, 0.56595400E+00, 0.94300300E+00, 0.36908700E-01, 0.19422000E+00, 0.63875500E-01, -.11215200E+00, 0.62426700E-01, -.12425700E+00, 0.12364900E-01, -.14145800E-01, -.45934300E-01, -.44913500E+00, 0.57310700E+00, 0.15694900E+00, 0.32202200E+00, 0.43541100E-01, -.40131900E-01, -.21174700E+00, -.51712900E-02, 0.31250300E-01, 0.34529900E-02, 0.20798900E+00, 0.13920900E+00, 0.37169400E+00, -.45779900E-01, 0.29412900E+00, 0.43766000E+00, -.10334400E+00, -.10767500E-01, 0.57706600E+00, 0.40499700E-01, 0.45460400E-01, -.32529300E-01, 0.13390700E+00, 0.20870900E+00, 0.35345400E+00, 0.23280800E-01, -.13332700E+00, -.25453800E+00, 0.22142500E+00, -.50435200E-01, -.71212200E+00, -.22408800E+00, 0.48846900E-02, -.44427000E+00, -.13320400E-01, -.23823700E+00, -.16851700E-01, 0.32326000E+00, 0.29779900E+00, -.45673500E+00, 0.17276900E+00, 0.42609200E+00, 0.42759900E+00, -.10525300E+00, 0.66583800E-01, -.17823300E+00, -.64486100E+00, 0.61489400E+00, -.18751200E+01, 0.71518100E+00, -.13666500E+01, -.56863500E+00, 0.67666600E-01, -.12326700E+01, 0.74176000E+00, -.53315800E+00, 0.15022800E+01, -.74117300E-01, 0.51576200E+02, 0.21972400E+01, -.63091000E+02, 0.16222500E+02, 0.31118800E+02, -.21636400E+02, -.68317600E+01, 0.11551600E+02, -.29974800E+01, 0.27557600E+02, 0.54477600E+02, 0.36295100E+01, 0.11040100E+02, -.17426900E+01, 0.41209400E+02, 0.20513400E+02, -.80667600E+00, -.19208300E+02, -.13128100E+02, 0.34000400E+02, -.18680800E+01, -.87554000E+01, 0.85191600E+01, -.30674000E+02, -.32577400E+02, 0.19367200E+02, -.68564600E+02, 0.88223200E+02, -.30921300E+02, -.13119500E+02, -.12114900E+02, 0.49946500E+01, -.69292100E+01, 0.73306700E+01, 0.11727000E+02, -.55643100E+00, -.89958600E+01, 0.95883900E+01, 0.57550400E+01, -.85436800E+01, -.93812900E+01, -.19079300E+01, 0.35250800E+02, 0.67272300E+01, 0.51481800E+00, -.66118800E+01, -.68643900E+01, 0.35966800E+02, -.49310700E+01, 0.91269100E+01, -.17003300E+02, -.29310900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21489200E+01, 0.30941900E+00, -.16417500E+01, -.11001100E+01, 0.97522000E+01, -.75487400E-01, -.10722400E+02, -.59900600E+01, 0.77789300E+00, 0.92025800E+00, 0.30774300E+01, -.18420500E+01, 0.25639300E+01, -.23804300E+01, -.11858700E+01, 0.15618900E+01, 0.52996000E+00, 0.13542300E+00, -.13715000E+01, 0.20840800E+01, -.43344200E+01, -.65389200E+00, -.17213700E-01, 0.73871700E+00, -.45071600E+00, -.10997300E+01, -.37809200E+00, 0.23891600E+00, -.29246000E+00, -.17071900E+01, 0.67332900E+00, -.36720500E+00, -.23754000E+00, 0.66051700E-02, 0.62411700E+00, -.22804200E+01, -.52455100E+00, -.16972100E+00, 0.31864200E+01, -.11493500E-01, 0.19240600E+01, 0.18928700E+00, 0.90941800E+00, -.56659400E+00, -.13666300E+01, 0.11040100E+01, -.11028600E+00, -.22469300E+00, -.25932700E+01, -.32817600E+01, 0.21620700E+00, -.69106600E+00, 0.24276600E+01, -.23846300E+01, -.30012400E+00, 0.43607900E+00, -.24249800E+00, 0.18930100E+00, -.27106200E+00, 0.66101100E+00, -.16629900E+00, 0.68996500E+00, -.48838500E+00, -.98302700E+00, 0.45897000E+00, -.15416100E+00, -.19721600E+00, -.31039200E+00, -.74901200E+00, 0.64001700E+00, 0.84493800E+00, 0.28203400E+00, 0.14880500E+00, 0.23797100E-01, 0.70224200E-01, -.55818200E+00, 0.18690700E+00, 0.36226900E+00, -.44477300E+00, -.61119400E+00, -.18797000E+00, -.61731400E+00, -.18766400E+00, 0.11806600E+00, -.16593700E+00, 0.22889600E+01, 0.55008600E+00, 0.10214700E-01, -.90189400E-01, 0.94258600E+00, -.80197800E+00, 0.19221800E+00, -.39711900E+00, 0.12651100E+00, 0.26673800E+00, -.34366300E+00, 0.20983300E+00, -.20010400E+00, 0.24402200E+00, 0.44639300E+00, 0.56441500E-01, -.94345000E+00, 0.16870500E+00, 0.67488600E+00, -.30583600E+00, 0.59784200E+00, 0.17387400E-01, -.18705400E+00, 0.38773300E-01, -.44882600E-01, 0.31468900E-01, -.13426600E+01, 0.38121100E+00, -.55995200E+00, 0.99757900E-01, 0.26945700E-01, 0.13653400E+00, 0.20835200E+00, -.11307500E-01, 0.31100400E-01, 0.11330800E+00, 0.29502100E+00, 0.13424400E+00, 0.41037300E+00, 0.14170800E+00, -.47396200E+00, 0.23262800E+00, -.82654900E-01, 0.79406700E+00, 0.43039900E+00, -.31796400E+00, 0.41294300E+00, 0.64563500E+00, 0.22795600E+00, 0.37172800E+00, 0.10962300E+00, 0.19458600E-01, 0.50186300E-02, -.14914400E+00, -.18130000E+00, -.55824500E-01, 0.29190400E+01, 0.18081800E+01, -.21418400E+01, 0.34205400E+00, -.20583500E-01, 0.36974300E-02, -.20107600E+00, -.49443700E+00, 0.67937100E+00, -.43519100E-01, 0.32223600E+00, -.92521700E-01, -.19681600E+00, -.18580000E+00, 0.20418600E+00, -.31673600E-01, -.94488200E+00, 0.13399800E+01, 0.29054100E+00, -.54798700E+00, 0.10477300E+01, 0.66145900E-02, -.18701400E+00, -.14961200E+01, -.15381200E+01, 0.65297300E-01, 0.88577900E-01, -.10385500E+00, 0.48996800E-01, 0.18440800E+02, 0.18691300E+02, -.74001400E+01, -.70304800E+01, 0.22305600E+02, 0.17351300E+02, 0.42021000E+01, 0.42495800E+02, -.75841400E+00, 0.18223600E+02, -.78684900E+02, 0.46675300E+02, 0.39287800E+02, -.10073600E+02, -.27233300E+01, 0.22892900E+02, 0.10681100E+02, 0.36303700E+02, 0.12951900E+02, -.43687600E+02, 0.25720300E+02, 0.22199100E+02, 0.17863900E+02, 0.22678500E+02, -.13082100E+01, 0.11719000E+02, -.44256000E+02, 0.21311400E+02, -.90620500E-01, -.68728200E+01, 0.90113200E+01, -.99170300E+00, 0.26496200E+01, 0.70409900E+01, 0.11105900E+01, -.27005700E+01, -.31719900E+02, -.29205500E+02, 0.24791800E+01, -.89369300E+00, -.80596800E+00, 0.14954700E+02, 0.95265000E+00, -.50635500E+00, -.40120300E+01, -.40268300E+01, 0.14751900E+02, -.34596000E+01, -.71307300E+01, -.53871500E+01, 0.32635800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.27091600E+01, -.13427700E+01, 0.19344000E+01, 0.13821200E+01, -.14065800E+02, 0.11512400E+00, 0.13609100E+02, 0.76303000E+01, 0.36509100E+00, -.98229200E+00, -.44849200E+01, 0.21970300E+01, -.31942100E+01, 0.32598300E+01, 0.14312700E+01, -.17739400E+01, 0.21603900E+00, 0.97871300E+00, 0.26091300E+01, -.18229600E+01, 0.51287000E+01, 0.63651700E+00, 0.16811000E+00, -.67730100E-01, -.29744600E+00, 0.17231300E+01, -.17081100E+00, 0.22910100E+00, -.16921200E+01, 0.20431000E+01, -.18240600E+00, 0.93665400E+00, -.40504400E+00, -.10138200E+01, -.48207600E-01, -.35023000E+00, 0.60610900E-01, 0.41575900E+00, -.30571900E+01, -.82001900E-01, -.16643400E+01, -.26316800E-02, 0.27208200E+00, 0.41638000E+00, 0.79378000E+00, -.19260100E+00, 0.12698100E+00, 0.59161900E+00, 0.12001900E+01, 0.13301100E+01, -.35945800E-02, 0.32737000E+00, -.40516100E+00, 0.13688000E+01, -.69957200E-01, -.21382700E+00, 0.29837900E+00, -.24929200E+00, 0.53951200E-01, 0.35390100E+00, 0.46494400E+00, -.12738200E+01, 0.29174200E+00, 0.69607900E+00, -.37513500E+00, 0.36640100E-01, -.10067300E+01, 0.23007300E+00, 0.16290300E+01, 0.17171400E+00, -.71642400E+00, -.34007100E+00, -.87928000E+00, 0.36346000E+00, -.18059100E+00, -.67909600E+00, 0.89886600E-01, 0.29330500E-01, -.11576800E+00, 0.53947500E+00, -.31181800E+00, 0.28230500E-01, -.99792300E-02, -.55177800E-01, 0.40261300E+00, -.44649600E+00, -.50868200E+00, 0.14417500E+00, -.24370700E+01, -.15787600E+01, -.49479300E+00, 0.86092700E-01, 0.37999600E+00, -.11770900E+01, -.91229200E+00, 0.43415400E-01, 0.70041500E+00, 0.15281600E+00, 0.10669900E+00, 0.14091000E+00, 0.83094100E+00, -.11407400E+01, -.31186200E+00, 0.24146300E+00, -.40620900E+00, 0.19742200E+00, 0.13077800E+00, -.40419500E+00, -.35082100E-02, -.51015600E-01, -.18841900E+00, -.37167000E+00, 0.27564400E+00, -.82121900E-01, 0.15250600E+00, 0.42027300E+00, 0.39735400E+00, 0.34135400E+00, -.37464600E+00, 0.76153600E-01, 0.14673400E+00, -.25154400E+00, -.54945200E+00, 0.25378400E+00, 0.23646600E-01, 0.38306200E+00, 0.49320500E+00, -.71593200E-01, -.21930700E+00, 0.16424000E+00, 0.60957400E-01, 0.81236300E-01, -.74846600E+00, -.29213400E-01, -.32230400E+00, 0.10406800E+00, 0.13208100E+00, -.48535700E+00, 0.12781000E-01, -.75514400E+00, 0.63552900E-01, 0.85859000E+00, -.15700700E+00, -.13181100E+01, -.17657000E+00, 0.38547500E-01, -.22230500E-01, -.57301600E+00, 0.34980400E+00, 0.14508700E+01, 0.17757800E+00, -.67874600E-01, 0.23872500E+00, 0.54878300E+00, 0.52300700E-01, 0.39283500E-02, 0.21056700E+00, 0.72203400E+00, -.36748600E+00, -.31154500E+00, 0.46955900E+00, -.14972500E+00, -.47417000E+00, 0.18732800E-01, -.14486400E+00, -.20820400E+01, -.22680200E+00, 0.10429900E+01, -.14792700E+00, 0.20447100E+00, -.11199600E+00, 0.11330200E+03, -.51281000E+02, -.53663900E+02, 0.12254700E+02, 0.22409900E+01, -.44042300E+02, -.29037700E+02, -.48152400E+02, -.34178000E+02, 0.67565400E+02, -.46774900E+02, -.34183200E+02, -.89002200E+01, -.19697900E+02, -.35238200E+02, -.31703100E+02, -.34865600E+02, -.34259800E+02, 0.45455800E+02, -.18824300E+02, -.24605700E+02, 0.79222900E+01, 0.84009400E+01, -.18291200E+02, 0.61878200E+02, -.37287400E+02, 0.43259700E+01, 0.30055600E+01, 0.10515800E+02, -.13198800E+02, 0.52348200E+01, -.16995300E+01, -.10198300E+02, 0.55930400E+01, 0.24570500E+01, -.26685200E+02, -.29989200E+02, -.57711100E-01, 0.60552000E+01, -.34150600E+01, -.32517800E+02, -.24581800E+01, 0.30890600E+00, 0.32593300E+01, 0.34922900E+01, -.32716400E+02, 0.40272700E+01, 0.24595100E+01, 0.92717900E+01, 0.15933900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.86862200E+01, 0.15781000E+01, -.90250600E+01, -.33731100E+01, 0.66652100E+01, -.34333400E+00, -.13326300E+02, -.25984200E+01, -.18624900E+01, -.15631800E+01, 0.52012900E+01, -.26586100E+01, 0.36065000E+01, -.38231700E+01, 0.50598800E-01, 0.35472000E+00, 0.14439900E+01, -.38605800E+00, -.19242400E+01, -.20200000E+01, -.61424000E+01, 0.14250800E+00, 0.70796700E+00, -.25634200E+00, 0.21918600E+01, -.11701100E+01, -.16961200E+01, 0.81065500E+00, 0.47425200E+01, -.24620100E+01, 0.95707700E+00, -.40560700E-01, 0.13411200E+01, -.45304100E+00, -.10889800E+01, 0.21203600E+01, 0.45204600E+00, 0.12604400E+01, -.10563600E+01, -.20257100E+01, 0.22660300E+01, -.15556400E+00, -.18180800E+01, -.97204000E+00, 0.41218700E+01, 0.64103200E+00, -.11248500E+01, -.29610600E-01, -.26423900E+01, -.22112400E+01, 0.66221800E+00, 0.50395000E+00, -.14231100E+01, -.18467200E+00, -.42249300E+00, 0.10132900E+01, -.87122000E-01, 0.73533800E+00, -.43271700E+00, -.44014600E+00, -.86874300E-01, -.13684200E+01, 0.42292000E+00, 0.17946900E+01, -.11084300E+01, -.12747600E+01, -.21957300E-02, 0.40517400E+00, 0.18765600E+01, 0.19073300E+01, 0.12905300E+01, -.82434700E+00, -.16664000E+01, -.10011700E+01, 0.19937700E+01, 0.78175600E+00, -.12168300E+00, -.41390100E+01, 0.29520400E+00, -.30529900E+01, 0.68096600E+00, -.42686100E+00, 0.40176700E+00, 0.17424000E-01, -.43501400E+00, -.30660200E+01, -.78309000E+00, 0.41155700E+00, -.36922900E+00, 0.47339400E-01, -.23892000E+00, 0.23418100E+01, 0.28142000E+00, 0.28579500E+01, -.24793800E+00, 0.73159000E+00, 0.74861900E+00, 0.12046300E+01, -.72514400E+00, 0.31329200E+00, 0.57023900E+00, 0.25376400E+00, -.59499100E-01, -.34382700E+00, 0.20809600E+00, -.13418000E+00, 0.25574900E+00, -.47389100E+00, -.64498700E-01, -.11806700E+00, 0.65177300E-01, 0.15111200E+01, -.22339600E+01, -.18902100E+00, -.13013300E+01, -.16969500E+01, -.17521400E+00, -.38199700E+00, 0.28045900E+00, -.14533700E-01, 0.39341600E+00, 0.10171300E+01, 0.42411600E+00, -.50676100E+00, -.54054700E+00, 0.13817800E+01, -.85668300E-02, 0.89944400E-01, -.15087200E+01, -.85051600E+00, 0.31262600E+00, -.16192400E+01, -.49556700E+00, -.99913000E+00, -.36669300E+00, 0.11616900E+00, -.86069500E+00, 0.18731500E+00, 0.62250400E-01, 0.16697800E+01, -.20466500E+00, -.23531400E+01, -.21249500E+01, 0.27980900E+01, -.16630100E+01, -.19075500E+00, -.11231100E+00, 0.59801900E+00, 0.35231700E+00, 0.49483300E+00, -.23476300E+00, 0.57746700E+00, -.23631100E+00, -.31745300E+00, -.22238100E+00, -.73695700E-01, 0.31898000E+00, 0.13430900E+01, -.15293200E+01, 0.39325000E+01, -.68766900E+00, 0.32669600E+00, 0.23879900E+00, 0.20004800E+00, -.12198600E+01, -.52232100E+00, 0.81665500E+00, -.10395200E+01, -.44628300E+00, -.66364500E-02, -.88394000E-01, -.39560200E+00, 0.72909600E+02, -.15892300E+01, 0.50665900E+01, 0.16573200E+02, 0.65029100E+01, 0.25495500E+01, -.81290600E+01, 0.82091300E+01, -.92767700E+01, -.45200100E+02, 0.38848600E+01, -.95023300E+01, -.45376400E+01, 0.12855800E+01, 0.69719800E+00, 0.64804100E+01, -.67430200E+01, 0.15407400E+02, 0.22149100E+01, -.84119700E+01, 0.18555300E+01, 0.26887000E+01, -.69471500E+01, 0.20737100E+02, -.21653500E+02, 0.98762600E+00, 0.34074700E+01, 0.35511000E+01, 0.20639800E+01, 0.14557000E+01, 0.13167200E+01, -.30707200E+01, -.19561200E+01, -.12717200E+01, -.20132500E+01, -.78214000E+00, 0.26385200E+01, 0.15565700E+01, 0.10000100E+01, -.72456900E+01, -.87612300E+00, 0.27482600E+01, 0.14594100E+01, 0.49553700E+00, -.72263900E+01, 0.12242400E+01, -.75101200E+01, 0.25849700E+01, 0.53580700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10610300E+01, -.33694500E+00, -.46755800E-01, 0.13308300E+01, -.16742000E+02, 0.13586800E+01, 0.79600900E+01, 0.43368700E+01, 0.12274800E+01, -.28412800E+01, -.30239200E+01, 0.26953900E+01, -.26915900E+01, 0.17436100E+01, 0.30981000E+00, -.24069600E+01, 0.79511500E-01, 0.96425400E-01, 0.24029700E+01, 0.14420500E+01, 0.34050800E+01, -.58059400E+00, 0.73913300E+00, 0.28098600E+00, 0.11557000E+01, 0.72034600E+00, -.14270700E+01, -.16767900E+00, 0.84855500E+00, 0.13911600E+01, -.49824400E+00, -.90078000E+00, 0.55477000E+00, 0.25306200E+00, 0.80789700E+00, -.77715000E+00, -.12083900E+00, -.43614100E+00, 0.14271400E+01, -.19570400E+00, -.63328800E-01, -.25198400E+00, 0.23544600E+01, 0.58951900E+00, -.13886200E+01, -.55843600E+00, -.20789400E+00, 0.20848100E+00, 0.18301300E+01, -.15758800E+01, -.31926700E+00, -.18867200E+00, 0.28011300E+00, -.17649100E+01, 0.29836300E+00, -.21415400E+01, 0.15023700E+00, -.35317900E-02, 0.34177100E+00, 0.60910800E+00, -.60241000E+00, 0.55780900E+00, -.12521800E+01, -.22697200E+01, -.81403700E+00, -.36712800E+00, -.27610300E+00, -.12751600E+00, -.19472400E+00, -.11125900E+00, 0.35682800E+00, -.22093200E+00, 0.15760300E+00, 0.11613700E+00, -.84383100E+00, 0.53893700E+00, 0.22979800E+00, 0.16637800E+01, -.13326400E+00, 0.56845200E+00, 0.28562900E+00, -.22801000E+00, -.20619900E+00, 0.12544500E-01, -.57336300E+00, 0.41798300E+01, 0.67465200E+00, -.89461500E+00, 0.19570200E+01, 0.63165300E+00, 0.60157200E-01, -.57430800E+00, -.50447600E+00, 0.27886300E+01, 0.40354700E+00, -.22910200E+00, 0.70300400E-02, -.33003900E+00, -.38690500E-01, -.12468900E+01, 0.90774400E+00, 0.90554000E+00, 0.66193500E-01, 0.18666400E+00, 0.19722700E+00, -.57988300E-01, 0.90070800E-01, 0.30833400E+00, 0.17112000E+00, 0.26091700E-02, -.11693500E+00, -.58504400E+00, 0.15845800E+01, 0.62801000E+00, 0.38232300E+00, -.86175700E+00, -.47790900E+00, -.68080000E+00, 0.11793400E+00, 0.33238600E-01, 0.24352100E-01, -.38209400E+00, 0.30685500E+00, -.53094300E-01, 0.48827100E+00, 0.98882100E-01, -.33076400E+00, -.37220800E+00, 0.34298700E+00, 0.72255900E-01, -.46407300E+00, 0.12124000E+00, -.61881900E-01, 0.93365000E-01, -.31006600E+00, -.81053000E-01, 0.66992300E-01, -.34739600E+00, -.56574700E-02, -.40830700E-01, 0.11091000E+00, 0.61848200E+00, -.15618700E+00, 0.30993400E+00, 0.57269300E-01, -.33211700E-01, 0.16378500E+00, 0.38902400E+00, -.27918000E+00, -.18424300E+00, 0.26337000E-01, 0.34067900E+00, -.15546400E+00, -.42084000E+00, -.20038900E+00, -.49923000E-01, -.33421200E+00, -.38095200E+00, 0.37075300E-01, 0.45320000E+00, -.43311500E+00, -.95470500E+00, 0.34012900E+00, 0.24841700E-01, 0.50067900E+00, 0.95941300E+00, 0.18361800E+00, 0.62655900E+00, -.18238900E+00, 0.55983400E+00, -.45696100E+00, -.64775000E+00, -.15699400E+00, -.96552100E+01, -.18230000E+02, -.13245500E+02, 0.54970000E+01, -.57024000E+02, 0.22590200E+02, -.14813000E+02, 0.38398800E+02, -.69011200E+02, -.20921200E+02, -.28447000E+02, 0.33296400E+02, -.15303900E+02, -.27030200E+02, -.22258000E+02, 0.14531500E+02, 0.48362200E+02, -.29024500E+02, -.26858200E+02, -.18338200E+02, -.21559900E+02, -.48903100E+00, -.26717700E+02, 0.39769400E+02, -.14962000E+02, 0.85589100E+00, -.14857200E+01, -.18943000E+01, -.37106400E+01, -.88591000E+00, 0.12909200E+01, 0.87467000E+00, 0.13731100E+01, -.37038600E+01, -.42726400E+01, -.29546000E+01, -.23602700E+01, -.36541000E+00, 0.12015500E+02, -.45065600E+00, -.14970200E+01, -.12605500E+01, 0.21848500E+01, 0.12517000E+02, -.10401600E+01, 0.28764000E+01, -.56602700E+01, -.64593100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.17791600E+01, 0.29814300E+00, -.14891600E+01, -.10055900E+01, 0.10311400E+02, 0.16315800E-01, -.98580800E+01, -.58890900E+01, -.38411700E+00, 0.11107400E+01, 0.29342200E+01, -.18555100E+01, 0.24603500E+01, -.22807500E+01, -.11406300E+01, 0.17096300E+01, 0.66765900E+00, -.11628300E-01, -.14385800E+01, 0.15029600E+01, -.42221300E+01, -.31276200E+00, -.19458000E+00, 0.40060400E+00, -.16368000E+00, -.10447200E+01, 0.12586800E+01, 0.11527100E+00, 0.73214300E+00, -.16874100E+01, 0.51921100E+00, -.72016700E+00, -.31989500E+00, -.96759800E-01, -.66464900E-01, -.81314800E+00, -.46714200E+00, 0.21680800E+00, 0.23197200E+01, -.83050100E+00, 0.15457400E+01, 0.15756100E+00, 0.11719600E+00, -.57296000E+00, -.65532500E+00, 0.13072100E+01, -.35779200E+00, 0.36598700E+00, -.24271800E+01, -.23916400E+01, 0.16508000E+00, -.59326400E+00, 0.18985200E+01, -.13608200E+01, -.31344600E+00, 0.67592700E+00, -.11480500E+00, 0.14104000E+00, -.33161600E+00, 0.10424600E+01, 0.45648600E-01, -.66879000E+00, 0.29047700E+00, 0.12679000E+01, -.70312100E-01, -.25826500E+00, -.64928400E+00, 0.21081200E+00, 0.62372800E+00, 0.32819200E+00, 0.30507200E+00, -.11780800E+00, -.27944600E+00, -.27200400E+00, 0.73353100E+00, -.10501700E+01, -.56128300E-02, -.23150700E+00, -.17148100E-01, -.20153100E+01, -.27262400E+00, 0.47756900E+00, -.99683800E-02, 0.21377300E+00, -.38570700E+00, -.65776700E+00, 0.32547800E+00, 0.67241500E+00, 0.49681200E-01, 0.70094800E+00, 0.25444900E-01, 0.39753800E+00, 0.51549600E-01, -.56352000E+00, -.11966300E-01, 0.25993400E+00, -.10671700E-01, -.97166000E-01, 0.66902700E-01, 0.68567800E+00, 0.31557700E-02, -.71693900E+00, -.28934500E-01, -.19213100E+00, -.19645900E+00, 0.15565200E+00, -.66714000E-01, 0.60156100E+00, -.43595500E-01, -.21898600E-01, 0.14458700E+00, -.30295600E+01, 0.50809900E+00, -.71634600E-01, 0.21099600E+00, -.97654100E+00, -.32205100E+00, -.30298900E+00, 0.13652000E-01, 0.78869400E-01, 0.14412800E+00, 0.26062000E+00, 0.30494400E-01, -.25424000E+00, -.91028800E-01, 0.34516600E+00, 0.15333400E+00, 0.26771700E-01, -.64587500E-01, 0.29997000E+00, -.13036500E+00, 0.28783700E+00, 0.62577200E+00, 0.61270900E+00, 0.60604200E+00, -.80450000E-01, 0.28781100E-01, 0.23128800E+00, -.14704900E+00, -.52473700E+00, 0.55720600E-01, -.21093500E+00, 0.61985800E+00, -.18143400E+01, 0.42752000E+00, -.52022900E-01, -.70187100E-01, -.41346000E+00, -.41646300E+00, -.94375500E+00, -.95629400E-01, 0.38623900E+00, 0.23165700E+00, 0.11376400E+01, -.10026900E+00, 0.62160700E-01, -.23478200E+00, -.15281300E+00, 0.80114100E+00, -.43796900E+00, 0.43074100E-02, -.86336800E+00, -.30777900E+00, 0.34955300E-02, 0.10949400E+00, -.18176100E+01, 0.12835300E+00, -.37855300E+00, -.16057400E+00, -.14945600E+00, 0.39339000E+00, 0.20547300E+00, 0.39818000E-01, -.12451100E+00, -.31567400E+02, -.12585900E+02, 0.54144500E+01, -.24747500E+02, 0.14959500E+02, 0.41213700E+01, 0.56441100E+02, -.23927600E+02, -.27928300E+02, -.13112700E+02, 0.58382000E+01, -.20745900E+02, -.27033000E+02, -.20258500E+02, -.22800800E+01, -.20206200E+02, 0.78338300E+01, 0.99750900E+01, 0.84769500E+01, 0.16733200E+02, -.41248100E+01, -.42307100E+02, -.10746100E+01, 0.22191000E+02, 0.65096900E+00, 0.14287400E+01, -.30698900E+01, -.14424100E+01, 0.12383700E+01, -.14817900E+01, 0.99330500E+00, -.15896800E+01, -.10704400E+02, -.88584200E+01, -.67394900E+00, -.16644100E+01, -.10583700E+01, -.12131800E+01, 0.28502200E+00, -.15407100E+01, -.46962800E+00, 0.29796100E+00, -.12139500E+01, -.93549300E+00, 0.18701800E+01, -.87610300E+00, -.44936700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10115800E+02, -.56160600E+00, 0.15708600E+02, 0.69708600E+01, -.28333900E+02, -.50763600E+00, 0.27971600E+02, 0.19299400E+02, 0.87035500E+00, -.43050600E+01, -.70476800E+01, 0.42941100E+01, -.53953300E+01, 0.57976500E+01, 0.50191300E+01, -.56625900E+01, -.76199600E-01, 0.11353600E+01, 0.31124500E+01, -.23483700E+01, 0.11589800E+02, 0.11113300E+01, -.70503600E+00, -.90666200E+00, -.97510200E+00, 0.32196600E+01, -.20524500E+01, 0.64253200E-02, -.69975800E+01, 0.79105900E+01, -.17599600E+01, 0.20557900E+01, -.10150600E+01, -.93424400E+00, 0.30270300E+01, 0.15509800E+01, 0.39681900E+00, 0.16241000E+00, -.89093500E+01, 0.21296200E+01, -.85234500E-02, -.14952800E+00, -.53812900E+01, 0.86201100E-01, 0.33405300E+01, -.14075700E+01, 0.73208400E+00, -.13879800E+01, -.37122200E+01, 0.10299400E+02, 0.64507800E+00, 0.19692000E+01, -.37870100E+01, -.86139500E+00, -.42906400E+00, -.12416600E+01, 0.23834500E+00, -.67535800E+00, 0.10305900E+00, 0.85923300E+00, 0.10784600E+01, 0.32849500E+01, -.27923100E+00, -.98323600E+01, 0.25335900E+01, 0.14942500E+01, 0.25417800E+01, 0.14955300E+00, 0.66393300E+00, -.14424600E+01, -.26033600E+01, 0.36114300E+00, -.10843000E+01, 0.88417100E+00, -.20279900E+01, -.20654400E+00, -.70326200E+00, 0.96182700E+00, 0.54945000E+00, 0.70883400E+01, 0.17425000E+01, -.36265300E+01, -.17627700E+00, -.75133500E+00, 0.39136100E+01, 0.46482500E+01, -.16710800E+01, -.30693100E+01, -.64100200E+01, 0.37423500E+00, -.20777300E+01, -.15554900E+01, 0.57826500E+00, -.66295000E+01, -.10998300E+01, -.10414400E+01, -.10054300E+01, -.22224200E+00, 0.64942000E+00, -.63228500E+00, 0.15877300E+01, -.27578700E+01, 0.63095600E+00, -.20881900E+01, -.74873800E+00, 0.76304100E+00, -.39612900E-01, -.12744400E+01, -.58416200E-01, -.16842500E+00, 0.42167300E+00, 0.33233100E+01, 0.37008500E+00, -.38045800E+00, 0.80277700E+00, 0.12480100E+01, 0.56619000E+00, 0.36660800E+00, -.54292000E+00, -.34704800E-01, 0.27317100E+00, -.22062300E+00, -.40265400E+00, 0.17902900E+01, 0.28323400E+00, -.10274000E+01, 0.20870700E+01, -.46351900E+00, 0.43323100E+01, 0.35443100E+01, 0.11994400E+01, 0.29117600E+01, 0.58622900E+00, 0.26657500E+01, 0.28710500E+01, 0.71804500E+00, 0.94106500E-01, 0.54583600E+00, -.91747600E+00, -.13714100E+01, 0.11533500E+01, 0.74826800E+01, 0.60119800E+01, -.30405200E+01, 0.99217100E+00, -.22708000E-01, -.17051800E-01, 0.79535200E+00, -.11147100E+00, -.19503300E+01, -.14425200E+01, -.26295900E+01, -.40342000E+00, -.27561100E+01, 0.10867700E+01, -.40216000E+00, -.25023600E+00, 0.41241500E+01, -.48139500E+01, -.52063000E+01, 0.25792700E+01, -.34195500E+01, -.10815700E+01, 0.24491900E+00, 0.44620300E+01, -.51733900E+01, -.10339800E+01, -.32448100E+00, -.32618500E+00, 0.41277100E+00, -.19385600E+00, 0.21517300E+01, 0.14628600E+00, -.53525000E+00, -.48078700E+00, -.66201300E+02, 0.28377000E+02, 0.91317100E+01, 0.85764100E+02, -.10841300E+03, 0.19831700E+03, -.11724600E+03, -.96967000E+02, -.91367900E+02, 0.85088800E+02, -.45013900E+02, 0.18497700E+02, -.75243700E+02, 0.12934500E+02, -.29727500E+03, 0.14928100E+03, 0.14881800E+03, 0.87920700E+02, 0.10191800E+03, 0.85251600E+01, -.12972300E+03, -.44314300E+02, 0.11511000E+03, 0.95312500E+01, -.14098600E+02, -.17307700E+02, -.56932200E+01, -.99136700E+00, 0.12579400E+02, 0.56090900E+01, 0.15776700E+00, 0.42585000E+02, 0.74389300E+02, 0.71312200E+01, -.37799300E+01, 0.38179900E+01, 0.82609200E+00, 0.49094800E+01, -.15136100E+02, 0.19104100E+02, -.29236000E+01, 0.17145800E+00, -.36959800E+01, 0.38661700E+01, 0.33218400E+02, -.12287000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.89816000E+01, 0.13629700E+01, -.10988400E+02, -.51542100E+01, 0.16760800E+02, -.69080000E+00, -.12311500E+02, -.50816500E+01, -.23154500E+00, -.18980600E+00, 0.10472700E+02, -.43792700E+01, 0.22034800E+01, -.98750300E+00, -.24279900E+01, 0.23753800E+01, -.70896400E+00, -.78614600E+00, 0.85900700E-01, -.95645900E+00, -.21847000E+01, -.15909000E+00, 0.14231900E+01, 0.14147300E+00, 0.48801700E+01, -.36762300E+00, -.50550400E+01, -.25995400E+00, 0.10014200E+02, -.22716500E+01, 0.27003400E+00, -.18900600E+01, 0.24170300E+01, 0.76385700E+00, -.45237900E+00, 0.13072000E+01, 0.17238400E+01, -.66642000E+00, 0.57242000E+00, -.35545000E+01, 0.13166900E+01, -.24057400E+00, -.14534200E+01, 0.54837900E+00, 0.58862300E+01, 0.81486000E+00, -.43407000E+00, -.13755800E+01, -.61270700E+01, -.10643100E+01, 0.65678900E+00, -.50958200E+00, 0.22825900E+00, -.62684600E+00, -.17432200E+01, 0.27373600E+01, 0.89738600E+00, 0.16072100E+00, -.75484500E+00, 0.35902800E+00, -.31393100E+00, 0.20130200E+00, -.11904900E+01, -.16026600E+01, 0.10965200E+01, 0.24285400E+00, 0.85769500E+00, 0.45264900E+00, 0.15205600E+01, 0.46771200E+00, 0.92946600E-01, 0.29031700E+00, -.55915800E+00, -.78349900E-01, -.58392600E+00, 0.12666100E+01, 0.13441200E+01, 0.43168500E+01, 0.23488300E+00, -.29022500E+00, -.49072100E+00, 0.11235800E+01, 0.28537800E+00, 0.32022900E-01, -.13911600E+01, 0.38955800E+01, -.41044600E+00, -.21446400E+01, 0.55786600E+01, -.21743100E+00, 0.13716900E+01, 0.10854000E+01, 0.54342600E-01, 0.40129300E+01, -.46846500E+00, 0.12765800E+01, -.44155100E+00, 0.11180700E+01, -.86702100E+00, 0.12952100E+01, 0.14965200E+01, -.25957900E+01, 0.11862700E-01, -.10124600E+01, 0.21437500E+00, -.21591100E+00, 0.20497700E-01, -.61566400E+00, -.35433100E+00, -.12421300E-01, 0.28588800E+00, -.42695500E+01, 0.17523800E+01, -.17786500E+01, -.91719700E+00, 0.10356300E+01, -.10590100E+01, 0.90229000E+00, -.26773200E+00, -.23433400E+00, -.47339100E+00, -.36479600E+00, -.12255100E+00, 0.85268800E+00, 0.23487700E+00, -.10693900E+01, 0.14417500E+00, -.32111500E+00, -.10954000E+00, -.89201300E+00, 0.25615300E+00, 0.96245800E-01, 0.38724400E+00, 0.80090300E+00, -.86439400E-01, -.23580600E-01, -.14861600E+00, -.88458000E+00, 0.40438400E+00, -.10117700E+00, -.17543100E+00, -.98754100E+00, -.73754400E+00, -.19462600E+00, -.28849200E+00, -.92532900E-02, -.23840500E+00, 0.78936800E+00, -.10403400E-01, 0.24567800E+00, 0.12647800E+00, 0.13883300E+01, -.75724900E-02, -.72863700E+00, -.79154300E+00, 0.60072400E+00, -.65489100E+00, -.16755900E+01, 0.17724500E+01, 0.93419300E+00, -.15021500E+00, -.14598100E+01, -.72953100E+00, -.13228100E+00, -.17439600E+01, -.14999800E+01, -.59894000E+00, 0.15048500E+01, -.18302400E+00, 0.17689900E+00, -.89565500E-01, 0.13098700E+01, -.22729700E+00, 0.83426700E+00, -.47902600E+00, -.14215700E+00, 0.28723600E+02, 0.10571500E+03, 0.45895100E+02, 0.10423200E+03, -.16201900E+02, 0.72842100E+02, 0.94395300E+01, 0.37245100E+02, 0.11601600E+02, 0.49244700E+01, -.21840000E+02, 0.18619400E+02, 0.18375900E+02, -.28683500E+03, 0.14219500E+03, 0.15266500E+03, 0.25874700E+02, 0.43561900E+02, 0.67694900E+02, -.15187300E+03, 0.54164000E+02, 0.59058200E+02, -.16173900E+02, -.20435500E+02, 0.16942000E+02, -.13540400E+02, 0.94348600E+01, 0.20930500E+02, -.11640000E+02, -.11267300E+02, -.13706700E+02, -.12027900E+02, 0.14506700E+01, -.16036300E+02, 0.37856600E+01, 0.47701700E+02, 0.60442800E+01, 0.67235100E+01, 0.30853600E+00, -.87657600E+01, 0.47504000E+02, -.95610800E+01, -.56570100E+01, -.16480800E+02, -.38912200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.77621400E+00, -.61481700E+00, 0.46570800E+00, 0.33580800E+00, -.35219500E+01, 0.20908400E-01, 0.32670200E+01, 0.18809400E+01, 0.16003800E+00, -.36626900E+00, -.10376700E+01, 0.58667500E+00, -.78251000E+00, 0.89841200E+00, 0.34444600E+00, -.48602300E+00, -.19392500E+00, 0.11103600E+00, 0.39245600E+00, -.12783400E+00, 0.11053100E+01, -.32145300E-01, 0.17847500E+00, -.10709000E+00, 0.18461800E-01, 0.22350700E+00, -.20174200E+00, -.50866200E-01, -.51982300E-01, 0.32043700E+00, -.10617400E+00, -.29019400E+00, -.18753600E-01, 0.18640700E-01, 0.45357300E+00, -.21682000E+00, -.20213400E-01, -.10503800E+00, 0.23827100E+00, -.24475800E+00, -.11281600E+00, -.53852200E-01, 0.32716100E+00, 0.78035600E-01, -.44140500E+00, -.22474400E+00, 0.24773200E-02, 0.88374600E-01, 0.55286400E+00, 0.34000900E-01, -.32791000E-02, 0.49930000E-01, 0.37246300E+00, 0.25965000E+00, -.19992100E-01, -.17865900E+00, 0.64199600E-01, -.96465600E-01, 0.85315600E-01, -.82298100E-01, 0.19764700E+00, 0.14843800E-01, -.27791300E-02, 0.61368600E-01, -.49807600E-01, 0.10436400E+00, 0.26315400E+00, -.61217000E-01, -.25598200E-01, -.10235600E-01, 0.15235600E+00, 0.18944100E-01, 0.28074700E+00, 0.92186300E-02, -.17113400E+00, 0.17807300E+00, 0.21342400E-01, 0.22064600E+00, 0.19550800E-01, -.12247200E+00, 0.17686300E+00, 0.99325900E-02, 0.19477800E-01, 0.67196800E-02, -.32428000E-01, -.28572100E+00, -.14724900E+00, -.11521700E+00, 0.40259200E-01, -.35809000E+00, 0.86981600E-01, -.59054700E-01, -.54283800E-02, 0.33473100E+00, 0.16048900E+00, 0.53929200E-01, -.70910500E-02, -.45152500E-01, 0.14649400E-01, -.27654300E+00, 0.56941200E-01, 0.78728000E-01, -.44179700E-01, 0.13037800E+00, 0.10757300E-01, 0.16715500E-01, 0.31782400E-01, 0.15294400E-01, -.16289700E-01, 0.31793400E-03, 0.42969100E-01, 0.23445500E+00, 0.19071400E+00, 0.14669600E+00, 0.12327200E-01, 0.45361400E-01, -.61157600E-01, -.67364300E-01, -.41971900E-02, 0.33807700E-02, 0.12859100E-01, -.20703900E+00, -.22121400E-01, -.10388500E+00, -.48113900E-02, 0.25267900E+00, 0.16615600E-01, -.30037700E-01, -.54436600E-01, -.75841500E-01, -.19776800E+00, -.58966600E-01, 0.42374000E-01, 0.22085300E-01, -.33866400E-01, -.62410700E-01, 0.42316900E-01, 0.78611500E-01, -.11804100E-01, 0.54545600E-01, -.49943600E-01, -.14496700E+01, -.59986600E+00, 0.53417100E+00, -.25233900E-01, -.89437600E-02, 0.18911800E-01, -.16160300E-01, -.54384400E-01, -.32626400E+00, -.59126200E-01, 0.14111500E+00, 0.87701000E-01, 0.32368000E+00, -.52002200E-01, -.79462400E-02, -.41671600E-01, -.18223800E+00, 0.30658900E+00, 0.28381300E+00, -.54775200E-01, 0.19817400E+00, 0.17681000E-02, -.40276500E-02, 0.61218900E-01, -.14158800E+00, 0.17901000E-01, 0.12904400E+00, -.11401200E-01, 0.16125400E-01, -.11697000E+00, -.54760200E-01, -.57912200E-02, 0.99717600E-01, -.14643500E+00, -.60524600E-01, 0.17740900E+00, -.13908100E+02, -.13494500E+01, -.13291500E+02, 0.63583600E+01, -.12637000E+02, -.33582600E+01, -.13348900E+02, 0.19580800E+01, -.31699600E+01, -.16430700E+01, -.19281200E+01, -.44712600E+01, 0.32971900E+02, -.15562000E+02, -.17618900E+02, 0.18540000E+00, -.50052200E+00, -.12328400E+02, 0.15513100E+02, -.12804300E+02, -.11116900E+01, 0.23671600E+01, 0.15804800E+01, -.14243100E+01, 0.14170300E+01, -.93762100E+00, -.15810800E+01, 0.25351400E+01, 0.12590700E+01, -.51540200E+01, -.43617100E+01, -.12046500E+00, 0.17702800E+01, -.11590000E+01, -.50189000E+01, -.67072800E+00, -.19443300E+01, 0.22077700E+01, 0.11925800E+01, -.50175100E+01, 0.83587800E+00, -.50784300E+00, 0.36758000E+01, 0.52391500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.76262600E+01, -.13333100E-01, 0.82925600E+01, 0.31349200E+01, -.12702100E+02, -.94721400E+00, 0.11292700E+02, 0.40706500E+01, -.49470200E+00, -.35693200E+01, -.37740900E+01, 0.54556100E+01, -.14182000E+01, 0.56891500E+01, 0.26182200E+01, -.22037200E+01, -.94804300E+00, 0.55068400E+00, 0.25175800E+01, 0.49338300E-01, 0.52192900E+01, 0.22135000E+00, 0.75513200E-01, -.29376100E-01, -.77502600E+00, 0.13340900E+01, 0.42908100E+00, -.55645200E-01, -.94940400E+00, 0.25413900E+01, -.29382300E+00, -.10224700E+01, -.10270300E+01, -.73609300E+00, 0.18333600E+01, 0.10680100E+01, -.14886500E-01, 0.16354200E+00, -.36180600E+00, -.82436900E+00, 0.15857800E+01, -.21903900E+00, -.17596600E+01, 0.13470200E-01, 0.11788300E+01, -.28637000E+00, 0.20562700E+00, -.88445700E+00, -.42606300E+01, 0.32439100E+01, 0.82718100E+00, 0.65004100E+00, 0.58492600E+00, -.26839500E-01, -.79057300E+00, 0.17069800E+01, 0.33294700E+00, -.26418700E+00, -.33171400E+00, -.83469700E+00, 0.19305100E+00, 0.25290400E+00, 0.49344700E+00, -.55253000E+00, 0.19927300E+01, 0.10402900E+01, 0.77787300E+00, -.11272300E+00, 0.36079900E-01, 0.39478700E+00, 0.22045600E+00, 0.54308700E+00, -.15853300E+00, 0.13561300E+00, -.36865900E+00, -.50577700E+00, 0.15447200E+00, 0.68584900E+00, -.94490900E-01, -.88274400E+00, 0.37599500E+00, 0.40155300E+00, 0.89841700E-01, 0.14949300E+00, 0.11816300E-01, -.41604300E+01, -.38867800E+00, 0.71162700E+00, 0.95058900E+00, 0.65938800E+00, 0.80552300E+00, -.52456400E+00, 0.37768700E+00, -.17568800E+01, -.81602700E-01, -.34953500E-01, -.50729600E+00, -.89495300E-01, 0.88320600E-01, -.94668100E+00, 0.84876800E+00, -.36886700E+00, 0.11908900E+00, -.34040000E+00, -.95925700E-02, 0.16038800E+00, -.83635200E-01, 0.58902700E+00, -.17399200E+00, 0.52069000E-02, 0.70667500E-01, -.76893800E+00, 0.91442900E+00, -.10934300E+00, 0.56771700E+00, 0.64387000E+00, 0.25106300E-01, 0.64507800E+00, -.19690900E+00, -.19059400E-01, -.12581200E+00, -.71038700E+00, -.35491400E+00, 0.44089200E+00, 0.44833700E-01, 0.62235600E+00, 0.51350100E+00, -.63613800E-01, 0.48301200E+00, 0.14966400E+00, -.39677500E+00, 0.25513500E+00, 0.10144700E+00, 0.83126700E+00, 0.12150200E+00, -.28762000E-01, 0.45948100E+00, -.43988900E+00, -.10144000E+00, -.68072600E+00, -.37233300E+00, -.12959700E+01, -.11420400E+01, -.35526200E+00, -.25229600E+00, 0.26175300E-01, 0.12848900E+00, -.63957200E-01, 0.32353100E+00, 0.48662800E+00, 0.14419900E+00, -.19913100E+00, 0.37972400E+00, 0.34046200E+00, 0.85045900E-01, -.54614100E-01, 0.19458600E+00, 0.15539300E+01, -.13510000E+01, -.10469500E+01, 0.12931700E+01, -.11362900E+01, -.10230600E+01, 0.27720000E+00, 0.18518200E+01, -.21788600E+01, -.48081700E+00, 0.17876800E+00, -.22967800E+00, 0.37527300E+00, -.79257300E+00, 0.40587400E+00, 0.18876800E+00, -.55494700E+00, -.71452300E+00, 0.23308800E+00, -.51217600E+00, 0.33037800E+01, 0.35149700E+02, 0.67735600E+02, -.11538400E+02, 0.45048600E+02, 0.65402800E+01, 0.48682400E+02, -.48148000E+01, 0.36114200E+01, -.23409600E+02, 0.28507300E+02, 0.66056300E+01, -.16964300E+03, 0.79737000E+02, 0.88671000E+02, 0.16768600E+02, 0.24875700E+02, 0.46487100E+02, -.10537200E+03, 0.67449800E+02, 0.34945700E+02, -.83492100E+01, -.44992000E+01, 0.17860400E+02, -.74208700E+01, 0.54272300E+01, 0.48953600E+01, -.13452600E+02, -.60231000E+01, -.10514400E+02, -.15268800E+02, -.62644900E+00, -.87794000E+01, 0.44565200E+01, 0.26171600E+02, 0.16086800E+01, 0.86728800E+01, -.15871600E+01, -.35529100E+01, 0.25858200E+02, -.45554900E+01, -.44166100E+01, -.17107500E+02, -.24325500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.35161300E+01, 0.40675800E+00, -.38995700E+01, -.12758200E+01, 0.32368600E+01, 0.51483600E+00, -.15979100E+01, 0.24259100E+00, 0.32771000E+00, 0.62308600E+00, 0.18172200E+01, -.17027100E+01, 0.14641800E+00, -.11175700E+01, -.38313400E+00, 0.28719000E+00, 0.68945600E-01, -.16175900E+00, -.13287600E+01, -.88203200E+00, -.13703500E+01, -.15046900E+00, 0.46852800E+00, 0.20579100E+00, 0.12243200E+01, -.18024700E+00, -.16576800E+01, 0.20454000E+00, 0.18744800E+01, -.82417400E-01, 0.13519900E+00, 0.29254700E-01, 0.72731400E+00, 0.13031700E+00, 0.38435500E+00, 0.51616500E+00, 0.49603900E+00, 0.16266800E-01, -.83278100E-01, 0.16806400E+00, -.70703900E-01, -.37492500E-01, 0.60829900E+00, 0.17535100E+00, -.63691200E+00, 0.15273800E+00, -.22887400E+00, 0.66699200E+00, 0.43086600E+00, -.85473200E+00, 0.59834300E-01, -.37655500E-01, 0.79369800E+00, -.83900300E-01, -.25050400E+00, -.36518600E-01, -.16142900E+00, 0.10156200E+00, -.46265400E-01, -.27303200E+00, 0.64078900E+00, 0.17358800E+00, -.14527300E+00, 0.21105000E+01, -.10227600E+01, -.82986100E+00, 0.35827200E-01, 0.31466200E+00, 0.10693800E+01, 0.35923400E+00, -.84318900E+00, -.22885200E+00, -.22801300E+00, -.15428900E+00, 0.69624400E+00, 0.55788400E-01, 0.12586700E-01, -.34512800E+00, -.95901700E-01, 0.38157200E+00, 0.19413500E+00, 0.45129700E+00, 0.31146800E-02, -.46785200E-01, 0.13722300E-02, -.66239400E+00, 0.67341900E-01, 0.43605400E+00, -.61868800E+00, 0.39523800E+00, -.18515800E+00, 0.65357000E-01, -.83255000E-01, -.67674800E+00, 0.47045800E+00, -.39901800E-01, -.20589600E+00, -.21482900E+00, 0.88035200E-01, -.24740400E+00, -.21101600E+00, 0.50409300E+00, 0.26335200E+00, -.13499200E+00, 0.18062600E-01, 0.95732000E-01, -.19176600E-01, 0.12781600E+00, -.14868500E-02, 0.36547000E-01, 0.30465000E+00, -.64669500E-01, 0.12558000E+00, 0.51569300E+00, -.23996100E-01, -.79626300E+00, -.15263200E+00, 0.14787400E+00, 0.54320000E-01, 0.52104900E-01, -.50271200E-01, 0.11551500E+00, 0.17120200E-01, -.33432000E+00, -.58063400E-01, 0.79315600E+00, 0.43493600E+00, -.10542600E+00, -.35953200E-01, 0.38374200E+00, -.14461000E+00, 0.13410800E+00, 0.24949800E+00, 0.48336100E+00, 0.50808700E+00, -.10169700E+00, 0.61650600E-02, 0.22725600E+00, -.15191100E+00, -.23054500E+00, 0.15917500E+00, -.19425000E+00, 0.16380300E+00, 0.13347000E+00, 0.18780400E+00, -.26843700E-01, 0.13499000E-01, 0.15550900E+00, -.25770700E-02, -.46897800E+00, -.25904900E+00, -.40776000E+00, 0.11116000E+00, 0.23668400E+00, 0.22263300E+00, -.11628200E+00, -.88574800E-02, -.48647400E+00, -.39391600E+00, -.88748000E+00, 0.46906500E-01, -.91548900E+00, -.33207100E+00, 0.31454500E-01, -.13532100E+00, -.80146700E+00, -.13904900E+00, 0.83987000E+00, -.14047500E-01, 0.11641300E+00, -.17589400E-01, -.10939600E+00, -.85131400E-02, -.58030400E-01, 0.57035600E-01, -.10217600E+00, 0.24834100E+00, 0.92660700E+00, 0.80397300E-01, -.30014500E+02, 0.10095800E+03, -.53837300E+02, -.50451500E+02, -.24774200E+02, 0.19907800E+02, -.38623400E+02, -.25750200E+02, -.50551600E+02, -.10848000E+01, 0.20291600E+02, -.92240000E+01, -.11515400E+02, -.94984000E+00, -.82226600E+00, -.48492600E+01, 0.32281800E+02, -.25530000E+02, -.25692500E+01, 0.37793600E+01, 0.74796600E+00, -.75775000E+01, 0.40259500E+01, -.18530200E+01, -.11963800E+01, 0.33513600E+01, 0.18110400E+01, -.12596800E+02, -.12572200E+02, 0.18793300E+01, 0.47112700E+01, 0.82887900E+00, -.12871400E+02, -.65909600E+00, -.95110100E+00, -.22357500E+01, 0.11957000E+01, -.12897300E+02, 0.26424300E+01, 0.12524200E+01, 0.37599000E+01, 0.72859200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14609900E+01, -.24357700E+00, 0.95999200E+00, 0.73124500E+00, -.69278600E+01, 0.67797500E-01, 0.73498600E+01, 0.39266500E+01, -.32458900E+00, -.65561300E+00, -.21747400E+01, 0.12181000E+01, -.18343000E+01, 0.15581800E+01, 0.73500400E+00, -.10796000E+01, -.54583500E+00, -.17170100E+00, 0.97000000E+00, -.11412900E+01, 0.37914000E+01, 0.21294600E+00, 0.71740900E-01, -.66029200E+00, -.76784900E-01, 0.72493300E+00, -.93974200E-01, -.33283000E+00, -.51405700E+00, 0.91659500E+00, -.60507100E+00, -.29119800E+00, 0.42599900E+00, 0.47833800E+00, 0.34922200E+00, 0.61805100E+00, -.56213300E-01, -.15840600E+00, 0.69174300E-01, -.62994400E+00, -.43038800E+00, -.27183500E+00, 0.83436300E+00, 0.73147200E-01, -.99375600E+00, -.81482400E+00, 0.36873000E-01, -.55045800E-02, 0.15979200E+01, 0.14055900E+01, -.91467700E-01, 0.23847900E+00, 0.27395900E+00, 0.19323500E+01, 0.35003500E+00, 0.21342800E+00, 0.96586200E-01, -.20221800E+00, 0.31002600E+00, -.53549800E+00, -.66350500E-01, -.10729600E+01, 0.10296600E+01, 0.27874400E+01, -.65696000E+00, 0.17780900E+00, -.89428000E+00, 0.13506600E+00, 0.38576900E+00, -.13635200E+00, -.46247200E+00, -.23355000E+00, -.30836100E+00, 0.31878300E-01, -.23698100E+00, -.68594700E+00, 0.93032700E-01, 0.81274000E+00, 0.35846600E-01, -.57171800E+00, 0.30781400E+00, 0.42834000E+00, 0.20991900E-01, 0.19309100E+00, -.51372700E+00, 0.12885000E+00, 0.10479200E-01, -.54498000E-01, 0.20384700E+00, 0.10526800E+01, 0.14643900E+00, 0.94080800E-01, -.26118100E+00, 0.16875800E+01, -.53834200E+00, 0.10010800E+00, 0.23316300E+00, -.53459900E+00, -.21955700E-01, -.13700000E+00, 0.89436700E-01, 0.34706900E+00, -.11007000E+00, -.90905300E-01, -.21623900E+00, 0.76786900E-01, 0.42521700E-01, 0.89028000E+00, 0.17770300E+00, -.24789700E-01, -.23936700E-01, -.37301500E+00, 0.11869500E+00, 0.30560800E+00, 0.29533000E+00, -.15298100E+00, -.40593100E-01, -.48423500E+00, 0.11780500E+00, 0.49435400E-01, 0.23302900E+00, -.41781300E+00, 0.33856900E-01, -.55116300E+00, 0.15227600E+00, 0.35226300E+00, -.24100100E+00, 0.10492100E+00, 0.46242700E+00, -.43983800E+00, 0.21395200E+00, -.24816900E+00, -.45446700E-01, 0.66873900E-03, -.16299100E+00, -.10939400E+00, 0.18358000E-01, 0.17011100E-01, 0.17193200E+00, 0.55009300E-01, -.14082600E+00, -.21158800E+01, -.10836900E+01, 0.88653400E+00, 0.84359300E-01, 0.76788800E-04, -.18511700E-01, 0.13499500E+00, -.13480600E+00, -.84450700E+00, -.39894400E-01, 0.18287100E+00, 0.54532600E-01, 0.64865600E+00, -.38800600E-01, 0.64000000E-01, -.73643000E-01, 0.42250600E+00, 0.41498400E+00, -.19162400E+00, 0.17316800E+00, -.70775400E+00, 0.75280700E-01, 0.30181700E-01, 0.33768700E+00, -.54712100E+00, 0.63727700E-01, -.49125700E+00, -.12793800E+00, 0.12863700E+00, 0.47646200E+00, 0.26688000E+00, 0.27587900E-01, -.36046800E-01, 0.29893600E+00, 0.14218400E+00, -.19446600E+00, -.57721600E+00, 0.46574300E-01, -.79219200E-01, 0.66114200E+02, -.27148800E+02, -.32813100E+02, 0.19088300E+02, 0.22825300E+01, -.24351100E+02, -.14261500E+02, -.32506600E+02, -.14156700E+02, 0.19747500E+02, -.10067800E+02, -.10859500E+02, -.54486200E+01, -.11581200E+02, 0.31537000E+01, 0.16444700E+02, 0.90492000E+01, -.12183500E+02, -.63912100E+00, 0.24955700E+01, -.20684900E+01, 0.12248300E+01, -.14479800E+01, -.23385000E+01, -.10362400E+01, 0.13873500E+01, 0.90839700E+01, 0.64744800E+01, -.54050400E+00, 0.84860400E+00, 0.11727200E+01, -.10337300E+02, -.64717200E+00, 0.22235300E+01, 0.36349200E+01, 0.16464700E+01, -.10440300E+02, 0.64974600E+00, -.98478100E-01, 0.34783700E+01, 0.27305700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13016300E+02, -.30253600E+01, 0.12038600E+02, 0.55208800E+01, -.25501300E+02, -.20314400E+00, 0.30140900E+02, 0.13429800E+02, 0.16995800E+01, -.32424900E+01, -.75708000E+01, 0.77888900E+01, -.67752700E+01, 0.79921700E+01, 0.37449600E+01, -.39618700E+01, -.14774900E+01, 0.17263100E+01, 0.64388600E+01, -.86026000E+00, 0.13557500E+02, 0.45966200E+00, 0.36289600E+00, -.10578200E+01, -.10244600E+01, 0.32524400E+01, 0.27729200E+00, -.20637600E+01, -.32005400E+01, 0.38905500E+01, -.16616600E+01, 0.64148000E+00, -.70132500E+00, 0.48408100E+00, 0.19350800E+01, -.98170400E+00, -.38380600E-02, -.10778400E+00, -.64125500E+00, -.10908400E+00, 0.16400500E+01, -.18017100E+00, -.29057100E+00, 0.20455100E+00, -.25855300E+00, -.14798600E+01, 0.15089000E+01, -.28984600E+01, -.20261700E+01, 0.43156200E+01, 0.21599900E+00, 0.53637500E-01, 0.99739500E+00, 0.37218300E+00, -.26185800E-01, 0.44753100E+00, 0.71436400E+00, -.60864800E+00, -.13080500E+00, 0.12369000E+01, 0.37332300E+00, 0.20440500E+01, -.23473400E+01, -.60733600E+01, 0.18351400E+01, 0.15376200E+01, 0.13715200E+01, 0.92556500E-01, 0.49689100E+00, -.50478700E+00, -.17800300E+01, 0.43043800E+00, 0.16338100E+00, 0.91832500E+00, -.31525700E+01, -.58164200E+00, 0.46205900E+00, 0.36273400E+01, 0.30890800E+00, 0.11861600E+01, 0.22220300E+00, -.14866000E+01, -.22671400E+00, 0.12819700E+00, -.44555100E+00, -.57549500E+00, 0.86669100E+00, 0.83501500E+00, -.21648700E+00, 0.44333900E+01, -.16147700E+00, -.47338300E+00, 0.57321100E-01, 0.94927000E+00, -.40750100E+00, 0.24987500E+00, 0.93152100E+00, -.58937700E+00, 0.70136500E-01, -.31882700E+01, 0.62258100E+01, -.17229100E+01, 0.36099500E+00, 0.33501100E+01, -.48912000E+00, 0.13500700E+01, 0.25328200E+00, 0.91305600E-01, -.13472600E+01, -.10161200E+00, -.34201500E+00, -.25446700E+01, 0.34108000E+01, -.49473800E+00, 0.17053800E+01, 0.25524700E+01, -.21175200E+00, -.13588600E+01, -.23429000E+01, 0.40646000E+00, 0.77917500E+00, -.20040100E+01, -.10323700E+01, 0.20454500E+01, 0.13032500E+01, 0.10039800E+01, -.19581000E+01, -.20599800E+01, 0.50199800E+01, 0.49858500E+00, -.56940200E+00, 0.17238200E+01, -.50505300E+00, 0.97906900E+00, -.11505800E+01, -.15829800E+00, -.12889300E+01, -.74584700E+00, 0.21151000E+00, 0.21903700E+00, -.75442300E+00, 0.55993300E+01, 0.13555600E+01, -.33660500E+01, -.11658600E+01, 0.42090300E+00, 0.29480400E+00, -.72835000E+00, 0.64913800E+00, 0.27802700E+01, -.18040100E+00, -.15498500E+01, 0.11921000E+01, 0.18498500E+01, 0.65376800E+00, -.37862800E+00, 0.24275900E+00, -.10690400E+01, -.10535100E+01, -.52788500E+01, 0.13523900E+01, 0.27159700E+01, -.81456000E+00, -.71595500E+00, 0.12848000E+01, -.15699800E+01, -.13232000E+01, 0.29138900E+01, 0.72375300E+00, -.26195200E+00, -.25333900E+01, 0.13533100E+01, -.93594500E+00, -.28136500E+00, -.22780200E+01, 0.22922400E+00, -.92862800E+00, -.54465100E+01, 0.64517200E+00, -.22347800E+00, -.21743900E+01, 0.27449800E+03, -.35054700E+00, -.86721500E+02, 0.57076200E+02, -.44804900E+02, -.11039200E+03, -.40674800E+01, 0.94134700E+01, 0.85795800E+02, -.25345500E+02, -.39879700E+02, -.21269800E+02, -.34588200E+02, -.39153700E+02, -.99516200E+02, -.31383100E+02, -.14521700E+02, -.10049500E+02, -.25775700E+02, 0.29205000E+01, -.11280600E+02, 0.30806600E+01, 0.26202800E+02, 0.57214700E+01, -.13177700E+01, -.81124000E+02, -.80571700E+02, -.63952200E+01, -.11604900E+02, -.70965300E+01, 0.51247200E+02, 0.29684000E+01, -.63890900E+01, 0.83671700E+01, -.61646200E+01, 0.52074300E+02, -.99931000E+01, 0.89261500E+01, -.97520300E+01, -.13581200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.27578400E+01, -.79324800E+00, -.40411100E+01, -.13375400E+01, 0.27345700E+01, 0.60713100E+00, -.50813500E+01, -.30077200E+01, 0.79291900E+00, 0.13990500E+00, 0.15470600E+01, -.10247700E+01, 0.87742000E+00, -.15069200E+01, -.30053300E+00, 0.74234500E+00, -.47604600E+00, -.31282300E+00, 0.13419400E+00, 0.12509200E+01, 0.91597300E+00, -.11392300E+00, 0.21904400E+00, 0.89497800E-01, 0.57537100E+00, -.17052000E+00, -.71822200E+00, -.20648300E+00, 0.19760400E+01, -.53566600E+00, -.27291200E+00, -.82616100E+00, 0.83215200E+00, 0.56436400E+00, -.32940400E+00, -.40995000E+00, -.49006700E-01, -.58139300E+00, 0.97353200E+00, -.11970600E+01, 0.25053100E+00, -.18742900E+00, 0.68594000E+00, 0.44868400E+00, 0.80908400E+00, 0.80221500E+00, 0.91796000E-02, -.12012700E+00, -.23389300E+01, 0.40258000E+00, 0.17675700E+00, -.18145700E+00, 0.89966500E-01, 0.64010000E+00, -.53937100E+00, 0.18840600E+01, 0.10443800E+00, 0.75837100E-01, -.40325500E+00, -.19115800E+00, -.64778100E-01, 0.15028400E+00, -.49465400E-01, 0.29617900E+00, -.87230900E-01, -.40103800E-01, -.40246600E-01, -.65793500E-01, -.18906100E+00, -.56480900E-01, 0.22133600E-01, 0.85180000E-01, 0.38110500E-01, 0.27124400E-01, -.72678500E-01, 0.37741300E-02, 0.10367200E+00, -.55515600E-01, 0.26618700E-01, -.13498600E+00, 0.39302000E-01, -.19189900E+00, -.25477400E-01, 0.94461800E-02, -.19555200E+00, 0.48717300E+00, 0.34327600E-01, -.93534500E-02, -.12162500E+00, -.40727300E-01, -.15922400E+00, 0.10311400E+00, -.74241700E-01, 0.15287100E+00, -.28762400E-01, -.71483600E-01, 0.11219100E+00, -.13070200E+00, 0.46593000E-01, 0.15939000E+00, -.68959000E-01, -.26791200E+00, -.43610700E-01, 0.19275300E-02, -.12219500E+00, 0.12637600E+00, 0.15922500E-01, 0.16390800E+00, 0.28803400E-01, -.15284900E-01, -.89462600E-02, 0.48288900E+00, -.15298300E+00, -.17926000E-01, 0.95650100E-01, 0.13164200E+00, 0.12663200E+00, -.35959000E-01, -.21712200E-01, -.35180600E-02, 0.15556000E-01, -.79872200E-01, -.29901500E-01, -.29519600E-01, 0.35433600E-01, -.15693300E+00, -.32170500E+00, 0.43060700E-01, 0.37311900E+00, -.17774400E+00, 0.18309700E+00, -.36767900E-01, -.39071700E-01, -.64965800E-01, -.15127000E+00, -.57909000E-01, -.14018000E-01, 0.43792000E-01, 0.11750500E+00, 0.36908500E-01, 0.33805500E-01, -.19299100E+00, -.26523300E+00, 0.47984600E+00, -.66566900E-01, 0.98426600E-02, 0.44853900E-02, -.10542700E+00, 0.65643100E-01, 0.22790900E-02, -.38311500E-01, -.94997600E-01, 0.18958900E-01, 0.49122100E-01, 0.49957800E-01, -.52836400E-02, 0.23086900E-01, 0.73273200E-01, -.32584700E+00, -.47686000E-01, 0.33358200E-01, 0.12041900E+00, 0.52805300E-01, -.69084500E-02, 0.45509000E-01, 0.23101500E-01, 0.55368000E-01, -.41574300E-01, 0.23543700E-01, -.83503600E-01, -.47584800E-01, 0.31097800E-01, -.39595600E-02, -.95970600E-02, 0.13070000E-01, -.42883000E-02, 0.33790100E-01, 0.11703100E+00, -.31629300E-01, -.67172100E-01, 0.19581700E-01, -.15255400E-03, 0.20582500E+01, -.26126200E+01, 0.21441700E+01, 0.24882700E+00, -.10813100E+01, 0.85821400E+00, 0.28269500E+01, -.25761900E+01, 0.11651700E+01, 0.11936600E+01, -.33695400E+00, -.51809900E+00, 0.99234400E+00, -.31619600E+01, 0.18849800E+00, -.17029800E+00, 0.18743800E+00, -.32969600E+00, 0.22757600E+00, -.72670900E-01, -.23829000E-01, 0.29363500E+00, -.56531900E+00, -.25175300E-03, 0.19345700E+00, 0.36879000E+00, 0.31054900E+00, -.91187600E-01, 0.36649200E+00, 0.16218000E+01, 0.14590000E-01, 0.49603500E+00, -.84867200E+00, -.19995200E+00, 0.16429900E+01, -.83774400E-01, 0.56922700E-01, -.10468300E+01, -.59684800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.73431000E+01, 0.69196800E+00, -.76723000E+01, -.31455100E+01, 0.10290100E+02, 0.59796300E+00, -.10645900E+02, -.30953500E+01, 0.19995900E+01, 0.26693900E+01, 0.26964700E+01, -.45862500E+01, 0.12483400E+01, -.58355700E+01, -.19984200E+01, 0.12275800E+01, 0.13387800E+01, -.12406400E+00, -.20917500E+01, 0.17232300E+01, -.52357100E+01, -.97857700E+00, 0.39533300E+00, 0.81386100E+00, 0.33107700E+00, -.14476400E+01, -.49335400E+00, 0.73727200E-02, 0.39429200E+00, -.23856000E+01, 0.59154000E+00, 0.22391500E+01, 0.70781200E+00, 0.15744500E+01, -.57890200E+00, -.11940700E+00, 0.23483200E+00, -.12233700E+00, -.24276100E+00, 0.30431000E+00, -.37397800E+00, 0.85911200E-01, 0.16562700E+00, -.73905700E+00, 0.28622900E+00, 0.70949600E+00, -.20876500E+00, -.40629200E+00, 0.23056500E+00, -.84493800E+00, -.35552700E+00, -.10342900E+00, -.16465600E+01, -.32132400E+01, -.69467400E+00, -.24062100E+01, -.56583800E+00, 0.53683800E+00, 0.29797400E+00, -.27030800E+00, -.48292700E+00, 0.19135900E+01, -.10783500E+01, -.22837200E+01, -.22574900E+00, -.79782200E+00, -.34123100E+00, -.41101800E+00, -.98845600E+00, 0.45413800E+00, 0.41377100E+00, 0.13610100E+00, -.81574000E+00, 0.95207900E-01, 0.27462600E+00, 0.33155600E+00, 0.11515400E+00, -.57161900E-01, -.46330200E+00, 0.14927000E+01, -.17255100E+00, 0.78517800E-01, -.16586600E+00, -.10010900E+00, 0.20535700E+00, 0.49100700E+01, 0.68576300E+00, -.66917100E+00, -.21247900E-01, -.22704200E+00, -.52606300E-01, -.37935200E+00, -.40739800E+00, 0.62846500E+00, -.14076300E+01, -.30343400E+00, 0.62142900E+00, 0.27858100E+00, 0.13172200E+00, 0.17154500E+01, -.34084500E+00, -.16853000E+01, -.68433600E+00, -.65124200E+00, -.12180400E+00, -.41827100E+00, 0.16934500E-01, -.58829700E+00, 0.35016200E+00, -.31045400E-01, -.38877200E+00, 0.93297900E+00, -.49350400E+00, 0.20179900E+00, -.44724400E+00, -.11265500E+01, -.16272700E-01, -.14604200E+00, -.26357600E+00, -.42695300E-01, -.48223400E+00, 0.33331300E+00, -.24854600E+00, -.17303900E+00, -.84939600E-01, -.75120000E+00, 0.73488700E+00, 0.29100700E+00, -.24612300E+01, 0.10266600E+00, 0.11715600E+01, -.25978400E+00, -.75059900E+00, -.87432800E+00, 0.20643300E-01, 0.62317300E+00, -.24467100E+00, -.79451100E+00, -.49562700E-01, 0.60800300E+00, -.21723400E+00, 0.10467300E+01, 0.72043600E+00, -.82626600E+00, -.57994700E+00, 0.25475400E-01, 0.48992200E-01, 0.10425500E+01, 0.67920000E-01, 0.72509600E+00, 0.28209300E+00, 0.55895500E+00, -.36887300E+00, -.79839200E+00, -.31451900E+00, 0.35901700E+00, -.23104300E+00, 0.31568000E-01, 0.39440000E+00, 0.77012600E+00, -.60401400E+00, -.30153500E+00, -.18512700E+00, -.14410800E+00, -.24966700E+01, -.16089300E+00, 0.80765600E-01, 0.34616700E+00, -.13886600E+00, -.88541600E-01, 0.27170700E-01, -.16284600E+00, -.92337800E-01, -.20615400E+00, 0.15161300E+00, 0.33710400E-01, -.25521100E+00, -.17767100E+01, 0.29586200E+00, -.71211300E+00, 0.15072600E+01, -.71428000E-01, -.44851600E+00, -.74610100E+02, 0.32853300E+02, -.11356200E+02, -.38869100E+02, -.88363500E+01, 0.34657000E+02, 0.41222200E+02, -.17822700E+02, -.20085700E+02, -.94338300E+01, 0.62946700E+00, -.18215600E+02, -.25818700E+02, -.44560800E+02, 0.38162700E+01, -.66880400E+00, -.96794800E+01, 0.14335600E+01, -.54422800E+00, 0.38629100E+01, 0.89615400E+01, 0.85348500E+01, -.35190600E+01, -.50789800E+02, -.47280300E+02, 0.15570700E+00, 0.71662900E+00, -.41648600E+01, 0.24358100E+02, 0.20077700E+01, -.51841100E+01, -.12109100E+02, -.32074100E+01, 0.24932500E+02, -.88867500E+00, 0.28748500E+01, -.11653800E+02, -.43990700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.30902600E+01, -.16248100E+01, 0.21799900E+01, 0.15281200E+01, -.16274300E+02, 0.13975700E-01, 0.15345000E+02, 0.91287100E+01, 0.63448600E+00, -.15498100E+01, -.41933700E+01, 0.28969700E+01, -.35348900E+01, 0.40593800E+01, 0.16081400E+01, -.20106000E+01, -.69456500E+00, 0.93416900E+00, 0.27765600E+01, -.17981800E+01, 0.54065500E+01, 0.10488000E+00, 0.83662800E+00, -.62690200E+00, -.45193400E+00, 0.13896100E+01, 0.27242400E+00, -.37175600E+00, -.11961300E+01, 0.12386100E+01, -.61425800E+00, 0.63012300E+00, -.55767000E+00, -.24771900E+00, 0.13219900E+00, -.54842800E+00, 0.28575000E-01, 0.18160300E+00, -.14461000E+01, -.18233300E+00, -.10155400E+00, 0.36471600E-01, -.19540200E+00, 0.54682500E-01, 0.28273900E+00, -.77150300E+00, 0.13767500E+00, -.20940900E+00, 0.24305000E+01, -.59687600E+00, -.14885900E+00, -.13471000E-01, 0.38258600E+00, 0.14781900E+01, 0.63442500E+00, -.42292000E+00, 0.34557100E+00, -.23869900E+00, 0.19309200E+00, 0.39351800E+00, 0.95392000E-01, -.14501200E+01, 0.23270700E-01, 0.16097800E+01, -.12730900E+01, -.37378200E+00, -.10473000E+01, 0.61350700E+00, 0.20567400E+01, 0.33937400E+00, -.13761700E+01, -.72589500E+00, -.85208800E+00, 0.12034200E+00, -.70727700E+00, -.71470300E+00, -.62181800E-01, 0.61769000E+00, 0.25821600E+00, -.42118600E+00, 0.31326100E+00, -.51875200E+00, -.11158100E+00, 0.80682600E-01, -.69364500E+00, 0.19457600E+00, 0.36459200E+00, 0.52777000E+00, -.21530200E-01, 0.20030600E+01, -.63984500E+00, 0.47466900E+00, -.11310700E-01, -.47349500E+00, 0.78788900E+00, -.22694300E-01, 0.12240100E+00, -.56915200E+00, 0.30945700E-03, -.11592800E+01, 0.12007900E+01, 0.93064700E+00, 0.89136300E+00, -.76822100E+00, -.34001800E+00, 0.20551700E+00, 0.11285800E+00, 0.47814000E+00, -.62643600E-01, -.33848700E-01, 0.54384900E-01, -.28236000E+00, 0.37246500E+00, 0.46271400E+00, 0.24919500E+00, -.77079400E+00, -.34810300E+00, -.83795300E+00, -.17577400E+00, 0.11830700E+00, 0.31442000E+00, 0.27137900E+00, -.10251200E+00, 0.29058900E+00, -.13852100E+00, 0.10636300E+01, 0.16905400E+00, -.23841400E+00, -.14470300E+00, 0.22137600E+00, -.42305100E+00, -.26270200E+00, 0.29300500E+00, 0.31506700E+00, 0.20957100E+00, 0.21534600E+00, -.88764900E-01, -.17002900E+00, -.22505000E+00, 0.40164800E+00, -.35839400E+00, 0.97234900E+00, 0.57116800E-01, -.29777500E+00, -.59021500E+00, -.16427100E-01, 0.62248900E-01, -.14493400E+00, -.19264300E-01, 0.64842800E+00, -.21705200E+00, 0.11914200E-01, -.13995500E+00, 0.14918400E+00, 0.13724200E-01, -.16197800E+00, 0.25239500E+00, -.10637900E+00, -.84266800E+00, 0.73395500E+00, -.25783200E+00, 0.29848600E+01, -.10938400E+00, -.87934900E-01, -.11715000E+01, 0.10330900E+01, -.26960000E-01, 0.11552700E+01, 0.14288500E+00, -.77811500E-02, -.78467500E+00, -.11400700E+00, -.11478900E+00, 0.91380100E-01, -.12440400E+01, -.24073100E+00, 0.36767400E+00, 0.20858900E+01, 0.34683900E+00, 0.76499700E+00, -.12219500E+01, 0.22315500E-01, -.27937600E-01, -.39641800E+00, 0.17200900E+02, -.47015500E+01, -.19088500E+02, -.13652500E+02, 0.17051800E+02, -.41684100E+02, 0.21020300E+02, 0.21521200E+02, 0.14030900E+02, 0.19511100E+02, -.32336000E+01, -.51545400E+02, -.29229600E+02, 0.21474900E+02, -.35497100E+01, -.49331500E+01, -.13802400E+01, -.33001200E+01, 0.38043200E+01, 0.47496200E+01, 0.38931100E+01, -.39254300E+01, -.29182300E+01, 0.48368600E+01, -.20514600E+01, -.31260500E+01, -.32949000E+01, 0.18393600E+02, 0.22462300E+01, -.19672100E+01, -.40666500E+01, -.32056700E+01, 0.18790800E+02, -.20126700E+01, 0.30587200E+01, -.85963700E+01, -.55462900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.97359200E+01, -.89689000E+00, -.11127700E+02, -.48281100E+01, 0.18382700E+02, 0.23495100E+00, -.20849200E+02, -.11084500E+02, 0.15507100E+01, 0.95749600E+00, 0.77005900E+01, -.42470000E+01, 0.40802200E+01, -.44629400E+01, -.21543200E+01, 0.36343200E+01, -.50732800E+00, -.47361100E+00, -.76278400E+00, 0.43810900E+01, -.19260700E+01, -.91035200E+00, 0.63193900E+00, 0.13081300E+01, 0.61733200E+00, -.11209300E+01, 0.24427300E+01, -.41913100E+00, 0.57862700E+01, -.26022600E+01, 0.16508300E+00, -.11314400E+01, 0.14341900E+01, 0.10229300E+01, -.19292200E+01, 0.29605100E+01, -.57460900E+00, -.50855500E+00, 0.21667400E+00, -.38270100E+01, -.75915700E+00, -.24268600E+00, 0.80095200E+00, 0.63610400E+00, 0.27036200E+01, 0.39526700E+01, -.14982300E+01, 0.26290900E+01, -.37679300E+01, -.71701700E+00, -.10042100E+00, -.72119100E+00, -.90815400E+00, 0.71109400E+00, -.17795800E+01, 0.29141900E+01, 0.24732500E+00, -.13473900E-01, -.67108500E+00, -.46694300E+00, -.54030400E+00, -.23170300E+01, 0.27839100E+01, 0.47569800E+01, -.12908400E+01, -.70356600E+00, -.19834100E+01, 0.10355600E+01, 0.21377900E+01, -.68293400E+00, -.13930700E+01, -.10683200E+01, -.14210300E+01, -.63906200E+00, 0.12585100E+01, -.16418300E+01, -.79309600E+00, -.28459200E+00, 0.43214400E+00, -.17888700E+01, 0.51339000E+00, 0.25192200E+01, 0.90878400E-01, 0.22889300E+00, 0.35751100E+00, -.48460200E+00, -.17369400E+00, -.44017900E+00, 0.17378900E+01, 0.81613000E+00, 0.15727800E+01, -.79347600E+00, 0.25631000E-01, -.14962900E+01, 0.29309900E+00, -.71586600E-01, -.16937900E+01, 0.29004300E-01, 0.28192100E-01, 0.21062000E+01, -.24164100E+00, -.41486200E+01, 0.49584700E+00, -.28164500E+01, -.77182300E-01, -.13233600E+00, -.45067900E+00, 0.36338000E+00, 0.10006600E+00, 0.61737000E-01, -.12180900E+00, -.17874700E-01, 0.36776400E+00, 0.22584000E+00, -.75999300E+00, -.45240600E+00, -.39956800E+00, 0.60698600E+00, -.12420400E+00, -.20736900E+00, -.46866200E+00, -.10916100E+01, -.36425500E+00, -.70684300E+00, 0.65078400E+00, -.11820600E+01, -.14887500E+00, -.34209300E+00, 0.39875100E+00, -.16282400E+00, -.36481200E+00, 0.74445800E+00, -.30398600E+00, 0.74693900E+00, -.52050500E+00, 0.41411500E-01, 0.32201200E+00, -.75275000E+00, 0.18473500E+00, -.66861400E+00, 0.30066800E+00, -.35805600E+01, -.96219900E+00, 0.13836000E+01, 0.86191900E+00, -.96732200E-01, 0.33890000E+00, -.19539500E+00, -.40836000E+00, -.14767800E+01, -.36611800E-01, 0.61905500E-01, -.30566800E-01, 0.10424100E+01, 0.95184800E-01, -.73877700E-01, 0.43514700E+00, 0.95303700E+00, -.16475000E+01, 0.11572100E+01, -.19698600E+00, -.73575000E+00, 0.13182300E-01, 0.28716600E+00, 0.12264600E+00, 0.19440700E+01, 0.30062400E+00, 0.76286000E+00, 0.12898300E+00, 0.48040700E+00, -.45362500E+00, 0.44809600E+00, 0.69086300E-01, 0.84318000E+00, -.26863500E+00, 0.33275100E-02, -.38040100E+00, -.28961800E+01, -.47105300E+00, -.68415700E+00, 0.15298900E+01, 0.24703900E+00, 0.13203600E+01, 0.19968600E+00, -.12059200E+01, 0.16436000E+02, 0.18980800E+02, 0.31212100E+02, 0.20420100E+02, -.18651400E+03, 0.94239800E+02, 0.94421700E+02, 0.70051600E+02, 0.10139500E+03, -.10215800E+02, -.77061400E+02, -.11588000E+03, 0.97238900E+02, 0.88836800E+01, 0.54958600E+01, 0.45420400E+01, 0.13433200E+01, 0.49456900E+01, -.59786100E+01, -.14017100E+01, -.58808900E+01, -.62974100E+01, 0.12472600E+02, 0.84865800E+01, 0.15577200E+01, 0.14118700E+01, 0.80101900E+00, 0.12717400E+01, 0.21989300E+00, -.64979800E+01, -.42006800E+01, 0.14260600E+00, 0.46147000E+00, -.57737300E+01, -.38311500E+01, 0.27112100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.93183200E+01, -.21465100E+00, -.96669200E+01, -.53746900E+01, 0.31544700E+02, -.56360000E+00, -.28465400E+02, -.15421500E+02, -.87260200E+00, 0.30538000E+01, 0.10681500E+02, -.72282700E+01, 0.63000700E+01, -.63667100E+01, -.36886500E+01, 0.40752800E+01, 0.12053700E+01, -.13594700E+01, -.31808700E+01, 0.26579100E+01, -.71073100E+01, -.70312800E+00, -.51854500E+00, 0.14884900E+01, 0.89693000E+00, -.22377500E+01, 0.29461800E+00, 0.35861300E+00, 0.66227200E+01, -.44243100E+01, 0.11739800E+01, -.23824700E+01, 0.14649600E+01, 0.30456600E-01, -.24308500E+01, 0.64201400E+00, 0.98697800E-01, -.90612800E+00, 0.35505900E+01, -.12751000E+01, -.33297900E+01, -.25717700E+00, 0.44519900E+01, 0.14809900E+01, -.17482900E+01, 0.19040500E+00, -.98714900E+00, 0.37448300E+01, 0.43295300E+01, -.20713200E+01, -.32869700E+00, -.32456800E+00, 0.10242200E+01, 0.21024100E+01, 0.56811500E-02, 0.90276400E+00, -.70584800E+00, 0.20234500E+00, 0.12920000E+00, -.80238700E+00, -.17206600E+01, -.25525100E+01, 0.72875800E+00, 0.75937700E+01, -.34419500E+01, -.22044700E+01, -.32219400E+01, -.51066300E+00, -.90022800E+00, 0.12441800E+01, 0.23593700E+01, -.51518200E+00, 0.99194800E+00, -.38081000E+00, 0.11645700E+01, 0.17688100E+01, 0.15299600E+00, -.15276400E+01, -.26888500E+00, -.71873200E+00, 0.38548800E-01, 0.15178400E+01, 0.30949600E+00, -.19079600E+00, -.13142600E+01, -.65450000E+01, -.43066300E-01, 0.18915700E+01, 0.36341100E+01, -.43589600E+01, 0.21427100E+01, -.22420100E+00, 0.68097300E+00, 0.32715800E-01, 0.10002100E+01, 0.83074700E+00, -.85035400E+00, 0.98648500E+00, -.46504000E+00, -.15688100E+01, -.83995000E+00, 0.25910600E+01, -.33054300E+00, 0.19145200E+01, 0.13720500E+01, -.61972000E+00, -.37916300E+00, 0.14240700E+01, -.62648800E+00, 0.23474100E+00, -.42441200E+00, -.43223600E+01, 0.75505400E+00, -.22398100E+00, 0.91097300E+00, -.98160100E-02, -.77395000E-01, 0.86461000E+00, 0.33199600E+00, -.30695500E-01, -.32793600E+00, 0.37586800E+00, 0.44437400E+00, -.22446400E+00, 0.12603600E+00, -.64976500E+00, -.55940700E+00, 0.11211400E+00, -.13957200E+01, -.71340900E+00, -.27469700E+00, -.51342700E+00, 0.16030200E+01, 0.16159600E+00, 0.14289700E+01, -.16014900E+00, -.26289800E+00, 0.57281000E+00, -.17664700E+00, -.74407100E-01, 0.27530700E+00, 0.39239400E+01, 0.34468900E+01, -.20848800E+00, 0.92036000E+00, -.12700900E+00, 0.25272300E+00, -.11852500E+00, -.51568500E+00, -.45736200E+00, 0.19470800E-01, 0.13347300E+00, -.42876400E+00, -.90693900E+00, -.85786900E-01, 0.13464600E+00, 0.63452800E-02, 0.18137900E+01, -.13859000E+01, 0.15947200E+01, -.17271500E+00, -.11940600E+01, -.82578800E+00, 0.16282800E+00, -.20990400E+01, -.24897100E+01, -.47630200E-01, 0.13886800E+01, -.45037900E+00, 0.72193700E+00, 0.37536800E+00, 0.13352200E+01, 0.51755000E-01, 0.36039000E+00, -.51467200E+00, -.20181300E+00, 0.10440000E+01, 0.62576100E+01, 0.35882500E+00, 0.12585500E+01, 0.10493400E+01, 0.71272700E-01, 0.57866900E+00, -.61308800E+00, 0.65694500E+00, 0.87375500E+00, 0.54413300E+02, -.19339700E+02, 0.63450000E+01, 0.12503500E+03, -.67896400E+02, -.65554600E+02, -.45682200E+02, -.66983300E+02, 0.99371800E+01, 0.80160800E+02, 0.64497200E+02, -.69380400E+02, 0.20765300E+01, 0.68085000E+01, 0.19237100E+01, 0.27170700E+01, -.67370900E+01, -.67493100E+01, -.35058500E+01, 0.66573400E+01, 0.44291000E+02, 0.33451900E+02, 0.17048500E+01, 0.25491900E+01, 0.63876900E+01, -.18334200E+02, -.31939400E+01, 0.25516500E+01, -.76936400E+01, 0.43171600E+01, -.18387200E+02, 0.17355000E+01, -.11763100E+01, 0.75534100E+01, 0.50658100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.91796000E+00, -.23084500E+00, -.18976000E+01, -.83424500E+00, 0.43044700E+01, -.54627300E-01, -.31878300E+01, -.10155800E+01, 0.13823200E-01, 0.56651500E+00, 0.14476100E+01, -.11569900E+01, 0.62232900E+00, -.54049900E+00, -.57236200E+00, 0.66036200E+00, 0.24575300E+00, 0.12213200E-01, -.66259900E-01, 0.39824700E+00, -.87115300E+00, -.15694500E+00, 0.11608300E+00, 0.10900600E+00, 0.28144800E+00, -.24026100E+00, 0.13763500E+00, 0.17766700E-01, 0.12425100E+01, -.68168000E+00, 0.16160700E+00, -.38336100E+00, 0.25530100E+00, 0.54919200E-01, -.18598900E+00, 0.16191100E+00, -.18977300E-01, -.48447000E-01, 0.41789200E+00, -.41094400E+00, -.22477700E-01, -.16964200E-01, 0.43657100E+00, -.53369700E-01, 0.12809700E+00, 0.47195100E+00, -.28326500E+00, 0.41359900E+00, -.93094900E-01, -.10169100E+01, -.22502000E-02, -.13937300E+00, 0.15160000E+00, 0.14119300E-01, -.74037500E-01, 0.32311400E+00, -.23062900E-01, 0.90055700E-01, -.86851600E-01, 0.61332000E-01, -.67487500E-01, -.45110400E+00, 0.12270200E+00, 0.93308000E+00, -.46091300E+00, -.29753100E+00, -.26948000E+00, 0.78245900E-01, 0.14550000E+00, 0.23199700E-01, 0.30174100E+00, -.17940600E+00, 0.85709800E-01, -.20516400E+00, 0.37048400E+00, -.51246000E-02, -.16908900E+00, -.54757700E+00, 0.40541000E-01, -.76640300E+00, -.10680300E-01, 0.46125100E+00, 0.45105900E-01, 0.39201900E-01, 0.28667700E-01, -.14201300E+00, 0.11046400E-01, -.12226500E+00, 0.65033200E+00, -.10659800E+00, 0.40051200E+00, -.65444800E-01, -.39033700E-01, 0.45280300E+00, 0.74788500E-01, 0.38467300E-01, -.15183400E+00, 0.84627500E-01, -.50660500E-01, 0.40258700E+00, -.32899900E+00, -.32479000E+00, -.89126200E-01, -.11683300E+00, 0.93195400E-01, -.13349500E+00, -.44851800E-01, -.91012900E-01, 0.23451200E-01, 0.11140300E-01, -.30790900E-02, 0.82453700E-01, -.29311600E+00, -.46361500E-01, -.26482000E+00, -.34225700E+00, -.75791100E-01, 0.56788100E-01, 0.45021000E-01, -.35274200E-01, -.92104800E-01, 0.92748100E-01, 0.67717900E-03, -.20457100E+00, -.77303000E-01, -.15785400E-01, 0.27767700E+00, 0.47477000E-01, -.42027500E+00, 0.50765200E-01, 0.12273800E+00, 0.10840900E-01, -.13185300E+00, -.67685300E-01, 0.38401800E-01, 0.31329800E-01, -.56846900E-01, 0.16868700E-01, 0.15228700E-01, 0.67790600E-01, 0.33538400E-02, -.83971000E+00, -.36181300E+00, 0.23190700E+00, -.46890400E-01, 0.65492400E-03, -.42121200E-01, 0.22087000E+00, -.15347200E-01, -.25309800E+00, 0.10787500E-01, 0.16561900E+00, -.43800700E-01, -.39698500E-01, -.84534800E-01, 0.50872300E-01, -.10355400E+00, -.37699100E+00, 0.58564300E+00, 0.15693500E+00, -.16796000E+00, -.14138000E+00, 0.19348700E+00, -.24488100E-01, -.17079000E-01, 0.23957400E+00, 0.10757200E+00, -.52299100E+00, -.36970800E-01, 0.98533600E-02, 0.21668700E+00, -.20759300E+00, 0.71462900E-03, -.20482800E-01, 0.15430000E+00, 0.82247800E-02, 0.22789700E-01, 0.10173000E+00, -.12885900E-01, 0.62067700E-02, 0.11449000E+00, -.17100800E-02, -.82777300E-02, -.42936300E-01, -.23506300E-01, 0.47714800E-01, -.18700400E-01, -.48950800E+01, -.83547500E-01, 0.23913000E+02, -.12460300E+02, -.12630100E+02, -.72552600E+01, -.96870200E+01, 0.60153200E+00, 0.10205500E+02, 0.77915900E+01, -.10178500E+02, -.72359100E+00, -.22612800E+00, -.49192700E+00, 0.40543700E+00, -.54716900E+00, 0.22807500E+00, 0.98611800E+00, 0.55316900E+00, 0.23870100E+00, -.14308100E+01, -.52981300E+00, 0.58342400E+00, 0.81752200E-01, -.29769100E+00, -.28068700E+00, -.15124000E+00, -.61971600E+00, 0.60966300E+00, -.22545500E+00, 0.38588900E+00, 0.38376200E+00, -.30077100E+00, 0.68131700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.33356300E+01, 0.79212700E+00, -.25344300E+01, -.18059700E+01, 0.18928300E+02, -.10542900E+00, -.17227700E+02, -.96964300E+01, -.32812800E+00, 0.18061300E+01, 0.59876100E+01, -.29233800E+01, 0.43482600E+01, -.33925700E+01, -.19643600E+01, 0.29892300E+01, 0.10555000E+01, 0.10593300E+00, -.19440200E+01, 0.18612700E+01, -.61381900E+01, -.42903500E+00, -.40709100E+00, 0.68037300E+00, -.13105200E+00, -.13671200E+01, 0.17327500E+01, 0.24922400E+00, 0.18709500E+01, -.22805000E+01, 0.77246500E+00, 0.67553100E-01, -.62238300E+00, -.37247400E+00, -.12078000E+01, -.18748700E+00, -.24114900E+00, 0.36830000E+00, 0.24416100E+00, -.42448400E-01, 0.69465100E+00, 0.36982500E+00, -.96134400E+00, -.45496400E+00, 0.12799800E+01, 0.22771100E+01, -.65797900E+00, 0.10742300E+01, -.18115200E+01, -.24855300E+01, -.42475000E-01, -.40124700E+00, -.76290800E+00, -.23981700E+01, -.47046300E+00, -.43246400E+00, -.21328200E+00, 0.39283800E+00, -.27249900E+00, 0.11772400E+01, -.31524400E+00, -.61833100E+00, 0.23993200E+00, -.99342100E+00, 0.14921800E+00, -.70494300E+00, -.41547000E+00, 0.39375600E+00, 0.86329600E+00, 0.38675800E+00, 0.84727800E+00, -.24347400E+00, -.85053700E+00, -.57240200E+00, 0.14943300E+01, -.72031900E-01, -.13520000E+00, -.95687000E+00, -.14879800E+00, -.11634200E+01, -.83465000E+00, 0.66282900E+00, 0.53735500E-01, 0.33565200E-01, 0.24539500E+00, -.87015200E+00, 0.44870300E-01, 0.22891300E+00, 0.86163800E+00, -.12473300E+01, 0.65129100E+00, -.74875500E-01, 0.32446100E+00, -.19344500E+01, -.24805000E+00, 0.31007500E+00, -.56304900E+00, 0.72446200E+00, -.88531600E-01, 0.21442200E+01, -.85577600E+00, -.37166800E+01, -.71551000E+00, -.16209000E+00, 0.57371800E-01, -.15909700E+00, -.12335900E+00, -.33925400E+00, 0.57684600E-01, 0.23912400E-01, -.35482500E-01, -.56334100E+00, -.42004400E+00, -.89867200E+00, -.77738100E+00, -.56746800E+00, -.77180000E-01, 0.50467100E+00, 0.50177200E-01, -.87652800E-01, -.32851600E+00, 0.22268500E+00, -.41081600E+00, -.71839900E+00, -.51810400E+00, 0.14807300E+01, -.28245900E-01, 0.90647400E-01, -.43323500E+00, 0.38319300E+00, -.57038600E-01, -.20701300E+00, -.34445400E+00, 0.35678400E-01, 0.65738400E-01, 0.41857000E+00, 0.45042600E-01, -.53126300E+00, -.52124700E-01, -.97484100E-01, -.44612400E+00, -.13030100E+01, -.11162400E+01, -.13131000E+01, -.87459800E+00, 0.29806300E-01, -.21657300E+00, 0.31046400E+00, 0.16063800E+00, 0.96431100E-01, 0.19130700E+00, 0.47533600E+00, -.28574800E-03, 0.16252000E+00, -.23824700E+00, 0.17008400E+00, -.17121300E+00, -.28463400E+00, 0.18491900E+01, -.29925700E+00, 0.11771000E+00, 0.10086400E+01, -.37558200E+00, -.61962200E-01, -.32556800E+00, -.87910300E+00, -.26762800E+00, -.31390600E+00, -.16714900E+00, 0.36686700E+00, -.24797000E+00, -.16254300E+00, 0.89405300E-01, -.25171500E+00, -.15653800E+01, 0.19696600E+00, 0.41312300E+00, 0.44394400E+01, 0.31104800E+00, -.10015300E+01, 0.93957900E+00, -.46832000E-01, -.47090100E+00, 0.15213500E+00, -.20483300E+00, -.69718700E+00, -.36655000E+00, 0.65155700E+00, 0.32862900E+02, -.80821200E+02, 0.39534500E+02, 0.37831000E+02, 0.40474600E+02, 0.60835800E+02, -.89378900E+01, -.16389300E+02, -.98881300E+02, 0.56955400E+02, 0.37216500E+01, 0.15348000E+01, 0.23960300E+01, -.38502600E+00, 0.47790700E+01, -.22689400E+01, 0.37259400E+01, -.56555900E+01, -.31344600E+02, -.23148900E+02, 0.40209900E+01, 0.97716800E-02, -.11409600E+01, 0.56301900E+01, 0.10607900E+01, -.95552200E+00, -.20684200E+02, -.46357200E+01, 0.53159000E+01, -.46960300E+00, -.14831900E+01, -.14369200E+02, 0.65235600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.40218700E+01, -.55979600E+00, 0.63745400E+01, 0.28465700E+01, -.14822200E+02, -.31487800E+00, 0.13523400E+02, 0.95165100E+01, 0.50034700E+00, -.23964500E+01, -.30618000E+01, 0.17248900E+01, -.28374800E+01, 0.31160600E+01, 0.20452100E+01, -.28664500E+01, -.12278200E+01, -.14925400E+00, 0.61258700E+00, -.14458500E+01, 0.35712300E+01, 0.31172100E+00, 0.87090000E-01, -.18972000E+00, -.35622400E+00, 0.11123800E+01, -.77117700E+00, 0.10127400E+00, -.29547600E+01, 0.28056800E+01, -.67106700E+00, 0.65404100E+00, -.56938100E+00, -.85873100E+00, 0.84875200E+00, -.93078900E+00, -.35198900E-01, 0.15074900E+00, -.25048900E+01, 0.11120500E+01, 0.13363800E+00, 0.12627600E+00, -.14026800E+01, 0.65946200E-01, 0.17108500E+00, -.11186200E+01, 0.45803400E+00, -.10624200E+00, 0.14504900E+00, 0.28402200E+01, 0.31041500E+00, 0.43686900E+00, 0.96442600E+00, 0.19773800E+01, 0.43485600E+00, 0.12332900E+01, 0.41682100E+00, -.83581700E+00, 0.36565200E-01, -.32377200E+00, 0.65896300E+00, -.67311300E+00, 0.13577200E+01, 0.81581700E+00, 0.60144500E+00, 0.10025500E+01, -.22045900E+00, -.13042200E-01, 0.70494400E-01, -.61274600E+00, -.40430300E+00, 0.32109200E-01, 0.35774200E+00, 0.33329000E+00, -.86923000E+00, -.61062000E+00, -.20023100E+00, 0.17947400E+01, 0.24183100E-01, 0.17736100E+01, 0.57595500E+00, 0.16862800E+00, 0.44539600E-01, -.10801500E+00, 0.70740500E+00, -.11055900E+01, -.38220800E+00, -.62962800E+00, 0.30290100E+00, 0.95656000E-03, 0.30009500E+00, -.75304800E+00, 0.22921100E+00, 0.87117100E+00, 0.60697400E-01, -.72779300E-01, -.83284300E-01, -.17263200E+00, -.43329800E-01, -.18344600E+01, 0.28967200E+00, 0.32572900E+01, 0.37642400E+00, -.16359500E+00, 0.15114100E+00, -.27667200E+00, 0.39939300E-02, 0.77195200E+00, 0.24205400E-01, 0.45889000E-02, -.11287900E-01, -.15972000E+01, 0.51898900E+00, 0.71035900E+00, 0.83933800E+00, 0.37177300E-01, -.91969100E-01, -.75746700E+00, 0.24829100E+00, 0.12208700E+00, 0.51401900E+00, -.21968800E-01, 0.13731700E+00, -.28114300E+00, -.99004800E-01, 0.12736200E+01, 0.14994200E+00, -.18925700E-01, 0.15146000E+01, 0.29400700E+00, -.31115500E+00, 0.42807000E-01, 0.33256400E+00, 0.31918300E+00, 0.18090500E+00, -.30655400E-01, 0.17719600E+00, 0.29014200E+00, -.15080400E+00, -.29411900E+00, -.21943600E-01, -.13481300E+01, -.16640900E+00, -.24724800E+00, 0.26105400E+00, -.39066300E-01, -.26335500E+00, -.39562000E+00, -.10301200E+00, -.63266400E+00, -.52756300E+00, -.18729900E+00, 0.25109600E+00, 0.51880600E+00, 0.10698700E+00, -.27439300E+00, -.12539000E+00, 0.30223100E+00, 0.12934000E+00, -.23188600E+01, 0.93114900E+00, -.73016400E+00, -.40136300E+00, 0.91769800E-01, 0.12430200E+01, -.61067200E+00, -.58493800E+00, -.12328900E+00, -.48609700E-01, 0.27680400E+00, 0.30091100E+00, -.34870200E+00, 0.68370100E-01, 0.89578100E-01, -.27767800E+00, 0.89057600E-01, -.14917900E+00, 0.28118200E-01, 0.31692500E+00, 0.95375600E+00, -.79930100E+00, 0.96497800E-02, 0.68501900E-01, -.57658700E+00, -.76826000E+00, -.43399100E+00, -.18266100E+00, 0.26785800E+01, 0.13184200E+00, -.82398800E+02, 0.44061300E+02, 0.48026600E+02, 0.37056800E+02, 0.60228500E+02, -.20326900E+02, -.51207400E+02, -.74591900E+02, 0.59377600E+02, -.19142700E+01, -.26058300E+01, -.20243000E+01, -.24309100E+01, 0.71551600E+01, 0.26266500E+01, 0.92343200E+01, -.71756500E+01, -.12178100E+02, 0.23409300E+01, -.12644000E+01, -.25058400E+01, -.74752700E+01, 0.54956800E+01, 0.37923500E+01, -.75561800E+01, 0.30853400E+01, -.47248400E+01, 0.54352100E+01, -.22849100E+01, 0.99875500E+00, 0.33971600E+01, -.25335600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.53110600E+01, 0.10307100E+01, -.39157200E+01, -.23697100E+01, 0.15344600E+02, 0.17564800E+00, -.16645500E+02, -.75951500E+01, -.93812200E+00, 0.13962700E+01, 0.49391300E+01, -.34053600E+01, 0.43434000E+01, -.36152000E+01, -.17817700E+01, 0.24291000E+01, 0.14715000E+01, -.69529400E-01, -.25976900E+01, 0.82736600E+00, -.86003600E+01, -.18111200E-01, -.31585400E+00, 0.65097000E+00, 0.94006200E+00, -.16510400E+01, 0.69055700E+00, 0.82807100E+00, 0.14049800E+01, -.21776500E+01, 0.14694300E+01, 0.13345600E+01, -.42805100E+00, -.87633000E+00, -.13317600E+01, 0.50975600E+00, 0.17810600E+00, 0.10068200E+01, -.70339600E-01, 0.44145500E+00, 0.18686400E+00, 0.33816400E+00, -.40403100E+00, -.29784900E+00, 0.13335400E+01, 0.14755700E+01, -.46973000E+00, 0.91386100E+00, -.12472500E+01, -.24386800E+01, -.13617100E-01, -.24289300E+00, -.10246600E+01, -.25190600E+01, -.10572100E+00, -.92248200E+00, -.26668000E+00, 0.47548500E+00, -.30814100E+00, 0.14611100E+01, -.80316300E-01, 0.26707900E+00, -.10620700E+01, -.28578600E+01, -.87998600E-01, -.43071200E+00, 0.92675200E+00, 0.30690100E+00, 0.29392900E+00, -.52077700E-01, 0.12721100E+01, -.39738500E+00, 0.70607000E+00, -.56226900E+00, 0.11279100E+01, 0.13140900E+01, -.81838900E+00, -.21879700E+01, 0.29168800E+00, -.10976600E+01, -.11076100E+01, 0.10102100E+01, 0.34205100E+00, -.27810600E+00, 0.20450400E+01, 0.87328200E-01, -.25749900E+00, -.77383600E+00, 0.39998200E+00, -.24850800E+01, 0.12777100E+01, 0.34081700E+00, 0.87229200E-01, 0.33155300E+01, -.88154400E+00, 0.10379900E+01, 0.46745000E+00, 0.12134800E+01, -.53825600E+00, 0.99127000E+00, 0.43967100E-01, 0.31645700E-01, -.42232800E+00, 0.10292300E+00, 0.30242800E+00, -.53149800E+00, -.63483800E-02, 0.27200900E+00, 0.14361900E+00, -.37476200E-01, -.41695300E+00, -.33493300E+00, -.95020000E+00, -.35659600E+00, -.14317000E+00, -.51990800E+00, 0.14947700E+00, 0.78095400E+00, -.17091800E+00, -.11976400E+00, -.40849200E+00, 0.40386700E+00, -.44365200E+00, -.19373700E+00, -.39420100E+00, 0.31643900E-01, 0.12568600E+01, 0.53406000E+00, -.19291600E+01, -.26125400E+00, 0.13741200E+00, 0.24801100E+00, -.16808600E+00, -.52789300E-01, -.18842100E+00, 0.15708400E+00, 0.91873800E-01, -.35177300E+00, 0.14370600E-01, -.17671800E+00, -.35706100E+00, -.73140600E+00, -.11984400E+01, 0.35956800E+00, -.40898500E+00, -.49738600E-01, -.39795800E-01, 0.47765800E+00, 0.23213800E+00, 0.75124600E-01, 0.32253600E+00, 0.28136700E+00, -.22908300E+00, -.46280000E+00, -.11562500E+00, -.41513600E-01, -.30445600E-01, 0.11744400E+01, -.12530600E+00, 0.69737200E+00, 0.27103100E+00, -.13283900E+01, 0.78491200E-01, 0.14243200E+00, 0.76046900E+00, -.53805800E+00, 0.16536900E+00, -.18546300E+01, -.43940900E+00, 0.20254500E+00, 0.67739300E+00, -.41470200E+00, 0.35826400E+00, -.31034200E+00, 0.15105300E+00, 0.21741200E+00, 0.42809400E-01, 0.27656800E+01, 0.35023100E+00, 0.27846400E+00, 0.14036200E+00, -.17880500E+00, -.22481300E+00, -.50537100E+00, 0.52832300E-01, -.31852500E+00, -.65386400E-01, 0.24829200E+01, 0.34155800E+00, 0.33453800E-01, 0.47546100E+02, 0.11171900E+01, 0.44509800E+00, 0.11269800E+02, -.10089400E+02, -.98664400E+00, -.16736600E+02, 0.10624700E+02, -.25668400E+00, 0.12620800E+01, -.34472300E+00, 0.95070300E+00, 0.80752400E+00, -.13226500E+01, 0.25815900E+01, -.93662800E+00, 0.54194100E+01, 0.10528400E+02, -.10489800E+00, 0.10281600E+01, -.27336000E+01, -.64669300E+00, 0.12173900E+00, -.12299400E+01, 0.14918500E+00, 0.15788100E-01, -.53241200E+00, 0.62747800E-01, -.22688200E+00, 0.44972400E+00, -.37665400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11788800E+02, -.21400100E+01, -.14747800E+02, -.58715700E+01, 0.31053600E+02, -.86416900E+00, -.31823900E+02, -.13381600E+02, 0.26635800E-01, 0.12188500E+01, 0.13002400E+02, -.53328600E+01, 0.72423700E+01, -.39953400E+01, -.26036700E+01, 0.58548600E+01, 0.15884700E+01, 0.14635500E+01, -.28653600E+00, 0.37130500E+01, -.49744200E+01, -.15486800E+01, 0.15033200E+01, 0.21028400E+01, 0.17234200E+01, -.14884700E+01, 0.12836400E+01, 0.68771000E+00, 0.94009300E+01, -.38972300E+01, 0.92756100E+00, -.39727300E+01, 0.17383000E+01, -.12242800E+01, -.31231100E+01, 0.28686600E+01, 0.11854000E+00, -.77273400E+00, -.25521900E+01, -.40906600E+01, -.12064900E+01, -.53821300E-01, -.25823700E+00, -.25509700E+00, 0.73822100E+01, 0.56697700E+01, -.20628600E+01, 0.31105600E+01, -.60947400E+01, -.18421200E+01, 0.25587300E+00, -.62108500E+00, -.16697100E+01, 0.98346300E+00, -.16745800E+01, 0.41146300E+01, 0.31394900E+00, 0.59192800E+00, -.14352400E+01, 0.11803000E+01, -.43182100E+00, -.22728200E+01, -.11360300E+00, 0.15311100E+01, -.26980900E+01, -.27070500E+01, 0.44433500E+00, 0.69074700E+00, 0.22830200E+01, 0.10698200E+01, 0.29785500E+01, -.15356800E+01, 0.52553400E+00, -.20684400E+01, 0.49030400E+01, 0.99185100E+00, -.10726900E+01, -.67579900E+01, 0.76934100E-01, -.22298100E+01, -.80054800E+00, 0.11447700E+01, 0.30400900E+00, -.14868100E+00, 0.15232900E+01, -.34366300E+01, -.17825900E+01, -.52813700E+00, 0.22719100E+00, -.65813500E+01, 0.46562400E-01, 0.34636000E-01, 0.14096000E+01, -.26108200E+01, 0.18584000E+01, 0.47094500E-01, -.56021100E+00, 0.20521500E+01, -.77012500E+00, -.34989000E+01, -.15620800E+01, 0.44367600E+01, -.25766200E+00, 0.13690300E+01, 0.13087800E+01, -.48970100E+00, 0.14934900E+00, -.14249400E+01, -.61448400E+00, 0.12293000E+00, 0.24297500E+00, 0.51787100E+01, -.22935000E+01, 0.37330600E+00, -.76376900E+00, -.55057000E+00, 0.15612900E+00, -.44066700E+00, 0.61094100E+00, 0.22542000E-01, 0.10248400E+01, 0.50221500E+00, 0.40918100E+00, -.89885800E+00, -.11440200E+01, 0.21764400E+01, -.21891700E+00, 0.48694600E-01, -.88975200E+00, -.40259800E+00, -.18642800E+01, -.70412200E+00, -.11223800E+00, 0.40737100E+00, -.96987300E+00, -.41977100E+00, 0.14525500E+00, 0.10694000E+01, -.16955200E+00, -.53316000E+00, 0.60815300E+00, -.38896400E+01, -.25055200E+01, 0.38025100E+01, 0.57608400E+00, -.12159700E+00, -.95930400E-01, -.41450000E+00, -.33803400E+00, -.96813100E+00, 0.71249500E-02, 0.62019300E+00, -.35566300E+00, -.56513200E+00, -.30049800E+00, -.72406300E-01, 0.49538600E-01, 0.16340500E+01, -.10248900E+01, 0.37002800E+01, -.63178400E+00, -.10500200E+01, 0.70144900E+00, -.80071200E-02, -.38865300E+00, 0.59702900E+00, 0.10830300E+01, -.23649000E+01, -.48664500E+00, 0.23668200E-01, 0.76368200E+00, -.81737400E+00, 0.15974200E+00, -.42626500E+00, 0.85078600E+00, 0.27134000E+00, -.44518400E-01, 0.27620900E+01, -.23345700E+00, -.11045800E+01, 0.12016300E+01, -.82533200E-01, -.25996200E+00, -.20700700E-01, -.80938500E+00, -.97679700E-01, -.53646300E+00, 0.59877100E+01, 0.85575200E+00, -.27018500E+00, 0.72998000E-03, 0.72809500E+01, -.30687900E+02, -.32233100E+02, 0.20141500E+02, -.39816400E+02, 0.63917500E+02, -.27638400E+02, -.24997700E+01, 0.56965600E-01, -.30214600E+01, 0.18947800E+00, -.22142700E+01, 0.16181100E-01, -.47865400E+01, 0.27624200E+01, 0.45969800E+02, 0.48039700E+02, -.27680800E+01, -.37684600E+00, -.44222100E+00, 0.25052900E+01, 0.15633700E+00, 0.29843100E+01, 0.53210300E+00, 0.64594400E+00, 0.28742000E+01, 0.31317100E+00, 0.30469900E+01, -.53227100E+00, -.16764500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.92416100E+01, -.10525600E+00, 0.73835200E+01, 0.36381400E+01, -.17218000E+02, -.13654800E+01, 0.23351900E+02, 0.13429300E+02, 0.59227700E+00, -.14370700E+01, -.77498500E+01, 0.71130500E+01, -.45223900E+01, 0.97670800E+01, 0.33566500E+01, -.22611000E+01, -.48400300E+01, 0.71174700E+00, 0.30668100E+01, -.38369200E+01, -.30465900E+00, -.27333400E+00, 0.29725600E+01, -.19991100E+01, -.37860600E+00, 0.27649400E+00, 0.31085100E+01, -.11189100E+01, -.30385400E+01, -.39832900E+00, -.56470200E+00, 0.27241200E+01, -.11440300E+01, 0.11763300E+01, 0.10966800E+01, 0.23721700E+01, 0.12122900E+00, 0.11558600E+01, -.28873100E+01, 0.10279800E+01, 0.35957300E+01, 0.38101200E+00, -.63975900E+01, -.16407400E+01, 0.23635700E+01, -.16461400E+00, 0.10728600E+01, -.37859300E+01, -.34085100E+01, 0.36377500E+01, 0.16275900E+00, 0.20967000E+00, -.10692700E+01, -.20879800E+01, -.80023300E+00, -.92674800E+00, 0.80566900E+00, -.37020500E+00, -.34362300E+00, 0.48994900E+00, 0.56913200E-01, 0.16074100E+01, -.87847300E+00, -.42468900E+01, 0.17287300E+01, 0.75584700E+00, 0.10295300E+01, 0.64053200E+00, 0.18234400E+01, 0.89321400E+00, -.22317500E+01, -.42320600E+00, -.14509000E+01, 0.15825000E+00, -.10053300E+01, -.16647000E+01, -.62993500E+00, -.64984000E+00, 0.32341900E+00, -.23572600E+00, 0.66357500E+00, -.15580700E+01, -.66557300E-01, 0.18388000E+00, -.19121400E+00, -.15854900E+01, 0.68290000E+00, 0.24269900E+01, -.22226200E+00, 0.74016000E+01, -.10764400E+01, 0.13074000E+01, -.17668400E+00, -.30283800E+01, 0.46859300E-01, -.20554100E+00, 0.28137300E+00, -.13050000E+01, 0.14409800E+00, 0.17659200E+01, 0.61750700E+00, -.19650000E+01, 0.10098600E+01, -.18991700E+01, -.99870300E+00, 0.80582400E+00, -.76895100E-01, 0.71156700E+00, -.39754100E+00, -.15232800E-01, 0.10075000E-01, 0.22005300E+01, -.45076100E+00, -.10308500E+01, -.47302100E+00, 0.27540100E+01, 0.16844100E+00, -.57835100E-01, -.60260200E+00, 0.45007600E-01, 0.77391500E+00, -.98053800E+00, -.87473600E+00, 0.50054400E-02, -.41274300E-01, 0.10887200E+01, -.88179700E+00, -.34756700E+00, 0.13809400E+01, -.10589900E+01, -.13229300E+01, -.15702000E+00, -.84903300E-01, -.64117600E+00, -.77000000E+00, -.60589100E+00, -.38207900E+00, -.85325900E-01, 0.33590200E+00, 0.14183900E+01, -.31778500E+00, -.35878300E+01, -.25671000E+01, 0.26046500E+01, -.99854400E+00, 0.10652900E-01, 0.29202900E+00, -.73032000E+00, -.28916400E+00, -.18713500E+00, 0.11679500E-01, 0.30962000E+00, -.10667200E+00, 0.15906300E+01, 0.14986400E-02, -.52343900E+00, 0.72790600E+00, 0.32161000E+01, -.38817600E+01, 0.41742200E+01, -.66442400E+00, 0.20697400E+01, 0.26083000E+00, -.20285600E+00, -.13919300E+01, 0.40719700E+00, 0.64699400E+00, 0.75356500E+00, 0.25814100E+00, -.56541800E+00, -.58593800E+00, 0.57685400E+00, -.13279800E+00, 0.44027300E+00, -.65573500E+00, -.27421500E+00, -.39777000E-01, -.22638900E+01, 0.92905200E-01, 0.18264100E+01, -.22051900E+01, 0.20788500E-01, 0.13454400E+00, 0.24089100E-01, 0.22394100E-01, 0.88219900E-01, 0.12020700E+00, -.12111900E+01, -.13468000E+01, -.10633300E+01, 0.96636500E-01, 0.68175900E+00, 0.76395100E+02, 0.10374400E+03, -.95569600E+02, -.12400100E+03, -.24496900E+03, 0.10126100E+03, 0.13445900E+01, -.24215000E+01, 0.35255200E+01, -.43402400E+01, 0.14699600E+02, 0.25865400E+01, 0.11173000E+02, -.15779300E+02, -.47654700E+02, -.17708900E+02, 0.31669500E+01, -.60944200E+01, -.70895900E+01, 0.11468300E+02, 0.46218400E+01, -.62780900E+01, 0.15110700E+01, -.92674200E+01, 0.10833300E+02, -.76768300E+01, -.33216300E+01, 0.38237500E+01, 0.12110400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15957200E+01, 0.50671500E+00, -.10186500E+01, -.80561000E+00, 0.90837400E+01, -.18068200E-01, -.93474300E+01, -.51989000E+01, -.40383300E+00, 0.61719900E+00, 0.25738600E+01, -.14020900E+01, 0.22811400E+01, -.21569000E+01, -.58541400E+00, 0.12871600E+01, 0.42091400E+00, -.23130700E+00, -.16306400E+01, 0.56741100E+00, -.46006200E+01, 0.12637000E+00, -.49109200E+00, 0.31372700E+00, 0.61830300E+00, -.81929800E+00, 0.70972700E-01, 0.38387800E+00, 0.52903300E+00, -.79382600E+00, 0.66225500E+00, 0.65353600E+00, -.13264600E+00, -.37882300E+00, -.65904800E+00, 0.12742400E+00, 0.68248500E-01, 0.47072000E+00, 0.12726100E+00, 0.94701500E+00, 0.80919900E+00, 0.25881900E+00, -.77819500E+00, -.11433600E+00, 0.73255100E+00, 0.10374600E+01, -.40654000E-01, 0.12139100E+00, -.22053800E+01, -.58101100E+00, 0.21248700E-01, -.24237800E+00, -.87119000E+00, -.23232200E+01, -.43829800E+00, -.27336500E+00, -.22386900E+00, 0.29518600E+00, -.39498800E+00, 0.80491600E+00, 0.16078400E+00, 0.13438200E+01, -.96636800E+00, -.35904100E+01, 0.76891600E+00, 0.52778500E-02, 0.13033300E+01, -.29848300E-01, -.20655300E+00, 0.12236100E+00, 0.76195000E+00, 0.77872300E-01, 0.62936500E+00, -.21219600E+00, 0.53964800E+00, 0.67165500E+00, -.22524200E+00, -.48655900E+00, -.96301400E-02, -.10885800E+00, -.59757600E+00, 0.16222600E+00, 0.12487900E+00, -.92214400E-01, 0.12050400E+01, -.31266000E+00, -.60978600E-01, -.63357900E-01, -.45659300E+00, -.73994800E+00, 0.26042900E+00, 0.14636000E+00, 0.76375300E-01, 0.13786600E+01, -.53634500E+00, 0.32541900E+00, 0.52278100E+00, 0.73112200E+00, -.24036600E+00, -.28601900E+00, 0.32049500E+00, 0.11104000E+01, -.27669100E+00, 0.96029200E+00, 0.95078600E-01, -.18175700E+00, 0.52940700E-01, -.18853200E+00, 0.13689000E+00, -.40724300E-01, -.21999300E+00, -.23189100E+01, 0.83537100E+00, -.15243700E+00, 0.51642700E+00, 0.43011300E+00, 0.29204000E+00, 0.58910600E+00, -.76093600E-01, -.18419900E-01, -.20379900E+00, -.28950700E+00, -.16114500E+00, -.12822800E+00, 0.13239000E+00, -.30281600E+00, 0.31523000E+00, 0.18460700E+00, 0.34294200E-01, 0.36663700E-01, 0.94554800E+00, 0.45707900E+00, -.29175000E+00, 0.31697900E+00, -.23741900E-01, 0.43209100E-02, 0.21207900E+00, -.40504200E+00, 0.10776000E+00, -.77721400E+00, 0.17053600E+00, 0.13283200E+01, 0.65584100E+00, -.87098000E+00, 0.26736800E+00, 0.23840200E-01, 0.65295800E-01, -.73481700E-01, 0.15205300E+00, 0.16459000E+00, 0.13447400E+00, -.24180800E+00, -.24158500E-01, 0.11271000E+00, 0.14899600E+00, -.10693700E+00, -.90706500E-01, -.20139500E+00, -.27057900E+00, -.63125900E+00, 0.11524500E+00, -.47330400E+00, -.80783100E-02, 0.41366200E-01, 0.41270400E+00, -.88018600E+00, -.35821600E-01, 0.31124600E-01, -.39485200E-01, -.14959000E+00, 0.15568100E+00, 0.19280100E+00, 0.28614700E-01, 0.10247800E+00, 0.54126000E+00, 0.23033800E-02, 0.10273500E+00, -.46855400E+00, -.25957600E+00, -.17965900E+00, 0.29270200E+00, -.48737500E-02, 0.53647200E-01, -.30685600E-01, -.10412200E+00, 0.11028200E+00, 0.43454800E-02, 0.79626500E+00, 0.10853900E+00, 0.29952700E+00, 0.67338000E-02, 0.45609000E-03, -.17938000E+00, 0.11185600E+02, -.38920500E+01, 0.35263000E+01, -.91277300E+01, 0.88537500E+01, 0.39280500E+00, 0.17411300E+01, 0.15122200E+01, 0.13377800E+01, 0.10541100E+01, -.17561300E+01, -.11444200E+01, -.12120500E+01, -.11008100E+02, -.10432800E+02, 0.22029700E+01, 0.10984800E+01, 0.11389800E+01, -.80767800E+00, -.67775100E+00, 0.15111200E+01, -.11754000E+01, 0.18356200E+00, -.80888400E+00, 0.21338700E+00, -.13593500E+01, -.11450400E+01, 0.47294100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.26486000E+02, -.29070200E+01, 0.24251500E+02, 0.12124400E+02, -.64149100E+02, 0.24557200E+00, 0.68792100E+02, 0.29854100E+02, -.66248900E+00, -.40864900E+01, -.24527500E+02, 0.14196800E+02, -.15863600E+02, 0.17730000E+02, 0.69644400E+01, -.93820100E+01, -.43152100E+01, -.12977000E+00, 0.82041700E+01, -.65249600E+01, 0.23104100E+02, 0.30594000E+01, -.70772200E+00, -.36092500E+01, -.52359800E+00, 0.56820500E+01, -.23569200E+01, -.96268700E+00, -.11130700E+02, 0.10536900E+02, -.26335200E+01, -.12548800E+01, -.79503100E+00, -.42771000E+00, 0.50809800E+01, 0.57798400E-01, -.28219700E-01, -.53022900E-01, 0.18082500E+01, 0.14186200E+01, -.45209600E+01, -.96961900E+00, 0.60512500E+01, 0.29481700E+01, -.10802100E+02, -.84212200E+01, 0.24511500E+01, -.11099000E+01, 0.13965700E+02, 0.67191200E+01, -.91250300E+00, 0.98634900E+00, 0.31816100E+01, 0.77431300E+01, 0.23493800E+01, -.34825700E+01, 0.54791400E+00, -.18353300E+01, 0.20931500E+01, -.64486600E+00, 0.15059200E+01, 0.20909800E+01, -.11468900E+01, -.15357200E+01, 0.79871400E+00, 0.36254800E+01, 0.34351800E+01, -.10648500E+01, -.19149400E+01, -.31185600E+01, -.19283700E+01, 0.11529400E+01, 0.48090100E+01, 0.19150600E+01, -.56430500E+01, 0.53953300E+00, 0.58550600E+00, 0.47606100E+01, 0.11508400E+01, 0.94334800E+00, 0.15009200E+01, -.11680400E+01, 0.13523200E-01, 0.68744000E-01, -.64122700E+00, -.51619900E+01, -.13505600E+01, -.37704000E-01, -.26062700E+01, -.87855000E+00, -.50826200E+00, -.63930600E+00, 0.64387500E-01, -.18293600E+00, 0.21858800E+01, 0.11040100E+00, 0.11500800E+00, -.19787700E+01, 0.66413600E+00, -.52982000E+01, 0.12846300E+01, 0.65328200E+01, 0.15646700E+01, 0.17415500E+01, -.63129400E+00, 0.74839300E+00, 0.12933000E+00, 0.15735300E+01, -.34256200E+00, -.64756000E-01, 0.16679900E+00, 0.16786500E+01, 0.25337900E+01, 0.83747600E+00, 0.15535800E+01, 0.46316800E+01, 0.72738100E+00, 0.56716800E+00, -.33534900E+00, 0.18078600E+00, 0.96568400E+00, -.26329100E+01, 0.27560300E+00, 0.22565800E+01, 0.17413900E+01, -.32996400E+01, -.15708700E+01, -.32599800E+00, 0.28423100E+01, -.14573200E+01, -.37429400E+01, 0.17153600E+01, 0.25641000E+01, 0.68337800E+00, -.10318600E+00, -.18914700E+01, 0.10259600E+01, 0.20666100E+01, 0.22705700E+00, -.16809600E+01, 0.12097100E+01, 0.30433700E+01, 0.27264200E+01, 0.17500900E+01, 0.47543700E+01, -.12409800E+00, 0.31759300E+00, -.26110500E+01, -.13583000E+01, -.35365300E+00, -.16609800E+00, -.10532200E+01, 0.69474000E+00, 0.67285300E+00, 0.52092800E+00, -.51166500E+00, 0.31638600E+00, -.15380500E+01, -.28244100E-01, -.12525500E+01, 0.27217200E-01, 0.12879600E+00, 0.77970100E+00, 0.26438000E+00, 0.21917300E+01, 0.11905200E+01, -.10590300E+00, 0.46111400E+01, 0.10804400E+01, -.47548300E+00, 0.46451500E+00, 0.17467800E+00, -.25150100E-01, 0.13089300E+01, 0.20408900E+01, -.61028200E+00, -.93473800E+00, -.84183300E+01, -.11950900E+01, 0.14542400E+01, -.40577500E+00, 0.23173000E+00, 0.11671500E+01, 0.28400500E+00, -.23052000E+01, 0.69061000E+00, -.42995400E-01, -.27253200E+01, -.15739500E+01, 0.35341000E+01, -.16081600E+00, -.25193700E+01, -.17480400E+01, -.95380500E+00, -.27558800E+02, -.28158800E+03, -.80952200E+02, 0.22061000E+02, 0.18781200E+01, 0.60922200E+01, 0.26145600E+01, -.11418300E+02, 0.18557500E+01, -.49027700E+01, -.27681600E+02, -.36439700E+01, 0.72377900E+02, 0.98522600E+02, 0.81256400E+01, -.16978000E+02, 0.13097100E+02, 0.15250400E+02, -.34923800E+01, 0.23445300E+02, -.64167400E+01, -.22019200E+01, 0.15111900E+02, -.12042000E+02, -.28507900E+01, -.73721000E+01, -.26169700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10649100E+02, -.85311500E+00, 0.80213300E+01, 0.48976700E+01, -.34219200E+02, -.41967700E+00, 0.35123600E+02, 0.16520800E+02, 0.16117300E+01, -.26646200E+01, -.13726400E+02, 0.72751200E+01, -.88498400E+01, 0.80123100E+01, 0.39458900E+01, -.55719200E+01, -.24613500E+01, -.16357200E+00, 0.43966300E+01, -.30272600E+01, 0.14969300E+02, 0.45930700E+00, 0.38893000E+00, -.16602300E+01, -.19952400E+01, 0.30864400E+01, -.17850800E+01, -.84150400E+00, -.68504000E+01, 0.48443700E+01, -.18948900E+01, -.39378300E+00, -.43993300E-01, 0.10452700E+01, 0.29739300E+01, -.11005400E+01, -.33121800E+00, -.68574200E+00, -.24369500E+00, 0.18507800E+00, -.10406100E+01, -.49494100E+00, 0.45656100E+00, 0.81156500E+00, -.38799000E+01, -.36076600E+01, 0.11573900E+01, -.14314000E+01, 0.46298500E+01, 0.55112900E+01, -.26306700E+00, 0.68909900E+00, 0.17761500E+01, 0.41860900E+01, 0.38821900E+00, -.86295700E+00, 0.38368800E+00, -.11219400E+01, 0.12982000E+01, -.21344600E+01, 0.29745200E+00, -.14284400E+00, 0.19067600E+01, 0.27256900E+01, 0.10205300E+01, 0.12539200E+01, -.10481400E+01, -.54451400E+00, -.67821300E+00, 0.11415700E-01, -.19529600E+01, 0.85575400E+00, -.13286300E+01, 0.96715800E+00, -.21512900E+01, -.19248700E+01, 0.16373200E+01, 0.43782600E+01, -.44038500E+00, 0.18484800E+01, 0.19016500E+01, -.21047400E+01, -.35232300E+00, 0.28171100E+00, -.39309700E+01, -.34917900E+00, 0.23919300E-01, 0.10129300E+01, -.34526600E+00, 0.19382900E+01, -.19226400E+01, 0.22516600E+00, -.17504200E+00, -.24036500E+01, 0.18784400E+01, -.70002100E+00, -.13946800E+00, -.14223600E+01, 0.55754400E+00, -.27540400E+01, -.14524800E+00, 0.11682900E+01, 0.38328500E+00, 0.95870900E-01, -.36557400E+00, 0.79202400E+00, 0.34900200E+00, 0.53779500E+00, -.74186100E-01, 0.11773900E-02, 0.62315400E+00, 0.41606600E+00, 0.54452000E+00, 0.12259900E+01, 0.18723800E+00, -.18827100E+00, -.28280100E+00, -.18322000E+01, 0.67517200E+00, 0.26405600E+00, 0.10347100E+01, 0.18756400E+00, 0.10794400E+01, -.21379500E+00, 0.13030600E+00, 0.71738400E+00, -.26056800E+01, -.28911200E+00, 0.21382600E+01, -.26020000E+00, -.90072500E+00, -.17210900E+01, 0.98055900E+00, -.83430400E+00, 0.59182300E+00, -.30313800E+00, -.49820700E+00, 0.11141200E+01, -.17219000E+00, 0.12510100E+01, 0.53106400E+00, 0.63664400E+00, 0.17595900E+01, 0.24663500E+00, 0.38597100E+00, -.89852700E-01, -.20741200E-01, -.14376500E+01, -.71766600E+00, -.33018800E+00, -.47107700E+00, 0.39353100E+00, -.93196400E-02, 0.15610300E+01, -.47451800E-01, 0.38044600E-02, 0.38622200E+00, -.14733200E+01, -.31941200E+00, 0.29658500E+01, -.16674400E+01, 0.37903400E+01, 0.22732700E+00, -.32731800E+00, -.35117000E+01, 0.37838800E+01, 0.25582900E+00, 0.30004000E+01, 0.84048400E+00, -.54698900E+00, -.12248700E+01, -.16712100E+00, -.30727900E+00, 0.83491400E+00, -.69840700E+00, -.70243700E+00, 0.41363900E+00, -.29203800E+01, -.76957600E+00, -.31210100E+00, -.30649800E+00, 0.91534100E-01, 0.19022800E+00, 0.92603900E+00, 0.25460800E+00, 0.34055600E+00, 0.72748200E-01, -.59182000E+01, -.60810100E+00, -.52726200E+00, -.35121200E-01, 0.19306900E+00, 0.24132800E+00, -.16777900E+01, -.38996600E+00, -.10647200E+03, -.45597500E+01, 0.65682900E+01, 0.10039300E+01, 0.29102800E+01, 0.25495100E+01, -.40162200E+01, 0.12800600E+01, -.24025700E+01, -.16476200E+02, -.23051000E+01, 0.67992600E+01, 0.90626200E+01, 0.61032700E+01, -.62927300E+01, 0.10977600E+02, 0.62313000E+01, -.28078800E+01, 0.13741600E+02, -.47257600E+01, -.57304500E+00, 0.60709900E+01, -.42274200E+01, -.26242500E+01, -.53081500E+01, -.10395200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13009400E+02, -.17432800E+01, 0.12281200E+02, 0.59932200E+01, -.38736800E+02, -.22543000E+00, 0.39701700E+02, 0.20020700E+02, 0.36902300E+00, -.31622600E+01, -.14252600E+02, 0.83746200E+01, -.88237800E+01, 0.10745600E+02, 0.46464400E+01, -.74130600E+01, -.14771200E+01, 0.44480300E+00, 0.57420200E+01, -.27389400E+01, 0.15265900E+02, 0.21813800E+01, 0.37378300E+00, -.32020900E+00, 0.11694600E+00, 0.38452200E+01, -.41988500E+01, 0.78560900E-02, -.35829700E+01, 0.67605900E+01, -.12725100E+01, 0.13024800E+01, -.48883200E-01, 0.23404800E+00, 0.24096300E+01, 0.24378300E+00, 0.10159500E+01, -.88899800E+00, -.59432700E+01, -.57272300E+00, -.61772500E+01, -.10242300E+01, 0.39488400E+01, 0.25038600E+01, -.11071900E+01, -.58607700E+01, 0.13230500E+01, -.93809600E+00, 0.63254700E+01, 0.88062600E+01, -.12617700E+00, 0.16599600E+01, 0.48629200E+00, 0.38460600E+01, 0.21824200E+01, -.29290000E+01, 0.47774800E+00, -.99284400E+00, 0.12392500E+01, -.44771500E+00, 0.16597900E+01, 0.31570700E+01, -.19375100E+01, -.69401300E+01, -.51166200E+00, 0.65339300E+00, 0.33266200E+01, -.74943800E+00, -.72758100E+00, -.15928500E+01, -.33048300E+01, -.68370900E-01, 0.10829700E+01, 0.13699900E+01, -.28498400E+01, 0.38134600E+01, 0.17296100E+00, 0.11620700E+01, 0.56910800E+00, 0.11022000E+02, 0.19171400E+01, -.15829300E+01, 0.51416200E+00, -.11109400E+01, 0.12742800E+01, 0.23788200E+00, -.21053200E+01, -.30017000E+01, 0.13156900E+01, -.29846200E+01, 0.18982100E+01, -.16001200E+01, 0.23120000E+00, 0.47855600E+01, -.26760400E+01, -.15973600E+00, 0.15476800E+01, 0.88710600E+00, -.13430700E+00, -.18312300E+01, 0.29246300E-03, 0.35467000E+01, -.21791600E+01, -.17225400E+01, 0.12074600E+00, -.19200100E+01, 0.45784600E+00, -.27907700E+00, 0.10302600E+00, -.56400100E-01, -.52627000E-01, 0.34154300E+01, -.17888200E+01, 0.11543100E+01, -.58582000E+00, -.26061900E+01, -.31819200E+00, -.18482700E+01, -.45560900E+00, 0.17303700E+00, -.22730100E+00, -.50143500E+00, -.25577100E+00, -.86487800E+00, 0.74268700E-01, -.24368700E+01, -.10012500E+01, 0.96628200E+00, -.53206600E+01, -.14314900E+01, 0.25228700E+01, -.24392700E+01, -.24534600E+01, -.28999200E+01, -.19515100E+01, 0.32648000E+00, -.19623300E-01, -.19405800E+01, 0.72380100E+00, 0.21781300E+01, -.13969500E+01, -.30501000E+01, -.19017500E+01, 0.18591500E+01, -.16036700E+01, 0.23504000E+00, 0.34149200E+00, 0.14588700E+01, 0.98343000E+00, 0.24708200E+01, 0.14163000E+01, 0.12376700E+01, 0.45659600E+00, -.31182300E+00, -.71001700E+00, 0.82221400E+00, -.25454400E+00, -.98677200E-01, 0.16828400E+01, -.69916000E+00, 0.21995700E+00, -.15616200E+01, -.54448300E+00, -.48166200E-01, -.10635700E+01, 0.39789100E+01, -.49513600E+00, -.86478300E+00, 0.24780600E+00, 0.48054700E+00, -.37921100E+00, -.13064800E+01, -.18015800E-01, -.72190100E+00, 0.94254600E+00, 0.17677600E+00, -.17377800E+01, -.65722800E+01, 0.92917200E+00, 0.25339200E+00, -.13345600E+01, -.76260300E-01, -.84623900E+00, 0.39262400E+00, -.67421200E+00, -.11371100E+01, 0.24538300E+00, -.48497700E+01, -.49793100E+00, 0.28261400E+00, 0.79618300E-01, -.11059300E+01, 0.57115100E-01, 0.17432200E+01, -.24224600E+00, 0.94381500E+00, -.74512500E+02, -.18304500E+01, -.84127200E+00, -.40104000E+01, -.21478100E+01, -.21332600E+01, -.78915100E+00, 0.38763000E+01, 0.20954500E+02, 0.29039800E+01, 0.42452600E+02, 0.58703200E+02, -.78051400E+01, 0.27362000E+01, -.14159900E+02, 0.56407000E+00, 0.33743300E+01, -.18754200E+02, 0.52392700E+01, -.10168300E+01, 0.52577300E+00, 0.25670800E+01, 0.31711600E+01, 0.58233900E+01, 0.18754400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18952900E+01, 0.36631200E+00, -.10000100E+01, -.87084700E+00, 0.89077700E+01, -.70780400E-01, -.10031700E+02, -.51835700E+01, 0.11615400E+00, 0.38189100E+00, 0.31636300E+01, -.14419300E+01, 0.25489600E+01, -.18763700E+01, -.70756900E+00, 0.12152100E+01, 0.53120100E+00, -.23135500E-01, -.15698700E+01, 0.10454900E+01, -.49090300E+01, -.12983100E+00, -.28433000E+00, 0.51823100E+00, 0.54846700E+00, -.94262200E+00, -.94522800E+00, 0.45895000E+00, 0.89590200E+00, -.11246600E+01, 0.86600400E+00, 0.55085100E+00, -.35128400E+00, -.35632200E+00, -.54832500E-01, -.77156800E+00, 0.13422300E+00, 0.22007000E+00, 0.84483000E+00, 0.10543600E+01, 0.69276500E+00, 0.25313600E+00, -.11347300E+00, 0.26241000E-01, -.51471000E-01, 0.70423300E+00, -.16798400E-01, 0.13249900E+00, -.14683300E+01, -.13767900E+01, 0.67933800E-06, -.20608100E+00, -.63736400E+00, -.30867300E+01, -.40812900E+00, -.12195900E+01, -.36510300E+00, 0.36759500E+00, -.33335500E+00, 0.76828700E+00, 0.20203300E+00, 0.22554500E+01, -.14493800E+01, -.55398300E+01, 0.10712400E+01, 0.35874900E-01, 0.20676000E+01, -.32926800E+00, -.85733900E+00, 0.20239200E+00, 0.16571500E+01, 0.19757300E+00, 0.10442200E+01, -.24653100E+00, 0.47106500E+00, 0.12014200E+01, -.11071600E+00, -.76993400E+00, -.56221900E-01, 0.41029500E+00, -.51381400E+00, -.40994700E+00, 0.83320800E-01, -.14426200E+00, 0.13962400E+01, -.47454700E+00, -.20343700E+00, -.30020100E+00, -.24952700E+00, -.16140000E+01, 0.13465300E+00, -.10465900E+00, 0.21905200E+00, 0.44413100E+00, -.10291800E+00, 0.23191300E+00, 0.34685100E+00, 0.10887300E+01, -.15293200E+00, -.41419300E-02, -.16124500E+00, 0.62433800E-01, -.47087400E+00, 0.12141300E+01, 0.11464600E+00, -.88928700E-01, 0.74208800E-01, -.50977300E+00, -.16176000E-02, -.26171400E-01, -.16621500E+00, -.26579700E+00, 0.25230800E+00, -.37622300E+00, 0.21272300E+00, 0.28106700E+00, 0.28513000E+00, 0.58918700E+00, -.16916200E+00, -.36215000E-01, -.24443100E+00, 0.45267100E-01, -.23111300E+00, 0.19783300E+00, -.20299300E+00, 0.17041900E+00, 0.17452600E+00, 0.19094700E+00, -.32106800E+00, 0.62982400E-01, 0.16752500E+00, 0.26152200E+00, -.24760300E+00, 0.15723700E+00, -.30268800E+00, 0.19722600E-01, 0.17495300E+00, -.37603400E+00, 0.96638800E-01, -.27206200E+00, -.27064100E-01, 0.71251600E+00, -.19965500E+00, -.14713500E+00, -.19127800E+00, 0.46311200E-01, 0.65836900E-01, 0.18404000E+00, 0.34601700E+00, 0.61620800E+00, 0.19976800E+00, -.17808700E+00, -.24357800E-02, -.17789600E+00, 0.84853500E-01, -.83002200E-01, -.56882900E-01, -.42222000E+00, -.66921400E+00, -.23088000E+00, 0.35942500E-01, -.44407200E+00, -.60513100E-01, -.17395100E-02, 0.29067000E+00, -.11192500E+01, -.34587900E-01, 0.18829200E-01, -.10042700E+00, -.19107200E+00, -.18624500E+00, -.15021300E-01, 0.22263700E-01, 0.52673000E-01, 0.17516200E+00, -.32780100E-01, 0.40417500E+00, 0.15521400E+01, -.13246500E+00, -.19637500E-01, -.81914100E+00, -.50070000E-01, 0.78950400E-03, -.13630100E+00, -.10258400E+00, -.80951000E-01, -.10130400E-01, 0.81238000E+00, 0.24632700E+00, -.20285900E+00, 0.55244100E-01, 0.29841500E+00, 0.10347900E+00, 0.86918600E+00, -.78572700E-01, -.77176000E-01, -.31351400E-02, 0.50946000E+01, 0.40709900E+00, 0.13039200E+01, 0.16204800E+00, -.65169800E+00, -.11910300E+01, -.10940700E+01, -.29769800E+00, 0.96688400E+00, 0.99274600E+01, 0.11243500E+02, 0.40057800E+00, -.90662000E+00, 0.19440300E+00, -.62819700E+00, -.92955900E+00, 0.90847500E+00, -.15865700E+00, 0.76787800E+00, -.59397200E+00, -.59292800E+00, -.45884100E+00, -.36137000E+00, 0.77061800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10303400E+01, -.93865800E+00, -.81359500E+00, 0.62277100E+00, -.11108500E+02, 0.56773100E+00, 0.97623300E+01, 0.53960600E+01, 0.12474200E+00, -.96283400E+00, -.28904700E+01, 0.15199100E+01, -.26237600E+01, 0.15854300E+01, 0.11888200E+01, -.16419800E+01, -.64248400E+00, -.12617500E-01, 0.13001800E+01, -.17830700E+01, 0.42331400E+01, 0.36505700E+00, 0.43618900E+00, -.80326600E+00, 0.14302200E+01, 0.89641100E+00, -.25533900E+01, -.32865800E+00, 0.72385800E+00, 0.10839800E+01, -.69602400E+00, -.12370600E+01, 0.12358300E+01, 0.33981900E+00, 0.70026000E+00, -.72439200E+00, 0.22540400E+00, -.56665600E+00, 0.59399700E+00, -.59138600E+00, -.52600600E+00, -.20483800E+00, 0.13089700E+01, 0.76599900E+00, -.54111700E+00, -.27995200E+00, -.65285700E-01, 0.47830900E+00, 0.14240900E+01, -.22031100E+00, -.24975800E-01, -.17481300E+00, 0.12312300E+01, 0.31593800E+01, -.48456700E-01, 0.16854500E+01, 0.15569900E+00, -.41044800E+00, 0.10802800E-01, -.36566100E+00, 0.72386200E+00, -.96786900E+00, 0.66015000E+00, 0.31450000E+01, -.10181700E+01, -.24784500E-01, -.35938700E+00, 0.21953400E+00, 0.46986600E+00, -.36557600E+00, -.10557200E+01, -.41177700E+00, 0.72440200E+00, 0.32427700E-01, -.42593800E+00, -.81522700E+00, -.25994700E+00, 0.69506600E+00, 0.10693600E+00, 0.54759800E-01, 0.38630800E+00, 0.54395400E+00, -.20768400E-02, 0.84166600E-01, -.21445000E+00, 0.67638000E+00, -.23682400E+00, -.59221100E+00, 0.12917100E+00, 0.24326400E+00, 0.28696100E-01, -.15104500E+00, -.18330800E+00, 0.16368900E+01, 0.23594200E+00, 0.61236500E-01, 0.17408500E+00, -.41102000E+00, -.19321400E-02, -.13593100E+01, 0.62829100E+00, 0.82872500E+00, 0.78383100E-01, 0.42186500E+00, -.81131900E-01, 0.13288100E+00, 0.13665600E+00, 0.28204400E+00, -.74865300E-01, -.18943800E-01, -.11279700E-01, -.18052300E+00, 0.10517900E+00, 0.45784400E+00, 0.28815800E+00, 0.32557200E+00, 0.68639200E-01, -.34261600E+00, -.10994400E-01, 0.53442100E-01, 0.25894300E+00, -.37097300E+00, 0.11440500E+00, -.88227000E-01, 0.11765000E+00, 0.10323300E+00, -.51482000E+00, -.61609300E-01, 0.49709200E+00, -.13826100E+00, -.27849300E+00, -.12941600E+00, 0.37193300E+00, 0.45283400E-01, 0.11071800E+00, -.26889200E-02, -.49571100E-01, 0.26826200E+00, -.90112500E-01, 0.31050600E+00, -.13555200E+00, -.32287500E+00, -.36527200E+00, 0.43644800E+00, -.11218700E+00, -.92468000E-02, -.46200600E-01, -.26982000E+00, 0.88850400E-01, 0.38378700E+00, -.12674600E+00, -.55467600E-01, 0.21522700E+00, -.38911600E-01, -.10387900E-01, 0.27154600E-01, -.31378500E-01, -.88815500E-01, 0.59315900E+00, -.48438000E+00, 0.20884000E+00, 0.25447400E+00, -.52335700E-01, 0.11877200E-01, 0.19954100E+00, -.32697600E+00, 0.40337900E-02, 0.28105000E+00, -.33629500E-01, 0.75983200E-01, -.14379000E+00, 0.18227700E-01, -.22872500E-01, -.46474900E-01, -.26764600E+00, -.24950700E-01, 0.23526300E-01, 0.76127300E+00, 0.17930000E+00, 0.42475700E+00, -.25242100E-01, 0.31916000E-02, 0.32252200E-01, -.34701000E-01, 0.10315400E+00, -.92215800E-01, -.24711300E-01, -.45577000E+00, 0.35327600E-01, 0.35741300E-01, -.10454600E-01, -.27164200E-01, -.26057600E-01, -.11545400E+00, 0.27024200E-01, 0.24863800E-01, -.48513400E-01, -.83176000E-01, -.18627300E+01, -.21771400E+01, -.34795400E+00, -.10650800E+01, 0.12325200E+01, 0.23038600E+01, 0.23125900E+01, -.11341300E+01, 0.27764800E+01, 0.40217400E+01, -.13697800E+01, -.69579400E+00, -.16211400E+01, 0.58190900E+01, 0.11224900E+01, -.19289000E+01, 0.15858400E+01, -.66536000E+00, 0.57104500E+01, -.37790600E+00, 0.10708700E+01, 0.18181100E+01, -.11277100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20526400E+01, -.10925200E+01, 0.92506200E+00, 0.10800000E+01, -.13136900E+02, 0.20343600E+00, 0.10676300E+02, 0.61789500E+01, 0.14170000E+01, -.11981400E+01, -.39308400E+01, 0.21164800E+01, -.27465500E+01, 0.21527300E+01, 0.13728300E+01, -.24892900E+01, -.36508200E+00, 0.38299800E+00, 0.15231000E+01, -.35798200E+00, 0.35845000E+01, -.26650800E+00, 0.78626400E+00, 0.12237800E+00, 0.42750600E+00, 0.79580700E+00, -.14322600E+01, -.11570900E+00, -.28401200E+00, 0.11845100E+01, -.40722900E+00, -.54906500E+00, 0.45618000E+00, 0.18443900E+00, 0.94820700E+00, -.39610500E+00, 0.10893600E+00, -.37195800E+00, 0.14434700E+00, 0.40052200E-01, -.93752600E+00, -.15409400E+00, 0.90829600E+00, 0.56692300E+00, -.16799900E+01, -.10935600E+01, 0.22169100E-02, 0.60445400E+00, 0.27065900E+01, 0.24843800E+00, -.13401300E+00, 0.14780800E+00, 0.92638000E+00, 0.15082400E+01, 0.14493500E+00, -.34975800E+00, 0.34983100E-01, -.35887000E+00, 0.34221000E+00, -.53675600E+00, 0.52625900E+00, -.53200900E+00, 0.72508400E+00, 0.18147500E+01, -.55577700E+00, 0.10489200E+00, -.10522500E+00, -.39038000E-01, 0.79878800E-01, 0.69577600E-01, -.63294100E+00, -.22446800E+00, 0.25806800E+00, 0.11850700E+00, -.48869100E+00, -.15327700E+00, -.10458100E+00, 0.39881700E+00, -.19514800E-01, 0.26160700E+00, 0.68276400E+00, -.11877200E+00, -.24724300E-01, 0.39753300E-01, -.43047100E+00, -.55236000E+00, -.26344100E+00, 0.36234400E-01, -.33818800E+00, -.18013800E+00, -.24132800E+00, -.12766000E+00, -.84340900E-01, 0.71106100E+00, 0.68104900E+00, -.19892600E+00, 0.16927400E+00, -.34958200E+00, 0.11773000E+00, -.15875900E+01, 0.29148200E+00, 0.14282100E+01, 0.25107900E+00, -.89130400E-02, -.49299700E-01, 0.21248900E+00, 0.12640400E+00, 0.18944900E+00, -.71138400E-01, 0.18810500E-01, 0.83075200E-01, 0.18919000E+01, 0.17199600E+00, 0.83393900E+00, 0.14801700E+00, -.18760600E+00, -.93458500E-02, -.38194000E+00, -.99360900E-02, 0.58627300E-01, 0.12374700E+00, -.27241400E+00, 0.10540600E+00, 0.68397400E-01, 0.10449000E+00, 0.31655400E+00, -.46080400E+00, -.19414700E+00, -.11567400E+00, -.18749100E+00, -.77866200E+00, -.23026800E+00, 0.28188800E+00, 0.14164100E+00, -.18661200E+00, -.18968200E+00, 0.11306900E+00, 0.36103300E+00, -.12716000E+00, -.24852000E-01, 0.47082500E-01, -.36307200E+00, -.49885600E+00, 0.58683300E+00, 0.25348400E+00, -.30530300E-01, 0.44388800E-01, -.65721800E+00, -.77034900E-01, -.51142200E-01, -.90364500E-01, -.46524500E-02, 0.32633900E+00, 0.99512200E+00, 0.61934600E-01, -.13236500E+00, 0.21179400E+00, -.49153400E+00, -.10197900E+00, 0.45037200E+00, -.21783300E+00, 0.36043300E-01, 0.66430500E-01, 0.28692400E-02, 0.74142900E-02, 0.38211000E-01, 0.98363000E-01, 0.84247400E+00, 0.10557700E+00, -.11444200E+00, -.29649200E+00, -.20720300E+00, -.36377500E-01, 0.12345200E+00, 0.22931400E-01, -.14231800E+00, 0.51174200E-01, 0.21431500E+00, -.22766700E+00, -.30988800E+00, 0.49142900E+00, 0.25311700E-01, -.53842000E-01, 0.38894800E+00, -.26548700E+00, -.31324200E-01, -.17432100E+00, -.95234200E+00, 0.68800500E-01, 0.38166500E+00, -.62262400E-01, -.21660100E+00, -.33299000E+00, -.30707900E+00, 0.12407800E+00, 0.33051200E-01, 0.49298600E-02, -.12096200E+00, 0.50299000E+00, -.21389300E+01, -.34424600E+00, 0.74277200E-01, 0.32252700E+00, 0.23449200E+01, -.13269200E+01, -.50359700E+00, -.85504700E+01, -.10013700E+02, 0.11682300E+01, -.22085600E+00, 0.14956800E+01, -.10752600E+01, -.69387300E-01, 0.17668800E+01, -.92022400E+00, -.65284300E+00, -.10679000E+01, -.47727200E+00, 0.43374600E-01, -.83936400E+00, 0.11587300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.73210500E+01, -.20797700E+00, -.68495700E+01, -.31147000E+01, 0.16587100E+02, 0.19075600E+00, -.16953700E+02, -.74216800E+01, -.30121100E+00, 0.13282600E+01, 0.64692400E+01, -.39744200E+01, 0.38976700E+01, -.41691100E+01, -.16761000E+01, 0.26703200E+01, 0.12192900E+01, 0.27425600E-01, -.16784100E+01, 0.13091900E+01, -.47266500E+01, -.26727500E+00, 0.15286100E-01, 0.75927000E+00, 0.12018600E+01, -.10448300E+01, 0.42564000E+00, 0.40264900E+00, 0.43951200E+01, -.17783800E+01, 0.46702200E+00, -.10477800E+01, 0.11940600E+01, -.21269000E+00, -.12803300E+01, 0.12177100E+01, 0.30772400E-01, -.83824800E-01, -.11223600E+01, -.92563900E+00, -.94844900E+00, -.11267000E-01, 0.35721000E+00, 0.12987100E+00, 0.21277400E+01, 0.24912200E+01, -.10335000E+01, 0.20127000E+01, -.16602400E+01, -.13090000E+01, 0.60701900E-01, -.21949400E+00, -.10436600E+01, 0.47771800E+00, -.78728600E+00, 0.17052900E+01, -.18363300E+00, 0.30084400E+00, -.53550500E+00, 0.13223900E+00, -.46465700E-01, -.15795100E+01, 0.90433500E+00, 0.26617600E+01, -.11719600E+01, -.10338100E+01, -.93614600E+00, 0.38759300E+00, 0.86925000E+00, 0.27816900E+00, 0.57751200E+00, -.74408800E+00, -.28692800E+00, -.70600300E+00, 0.18986700E+01, -.36774300E+00, -.68877200E+00, -.27483400E+01, 0.83744800E-01, -.11483100E+01, -.24247500E+00, 0.10439600E+01, 0.96452900E-01, -.20491500E-01, 0.64014500E+00, -.55152000E+00, -.39342600E+00, -.18641400E+00, 0.19424100E+00, -.15219400E+01, 0.27948700E+00, -.61293200E-01, 0.33522100E+00, -.12621000E+01, 0.34743500E+00, -.13766800E+00, -.50787600E+00, 0.56053100E+00, -.13898500E+00, 0.66454000E+00, -.97156700E+00, -.63655700E+00, -.85360100E-01, -.75152200E+00, 0.29045200E+00, -.29482000E+00, -.10317600E+00, -.61595700E+00, -.11467100E+00, 0.47388500E-01, 0.50285800E-01, 0.10823000E+01, -.12434800E+01, 0.34467500E-01, -.89606600E+00, -.10898800E+01, -.17904900E+00, 0.14911600E+00, 0.94116900E-01, -.10180700E+00, -.19752400E+00, 0.53164300E+00, 0.12085100E+00, -.14363900E+00, -.17488100E+00, -.97291100E+00, 0.53820900E+00, 0.58336500E-01, -.11316600E+01, 0.19699000E+00, 0.45746300E-01, -.17412100E+00, -.84155600E-01, -.10231900E+00, 0.37383500E+00, 0.91972900E-01, -.31205800E+00, 0.28462300E+00, -.12053100E+00, 0.42568100E+00, -.18877800E+00, -.16967300E+01, -.52920500E+00, -.14664300E+00, 0.50196200E-01, -.39191500E-02, -.15864000E+00, 0.45024900E+00, 0.90454600E-01, -.19111400E+00, -.15031700E+00, -.25657800E+00, 0.35138400E+00, -.43196400E+00, 0.43450800E-01, 0.15638800E+00, -.17877600E+00, 0.51607500E+00, 0.45306700E+00, -.24367000E+01, 0.93838100E+00, -.17992500E+01, -.13442400E+00, 0.15425800E+00, 0.23857800E+00, 0.36396900E-01, -.30799500E+00, 0.31986100E-02, -.17481100E+00, 0.45959000E+00, 0.10669600E+01, 0.99194500E-01, -.98578000E-02, -.41097100E+00, 0.12254900E+01, 0.21966100E+00, -.78002200E+00, -.39019200E+01, 0.26267700E+00, 0.52743400E+00, 0.37196300E+00, -.18326100E-01, 0.21060200E-01, -.14410500E+00, 0.11966400E+00, 0.14260300E+00, 0.10320600E-01, 0.88814100E+00, -.52708600E+00, -.73515800E+00, 0.73383100E-01, 0.62042800E+00, 0.45794100E+00, 0.97607500E+00, -.20526700E+00, 0.64334600E-01, 0.29374700E-02, 0.44814800E+00, 0.20082000E+01, -.74576800E-01, -.28490300E+01, -.15747900E+01, 0.20967600E+00, -.30547700E+00, 0.44300800E+01, -.24080400E+00, -.39920900E+02, -.45514200E+02, -.29195200E+01, -.21253100E+01, -.29464700E+01, -.80513400E+01, 0.19067400E+00, -.35357000E+01, -.22140700E+01, 0.12197400E+01, -.78287800E+01, -.64566700E+00, 0.11660100E+01, -.24154000E+01, 0.96031100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22458500E+02, 0.29278100E+01, -.19465300E+02, -.99497600E+01, 0.67173500E+02, 0.15429200E+00, -.69985200E+02, -.33526900E+02, 0.41306200E+00, 0.51534500E+01, 0.24949300E+02, -.12667700E+02, 0.16668700E+02, -.16746000E+02, -.76245600E+01, 0.12324800E+02, 0.38982600E+01, 0.10621800E+01, -.84760100E+01, 0.52679900E+01, -.30528700E+02, -.37840300E+01, 0.42621400E+00, 0.21295400E+01, 0.11346800E+01, -.65376400E+01, 0.76915900E+01, 0.83833000E+00, 0.88853900E+01, -.11103000E+02, 0.29167500E+01, 0.44879000E+00, -.84690500E+00, -.17454900E+01, -.60220700E+01, -.54585100E-01, -.11938900E+01, 0.22506900E+01, -.22915200E+01, 0.26463500E+01, 0.55201000E+01, 0.23090900E+01, -.10863300E+02, -.25402600E+01, 0.10729700E+02, 0.12646700E+02, -.30528800E+01, 0.62476100E+01, -.16073500E+02, -.69182500E+01, 0.12143500E+01, -.26186900E+01, 0.57512600E+00, -.23711900E+01, -.59885000E+01, 0.11223100E+02, -.60307700E+00, -.80932600E+00, -.30283400E+01, 0.13825000E+01, -.19724700E+01, -.75578900E+01, 0.58248200E+01, 0.11519800E+02, 0.15833000E+01, -.27750200E+01, -.91819500E+01, 0.24004600E+01, 0.37520400E+01, 0.13671500E+01, -.18217400E+00, -.30264100E+00, -.32523000E+01, -.18124600E+01, 0.46107100E+01, -.90660800E+01, -.22715900E+01, 0.33803300E+01, -.17193500E+01, -.11075900E+02, -.13863300E+01, 0.48029600E+01, -.67955300E-01, 0.10418400E+01, -.52752800E+00, -.31746000E+01, 0.10438300E+01, 0.22178700E+01, -.10455500E+01, 0.47606500E+01, 0.76970000E+00, 0.25645100E+00, 0.66145600E+00, -.29332900E+01, 0.81235200E+00, 0.38158800E+00, -.23384000E+01, -.77141500E+00, -.40845600E+00, 0.22618300E+01, 0.36354600E+00, -.24398200E+01, 0.21725400E+01, -.44854100E+01, 0.75904900E+00, -.41416600E+00, -.52503800E+00, -.38535300E+00, 0.67453700E+00, 0.97444600E-01, -.96852200E+00, 0.41075200E+01, 0.16644400E+01, 0.10273300E+01, -.25043300E+00, 0.61204000E+00, -.86752400E+00, -.14557800E+01, 0.77316100E+00, -.28917800E+00, -.22238900E-02, -.91190200E+00, -.18424200E+00, -.14832800E+01, 0.13048200E+00, 0.42791900E+01, -.21102400E+01, -.10985100E+01, 0.62990200E+01, 0.12651200E+01, -.34781200E+01, 0.13911700E+01, 0.16726600E+01, 0.25794300E+01, 0.15163200E+01, -.59951500E+00, 0.49426400E-01, 0.19421000E+01, -.72704200E+00, -.29558300E+01, 0.61163500E+00, -.18550400E+01, -.18765700E+01, -.69148500E+01, 0.29455900E+00, -.27262300E+00, -.56296000E+00, -.30957400E+01, -.11594200E+01, -.21978300E+01, -.10977800E+01, -.17828800E+01, 0.35218800E+00, 0.31973900E+00, 0.92119700E+00, -.11343600E+01, 0.38795600E+00, 0.33546300E+01, -.51351300E+01, -.29258700E+01, 0.18201000E+01, -.17162800E+01, -.95048000E+00, 0.43200300E+00, 0.61780800E+01, 0.89906300E+00, -.75558300E+00, -.39551100E-01, 0.86948400E+00, -.52095400E+00, -.11111900E+01, 0.15025800E+01, 0.96469400E-01, 0.21109300E+00, -.38917600E+00, 0.11836500E+01, -.14066400E+01, -.97127100E+01, -.15629500E+01, -.53587900E+01, 0.55130800E+01, 0.28057600E+00, -.54646900E-01, 0.18598900E+01, -.18514200E+01, -.18182100E+00, -.14757100E+01, -.31511200E+01, 0.11230200E+01, 0.23835800E+01, -.34403800E+00, -.11632300E+01, -.19554100E+01, 0.12785000E+01, 0.41460700E+00, 0.28587500E+00, 0.52266400E+00, 0.57616200E+00, -.14566100E+01, 0.10493500E+01, -.10716300E+01, 0.99636300E+01, -.15137300E+01, -.57225400E+00, -.33939400E+01, 0.49392700E+00, -.14471300E+03, -.16850900E+03, 0.20965500E+01, 0.42326100E+01, 0.40310400E+01, 0.15539400E+01, -.49069800E+00, 0.11301400E+02, -.50121300E+01, 0.18363400E+00, 0.16944700E+01, 0.17637500E+01, -.25283400E+01, -.59743000E+01, 0.38951600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20520600E+02, 0.78164100E+00, -.18679900E+02, -.10023300E+02, 0.54987000E+02, -.82964100E+00, -.56291600E+02, -.25871400E+02, -.18506800E+01, 0.37751900E+01, 0.22403000E+02, -.12780900E+02, 0.13201700E+02, -.10854100E+02, -.72931900E+01, 0.91948200E+01, -.18932800E+01, -.25778900E+01, -.99154900E+01, 0.23676800E+01, -.28054200E+02, -.20089700E+01, 0.12368000E+01, 0.15472700E+01, 0.24765200E+01, -.69677800E+01, 0.31178400E+01, 0.86825900E-01, 0.10501300E+02, -.11668200E+02, 0.19788000E+01, -.22824800E+01, 0.13333900E+01, 0.45584900E+00, -.58309000E+01, -.40227500E+00, -.15106900E-02, -.86539100E-02, 0.54379600E+01, -.90455700E+00, 0.32191000E+01, 0.72514200E+00, -.14756000E+01, -.17549200E+01, 0.40430900E+01, 0.31609900E+01, -.96179300E+00, -.48593500E+00, -.44452300E+01, -.95797200E+01, 0.40581200E+00, -.22005300E+01, 0.21616400E+01, 0.25149200E+01, -.10727100E+00, 0.77497800E+01, -.47746800E+00, 0.55063100E+00, -.12467100E+01, -.23718200E+01, -.17121400E+01, -.32509500E+01, 0.25771800E+01, 0.98309700E+01, 0.45839100E+00, -.76423300E+00, -.14731700E+01, 0.19921900E+00, -.22203700E+01, 0.13030400E+01, 0.22160600E+01, -.49257700E-01, 0.12292800E+01, -.17471000E+01, 0.29985400E+01, -.14320900E+01, -.94393200E+00, -.29427100E+01, -.13247800E+00, -.67742400E+01, -.67079200E+00, 0.39900200E+01, 0.15542900E+00, 0.70477700E+00, -.21211600E+01, -.70278500E+01, 0.16823400E+01, 0.30126100E+01, 0.76405700E+01, 0.35158400E+01, 0.30631400E+01, 0.53154400E-01, 0.30413500E+00, 0.26976800E+01, 0.13931700E+01, 0.17189900E+00, -.34180700E+00, 0.34999300E+00, -.68524600E+00, 0.18348700E+00, -.12221300E+01, 0.57817700E+01, 0.57030000E+00, -.23854700E+01, 0.15368300E+01, -.20480800E+01, -.48529900E+00, 0.14146200E+01, -.88218700E+00, 0.27632400E+00, -.51461700E+00, -.41025600E+01, -.21171700E+01, 0.52766800E+00, -.40899000E+00, -.99460000E+00, -.88466200E+00, -.30763300E+00, -.11050700E+00, -.87361300E-01, -.38505100E+00, 0.68433000E+00, -.23708200E+00, -.12478300E+01, -.16537300E+01, 0.29131000E+01, -.24687100E+00, 0.23986600E+00, -.43969600E+01, -.17162200E+01, -.17525000E+01, -.24273800E+01, 0.41690300E+00, -.19482100E+01, -.16627500E+01, 0.11745100E+00, -.34695500E+00, -.28161800E+00, -.40317000E-01, 0.21435600E+01, -.16238700E+01, -.74569000E+01, -.57843000E+01, 0.14171300E+01, -.15518900E+01, -.25857700E-01, -.47100500E+00, -.39175900E+00, 0.92848200E-01, 0.96835700E+00, 0.83973200E+00, 0.27699800E+01, -.17296600E+00, 0.31758000E+01, -.10691400E+01, 0.70179700E-01, 0.53925300E+00, -.40462700E+01, 0.42283200E+01, 0.78291200E+01, -.30826300E+01, 0.46762100E+01, 0.18154500E+01, -.37652000E+00, -.35674900E+01, 0.94198500E+01, 0.10063200E+01, -.79291700E+00, 0.57767400E+00, -.90645900E+00, -.31968600E+00, -.31305700E+01, -.33503100E+00, 0.10368100E+01, -.24455700E+00, -.93464000E+00, 0.28911600E+00, -.37443400E+01, -.66953500E+00, -.16695200E+00, -.12437200E+01, -.14435200E+00, -.49389900E+00, -.16348600E+00, 0.24490100E+00, -.78136700E+00, -.94556100E+00, 0.39118400E+00, 0.10456700E+00, -.87615200E+00, -.39233200E-01, 0.93743500E+00, 0.65351100E+00, -.70617600E+00, -.18065500E+00, -.27737200E+00, -.66890800E+00, 0.68082200E+00, 0.95521600E+00, -.26751700E+00, 0.94227200E+00, 0.23433800E+00, -.35368300E+01, 0.31188200E+00, 0.41093300E+01, 0.36740800E+01, 0.84500000E+02, 0.98998800E+02, -.45718600E+00, 0.50009300E+01, -.31625300E+01, 0.37886400E+01, -.73713600E+00, 0.42018900E+01, 0.37326300E+01, 0.69617200E+00, 0.38844400E+01, 0.30021000E+01, 0.35932700E+00, 0.34714700E+01, -.57936600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22658200E+01, 0.11319600E+01, -.10870800E+01, -.11767900E+01, 0.13750000E+02, -.10146300E+00, -.10718200E+02, -.59240200E+01, -.90057500E+00, 0.17352200E+01, 0.39721100E+01, -.24504600E+01, 0.26797100E+01, -.22521000E+01, -.16184700E+01, 0.23842400E+01, 0.51017200E+00, -.27773200E+00, -.13605900E+01, 0.23673400E+00, -.36079700E+01, 0.15125400E+00, -.63267500E+00, 0.10064100E+00, -.13269400E+00, -.73629200E+00, 0.86224900E+00, 0.15882500E+00, 0.82777500E-01, -.10667700E+01, 0.39930400E+00, 0.79654100E+00, -.17789600E+00, -.16673400E+00, -.11515600E+01, 0.37840500E+00, 0.17208200E-01, 0.32536200E+00, -.55378600E+00, 0.42123300E+00, 0.28089200E+00, 0.18196900E+00, -.66724100E+00, -.38457600E+00, 0.10556400E+01, 0.86277900E+00, -.17710300E+00, 0.65808300E-01, -.11206000E+01, -.60586500E+00, -.56969300E-01, -.16671000E+00, -.95784800E+00, -.10567300E+01, -.13312500E-01, -.23385100E-01, -.18284600E+00, 0.26151100E+00, -.13370500E+00, 0.44975000E+00, -.47844200E+00, 0.80255900E-01, -.10783000E+00, -.64453100E+00, 0.40191200E-01, -.32609300E+00, -.39238500E+00, 0.14199800E+00, 0.10687300E+00, -.10854300E+00, 0.18647300E+00, -.28790400E-01, -.32290200E+00, -.13830700E+00, 0.59289200E+00, -.12832600E+00, -.15185600E+00, -.72190400E+00, -.18863000E-01, -.97798800E-01, -.65442600E+00, 0.33273500E+00, -.12786200E-01, -.42639500E-01, 0.42383700E+00, 0.61967900E+00, 0.31501800E+00, 0.82279900E-01, 0.49273200E-01, 0.11989800E+00, 0.82314500E-01, 0.29442300E-01, 0.79266700E-01, -.12595000E+01, -.47963400E+00, 0.27251900E-01, -.23339800E+00, 0.26675100E+00, -.59324700E-01, 0.13379000E+01, -.49535600E+00, -.10987000E+01, -.16041400E+00, -.94649300E-01, 0.45617400E-01, -.18407400E+00, -.14051900E+00, -.78796400E-01, 0.76091200E-01, -.37753200E-02, -.80264400E-01, -.14485100E+01, -.45956200E+00, -.51491000E+00, -.11427400E+00, -.98170100E-01, 0.13810700E+00, 0.42116400E+00, 0.45034400E-01, -.46770200E-01, -.14968400E+00, 0.46225700E+00, -.81277400E-01, -.12785800E+00, -.13761700E+00, -.32448900E+00, 0.46320000E+00, 0.18401200E+00, 0.42099200E-01, 0.33858300E+00, 0.79767700E+00, 0.28885800E+00, -.23988200E+00, -.69229600E-02, 0.30781100E+00, 0.25507200E+00, -.88096700E-01, -.24560800E+00, 0.50759900E-01, -.60963300E-01, -.31324000E-01, 0.10796300E+00, 0.27031600E+00, -.56688200E+00, -.22245000E+00, 0.16490900E-01, -.57384800E-01, 0.54942200E+00, 0.10584000E+00, 0.87504000E-01, 0.21873700E-01, -.11175700E+00, -.21243200E+00, -.83453700E+00, 0.18639000E-02, 0.80197300E-01, -.12893000E+00, 0.29231400E+00, 0.20262500E-01, -.68111300E+00, 0.19075800E+00, -.36184700E+00, -.14323300E+00, 0.62185600E-02, 0.68021100E-02, -.18072900E+00, -.13168100E+00, -.61770000E+00, -.94508600E-01, 0.13289300E+00, 0.27759300E+00, 0.16148700E+00, 0.30278900E-01, -.13543100E+00, 0.26468800E-02, 0.10519000E+00, 0.28930600E-01, -.18756500E-02, 0.22986900E+00, 0.61116500E+00, -.49710400E+00, -.24770400E-01, 0.55737900E-01, -.37938000E+00, 0.28430900E+00, 0.38232800E-01, 0.18266400E+00, 0.84071500E+00, -.80690400E-01, -.38681000E+00, 0.60415400E-01, 0.21621400E+00, 0.32923500E+00, 0.31305100E+00, -.12601200E+00, -.31739400E-01, 0.51891200E-03, 0.15354200E+00, -.51694500E+00, -.10013700E+01, -.88074700E-02, -.11230600E-01, -.11939600E-01, 0.31677200E+00, -.50558300E-01, -.35494000E-01, -.19257200E+01, -.22145200E+01, 0.94270400E-01, -.23869200E-01, 0.11837100E+00, 0.21063500E+00, -.14714600E-01, 0.27218200E+00, -.27683100E-01, -.47493900E-01, 0.19308000E+00, -.51668200E-01, -.60922000E-01, -.49660800E-01, 0.44080500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13064800E+02, 0.16640800E+01, -.19780900E+02, -.84142100E+01, 0.33071100E+02, 0.99311800E+00, -.33966500E+02, -.22396100E+02, 0.46407100E+00, 0.50849900E+01, 0.73055400E+01, -.51237600E+01, 0.62320800E+01, -.97973900E+01, -.52197400E+01, 0.58966500E+01, 0.34554200E+01, 0.70114700E-01, -.20040600E+01, 0.47308500E+01, -.82910800E+01, -.15538100E+01, 0.21347600E+00, 0.20522900E+01, -.26037500E+00, -.24727800E+01, 0.16653900E+01, 0.39333700E+00, 0.67794500E+01, -.65994000E+01, 0.17494500E+01, -.90083400E+00, 0.86564200E+00, 0.44793800E+00, -.33043600E+01, -.14593100E+01, -.28760900E+00, -.45452700E+00, 0.20774900E+01, -.19767100E+01, -.19206100E+00, 0.35424400E+00, 0.67973000E+00, -.15826700E+00, 0.35845900E+01, 0.40693300E+01, -.10251200E+01, 0.37487400E+00, -.27517700E+01, -.89565000E+01, -.38007400E+00, -.14167800E+01, -.83001400E+00, -.45077800E+01, -.81018100E+00, -.25333900E+00, 0.38772600E+00, 0.12912000E+01, -.69923600E+00, 0.29012900E+00, -.10347900E+01, -.17487400E+01, 0.18051500E+00, 0.23029800E+01, -.91796600E+00, -.10814500E+01, -.19255800E+01, -.31006400E-01, 0.18444500E+00, 0.11973100E+01, 0.23754200E+01, -.52373500E+00, -.23451500E+01, -.48391800E+00, 0.27254700E+01, 0.98918100E+00, 0.94154200E+00, -.30145700E+01, -.55825100E+00, -.85819400E+00, -.21949500E+01, 0.13826900E+01, -.17785200E+00, 0.74246200E-01, -.32790100E+00, 0.39900800E+01, 0.10731800E+01, -.21469800E+00, 0.36944700E+01, -.35535200E+01, 0.12211400E+01, -.60955500E+00, -.23942300E+00, -.10361000E+01, -.85434100E+00, -.11845300E+00, -.89480500E+00, 0.13535100E+01, -.13060500E+00, 0.43288400E+01, -.10076000E+01, -.78557600E+01, -.11493700E+01, -.48034300E-02, 0.31087200E+00, -.42100200E-01, -.39722000E+00, -.27834700E+00, -.10229600E+00, 0.13758300E+00, -.29538900E+00, -.39748600E+01, -.19443000E+01, -.16044100E+01, -.13219000E+01, -.16305500E+01, -.26687000E+00, 0.71084800E+00, 0.19876800E+00, -.15692300E+00, -.68694700E+00, 0.11309900E+01, -.42535800E+00, -.12841000E+01, -.78810400E+00, -.19631500E+00, 0.79329100E+00, 0.64390600E+00, -.27758100E+01, 0.69111300E-01, 0.21584500E+01, -.46739500E+00, -.15403600E+01, -.12672000E+01, 0.10992300E+00, 0.87408600E+00, -.28006700E+00, -.14634500E+01, 0.19178100E+00, 0.47631300E+00, -.15527100E+00, 0.13739700E+01, 0.31585000E+00, -.11870700E+01, -.10288600E+01, 0.11214400E+00, -.27523800E+00, 0.14701300E+01, 0.53983100E+00, 0.62596400E+00, 0.81523600E+00, 0.10274500E+01, -.52029000E+00, -.78453400E-01, -.46803400E+00, 0.63695800E+00, -.32786900E+00, -.11885600E+01, 0.28670300E+01, 0.13064200E+01, -.92082900E+00, 0.11306900E+01, -.27519500E+00, -.26863000E+00, -.44445300E+01, 0.26683400E+01, 0.34604300E-02, -.40922100E+00, -.40845600E+00, 0.10917000E+01, 0.45987200E+00, -.14388100E+01, -.53600400E-01, 0.11080900E-01, -.13631300E+01, -.18955900E+00, 0.69361600E+00, 0.37522000E+01, 0.55230800E+00, 0.87856200E+00, -.72481500E+00, -.14335000E+00, -.41062900E+00, -.60929200E+00, 0.61655000E-01, -.68724500E+00, -.13819600E+00, 0.45748700E+01, 0.86265300E+00, -.86084700E+00, 0.94915700E-01, 0.88274900E-02, 0.65461000E+00, -.50580900E+00, 0.16350500E+00, -.36137900E+00, -.82287800E+00, -.14095700E+01, 0.19475900E+01, -.51492500E+00, 0.13052800E+01, 0.49060700E+00, 0.44851800E+00, 0.91459200E-01, 0.14247900E+02, 0.26556700E+01, 0.14724900E+03, 0.17301300E+03, -.74706700E+01, 0.64379100E+01, -.12455100E+02, -.12493600E+01, 0.27762000E+01, -.22575800E+02, 0.89209300E+01, -.12481700E+01, -.12805600E+01, 0.42890500E+01, 0.33784900E+01, 0.91473500E+01, -.58713800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.43709600E+01, 0.12008700E+01, -.34729500E+01, -.19936900E+01, 0.12270800E+02, 0.68954500E-01, -.12133200E+02, -.59287600E+01, 0.39633200E+00, 0.11827500E+01, 0.46764400E+01, -.29441600E+01, 0.29115200E+01, -.43021000E+01, -.95221500E+00, 0.15963700E+01, 0.50508400E+00, -.32757900E+00, -.17124100E+01, 0.70502300E+00, -.42591100E+01, -.45104100E-02, -.20747500E+00, 0.44927700E+00, 0.35648600E+00, -.93361300E+00, 0.14599900E+00, 0.14397900E+00, 0.12849200E+01, -.14717400E+01, 0.27485100E+00, 0.49554100E+00, 0.52124200E+00, 0.35049200E-01, -.12118800E+01, 0.30259600E+00, 0.26492700E-01, 0.17305300E+00, -.37193500E-01, 0.20121200E+00, 0.64574600E+00, 0.17017300E+00, -.53510700E+00, -.27014100E+00, 0.13671400E+01, 0.10453100E+01, 0.44391500E-01, -.39430600E+00, -.21803300E+01, -.65488200E+00, 0.10047700E+00, -.19465600E+00, -.98233100E+00, -.72144700E+00, 0.63500200E-01, 0.88413900E+00, -.10443900E+00, 0.37946700E+00, -.52412100E+00, 0.35419400E+00, -.32615500E+00, 0.46032700E-01, -.62600700E+00, -.16633100E+00, -.21825700E+00, -.48800500E+00, -.38916800E+00, -.39130700E-01, -.29779900E+00, 0.10553200E+00, 0.29396300E+00, -.97155400E-01, -.47162600E-01, -.10809500E+00, 0.75534700E+00, -.24265000E+00, -.75704800E-01, -.94394800E+00, -.14227700E+00, 0.42562200E+00, -.60237500E+00, 0.15159400E+00, -.17112200E-01, -.17418400E-01, 0.22749500E+00, 0.18521100E+00, 0.22272400E+00, 0.25011000E+00, -.67984800E-01, -.18418700E+00, -.14794600E+00, 0.25280700E+00, 0.14908400E+00, -.90223300E+00, -.36884100E+00, 0.49117600E-02, 0.90720600E-01, 0.37561900E+00, -.72634800E-01, 0.11063200E+01, -.35254600E+00, -.66730700E+00, -.15344200E+00, 0.13017800E+00, 0.35224800E-01, -.75379200E-01, -.76740200E-01, -.30339800E+00, -.86328400E-01, 0.71091700E-02, -.99303500E-01, -.27854100E+00, -.89674300E+00, -.58407500E+00, -.45235800E+00, 0.31197400E+00, 0.15853200E+00, 0.34663400E+00, -.11133800E-01, -.59184800E-01, -.33629400E-01, 0.25736200E+00, -.38361200E-01, 0.25418000E-02, -.14118700E+00, -.31274000E+00, 0.12911500E+00, 0.82922600E-01, -.12069000E+00, -.67617100E-01, 0.57677400E+00, -.13787700E-01, -.23320500E+00, -.21496300E+00, 0.36831500E-02, 0.10079000E+00, -.21374600E+00, -.12137300E+00, 0.13273500E+00, 0.30722200E+00, -.87369200E-02, 0.33141400E+00, 0.21529000E+00, -.48936900E-01, -.10211600E+00, 0.21998000E-01, -.46522100E-01, 0.50063700E+00, 0.63149000E-01, 0.36356500E-01, 0.70439100E-01, -.53414500E-01, -.17026200E+00, -.42491100E+00, 0.48953400E-02, 0.67820300E-01, -.76444200E-01, -.22303900E+00, 0.21885300E+00, -.40550500E+00, -.60169400E-01, -.56459700E+00, 0.18738500E+00, -.29504700E-02, -.12150200E+00, 0.40391600E+00, 0.60961400E-01, -.48016700E+00, -.21181700E-01, 0.17937800E-01, 0.31399100E+00, -.61793700E-01, -.15222300E-01, -.11597700E+00, 0.29298300E+00, 0.38405300E-01, -.20510000E+00, -.13114500E+01, 0.14908200E+00, 0.46263000E+00, -.36126600E+00, -.10431400E-01, 0.45386900E-01, -.14628300E+00, -.55999200E-02, -.77437600E-02, 0.77855600E-01, 0.71774000E+00, -.13324900E+00, -.17559400E+00, 0.30735600E-01, 0.79790000E-01, 0.21850700E+00, 0.11435900E+00, -.28782400E-01, -.42647400E-01, -.51579100E-01, -.14064300E-01, -.21486300E-01, -.25631400E+00, -.42594700E+00, -.84232400E-01, 0.70935600E-01, -.44202300E+00, 0.20025100E+00, -.43374400E+00, -.57730100E+02, -.66913100E+02, -.21563200E+00, -.19846100E+01, 0.66476100E+00, -.31502400E+01, -.44572900E+00, 0.19918000E+01, -.30575100E+01, 0.10462300E+01, -.30411800E+01, -.91757600E+00, -.63709500E+00, -.31381200E+01, 0.18821300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.43955100E+01, 0.46414100E+00, -.36370200E+01, -.19302400E+01, 0.10862000E+02, 0.24618800E+00, -.11832600E+02, -.58000200E+01, -.26283800E+00, 0.11440600E+01, 0.51000400E+01, -.30816000E+01, 0.27231900E+01, -.39986000E+01, -.14674700E+01, 0.17819300E+01, 0.70598700E+00, -.17002800E+00, -.17647900E+01, 0.92544700E+00, -.40130000E+01, -.19708500E+00, -.18490400E+00, 0.68119100E+00, 0.52299000E+00, -.88433200E+00, 0.22918900E+00, 0.37919000E+00, 0.14510600E+01, -.12521800E+01, 0.40843900E+00, -.69980700E-01, 0.42801100E+00, -.25279200E+00, -.14765400E+01, 0.37892600E+00, 0.42761800E-01, 0.13140800E+00, -.64416300E+00, -.24031300E+00, -.49323700E-01, 0.15546000E+00, -.31121800E+00, -.30600800E+00, 0.15677900E+01, 0.11853600E+01, -.35567300E+00, 0.39360700E+00, -.11834800E+01, -.16363600E+01, 0.76770400E-01, -.17333700E+00, -.61810900E+00, -.50790400E+00, -.14626700E+00, 0.73209100E+00, -.77136600E-01, 0.32289000E+00, -.31434000E+00, 0.22447100E+00, -.10879700E+00, -.59920300E+00, -.25340600E+00, 0.73077900E+00, -.40086300E+00, -.60237000E+00, -.37703500E+00, 0.50182000E-01, 0.24088000E+00, 0.21277200E+00, 0.53271700E+00, -.10465600E+00, -.73143400E-01, -.27961700E+00, 0.98629600E+00, 0.47527400E-01, -.17850400E+00, -.15250600E+01, -.10694800E+00, -.62133100E+00, -.68935800E+00, 0.57528600E+00, -.60787300E-02, -.12119500E-01, 0.26786000E+00, -.29892300E+00, 0.36019900E-01, 0.13090100E+00, -.12653100E+00, -.10950000E+01, -.16491200E+00, 0.11033900E+00, 0.28252200E+00, -.15441600E+01, -.62316400E-01, -.76415500E-01, -.30128700E-01, 0.43417700E+00, -.13108000E+00, 0.31501000E+00, -.77798100E+00, 0.17379500E+00, -.23394800E+00, 0.26316000E+00, 0.24411900E+00, -.30766300E+00, -.11810000E-01, -.59179500E+00, 0.11840200E-01, 0.23004200E-01, -.13362800E+00, 0.10654100E+01, -.10901000E+01, 0.54484200E-01, -.58701000E+00, -.15543400E+00, 0.16197100E+00, 0.22919900E+00, 0.13000700E+00, -.53661600E-01, 0.25178500E-01, 0.43367200E+00, 0.81254000E-01, -.17487700E+00, -.28643900E+00, 0.13348600E-01, 0.38784500E+00, 0.15464300E+00, -.82063200E+00, -.12829700E+00, 0.12715600E+00, -.22351300E+00, -.38011500E+00, -.40042900E+00, -.15965000E+00, 0.10598200E+00, -.21855800E+00, 0.77517600E-01, 0.41864200E-02, 0.39814900E+00, -.12585300E+00, -.15158900E+01, -.97361600E+00, 0.70519300E+00, -.28497200E+00, 0.87897600E-02, -.48170000E-01, 0.33893400E+00, 0.13537000E+00, 0.38512700E+00, 0.10604300E+00, 0.16847200E+00, 0.55374100E-02, -.35565900E+00, -.11783000E+00, 0.12688400E+00, 0.11246200E-02, -.10875900E+00, 0.41348000E+00, 0.44783300E+00, -.24270700E+00, -.28628700E+00, 0.28117200E+00, -.42464500E-01, -.45233600E+00, 0.40538400E+00, 0.21418300E+00, -.62651900E+00, -.75200700E-01, -.15632500E-01, 0.32589100E+00, -.70714700E-01, -.40394200E-01, -.16525100E+00, 0.45953500E+00, -.10949000E-01, -.14304600E+00, -.83795900E+00, 0.44800800E-01, 0.15238400E+00, -.48820400E-01, -.22235400E-01, -.18507700E-01, -.50902500E-01, 0.22607400E+00, 0.13058300E+00, 0.73554700E-01, 0.77326300E+00, -.19968300E+00, -.25507900E+00, 0.17224600E-01, 0.13179700E+00, 0.10844500E+00, 0.12334700E+00, -.32895900E-01, -.27351000E-01, 0.25490700E-01, 0.23004000E+00, -.14554800E-01, 0.41911600E+00, 0.14589200E+00, -.56047900E-01, 0.14267100E+00, -.51671200E+00, 0.35478800E-01, -.65169700E+00, -.66405300E+02, -.76983600E+02, -.76314200E+00, -.23023700E+01, 0.11939900E+00, 0.50162000E-01, 0.41352600E-01, 0.70953800E+00, -.25433500E+01, 0.36293700E+00, 0.43495600E-01, -.10138100E+01, -.27401200E+00, -.27295500E+01, 0.11128200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.38079500E+01, 0.48920700E+00, -.58409200E+01, -.22938500E+01, 0.12391000E+02, -.65555700E-01, -.12503400E+02, -.74465600E+01, 0.30216400E+00, 0.10563400E+01, 0.25456900E+01, -.17098200E+01, 0.26750100E+01, -.24026500E+01, -.10639600E+01, 0.21758000E+01, 0.10067500E+01, -.51576200E-01, -.63712200E+00, 0.71476000E+00, -.21303900E+01, -.27993900E+00, -.31129800E+00, 0.19648200E+00, 0.67009000E-01, -.63543700E+00, -.93884800E+00, 0.32218600E+00, 0.87213700E+00, -.20112800E+01, 0.12065800E+01, -.13533800E-01, 0.37816000E+00, 0.59604900E+00, 0.39353000E-01, 0.72391600E+00, 0.53912400E-01, 0.12482900E-01, -.79040900E-02, -.55422600E+00, -.26848600E+00, -.10377800E+00, -.13573200E-01, 0.13708200E+00, 0.49277200E+00, 0.84214600E+00, -.32461000E+00, 0.43738700E+00, -.98785100E+00, 0.21364300E+00, 0.62354100E-01, 0.86582300E-01, -.59657800E+00, -.42663000E+00, -.83701900E+00, 0.47797300E-01, -.53123600E+00, 0.26904400E+00, -.50562800E-01, -.18820800E+00, -.34293800E-01, 0.77687700E-01, 0.16399800E+00, -.19167200E+00, 0.35520900E+00, 0.14730600E+00, 0.15192400E+00, -.22497500E+00, -.47484300E+00, 0.31502100E+00, 0.32624400E+00, 0.42421100E-01, 0.13532500E+00, -.77988200E-02, 0.25926100E-01, 0.17347200E+00, 0.19499500E+00, -.68527600E-02, -.41061400E-01, 0.83874900E-01, 0.12053200E+00, -.24853800E+00, 0.31276700E-02, 0.86524100E-02, -.47343400E+00, -.40307000E+00, 0.36848300E-01, 0.28991600E+00, 0.10578500E-01, -.27326000E-01, -.12336500E+00, 0.21197300E+00, -.16522200E-01, -.22964500E+00, 0.18684400E+00, 0.85458600E-01, -.26221300E-01, 0.13152600E+00, -.25725500E-01, 0.74644200E-01, -.26554500E+00, -.32298100E+00, -.10519100E-01, 0.86111200E-01, -.97589700E-02, 0.10242400E+00, 0.22880900E-01, -.16567500E+00, 0.41613600E-01, -.48240800E-02, -.11246800E-02, 0.33962500E+00, -.10861300E+00, -.14764400E+00, -.23472600E+00, 0.20864900E+00, 0.78138100E-01, 0.31900300E+00, 0.50537100E-01, -.53283400E-01, -.10036200E+00, -.26888200E-01, 0.60295000E-01, -.71431600E-01, 0.26387500E-01, -.33750500E+00, 0.21239700E+00, 0.79202100E-01, -.28520700E+00, -.57779800E-01, -.32931500E+00, 0.15298000E+00, 0.19526800E+00, 0.67101200E-01, 0.12154700E+00, -.39549400E-01, -.11621400E-01, 0.14372400E+00, -.53922900E-01, 0.28042900E-01, -.21248300E-01, -.91529800E+00, -.67416300E+00, 0.13099100E+00, 0.84853400E-01, -.16350200E-01, 0.14595400E-01, -.68281000E-01, -.82532500E-01, 0.24321600E+00, 0.72092900E-01, 0.73666300E-01, 0.15053500E+00, 0.22217200E-01, -.44294700E-01, 0.10198500E+00, 0.27748200E-02, -.60768900E-01, 0.14969000E+00, 0.32124500E+00, -.16777400E+00, -.30744500E+00, 0.44708700E-01, -.21641000E-01, -.46925300E+00, -.76918900E-02, 0.89180800E-01, 0.17680100E+00, -.20077900E-01, 0.25021600E-01, 0.14037700E+00, 0.17446400E+00, -.35249200E-01, 0.14439800E-01, 0.23784300E+00, -.17045000E-01, -.77106000E-01, -.11670800E+01, -.91025200E-01, -.14011700E+00, 0.35801600E+00, -.47237500E-02, 0.19866600E-01, 0.25736900E+00, 0.35272200E-02, 0.15500000E+00, 0.78317900E-01, -.67808800E+00, -.20821200E+00, -.17966700E+00, 0.58852800E-02, -.26767400E-01, 0.38888200E-01, -.12259200E+00, -.10455500E-01, 0.51139000E-01, -.28918700E-02, 0.57239600E-01, 0.19768300E+00, 0.88912300E-02, 0.11938700E+00, 0.13631200E-01, 0.51130300E-01, -.99205900E-01, -.96704300E-02, -.37854900E-01, 0.22397600E-01, -.38128600E+01, 0.10096600E+00, -.92020300E-01, -.90791200E-01, -.11086700E+00, -.79885000E-01, -.69640500E+00, -.25918500E+00, -.17787800E-01, -.12449200E+00, -.11502300E+00, 0.10394100E-01, -.26600000E+00, 0.51028600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.26105700E+02, 0.83695500E+00, -.24991500E+02, -.11738800E+02, 0.66091800E+02, 0.71033200E+00, -.68018200E+02, -.32625000E+02, -.22420900E+01, 0.59319900E+01, 0.25918500E+02, -.16755600E+02, 0.14748900E+02, -.17809200E+02, -.86172200E+01, 0.10408900E+02, 0.19904500E+01, -.25299500E+01, -.10240800E+02, 0.42445200E+01, -.24096100E+02, -.13269400E+01, -.57469200E+00, 0.26811100E+01, 0.29881500E+01, -.59179100E+01, 0.15804200E+01, 0.10449400E+01, 0.12688700E+02, -.97074600E+01, 0.19036200E+01, -.30880300E+01, 0.33573900E+01, -.21893200E-01, -.63926400E+01, 0.13620400E+01, 0.28304500E-01, -.71217800E+00, 0.14152700E+01, -.29567400E+01, -.16631400E+00, 0.13694900E+00, 0.26737200E+00, -.13032800E+01, 0.56063500E+01, 0.48458100E+01, -.19700700E+01, 0.21548700E+01, -.62871900E+01, -.47787700E+01, 0.35999900E+00, -.73549100E+00, -.17069200E+01, -.34863200E+00, 0.79848500E-01, 0.43277700E+01, -.53152700E+00, 0.12546500E+01, -.11212600E+01, 0.26192500E-01, -.93882400E+00, -.33395200E+01, 0.15907900E+01, 0.52006200E+01, -.12526200E+01, -.19857300E+01, -.13334500E+01, 0.96582700E-01, -.17627400E+01, 0.24592100E+00, 0.22753100E+01, -.26212000E+00, 0.13339900E+00, -.17636800E+01, 0.48901600E+01, 0.10036000E+01, -.83312200E+00, -.45302800E+01, -.47263900E+00, -.15535900E+01, -.18862300E+01, 0.30652400E+01, 0.27263800E+00, -.68781000E-01, 0.15725100E+01, 0.31064100E+01, -.80920900E+00, -.24266500E+01, 0.12970600E+01, -.70953400E+01, 0.15399100E+01, -.26646000E+00, 0.50601600E-01, 0.45754800E+01, -.12295800E+01, 0.43751700E+00, 0.10600900E+00, 0.17135800E+01, -.49053900E+00, 0.62062000E+01, -.44371800E+01, -.25160800E+01, -.22115600E+01, -.85028800E+00, 0.11615900E+01, -.17591600E+01, -.21785800E+00, -.20063900E+01, 0.25824200E+00, 0.12854200E+00, 0.69085200E-01, 0.27955800E+01, -.40749700E+01, -.23615700E+00, -.27323800E+01, -.23189100E+00, 0.10162300E+00, 0.21007200E+01, 0.32585900E+00, -.56404900E+00, -.15638300E+01, 0.49777100E+00, -.35733000E+00, -.24085700E+01, -.13370900E+01, 0.70651600E-01, 0.26187800E+01, 0.10476000E+01, -.47014800E+01, -.11059800E+01, 0.96897400E+00, -.98176500E+00, -.13745300E+01, -.17533400E+01, -.66138600E+00, 0.28180900E+00, -.60964400E+00, 0.10096400E+00, 0.40196700E+00, 0.50702700E+00, -.22779400E-01, -.94370200E+01, -.55952900E+01, 0.26891100E+01, -.53751700E+00, 0.50214500E-01, -.61301300E+00, 0.16383100E+01, 0.30200900E+00, -.23097400E+00, 0.40762700E+00, 0.12299200E+01, -.72206300E+00, -.17922600E+01, -.72531400E+00, 0.33915700E+00, -.55285000E+00, -.13137000E+01, 0.37900500E+01, 0.28490700E+01, -.15046700E+01, -.11545100E+01, 0.24329800E+01, -.36647000E+00, -.98069200E+00, 0.72077100E+00, 0.14795600E+01, -.51887800E+01, -.69502700E+00, -.19666100E+00, 0.34170200E+01, -.62635500E+00, -.38756700E-01, 0.17208800E+00, 0.26117500E+01, 0.77091400E-01, 0.28296400E+00, -.33127800E+01, -.62484600E+00, 0.86212800E+00, 0.13600300E+00, -.16995600E+00, 0.20857200E+00, -.83343200E+00, -.40497100E-01, 0.88162200E+00, -.13260800E+00, 0.15050500E+02, -.83261900E+00, -.45626400E-01, 0.11745500E+00, 0.17609500E+00, 0.33334900E+00, -.60331900E+00, -.22040400E-01, -.28935200E+00, -.12427400E+00, 0.79966200E+00, 0.72712000E+00, -.94497700E+00, 0.72207300E+00, 0.34083100E-01, -.12354800E+00, -.30124100E+00, -.63824300E+00, -.47789700E+01, 0.22764800E+01, -.17714800E+00, -.31722700E+01, -.72681700E+00, -.50759000E+01, -.11938300E+02, -.32547100E+00, 0.21880700E+01, -.33071900E+01, 0.18758600E+01, -.11384300E+02, 0.27606900E-01, 0.92561100E-01, -.30560800E+01, 0.60215500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12890300E+02, -.61061400E+00, 0.19581100E+02, 0.80479400E+01, -.33942700E+02, -.13823300E+01, 0.33763000E+02, 0.23368800E+02, 0.10562600E+01, -.56622500E+01, -.83879300E+01, 0.52136400E+01, -.63021500E+01, 0.85129700E+01, 0.57499300E+01, -.66797700E+01, -.16612900E+01, 0.77682000E+00, 0.29847000E+01, -.28556000E+01, 0.11082700E+02, 0.89392900E+00, -.35264000E+00, -.10314500E+01, -.18713500E+01, 0.30350200E+01, -.13974900E+01, -.19867300E+00, -.89785300E+01, 0.75552400E+01, -.16516200E+01, 0.25198800E+01, -.21946900E+01, -.12415300E+01, 0.32044200E+01, -.90053700E-01, 0.17311900E+00, 0.53667300E+00, -.44776200E+01, 0.32474500E+01, 0.17688400E+01, 0.10287700E+00, -.39713400E+01, -.29667700E-01, -.29614700E+00, -.30084800E+01, 0.13404400E+01, -.22664800E+01, -.79129500E+00, 0.65219800E+01, 0.46282200E+00, 0.12048100E+01, -.15802200E+01, -.23075400E+00, 0.50248200E+00, -.46024700E+00, 0.68295200E+00, -.75654200E+00, 0.18272200E+00, -.26651000E+00, 0.55648700E+00, 0.25255400E+01, 0.14964000E+00, -.59681100E+01, 0.23400800E+01, 0.16723300E+01, 0.19861400E+01, 0.96161600E-01, 0.53738400E+00, -.53974200E+00, -.25128500E+01, 0.35653500E+00, -.92451000E+00, 0.92677000E+00, -.21957600E+01, -.10037800E+01, 0.72031100E-01, 0.24224800E+01, 0.34493600E+00, 0.52569100E+01, 0.16792000E+01, -.28015900E+01, -.22698400E+00, -.20258400E+00, 0.16285900E+01, 0.12058300E+01, -.55907100E+00, -.13153600E+01, -.50949800E+00, 0.41980800E+01, -.10480800E+01, -.16648400E+01, 0.31332500E+00, -.73214200E+01, 0.66222400E+00, -.11337500E+01, -.14946000E+01, -.51655100E+00, 0.56985100E+00, -.42959200E+01, 0.22099200E+01, -.11266100E+00, 0.11962200E+01, -.14332800E+01, -.24598700E+00, 0.57898700E+00, -.29182300E-01, 0.12370900E+00, -.40336500E+00, -.60894800E-01, -.34782500E+00, 0.33840900E+01, -.53169300E+00, 0.40728400E+00, 0.95256400E+00, -.10245600E+01, 0.31606300E+00, -.15074200E+01, -.11905800E+00, 0.28636000E+00, 0.13323800E+01, 0.63186600E+00, 0.23383400E+00, 0.17185600E+01, -.52036200E-01, 0.14403000E+01, -.10198300E+01, -.52759800E+00, 0.48286400E+01, 0.15779900E+01, 0.66201300E+00, 0.38771900E+00, 0.58437500E+00, 0.70177400E+00, 0.10584600E+01, 0.48578400E+00, -.33879800E+00, -.91752000E-01, -.39567300E+00, 0.89990800E+00, -.28539700E+00, 0.77728300E+01, 0.35905400E+01, -.30158400E+01, -.12999400E+01, 0.56742600E-01, -.94533500E-01, 0.66945200E+00, 0.14578400E+00, -.18661300E+00, -.45293000E+00, -.93397700E+00, -.41378300E+00, -.94937400E+00, 0.39903800E+00, -.23890900E+00, 0.21306800E+00, 0.18783600E+01, -.31266400E+01, -.73482100E+00, 0.82342000E+00, 0.64153600E+00, -.47891400E+00, 0.37377300E-02, 0.16525800E+01, -.14429700E+01, -.60142800E+00, 0.36145600E+00, 0.78559200E-01, -.38659900E+00, -.13632200E+01, 0.18697600E+00, 0.50817000E-01, -.33487000E-02, -.15717700E+01, 0.25620800E+00, 0.34957200E+00, 0.25141300E+01, 0.34851000E+00, 0.73091100E+00, -.33620100E+01, -.32440900E-01, 0.11276700E+00, -.40971300E+00, -.11474800E-01, -.79613300E+00, -.18060500E+00, -.54052100E+01, 0.31752300E+00, -.15201900E+01, 0.85601400E-01, 0.90317000E+00, 0.95145200E+00, -.48443200E+00, -.32808800E+00, -.23683200E-01, -.24771000E+00, 0.76343700E-01, 0.18683800E+00, -.97761800E+00, 0.31676000E+00, 0.12829300E+00, 0.44354600E+00, 0.21676600E+01, 0.70310100E-01, 0.11877500E+01, -.17588800E+01, 0.64420500E-01, -.26011400E+00, -.41796600E+01, 0.50823400E+00, -.30987100E+01, -.40210500E+00, -.56687100E+00, -.74513300E+00, 0.76654400E+00, -.30152300E+01, -.22059300E+01, -.18836000E+00, -.47447900E+00, 0.10304500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.36812900E+01, 0.11990400E-01, -.58744700E+01, -.24584100E+01, 0.12876300E+02, -.35549700E-02, -.10990200E+02, -.65124200E+01, -.29165100E+00, 0.18436900E+01, 0.30615600E+01, -.23379600E+01, 0.20972900E+01, -.28036900E+01, -.14688000E+01, 0.20862200E+01, 0.74691100E+00, -.20033200E+00, -.76861700E+00, 0.98379600E+00, -.22557800E+01, -.26186100E+00, -.75940600E-01, 0.34836300E+00, 0.29772000E+00, -.68680100E+00, 0.48619400E+00, 0.15871400E+00, 0.27415900E+01, -.20360600E+01, 0.55009400E+00, -.78070600E+00, 0.80191200E+00, 0.23465500E+00, -.97904900E+00, 0.38504300E+00, -.11375000E+00, -.97154500E-01, -.26064500E+00, -.97574000E+00, -.51373400E+00, 0.10865800E-01, 0.31761100E+00, 0.15767700E-01, 0.12348300E+01, 0.12295500E+01, -.56108600E+00, 0.90556900E+00, -.44377700E+00, -.18089000E+01, 0.14911700E-01, -.25632200E+00, 0.82423600E-01, 0.31536400E+00, -.36906600E+00, 0.10382400E+01, -.23519900E+00, 0.22022900E+00, -.18249500E+00, -.40864600E-01, -.32096000E-01, -.87717700E+00, 0.37280900E+00, 0.19367700E+01, -.67556200E+00, -.51761000E+00, -.40219800E+00, -.14564800E-01, -.24390400E+00, 0.23757700E-01, 0.73638100E+00, -.17091500E+00, 0.33127200E+00, -.33913800E+00, 0.83141700E+00, 0.45241100E+00, -.26963800E+00, -.12290100E+01, 0.14790100E-01, -.10628500E+01, -.20105000E+00, 0.94706300E+00, 0.12283800E+00, -.63321500E-01, 0.27249800E+00, -.49483200E+00, -.29487900E+00, -.38235100E+00, 0.26682600E+00, -.21787800E+01, 0.62455700E+00, -.43573500E-01, 0.34839300E-01, 0.14179000E+01, -.14195900E-02, 0.16355800E+00, -.12218900E+00, 0.28772900E+00, -.15853100E+00, 0.50071600E+00, -.42783300E+00, -.20204100E-01, -.12521900E+00, 0.31081500E+00, 0.24486000E+00, -.17944500E+00, -.72288300E-01, -.15673600E+00, 0.41343300E-01, 0.26739900E-01, -.16888000E-01, -.74504600E-02, -.45152800E+00, -.80910200E-01, -.28059100E+00, -.46584300E-01, 0.63106900E-01, 0.47443000E+00, 0.10489800E+00, -.91499300E-01, -.25665500E+00, -.39677200E-01, 0.35998100E-01, -.30195100E+00, -.14094400E-01, -.52963600E+00, 0.50553400E+00, 0.16975400E+00, -.66471100E+00, -.32868700E-01, 0.41397500E+00, 0.14639800E+00, -.23695700E+00, 0.77769700E-02, 0.85895100E-02, -.38910300E-01, 0.29661900E-01, 0.48994800E-01, 0.80993700E-01, -.23354100E+00, 0.98727700E-01, -.13189600E+01, -.47611500E+00, 0.43982700E+00, 0.27806100E+00, 0.42899600E-02, -.33245000E-01, 0.33997400E+00, 0.33753700E-01, -.36021700E+00, 0.12260200E+00, 0.12378200E+00, 0.15247200E-01, -.25706300E+00, -.85699600E-01, 0.13539200E+00, -.18533300E+00, -.28855500E+00, 0.87138900E+00, -.27848100E+00, 0.20994600E-01, -.11251400E+01, 0.17115300E+00, 0.42769900E-01, 0.33115300E+00, -.14274300E+00, 0.89298200E-01, -.80809000E+00, -.13651700E+00, 0.10487700E+00, 0.53616500E+00, -.89411000E-01, 0.39402400E-01, -.11922200E+00, 0.60042200E+00, 0.98159600E-01, -.10370200E+00, -.34780000E+00, -.54214600E-01, -.24602500E+00, 0.65738400E+00, -.98888500E-02, 0.47259500E-02, 0.11402800E-01, -.22246500E+00, 0.11604900E+00, -.25813100E-01, 0.18104900E+01, 0.43771700E-01, 0.82712900E-01, -.94474000E-03, -.55461500E-01, -.85945300E-01, 0.17278900E+00, 0.34195000E-01, -.42856800E-01, -.32703500E-01, 0.22242400E-01, 0.16406100E+00, 0.18575700E+00, 0.11240400E+00, 0.12597800E-01, 0.69977200E-03, -.21008800E+00, 0.79962500E-01, -.32763400E-01, 0.17097800E+00, 0.54548500E-01, -.13034100E+00, -.33860600E-01, -.88329500E+00, -.84391800E+00, -.29889700E-02, 0.66820500E+00, -.34799000E+00, 0.19091600E+00, -.77565900E+00, 0.50585600E-01, 0.50427300E-01, -.34759200E+00, -.89659800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.54217000E+01, -.22604500E-01, -.50398500E+01, -.24486900E+01, 0.15019400E+02, 0.84842000E-01, -.14955100E+02, -.68246800E+01, -.41925100E+00, 0.13092700E+01, 0.55409300E+01, -.34981100E+01, 0.34893200E+01, -.37401800E+01, -.15909900E+01, 0.24097400E+01, 0.12547800E+01, 0.89866900E-01, -.17679400E+01, 0.11194700E+01, -.49045900E+01, -.21623800E+00, -.16009200E+00, 0.77284300E+00, 0.82970800E+00, -.10283700E+01, 0.24905300E+00, 0.42346500E+00, 0.30449900E+01, -.17358200E+01, 0.69464300E+00, -.45348100E+00, 0.65479800E+00, -.30688000E+00, -.11021400E+01, 0.70676200E+00, 0.62138900E-01, 0.90797100E-01, -.79437800E+00, -.68962700E+00, -.71412500E+00, 0.51620600E-01, 0.23506200E+00, -.31538600E-01, 0.16006700E+01, 0.19336400E+01, -.83073000E+00, 0.15437100E+01, -.13340000E+01, -.15854500E+01, 0.46813900E-01, -.17367500E+00, -.86744100E+00, -.50990600E+00, -.68710200E+00, 0.76415400E+00, -.19939600E+00, 0.34479400E+00, -.37443200E+00, 0.24719200E+00, 0.75647700E-01, -.81442800E+00, 0.31425700E+00, 0.98471300E+00, -.63367400E+00, -.80354700E+00, -.23892000E+00, 0.16557100E+00, 0.44879500E+00, 0.40837800E+00, 0.87156800E+00, -.39689500E+00, -.34395300E-01, -.55128600E+00, 0.15571400E+01, 0.24648600E+00, -.48128500E+00, -.24835400E+01, -.49129900E-01, -.87646800E+00, -.49361200E+00, 0.80795000E+00, 0.76087400E-01, -.56012900E-01, 0.69667300E+00, -.76391400E+00, -.32529200E+00, -.26803700E-01, -.13928500E-01, -.19648400E+01, 0.13100000E+00, 0.13092700E-03, 0.36201900E+00, -.13221700E+01, 0.30134700E+00, -.52261800E-01, -.27832200E+00, 0.72196000E+00, -.22687000E+00, 0.25901200E+00, -.81102500E+00, -.16332300E+00, -.16194000E+00, 0.10069800E+00, 0.39249400E+00, -.30805400E+00, -.39181700E-01, -.89994400E+00, -.13638500E+00, 0.49578000E-01, -.76868300E-01, 0.13531800E+01, -.13780900E+01, 0.63834800E-01, -.87165300E+00, -.32951600E+00, 0.73916600E-01, 0.30730900E+00, 0.12823800E+00, -.86869500E-01, -.57350800E-01, 0.50982100E+00, 0.53102000E-01, -.23654500E+00, -.38039700E+00, -.31810300E+00, 0.59502900E+00, 0.14948000E+00, -.11391600E+01, -.11160000E+00, 0.15503500E+00, -.30213700E+00, -.45104900E+00, -.57319300E+00, -.12883400E+00, 0.47285100E-01, -.24601300E+00, 0.12624300E+00, 0.74051300E-02, 0.68309100E+00, -.20004600E+00, -.28347100E+01, -.16534200E+01, 0.94628200E+00, -.41302700E+00, 0.15021900E-01, -.55931100E-01, 0.38952500E+00, 0.16087100E+00, 0.19696000E+00, 0.15172500E+00, 0.25972400E+00, 0.57729200E-01, -.22500300E+00, -.15771200E+00, 0.13523200E+00, -.66282100E-02, -.20034500E-01, 0.46178500E+00, 0.72790800E+00, -.28117800E+00, -.40414000E+00, 0.42450100E+00, -.48520500E-01, -.13088600E+00, 0.51502200E+00, 0.25733600E+00, -.10491600E+01, -.85846300E-01, -.81369400E-01, 0.46826200E+00, -.19977300E+00, -.23403900E-01, -.13028700E+00, 0.65916600E+00, -.28219400E-01, -.13735100E+00, -.10650400E+01, 0.11831400E-01, 0.29648600E+00, -.29293300E+00, -.18461700E-01, 0.17889900E-01, -.13834900E+00, 0.20594700E+00, 0.19974700E+00, 0.59316400E-01, 0.12610500E+01, -.37302600E+00, -.49746400E+00, 0.37861200E-01, 0.29259100E+00, 0.25877500E+00, 0.29034700E+00, -.10360900E+00, 0.43227800E-02, 0.12606600E-01, 0.24769300E+00, -.86924600E-01, 0.75393000E+00, 0.41200700E+00, -.11211700E+00, -.42718300E-01, -.27701600E+00, 0.14394000E+00, 0.43736800E+00, 0.11071900E-01, -.11377200E+00, 0.12825700E+00, -.22727700E-01, 0.88943900E-01, 0.91190800E+01, 0.55598600E+00, 0.90965600E+00, 0.20399000E+01, -.10043400E+01, 0.88872800E+01, -.39180300E-01, 0.39650600E+00, 0.18383300E+01, -.76279600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.81819400E+01, 0.95628500E+00, -.66886000E+01, -.38286500E+01, 0.28786100E+02, -.21811500E+00, -.26684700E+02, -.12633000E+02, -.90263600E+00, 0.28153900E+01, 0.96840200E+01, -.56233000E+01, 0.66087100E+01, -.60430000E+01, -.27959700E+01, 0.48278100E+01, 0.14056800E+01, 0.17536200E+00, -.31322300E+01, 0.20987100E+01, -.11855400E+02, -.32594500E+00, -.22412200E+00, 0.11848800E+01, 0.72571600E+00, -.23648300E+01, 0.24700100E+01, 0.57294400E+00, 0.36626900E+01, -.35975800E+01, 0.13043500E+01, 0.73474600E+00, -.71321800E-01, -.88752100E+00, -.26596300E+01, 0.12919400E+01, 0.26804400E-01, 0.80843000E+00, -.19124500E+01, 0.13134700E+00, 0.64082600E+00, 0.47951200E+00, -.19008200E+01, -.62842500E+00, 0.42694400E+01, 0.33512600E+01, -.82872200E+00, 0.11010000E+01, -.48382600E+01, -.23046000E+01, 0.25883800E+00, -.61429900E+00, -.16265000E+01, -.22110000E+01, -.98349400E+00, 0.18065800E+01, -.27070100E+00, 0.46191600E+00, -.10069000E+01, 0.14088200E+01, -.40950800E+00, 0.73253600E-01, -.80029400E+00, -.21392300E+01, 0.31567300E-01, -.11625700E+01, 0.51450900E-01, 0.57629000E+00, 0.69331000E+00, 0.11613300E+00, -.77121800E+00, -.27978000E+00, -.35586800E+00, -.43470900E+00, 0.12355500E+01, 0.30544800E+00, -.87869900E+00, -.21618300E+01, 0.28397900E+00, 0.27726900E+00, -.50191900E+00, 0.10605200E+00, 0.11097100E+00, -.36034700E+00, 0.13289600E+01, 0.66267200E+00, -.41734900E-01, -.44714900E+00, 0.20357000E+00, -.40966300E+00, 0.53188600E+00, -.22236600E-01, 0.32298300E+00, -.24762800E+01, 0.42279000E+00, 0.56975100E-01, -.94700900E+00, 0.71271500E+00, -.33914000E-01, 0.23482800E+01, -.41161200E+00, -.19288200E+01, 0.48059800E+00, -.17930400E+01, 0.40453300E+00, -.60175800E+00, -.34414600E+00, -.13828300E+01, -.30972200E+00, 0.46303800E-01, 0.42049500E-01, -.10411900E+01, -.94161800E+00, -.86663100E+00, -.97241200E+00, -.59933800E+00, -.32728500E+00, 0.86717900E+00, -.33829600E+00, -.16248400E+00, -.63693300E+00, 0.11278400E+01, -.82005000E-01, 0.10924000E+01, -.11110000E+00, -.22867000E+01, 0.10721800E+01, -.99733800E-01, -.19262000E+01, 0.11897000E+01, 0.18457400E+00, 0.10066000E+01, 0.32032500E+00, 0.40889700E+00, 0.10573000E+01, 0.34601100E+00, -.21541500E+00, -.67663600E-01, -.34234500E+00, -.36843600E+00, 0.15625400E+00, 0.53210300E+01, 0.35108000E+01, -.32615800E+01, 0.36493300E+00, 0.10772800E-02, -.75468200E-01, 0.48439200E+00, 0.47798300E-01, 0.67713800E+00, 0.10733900E-01, -.53467100E+00, -.48144100E+00, -.29410900E+01, 0.39428200E-01, -.23066300E-01, -.20461600E+00, 0.78209200E+00, -.51385500E+00, -.14293300E+01, 0.75962100E+00, -.14116600E+01, -.42026900E+00, 0.11737900E+00, 0.58708300E+00, -.17763900E+01, -.28274000E+00, -.65700000E+00, -.37134400E+00, 0.29348800E+00, 0.72845900E+00, 0.55208300E+00, 0.85850200E-01, -.94096400E-01, 0.25150100E-01, 0.34125100E+00, -.37017100E-01, 0.40523900E+00, 0.34085300E+00, 0.20389000E+00, 0.24494600E+00, -.37855900E-01, 0.85944600E-01, -.51202300E+00, 0.55224800E-01, -.11832700E+00, 0.90370100E-01, 0.17275000E+01, 0.33512200E+00, -.29735700E+00, 0.78580500E-01, 0.65981000E+00, 0.48607900E+00, 0.20187900E+00, -.30360800E+00, -.21288000E-02, 0.23782000E-01, 0.36501500E+00, -.20746800E+01, -.55982000E+00, -.65391400E+00, -.68153400E-01, 0.32449400E+00, 0.10353800E+00, -.26455400E-01, 0.64467700E+00, 0.87190000E-01, 0.24918800E+00, 0.15648600E+00, 0.16407200E+00, -.97728600E+00, 0.41951700E+00, -.64311200E+00, -.31359900E+01, -.94829500E+00, 0.25793700E+01, -.15498200E-01, 0.35469900E+00, -.75164200E-01, -.45373000E+00, 0.13657800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.41644200E+01, -.49054800E+00, 0.34053800E+01, 0.18061800E+01, -.11080700E+02, -.20379700E+00, 0.11164500E+02, 0.52022400E+01, 0.51505600E+00, -.11963700E+01, -.46478800E+01, 0.30168400E+01, -.26304100E+01, 0.36324400E+01, 0.13647800E+01, -.17254200E+01, -.93765500E+00, 0.98676700E-01, 0.17536800E+01, -.78934900E+00, 0.40588900E+01, 0.14012000E+00, 0.21892600E+00, -.58351500E+00, -.59314300E+00, 0.87484700E+00, -.37664200E-01, -.37018900E+00, -.16322800E+01, 0.11940700E+01, -.49474000E+00, -.13858700E+00, -.48981600E+00, 0.99523100E-01, 0.10344000E+01, -.47643100E+00, -.67000500E-01, -.11126700E+00, 0.57696100E+00, 0.17263600E+00, 0.49941600E+00, -.78710000E-01, -.13916500E+00, 0.13594800E+00, -.81542900E+00, -.11329800E+01, 0.44302900E+00, -.86136600E+00, 0.70838700E+00, 0.10629300E+01, -.14967700E-01, 0.77914600E-01, 0.75020500E+00, 0.55092500E+00, 0.48824600E+00, -.36674800E+00, 0.22411900E+00, -.29687400E+00, 0.21077200E+00, -.63903600E-01, 0.25676100E-01, 0.47755900E+00, -.10510400E+00, -.89120400E+00, 0.41542200E+00, 0.56354300E+00, 0.45864600E+00, -.18496000E-01, -.13087800E+00, -.24404900E+00, -.50010700E+00, 0.13017000E+00, 0.10655400E+00, 0.24521500E+00, -.87354300E+00, -.38831500E-01, 0.21995000E+00, 0.15840000E+01, 0.92035700E-01, 0.64419400E+00, 0.53120500E+00, -.50648700E+00, -.41131500E-02, 0.20657500E-01, -.11637600E+00, 0.42096300E+00, -.12565700E+00, -.37786000E+00, 0.27551700E+00, 0.60946400E+00, 0.21436300E+00, -.27579700E+00, -.19865300E+00, 0.13159200E+01, 0.32990400E-01, 0.46468700E-01, 0.24728300E-02, -.36994600E+00, 0.15229800E+00, -.35878000E+00, 0.70936000E+00, -.19895200E+00, 0.12254100E+00, -.11914200E+00, -.21083800E+00, 0.23707500E+00, 0.17968700E-01, 0.44150700E+00, -.16503300E-01, -.33400700E-01, 0.10536300E+00, -.10588000E+01, 0.99426900E+00, -.12936400E+00, 0.50210100E+00, 0.38402700E+00, -.94978000E-01, -.68720600E-01, -.12717000E+00, 0.29294600E-01, -.24060200E-01, -.57723500E+00, -.14259500E+00, 0.98365600E-01, 0.22301100E+00, 0.12648300E+00, -.22662000E+00, -.85928100E-01, 0.86795400E+00, 0.55598500E-01, -.51470100E-01, 0.26159100E+00, 0.40719600E+00, 0.50490100E+00, 0.25225800E+00, -.95154700E-01, 0.23908400E+00, -.10233100E+00, 0.37111300E-02, -.53250400E+00, 0.13906200E+00, 0.13182800E+01, 0.83141000E+00, -.50635100E+00, 0.29138200E+00, -.12027500E-01, 0.59588200E-01, -.32468000E+00, -.14696500E+00, -.40395800E+00, -.12181500E+00, -.18780200E+00, -.66013500E-02, 0.39266900E+00, 0.13244200E+00, -.15156200E+00, 0.22811200E-01, 0.11784500E+00, -.58703900E+00, -.40477200E+00, 0.22350800E+00, 0.42886300E+00, -.24672500E+00, 0.49500300E-01, 0.39868700E+00, -.15461300E+00, -.17058300E+00, 0.68390700E+00, 0.95193600E-01, 0.99986200E-02, -.34954600E+00, 0.21508700E-01, 0.32484300E-01, 0.15074000E+00, -.43491000E+00, 0.67964200E-02, 0.80889800E-01, 0.50888400E+00, -.44440100E-01, -.17373900E+00, 0.55919400E-01, 0.22234800E-01, 0.83983900E-02, 0.90792200E-01, -.23743100E+00, -.11125500E+00, -.91952300E-01, -.59062800E+00, 0.16589300E+00, 0.30650400E+00, -.21964900E-01, -.15717900E+00, -.13698700E+00, -.12073600E+00, 0.42483100E-01, 0.44668800E-01, -.14101500E-01, -.24648600E+00, 0.40534700E-01, -.37840300E+00, -.15315500E+00, 0.51860300E-01, -.17665600E+00, 0.43807300E+00, -.20564700E-01, -.18707700E+00, -.24717700E+00, -.28621800E-01, -.11383700E+00, -.13721600E-01, 0.24543900E+00, -.40798800E+00, 0.31964600E+00, 0.29339900E+01, 0.13925900E+00, -.46358100E+00, 0.56693600E-01, -.10380900E+00, -.79127200E-01, -.28866500E-01, 0.97428900E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19657800E+01, -.37928500E+00, 0.77583900E+00, 0.10712900E+01, -.99237000E+01, 0.54731600E+00, 0.96706600E+01, 0.43734300E+01, -.52765500E+00, -.58809000E+00, -.35783200E+01, 0.18225000E+01, -.25305800E+01, 0.19876500E+01, 0.54947300E+00, -.12196200E+01, -.65241700E+00, -.11974900E+00, 0.11572500E+01, -.10858800E+01, 0.41396600E+01, 0.21405900E+00, 0.24061400E+00, -.61527000E+00, -.28384400E+00, 0.78000800E+00, 0.33571100E+00, -.40587700E+00, -.69929300E+00, 0.90360000E+00, -.68036300E+00, -.32330500E+00, -.36713900E-01, 0.17751900E+00, 0.17785900E+00, -.19467500E+01, -.16545200E+00, -.23733000E+00, 0.19041000E+00, -.81745400E+00, -.17829400E-01, -.15096200E+00, 0.40453100E+00, 0.32030700E+00, -.45884800E+00, -.82602700E+00, 0.19658200E+00, -.27062800E+00, 0.97104400E+00, 0.71226700E+00, -.45455300E-01, -.26712900E-01, 0.89882200E+00, 0.15155300E+01, 0.36682200E+00, 0.45538800E+00, 0.28566300E+00, -.34542200E+00, 0.22230400E+00, -.68059700E-01, 0.13038600E+00, -.48646400E+00, 0.49163200E+00, 0.57821400E+00, -.19848000E+00, 0.35358800E+00, -.20323500E+00, 0.14963100E+00, 0.37664300E+00, -.23923500E+00, -.91162800E+00, -.14018600E+00, -.16346200E+00, 0.21180500E+00, -.82467600E+00, -.21146400E+00, 0.93265700E-01, 0.12929700E+01, 0.12778800E+00, 0.27222700E+00, 0.45972900E+00, -.13387500E+00, -.89013100E-02, 0.49081900E-01, -.28114500E+00, 0.62762500E+00, -.72912500E-01, -.40336300E+00, 0.20137300E+00, 0.50967400E+00, 0.15975100E+00, -.14701600E+00, -.20570700E+00, 0.14781500E+01, 0.93619900E-01, 0.16264800E+00, 0.52646700E-01, -.34845500E+00, -.51615000E-02, -.72025500E+00, 0.78464800E+00, 0.29783000E+00, 0.14997600E+00, 0.10420100E+00, -.71894300E-01, 0.77305800E-01, 0.51764200E-01, 0.45003700E+00, -.47814900E-01, -.68923000E-02, 0.29340300E-01, -.98617000E+00, 0.50340500E+00, 0.30546500E+00, 0.45904400E+00, 0.26334400E+00, -.65287200E-01, -.34311900E+00, -.30108400E-01, 0.57377400E-01, 0.13128300E+00, -.17460400E+00, 0.23768700E-01, 0.40072800E-01, 0.13069300E+00, 0.28511900E+00, -.29491900E+00, -.15956300E+00, 0.30396800E+00, 0.13681400E+00, -.20882700E+00, 0.14902900E-01, 0.13848200E+00, 0.14964000E+00, -.24635000E-01, 0.11739900E+00, 0.10186300E+00, -.54711200E-01, -.10562800E+00, 0.68055400E-01, -.34794500E-01, 0.12531600E+00, -.12843800E+00, 0.27122000E+00, -.22213600E+00, -.21127800E-01, -.15458700E-01, -.23551400E+00, 0.22795500E-01, 0.19187300E+00, -.12664600E+00, 0.14394200E+00, 0.37156200E-01, 0.12388100E+00, -.71012600E-01, -.23808600E-02, 0.77561400E-01, 0.31593000E+00, 0.13465600E+00, 0.49934100E+00, -.60136300E-02, 0.52844700E+00, -.12267200E+00, -.31612500E-02, -.20026200E+00, 0.58887500E+00, -.52555800E-01, 0.33416600E+00, 0.57307000E-01, 0.10056900E+00, -.35776500E+00, -.28803500E-01, -.19464900E-01, 0.12244200E+00, -.55720200E+00, -.29732000E-01, 0.14799500E+00, 0.62817100E+00, -.17463300E-01, -.16331900E-01, -.21909900E+00, 0.18673200E-01, 0.63234000E-02, -.59269300E-01, 0.17546900E-01, -.11892000E+00, -.45939300E-01, -.54134800E+00, 0.21822200E+00, 0.15136800E+00, -.26362100E-01, -.14434200E+00, -.96003100E-01, -.18282900E+00, 0.55333300E-01, -.40788300E-01, -.27211300E-01, -.15217800E+00, -.24721700E+00, -.19187700E+00, -.14512500E+00, 0.42075300E-01, 0.91060100E-03, 0.33464100E+00, 0.29058100E-01, 0.80251300E-01, -.14494600E+00, -.42383700E-01, -.46324700E-01, -.35213800E-02, -.26667800E-01, -.43584800E-01, -.29687100E+00, -.20076400E+00, 0.11401000E+01, 0.68821000E+00, 0.30060500E-01, 0.23782100E-01, -.49070000E-01, 0.88879000E+00, 0.42859500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18576600E+01, -.48243300E+00, 0.15106300E+01, 0.10037200E+01, -.78392500E+01, 0.15526900E+00, 0.74320300E+01, 0.36540100E+01, -.21852300E+00, -.80666800E+00, -.24723700E+01, 0.16524000E+01, -.17712600E+01, 0.19299700E+01, 0.66997500E+00, -.97557600E+00, -.55315100E+00, 0.62954400E-01, 0.95929800E+00, -.77128300E+00, 0.25947000E+01, 0.13487800E+00, 0.18899100E+00, -.46132000E+00, -.15473700E+00, 0.55931700E+00, 0.85667600E-01, -.23200400E+00, -.68051400E+00, 0.77664300E+00, -.39641200E+00, -.20146700E+00, -.10992600E+00, 0.38503900E-01, 0.37270900E+00, -.33662400E+00, -.72919700E-01, -.48807200E-01, 0.33646700E-01, -.27034600E+00, -.37543000E-01, -.91371400E-01, 0.25451200E+00, 0.11821100E+00, -.52991800E+00, -.68687700E+00, 0.14732900E+00, -.18198700E+00, 0.10178600E+01, 0.47992500E+00, -.14824800E-01, 0.70960600E-01, 0.62360900E+00, 0.10104800E+01, 0.26379000E+00, 0.25628100E-01, 0.15983800E+00, -.23727300E+00, 0.16837100E+00, -.83011000E-01, 0.12165900E+00, -.34422300E+00, 0.22023700E+00, 0.70069900E+00, -.19406400E+00, 0.20313700E+00, -.13922000E+00, 0.90042200E-01, 0.27997000E+00, -.11873100E+00, -.56526900E+00, -.30029200E-01, 0.16680200E-01, 0.15352500E+00, -.55508800E+00, -.13328600E+00, 0.92395300E-01, 0.10025700E+01, 0.63011700E-01, 0.94097600E-01, 0.29378300E+00, -.10981300E+00, -.30150500E-02, 0.32647300E-01, -.28324400E+00, 0.22494000E+00, -.29457600E-01, -.14372300E+00, 0.41835000E-01, 0.48325000E+00, 0.46310400E-01, -.12768900E-02, -.14672900E+00, 0.97683400E+00, 0.14623400E-01, 0.86906000E-01, 0.97938900E-01, -.37737300E+00, 0.44163500E-01, -.38147500E+00, 0.47403300E+00, 0.41842600E+00, 0.12876200E+00, -.93175100E-01, -.77348100E-01, 0.36396500E-01, 0.25204300E-01, 0.34350300E+00, 0.98188100E-02, -.11669700E-01, 0.25531500E-01, -.54723500E+00, 0.53505800E+00, 0.20184100E+00, 0.33664300E+00, 0.19974300E+00, -.97811500E-01, -.19230400E+00, -.61713600E-01, 0.26349000E-01, 0.17290000E-01, -.27738800E+00, -.25431700E-01, 0.11519400E+00, 0.14116300E+00, 0.82498300E-01, -.69267600E-01, -.77508800E-01, 0.10622000E+00, -.24916400E-01, -.18625300E+00, 0.37656900E-01, 0.19925900E+00, 0.13588900E+00, 0.56657400E-01, -.17968900E-01, 0.10458300E+00, 0.69954800E-02, -.41107600E-01, -.12587900E+00, 0.39073800E-02, 0.24571200E+00, 0.27091300E+00, -.12155800E+00, 0.11809900E+00, -.11629600E-01, 0.14072800E-01, -.13900800E+00, -.51320500E-01, -.12145700E+00, -.80631300E-01, -.42883600E-01, 0.17159400E-01, 0.75582900E-01, 0.23460000E-01, -.43172100E-01, -.27560800E-01, 0.79662100E-01, 0.13457600E+00, -.22038200E+00, 0.16041200E+00, 0.13060800E+00, -.14584700E+00, 0.35270600E-01, 0.24072100E+00, -.26344800E+00, -.84901500E-01, 0.30477900E+00, 0.20489200E-02, 0.74778500E-01, -.14602100E+00, 0.81725700E-01, 0.17332800E-01, 0.71476600E-01, -.29037200E+00, 0.22942100E-01, 0.68456000E-01, 0.63215400E+00, 0.51365000E-02, -.12863600E+00, 0.19093700E+00, 0.13297100E-01, -.13083300E-01, 0.13359700E-01, -.97423600E-01, -.71119400E-01, -.36598700E-01, -.16279300E+00, 0.14581000E+00, 0.24932400E+00, -.22412300E-01, -.14507400E+00, -.12396500E+00, -.14288100E+00, 0.51903000E-01, -.20023300E-01, -.89034600E-03, -.14778500E+00, -.10103100E+00, -.17231500E+00, -.13082200E+00, 0.35721700E-01, -.25645900E-01, 0.99832200E-01, -.38742100E-01, -.19928400E+00, -.42111700E-02, -.32279600E-01, -.21262900E-01, -.68561900E-02, -.94607100E-03, -.20838400E+00, -.24554200E+00, -.15130400E+00, -.31536700E-01, 0.66905200E+00, 0.14061000E-01, 0.63422000E-01, -.10972000E-01, 0.73438800E-01, 0.41279600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11425600E+01, -.97140200E+00, -.44293200E+00, 0.76515300E+00, -.11768100E+02, 0.58017500E+00, 0.10049000E+02, 0.54059000E+01, 0.18277600E-01, -.11958600E+01, -.30981800E+01, 0.16812500E+01, -.26830500E+01, 0.16641700E+01, 0.13252000E+01, -.15927500E+01, -.92092300E+00, -.12415000E+00, 0.10173200E+01, -.16275500E+01, 0.41664200E+01, 0.41349300E+00, 0.38304300E+00, -.87201900E+00, 0.10863000E+01, 0.85477300E+00, -.19199100E+01, -.34026500E+00, 0.46066300E+00, 0.11395100E+01, -.71685700E+00, -.11097300E+01, 0.89699300E+00, 0.25684400E+00, 0.75134100E+00, -.98500100E+00, 0.86522100E-01, -.51876500E+00, 0.86969500E+00, -.74212700E+00, -.25713700E+00, -.19527200E+00, 0.13700800E+01, 0.67880800E+00, -.49682000E+00, -.20936300E+00, 0.77629200E-01, 0.15398500E+00, 0.74314300E+00, 0.87868100E-01, 0.38537500E-01, -.19531500E+00, 0.12125900E+01, 0.27926200E+01, 0.42823300E-01, 0.17999300E+01, 0.25364300E+00, -.38957400E+00, -.85132900E-01, -.23001200E+00, 0.62904400E+00, -.57029600E+00, 0.35214200E+00, 0.19157700E+01, -.72034900E+00, 0.14503100E+00, -.86863000E-02, 0.12739300E+00, 0.26910100E+00, -.48643300E+00, -.84664700E+00, -.33444400E+00, 0.80675200E+00, 0.73284400E-01, -.61148500E+00, -.68606200E+00, -.23300200E+00, 0.73323700E+00, 0.18978800E+00, 0.87780600E-01, 0.47394400E+00, 0.30835100E+00, 0.27025100E-01, 0.55036900E-01, -.60940800E-02, 0.47940000E+00, -.30198800E+00, -.71930500E+00, 0.23559500E+00, 0.15521200E+00, 0.24162900E+00, -.21647900E+00, -.18886400E+00, 0.16888400E+01, 0.28543700E+00, 0.24066900E+00, 0.37870900E-01, -.33292100E+00, -.14206800E-01, -.11031500E+01, 0.81477100E+00, 0.40081100E-01, 0.61609700E-01, 0.49051200E+00, -.99532000E-01, 0.14573400E+00, 0.13815800E+00, 0.19821300E+00, -.70411500E-01, -.26975700E-01, -.64278600E-02, -.19055000E+00, 0.16888800E+00, 0.30228200E+00, 0.18715000E+00, 0.33308700E+00, 0.82609100E-01, -.20970700E+00, -.33139500E-01, 0.53381900E-01, 0.25364700E+00, -.43029900E+00, 0.59605800E-01, -.12504400E+00, 0.75193300E-01, 0.42908600E+00, -.50937700E+00, -.78018500E-01, 0.55366200E+00, -.28845600E+00, -.31631500E+00, -.11466100E+00, 0.41552200E+00, 0.76677300E-01, 0.41662400E-01, -.56481800E-01, -.39189900E-01, 0.21546600E+00, -.36961300E-01, 0.25755800E+00, -.17803800E+00, -.59032200E+00, -.58601000E+00, 0.43337600E+00, -.13613900E+00, -.10692700E-01, -.43483700E-01, -.30147300E+00, 0.65849000E-01, 0.42472600E+00, -.73329400E-01, 0.10468900E+00, 0.20756000E+00, -.30467000E-01, -.91206200E-01, 0.44474400E-01, -.39470900E-01, -.39959800E-01, 0.57822300E+00, -.36041800E+00, 0.18835900E+00, 0.48317100E+00, -.60121600E-01, 0.11350800E-01, 0.14347400E+00, -.35801500E+00, 0.10585900E-01, 0.34691300E+00, -.37716500E-01, 0.71036600E-01, -.16845300E+00, 0.77180200E-01, -.29021300E-01, -.51161900E-02, -.28525800E+00, -.30909300E-01, 0.55087500E-01, 0.75753900E+00, 0.16236200E+00, 0.36549600E+00, 0.26601900E-01, 0.66278500E-02, 0.52242100E-01, -.11293800E-01, 0.94926000E-01, -.61064700E-01, -.29700100E-01, -.42997100E+00, 0.34140200E-01, 0.18354900E-01, -.10238800E-01, -.67122300E-02, -.26024400E-01, -.12964000E+00, 0.24111500E-01, 0.22373900E-01, -.49712600E-01, -.65893700E-01, 0.98609700E+00, -.13476000E-01, -.78945600E-02, -.15347000E-02, -.57458000E-02, -.39419900E-01, -.12241900E-01, -.17492000E-01, -.82874300E-03, 0.93732900E-04, 0.34614500E-02, 0.18580300E-02, -.10074600E-02, -.13848000E-01, 0.28063700E-02, 0.42560000E-02, 0.14280600E-01, -.19032600E-01, 0.26385900E+00, 0.44662000E-02, 0.65574700E-02, -.45556200E-02, -.68951200E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.91071600E+00, 0.79650300E+00, -.41007300E+00, -.13078600E+00, 0.44646800E+01, 0.13866600E+00, -.41077700E+01, -.21770800E+01, -.41240000E+00, 0.51491500E+00, 0.13271400E+01, -.96123300E+00, 0.89504100E+00, -.13505500E+01, -.54197000E+00, 0.74285200E+00, 0.23864300E+00, -.21678900E+00, -.79566400E+00, 0.12596100E+00, -.18123800E+01, 0.55099100E-01, -.24400200E+00, 0.50576200E-01, 0.67826900E-01, -.36088500E+00, 0.72860100E+00, 0.42594200E-01, 0.11762000E+00, -.39854600E+00, 0.10702600E+00, 0.46700500E+00, -.41507600E-01, 0.26855500E-01, -.58879600E+00, 0.27590400E+00, -.29405300E-01, 0.25218000E+00, -.19492600E+00, 0.24111300E+00, 0.40116300E+00, 0.99484500E-01, -.58342000E+00, -.22646900E+00, 0.37156900E+00, 0.50653900E+00, -.14185000E+00, 0.14217100E+00, -.52128900E+00, -.72163600E-01, -.50072100E-01, -.38711700E-01, -.77972400E+00, -.84851100E+00, -.12748900E+00, -.19317500E+00, -.10153500E+00, 0.14965600E+00, -.82902300E-02, 0.22221800E+00, -.24398900E+00, -.47587300E-01, 0.10369600E+00, -.26498900E+00, 0.70804500E-01, -.13222000E+00, -.24415300E+00, 0.14696300E+00, 0.15520200E+00, -.72357700E-01, -.66164400E-01, -.38600900E-01, -.33287400E+00, -.10285600E+00, 0.26566800E+00, -.16882200E+00, -.97317600E-01, 0.21084900E-01, 0.97224600E-05, -.18458900E+00, -.23382200E+00, 0.41114200E+00, 0.12517100E-01, 0.30048800E-01, 0.23276700E+00, 0.30840300E+00, 0.15428100E+00, -.90248800E-01, 0.29437700E+00, 0.36423600E+00, 0.25526900E+00, -.91445100E-01, 0.51790200E-02, -.88381800E-01, -.32786600E+00, 0.90256500E-01, -.10218400E+00, 0.20471700E+00, -.80478800E-01, 0.49983100E+00, -.12561100E+00, -.36421200E+00, -.12503700E+00, -.16325600E-01, 0.91787700E-01, -.20701100E+00, -.59462100E-01, -.11916400E+00, 0.81433200E-01, 0.39125400E-02, -.14692000E+00, -.85588500E+00, -.29683100E-01, -.25578800E+00, -.12728500E+00, 0.10509100E-01, 0.30746000E-01, 0.11959000E+00, 0.73226500E-01, -.22019000E-01, -.22395800E-01, 0.10470100E+00, -.17478300E-01, -.16852900E+00, -.18103600E-01, -.44626800E-01, 0.58954900E-01, 0.65518200E-01, 0.47324100E-01, 0.87299100E-01, 0.12644000E+00, 0.73715300E-01, -.12090600E+00, -.21503800E+00, 0.10753200E+00, 0.13429300E+00, -.60243600E-01, -.16465500E+00, -.18016500E-01, -.27858000E-01, -.20481700E-01, 0.66877400E+00, 0.31203100E+00, -.98043800E+00, -.70499100E-01, 0.49759400E-02, -.70355100E-01, 0.14391400E+00, -.27016700E-01, 0.29155100E+00, 0.13197600E+00, 0.17895600E+00, -.40054900E-01, -.19788800E+00, -.10600000E+00, 0.13601800E+00, -.12220200E+00, -.20254700E+00, 0.91071100E+00, -.17953800E+00, -.79067100E-01, -.14297200E+00, 0.40143300E-01, -.19719500E-01, -.22031500E+00, -.24111500E+00, -.23730600E-01, -.31278800E+00, -.58420300E-01, 0.86949400E-01, 0.10097500E+00, -.17118900E-01, 0.28228400E-01, -.11566600E+00, -.28722600E-01, 0.69436400E-01, -.56363400E-01, 0.37744400E-01, 0.58877100E-01, -.22429600E+00, 0.26385800E+00, -.77922900E-02, -.10221100E+00, 0.82839400E-01, -.87331200E-01, -.11656000E+00, -.67966400E-01, 0.15587500E+00, 0.15096700E+00, -.78405400E-02, -.20827000E-02, -.50874200E-01, -.10957700E-02, -.65238000E-02, 0.12991900E-01, 0.15172300E-01, -.19945700E-01, -.11753700E+00, 0.16147500E+00, -.40726900E-02, 0.78641900E-01, 0.43232600E-01, 0.14090000E-01, -.81046700E-01, 0.51435500E-01, -.10688500E+00, 0.87912300E-01, -.40188100E-01, 0.37278000E-02, -.62085400E-02, 0.20801300E-01, -.26132900E-01, -.39148700E-01, 0.25836300E-02, -.35521400E-01, -.26645300E-01, 0.16926500E-01, 0.31047300E+00, -.61938400E-01, 0.43954500E-01, -.94909200E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.34110200E+01, -.11297800E+01, 0.26031700E+01, 0.15148700E+01, -.11113300E+02, -.15956400E+00, 0.10194500E+02, 0.51348500E+01, 0.34153000E-02, -.15296200E+01, -.33702000E+01, 0.26560900E+01, -.23245800E+01, 0.36271300E+01, 0.11689100E+01, -.14081200E+01, -.90554900E+00, 0.25263200E+00, 0.16621700E+01, -.62498900E+00, 0.40238100E+01, 0.41145000E-01, 0.35090700E+00, -.49864200E+00, -.19215700E+00, 0.79214300E+00, -.24630400E+00, -.34896200E+00, -.52167000E+00, 0.93593000E+00, -.36495500E+00, -.72557600E+00, -.34821300E+00, 0.96352300E-01, 0.10870800E+01, -.34380500E+00, -.35091700E-04, -.27448600E+00, 0.68870900E+00, -.85364800E+00, 0.26332600E+00, -.19483700E+00, 0.32189000E+00, 0.13812500E+00, -.33818900E+00, -.70697000E+00, 0.16090900E+00, -.44369500E+00, 0.21086800E+00, 0.88775600E+00, 0.99770200E-01, 0.11755900E+00, 0.92514100E+00, 0.91487500E+00, 0.49042900E-01, 0.11034700E+00, 0.25644800E+00, -.28350800E+00, 0.12914000E+00, -.11920800E+00, 0.26585500E+00, 0.17482500E+00, -.20568200E+00, -.65214400E+00, 0.29599600E+00, 0.47756600E+00, 0.83547500E+00, -.17939200E-01, 0.66545700E-01, 0.26585800E-01, -.34053600E+00, 0.85340500E-01, 0.37718500E+00, 0.10628900E+00, -.77539800E+00, 0.30383400E+00, 0.14499100E+00, 0.12141000E+01, 0.93382800E-01, 0.36972800E-01, 0.54265900E+00, -.24083500E+00, 0.32097200E-01, 0.50636600E-01, -.95146000E-01, -.34349700E+00, -.37672900E+00, -.42275300E+00, 0.17970100E+00, -.26531600E-01, 0.21537900E+00, -.25606700E+00, -.58353100E-01, 0.13923300E+01, 0.22288500E+00, 0.11275600E+00, 0.76310900E-01, -.20324100E+00, 0.83204000E-02, -.99248700E+00, 0.60356200E+00, 0.38983800E+00, 0.25603800E-01, 0.14171000E+00, -.42795200E-01, 0.12970400E+00, 0.12888700E+00, -.40623300E-01, -.34844500E-01, -.22166600E-01, 0.14329200E+00, 0.55480100E+00, 0.77999700E+00, 0.24105500E+00, 0.16943900E+00, 0.24063600E+00, -.18031100E+00, -.20927000E+00, -.71484800E-01, 0.19817300E-01, 0.59182200E-01, -.62184200E+00, 0.30026400E-02, 0.30410200E-01, 0.11537800E+00, 0.54408500E+00, -.11919200E+00, -.16001700E+00, 0.18194500E+00, -.45950500E-01, -.65206300E+00, -.33143200E-01, 0.27244200E+00, 0.36015500E+00, -.49494100E-01, -.11761200E+00, 0.15441900E+00, 0.96494400E-01, -.10153600E+00, -.20952500E+00, 0.16773600E-01, -.71955100E+00, -.51073100E+00, 0.43542500E+00, 0.60237900E-01, -.19125900E-01, 0.35963000E-01, -.39397100E+00, -.83221100E-01, -.11848700E+00, -.10331800E+00, 0.95153000E-01, 0.11516200E+00, 0.33600900E+00, -.34993300E-01, -.62113400E-01, 0.51799800E-01, 0.16610900E+00, -.11629600E+00, 0.59902500E+00, 0.19308700E-01, 0.63129200E+00, -.68192300E-01, -.15053200E-01, -.47646400E-01, -.49643200E+00, 0.56228100E-01, 0.35340700E+00, -.64534400E-01, 0.12312000E-01, -.19528900E+00, 0.40706000E-01, -.24201500E-01, 0.11810300E+00, -.29006000E+00, -.44385600E-01, 0.11613600E+00, 0.97841700E+00, -.19288400E-01, -.22844800E+00, 0.20237000E+00, 0.10661000E-01, -.65672400E-03, 0.69136800E-01, -.42288900E-02, 0.13244300E-01, -.56776200E-01, -.14514200E+00, 0.59691900E-01, 0.12717700E+00, -.20668000E-01, -.21144100E-01, -.10534100E+00, -.10878400E+00, 0.26351900E-01, -.50035200E-02, 0.11387500E-01, -.19619500E-01, 0.50458100E-01, 0.18068100E+00, 0.13191200E+00, 0.46578100E-02, -.45132500E-01, -.58013700E-01, -.94346300E-01, -.53753800E+00, 0.14380200E+00, -.81559400E-02, -.79910900E-02, -.18297700E-02, 0.87422200E-02, -.65412000E-01, 0.35323800E-01, 0.15581000E+00, -.40597400E-01, 0.23644300E+00, 0.24852200E-01, -.19949700E+00, 0.36396800E+00, -.33262900E-01, -.41144500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.33143500E+01, -.40639800E+00, 0.23521700E+01, 0.18263200E+01, -.12841200E+02, 0.48555200E+00, 0.11807800E+02, 0.59030600E+01, -.43422200E+00, -.96390100E+00, -.46287100E+01, 0.26142900E+01, -.29490100E+01, 0.29102400E+01, 0.69518300E+00, -.16265700E+01, -.40328400E+00, 0.93018000E-01, 0.14596600E+01, -.16120800E+01, 0.39708900E+01, 0.29801200E+00, 0.17214200E+00, -.77313800E+00, -.22565400E+00, 0.91046900E+00, -.18059500E+00, -.27025500E+00, -.14354600E+01, 0.12412700E+01, -.59074400E+00, -.27618300E+00, -.31739400E+00, -.40220300E-01, 0.53760500E+00, -.14338500E+01, -.64092600E-01, -.90633100E-01, 0.15651300E+00, -.12331100E+00, 0.11344400E+00, -.96760600E-01, 0.14222500E+00, 0.15985000E+00, -.61917300E+00, -.12082800E+01, 0.33852200E+00, -.58273700E+00, 0.11684800E+01, 0.61808400E+00, 0.28919000E-01, 0.36013000E-01, 0.10883400E+01, 0.15886300E+01, 0.56911500E+00, 0.39473700E+00, 0.23311500E+00, -.33991900E+00, 0.22886100E+00, -.28078300E-01, 0.27854800E+00, -.28585700E+00, 0.77680100E-01, 0.44924600E+00, -.23330400E-01, 0.41924900E+00, 0.68725900E-01, 0.93774700E-01, 0.19791000E+00, -.28001800E+00, -.72003600E+00, 0.84082000E-02, 0.23009700E+00, 0.21164600E+00, -.83128800E+00, -.30005200E+00, 0.11057800E+00, 0.14806900E+01, 0.96205900E-01, 0.16601400E+00, 0.40359000E+00, -.23706900E+00, 0.33528300E-02, 0.55438200E-01, -.24045600E+00, 0.38578800E+00, -.72523500E-01, -.33251600E+00, 0.23630500E-01, 0.75982500E+00, 0.77600000E-01, -.46591600E-01, -.22707900E+00, 0.17857900E+01, 0.33290500E-01, 0.18280400E+00, 0.18549900E+00, -.43760300E+00, -.31343600E-02, -.75276600E+00, 0.70617900E+00, 0.75939700E+00, 0.12112000E+00, 0.27023900E+00, -.67306900E-01, 0.62888600E-01, 0.78131000E-01, 0.30842600E+00, -.14276300E-01, -.22975100E-01, 0.54190800E-01, -.10392700E+01, 0.63024900E+00, 0.19370000E+00, 0.42690800E+00, 0.47918200E+00, -.58446700E-01, -.18457300E+00, -.39357700E-01, 0.37636800E-01, 0.84517300E-01, -.27858200E+00, 0.56561000E-01, 0.21232700E+00, 0.14385900E+00, 0.25040100E+00, -.16362200E+00, -.12274200E+00, 0.31741900E+00, 0.58630000E-01, -.20648500E+00, 0.28945500E-01, 0.20639300E+00, 0.19331100E+00, 0.39342800E-01, 0.61966900E-01, 0.99817500E-01, -.31561000E-01, -.88186100E-01, -.46692200E-01, 0.59511300E-01, 0.11018700E+00, 0.28388100E-01, -.35465900E-01, -.74655500E-01, -.21152200E-01, -.25133900E-01, -.28428300E+00, -.14911400E-01, 0.21898300E+00, -.81271300E-01, 0.11357000E+00, 0.10521200E-01, 0.71875400E-01, -.54972900E-01, -.78043200E-02, 0.40522700E-01, 0.10783700E+00, 0.41232200E+00, 0.30339600E+00, -.40545900E-01, 0.49861100E+00, -.76283700E-01, -.92304800E-02, -.16147700E+00, 0.74115600E+00, -.28496600E-01, 0.25740100E+00, 0.95618500E-01, 0.23846600E-01, -.37280700E+00, -.48291200E-01, -.73824200E-02, 0.80248400E-01, -.49999500E+00, -.11779000E-01, 0.56541400E-01, 0.23510500E+00, -.39815500E-01, -.10943600E+00, -.23452800E+00, 0.18435200E-01, -.33537400E-01, 0.54482100E-03, -.16967900E-01, -.13762600E+00, -.94416400E-01, -.65501000E+00, 0.18655000E+00, 0.19627000E+00, -.28441600E-01, -.16370000E+00, -.13066400E+00, -.21882400E+00, 0.62914700E-01, -.12211700E-01, -.11792000E-01, -.17712400E+00, -.16482200E+00, -.19214300E+00, -.19583000E+00, 0.50247600E-01, -.92119400E-02, 0.26214200E+00, 0.58866400E-02, 0.57671700E-01, -.15401600E+00, -.44645100E-01, -.41257500E-01, 0.38432400E-02, -.33238700E-01, -.11918200E+00, -.26261400E+00, -.13826700E+00, 0.70629900E+00, 0.22245500E+00, -.17265400E-01, 0.14157300E+00, -.91389600E-01, 0.53893600E+00, 0.16648700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.28381800E+01, 0.24267200E+00, 0.38738800E+01, 0.14448500E+01, -.58622800E+01, -.54870200E-01, 0.46609700E+01, 0.24161400E+01, -.24098800E+00, -.12319800E+01, -.11758400E+01, 0.12143700E+01, -.86008800E+00, 0.14358100E+01, 0.73368900E+00, -.12084800E+01, -.54207400E+00, -.25349800E+00, 0.55161400E-02, -.23750900E+00, 0.43738400E+00, 0.34012600E+00, -.31674400E+00, -.15100800E-01, 0.11526500E+00, 0.35508100E+00, -.27740700E+00, 0.11094200E+00, -.15147300E+01, 0.15216800E+01, -.21253600E+00, 0.45278400E+00, -.47221500E+00, -.46820900E+00, 0.39074500E+00, -.33374600E+00, 0.73775300E-02, 0.25267600E+00, -.19573400E+00, 0.70606200E+00, 0.38642700E+00, 0.80210800E-01, -.29350300E+00, 0.77399300E-01, -.31333400E+00, -.18645000E+00, 0.20838400E+00, -.17378900E+00, -.43092700E+00, 0.39401200E+00, 0.67074300E-01, 0.65289200E-01, 0.19777500E-01, -.41377800E+00, 0.69823100E-01, -.25234900E+00, 0.85083600E-01, -.83175100E-01, -.60448500E-01, 0.25455100E+00, 0.18415700E+00, 0.30545900E+00, -.24882800E+00, -.10969600E+01, 0.49443900E+00, 0.27084700E+00, 0.12396000E+00, 0.85174600E-01, 0.47151200E+00, 0.67919200E-02, -.12502200E+00, 0.58704600E-01, -.15453000E+00, 0.12389900E+00, -.25892600E+00, -.31374800E+00, 0.10445800E+00, 0.42549800E+00, -.56635700E-01, 0.16955500E+00, -.13020800E+00, -.27965200E+00, -.57771600E-01, 0.17360300E-01, -.77352200E-01, -.50561600E+00, 0.22962000E+00, 0.49516700E+00, -.55382800E-02, 0.93397300E+00, -.29593200E+00, 0.69106200E-01, 0.16170500E-01, -.89353700E+00, 0.39704800E-01, -.97596500E-01, -.17811500E-01, -.28982400E+00, 0.76100000E-01, -.33826100E+00, 0.15581700E+00, -.14823500E+00, -.89059300E-02, 0.13969700E-01, -.14700100E+00, 0.18987100E+00, 0.45621900E-01, 0.36639500E+00, 0.71737700E-02, -.59558100E-02, 0.59402900E-01, -.18580200E+00, 0.15240800E+00, 0.12584500E+00, 0.12804900E+00, 0.91982500E-01, 0.21387400E-01, -.17834800E+00, 0.71941500E-01, 0.39960000E-01, 0.17374400E+00, -.64923100E-01, 0.98936700E-01, -.52578700E-01, 0.79492400E-02, 0.42385900E+00, -.37532000E+00, -.75339600E-01, 0.75834600E+00, -.13855400E+00, 0.13810200E+00, -.26919400E+00, -.49502400E-01, -.73115600E-01, -.81789600E-01, -.32229400E-01, -.92487000E-01, -.48490000E-01, 0.77106700E-01, 0.20703600E+00, -.21122300E-01, -.62326600E+00, -.30675300E+00, 0.35385100E+00, -.19050300E+00, 0.94603800E-02, 0.23173200E-01, 0.19753000E-01, -.27197900E-01, -.16789500E+00, -.40851000E-01, 0.11423000E+00, 0.27349300E-01, 0.52567400E+00, -.13662800E-01, -.51227100E-02, 0.60591700E-01, -.48816000E+00, -.12408800E+00, 0.41479500E+00, -.25974200E+00, 0.61174700E+00, 0.48717300E-01, -.53987600E-01, -.40716900E+00, 0.69312700E+00, 0.58747200E-01, 0.34258300E+00, 0.12625800E+00, -.91610900E-01, -.28216200E+00, -.18362900E+00, -.61226700E-01, 0.10483400E+00, -.16094300E+00, -.11758800E+00, 0.25066500E-01, -.33033500E+00, -.44297300E-01, 0.30442900E-01, -.23526500E+00, 0.16243100E-01, 0.36293600E-01, 0.78499800E-01, 0.13071700E+00, 0.48220500E-01, 0.20589700E-01, -.98803300E+00, -.11360100E+00, -.18465900E+00, -.63248900E-02, 0.44507200E-01, 0.58675400E-01, -.13759200E+00, -.33369100E-01, 0.59671000E-01, -.10602900E-01, 0.87331200E-02, -.46117900E-01, 0.16162000E+00, 0.28152200E-01, 0.48834300E-03, 0.28615100E-01, -.52881000E-02, 0.70774200E-01, 0.37225300E+00, -.15225800E+00, 0.38614500E-01, -.10013000E-03, 0.16796200E-02, -.18622900E+00, 0.17907700E+00, 0.77260400E-01, 0.57989400E-01, 0.12659100E-01, -.29074200E+00, -.26131900E-01, -.30569200E+00, -.11304400E+00, 0.30891800E-01, 0.61194500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
        },
        {
            { 0.19744900E+06, -.98445900E+05, -.92254900E+05, 0.78373100E+04, -.11704000E+05, -.73998400E+05, -.36223000E+05, -.82122400E+05, -.15996200E+05, 0.25103900E+06, -.12481100E+06, -.12107500E+06, 0.18649300E+05, -.49033600E+04, -.10231600E+06, -.69053000E+05, -.11654700E+06, -.13591800E+05, 0.16135500E+05, -.80218100E+04, -.75821100E+04, 0.14373200E+04, 0.38643100E+03, -.69316900E+04, -.47897200E+04, -.10411700E+05, -.31768500E+03, 0.13521400E+06, -.67364400E+05, -.62184500E+05, 0.96252000E+04, 0.10338500E+04, -.57896500E+05, -.39478100E+05, -.91970400E+05, -.34531800E+04, 0.33609600E+04, -.16714500E+04, -.15780100E+04, 0.30145200E+03, 0.78599200E+02, -.14462900E+04, -.10026000E+04, -.21842800E+04, -.65697200E+02, -.12754900E+06, 0.63554900E+05, 0.60308500E+05, 0.53589700E+04, 0.12176700E+05, 0.38077900E+05, -.78311200E+03, 0.42030900E+05, 0.17092100E+05, -.14967800E+06, 0.74623900E+05, 0.72454400E+05, -.13722800E+05, -.10269800E+03, 0.63902900E+05, 0.43406600E+05, 0.79699200E+05, 0.53938000E+04, 0.24919600E+06, -.12414600E+06, -.12225500E+06, 0.17932600E+05, -.36327700E+04, -.10124000E+06, -.62475100E+05, -.13444400E+06, -.12927000E+05, 0.13689100E+06, -.68256200E+05, -.66714300E+05, 0.23172100E+05, 0.89977100E+04, -.68838900E+05, -.64762800E+05, -.11443700E+06, 0.44276800E+04, 0.42221600E+05, -.20978700E+05, -.19641000E+05, 0.33632300E+04, 0.98180900E+03, -.17702500E+05, -.11349700E+05, -.27463800E+05, -.11018100E+04, 0.11899400E+05, -.59156300E+04, -.55893000E+04, 0.10867900E+04, 0.32393200E+03, -.51399700E+04, -.35826200E+04, -.77885900E+04, -.20190500E+03, 0.30363400E+05, -.15090300E+05, -.14188500E+05, 0.22902300E+04, 0.43936700E+03, -.12597600E+05, -.80143400E+04, -.18766400E+05, -.10126200E+04, 0.14618000E+06, -.72694000E+05, -.73007400E+05, 0.12520500E+05, 0.76697100E+04, -.58979900E+05, -.28103800E+05, -.90999400E+05, -.13963500E+04, 0.34453800E+05, -.16988400E+05, -.17448300E+05, 0.15227700E+05, 0.16756100E+05, -.24380200E+05, -.24515700E+05, -.53358100E+05, 0.13002700E+05, -.83888400E+05, 0.41604200E+05, 0.41904200E+05, -.14959000E+05, -.55975700E+04, 0.39572100E+05, 0.32483100E+05, 0.50143500E+05, -.30452700E+04, 0.36649100E+05, -.18192500E+05, -.16332800E+05, 0.10579100E+04, 0.36130000E+04, -.15001500E+05, -.64726200E+04, -.33962900E+05, 0.69261400E+03, -.33209100E+05, 0.16384600E+05, 0.16681900E+05, -.14874400E+05, -.10045600E+05, 0.23251300E+05, 0.27505600E+05, 0.42373700E+05, -.95428000E+04, -.90174200E+05, 0.44950000E+05, 0.45027500E+05, -.15465000E+05, -.56958700E+04, 0.44421800E+05, 0.40226500E+05, 0.73209800E+05, -.23003400E+04, 0.21698800E+06, -.10798600E+06, -.10091900E+06, 0.35875400E+04, -.80622400E+04, -.77421900E+05, -.31087700E+05, -.10096200E+06, -.20991300E+05, 0.14848200E+06, -.73833200E+05, -.70148900E+05, 0.92813100E+04, 0.87848300E+03, -.56465400E+05, -.25262800E+05, -.78193400E+05, -.51355300E+04, -.18737200E+06, 0.93155800E+05, 0.85784900E+05, 0.30745200E+04, 0.92345600E+04, 0.60578500E+05, 0.78573800E+04, 0.89095700E+05, 0.21129500E+05, 0.24579100E+06, -.12225200E+06, -.11674100E+06, 0.14944000E+05, 0.31442600E+03, -.98817100E+05, -.56579500E+05, -.14449300E+06, -.94938300E+04, 0.12849400E+06, -.63781100E+05, -.57542500E+05, -.30355000E+04, -.49999700E+04, -.39815600E+05, 0.13451000E+04, -.64446700E+05, -.12771100E+05, -.14408400E+06, 0.71828700E+05, 0.65940000E+05, 0.82515200E+04, 0.15661900E+05, 0.40532500E+05, -.64318200E+04, 0.43963100E+05, 0.22287300E+05, -.17072900E+06, 0.85128200E+05, 0.79091400E+05, -.29512700E+04, 0.10122400E+05, 0.62155100E+05, 0.26020300E+05, 0.82145400E+05, 0.14370100E+05, -.10667500E+06, 0.27783200E+05, 0.23401800E+05, 0.32098100E+04, 0.46800500E+05, -.14762900E+05, -.70736500E+05, 0.70473400E+04, -.16754200E+05, -.61987300E+05, -.39815000E+05, 0.58176600E+04, -.31375700E+05, 0.10378100E+06, -.11124300E+06, 0.69911100E+05, -.73458800E+05, -.89736200E+05, -.68474500E+05, -.30898900E+05, 0.63810000E+05, -.78517300E+05, 0.41706800E+05, -.11408300E+06, 0.79465600E+05, 0.58504400E+05 },
            { 0.42594500E+00, -.65571700E+03, -.26106600E+04, -.12428000E+05, -.15026100E+05, 0.14368500E+05, 0.32337200E+05, 0.37370600E+05, -.11396700E+05, -.92903200E+05, 0.32444200E+05, 0.44786500E+05, -.23921700E+05, -.44257700E+05, 0.56168900E+05, 0.59151500E+05, 0.84533000E+05, -.23298000E+05, 0.47650600E+04, -.32609900E+04, -.25430800E+04, -.31000100E+04, -.58396200E+04, 0.18216700E+04, 0.63826900E+04, 0.76150600E+04, -.45144600E+04, 0.10532100E+06, -.54256200E+05, -.54500700E+05, -.24432400E+05, -.43137400E+05, -.51632800E+04, 0.53119100E+05, 0.52859500E+05, -.40491600E+05, 0.11627500E+04, -.74390600E+03, -.61532900E+03, -.64748300E+03, -.11963600E+04, 0.32643500E+03, 0.13287500E+04, 0.15564700E+04, -.94295400E+03, -.24022500E+04, 0.30016800E+04, 0.26290600E+04, 0.34906100E+04, 0.10183300E+05, -.51847400E+04, -.12029900E+05, -.19925100E+05, 0.69061700E+04, -.38458900E+05, 0.20108200E+05, 0.20101100E+05, 0.19363600E+05, 0.28639400E+05, -.88632200E+04, -.43486100E+05, -.44759500E+05, 0.23680900E+05, 0.47945000E+05, -.29032900E+05, -.24380700E+05, -.35394700E+05, -.56573100E+05, 0.21919300E+05, 0.72783100E+05, 0.82391100E+05, -.44715400E+05, 0.14183200E+06, -.71309900E+05, -.71055400E+05, -.38442600E+05, -.58304900E+05, -.54085800E+04, 0.75122300E+05, 0.69320700E+05, -.54287700E+05, 0.14567700E+05, -.99847300E+04, -.77734500E+04, -.83870200E+04, -.16135800E+05, 0.42952200E+04, 0.16714700E+05, 0.20417600E+05, -.12490700E+05, 0.38028700E+04, -.25544100E+04, -.20199800E+04, -.23439400E+04, -.44147800E+04, 0.13106300E+04, 0.48041400E+04, 0.57091500E+04, -.34306400E+04, 0.70128500E+04, -.53321100E+04, -.38429900E+04, -.55074100E+04, -.10622300E+05, 0.36874400E+04, 0.11316000E+05, 0.13976000E+05, -.80005700E+04, 0.83658900E+05, -.49582700E+05, -.41330500E+05, -.35727300E+05, -.72773800E+05, 0.10766000E+05, 0.66900900E+05, 0.75769500E+05, -.57789500E+05, 0.96110600E+05, -.54864800E+05, -.47827200E+05, -.28569500E+05, -.57288200E+05, -.17551000E+04, 0.49544400E+05, 0.52472900E+05, -.47888700E+05, 0.20297600E+05, -.14721700E+04, -.10158800E+05, 0.17613600E+05, 0.35621100E+05, -.24651200E+05, -.37758800E+05, -.48320900E+05, 0.22615700E+05, 0.53377700E+05, -.29353000E+05, -.27313800E+05, -.12301800E+05, -.28561400E+05, -.27573700E+04, 0.23878900E+05, 0.28009900E+05, -.24531600E+05, -.57689700E+05, 0.35482200E+05, 0.28760700E+05, 0.19797300E+05, 0.33884700E+05, -.46546700E+03, -.33704900E+05, -.35118400E+05, 0.28589700E+05, -.88917800E+05, 0.45419000E+05, 0.44218700E+05, 0.25512700E+05, 0.39060100E+05, 0.25119100E+04, -.48502200E+05, -.45812400E+05, 0.35561400E+05, -.32950300E+05, 0.87095200E+04, 0.13709100E+05, -.22312000E+05, -.47378600E+05, 0.36002800E+05, 0.52929800E+05, 0.76289300E+05, -.28953000E+05, 0.50960600E+04, -.98960400E+04, -.40241000E+04, -.23321900E+05, -.51713200E+05, 0.24034900E+05, 0.50003100E+05, 0.67005000E+05, -.35920300E+05, -.58587300E+05, 0.39239400E+05, 0.32343400E+05, 0.23457400E+05, 0.50503400E+05, -.64340500E+04, -.43348000E+05, -.61630800E+05, 0.37961200E+05, 0.62730800E+05, -.42913600E+05, -.33638600E+05, -.40770600E+05, -.82057400E+05, 0.25436200E+05, 0.85210300E+05, 0.10507100E+06, -.63672700E+05, 0.68534200E+05, -.44915900E+05, -.36863500E+05, -.21646300E+05, -.47989000E+05, -.13558000E+03, 0.33865100E+05, 0.48385600E+05, -.38000000E+05, 0.19573200E+04, -.26653900E+03, 0.15557300E+04, 0.25137400E+04, 0.73336400E+04, -.51865000E+04, -.92846100E+04, -.18891900E+05, 0.41521600E+04, -.61892500E+05, 0.31210700E+05, 0.33355700E+05, 0.15539900E+05, 0.27177900E+05, 0.42043400E+03, -.38339300E+05, -.40587000E+05, 0.25417300E+05, -.34002300E+05, -.12999500E+06, 0.94031000E+05, -.16201300E+05, -.62658500E+05, 0.24260900E+05, 0.14923400E+06, -.10216000E+06, 0.36523900E+05, 0.39989400E+05, -.11521700E+05, -.53121000E+04, -.23689000E+05, -.70501400E+05, 0.27708200E+05, 0.60212800E+05, 0.27376300E+05, -.10004200E+05, 0.43104200E+05, -.68128600E+05, 0.52217900E+05, 0.10993100E+06, -.62696800E+05, 0.11166300E+06, -.15612600E+06, -.11518100E+06 },
            { 0.30597200E+00, 0.94880700E+00, 0.11642100E+05, 0.39403700E+05, 0.32699200E+05, -.45229200E+05, -.12090500E+06, -.11539200E+06, 0.28609600E+05, 0.17429500E+06, -.88253500E+05, -.69548300E+05, 0.50958500E+05, 0.41678000E+05, -.11111700E+06, -.18633500E+06, -.20051100E+06, 0.19758300E+05, -.13197900E+05, 0.64570100E+04, 0.84110200E+04, 0.59252700E+04, 0.85575100E+04, -.23619500E+04, -.18031300E+05, -.19705000E+05, 0.73498000E+04, -.23963400E+06, 0.11983600E+06, 0.13909800E+06, 0.55752800E+05, 0.90484800E+05, 0.11116200E+05, -.15434600E+06, -.15835800E+06, 0.86431200E+05, -.29933000E+04, 0.14706400E+04, 0.18767800E+04, 0.12619500E+04, 0.18134400E+04, -.43794500E+03, -.37846200E+04, -.41168800E+04, 0.15741300E+04, 0.54662000E+05, -.27446600E+05, -.32487900E+05, -.68908900E+04, -.17825500E+05, -.15003500E+04, 0.42111600E+05, 0.43729900E+05, -.16840000E+05, 0.12583300E+06, -.62760400E+05, -.67981200E+05, -.59196900E+05, -.69293900E+05, 0.25245600E+05, 0.15133800E+06, 0.12934400E+06, -.62449200E+05, -.52988900E+05, 0.25933300E+05, 0.39612800E+05, 0.72085000E+05, 0.82172900E+05, -.62598200E+05, -.21801900E+06, -.23653100E+06, 0.66308600E+05, -.23463100E+06, 0.11701900E+06, 0.13485500E+06, 0.81486900E+05, 0.10594700E+06, -.78414400E+04, -.21976200E+06, -.22927400E+06, 0.97424500E+05, -.41603000E+05, 0.20356200E+05, 0.26271200E+05, 0.14945700E+05, 0.22954100E+05, -.32990700E+04, -.46309200E+05, -.51839000E+05, 0.19753900E+05, -.10467400E+05, 0.51275600E+04, 0.65899900E+04, 0.44858300E+04, 0.65269700E+04, -.16262700E+04, -.13552600E+05, -.14792200E+05, 0.56336600E+04, -.21566900E+05, 0.10493100E+05, 0.14402600E+05, 0.99879600E+04, 0.14733500E+05, -.42255900E+04, -.31549400E+05, -.35240400E+05, 0.12281900E+05, -.29523800E+06, 0.14681300E+06, 0.15773600E+06, 0.70730400E+05, 0.12060300E+06, 0.18193500E+05, -.17629000E+06, -.16770700E+06, 0.10893300E+06, -.37218600E+06, 0.18557000E+06, 0.18767100E+06, 0.72619400E+05, 0.12163000E+06, 0.44159500E+05, -.14224200E+06, -.11299800E+06, 0.11846900E+06, 0.55496600E+05, -.27660500E+05, -.28173200E+05, -.49135600E+05, -.58381200E+05, 0.32450200E+05, 0.11690200E+06, 0.99863200E+05, -.49709500E+05, -.15257400E+06, 0.76504800E+05, 0.83062200E+05, 0.19336800E+05, 0.46230100E+05, 0.24311400E+05, -.56516800E+05, -.66764500E+05, 0.45006200E+05, 0.20167700E+06, -.10037200E+06, -.10158300E+06, -.53707500E+05, -.72937800E+05, -.11168300E+05, 0.10842100E+06, 0.88628000E+05, -.72219200E+05, 0.16667800E+06, -.82694700E+05, -.91094100E+05, -.54229800E+05, -.70996400E+05, 0.95066200E+03, 0.14200800E+06, 0.14507600E+06, -.65230600E+05, 0.48107800E+05, -.25153300E+05, -.12093900E+04, 0.31667100E+05, 0.45245300E+05, -.54650500E+05, -.14170600E+06, -.17960900E+06, 0.22160100E+05, -.13845200E+06, 0.68864100E+05, 0.84909100E+05, 0.49354500E+05, 0.78886200E+05, -.79938200E+04, -.13707400E+06, -.13812200E+06, 0.68574600E+05, 0.20881000E+06, -.10271400E+06, -.12092100E+06, -.31826000E+05, -.66451000E+05, -.23181400E+05, 0.11949100E+06, 0.14063000E+06, -.57301900E+05, -.19602400E+06, 0.96503700E+05, 0.11840300E+06, 0.69135700E+05, 0.11158300E+06, -.18576500E+05, -.22901500E+06, -.25848400E+06, 0.98751600E+05, -.22482600E+06, 0.11044000E+06, 0.12694600E+06, 0.20571300E+05, 0.55342800E+05, 0.44362000E+05, -.80632600E+05, -.10056200E+06, 0.53690100E+05, 0.38056800E+05, -.19026300E+05, -.27837300E+05, -.31175300E+04, -.11387600E+05, -.65908200E+03, 0.35376100E+05, 0.43092300E+05, -.84924500E+04, 0.16091200E+06, -.80397000E+05, -.94614000E+05, -.36922700E+05, -.57867900E+05, -.27217700E+04, 0.11831100E+06, 0.11715600E+06, -.56813100E+05, 0.93460100E+05, 0.23460800E+06, -.21005700E+06, 0.41918600E+05, 0.55962800E+05, -.32003500E+05, -.30960400E+06, 0.16018200E+06, -.19185000E+06, -.18169300E+05, 0.28183000E+05, 0.16452100E+05, 0.51398400E+05, 0.29534500E+06, -.16577500E+06, -.96216000E+05, -.68100800E+05, -.48083300E+03, -.36493500E+05, 0.13568500E+06, -.58901700E+05, -.25736900E+06, 0.18647900E+06, -.32260100E+06, 0.32863500E+06, 0.19642400E+06 },
            { -.13501600E+00, -.27945900E-01, -.44546300E+00, 0.44863800E+05, 0.27661700E+05, -.39293200E+05, -.99187200E+05, -.82459900E+05, 0.26989800E+05, 0.11652300E+06, -.58660900E+05, -.55700500E+05, 0.60201800E+05, 0.35157200E+05, -.90277100E+05, -.14792800E+06, -.14185200E+06, 0.24203200E+05, -.12309100E+05, 0.60895700E+04, 0.62696800E+04, 0.64853000E+04, 0.70532800E+04, -.19483200E+04, -.13860900E+05, -.12378900E+05, 0.65770500E+04, -.19757900E+06, 0.98665600E+05, 0.10002800E+06, 0.55286900E+05, 0.70724800E+05, 0.87540000E+04, -.11616400E+06, -.94171600E+05, 0.72306200E+05, -.27237800E+04, 0.13497100E+04, 0.13858700E+04, 0.13719200E+04, 0.14941200E+04, -.37294800E+03, -.29136000E+04, -.25873700E+04, 0.14025900E+04, 0.59276900E+05, -.29627800E+05, -.29491400E+05, -.11024100E+05, -.16561300E+05, -.58216900E+04, 0.29946600E+05, 0.21776700E+05, -.17168800E+05, 0.70840500E+05, -.35347300E+05, -.35184300E+05, -.53742900E+05, -.48158700E+05, 0.26737000E+05, 0.11422600E+06, 0.91266700E+05, -.44247800E+05, -.84002400E+05, 0.41717100E+05, 0.42037200E+05, 0.82040400E+05, 0.75737500E+05, -.46195500E+05, -.17476200E+06, -.15548800E+06, 0.68255700E+05, -.18337200E+06, 0.91478300E+05, 0.93355400E+05, 0.82998300E+05, 0.87980600E+05, -.15525400E+05, -.17123500E+06, -.14939700E+06, 0.84769200E+05, -.38958800E+05, 0.19274500E+05, 0.19841700E+05, 0.16887800E+05, 0.19342700E+05, -.28141200E+04, -.35740200E+05, -.31912700E+05, 0.18054700E+05, -.96210900E+04, 0.47617700E+04, 0.48965900E+04, 0.48842000E+04, 0.53619500E+04, -.13572500E+04, -.10402200E+05, -.92758400E+04, 0.50116500E+04, -.21506400E+05, 0.10621600E+05, 0.11005300E+05, 0.11367200E+05, 0.12435000E+05, -.33697800E+04, -.24423000E+05, -.21955400E+05, 0.11378400E+05, -.24912200E+06, 0.12409600E+06, 0.12496600E+06, 0.70008300E+05, 0.94956500E+05, 0.16003400E+05, -.13262100E+06, -.10226400E+06, 0.90196700E+05, -.23909400E+06, 0.11923900E+06, 0.11948600E+06, 0.56484100E+05, 0.79989000E+05, 0.24460800E+05, -.98911400E+05, -.71840500E+05, 0.79004600E+05, 0.17415700E+04, -.85442600E+03, -.85480000E+03, -.42984100E+05, -.34856700E+05, 0.36207400E+05, 0.88393100E+05, 0.76053900E+05, -.29793900E+05, -.13745600E+06, 0.68709000E+05, 0.68768300E+05, 0.20454000E+05, 0.37956900E+05, 0.23083600E+05, -.40232600E+05, -.32733200E+05, 0.38740100E+05, 0.10276300E+06, -.51173000E+05, -.51406700E+05, -.43573400E+05, -.46049600E+05, 0.52784100E+04, 0.80141200E+05, 0.64441400E+05, -.45857300E+05, 0.12446900E+06, -.61930000E+05, -.63378800E+05, -.53114900E+05, -.57584400E+05, 0.79362600E+04, 0.10950700E+06, 0.95058900E+05, -.55228100E+05, -.23878100E+05, 0.11440300E+05, 0.13378800E+05, 0.48343700E+05, 0.47109700E+05, -.34991300E+05, -.11370300E+06, -.10922200E+06, 0.34248200E+05, -.10312500E+06, 0.51350800E+05, 0.53413800E+05, 0.51052900E+05, 0.57622000E+05, -.11880400E+05, -.10473700E+06, -.88932300E+05, 0.54380400E+05, 0.21076500E+06, -.10455000E+06, -.10539600E+06, -.44291000E+05, -.64011400E+05, -.25249300E+05, 0.92767300E+05, 0.75566700E+05, -.59851900E+05, -.19894400E+06, 0.98725500E+05, 0.10160400E+06, 0.79754900E+05, 0.95763500E+05, -.11594900E+05, -.17532300E+06, -.15642500E+06, 0.92390200E+05, -.22439200E+06, 0.11124400E+06, 0.11239800E+06, 0.34131800E+05, 0.57297600E+05, 0.40202000E+05, -.65864500E+05, -.50024300E+05, 0.58359200E+05, 0.57679800E+05, -.28778900E+05, -.28556300E+05, -.11061600E+05, -.14843300E+05, -.67665900E+04, 0.27544400E+05, 0.19898100E+05, -.14071300E+05, 0.13856400E+06, -.69166100E+05, -.69570400E+05, -.40857200E+05, -.47591700E+05, -.35672300E+04, 0.90669400E+05, 0.69982600E+05, -.50361100E+05, 0.85839800E+05, 0.18885000E+06, -.17394600E+06, 0.32586200E+05, 0.66011100E+05, -.24312200E+05, -.25638200E+06, 0.14636800E+06, -.10757700E+06, 0.13408600E+05, 0.21519200E+05, 0.12117300E+05, 0.39045000E+05, 0.17361700E+06, -.71895400E+05, -.10820000E+06, -.77574500E+05, 0.47255700E+05, 0.44886500E+04, 0.91417800E+05, -.61231300E+05, -.19682800E+06, 0.13052700E+06, -.21451500E+06, 0.26318500E+06, 0.16257300E+06 },
            { -.61894800E-01, 0.30819700E+00, 0.12162600E+00, -.44681200E+00, 0.31993100E+04, -.39659400E+04, -.88339600E+04, -.13261000E+05, 0.32310200E+04, 0.18403400E+05, -.88517400E+04, -.91339800E+04, -.18483100E+04, 0.79980100E+04, -.12552100E+05, -.16591700E+05, -.24350700E+05, 0.55891700E+04, -.24935500E+04, 0.12424800E+04, 0.12113000E+04, 0.33234100E+03, 0.14465500E+04, -.10549500E+03, -.18346400E+04, -.25030700E+04, 0.13476100E+04, -.26999000E+05, 0.13702300E+05, 0.13161400E+05, 0.72195500E+04, 0.13621500E+05, -.15187900E+04, -.20538800E+05, -.24970400E+05, 0.12641900E+05, -.55860000E+03, 0.27867100E+03, 0.27188600E+03, 0.74625000E+02, 0.30152500E+03, -.11444900E+02, -.38328300E+03, -.52018700E+03, 0.28390300E+03, -.83210300E+04, 0.38903200E+04, 0.41177900E+04, -.47623100E+03, -.18432600E+04, 0.45958500E+04, 0.48868800E+04, 0.10607300E+05, -.71357200E+03, 0.18271200E+05, -.91360100E+04, -.90066200E+04, -.23328900E+04, -.84044400E+04, 0.82745300E+03, 0.13101200E+05, 0.15102500E+05, -.83876900E+04, -.19844900E+05, 0.99380000E+04, 0.92726100E+04, 0.27091300E+04, 0.13300500E+05, -.31907800E+04, -.19419000E+05, -.28286000E+05, 0.12688200E+05, -.53332000E+05, 0.26559600E+05, 0.26088100E+05, 0.58800400E+04, 0.16378600E+05, 0.60743500E+04, -.21005800E+05, -.24900300E+05, 0.17481700E+05, -.73487700E+04, 0.36594200E+04, 0.35721300E+04, 0.93598700E+03, 0.39300400E+04, -.14301600E+02, -.47539600E+04, -.66982800E+04, 0.36552600E+04, -.19486100E+04, 0.97105000E+03, 0.94728300E+03, 0.26122600E+03, 0.11015700E+04, -.61574100E+02, -.13852700E+04, -.18812900E+04, 0.10285100E+04, -.41228100E+04, 0.20537000E+04, 0.20004500E+04, 0.49609400E+03, 0.25331900E+04, -.22317300E+03, -.31558500E+04, -.44926000E+04, 0.23252400E+04, -.40932900E+05, 0.20657400E+05, 0.19844800E+05, 0.55160600E+04, 0.20268400E+05, 0.27290400E+04, -.18151700E+05, -.23660000E+05, 0.18627300E+05, -.51752200E+05, 0.26183400E+05, 0.25712300E+05, 0.55338100E+04, 0.17556500E+05, 0.77859800E+04, -.13594400E+05, -.13818200E+05, 0.17332700E+05, 0.18603100E+05, -.97503500E+04, -.92711100E+04, 0.16748500E+04, -.85565200E+04, -.24166700E+04, 0.55250600E+04, 0.69311300E+04, -.82718700E+04, -.14865500E+05, 0.77957600E+04, 0.72025100E+04, 0.35978500E+04, 0.85117900E+04, 0.18309300E+03, -.88531300E+04, -.12434000E+05, 0.73570900E+04, 0.39411500E+05, -.19857300E+05, -.19648700E+05, -.15386800E+04, -.93076800E+04, -.79327400E+04, 0.64277600E+04, 0.57835500E+04, -.10452500E+05, 0.34188100E+05, -.16905100E+05, -.16872900E+05, -.40211200E+04, -.10559600E+05, -.38122200E+04, 0.13680600E+05, 0.16235000E+05, -.11178200E+05, 0.32899100E+04, -.16749700E+04, -.18983300E+04, -.12607100E+04, 0.88652300E+04, -.62293500E+04, -.12409400E+05, -.23358000E+05, 0.66730800E+04, -.18503000E+05, 0.96193200E+04, 0.91964000E+04, 0.59808900E+03, 0.12775200E+05, -.13884600E+03, -.11195500E+05, -.17557500E+05, 0.11363800E+05, 0.20657800E+05, -.10341600E+05, -.10161800E+05, -.29424400E+04, -.10745400E+05, -.41331000E+03, 0.12457900E+05, 0.22387700E+05, -.91894300E+04, -.23280600E+05, 0.11816000E+05, 0.11611400E+05, 0.55736200E+04, 0.20120900E+05, -.53773900E+04, -.27162300E+05, -.38407400E+05, 0.17566800E+05, -.24969100E+05, 0.12389100E+05, 0.12356000E+05, 0.37438200E+04, 0.10411500E+05, 0.27152500E+04, -.10115700E+05, -.17314900E+05, 0.93740800E+04, -.90491900E+04, 0.44583500E+04, 0.44429800E+04, 0.14370400E+03, -.50949000E+03, 0.38840700E+04, 0.28579000E+04, 0.95194600E+04, 0.47894000E+03, 0.11456700E+05, -.57494100E+04, -.56017000E+04, -.39384800E+04, -.76931500E+04, 0.30434400E+04, 0.14510800E+05, 0.19654000E+05, -.70396600E+04, 0.17471700E+05, 0.32093000E+05, -.21760900E+05, 0.48942300E+04, 0.59102100E+04, -.54369000E+04, -.39283300E+05, 0.21761400E+05, -.23285700E+05, -.13129300E+05, 0.59766500E+04, 0.15345000E+04, 0.90987500E+04, 0.32803500E+05, -.18312600E+05, -.78807400E+04, -.10504300E+03, -.51098800E+04, -.18144400E+05, 0.22773900E+05, -.13463400E+05, -.32165500E+05, 0.18854400E+05, -.39539800E+05, 0.42738100E+05, 0.26097100E+05 },
            { 0.70054700E+00, -.14955700E+01, -.73369900E+00, 0.92161100E+00, 0.25537300E+01, 0.22913900E+05, 0.64961700E+05, 0.73383500E+05, -.16107900E+05, -.90343000E+05, 0.43741500E+05, 0.51998700E+05, 0.16905600E+05, 0.13360100E+05, 0.53107500E+05, 0.79440000E+05, 0.99039100E+05, -.67317400E+04, -.60622900E+04, 0.30435000E+04, 0.35829800E+04, 0.35635700E+04, 0.32183800E+04, 0.19110800E+04, 0.49427200E+04, 0.95402500E+04, 0.16752700E+04, -.10629600E+05, 0.44093100E+04, 0.11008600E+05, 0.97576600E+03, 0.82698900E+03, 0.27029200E+05, 0.77531000E+05, 0.11116800E+06, -.64252100E+04, -.11715200E+04, 0.58684200E+03, 0.70062100E+03, 0.72379400E+03, 0.66177200E+03, 0.38264800E+03, 0.10492000E+04, 0.20100300E+04, 0.33684900E+03, 0.17996000E+04, 0.14791400E+03, -.17002100E+03, -.26627100E+04, 0.85163100E+03, -.95280200E+04, -.31193000E+05, -.47634300E+05, 0.23940200E+04, -.97165300E+05, 0.48560900E+05, 0.48389400E+05, 0.44532000E+04, 0.18135000E+05, 0.17059600E+04, -.73719900E+05, -.66350600E+05, 0.32977800E+05, -.18622000E+06, 0.92817000E+05, 0.96916400E+05, 0.56909100E+05, 0.68920000E+05, 0.45096500E+05, 0.42662400E+05, 0.11287000E+06, 0.49478000E+05, -.47292700E+05, 0.23857000E+05, 0.32116200E+05, 0.40361700E+05, 0.44122400E+05, 0.12956500E+05, 0.55684000E+05, 0.10666500E+06, 0.22305500E+05, -.14623300E+05, 0.73629100E+04, 0.89924600E+04, 0.10377000E+05, 0.93096200E+04, 0.35880700E+04, 0.11415100E+05, 0.24919500E+05, 0.56134300E+04, -.44285700E+04, 0.22234300E+04, 0.26296000E+04, 0.26833900E+04, 0.24175500E+04, 0.13751900E+04, 0.36831500E+04, 0.71310300E+04, 0.12695700E+04, -.10578200E+05, 0.53164300E+04, 0.63906700E+04, 0.68503400E+04, 0.59660500E+04, 0.30028200E+04, 0.80312000E+04, 0.16852800E+05, 0.33746000E+04, -.42083100E+03, -.71387400E+03, 0.51605400E+04, 0.41862500E+05, 0.26045900E+05, -.89257400E+04, 0.25322800E+05, 0.60758600E+05, 0.15740600E+05, 0.17072700E+06, -.86774700E+05, -.84438400E+05, 0.60955400E+04, -.22227100E+05, -.40261100E+05, 0.39235700E+05, 0.29690200E+05, -.32586300E+05, -.13477000E+06, 0.69489900E+05, 0.67203000E+05, -.28769400E+04, 0.25612400E+05, 0.24413500E+05, -.38155900E+05, -.24569100E+05, 0.41290900E+05, -.30779400E+05, 0.13715600E+05, 0.16995600E+05, 0.15346000E+05, 0.13222700E+05, 0.38360600E+04, 0.13636700E+05, 0.42831500E+05, 0.13912100E+05, -.14669700E+06, 0.74314000E+05, 0.72859800E+05, -.12866700E+04, 0.18854800E+05, 0.31624400E+05, -.34037900E+05, -.22713000E+05, 0.33321100E+05, 0.18450300E+05, -.99543800E+04, -.13902400E+05, -.24863000E+05, -.27871600E+05, -.47761400E+04, -.35866600E+05, -.66177200E+05, -.13918400E+05, -.94314500E+05, 0.47302100E+05, 0.52607500E+05, 0.46520400E+05, 0.38972400E+05, 0.19496100E+05, 0.21684500E+05, 0.83974800E+05, 0.30682200E+05, 0.94321700E+05, -.48629500E+05, -.41427700E+05, 0.12001100E+05, -.13294400E+05, -.12693800E+05, 0.46938800E+05, 0.60539600E+05, -.29299100E+05, 0.63897700E+04, -.31379800E+04, -.41250200E+04, -.37889300E+05, -.30547900E+05, 0.90643500E+04, -.24619900E+05, -.84477200E+05, -.26638800E+05, -.15584300E+06, 0.77026100E+05, 0.83449200E+05, 0.52764600E+05, 0.55827500E+05, 0.45208100E+05, 0.71296600E+05, 0.14807800E+06, 0.40572000E+05, -.52399900E+05, 0.26524700E+05, 0.27181200E+05, 0.42782900E+05, 0.44908300E+05, -.71351700E+04, 0.30061400E+04, 0.58681900E+05, 0.41581800E+05, 0.96588000E+04, -.45747200E+04, -.34537800E+04, -.77027900E+04, -.60445500E+04, -.57522500E+04, -.18895000E+05, -.42538700E+05, -.59602300E+04, -.44554900E+04, 0.23578400E+04, 0.60185500E+03, 0.20214000E+04, 0.25388200E+04, -.22581000E+05, -.75041300E+05, -.10017800E+06, 0.99171800E+04, 0.39690300E+05, 0.27118100E+05, -.33277400E+05, -.30571500E+04, 0.14038800E+06, -.10758300E+05, 0.24558800E+05, 0.65843300E+05, 0.12062400E+06, -.88658500E+04, 0.17158100E+05, -.51031700E+04, 0.14812200E+05, -.19439600E+06, 0.19218200E+06, -.91590700E+05, -.51228400E+05, 0.12405900E+06, 0.37176800E+05, 0.70895300E+04, -.71941300E+05, 0.55682900E+05, -.60089800E+05, 0.15966400E+06, -.46859300E+05, 0.57741500E+05 },
            { -.17956400E+01, 0.85413300E+00, 0.14101600E+01, -.15371500E+01, 0.21664300E+01, -.58405900E-01, 0.19942000E+05, 0.13763400E+04, 0.59198900E+04, -.13118200E+06, 0.65341800E+05, 0.46323000E+05, 0.12822200E+05, 0.10346000E+05, 0.25028500E+05, 0.36451400E+05, 0.37865900E+05, 0.32186300E+05, -.78711900E+04, 0.39109500E+04, 0.24884900E+04, 0.55029800E+03, 0.97259600E+03, 0.11233300E+04, 0.25683300E+04, 0.26116700E+04, 0.21972200E+04, -.55386900E+05, 0.27697400E+05, 0.12701700E+05, 0.33195200E+04, 0.12062100E+05, 0.35373600E+04, 0.14544200E+05, 0.10890000E+05, 0.20340700E+05, -.15909800E+04, 0.79081700E+03, 0.49389500E+03, 0.11295300E+03, 0.21013600E+03, 0.21478800E+03, 0.52142400E+03, 0.52453900E+03, 0.45868300E+03, 0.16594300E+04, -.10105200E+04, -.25494800E+04, 0.27466000E+04, -.33454400E+04, -.51370200E+03, -.11895700E+05, 0.26661400E+04, -.36340400E+04, 0.19954000E+05, -.99557900E+04, -.97489100E+04, 0.36362700E+04, 0.20682600E+04, -.11153300E+05, -.25799600E+05, -.10608400E+05, -.54783000E+04, -.92728100E+05, 0.46161200E+05, 0.36394400E+05, 0.42964400E+04, 0.10415300E+05, 0.23075500E+05, 0.38076100E+05, 0.32845900E+05, 0.24987600E+05, -.11598000E+06, 0.57747000E+05, 0.36048700E+05, 0.11999500E+05, 0.22210100E+05, 0.14908300E+05, 0.17711400E+05, 0.32109100E+05, 0.34841100E+05, -.20560100E+05, 0.10207500E+05, 0.58683200E+04, 0.17528800E+04, 0.32307300E+04, 0.19083900E+04, 0.58364400E+04, 0.63846500E+04, 0.63014100E+04, -.58272500E+04, 0.28953100E+04, 0.18245200E+04, 0.40204900E+03, 0.72327700E+03, 0.81613300E+03, 0.19150500E+04, 0.19554800E+04, 0.16321600E+04, -.14620100E+05, 0.72610900E+04, 0.43995200E+04, 0.11618500E+04, 0.19626900E+04, 0.17278800E+04, 0.43770000E+04, 0.46300800E+04, 0.42294200E+04, -.46725900E+05, 0.23228600E+05, 0.10531900E+05, -.83156000E+03, 0.33134000E+04, 0.67980800E+04, 0.24589200E+05, 0.19920600E+05, 0.12869400E+05, 0.27563700E+04, -.13667900E+04, -.37398700E+04, -.54133500E+04, -.58491800E+04, 0.14838500E+02, 0.11843300E+05, 0.71858700E+04, -.16939600E+04, 0.24736100E+05, -.12281500E+05, -.11941300E+05, -.32283300E+04, 0.43905700E+04, -.85496000E+04, -.83073200E+04, -.53504700E+04, -.38835400E+04, -.10834700E+05, 0.54833900E+04, 0.15379500E+04, 0.20821500E+02, 0.42378400E+04, -.15515000E+04, 0.59507700E+04, 0.50282500E+04, 0.48545300E+04, 0.11857900E+05, -.57417100E+04, -.46846400E+04, -.34043300E+04, -.16331000E+04, -.12441500E+03, 0.15940900E+04, 0.13429900E+04, -.53139800E+04, 0.74021800E+05, -.36818900E+05, -.24424500E+05, -.64122600E+04, -.12702200E+05, -.10326500E+05, -.12707600E+05, -.22205000E+05, -.21846400E+05, -.92604000E+05, 0.46063100E+05, 0.31451800E+05, 0.52266700E+04, 0.95088600E+04, 0.15373500E+05, 0.30659500E+05, 0.29321300E+05, 0.23911900E+05, -.40528300E+05, 0.20258900E+05, 0.45905500E+04, 0.65902600E+04, 0.43735800E+04, -.33822300E+04, 0.94978100E+04, 0.78771100E+04, 0.14697600E+05, 0.46108500E+05, -.22960800E+05, -.20532900E+05, 0.15556000E+03, -.15254600E+05, -.36160700E+04, -.18038200E+05, -.68390700E+04, -.19551500E+05, -.10391300E+06, 0.51771200E+05, 0.35254900E+05, 0.90675100E+04, 0.17144300E+05, 0.94709600E+04, 0.28466500E+05, 0.30580200E+05, 0.32230900E+05, -.20793800E+05, 0.10218600E+05, 0.72488800E+04, 0.23906500E+04, 0.15412300E+05, -.92741300E+04, 0.20364700E+04, 0.73004500E+03, 0.16166400E+05, -.11047600E+05, 0.54581000E+04, 0.21061100E+04, 0.39484000E+04, -.22208400E+04, 0.35262300E+04, -.14361000E+05, 0.55681500E+04, -.23959100E+04, 0.16856700E+05, -.84115400E+04, -.42445400E+04, -.10780900E+04, -.77499200E+04, 0.14864800E+04, -.11616800E+05, 0.26462400E+04, -.12550700E+05, 0.52169000E+05, 0.52872100E+04, 0.19824000E+04, 0.12211500E+02, -.99259500E+04, -.42783600E+03, 0.64244900E+04, 0.11412200E+05, 0.15733300E+05, 0.10815200E+04, 0.16452300E+05, -.22115700E+04, 0.15066400E+05, -.50061000E+05, 0.49824800E+05, -.49561300E+05, 0.87579600E+05, 0.51789100E+05, -.84120900E+04, 0.12859600E+05, -.40719400E+05, 0.14760400E+05, -.37085700E+05, 0.34587100E+05, -.23417500E+04, -.10130800E+04 },
            { -.48921400E+00, -.19215000E+00, 0.50729800E+00, -.16894600E+01, -.85776400E+00, 0.30780400E+00, 0.18767600E+00, -.38883100E+05, 0.60274300E+04, -.27711600E+04, 0.20347800E+04, 0.13777400E+05, -.20899300E+05, -.22679500E+05, 0.28968100E+05, 0.36706300E+05, -.27948900E+05, -.97234100E+04, -.47970300E+04, 0.23805100E+04, 0.29353600E+04, -.10554700E+04, -.75875100E+03, 0.30450200E+04, 0.57570800E+03, -.67012000E+04, 0.15549800E+03, -.59431800E+05, 0.30134100E+05, 0.35291800E+05, 0.80643000E+04, 0.12623100E+05, 0.17728600E+05, -.21102700E+05, -.79220000E+05, 0.14798000E+05, -.10422500E+04, 0.51837300E+03, 0.63307600E+03, -.20108000E+03, -.12783400E+03, 0.62984500E+03, 0.84672500E+02, -.14378100E+04, 0.56338200E+02, -.56544100E+05, 0.27683600E+05, 0.29005700E+05, 0.56738900E+03, 0.59659600E+04, 0.16115800E+05, -.30640500E+04, 0.39328300E+05, 0.83355800E+04, 0.94995800E+05, -.47422200E+05, -.46432100E+05, -.92292100E+04, -.20139300E+05, -.19263000E+05, 0.12663500E+05, 0.37426300E+05, -.27755700E+05, 0.99584800E+04, -.49843500E+04, -.49361800E+04, -.19492400E+05, -.22017800E+05, 0.16420000E+05, 0.20071000E+05, -.74680200E+05, -.10326300E+05, -.88374400E+05, 0.44014700E+05, 0.51789600E+05, -.10950100E+05, -.44864100E+03, 0.42130000E+05, -.51769500E+04, -.81773600E+05, 0.10311600E+05, -.98563200E+04, 0.48743200E+04, 0.66100100E+04, -.32731100E+04, -.25675700E+04, 0.79660100E+04, 0.15699700E+04, -.19425500E+05, -.60068500E+03, -.37717700E+04, 0.18723800E+04, 0.22878900E+04, -.76133400E+03, -.51650000E+03, 0.23137800E+04, 0.36985500E+03, -.50753400E+04, 0.16188800E+03, -.62725700E+04, 0.31035500E+04, 0.43097900E+04, -.24830900E+04, -.21204600E+04, 0.54740500E+04, 0.18250700E+04, -.12127500E+05, -.61910600E+03, -.65472700E+05, 0.33032200E+05, 0.34925600E+05, -.28091300E+04, 0.32122500E+04, 0.28507000E+05, 0.21903800E+04, -.66067800E+05, 0.91080600E+04, -.16194200E+06, 0.81509700E+05, 0.81139100E+05, 0.17251200E+05, 0.36295300E+05, 0.34357300E+05, -.26988700E+05, -.44865000E+05, 0.41727100E+05, 0.10271700E+06, -.52290900E+05, -.51321700E+05, 0.64625600E+03, -.11474300E+05, -.29548300E+05, -.46977900E+04, 0.62804000E+04, -.21754900E+05, -.16219000E+05, 0.89202400E+04, 0.81385700E+04, 0.97183400E+03, 0.20143700E+04, 0.70549800E+04, -.93771400E+04, -.42766600E+05, 0.11764800E+04, 0.11761600E+06, -.59174300E+05, -.59060600E+05, -.77682500E+04, -.23450900E+05, -.26341300E+05, 0.15255800E+05, 0.25278200E+05, -.30123100E+05, 0.54161600E+05, -.26683800E+05, -.32763300E+05, 0.65434000E+04, 0.41322100E+03, -.25750600E+05, 0.34092200E+04, 0.54127100E+05, -.64234800E+04, 0.38571900E+05, -.19354700E+05, -.13015300E+05, -.28540700E+05, -.34662700E+05, 0.22339800E+05, 0.38446700E+05, -.52463600E+05, -.27983900E+05, -.45595500E+05, 0.23534600E+05, 0.31723900E+05, -.61507400E+04, -.83165200E+03, 0.26929300E+05, 0.71613900E+04, -.47900000E+05, 0.58259500E+04, -.29945100E+05, 0.14946600E+05, 0.15030400E+05, 0.99485800E+04, 0.12462900E+05, -.33287600E+04, -.50678900E+04, 0.87250300E+05, 0.13364200E+05, 0.77561300E+04, -.35096700E+04, 0.64859700E+04, -.17028900E+05, -.21719300E+05, 0.22905200E+05, 0.74663600E+04, -.10915700E+06, -.14349900E+05, 0.55019300E+05, -.27706300E+05, -.26484300E+05, -.11356400E+05, -.17408600E+05, -.65835400E+03, 0.46021400E+03, -.76803400E+05, -.20020100E+05, -.72164000E+05, 0.35882400E+05, 0.37361000E+05, 0.31358600E+04, 0.99821300E+04, 0.17995200E+05, -.93173300E+04, 0.40833800E+05, 0.13315200E+05, 0.37975200E+04, -.19715800E+04, -.29015600E+04, -.58373700E+04, -.41450800E+04, 0.19970800E+04, 0.15523300E+05, 0.69331300E+05, -.52395000E+04, 0.33974300E+05, -.66664700E+04, -.54711700E+02, 0.69255000E+04, -.41680100E+05, 0.10451900E+04, -.21209700E+05, -.38614200E+05, -.12759100E+06, -.19329300E+05, 0.27419300E+05, 0.27587800E+04, 0.26730300E+05, 0.12674300E+06, -.89116300E+05, 0.61264500E+04, 0.70626600E+04, -.28285600E+05, -.25580100E+05, 0.59646600E+05, -.22741000E+05, -.19376500E+05, 0.52994900E+05, -.84122600E+05, 0.27018600E+05, -.80917200E+04 },
            { 0.55097300E+00, 0.43219500E+00, -.19367500E+00, 0.18136400E-01, 0.17626700E+00, 0.11340900E+00, -.20543200E+00, 0.15615100E-01, -.49412900E+04, 0.83759800E+04, -.40150100E+04, -.72135300E+04, 0.10490000E+04, -.26877800E+03, -.44308000E+04, -.51047900E+03, -.12272000E+04, -.67355500E+04, 0.37504200E+04, -.18788800E+04, -.20332300E+04, -.82419900E+03, -.12177000E+04, -.61269700E+03, 0.70089100E+03, 0.17539000E+03, -.17189700E+04, 0.16100200E+05, -.78902400E+04, -.97410300E+04, -.71943400E+04, -.78603400E+04, -.16744200E+04, 0.71791900E+04, 0.44675700E+04, -.10439900E+05, 0.78172700E+03, -.39124500E+03, -.42372600E+03, -.17350800E+03, -.25609800E+03, -.12717700E+03, 0.14785900E+03, 0.39122500E+02, -.36021100E+03, 0.68299800E+04, -.35762500E+04, -.36282700E+04, 0.13253800E+04, -.62777800E+03, -.23130200E+04, -.78475500E+03, -.82624700E+03, 0.39902000E+03, -.55946700E+04, 0.27773600E+04, 0.26136500E+04, 0.25091700E+03, 0.12741900E+04, 0.14064100E+04, 0.72639500E+03, 0.34714000E+03, 0.49455600E+04, 0.53656300E+05, -.26764600E+05, -.27109700E+05, -.10579900E+05, -.16905300E+05, -.80171900E+04, 0.90921700E+04, 0.13389400E+04, -.23457100E+05, 0.47629900E+05, -.23813600E+05, -.26152300E+05, -.10403700E+05, -.16557800E+05, -.73900900E+04, 0.86792100E+04, 0.33379400E+04, -.22435100E+05, 0.10730300E+05, -.53791300E+04, -.58584200E+04, -.23611000E+04, -.34770800E+04, -.18440700E+04, 0.18542200E+04, 0.36899500E+03, -.46405100E+04, 0.28607400E+04, -.14330100E+04, -.15487200E+04, -.63179400E+03, -.93189600E+03, -.46491700E+03, 0.53725500E+03, 0.13945900E+03, -.13039300E+04, 0.68418300E+04, -.34296200E+04, -.37567000E+04, -.14082500E+04, -.21418800E+04, -.12432200E+04, 0.10931000E+04, 0.14530600E+03, -.29707800E+04, 0.47463500E+05, -.23540700E+05, -.24572000E+05, -.11023800E+05, -.15418000E+05, -.75348200E+04, 0.84763800E+04, 0.30827700E+04, -.19316000E+05, 0.23157900E+05, -.11298000E+05, -.11667300E+05, -.51729900E+04, -.70590300E+04, -.38311300E+04, 0.34081900E+04, 0.25846300E+04, -.10073500E+05, -.29439400E+04, 0.11080600E+04, 0.14885000E+04, -.25965600E+04, -.19826900E+04, 0.20610800E+04, 0.34539000E+04, 0.25028700E+04, 0.35309800E+04, 0.20466500E+05, -.99552600E+04, -.10434700E+05, -.63594000E+04, -.77787500E+04, -.19087600E+04, 0.59901500E+04, 0.22886200E+04, -.86993800E+04, -.76098700E+04, 0.36209900E+04, 0.39041000E+04, 0.52189800E+03, 0.16570000E+04, 0.16807500E+04, 0.54732900E+03, -.28898700E+03, 0.56522100E+04, -.29958000E+05, 0.15088600E+05, 0.16501500E+05, 0.67305800E+04, 0.10538700E+05, 0.47275900E+04, -.52000400E+04, -.20954700E+04, 0.13728500E+05, 0.34708800E+05, -.17403700E+05, -.19113700E+05, -.41695500E+04, -.85545800E+04, -.86905700E+04, 0.12238200E+04, -.42260900E+04, -.11608100E+05, 0.97337200E+04, -.46174400E+04, -.71622400E+04, -.17640400E+04, -.18410600E+04, -.34172200E+04, 0.60746800E+03, 0.27002000E+02, -.72952300E+04, -.32149400E+05, 0.16089000E+05, 0.16129000E+05, 0.84749200E+04, 0.10367000E+05, 0.51880100E+04, -.44091400E+04, 0.18981100E+04, 0.11970800E+05, 0.51004500E+05, -.25388400E+05, -.27797000E+05, -.14246800E+05, -.18567900E+05, -.68382400E+04, 0.12347200E+05, 0.39727300E+04, -.23569700E+05, 0.37732700E+05, -.18949600E+05, -.19066700E+05, -.11542800E+05, -.13755100E+05, -.46049400E+04, 0.79378700E+04, 0.12848700E+04, -.15025100E+05, 0.20835400E+04, -.10755300E+04, -.14401600E+04, 0.12079100E+04, 0.73395400E+02, -.61274200E+03, -.43901600E+02, 0.80318400E+03, 0.44487800E+03, -.28510300E+04, 0.14033000E+04, 0.18276400E+04, 0.43308700E+04, 0.34112200E+04, -.80548700E+03, -.34782800E+04, -.19850300E+04, 0.54115600E+04, -.25643100E+05, -.20766800E+05, 0.17707600E+05, -.36525200E+04, -.14191700E+05, 0.33562900E+04, 0.22766500E+05, -.22892100E+05, 0.27413700E+04, 0.26502100E+04, -.90145800E+04, -.51123100E+03, -.10008100E+05, 0.21594500E+04, -.17172000E+05, 0.26020000E+05, 0.16837700E+05, -.24414300E+05, 0.37179900E+04, -.16021400E+05, 0.24018700E+05, 0.16547800E+05, 0.82774600E+03, 0.33915200E+04, -.22363100E+05, -.13695200E+05 },
            { -.69052900E+00, -.81394100E+00, -.45431500E+00, 0.12655400E+01, 0.18519900E+01, 0.16051500E+00, -.35238300E+00, 0.16084000E+00, 0.13188100E+01, -.93605500E+05, 0.45053800E+05, 0.42424700E+05, 0.61231900E+04, -.14244800E+05, 0.30673700E+05, 0.56965700E+04, 0.29523700E+05, -.16434800E+04, -.10820500E+05, 0.53901700E+04, 0.45026800E+04, 0.18709600E+04, 0.12534800E+04, 0.23190500E+04, -.85282600E+03, 0.97022800E+03, 0.19828900E+04, -.53188600E+05, 0.25668000E+05, 0.17552700E+05, 0.11689400E+05, 0.15737500E+05, 0.86172700E+04, -.78879000E+04, -.35218000E+04, 0.16388100E+05, -.21688900E+04, 0.10793600E+04, 0.89509800E+03, 0.38945500E+03, 0.29438600E+03, 0.44678400E+03, -.20017400E+03, 0.16078800E+03, 0.42905600E+03, 0.45761800E+04, -.13288700E+04, -.30953400E+04, 0.15034300E+04, 0.38444400E+04, -.26533400E+04, -.11515400E+04, -.35121800E+04, 0.17951000E+04, 0.15799000E+05, -.77875100E+04, -.59930200E+04, -.26758000E+04, -.10892000E+04, -.39936300E+04, 0.15062900E+04, -.22477600E+04, -.30976800E+04, -.12350700E+06, 0.61355300E+05, 0.49360600E+05, 0.25330000E+05, 0.26248900E+05, 0.22276000E+05, -.18744000E+05, 0.26497600E+04, 0.31502700E+05, -.99090800E+05, 0.49590000E+05, 0.35091800E+05, 0.27545700E+05, 0.36584900E+05, 0.10610500E+05, -.23772800E+05, -.93557500E+04, 0.36256000E+05, -.30076500E+05, 0.14988700E+05, 0.12361700E+05, 0.53446300E+04, 0.38752900E+04, 0.62121100E+04, -.27002000E+04, 0.23852400E+04, 0.58848100E+04, -.81616800E+04, 0.40656400E+04, 0.33939400E+04, 0.14218100E+04, 0.97732400E+03, 0.17357200E+04, -.66312500E+03, 0.70324800E+03, 0.15202000E+04, -.19970400E+05, 0.99467000E+04, 0.83078000E+04, 0.33727300E+04, 0.20229400E+04, 0.43627600E+04, -.14197500E+04, 0.20206700E+04, 0.34900400E+04, -.14419900E+06, 0.70842000E+05, 0.59814900E+05, 0.23220200E+05, 0.13372100E+05, 0.33239900E+05, -.98875800E+04, 0.14447400E+05, 0.24398300E+05, -.74040700E+05, 0.35261300E+05, 0.34264800E+05, 0.10344600E+05, 0.26477900E+04, 0.18388200E+05, -.45277800E+04, 0.85577900E+04, 0.94552900E+04, 0.46485300E+05, -.20786300E+05, -.22692600E+05, -.30658200E+04, 0.15528000E+05, -.17405000E+05, -.54241800E+04, -.18183300E+05, 0.55074800E+04, -.56931400E+05, 0.26801400E+05, 0.24115800E+05, 0.91376300E+04, 0.72716500E+04, 0.12117500E+05, -.43283500E+04, 0.39494400E+04, 0.11467500E+05, 0.24774800E+05, -.11027400E+05, -.11288800E+05, -.62936600E+04, -.29219500E+04, -.41888100E+04, 0.59082200E+04, -.24405300E+02, -.51177400E+04, 0.63667600E+05, -.32413500E+05, -.25175300E+05, -.16454900E+05, -.21754900E+05, -.74986100E+04, 0.14133500E+05, 0.38256400E+04, -.21971700E+05, -.10773000E+06, 0.53751900E+05, 0.45840900E+05, 0.13744100E+05, -.48365900E+03, 0.28266100E+05, -.32315300E+03, 0.20118200E+05, 0.11103300E+05, -.88123200E+05, 0.42316300E+05, 0.38919800E+05, 0.73624000E+04, -.10851200E+05, 0.27132300E+05, 0.53866800E+04, 0.23694900E+05, 0.30075000E+03, 0.78323600E+05, -.38793400E+05, -.35909000E+05, -.11852500E+05, -.94926500E+04, -.15687400E+05, 0.93144100E+04, -.77492000E+04, -.16415900E+05, -.16232000E+06, 0.80000000E+05, 0.75359100E+05, 0.24180800E+05, 0.14180600E+05, 0.35869500E+05, -.92902400E+04, 0.20352100E+05, 0.27007900E+05, -.92531000E+05, 0.46247000E+05, 0.43745200E+05, 0.15545000E+05, 0.16554700E+05, 0.16715600E+05, -.11749800E+05, 0.57463000E+04, 0.22362900E+05, -.40832300E+04, 0.22396200E+04, 0.64627100E+02, 0.24411300E+04, 0.29711600E+04, 0.35304700E+03, -.25650400E+02, -.48223600E+03, 0.18093400E+04, 0.16751700E+05, -.82370600E+04, -.50953100E+04, -.43371600E+04, -.59755100E+04, -.20748300E+04, 0.31011700E+04, 0.21355100E+04, -.62826900E+04, 0.73067900E+05, 0.17261400E+05, -.38506600E+05, 0.75220600E+04, 0.61648800E+04, 0.82231600E+03, -.16352100E+05, 0.18007000E+05, -.23202900E+05, 0.19029700E+05, 0.24727200E+05, 0.90497500E+03, 0.24865300E+05, -.19282000E+04, 0.39663000E+05, -.53709200E+05, -.41168600E+04, 0.66461400E+05, 0.26230100E+05, 0.31060400E+05, -.41525400E+05, -.17101000E+05, 0.13502900E+05, -.34378700E+04, 0.17174400E+05, 0.15304900E+05 },
            { 0.46832000E+00, -.56183500E+00, -.38562400E+00, 0.55196700E+00, -.68799700E+00, 0.25232200E-01, -.97998700E-01, 0.52525300E-01, -.28689400E+00, 0.49062300E-01, 0.58131500E+03, -.94967000E+03, 0.12464100E+04, 0.18530600E+04, -.11442800E+04, -.11467000E+04, -.24240800E+04, 0.10371400E+04, 0.82465600E+03, -.40201200E+03, -.32895000E+03, -.25920600E+03, -.12377500E+03, -.22935400E+03, -.16500600E+03, -.84820500E+03, -.16941100E+03, -.69420400E+04, 0.37360100E+04, 0.42338900E+04, -.20375900E+04, 0.15404500E+04, 0.12680400E+04, 0.26293300E+03, -.42054600E+04, 0.17579800E+04, 0.16506900E+03, -.80328400E+02, -.65058300E+02, -.53816100E+02, -.25283000E+02, -.46773900E+02, -.34579100E+02, -.17709900E+03, -.34070600E+02, 0.61170400E+04, -.33363600E+04, -.30033800E+04, 0.10114300E+04, -.65024100E+03, -.20138600E+04, -.53283300E+03, -.20480400E+04, -.10669900E+04, 0.50734600E+04, -.25672800E+04, -.30073100E+04, -.85928800E+03, -.21293000E+04, -.49453400E+03, 0.18535300E+04, 0.36053300E+04, -.16557400E+04, 0.26917300E+05, -.13274700E+05, -.11205400E+05, -.59136600E+04, -.70966900E+04, -.44314500E+04, 0.26787100E+04, -.62774900E+04, -.79895400E+04, 0.10517600E+05, -.53019400E+04, -.38345100E+04, -.31637800E+04, -.26316100E+04, -.26833000E+04, -.23765300E+04, -.11194400E+05, -.29445900E+04, 0.24738400E+04, -.12080500E+04, -.10063500E+04, -.83501000E+03, -.43041800E+03, -.67869100E+03, -.45569500E+03, -.23496600E+04, -.55480100E+03, 0.60799100E+03, -.29629300E+03, -.24012000E+03, -.19547400E+03, -.89213700E+02, -.17141300E+03, -.12916400E+03, -.65116900E+03, -.12318100E+03, 0.17328000E+04, -.84508100E+03, -.73780700E+03, -.49955000E+03, -.28006700E+03, -.48208700E+03, -.28522500E+03, -.14690800E+04, -.37939500E+03, 0.29135200E+05, -.14067900E+05, -.12665600E+05, -.62520100E+04, -.57838300E+04, -.68729900E+04, 0.89271900E+03, -.86849600E+04, -.69993400E+04, -.43085900E+04, 0.27559900E+04, 0.26239000E+04, 0.12580400E+04, 0.46322200E+04, -.19293100E+04, -.58989300E+04, -.11019300E+05, 0.36394700E+04, 0.22750800E+04, -.19379300E+04, -.12283700E+04, -.37167000E+04, -.45391700E+04, 0.26918500E+04, 0.71838200E+04, 0.80082800E+04, -.33735500E+04, 0.56154900E+04, -.23230600E+04, -.20780100E+04, -.25479500E+04, -.12935200E+04, -.97313200E+03, 0.27980200E+03, -.43805200E+04, -.12121300E+04, 0.10195400E+05, -.55485700E+04, -.52432400E+04, -.36792400E+04, -.58556000E+04, 0.93611100E+03, 0.78494200E+04, 0.98259700E+04, -.51897600E+04, -.49295200E+04, 0.26599200E+04, 0.20949100E+04, 0.20243600E+04, 0.13838600E+04, 0.11846400E+04, 0.15188100E+04, 0.67985900E+04, 0.16820000E+04, 0.16532800E+05, -.82183000E+04, -.77216500E+04, -.30956600E+04, -.36211600E+04, -.36448200E+04, 0.26888000E+03, -.39142900E+04, -.45411700E+04, 0.14602900E+04, -.15832700E+03, -.11086300E+04, 0.74433400E+03, 0.26239700E+04, -.32557200E+04, -.49401700E+04, -.71132400E+04, 0.18740100E+04, -.16017100E+05, 0.78760500E+04, 0.74060300E+04, 0.60224400E+04, 0.46515400E+04, 0.23881600E+04, -.12809100E+04, 0.43994200E+04, 0.50464700E+04, 0.13110500E+05, -.61907300E+04, -.68126600E+04, -.62595000E+04, -.38326100E+04, -.16876600E+04, 0.11430300E+04, -.89121200E+04, -.42163500E+04, 0.27347100E+05, -.13597900E+05, -.13254400E+05, -.83832800E+04, -.81844900E+04, -.41322700E+04, 0.34188300E+04, -.44387400E+04, -.83750900E+04, 0.29961200E+04, -.15499000E+04, -.13360200E+04, 0.13277700E+04, 0.23808000E+03, -.13279600E+04, -.73427700E+03, -.22788500E+04, -.64508200E+02, 0.53495600E+04, -.27020800E+04, -.30610900E+04, 0.24477000E+04, -.18958400E+03, -.21264200E+04, -.18704300E+04, -.35669200E+03, -.29059500E+03, -.54354200E+04, -.80894300E+03, 0.14504500E+04, 0.62435100E+02, -.59830200E+04, -.25508500E+03, 0.44136900E+04, -.25744800E+04, -.72828500E+04, -.53797700E+04, -.14563700E+04, 0.31534900E+03, -.11285800E+04, 0.14745900E+05, -.19383800E+05, 0.45407700E+04, 0.15844500E+05, -.12397800E+05, -.76624500E+04, -.87520000E+03, 0.49989400E+04, -.12896400E+04, 0.36159000E+04, -.10592200E+05, -.33648900E+04, -.24049000E+04 },
            { -.24766000E+00, 0.20566300E+00, -.15240100E-01, 0.13169100E+00, -.72118700E+00, -.12049600E+00, 0.18830400E-01, -.14004900E+00, 0.15625200E+00, 0.53589300E-01, 0.76090300E-01, 0.36561900E+04, -.31051700E+04, -.42114400E+04, 0.40543100E+04, 0.39875200E+04, 0.35484700E+04, -.31207500E+04, -.36669700E+03, 0.18329000E+03, 0.46504300E+03, -.19864900E+03, -.33219900E+03, 0.44223700E+03, 0.50684000E+03, 0.10645600E+04, -.24380300E+03, 0.76505200E+04, -.37977200E+04, -.94801800E+03, 0.28159800E+02, -.30515900E+04, 0.80134000E+01, 0.19683300E+03, 0.44722800E+04, -.31481500E+04, -.68555000E+02, 0.34319100E+02, 0.92989200E+02, -.40373100E+02, -.67204200E+02, 0.89277700E+02, 0.10300800E+03, 0.21971700E+03, -.50293300E+02, -.11104500E+04, 0.54081700E+03, 0.89471200E+03, -.17663300E+04, -.55606200E+03, 0.84529700E+03, 0.37697900E+03, 0.62642900E+03, -.17103800E+03, -.32911700E+04, 0.16440300E+04, 0.15483200E+04, 0.11705100E+04, 0.17836700E+04, 0.41444500E+03, -.13941100E+04, -.17162500E+04, 0.14274700E+04, -.99352800E+04, 0.49490500E+04, 0.70792500E+04, -.93210500E+03, -.11073700E+04, 0.40533400E+04, 0.33302100E+04, 0.10063300E+05, 0.10949100E+03, 0.59170600E+03, -.27533100E+03, 0.39494400E+04, -.30749900E+04, -.31723200E+04, 0.35104600E+04, 0.53925700E+04, 0.11671300E+05, -.27987200E+04, -.98777700E+03, 0.49398800E+03, 0.13480200E+04, -.50467900E+03, -.87077300E+03, 0.12634900E+04, 0.13913400E+04, 0.29830600E+04, -.64662800E+03, -.25374900E+03, 0.12687100E+03, 0.33909100E+03, -.15224600E+03, -.25603600E+03, 0.32965500E+03, 0.38601800E+03, 0.80936800E+03, -.19041400E+03, -.88565100E+03, 0.44253100E+03, 0.10054600E+04, -.35436500E+03, -.56597800E+03, 0.90724600E+03, 0.92632700E+03, 0.19317100E+04, -.39228200E+03, -.90930700E+04, 0.45157000E+04, 0.71810000E+04, -.16736000E+04, -.32054700E+04, 0.61783100E+04, 0.62952400E+04, 0.11260700E+05, -.16946900E+04, 0.53717400E+04, -.27103900E+04, -.21478600E+04, -.39826800E+04, -.60911900E+04, 0.24570600E+04, 0.72207300E+04, 0.92950600E+04, -.48832800E+04, 0.55224200E+04, -.27069400E+04, -.28553300E+04, 0.42558600E+04, 0.35806500E+04, -.46621700E+04, -.70264400E+04, -.67440700E+04, 0.21903000E+04, -.37979900E+04, 0.18779800E+04, 0.26317400E+04, 0.47133400E+03, -.91187400E+03, 0.21010800E+04, 0.17696200E+04, 0.63125600E+04, -.84635100E+03, -.39879900E+04, 0.20281200E+04, 0.17307500E+04, 0.43374100E+04, 0.44703800E+04, -.21652300E+04, -.66681300E+04, -.70821200E+04, 0.36959000E+04, -.23441800E+04, 0.11530800E+04, -.13008500E+04, 0.15512700E+04, 0.20819300E+04, -.13356600E+04, -.28040100E+04, -.63891300E+04, 0.17154400E+04, -.14076700E+05, 0.70383800E+04, 0.98255700E+04, -.65654000E+03, -.71189900E+03, 0.65760600E+04, 0.36138600E+04, 0.90166200E+04, 0.72952000E+03, -.38623500E+04, 0.19274600E+04, 0.49322200E+04, -.33800100E+04, -.42903200E+04, 0.63522800E+04, 0.69571100E+04, 0.80379400E+04, -.30881000E+04, 0.13971900E+05, -.69820200E+04, -.74880300E+04, -.32396500E+04, -.23699300E+04, -.34840800E+04, -.36283900E+03, -.72486300E+04, -.30713800E+04, -.61070700E+04, 0.30602600E+04, 0.63578500E+04, 0.28971100E+03, -.28032900E+04, 0.50694800E+04, 0.41176100E+04, 0.12435700E+05, -.19016600E+04, -.13829000E+05, 0.68980800E+04, 0.74518000E+04, 0.34012000E+04, 0.24340600E+04, 0.38062000E+04, 0.60252800E+02, 0.71389000E+04, 0.28241700E+04, 0.10959800E+04, -.54945100E+03, 0.10309900E+03, -.22446000E+04, -.13332700E+04, 0.54534700E+03, 0.74076600E+03, 0.49079600E+03, -.11886700E+04, -.16193700E+04, 0.80259200E+03, 0.41447000E+02, -.20757100E+04, 0.40686700E+02, 0.85814800E+03, 0.20545600E+04, -.71606900E+03, -.75757900E+02, 0.22692400E+04, -.60610200E+04, 0.39125600E+04, -.99045300E+03, -.12797400E+04, 0.21079500E+04, 0.21745900E+04, -.50467000E+04, 0.40807300E+04, 0.72056900E+04, 0.12000600E+04, -.54326200E+03, 0.18207800E+01, -.11170500E+05, 0.94130000E+04, 0.33441000E+04, -.85040500E+04, 0.29879800E+04, 0.70812800E+04, -.17414700E+04, -.80043400E+03, 0.79241000E+04, -.60488000E+04, 0.15549600E+05, -.38671900E+04, -.50537200E+04 },
            { 0.78394700E+00, -.82089000E-01, -.42121100E+00, 0.69681100E+00, 0.62802700E+00, 0.64876000E-01, -.23192500E+00, 0.12162100E-01, 0.23119700E+00, 0.17777400E+00, 0.13363800E+00, -.13405000E+00, 0.31621900E+04, 0.19935400E+04, -.10870500E+04, -.17012100E+04, -.37062800E+04, 0.52051600E+03, 0.54314100E+03, -.26886600E+03, -.16202500E+03, 0.80998900E+02, 0.13997800E+03, -.28489000E+03, -.34076800E+03, -.11299100E+04, 0.87489700E+01, -.57847000E+04, 0.28742100E+04, 0.39442600E+04, -.10925100E+04, 0.13049700E+04, 0.12928900E+04, 0.89838400E+03, -.48469400E+04, 0.14926400E+04, 0.10910900E+03, -.54047900E+02, -.31663900E+02, 0.14731000E+02, 0.28407300E+02, -.58215500E+02, -.69922700E+02, -.23540300E+03, 0.23661300E+01, 0.70770800E+04, -.35192400E+04, -.34214200E+04, 0.10725100E+04, 0.28366900E+03, -.26927700E+04, -.14093400E+04, -.24989300E+04, -.33164100E+03, 0.42295200E+04, -.21107100E+04, -.24393200E+04, -.14185700E+04, -.23186300E+04, -.39959600E+02, 0.20169400E+04, 0.27268600E+04, -.14604300E+04, 0.14783300E+05, -.73694100E+04, -.54896900E+04, -.34431500E+03, -.80724500E+03, -.46799900E+04, -.21204900E+04, -.11514800E+05, -.27463800E+04, 0.94811900E+04, -.47190900E+04, -.29570700E+04, 0.86656600E+03, 0.15943400E+04, -.47920900E+04, -.60495700E+04, -.16594500E+05, -.18006500E+02, 0.16870500E+04, -.83501200E+03, -.52627800E+03, 0.81107800E+02, 0.28216000E+03, -.80013500E+03, -.90943500E+03, -.31363600E+04, -.78996500E+02, 0.38596500E+03, -.19098300E+03, -.10981100E+03, 0.62448300E+02, 0.11281000E+03, -.21175900E+03, -.26191000E+03, -.86026100E+03, 0.14916800E+02, 0.13340200E+04, -.66128600E+03, -.47373000E+03, 0.98184500E+02, 0.16074200E+03, -.58646800E+03, -.60099800E+03, -.20156600E+04, -.11018500E+03, 0.10737200E+05, -.53665800E+04, -.36393700E+04, -.71673200E+02, 0.93383300E+03, -.50716900E+04, -.38041100E+04, -.11610500E+05, -.65888400E+03, -.95172300E+04, 0.47274500E+04, 0.51245900E+04, 0.38896400E+04, 0.67994500E+04, -.15385300E+04, -.74584000E+04, -.10343800E+05, 0.57540400E+04, -.11379700E+04, 0.59573800E+03, 0.49874500E+03, -.42249000E+04, -.39645800E+04, 0.35047100E+04, 0.71775500E+04, 0.67338800E+04, -.22735300E+04, 0.11501900E+04, -.59919000E+03, 0.62205000E+02, -.13167400E+04, -.55448800E+03, -.47510000E+02, 0.33169400E+03, -.44447600E+04, -.34194000E+03, 0.76622100E+04, -.38118900E+04, -.39572500E+04, -.41323600E+04, -.58290600E+04, 0.15427100E+04, 0.73142000E+04, 0.82962300E+04, -.48872500E+04, -.50368500E+04, 0.24934200E+04, 0.18291900E+04, -.81104900E+03, -.15698500E+04, 0.29232600E+04, 0.42947000E+04, 0.10788300E+05, -.29101700E+03, 0.18324400E+05, -.91199300E+04, -.82432200E+04, -.65868400E+03, -.25115000E+04, -.48532400E+04, -.16174300E+04, -.82455800E+04, -.48835100E+04, 0.33938200E+04, -.17123000E+04, -.14241100E+04, 0.22329500E+04, 0.23056100E+04, -.35154400E+04, -.54890600E+04, -.74153200E+04, 0.12668200E+04, -.14264200E+05, 0.70926400E+04, 0.66250400E+04, 0.39009300E+04, 0.34205100E+04, 0.26484700E+04, -.10032300E+04, 0.72395900E+04, 0.44577300E+04, 0.39415000E+04, -.19575700E+04, -.15437100E+04, -.14059500E+04, 0.51241500E+02, -.89792400E+03, -.67352400E+03, -.12348800E+05, -.97906400E+03, 0.17031800E+05, -.84680800E+04, -.81172000E+04, -.47733400E+04, -.42653800E+04, -.31878900E+04, 0.15082900E+04, -.72852000E+04, -.46857300E+04, 0.30739000E+04, -.15293200E+04, -.12868200E+04, 0.14957500E+04, 0.87603400E+03, -.16555900E+04, -.15548100E+04, -.19397900E+04, 0.59173500E+03, 0.35191800E+04, -.17527800E+04, -.21851000E+04, 0.23694600E+04, 0.61182100E+03, -.21023700E+04, -.30143700E+04, 0.20617500E+02, 0.50760400E+03, -.34559700E+04, 0.30685800E+04, -.34273500E+04, 0.91490400E+03, 0.19088300E+03, -.14979100E+04, -.15356800E+03, 0.17908300E+04, -.91815500E+04, -.79145000E+04, -.43863300E+03, 0.58483000E+03, 0.33662500E+03, 0.15521700E+05, -.13898400E+05, -.94051300E+03, 0.71074600E+04, -.67909600E+04, -.86301400E+04, 0.28197300E+04, 0.19506100E+04, -.45053800E+04, 0.68397600E+04, -.13449700E+05, 0.43695700E+03, 0.22220600E+04 },
            { -.79150300E+00, -.15447700E+00, 0.16840100E+00, 0.28404400E+00, 0.15114300E+01, 0.19024100E+00, 0.21129300E+00, -.31030400E-01, -.96117800E-01, 0.91789100E-01, -.68307000E+00, -.43589400E+00, -.27495100E+00, -.70147400E+04, 0.28244400E+04, 0.69194900E+04, 0.50226400E+04, -.51299600E+04, 0.23086700E+04, -.11500000E+04, -.10366300E+04, -.65052900E+03, -.14485000E+04, -.64936100E+01, 0.10352900E+04, 0.73731300E+03, -.13178400E+04, 0.14655100E+05, -.73558200E+04, -.61774700E+04, -.47585700E+04, -.85032500E+04, -.66210700E+03, 0.52263500E+04, 0.48330900E+04, -.75841900E+04, 0.49987800E+03, -.24907100E+03, -.22535800E+03, -.13782600E+03, -.29475900E+03, -.10142000E+02, 0.20739300E+03, 0.14578900E+03, -.27086500E+03, 0.48552700E+04, -.23713100E+04, -.23169600E+04, -.60782100E+03, -.74191800E+02, -.14985900E+04, -.42032900E+03, -.14129700E+04, -.29299200E+03, -.34338200E+04, 0.17125200E+04, 0.13362700E+04, 0.71353700E+03, 0.13422300E+04, 0.41433000E+03, -.71707400E+03, 0.40748500E+03, 0.16488900E+04, 0.42166400E+05, -.21027200E+05, -.19013300E+05, -.98283700E+04, -.18112500E+05, -.37311800E+04, 0.12397200E+05, 0.74144800E+04, -.17652800E+05, 0.43574400E+05, -.21730600E+05, -.19885400E+05, -.99281400E+04, -.16006600E+05, -.56148000E+04, 0.88456100E+04, 0.43304600E+04, -.15950500E+05, 0.67783700E+04, -.33760100E+04, -.30484800E+04, -.18577700E+04, -.39848900E+04, -.13334900E+03, 0.27962300E+04, 0.19824200E+04, -.36790700E+04, 0.17723200E+04, -.88288600E+03, -.79671200E+03, -.49841300E+03, -.10988500E+04, -.10632300E+02, 0.78316300E+03, 0.55621500E+03, -.10018600E+04, 0.39984500E+04, -.19912300E+04, -.17927500E+04, -.11287300E+04, -.25960200E+04, 0.25883800E+02, 0.18584300E+04, 0.13551300E+04, -.23598800E+04, 0.36062700E+05, -.18001200E+05, -.16092100E+05, -.95981600E+04, -.21113600E+05, -.89671700E+03, 0.15356600E+05, 0.10376500E+05, -.19520900E+05, 0.17394700E+05, -.86871000E+04, -.82239400E+04, -.45861500E+04, -.10312900E+05, -.43944000E+03, 0.72552200E+04, 0.47704100E+04, -.96334400E+04, 0.55805900E+04, -.28209500E+04, -.28830400E+04, -.82042400E+03, 0.33236800E+04, -.29229700E+04, -.28430700E+04, -.19894800E+04, 0.23587500E+04, 0.10597700E+05, -.53309000E+04, -.46020000E+04, -.41342900E+04, -.84368000E+04, 0.99121600E+03, 0.59778300E+04, 0.52815800E+04, -.75079800E+04, -.91402100E+04, 0.44753100E+04, 0.43983300E+04, 0.14749200E+04, 0.28295700E+04, 0.13980700E+04, -.15924800E+04, 0.26362500E+03, 0.31176700E+04, -.28520100E+05, 0.14220800E+05, 0.13490600E+05, 0.59980300E+04, 0.99866100E+04, 0.38856700E+04, -.55704100E+04, -.22986400E+04, 0.10168300E+05, 0.10892200E+05, -.54136600E+04, -.45185300E+04, -.34832200E+04, -.11886500E+05, 0.22556800E+04, 0.92373300E+04, 0.77940300E+04, -.10481000E+05, 0.12891900E+04, -.68490600E+03, -.32713800E+03, -.12281500E+04, -.84219900E+04, 0.30448700E+04, 0.63446500E+04, 0.56179700E+04, -.65608300E+04, -.18737100E+05, 0.93351700E+04, 0.88343400E+04, 0.45370300E+04, 0.91283800E+04, 0.84537600E+03, -.63920100E+04, -.42702000E+04, 0.90754100E+04, 0.33160900E+05, -.16551000E+05, -.16206500E+05, -.94893900E+04, -.22070600E+05, 0.72001600E+03, 0.16126600E+05, 0.11510900E+05, -.19890600E+05, 0.31007100E+05, -.15434100E+05, -.15133000E+05, -.69926700E+04, -.12749000E+05, -.27568400E+04, 0.82387200E+04, 0.46682000E+04, -.12707600E+05, 0.39159700E+04, -.19447800E+04, -.17055600E+04, -.76056100E+03, -.78130700E+03, -.10004200E+04, -.26812200E+03, -.11151800E+04, -.64712300E+03, -.22534100E+04, 0.11288300E+04, 0.68481600E+03, 0.17956500E+04, 0.32037200E+04, -.74363900E+03, -.18064300E+04, -.25552900E+04, 0.26106800E+04, -.15875400E+05, -.22337500E+05, 0.19847100E+05, -.32059300E+04, -.18223900E+05, 0.51669500E+04, 0.21751500E+05, -.22559100E+05, 0.92514300E+03, 0.84098300E+04, -.48787000E+04, -.59163600E+03, -.70747900E+04, -.11701200E+04, -.98580700E+04, 0.17415800E+05, 0.97820100E+03, -.12794200E+05, 0.68544800E+04, -.15076500E+05, 0.15933300E+05, 0.19162300E+05, -.57957000E+04, 0.13315800E+05, -.22931900E+05, -.21801100E+05 },
            { 0.18446100E-01, 0.27666500E-01, 0.18385500E+00, -.10785200E+01, 0.87974600E+00, 0.39134800E+00, 0.36574400E-01, 0.54631900E+00, 0.23314700E+00, -.19760700E+00, -.58985600E+00, -.18552700E+01, 0.16579000E+00, 0.39374500E+00, -.27415900E+04, -.89422900E+04, -.74971500E+03, 0.15596500E+04, 0.39020200E+03, -.18992800E+03, -.10135700E+03, -.24319000E+03, -.17673000E+03, -.10599500E+03, -.24434000E+03, 0.59267500E+03, -.15596500E+03, 0.75808500E+04, -.37978300E+04, -.28500000E+04, -.55164200E+02, -.71862900E+03, -.33176800E+04, -.36806600E+04, 0.54428200E+03, -.71743800E+03, 0.77401100E+02, -.37797800E+02, -.19131700E+02, -.50072900E+02, -.38813300E+02, -.19151300E+02, -.44048000E+02, 0.12602800E+03, -.34354100E+02, 0.22937800E+04, -.11000200E+04, -.10647000E+04, -.76909300E+03, -.22023500E+03, -.66138200E+03, 0.51236200E+02, -.31285600E+03, -.43568700E+02, 0.12107800E+04, -.60756000E+03, -.93348500E+03, 0.10531600E+04, 0.99264600E+03, -.68156600E+03, 0.43821800E+03, -.88351700E+03, 0.71435500E+03, 0.68493800E+04, -.33551100E+04, -.16402800E+04, -.33453900E+04, -.35190400E+04, -.77093500E+03, -.69878100E+03, 0.69147200E+04, -.33707200E+04, 0.43815000E+04, -.21705800E+04, -.71371700E+03, -.28862700E+04, -.21742000E+04, -.28288300E+03, 0.75707100E+03, 0.81170500E+04, -.25947300E+04, 0.65567600E+03, -.31241500E+03, -.57990500E+02, -.67447100E+03, -.57043900E+03, -.13314800E+03, -.52613500E+03, 0.18548400E+04, -.42440300E+03, 0.31586500E+03, -.15406200E+03, -.86622800E+02, -.19017500E+03, -.14433100E+03, -.79430400E+02, -.17204200E+03, 0.45624500E+03, -.12844900E+03, 0.39240600E+03, -.18611600E+03, -.32674900E+02, -.40187000E+03, -.25819900E+03, -.15282000E+03, -.51251700E+03, 0.10753700E+04, -.17527800E+03, 0.98586000E+04, -.48400600E+04, -.33113900E+04, -.44202800E+04, -.43637100E+04, -.13700200E+04, -.10582800E+04, 0.57218600E+04, -.33882700E+04, 0.65220700E+04, -.32336400E+04, -.28646000E+04, -.42609400E+04, -.52406100E+04, 0.35876900E+03, 0.14773500E+04, 0.51969500E+04, -.38642000E+04, 0.47530000E+04, -.23532400E+04, -.24565800E+04, 0.15941300E+04, -.37695100E+03, -.81407700E+03, 0.31751400E+04, -.14156600E+03, -.12825800E+04, -.13396900E+04, 0.57996600E+03, 0.11905500E+04, -.12206300E+04, -.13456000E+04, 0.12818400E+04, 0.81554800E+03, 0.55327900E+04, -.13761800E+04, 0.24264400E+03, -.14970400E+03, -.26791600E+03, 0.25193500E+04, 0.23936900E+04, -.13196600E+04, -.11277100E+04, -.29153000E+04, 0.14779700E+04, -.44837500E+04, 0.22186200E+04, 0.16352100E+04, 0.13877300E+04, 0.16244400E+04, 0.11770400E+04, 0.79387400E+03, -.40560000E+04, 0.14764000E+04, -.48809100E+04, 0.24569800E+04, 0.31800100E+04, -.56225900E+03, 0.17264200E+04, -.84780400E+03, -.60688100E+04, 0.38802900E+04, 0.25786900E+04, -.39325900E+04, 0.19543800E+04, 0.22226500E+04, -.11557700E+04, -.14439200E+02, 0.70446800E+02, -.42845200E+04, 0.19453600E+04, 0.14955800E+04, 0.14461500E+05, -.72167800E+04, -.76610000E+04, -.16784700E+03, 0.29864200E+03, -.36157100E+04, 0.20083300E+04, -.70789400E+04, -.16470300E+04, 0.35848500E+04, -.17908900E+04, -.14098400E+04, -.15548700E+04, -.16833700E+04, -.16927800E+04, -.53368700E+04, 0.74044600E+04, -.99234800E+03, -.92737700E+04, 0.46756800E+04, 0.48310200E+04, -.63591900E+03, -.21154500E+04, 0.33134400E+04, 0.70003700E+02, 0.79720800E+04, -.26654200E+03, 0.22551200E+03, -.10022500E+03, 0.69405100E+02, -.76377200E+03, 0.59713500E+02, 0.25964400E+03, 0.55755700E+03, 0.20796000E+03, -.40653600E+03, -.19436600E+04, 0.96959200E+03, 0.63654600E+03, -.15996300E+04, -.93243200E+03, 0.21132500E+04, 0.35704300E+04, 0.16114300E+04, -.11582000E+04, -.28495300E+04, -.26218000E+04, 0.61861700E+03, -.71835100E+03, -.35036400E+04, 0.13815800E+04, 0.79605100E+03, -.25660400E+04, 0.65563500E+04, 0.47120300E+04, -.25755600E+04, -.19674400E+03, -.28298400E+04, -.35385500E+04, -.22794900E+04, 0.52501300E+04, 0.14402200E+04, -.39321400E+04, 0.34140100E+04, -.61273100E+04, 0.57351800E+04, 0.13913400E+04, -.35395800E+04, 0.46708400E+04, -.14411500E+04, -.27106000E+04 },
            { 0.20943100E+01, 0.12887800E+01, -.84803700E+00, 0.86729600E+00, 0.15716500E+01, 0.55697500E+00, -.56615800E+00, -.10083600E+00, -.47989000E+00, -.16606600E+01, -.30612600E+01, -.52686500E+01, 0.12307200E+01, 0.11052100E+01, -.27310900E+01, -.15932600E+05, 0.57348600E+04, 0.38001600E+04, 0.45340700E+04, -.22411100E+04, -.24318400E+04, -.22918700E+04, -.20992000E+04, 0.15022200E+03, 0.10971800E+04, 0.45131600E+04, -.21449100E+04, 0.17970500E+05, -.89272400E+04, -.10791800E+05, -.10573400E+05, -.11062300E+05, 0.41366200E+03, -.17327300E+04, 0.23596100E+05, -.98724600E+04, 0.90190900E+03, -.44640600E+03, -.48502200E+03, -.48116400E+03, -.45369000E+03, 0.50836100E+02, 0.24918300E+03, 0.96249300E+03, -.45685600E+03, 0.32621900E+05, -.16195400E+05, -.16284200E+05, -.32051300E+04, -.78819400E+04, -.76741700E+04, 0.21835200E+04, -.38338900E+04, -.70391700E+04, 0.44001600E+04, -.22063900E+04, -.18962400E+04, 0.61579700E+04, 0.62143500E+04, -.43283000E+04, -.29110000E+04, -.71202200E+04, 0.34220200E+04, 0.55016900E+05, -.27167600E+05, -.29029400E+05, -.28139400E+05, -.33689700E+05, 0.54421400E+04, 0.20878800E+05, 0.56632200E+05, -.31058900E+05, 0.35242800E+05, -.17544900E+05, -.20824000E+05, -.28843400E+05, -.30500800E+05, 0.11058100E+05, 0.22567800E+05, 0.65388700E+05, -.30128400E+05, 0.11649200E+05, -.57465600E+04, -.63274200E+04, -.64120600E+04, -.59223700E+04, 0.81081100E+03, 0.32517500E+04, 0.13022600E+05, -.58077900E+04, 0.36082400E+04, -.17845900E+04, -.19271900E+04, -.17834200E+04, -.16633800E+04, 0.10022000E+03, 0.88917600E+03, 0.34536300E+04, -.16967800E+04, 0.67762100E+04, -.33371800E+04, -.36933200E+04, -.38421700E+04, -.32287500E+04, 0.44264900E+03, 0.15681400E+04, 0.79542900E+04, -.31825000E+04, 0.97112700E+05, -.48025100E+05, -.50091600E+05, -.37430400E+05, -.36580000E+05, -.46644100E+04, 0.21494200E+05, 0.44616100E+05, -.36161000E+05, 0.78353500E+05, -.38983000E+05, -.39228000E+05, -.30066300E+05, -.32638600E+05, -.52631400E+04, 0.19023600E+05, 0.29548400E+05, -.31938100E+05, 0.82794300E+04, -.38609400E+04, -.40430700E+04, 0.85313800E+03, -.67217600E+04, 0.23580600E+04, 0.15707900E+05, 0.84912100E+04, -.81278900E+04, 0.13766000E+05, -.73097400E+04, -.82476400E+04, -.13652200E+05, -.13803600E+05, 0.70440500E+04, 0.13730200E+05, 0.34928100E+05, -.14345400E+05, -.17040400E+05, 0.86119600E+04, 0.86254000E+04, 0.10751700E+05, 0.10906100E+05, -.76629700E+02, -.17395800E+04, -.90705700E+04, 0.95725400E+04, -.33460200E+05, 0.16622300E+05, 0.17654500E+05, 0.17140200E+05, 0.20325800E+05, -.15034800E+04, -.95557000E+04, -.37133000E+05, 0.18727700E+05, -.15235600E+05, 0.76702800E+04, 0.58876300E+04, -.71450900E+04, 0.56174300E+04, 0.61894200E+04, -.65651900E+04, 0.31926700E+05, 0.81976900E+04, -.14031200E+04, 0.77841000E+03, 0.12895000E+03, -.84439500E+04, 0.30601000E+04, 0.24239200E+04, -.83399400E+04, 0.10539000E+05, 0.20536900E+04, 0.49768700E+05, -.24813900E+05, -.24194900E+05, 0.72580100E+04, -.23412600E+04, -.16090000E+05, 0.12383100E+04, -.39958300E+05, -.74238000E+04, 0.61905900E+05, -.30871900E+05, -.30307200E+05, -.26588400E+05, -.25652600E+05, -.15091000E+04, 0.63167100E+04, 0.59021900E+05, -.24820600E+05, 0.74683000E+04, -.35335200E+04, -.43478100E+04, -.16787900E+05, -.14708700E+05, 0.95756100E+04, 0.10497800E+05, 0.42525200E+05, -.12086200E+05, 0.16196600E+05, -.80437000E+04, -.85671000E+04, -.26938900E+04, -.61686600E+04, -.14394500E+04, 0.42330700E+04, -.81143000E+03, -.75836900E+04, 0.14744600E+05, -.73642300E+04, -.61077900E+04, -.39683800E+04, -.61744600E+04, 0.16656700E+04, 0.15422800E+05, -.11434600E+04, -.81832100E+04, -.32449800E+05, -.31645100E+05, 0.23106200E+05, -.90550700E+04, -.40206900E+05, 0.10517400E+05, 0.30293400E+05, -.29832000E+05, 0.47329200E+05, 0.29353600E+05, -.16207200E+05, -.28924600E+04, -.19971800E+05, -.45125700E+05, -.54761200E+04, 0.32335900E+05, 0.55013600E+05, -.32403700E+05, 0.28187700E+05, -.39218600E+05, 0.32870400E+05, 0.35005900E+05, -.29440100E+05, 0.51819500E+05, -.28911300E+05, -.36840400E+05 },
            { -.37318100E+00, -.37137500E+00, -.70753500E+00, 0.13499800E+01, 0.16292400E+01, 0.17573900E+00, 0.98437200E-01, -.96902400E-01, 0.16336300E+00, 0.36538500E+00, -.32413400E+00, -.45295500E+00, 0.11185000E+01, 0.11068900E+00, 0.27985800E+00, -.30987900E+00, 0.63595900E+04, 0.13037600E+04, 0.30078500E+03, -.14266600E+03, -.23493000E+03, -.19760100E+03, -.30501700E+03, 0.11591100E+03, 0.48375800E+03, 0.24102800E+04, -.26720800E+03, 0.60086900E+04, -.30424200E+04, -.38637300E+04, -.86518700E+03, -.45916000E+04, -.43754700E+03, -.77349800E+03, 0.13757600E+05, -.38217300E+04, 0.49465100E+02, -.23451300E+02, -.42398300E+02, -.43940600E+02, -.69566800E+02, 0.30683800E+02, 0.10384900E+03, 0.50997900E+03, -.59392400E+02, -.18725400E+04, 0.10151100E+04, 0.87134300E+03, -.27049800E+04, -.13919100E+04, 0.16419900E+04, 0.23517000E+04, 0.19523600E+04, -.10514700E+04, -.52550800E+04, 0.26205800E+04, 0.27969100E+04, 0.25879700E+04, 0.40958600E+04, -.66877800E+03, -.26922100E+04, -.33779200E+04, 0.28346800E+04, 0.21764700E+04, -.10013900E+04, -.23020800E+04, -.32821700E+04, -.57971100E+04, 0.30817300E+04, 0.68785600E+04, 0.27223700E+05, -.40948000E+04, -.31338400E+04, 0.15709900E+04, 0.91638400E+02, -.42949800E+04, -.55411500E+04, 0.42672900E+04, 0.87777300E+04, 0.34540500E+05, -.44057500E+04, 0.31198400E+03, -.13232700E+03, -.40819700E+03, -.31885800E+03, -.60724700E+03, 0.34599800E+03, 0.12633000E+04, 0.68012400E+04, -.46906000E+03, 0.29098800E+03, -.13969800E+03, -.20929200E+03, -.16514400E+03, -.25725100E+03, 0.82214500E+02, 0.38323500E+03, 0.18385400E+04, -.22855000E+03, -.21535700E+03, 0.12286400E+03, -.46364000E+02, -.14297300E+03, -.22220900E+03, 0.27913400E+03, 0.72353900E+03, 0.42715100E+04, -.11682700E+03, 0.23106800E+05, -.11416200E+05, -.12643800E+05, -.59543700E+04, -.99097400E+04, 0.14381400E+03, 0.97208100E+04, 0.22338700E+05, -.94495500E+04, 0.36908100E+05, -.18380500E+05, -.18566200E+05, -.98515100E+04, -.14582000E+05, -.20812900E+04, 0.12222400E+05, 0.15440500E+05, -.14733000E+05, -.11089800E+04, 0.56716400E+03, 0.58353800E+03, 0.31722000E+04, 0.89018300E+03, -.18896500E+04, -.42250000E+04, -.25915400E+04, 0.68030800E+03, -.23585900E+04, 0.10397900E+04, 0.57176500E+03, -.12243600E+03, -.17264400E+04, 0.17702200E+04, 0.24740400E+04, 0.15053400E+05, -.15720000E+04, -.17907500E+05, 0.88691100E+04, 0.89942800E+04, 0.62777400E+04, 0.74445900E+04, 0.24408000E+03, -.78608500E+04, -.84070400E+04, 0.76814800E+04, -.31848700E+04, 0.15644800E+04, 0.20331900E+04, 0.24978300E+04, 0.39203600E+04, -.85320900E+03, -.48988200E+04, -.20539400E+05, 0.31227300E+04, -.26669100E+05, 0.13337300E+05, 0.12426600E+05, 0.57605600E+04, 0.94239600E+04, 0.38359600E+04, -.18298700E+04, 0.17851000E+05, 0.11052000E+05, -.80768900E+03, 0.38381500E+03, 0.21820800E+03, -.58733500E+03, 0.96145100E+03, 0.17400400E+04, 0.30308100E+04, 0.87103000E+04, 0.17458500E+03, 0.24330800E+05, -.12143600E+05, -.11754000E+05, -.73036300E+04, -.79403100E+04, -.31385100E+04, 0.33258500E+04, -.17386800E+05, -.91018300E+04, 0.68190300E+04, -.34054900E+04, -.35330000E+04, 0.10819600E+04, -.17573900E+04, -.16567200E+04, 0.18629900E+04, 0.30158300E+05, -.13201900E+04, -.12972700E+05, 0.65618700E+04, 0.59742600E+04, 0.54629300E+04, 0.48577500E+04, 0.16064800E+04, -.32264100E+03, 0.17993700E+05, 0.48821700E+04, -.18307900E+04, 0.93128700E+03, 0.69260500E+03, -.32360500E+04, -.22634100E+04, 0.22811900E+04, 0.32032700E+04, 0.19484300E+04, -.23410400E+04, 0.23325700E+04, -.11602400E+04, -.72009200E+03, -.38000000E+04, -.18400700E+04, 0.19175300E+04, 0.68713100E+04, -.18127600E+04, -.25450000E+04, -.26357400E+04, -.57361600E+04, 0.48914800E+04, -.25836700E+04, -.43098900E+04, 0.27281900E+04, 0.19351500E+03, -.45089900E+04, 0.27254700E+05, 0.15425900E+05, -.34316700E+04, -.12173100E+04, -.46460000E+04, -.33495200E+05, 0.18969900E+05, 0.26579400E+04, -.62222600E+04, 0.25958500E+04, 0.15460300E+05, -.11717400E+05, 0.61989400E+03, 0.94909200E+04, -.15715600E+05, 0.29091300E+05, -.92607000E+03, -.60682000E+04 },
            { 0.64863300E+00, -.12088700E+00, -.93406600E-01, -.12764700E+00, 0.68477000E+00, 0.12194300E+00, -.10568100E+00, 0.10307900E+00, -.23561000E-01, -.14567400E-01, -.14109400E+00, -.91888200E+00, -.64253200E+00, 0.45464600E+00, -.14437000E+00, -.10514100E-01, 0.24838300E+00, -.10344500E+04, 0.19708000E+04, -.99129700E+03, -.79122200E+03, -.53925000E+03, -.64025300E+03, -.30049400E+03, 0.29620900E+03, 0.23096300E+02, -.71761400E+03, 0.49799200E+04, -.23721700E+04, -.61564200E+03, -.51218000E+04, -.38951100E+04, 0.12003100E+04, 0.59249500E+04, 0.45700100E+04, -.39781800E+04, 0.41149800E+03, -.20660600E+03, -.16517000E+03, -.11298100E+03, -.13460200E+03, -.62260400E+02, 0.64466800E+02, 0.70184400E+01, -.15023400E+03, 0.61030600E+04, -.31674800E+04, -.28914300E+04, 0.71078600E+03, -.88499600E+03, -.16859800E+04, 0.26073000E+02, 0.52159500E+02, -.10075200E+04, -.11921700E+04, 0.58799200E+03, -.20682500E+02, 0.71177200E+03, 0.38854100E+03, 0.45486900E+02, -.48513000E+03, -.11785600E+04, 0.11485100E+04, 0.23485600E+05, -.11733600E+05, -.82530900E+04, -.58969800E+04, -.72068700E+04, -.35945400E+04, 0.35558000E+04, -.41387900E+03, -.85973300E+04, 0.26458200E+05, -.13204500E+05, -.10085400E+05, -.64228500E+04, -.84748000E+04, -.41919900E+04, 0.33020300E+04, 0.50010800E+02, -.93438300E+04, 0.55838400E+04, -.28117000E+04, -.22308900E+04, -.16098300E+04, -.18740300E+04, -.83872000E+03, 0.84026700E+03, 0.60329100E+02, -.20949300E+04, 0.15045400E+04, -.75657200E+03, -.60469800E+03, -.41280400E+03, -.48973600E+03, -.22863000E+03, 0.22940000E+03, 0.22836500E+02, -.54779200E+03, 0.35695300E+04, -.17978700E+04, -.14439300E+04, -.96934000E+03, -.11457200E+04, -.56901800E+03, 0.47194300E+03, -.24190000E+02, -.13162600E+04, 0.19848900E+05, -.98739700E+04, -.67326900E+04, -.60638000E+04, -.56118900E+04, -.41297300E+04, 0.15694700E+04, -.21749800E+03, -.69072200E+04, 0.82632300E+04, -.40659600E+04, -.33996100E+04, -.24948300E+04, -.23169400E+04, -.21297900E+04, -.48369000E+03, 0.95742500E+03, -.29171900E+04, -.19356400E+04, 0.94027100E+03, 0.82681100E+03, -.16045100E+04, -.11805900E+04, 0.22040300E+04, 0.45833400E+04, 0.23415700E+04, -.36895100E+03, 0.11226200E+05, -.55101700E+04, -.44563100E+04, -.41093600E+04, -.43626800E+04, -.10917300E+04, 0.31651300E+04, 0.11754100E+04, -.42808300E+04, -.18338300E+04, 0.98296900E+03, 0.66085400E+03, -.60072400E+02, 0.46091500E+03, 0.11201100E+04, 0.22345500E+04, 0.13023700E+03, 0.64894200E+03, -.14588200E+05, 0.73321000E+04, 0.60509000E+04, 0.38967900E+04, 0.48780300E+04, 0.21213300E+04, -.18049000E+04, -.15943200E+02, 0.55685300E+04, 0.18415400E+05, -.92548100E+04, -.76230800E+04, -.39779600E+04, -.49827600E+04, -.35459000E+04, 0.79538400E+03, -.24066800E+04, -.68270100E+04, 0.74498400E+04, -.36140000E+04, -.32256200E+04, -.12003900E+04, -.11571200E+04, -.30296400E+04, -.26756800E+04, -.19467300E+04, -.16260600E+04, -.11782200E+05, 0.59384300E+04, 0.49831900E+04, 0.59289700E+04, 0.52084300E+04, 0.97656900E+03, -.23641300E+04, 0.85362900E+03, 0.60215700E+04, 0.17962300E+05, -.89776000E+04, -.82146700E+04, -.85544200E+04, -.82755100E+04, -.60668400E+03, 0.61000100E+04, 0.18536700E+04, -.89872300E+04, 0.13369600E+05, -.68029200E+04, -.60268300E+04, -.67976500E+04, -.65161800E+04, -.94729200E+03, 0.29797300E+04, 0.20158600E+03, -.64851200E+04, 0.37761600E+04, -.19066300E+04, -.14847900E+04, 0.77483500E+03, -.41380100E+03, -.11173500E+04, -.16728100E+03, 0.50629700E+03, -.21250200E+03, 0.45398100E+04, -.22832300E+04, -.29993300E+04, 0.32800900E+04, 0.11809700E+04, -.30030700E+04, -.38419000E+04, -.32692000E+04, 0.13770700E+04, -.13495700E+05, -.97222700E+04, 0.91579200E+04, -.18235900E+04, -.92281800E+04, 0.18085200E+04, 0.12184800E+05, -.95913600E+04, 0.10986200E+03, 0.55010300E+02, -.46622000E+04, -.22758900E+03, -.52894700E+04, 0.41610500E+04, -.10983600E+05, 0.11399100E+05, 0.14882000E+05, -.11921500E+05, -.17688000E+04, -.79302700E+04, 0.12805500E+05, 0.82885300E+04, -.25670800E+04, 0.48221200E+03, -.11182900E+05, -.10507400E+05 },
            { -.51687400E+00, -.45119400E-01, 0.13879700E+00, 0.24372700E+00, 0.19314000E+00, -.12752300E+00, -.57369900E-01, -.21871500E+00, -.99382100E-01, 0.22364100E+00, 0.10352900E+00, 0.29430700E+00, -.32224800E+00, -.18130600E-01, -.43390200E+00, -.10844000E+00, 0.31945000E+00, -.68064200E+00, 0.16465900E+04, -.82828100E+03, -.61144800E+03, -.64331400E+03, -.63039700E+03, -.18191500E+03, 0.44179400E+03, 0.33306000E+03, -.67912200E+03, 0.33673100E+04, -.15722600E+04, 0.33272600E+03, -.49056700E+04, -.36402900E+04, 0.93301300E+03, 0.42631400E+04, 0.51471400E+04, -.31832300E+04, 0.34242800E+03, -.17191800E+03, -.12691700E+03, -.13482300E+03, -.13299800E+03, -.37227700E+02, 0.93740300E+02, 0.71982900E+02, -.14253800E+03, 0.79442800E+04, -.40838300E+04, -.37804600E+04, 0.45212600E+03, -.19003200E+04, -.19523800E+04, 0.96982400E+03, -.14430400E+02, -.13416900E+04, -.22941500E+03, 0.10849700E+03, -.56317700E+03, 0.13591800E+04, 0.59314700E+03, -.54191000E+03, -.14498100E+04, -.15355800E+04, 0.10066700E+04, 0.19259500E+05, -.96253100E+04, -.57631900E+04, -.73076200E+04, -.74604400E+04, -.18866900E+04, 0.55501000E+04, 0.36118600E+04, -.82302000E+04, 0.18264200E+05, -.91125200E+04, -.57278900E+04, -.78561100E+04, -.84080400E+04, -.14044000E+04, 0.49240600E+04, 0.49307600E+04, -.87247900E+04, 0.47044900E+04, -.23689000E+04, -.17421300E+04, -.18748000E+04, -.17878600E+04, -.55722900E+03, 0.12020200E+04, 0.89135200E+03, -.19324500E+04, 0.12695800E+04, -.63840600E+03, -.47367900E+03, -.49333100E+03, -.48496800E+03, -.14109400E+03, 0.34069000E+03, 0.25768800E+03, -.52190000E+03, 0.29156600E+04, -.14690300E+04, -.10868100E+04, -.11492700E+04, -.10909600E+04, -.35012500E+03, 0.73973900E+03, 0.53266200E+03, -.11924800E+04, 0.19017700E+05, -.94695400E+04, -.59869300E+04, -.79065300E+04, -.58736700E+04, -.32865600E+04, 0.40355300E+04, 0.26783300E+04, -.67912300E+04, 0.98755200E+04, -.48878600E+04, -.41177500E+04, -.40967800E+04, -.31052500E+04, -.19600700E+04, 0.13797300E+04, 0.21991700E+04, -.33672100E+04, 0.11988100E+04, -.59584100E+03, -.75077500E+03, -.11228700E+04, -.15018400E+04, 0.96085700E+03, 0.30353300E+04, 0.19345600E+04, -.10693200E+04, 0.88379900E+04, -.43423500E+04, -.31884900E+04, -.43985000E+04, -.39242700E+04, -.30104900E+03, 0.39740700E+04, 0.32334900E+04, -.43365600E+04, 0.21073800E+03, -.25672300E+02, -.38413800E+03, 0.47570200E+03, 0.36327400E+03, 0.41145300E+03, 0.16610100E+04, -.33206500E+03, 0.26472000E+03, -.11284900E+05, 0.56747300E+04, 0.42738000E+04, 0.45075900E+04, 0.49294400E+04, 0.12453000E+04, -.20432000E+04, -.21985300E+04, 0.49529300E+04, 0.12432200E+05, -.62552700E+04, -.45110600E+04, -.49209800E+04, -.39863700E+04, -.17084000E+04, 0.28102700E+04, 0.84933800E+03, -.50455600E+04, 0.46986700E+04, -.22526800E+04, -.18181900E+04, -.16293200E+04, -.20980700E+03, -.22394300E+04, -.12554300E+04, -.98554000E+03, -.40468800E+03, -.62166100E+04, 0.31420400E+04, 0.21127500E+04, 0.58963700E+04, 0.28712700E+04, 0.34492900E+03, -.13865300E+04, -.73391700E+03, 0.37500800E+04, 0.14970800E+05, -.74736400E+04, -.65444800E+04, -.84538300E+04, -.70345300E+04, -.54830100E+03, 0.58956000E+04, 0.43866200E+04, -.75246100E+04, 0.97814700E+04, -.49903000E+04, -.41612600E+04, -.64242200E+04, -.43173200E+04, -.94767400E+03, 0.24425500E+04, 0.16794700E+04, -.46893700E+04, 0.40271000E+04, -.20323500E+04, -.15742900E+04, 0.57808300E+03, -.11507700E+04, -.71039800E+03, 0.14801500E+04, 0.79022000E+03, -.72885500E+03, 0.42597300E+04, -.21433400E+04, -.28894600E+04, 0.23378900E+04, 0.45226000E+03, -.16399400E+04, -.89987000E+03, -.19149200E+04, 0.27562900E+03, -.11394800E+05, -.98130500E+04, 0.95875000E+04, -.20832700E+04, -.11051000E+05, 0.21036200E+04, 0.11929100E+05, -.97078900E+04, 0.20781800E+04, 0.12692000E+04, -.40353300E+04, -.45301100E+03, -.48550500E+04, -.34791500E+02, -.84897600E+04, 0.99791700E+04, 0.20253400E+05, -.10904700E+05, -.16859300E+04, -.76844600E+04, 0.10674600E+05, 0.94090700E+04, -.51733400E+04, 0.40876800E+04, -.10644800E+05, -.11052200E+05 },
            { -.72715900E+00, 0.10166300E+01, 0.42151100E-01, 0.41892300E+00, 0.22397700E+00, -.21623600E+00, 0.10089100E+00, -.36351200E+00, -.31258200E-01, 0.30642900E-01, 0.44184400E+00, 0.18412100E+01, 0.47902800E+00, -.55952600E+00, -.78558500E-01, 0.64510500E-01, 0.13377900E+00, 0.24009400E-01, -.11738200E+00, -.16953400E+02, -.13747900E+03, 0.26601000E+03, 0.18801100E+03, -.19407500E+03, -.23892800E+03, -.45649000E+03, 0.15207100E+03, 0.45209400E+03, -.26209000E+03, -.16009800E+04, 0.14893300E+03, 0.52784500E+03, -.95370400E+02, 0.58759300E+03, -.32138200E+04, 0.30680200E+03, 0.54403300E+01, -.56494600E+01, -.31394500E+02, 0.54681800E+02, 0.38806900E+02, -.40996500E+02, -.47885500E+02, -.96964300E+02, 0.30696700E+02, -.51037400E+04, 0.25346000E+04, 0.24093700E+04, 0.75329800E+03, 0.11192900E+04, 0.15457700E+04, 0.23230800E+03, 0.66428700E+03, 0.88520500E+03, 0.22819500E+03, -.10435800E+03, 0.37177500E+03, -.92910800E+03, -.66126200E+03, 0.55589500E+03, 0.99997000E+03, 0.16669800E+04, -.88957600E+03, 0.40527900E+04, -.21726900E+04, -.46131800E+04, 0.22672300E+04, 0.80851400E+03, -.28526800E+04, -.15599900E+04, -.28824000E+04, 0.57724700E+03, 0.19130900E+04, -.99502900E+03, -.31169500E+04, 0.34762100E+04, 0.21205800E+04, -.24921100E+04, -.16685700E+04, -.53356600E+04, 0.15377400E+04, -.12049500E+03, 0.74442400E+01, -.33610100E+03, 0.75208000E+03, 0.49748000E+03, -.47265000E+03, -.59099200E+03, -.11932500E+04, 0.40199300E+03, -.15283100E+02, -.50006400E+01, -.96962200E+02, 0.20456800E+03, 0.14710600E+03, -.14455100E+03, -.18302700E+03, -.35032800E+03, 0.11999000E+03, 0.78833600E+02, -.74275300E+02, -.27918800E+03, 0.47340700E+03, 0.29244800E+03, -.34364100E+03, -.40155100E+03, -.76299200E+03, 0.22774600E+03, 0.60326500E+04, -.32018900E+04, -.53936200E+04, 0.21865900E+04, -.78133400E+03, -.24216000E+04, -.78396400E+03, -.15705100E+04, -.13380800E+04, 0.24362200E+04, -.11930200E+04, -.17994000E+04, 0.24139200E+04, 0.59184100E+03, -.17274700E+04, -.18602900E+04, -.36399700E+04, -.11073800E+03, -.48413100E+04, 0.21054000E+04, 0.25379500E+04, -.24995000E+04, -.67423300E+03, 0.24129700E+04, 0.24135200E+04, 0.24485000E+04, 0.17094500E+03, 0.21960600E+04, -.89807900E+03, -.18641900E+04, 0.12903100E+04, 0.14893200E+04, -.22443500E+04, -.24370500E+04, -.44324800E+04, 0.12601400E+04, -.21223400E+04, 0.79055400E+03, 0.12754400E+04, -.24526900E+04, -.11677000E+04, 0.17275500E+04, 0.19426300E+04, 0.34950900E+04, -.34984800E+03, 0.20150600E+03, 0.10144200E+02, 0.77473000E+03, -.15872800E+04, -.94333200E+03, 0.53862800E+03, -.31787400E+03, 0.18504400E+04, -.54102100E+03, 0.30898300E+04, -.16438000E+04, -.25919800E+04, 0.19478700E+04, 0.52915300E+03, -.19835100E+04, -.16974300E+04, -.24314600E+04, 0.23457900E+03, 0.41150100E+04, -.20846000E+04, -.24437900E+04, 0.19040300E+04, -.10428500E+03, -.16717600E+04, -.15919600E+04, -.21920900E+04, -.11664300E+04, -.17384400E+04, 0.94337100E+03, 0.14688500E+04, -.10225300E+04, 0.70108700E+03, 0.78897300E+03, -.98816400E+03, 0.33358500E+03, 0.70483400E+03, 0.51169800E+04, -.26132900E+04, -.30238700E+04, 0.18707400E+04, 0.83542800E+03, -.37693900E+04, -.21890900E+04, -.47572300E+04, 0.75122500E+03, 0.17058900E+04, -.10091200E+04, -.10900300E+04, 0.67210700E+03, -.92792400E+03, -.83939900E+03, 0.11104700E+04, 0.84606100E+03, -.10397600E+04, -.12505800E+04, 0.60212800E+03, 0.34576800E+03, 0.49906600E+03, 0.48162200E+03, 0.11221100E+03, -.66926900E+03, -.36358100E+03, 0.53642000E+03, -.53673100E+04, 0.26778100E+04, 0.31426600E+04, 0.71117600E+03, 0.10482800E+04, 0.12447700E+04, -.76324900E+03, 0.13697200E+04, 0.10369900E+04, 0.14266000E+03, 0.27904500E+04, -.22372200E+04, 0.70607600E+03, 0.31334000E+04, -.11131300E+04, -.19272600E+04, 0.25743100E+04, -.44588800E+03, -.28479000E+04, -.42455400E+02, 0.32070700E+03, 0.46989300E+03, 0.24244900E+04, -.17351900E+04, -.26714100E+04, -.54060600E+04, 0.15269900E+04, -.11842500E+04, 0.89047100E+03, -.50606700E+03, -.33649000E+04, 0.28070800E+04, -.34464200E+04, 0.22828400E+04, 0.31554100E+04 },
            { 0.38406800E-01, -.57710700E+00, -.65172000E+00, 0.12005000E+01, -.50925900E+00, -.75276200E-01, 0.17402300E+00, -.20274800E+00, 0.24408100E+00, 0.11622400E+00, -.72896200E+00, -.36195000E+00, 0.52492100E+00, 0.32418700E+00, 0.56011100E+00, -.20132100E+00, -.36051800E-01, -.17862700E+00, -.35564300E+00, -.31348800E+00, 0.21983800E+03, -.18633300E+03, -.81491000E+02, 0.86171100E+02, 0.97690500E+01, 0.11286300E+03, -.63653300E+02, -.43612100E+04, 0.22074000E+04, 0.44057800E+04, 0.18814700E+03, 0.56465200E+03, 0.79356700E+03, -.10314500E+04, 0.86818300E+03, 0.61138600E+03, -.81300200E+01, 0.40961300E+01, 0.49981800E+02, -.37934000E+02, -.16743200E+02, 0.19686900E+02, 0.21964300E+01, 0.25215200E+02, -.12526600E+02, 0.19709100E+04, -.99884700E+03, -.81656700E+03, -.84250100E+03, -.61627700E+03, -.40797800E+03, 0.54690000E+03, -.26873200E+03, -.60218900E+03, 0.12322000E+04, -.61971100E+03, -.13153100E+04, 0.22320800E+03, -.25398200E+03, -.37637800E+03, -.47195300E+02, 0.10409500E+04, -.14028000E+03, 0.70633800E+04, -.34957500E+04, 0.43242100E+03, -.39830800E+04, -.39783700E+04, 0.80592400E+03, 0.25579100E+04, 0.27192700E+04, -.38472900E+04, 0.65512900E+03, -.31320100E+03, 0.32295700E+04, -.32945200E+04, -.21476800E+04, 0.12348400E+04, 0.82194900E+03, 0.18326500E+04, -.17478100E+04, 0.76356800E+02, -.38449900E+02, 0.60109900E+03, -.53102100E+03, -.24470700E+03, 0.21173800E+03, 0.33604100E+01, 0.34819200E+03, -.19455200E+03, 0.12338700E+01, -.59673600E+00, 0.16632300E+03, -.14196400E+03, -.62475100E+02, 0.65123300E+02, 0.68351200E+01, 0.81942100E+02, -.48953200E+02, -.31747200E+01, 0.12554300E+01, 0.38901000E+03, -.33173800E+03, -.13298500E+03, 0.14487600E+03, 0.97563100E+01, 0.24879500E+03, -.10205100E+03, 0.10316300E+05, -.50993600E+04, -.15349600E+04, -.40646400E+04, -.32144300E+04, -.77229600E+03, 0.21381000E+04, 0.75267600E+03, -.33357400E+04, -.11378500E+04, 0.59778000E+03, 0.13827100E+04, -.11622000E+04, 0.54686300E+03, 0.37828300E+03, -.27550300E+03, -.18337800E+04, 0.62973100E+03, 0.35195700E+04, -.17666300E+04, -.19278100E+04, 0.80089600E+03, -.13249800E+04, -.78996600E+03, 0.33414200E+03, 0.13406200E+04, -.14863800E+04, -.12441900E+04, 0.63678200E+03, 0.19455800E+04, -.68338700E+03, -.39557500E+03, 0.94423000E+03, 0.17428100E+03, 0.12995300E+04, -.22945800E+03, 0.50586900E+04, -.25160100E+04, -.28347800E+04, 0.56255300E+03, -.12250500E+04, -.11313600E+04, 0.59074300E+03, 0.17103500E+04, -.15251900E+04, -.12037800E+04, 0.60404100E+03, -.74616400E+03, 0.15077000E+04, 0.95872000E+03, -.13537200E+03, 0.32050200E+03, -.19865200E+03, 0.87278800E+03, -.14837300E+03, 0.67273500E+02, 0.19698200E+04, -.12784400E+04, -.20972600E+03, 0.61958900E+03, 0.14194000E+03, 0.27568400E+04, -.17494700E+03, -.25755600E+04, 0.13142700E+04, 0.18670200E+04, -.62294000E+03, 0.13411200E+04, 0.27167300E+03, -.77170600E+03, -.31320600E+03, 0.15445000E+04, 0.95327800E+03, -.46078800E+03, -.15144600E+04, 0.47463400E+03, 0.10859500E+03, -.66153200E+03, 0.84867100E+03, -.17061800E+04, -.14687600E+02, -.76333400E+03, 0.37700700E+03, 0.10737000E+04, -.14842400E+04, -.71422000E+03, 0.15511600E+04, -.57942000E+01, 0.17272200E+04, -.64803000E+03, 0.47663000E+04, -.23987000E+04, -.16742300E+04, -.18308700E+04, -.22003700E+04, 0.25643500E+03, 0.58314800E+03, 0.19476400E+04, -.19958400E+04, 0.14090200E+04, -.70347600E+03, -.25399300E+03, -.98284900E+03, -.69719500E+03, -.92934600E+01, 0.10815100E+04, -.29732100E+03, -.66878800E+03, 0.40663500E+04, -.20369200E+04, -.29228600E+04, -.62897100E+03, -.76514400E+03, -.83502700E+03, 0.89974100E+03, -.10247900E+04, -.71742700E+03, -.22484600E+01, -.10415800E+04, 0.62127000E+03, -.16770300E+03, -.19098300E+04, 0.53253700E+03, -.27532500E+03, -.17044500E+04, -.13023800E+04, 0.11825400E+04, 0.56452100E+02, -.65440500E+02, -.14143500E+03, 0.16459900E+04, -.46190300E+04, 0.20407800E+04, 0.18822200E+04, -.43899000E+04, -.92227500E+03, -.65979200E+03, 0.32891900E+03, 0.10713600E+04, -.10928900E+04, 0.13720500E+04, -.24816100E+03, -.11796700E+04 },
            { -.49558300E+00, 0.58115200E+00, 0.40498300E+00, -.45955500E+00, -.11270600E+01, -.31498100E+00, 0.15340300E+00, -.20861300E+00, 0.33886100E+00, 0.10903300E+00, -.17292300E+00, 0.17430100E+01, -.29129500E+00, -.31413700E+00, 0.21786100E+00, -.53040900E-01, -.31122400E+00, 0.28296600E+00, -.57654900E+00, 0.21769600E+00, -.88243800E-01, -.11522300E+03, -.90638700E+02, 0.65553500E+02, 0.16365000E+03, 0.34261600E+03, -.73079600E+02, -.68606800E+03, 0.33776800E+03, 0.31766800E+03, -.23486900E+03, -.36394000E+03, 0.36587100E+03, 0.33185700E+03, 0.25024000E+04, -.46988600E+03, -.18892100E+00, 0.82562100E-01, 0.92228800E-01, -.24234500E+02, -.19107000E+02, 0.13797500E+02, 0.34025700E+02, 0.72571700E+02, -.15624800E+02, 0.12834900E+04, -.65481900E+03, -.64732500E+03, -.50842500E+03, -.49530000E+03, -.24549400E+03, 0.54032000E+03, 0.70053900E+03, -.43675200E+03, -.13363900E+04, 0.67021700E+03, 0.64247000E+03, 0.50514300E+03, 0.65760200E+03, -.15461600E+02, -.89948000E+03, -.14646800E+04, 0.50075800E+03, -.74043000E+04, 0.36644200E+04, 0.37611900E+04, 0.55945700E+02, 0.89994800E+03, 0.19889500E+04, 0.26404500E+03, 0.34645500E+04, 0.12808800E+04, -.14252000E+04, 0.71039400E+03, 0.69548200E+03, -.16074500E+04, -.10195800E+04, 0.11672600E+04, 0.18007500E+04, 0.50279900E+04, -.77894700E+03, -.99756200E+01, 0.50863400E+01, 0.26662800E+01, -.29305400E+03, -.22069600E+03, 0.16559000E+03, 0.44174200E+03, 0.91650000E+03, -.17924400E+03, 0.12341800E+02, -.61495800E+01, -.60559000E+01, -.89771700E+02, -.72575400E+02, 0.47810200E+02, 0.12708500E+03, 0.26421600E+03, -.59496200E+02, -.94892900E+02, 0.47317000E+02, 0.45854900E+02, -.18475000E+03, -.12569100E+03, 0.12921200E+03, 0.28212900E+03, 0.57253200E+03, -.91912800E+02, -.84805700E+04, 0.41766800E+04, 0.43032600E+04, -.42542200E+03, 0.96488100E+03, 0.25137100E+04, 0.10024600E+04, 0.49312200E+04, 0.13721700E+04, 0.30886500E+04, -.15618300E+04, -.14915700E+04, -.25004700E+04, -.22413600E+04, 0.62303700E+03, 0.32294500E+04, 0.49432900E+04, -.20880300E+04, -.17385000E+04, 0.85774500E+03, 0.86159800E+03, 0.89108000E+03, 0.59398700E+03, 0.34023800E+03, -.59593400E+03, -.40427400E+03, -.11263200E+02, -.66422000E+03, 0.35871500E+03, 0.31209900E+03, -.36558300E+03, -.45630000E+03, 0.54711000E+03, 0.94911000E+03, 0.24055000E+04, -.27138800E+03, -.32403700E+04, 0.15977200E+04, 0.16040300E+04, 0.14236000E+04, 0.11640600E+04, 0.34544900E+03, -.13520200E+04, -.17895500E+04, 0.94388900E+03, -.69942300E+03, 0.34919000E+03, 0.32173000E+03, 0.83820100E+03, 0.70775300E+03, -.13912300E+03, -.77663800E+03, -.26566300E+04, 0.72538400E+03, -.33083500E+04, 0.16561700E+04, 0.15879400E+04, -.10247300E+03, 0.48026500E+03, 0.10028600E+04, 0.79381100E+03, 0.11172400E+04, 0.75358300E+03, -.16808600E+04, 0.81890600E+03, 0.85042700E+03, -.11790400E+04, -.19130200E+03, 0.96785400E+03, 0.17499000E+04, 0.19836500E+04, -.91393900E+02, 0.47230300E+04, -.23847300E+04, -.23548900E+04, -.71097200E+03, -.13141900E+04, -.96030900E+03, 0.35423100E+03, -.11827800E+04, -.13151000E+04, -.36333200E+04, 0.18364900E+04, 0.18697600E+04, -.15735000E+03, 0.30930500E+03, 0.12324400E+04, 0.10464100E+04, 0.38663800E+04, 0.41788700E+03, -.79752700E+04, 0.40019100E+04, 0.39281000E+04, 0.12538500E+04, 0.23013000E+04, 0.14450800E+04, -.61414400E+03, 0.18999000E+04, 0.22742300E+04, 0.55386600E+03, -.28473400E+03, -.29051500E+03, -.53951800E+03, -.43702200E+03, 0.57722000E+02, 0.85595800E+03, 0.11259900E+04, -.29716900E+03, 0.18732900E+04, -.93769800E+03, -.90176400E+03, -.47785400E+03, -.49392900E+03, -.27845300E+03, 0.63545700E+03, -.40575400E+03, -.35298000E+03, -.11982700E+03, -.15406900E+04, 0.14271000E+04, -.50096200E+03, -.14272800E+04, 0.58075500E+03, 0.34906700E+03, -.94498200E+03, 0.23725100E+04, 0.16043900E+04, -.20027800E+03, -.23586800E+03, -.48227300E+03, -.50712500E+04, 0.40503100E+04, 0.12443300E+04, 0.27893000E+04, -.42650700E+03, 0.11751000E+04, -.92886700E+03, 0.26629200E+03, 0.22272100E+04, -.24731500E+04, 0.43503700E+04, -.34338200E+03, -.14205400E+04 },
            { 0.67286400E-01, 0.71848300E-01, -.30741300E-01, 0.77041900E+00, -.47839200E+00, -.66981500E-01, -.18503400E-01, -.23701700E+00, -.27017200E+00, -.20907600E+00, -.40112200E+00, -.23016600E+00, 0.59318500E+00, -.35948200E+00, -.11644300E+00, 0.12864700E+00, 0.23723400E+00, 0.56919100E+00, -.61782800E-01, -.71537600E-01, -.82137400E+00, -.71168200E+00, 0.43487700E+02, -.48631300E+02, -.31683400E+02, 0.17066300E+02, 0.60217900E+02, 0.28739800E+04, -.14364800E+04, -.13960500E+04, -.77342100E+02, -.67100000E+03, -.15765000E+03, 0.12489800E+04, 0.32583600E+03, -.10544400E+04, 0.21828200E+01, -.11102400E+01, -.10864300E+01, -.13153800E+00, 0.72856300E+01, -.94232000E+01, -.38913700E+01, 0.43932400E+01, 0.10429200E+02, 0.18159000E+04, -.91345700E+03, -.93138700E+03, -.17702700E+03, -.19924700E+03, -.52703700E+03, 0.10411600E+03, -.54445500E+03, -.51238600E+03, -.14179200E+04, 0.70967800E+03, 0.70813800E+03, -.36681600E+02, 0.28596700E+03, 0.43978500E+03, 0.11643200E+03, 0.12130500E+04, 0.45564600E+02, 0.43407400E+04, -.21934200E+04, -.21916300E+04, -.27068700E+03, -.12307800E+04, -.91990700E+03, 0.15824500E+04, 0.21746100E+04, -.87212400E+03, 0.26566700E+04, -.13236900E+04, -.13137000E+04, -.30544800E+03, -.66737500E+03, -.73327500E+03, 0.14684200E+04, 0.97140900E+03, -.46160900E+03, -.68716700E+02, 0.34272900E+02, 0.37063000E+02, 0.52507900E+01, 0.10329700E+03, -.11194900E+03, -.10929100E+03, 0.94248700E+02, 0.14875800E+03, -.20025400E+01, 0.10040600E+01, 0.96851900E+00, 0.59094300E+00, 0.33592200E+02, -.36718200E+02, -.24698100E+02, 0.96174100E+01, 0.45946000E+02, -.21961000E+02, 0.10903200E+02, 0.11674100E+02, -.59601500E+01, 0.71975900E+02, -.75355300E+02, -.75656800E+02, 0.74134500E+02, 0.10459700E+03, 0.11266000E+05, -.56705600E+04, -.56133500E+04, -.24867700E+04, -.27434100E+04, -.22024200E+04, 0.14116700E+04, 0.15271700E+04, -.30228200E+04, 0.45855800E+04, -.23067200E+04, -.22752400E+04, -.24133700E+04, -.19577700E+04, -.56205700E+03, 0.69049100E+03, -.19866300E+03, -.20790800E+04, -.22369200E+04, 0.11022600E+04, 0.11122200E+04, 0.28675900E+03, -.32623600E+03, 0.20199500E+04, 0.40645400E+04, 0.35175000E+04, -.10247800E+04, 0.21985400E+04, -.10265700E+04, -.10578700E+04, 0.19309600E+03, 0.33515100E+03, -.10520100E+04, -.55799000E+03, -.50406700E+03, 0.45655500E+03, -.38438000E+03, 0.19595100E+03, 0.17697800E+03, 0.60050500E+03, 0.30955800E+03, 0.69444400E+03, 0.16770100E+04, 0.23882100E+04, -.13056000E+03, -.25661300E+04, 0.12726400E+04, 0.13109800E+04, 0.22011300E+03, 0.58520400E+03, 0.73592800E+03, -.78652100E+03, -.56891800E+03, 0.79381900E+03, -.91351300E+03, 0.46025100E+03, 0.50274600E+03, 0.28801300E+03, 0.77119700E+03, -.16681800E+03, -.85140100E+03, 0.13986400E+04, 0.10415400E+04, -.74884900E+01, -.11272000E+02, 0.10726300E+02, -.18286900E+04, -.80286900E+02, 0.32387100E+02, -.13092000E+04, -.24120000E+03, -.36423300E+03, 0.10068600E+04, -.52314500E+03, -.51482500E+03, -.25864300E+03, 0.53235200E+03, -.16918500E+03, -.42287400E+03, -.24394700E+04, 0.14795300E+03, 0.21871600E+04, -.10716500E+04, -.12364400E+04, 0.33741500E+03, 0.46305700E+03, -.14187600E+04, -.54182300E+03, 0.83535800E+03, 0.56937700E+03, 0.20488200E+04, -.10137500E+04, -.97915000E+03, -.46661600E+03, -.14025800E+04, -.38345900E+03, 0.73510100E+03, 0.30321900E+04, -.12232600E+04, 0.34646500E+04, -.17332300E+04, -.17421500E+04, -.39393400E+03, -.56142400E+03, -.87952800E+03, 0.13893300E+03, -.98369200E+03, -.61096500E+03, 0.30319000E+02, -.17446900E+02, -.47095600E+02, -.61521500E+02, 0.32804100E+03, -.43368100E+03, -.60076400E+03, -.11223600E+04, 0.41739900E+03, 0.25790400E+02, -.26984000E+03, 0.10694000E+03, 0.42466400E+00, 0.13513300E+04, -.15240000E+03, 0.19067300E+02, -.47723200E+03, 0.19271000E+04, -.69264700E+03, -.21195100E+03, -.12433600E+02, -.15682500E+03, -.10134700E+04, -.33026400E+04, 0.33926600E+04, -.53682200E+03, -.41353300E+04, -.80979800E+03, -.76973900E+03, 0.12433500E+04, 0.56865100E+02, -.10405100E+04, 0.11895500E+04, -.25873500E+03, 0.15402500E+03 },
            { 0.30451300E+00, 0.24099900E-01, 0.26228300E+00, -.51888600E+00, -.74612800E+00, -.47929600E-01, -.34341800E-02, -.13031500E-01, 0.59268900E-02, -.78805000E-02, 0.27771400E+00, -.99895400E-01, -.23894100E+00, -.25594300E+00, 0.10700000E+00, -.50470100E-01, 0.24713100E-01, -.67779000E-01, 0.13233600E+00, 0.52669600E-01, -.16766200E+00, 0.35930600E+00, -.10859600E-01, 0.24420700E+02, 0.59683600E+01, -.22802600E+01, 0.18883200E+00, 0.23841600E+04, -.11579100E+04, -.11545800E+04, 0.33466600E+03, -.47691700E+03, -.51670800E+03, 0.57510900E+02, -.41997300E+03, -.34830200E+03, -.96069200E+00, 0.49628200E+00, 0.46358700E+00, 0.58841300E+00, -.60000100E+00, 0.54525400E+01, 0.15504200E+01, -.28442100E+00, -.15940900E+00, 0.11154900E+04, -.58733300E+03, -.55535500E+03, 0.22376600E+03, -.68944600E+01, -.57061400E+03, -.72868600E+03, -.79592300E+03, 0.12724600E+03, 0.58722900E+03, -.29487500E+03, -.29454100E+03, 0.52451400E+02, -.45455900E+02, -.20606100E+03, 0.21216300E+02, 0.51619400E+02, 0.14964900E+03, 0.12406700E+04, -.61005900E+03, -.60709100E+03, -.20886200E+03, -.58093500E+03, 0.19675000E+03, 0.56244900E+03, -.63428200E+02, -.65273300E+03, 0.70358700E+03, -.35126900E+03, -.35783900E+03, 0.23878500E+03, -.21266200E+03, -.58155600E+01, -.14738500E+03, -.56630300E+03, -.13044200E+03, 0.30406600E+02, -.15265400E+02, -.13900100E+02, -.24824400E+02, -.18269400E+02, 0.63715700E+02, -.17762200E+01, -.23775800E+00, -.13817300E+02, -.83461700E+00, 0.42330400E+00, 0.36749300E+00, 0.48834700E+00, 0.24164700E+00, 0.18585900E+02, 0.37668000E+01, -.25250500E+01, 0.47129800E+00, 0.20012800E+02, -.99478700E+01, -.94590300E+01, -.18518200E+02, -.51950500E+01, 0.38927800E+02, -.98379400E+00, 0.12208700E+01, -.74174700E+01, 0.22445500E+04, -.10954600E+04, -.11201000E+04, -.43501600E+03, -.32016200E+03, -.29709700E+03, 0.61898700E+02, -.90609700E+03, -.23597600E+03, -.29853900E+03, 0.15290600E+03, 0.13457800E+03, -.10654200E+03, 0.20775500E+03, 0.39894700E+02, -.48405300E+03, -.60873800E+03, 0.48103000E+03, 0.21292200E+04, -.10150600E+04, -.10664200E+04, 0.80632200E+03, -.14083700E+03, -.86532000E+03, -.30247000E+03, -.71656900E+03, -.95490600E+02, 0.48218600E+03, -.24281400E+03, -.24187500E+03, -.75043600E+02, -.18934400E+03, 0.25399000E+03, 0.59221000E+03, 0.31551700E+03, -.35646100E+03, 0.16745100E+04, -.76305200E+03, -.83894700E+03, 0.57005700E+03, 0.29749100E+03, -.79694800E+03, -.36507200E+03, -.66885100E+03, -.18059900E+02, -.62499100E+03, 0.30737700E+03, 0.33585100E+03, -.14771200E+03, 0.11350800E+03, 0.20591300E+03, 0.43039500E+03, 0.60348100E+03, -.40942600E+02, 0.25767600E+03, -.13060600E+03, -.98041600E+02, -.42591000E+03, -.39448300E+02, 0.11956700E+03, -.14368000E+03, 0.27778500E+03, -.23610800E+03, 0.32345600E+03, -.13160400E+03, -.15614100E+03, -.40426600E+03, -.58020100E+01, -.19295700E+02, -.48223600E+03, -.61053200E+02, 0.39129700E+03, -.12204500E+04, 0.61279800E+03, 0.61323100E+03, 0.56008300E+03, 0.44535800E+03, 0.55244800E+02, -.30122300E+03, -.68327900E+02, 0.47135800E+03, 0.53824100E+03, -.26654600E+03, -.32328000E+03, -.23721000E+03, -.31698800E+03, 0.50501000E+03, 0.59926000E+03, 0.34115500E+03, -.46290900E+03, 0.24493700E+04, -.12382900E+04, -.12611000E+04, -.63136900E+03, -.82346400E+03, -.19423700E+03, 0.21854300E+03, -.23489700E+03, -.70817100E+03, 0.30384200E+03, -.15431200E+03, -.15103000E+03, 0.29981400E+03, 0.63518600E+02, -.17648900E+03, -.46635100E+03, -.46839600E+03, 0.60454500E+02, -.23721900E+03, 0.11632200E+03, 0.10353700E+03, -.16736600E+02, 0.22386400E+03, -.17006900E+03, -.43886700E+03, -.28113900E+03, 0.15775700E+03, 0.97191800E+01, -.22283600E+03, -.26920300E+02, 0.76751500E+01, 0.55126200E+03, -.80648600E+01, 0.83391000E+03, -.38680800E+03, -.26584200E+03, 0.27537600E+03, 0.71153700E+02, 0.54512600E+00, 0.60206400E+02, 0.49506500E+03, -.78428400E+03, 0.55620800E+03, -.91142200E+03, -.34038600E+03, 0.36699900E+03, 0.12898900E+03, 0.10132300E+03, 0.34636200E+03, 0.21257800E+03, -.16811000E+03, -.98644800E+03, -.17074200E+03 },
            { -.74227700E+00, -.56081500E+00, -.37632300E+00, 0.13765100E+01, 0.16949900E+01, 0.27191900E+00, 0.57877300E+00, -.18263900E+00, -.68585300E+00, 0.45387800E+00, 0.94493200E-01, 0.23936400E+00, 0.78899400E+00, -.97844100E-01, 0.32252300E+00, -.35488700E+00, 0.67454000E+00, -.26506400E+00, -.16433600E+01, 0.71008800E-01, 0.27945900E+01, -.10802100E+01, -.61390800E+00, -.40850800E+01, 0.48683100E+03, 0.75838200E+03, -.93971700E+02, 0.19956800E+05, -.98216900E+04, -.98706700E+04, -.13189200E+04, -.63407000E+04, -.29239200E+04, 0.48607200E+04, 0.55853600E+04, -.54856200E+04, 0.13936400E+02, -.68443400E+01, -.70561400E+01, -.93331300E+00, -.64598500E+01, -.37170100E+00, 0.10425400E+03, 0.15979400E+03, -.24419100E+02, 0.38555100E+04, -.21164500E+04, -.18738200E+04, 0.12539600E+04, -.77167000E+03, -.18148400E+04, -.15182800E+04, 0.23967700E+03, 0.11774300E+04, -.39268300E+04, 0.19629200E+04, 0.19242600E+04, 0.21904400E+04, 0.24316700E+04, -.37643000E+03, -.33913800E+04, -.66365900E+04, 0.28816200E+04, -.29876500E+05, 0.14843500E+05, 0.14928300E+05, 0.66728800E+04, 0.98259400E+04, 0.31103300E+04, -.15741200E+04, 0.34062100E+04, 0.90838800E+04, -.26151700E+04, 0.13083000E+04, 0.12442500E+04, 0.24198800E+04, 0.14284800E+04, -.60925700E+03, 0.26527100E+04, 0.77462100E+04, 0.85667000E+03, 0.15166500E+02, -.72526000E+01, -.15276000E+01, -.48939100E+02, 0.46863400E+02, -.39840800E+02, 0.12848600E+04, 0.19562600E+04, -.23293000E+03, 0.26916700E+02, -.13365000E+02, -.13280600E+02, -.26856400E+01, -.71247500E+01, -.47095900E+01, 0.37591200E+03, 0.59236400E+03, -.78334500E+02, -.12204500E+03, 0.61154700E+02, 0.61666800E+02, -.52218600E+02, 0.51430100E+02, 0.22929700E+02, 0.81278300E+03, 0.11610100E+04, -.13349000E+03, -.34084600E+05, 0.16918600E+05, 0.17133000E+05, 0.48245400E+04, 0.10676300E+05, 0.47907800E+04, -.20745900E+04, 0.59845800E+04, 0.10493100E+05, 0.84188900E+04, -.43091300E+04, -.41876200E+04, -.45498100E+04, -.46942600E+04, 0.93921000E+02, 0.58252200E+04, 0.13536100E+05, -.37966600E+04, -.59657900E+03, 0.59447100E+03, 0.29127900E+03, 0.41841800E+04, 0.29175700E+04, -.18003100E+04, -.36944000E+04, -.76359800E+04, 0.31218700E+04, 0.13247400E+04, -.65901800E+03, -.58623800E+03, -.60830500E+03, -.93198400E+03, 0.10596400E+04, 0.59928800E+04, 0.66101800E+04, -.26308200E+04, -.84413900E+04, 0.45745700E+04, 0.42086900E+04, 0.52054400E+04, 0.67026400E+04, -.10184500E+04, -.63438900E+04, -.12672700E+05, 0.55432900E+04, -.15489100E+04, 0.73571300E+03, 0.91038900E+03, -.20781100E+04, -.88239400E+03, 0.23768100E+04, 0.85780900E+03, -.25231500E+04, -.12669400E+04, -.49702000E+04, 0.25108500E+04, 0.24509900E+04, -.14385200E+04, 0.15046800E+04, 0.12755400E+04, 0.26559800E+04, -.88673500E+03, -.26306900E+03, 0.43212200E+04, -.20917400E+04, -.21308200E+04, -.34833100E+04, -.23441800E+04, 0.39825100E+03, 0.34076900E+04, 0.49327800E+04, -.17132800E+04, 0.75465300E+04, -.38547800E+04, -.36626900E+04, 0.70248000E+02, -.38019500E+04, 0.64899700E+02, -.69858400E+03, 0.12247300E+04, -.17805800E+04, -.13785800E+05, 0.69602000E+04, 0.63865700E+04, 0.43369200E+04, 0.54489400E+04, 0.36665700E+03, 0.25007600E+04, 0.65474600E+04, 0.39476100E+04, -.28432000E+05, 0.14180700E+05, 0.13972900E+05, 0.57833400E+04, 0.10970600E+05, 0.19537200E+04, -.38869700E+04, -.11559200E+04, 0.96985700E+04, -.21893700E+04, 0.10549900E+04, 0.11121300E+04, 0.16003700E+04, -.80206000E+02, 0.55537000E+03, -.65652700E+02, 0.32643500E+04, 0.11715900E+04, -.55812000E+04, 0.27721500E+04, 0.29278300E+04, 0.23869600E+03, 0.20942300E+04, 0.11352200E+04, -.59292200E+03, 0.35442500E+03, 0.14758900E+04, -.28035900E+03, -.30608900E+04, 0.24297200E+04, -.96974600E+03, 0.31782000E+04, 0.17461700E+03, 0.45581900E+04, -.85569300E+03, 0.71037400E+04, 0.19820100E+04, -.20951200E+03, -.54163800E+03, -.59720100E+03, -.14746000E+05, 0.16614100E+05, 0.12725600E+04, 0.10015600E+04, 0.66068800E+04, 0.23540200E+04, 0.61811300E+03, 0.59334600E+03, 0.63351400E+04, -.54285800E+04, 0.88015900E+04, -.42114200E+04, -.23093300E+04 },
            { -.17514200E+01, 0.12212500E+01, 0.87080100E+00, -.99339400E+00, 0.58445300E+00, 0.77340500E-01, 0.65512900E+00, 0.45840000E+00, 0.14682900E-01, 0.52757900E+00, 0.91933900E+00, 0.48314600E+00, 0.37490400E+00, -.88081800E+00, 0.11180100E+01, -.44397700E+00, 0.12386600E+01, 0.51911000E+00, -.15515100E+01, 0.26235800E+00, 0.16307200E+01, -.61635000E+00, 0.14194000E+01, 0.97465300E+00, 0.36569700E+00, -.57962500E+03, -.12931000E+03, -.16011800E+05, 0.78073900E+04, 0.78213900E+04, 0.36708900E+02, 0.27554200E+04, 0.24510500E+04, -.28394700E+04, -.28689400E+04, 0.37218200E+04, -.78303800E+01, 0.38995900E+01, 0.39197500E+01, -.97452800E+00, 0.21122700E+01, 0.24884100E+00, -.37689200E+01, -.12260700E+03, -.23391900E+02, -.91181400E+04, 0.46704700E+04, 0.46086000E+04, 0.69008800E+03, 0.88039500E+03, 0.27733000E+04, 0.95315700E+03, 0.31976400E+04, 0.21287000E+04, 0.70016700E+04, -.34757100E+04, -.34486900E+04, -.63316400E+03, -.16788900E+04, -.17761400E+04, -.30312800E+03, -.33116100E+04, -.15825500E+04, -.20337600E+05, 0.10032500E+05, 0.99870300E+04, 0.21376800E+04, 0.58559000E+04, 0.26678100E+04, -.51553600E+04, -.87136900E+04, 0.49812500E+04, -.10613600E+05, 0.52913900E+04, 0.53501500E+04, 0.96497800E+03, 0.26549300E+04, 0.17517600E+04, -.43919600E+04, -.90003400E+04, 0.17052700E+04, 0.22309900E+03, -.10981500E+03, -.11884500E+03, -.80931500E+01, 0.16535700E+02, -.78656600E+02, 0.15431000E+03, -.18023000E+04, -.36675400E+03, -.70596200E+01, 0.34946500E+01, 0.34428900E+01, 0.10845300E+01, 0.26217600E+01, 0.47037300E+00, 0.84828600E+00, -.43023100E+03, -.94701900E+02, 0.19632200E+03, -.97725100E+02, -.98753300E+02, -.11620100E+01, -.25399900E+02, -.50978100E+02, 0.12779000E+03, -.11764700E+04, -.27316000E+03, -.40513900E+05, 0.19949300E+05, 0.19999400E+05, 0.88375800E+04, 0.12419100E+05, 0.53247300E+04, -.69543800E+04, -.56803900E+04, 0.11428300E+05, -.15926400E+05, 0.78146500E+04, 0.78511100E+04, 0.71123400E+04, 0.77912400E+04, 0.10644700E+04, -.29738700E+04, -.46065700E+03, 0.64268300E+04, -.35302600E+04, 0.16424400E+04, 0.17981500E+04, -.38395600E+04, -.12519500E+04, 0.73574800E+02, -.52488300E+04, -.37426700E+04, 0.12827700E+04, -.51554400E+04, 0.24723000E+04, 0.25061800E+04, -.25770900E+03, 0.58217400E+03, 0.11665100E+04, -.20963700E+03, -.33931600E+04, -.33920600E+03, -.37083700E+03, -.12234000E+03, 0.26070600E+03, -.39235300E+04, -.31137200E+04, 0.81647300E+03, -.57385200E+03, -.20730300E+04, -.11257400E+04, 0.77675600E+04, -.38710800E+04, -.39996000E+04, -.89645500E+03, -.20424100E+04, -.16591200E+04, 0.22336300E+04, 0.56200800E+04, -.19212500E+04, 0.95777900E+04, -.47230600E+04, -.49051800E+04, -.20885800E+04, -.31975600E+04, -.12135700E+04, 0.43547600E+04, -.87599600E+04, -.47161700E+04, 0.49095900E+03, -.45382500E+03, -.28008200E+03, 0.50294800E+04, 0.22470900E+04, -.16475800E+04, 0.28313400E+04, -.21345200E+04, 0.66170000E+03, -.44765600E+04, 0.21290100E+04, 0.22591500E+04, 0.10441100E+04, -.11587200E+04, 0.10313600E+04, 0.10098200E+04, 0.11345700E+05, 0.13465000E+04, -.34013200E+04, 0.17169300E+04, 0.21288300E+04, 0.10299300E+03, 0.11902100E+04, 0.17854500E+02, -.17777200E+04, -.11474400E+05, -.12891600E+03, -.10582500E+05, 0.54143700E+04, 0.53229400E+04, 0.25256200E+04, 0.63839100E+04, 0.19801000E+03, -.27333500E+04, -.12034100E+05, 0.41811100E+04, -.13873100E+05, 0.69239800E+04, 0.69869600E+04, 0.12428200E+04, 0.17534700E+04, 0.34807300E+04, 0.65789100E+03, 0.43255700E+04, 0.29389300E+04, -.19949700E+04, 0.10165200E+04, 0.10312500E+04, 0.48443500E+03, -.23744400E+03, 0.19609500E+04, 0.24494600E+04, 0.59176200E+04, -.47918100E+03, 0.48097000E+02, 0.15936000E+04, -.11356400E+04, 0.43555500E+03, -.44113800E+04, -.40501400E+03, -.15330200E+04, 0.22504700E+04, -.98482800E+04, -.23336400E+04, 0.10165900E+04, 0.23976400E+03, 0.12577800E+04, 0.68175700E+04, 0.65632600E+04, -.10541300E+05, 0.48961600E+04, 0.84804700E+04, -.27284800E+04, 0.50661800E+04, -.35110500E+04, -.18099500E+04, 0.58695100E+04, -.96302900E+04, 0.22986200E+04, 0.99636800E+03 },
            { 0.53692400E+00, -.14949900E-01, -.45534300E-01, -.98657000E+00, -.10310000E+01, 0.70419100E-02, -.25821700E+00, 0.38461500E+00, 0.78733600E+00, 0.11755100E+00, 0.76832000E+00, 0.15671200E+01, 0.74860700E-02, -.32250700E+00, -.18700400E+00, 0.46650200E-01, -.41614800E+00, -.31319100E+00, 0.62866600E-01, 0.73229000E-01, -.70447800E-02, 0.10836000E+01, -.11259400E+01, -.14973500E+01, 0.25218600E+00, 0.58519500E+00, 0.17333000E+03, 0.11407700E+05, -.55633800E+04, -.55377300E+04, 0.16642900E+03, -.90714300E+03, -.17636400E+04, 0.30133400E+04, -.18421500E+04, -.22784700E+04, 0.79389600E+01, -.39778400E+01, -.39606000E+01, 0.17405100E+01, 0.28906000E+00, -.18529500E+01, 0.18217100E+01, -.17469600E+01, 0.33929500E+02, 0.76725600E+04, -.38827200E+04, -.39056300E+04, 0.23971100E+02, -.39144400E+03, -.25751200E+04, -.16458600E+04, -.39937400E+04, -.21493600E+04, -.29842800E+04, 0.14704700E+04, 0.14778400E+04, -.43187500E+03, 0.13659000E+03, 0.13747000E+04, 0.16168300E+04, 0.59298400E+04, -.25978700E+03, 0.33108400E+05, -.16395100E+05, -.16466300E+05, -.48258600E+04, -.98348300E+04, -.43560700E+04, 0.80579700E+04, 0.45863300E+04, -.84395300E+04, 0.86019600E+04, -.42873700E+04, -.42893900E+04, -.86409900E+03, -.23482400E+04, -.12226500E+04, 0.33827600E+04, 0.15250800E+04, -.98519200E+03, -.32241500E+02, 0.14530700E+02, 0.23746500E+02, -.20533900E+02, -.64108800E+02, 0.43311700E+02, -.53194600E+02, 0.19266400E+03, 0.44415700E+03, -.92583200E+01, 0.46229800E+01, 0.44994900E+01, 0.30579000E+01, 0.41687400E+01, 0.71635400E+00, -.64659400E+01, -.19133700E+02, 0.13440400E+03, 0.42655100E+01, -.24082000E+01, -.19167700E+00, -.32551200E+02, -.52285100E+02, 0.22329700E+02, -.19812900E+02, 0.21580500E+03, 0.28906400E+03, 0.52195800E+05, -.25774800E+05, -.25958200E+05, -.10818100E+05, -.16091100E+05, -.71458200E+04, 0.97302400E+04, 0.51236500E+03, -.14830600E+05, 0.91121300E+04, -.44013000E+04, -.45093600E+04, -.45289600E+04, -.43506700E+04, -.89099900E+03, 0.11152900E+04, -.72800100E+04, -.32907200E+04, 0.33159400E+04, -.16141700E+04, -.16822600E+04, 0.16700100E+04, 0.14522900E+03, 0.10905900E+04, 0.67355900E+04, 0.70977900E+04, -.26420800E+04, 0.74599300E+04, -.36215700E+04, -.36572900E+04, 0.45273900E+03, 0.41954100E+02, -.24288000E+04, -.89467200E+03, -.19292200E+04, 0.11362200E+04, 0.57062500E+04, -.26357400E+04, -.29080700E+04, 0.12412600E+04, 0.16615300E+03, -.56296400E+03, 0.34631400E+04, 0.77228300E+04, -.16598200E+04, -.40365800E+04, 0.20115000E+04, 0.21106400E+04, 0.11687200E+04, 0.18239200E+04, 0.12612700E+03, -.27501800E+04, -.21124900E+04, 0.14714900E+04, -.32528800E+04, 0.15669600E+04, 0.18034900E+04, 0.64872300E+03, 0.43223200E+03, 0.54645000E+03, -.10366600E+04, 0.74783400E+04, 0.30149200E+04, 0.14974400E+03, 0.10012400E+03, -.49535100E+02, -.47645800E+04, -.25166600E+04, 0.13342300E+04, -.74048700E+03, -.51069600E+03, -.98907700E+03, -.15974300E+04, 0.92020600E+03, 0.74290700E+03, 0.71263000E+03, 0.33206700E+04, -.77650200E+03, -.28566800E+04, -.91726700E+04, 0.18238600E+03, 0.10696200E+05, -.53833300E+04, -.56906300E+04, -.19190800E+04, -.33600000E+04, -.80911300E+03, 0.31542900E+04, 0.44844000E+04, -.16155800E+04, 0.24218500E+05, -.12214100E+05, -.12023900E+05, -.55739300E+04, -.10315300E+05, -.19114400E+04, 0.56990900E+04, 0.87325500E+04, -.80448100E+04, 0.13395700E+05, -.66714600E+04, -.67394900E+04, -.44637800E+03, -.12260000E+04, -.38633100E+04, -.16447300E+04, -.59408500E+04, -.27581200E+04, 0.90063400E+03, -.46220900E+03, -.57388600E+03, 0.38246700E+03, 0.34552300E+03, -.21239700E+04, -.45358000E+04, -.49361700E+04, 0.84061600E+03, 0.11690900E+03, -.10312200E+04, 0.11413000E+04, 0.78084500E+01, 0.39270600E+04, -.48913000E+02, 0.31725600E+04, -.26749100E+04, 0.37853000E+04, -.10230400E+04, -.15212600E+03, 0.31241100E+01, -.28115500E+03, 0.17891200E+04, -.14687900E+05, 0.10056000E+05, -.19150500E+04, -.11176200E+05, -.10380700E+04, -.37058700E+04, 0.25466500E+04, 0.15245600E+03, -.31147200E+04, 0.49486800E+04, -.33053900E+04, -.24738700E+03 },
            { -.18569200E+01, 0.89679600E+00, 0.86883300E+00, 0.38524000E+00, 0.16152600E+01, 0.98909300E-01, 0.52619400E+00, -.94062500E-01, -.72455400E+00, 0.34831800E+00, 0.25829800E+00, 0.11294200E+01, -.19425100E+00, -.65919300E-01, -.49692000E+00, 0.18143000E+00, 0.17278100E-01, -.13824800E+00, -.12780200E+01, 0.10159700E+01, 0.14553700E+01, -.39743700E+00, -.19566800E+01, 0.12425500E+01, 0.89380400E+00, -.31629100E+00, 0.30412700E+00, -.16948000E+05, 0.82183300E+04, 0.82441000E+04, -.20888300E+03, 0.30966000E+04, 0.42015700E+04, 0.36613500E+03, 0.41374600E+04, 0.31861800E+04, -.34600400E+01, 0.16082100E+01, 0.17740500E+01, -.22069000E+01, 0.20285600E+01, 0.82449900E+00, 0.12957400E+01, 0.26305100E+01, 0.13346900E+01, -.65565600E+04, 0.34653000E+04, 0.32382700E+04, -.18169500E+04, 0.62177200E+02, 0.31603700E+04, 0.39833800E+04, 0.51357400E+04, -.66321700E+03, -.37445500E+04, 0.18878800E+04, 0.18742700E+04, -.47383000E+03, 0.47646600E+03, 0.85156500E+03, -.92470300E+03, -.22352500E+04, -.48293200E+03, -.22556200E+05, 0.11133400E+05, 0.11130600E+05, 0.35281900E+04, 0.67032000E+04, 0.34527800E+04, -.50341800E+04, -.43140900E+03, 0.74760800E+04, -.56437800E+04, 0.28134400E+04, 0.28922900E+04, -.88638700E+03, 0.95428900E+03, 0.20013500E+04, 0.54945700E+03, 0.26541900E+04, 0.97853300E+03, -.22924300E+02, 0.12609700E+02, 0.18911200E+01, 0.95539900E+02, 0.23334700E+02, 0.16350500E+02, 0.16785600E+03, -.58636400E+02, 0.48202400E+01, 0.63865300E+01, -.32310900E+01, -.30877500E+01, -.31457400E+01, -.30765600E+01, 0.17383300E+00, 0.71291200E+01, 0.10850800E+02, -.29831900E+01, -.29741300E+02, 0.14744100E+02, 0.11292200E+02, 0.85564900E+02, 0.20398100E+02, 0.26351700E+01, 0.71043000E+02, -.90986000E+02, 0.20364400E+02, -.34149300E+05, 0.16757000E+05, 0.16968600E+05, 0.66316400E+04, 0.91708100E+04, 0.62867200E+04, -.41272200E+04, 0.53959700E+04, 0.87928600E+04, -.16067500E+03, -.68766100E+01, 0.14562700E+03, 0.10077300E+04, 0.30427500E+03, 0.86380900E+03, 0.35642600E+04, 0.68906700E+04, -.13409200E+04, -.17358700E+05, 0.83472500E+04, 0.86827900E+04, -.31983900E+04, 0.62049100E+03, 0.56463800E+04, 0.31944100E+03, 0.21782600E+04, 0.17826300E+04, -.39457000E+04, 0.20229700E+04, 0.19487300E+04, 0.69425100E+03, 0.12952200E+04, -.22088700E+03, -.28715400E+04, -.14395700E+04, 0.22553100E+04, -.13521500E+05, 0.62545600E+04, 0.67686700E+04, -.18816300E+04, -.54943700E+03, 0.42886300E+04, -.49570500E+03, 0.17372800E+03, 0.16128300E+04, 0.31953900E+04, -.15777000E+04, -.18037400E+04, 0.31172800E+03, -.59448700E+03, -.18755700E+04, -.17748100E+04, -.23909400E+04, 0.12930900E+03, 0.86112900E+03, -.39353100E+03, -.65399600E+03, 0.21288900E+04, 0.20365800E+03, -.32753500E+03, 0.66303500E+03, -.44998000E+04, 0.69790100E+03, 0.15535700E+04, -.10261700E+04, -.78071300E+03, 0.18777500E+04, 0.75471300E+03, -.47871200E+03, 0.35927700E+04, 0.11487200E+04, -.18508600E+04, 0.98816200E+04, -.50175100E+04, -.49535100E+04, -.39926900E+04, -.28834000E+04, -.26047500E+04, 0.17589000E+04, 0.21874200E+04, -.29781700E+04, -.77178500E+04, 0.38696700E+04, 0.42572600E+04, 0.18593900E+04, 0.28328800E+04, 0.45233500E+03, -.34698100E+04, -.28400500E+04, 0.38877400E+04, -.26342000E+05, 0.13291900E+05, 0.13279300E+05, 0.55145800E+04, 0.74642400E+04, 0.50948200E+04, -.29882700E+04, -.33790800E+03, 0.72570300E+04, -.24840200E+04, 0.12472400E+04, 0.12350600E+04, -.22060300E+04, -.41138500E+03, 0.10928800E+04, 0.27174400E+04, 0.39035200E+04, -.23896800E+03, 0.32969300E+04, -.16289300E+04, -.16216500E+04, -.95014200E+03, -.15953300E+04, 0.18244100E+03, 0.21397900E+04, 0.15050200E+04, -.16496800E+04, -.77538200E+02, 0.14554600E+04, -.71455000E+03, -.20614900E+02, -.12909500E+04, 0.38226100E+01, -.65582900E+04, 0.29695300E+04, -.60987300E+03, -.87543200E+03, 0.60776100E+02, -.11739000E+02, 0.52286900E+02, -.41553000E+04, 0.10415700E+05, -.42700300E+04, 0.16309000E+04, 0.37952400E+04, -.16383600E+03, 0.85862100E+03, -.18866400E+04, -.18893700E+04, 0.11131200E+03, 0.75845700E+03, 0.70536500E+04, 0.11162200E+04 },
            { 0.23078700E+01, 0.18815300E+00, -.16720100E+01, 0.55795300E+00, 0.27665500E+01, 0.39889500E+00, -.10708400E+01, 0.51706200E+00, 0.73487700E+00, 0.26445300E+00, 0.84206600E+00, -.30794800E+01, 0.26190700E+00, 0.21870500E+00, 0.10724700E+00, 0.38047800E-02, 0.12710000E+01, 0.77057300E+00, 0.27889600E+01, 0.33985100E+00, -.24835800E+00, -.13893000E+01, -.79373700E+00, 0.15117700E+01, -.50182200E+00, 0.56525500E+00, 0.68745300E+00, -.44748200E+00, -.24882700E+03, -.42862100E+01, -.33694700E+03, -.52540400E+03, 0.89541100E+03, 0.83086500E+03, 0.16472900E+04, -.88042000E+03, 0.85861400E-01, -.17479300E+00, -.75888200E-01, -.48715200E+00, -.20663600E+01, 0.18584200E+01, 0.27995500E+01, 0.17033200E+01, -.22974500E+01, -.42942700E+04, 0.23049100E+04, 0.21298300E+04, 0.48217500E+03, 0.12348900E+04, 0.72065000E+03, -.53836100E+03, 0.24403700E+04, 0.10087000E+04, -.65078600E+03, 0.35364000E+03, 0.28055900E+03, -.32479900E+03, 0.97885000E+03, -.36378300E+03, -.95499400E+03, -.59491200E+04, 0.18204900E+03, -.39513100E+05, 0.19503400E+05, 0.19761500E+05, 0.73807600E+04, 0.11051000E+05, 0.56477300E+04, -.77990400E+04, -.22606200E+04, 0.12253400E+05, -.54246100E+04, 0.27068800E+04, 0.26847800E+04, 0.12111500E+04, 0.91417200E+03, 0.13673900E+04, 0.89911100E+03, 0.90291600E+03, 0.12047900E+04, -.67669200E+02, 0.35331100E+02, 0.30204300E+02, 0.10235300E+02, -.57126900E+02, 0.49497600E+02, 0.50188000E+02, -.15821400E+03, -.84317100E+02, 0.43932200E+01, -.22181400E+01, -.20887000E+01, -.28513900E+00, -.24561300E+01, -.85946500E-01, 0.44147100E+01, 0.18708900E+02, -.29560500E+01, -.48664600E+02, 0.24254200E+02, 0.22019600E+02, 0.31163200E+00, -.79930800E+01, 0.22721600E+02, -.17976500E+02, -.21176300E+03, -.13353000E+02, -.53718400E+05, 0.26352800E+05, 0.26862500E+05, 0.87752000E+04, 0.15139800E+05, 0.82099900E+04, -.11340000E+05, 0.43378800E+04, 0.15507600E+05, -.62444700E+04, 0.29408600E+04, 0.32075100E+04, -.97392500E+03, -.57506500E+03, 0.27629200E+04, 0.12656400E+04, 0.13565600E+05, -.10281400E+04, -.16931300E+05, 0.81627200E+04, 0.84476800E+04, -.63710900E+03, 0.13557600E+04, 0.61306400E+04, 0.37234100E+04, -.30943700E+03, 0.12925100E+04, 0.32016100E+04, -.14629300E+04, -.16545500E+04, 0.24004400E+03, 0.39624200E+03, -.15559700E+04, -.14886900E+04, -.21530600E+04, 0.35333200E+03, -.14417900E+05, 0.67284300E+04, 0.71784000E+04, 0.88397600E+03, 0.29951500E+04, 0.34693900E+04, -.81908300E+03, -.58527600E+04, 0.34765000E+04, 0.38293100E+04, -.19130800E+04, -.19834400E+04, -.91358900E+03, -.62129100E+03, -.12685600E+04, -.10245900E+04, -.11288400E+04, -.28438700E+03, 0.21571900E+04, -.10150600E+04, -.11773900E+04, -.50944700E+03, -.59865600E+03, -.10506500E+03, -.67701700E+03, -.88278100E+04, -.52080900E+03, -.18914500E+04, 0.63586300E+03, 0.97000100E+03, -.15987900E+04, -.18751900E+03, 0.86904700E+03, -.68987300E+03, 0.25300500E+04, -.12720500E+04, 0.26083000E+04, -.14627700E+04, -.12822000E+04, -.10094400E+04, 0.31040300E+03, -.12445600E+04, -.92742800E+03, 0.62472400E+04, 0.79412300E+03, -.86610300E+04, 0.43931300E+04, 0.43973900E+04, 0.30841000E+04, 0.46285400E+04, -.35908300E+03, -.44273500E+04, -.51740700E+04, 0.44030200E+04, -.29485300E+05, 0.14902300E+05, 0.14544100E+05, 0.63007500E+04, 0.89935100E+04, 0.40705000E+04, -.53410400E+04, -.56429200E+04, 0.82802000E+04, -.74073800E+04, 0.36914000E+04, 0.36844900E+04, 0.93958200E+03, 0.15608600E+04, 0.10893100E+04, -.17768800E+04, 0.41126100E+04, 0.23111100E+04, -.65259500E+03, 0.34313800E+03, 0.35545900E+03, -.25526900E+02, 0.19063800E+03, -.26307900E+03, 0.39565000E+03, 0.20943300E+04, 0.36904000E+03, -.57739600E+02, -.46135800E+03, 0.71287200E+01, -.20897400E+02, 0.25431400E+03, 0.33101100E+02, -.39166300E+03, 0.21020600E+04, -.21891700E+04, 0.20515100E+03, 0.47345400E+02, -.12998700E+02, 0.57323200E+02, -.28797500E+04, 0.11754200E+05, -.17858500E+04, -.22304900E+04, 0.43646600E+04, 0.98593900E+03, 0.21929600E+04, 0.12504100E+04, -.95933100E+02, 0.85487700E+03, -.33083800E+04, 0.68367300E+03, -.10364700E+03 },
            { -.48307600E+00, -.27600700E+00, -.31848300E+00, 0.13686400E+01, 0.12371800E+01, 0.31618100E+00, 0.39211300E+00, -.13225100E+00, -.52286100E+00, 0.36276300E+00, 0.78784100E+00, 0.95537200E+00, 0.59314900E+00, -.41776900E+00, -.83674600E-01, -.15479000E+00, 0.51043100E+00, -.10886300E+00, -.12295400E+01, 0.43406000E+00, -.20825500E+00, 0.10043000E+01, -.10632400E+00, 0.60377900E+00, 0.21716300E+00, -.24911700E+00, -.33788700E+00, 0.23193600E+00, -.28922000E+00, 0.97358100E+02, 0.10738600E+03, -.52663000E+03, 0.22740500E+03, 0.10935500E+04, 0.23618100E+04, -.19727800E+03, -.15592300E+01, 0.78179000E+00, 0.72979800E+00, 0.69457400E+00, -.70902200E+00, 0.68178100E+00, 0.11403500E+01, 0.23179400E+01, -.23174000E+00, -.30329300E+03, 0.16049200E+03, 0.18158100E+03, 0.13497000E+03, -.49700600E+02, 0.86951000E+02, 0.33837800E+03, 0.85370600E+03, 0.29152600E+03, -.12793400E+04, 0.63651400E+03, 0.70032200E+03, 0.44511800E+03, 0.65492000E+03, -.13614800E+03, -.11450300E+04, -.22300800E+04, 0.84255700E+03, -.12944000E+05, 0.64804600E+04, 0.62976300E+04, 0.28506500E+04, 0.41984600E+04, 0.16820500E+04, -.24397300E+04, -.12987400E+04, 0.41901400E+04, -.26661500E+04, 0.13276200E+04, 0.13670100E+04, 0.38078000E+03, 0.18538100E+02, 0.80609400E+03, 0.13653500E+02, 0.59469600E+03, 0.36921200E+03, -.40846800E+01, 0.20566800E+01, 0.71932800E+01, -.15530300E+02, 0.19486200E+01, -.16393100E+02, -.23881200E+02, -.86658800E+02, -.10471700E+02, 0.60466400E+00, -.31042600E+00, -.70612000E+00, 0.77709200E+00, 0.32474700E+00, -.72215100E+00, 0.76087500E+00, 0.47097100E+01, 0.23389300E+00, -.12282800E+02, 0.62013000E+01, 0.10443300E+02, -.16607100E+02, 0.67309700E+01, -.37556700E+01, -.12150200E+02, -.73685100E+02, -.35374500E+01, -.14573400E+05, 0.73127700E+04, 0.70217000E+04, 0.34429900E+04, 0.60990200E+04, 0.86249200E+03, -.42360000E+04, -.13546500E+04, 0.58344400E+04, -.10959200E+04, 0.57039600E+03, 0.37025600E+03, 0.39481000E+03, 0.87811500E+03, -.32289400E+03, -.56568600E+03, 0.22770100E+04, 0.90236200E+03, -.19523500E+04, 0.96491700E+03, 0.99638700E+03, 0.83446800E+03, 0.27935500E+03, 0.19846300E+03, -.68848300E+03, -.17134000E+04, 0.78039500E+03, 0.64570500E+03, -.33913500E+03, -.32649400E+03, 0.20759800E+02, 0.12255700E+03, -.19824200E+03, 0.23235300E+03, 0.10170900E+02, -.15094100E+03, -.15428900E+04, 0.76715300E+03, 0.82206200E+03, 0.85953400E+03, 0.12839200E+04, -.16193700E+03, -.11967100E+04, -.33624100E+04, 0.11255100E+04, 0.16902500E+04, -.84050300E+03, -.74439900E+03, -.29675500E+03, -.91359600E+02, -.40902900E+03, 0.36596400E+03, -.39480700E+02, -.35113400E+03, 0.64882600E+03, -.32796100E+03, -.12850900E+03, -.74668400E+03, -.17825200E+03, 0.25871500E+02, 0.26387800E+02, -.25013800E+04, -.57176800E+03, 0.10213500E+04, -.49602400E+03, -.52536500E+03, -.13509900E+03, 0.47145000E+03, -.85788300E+03, -.59353400E+03, -.63224600E+02, 0.55485100E+03, -.95247300E+03, 0.49364400E+03, 0.48110700E+03, 0.59144700E+03, 0.18811300E+03, 0.23844800E+03, 0.68229200E+03, 0.24239300E+04, 0.67349000E+03, -.44606900E+04, 0.22087700E+04, 0.21273100E+04, 0.77711900E+03, 0.15418600E+04, 0.67493100E+03, -.83697200E+03, -.11079900E+04, 0.13160900E+04, -.74424200E+04, 0.37036400E+04, 0.36716300E+04, 0.13158300E+04, 0.26197400E+04, 0.53117800E+03, -.22682000E+04, -.26765200E+04, 0.24496600E+04, -.21000700E+04, 0.10517800E+04, 0.10929000E+04, 0.28484100E+03, 0.14671000E+03, 0.63876300E+03, 0.59375100E+03, 0.16684500E+04, 0.58223800E+03, 0.13958300E+04, -.69534900E+03, -.80326700E+03, 0.75779300E+02, 0.18134500E+03, -.58165200E+03, -.25045700E+03, -.68398400E+03, 0.61963700E+02, -.11212100E+02, -.24580900E+03, 0.39474600E+02, -.44066200E+01, 0.55897200E+03, 0.89462000E+01, 0.42635600E+02, 0.48638300E+03, -.71974500E+03, 0.83141800E+03, -.33611300E+01, -.31432300E+01, 0.18210400E+02, -.59305400E+03, 0.36956300E+04, -.60053300E+03, -.34609800E+03, 0.21276800E+04, 0.69284200E+03, 0.90313800E+03, 0.63980300E+02, -.86782000E+02, 0.31742800E+03, -.22323300E+04, 0.18068800E+03, -.35377600E+03 },
            { 0.58859800E+00, 0.24897500E+00, -.16618600E+00, -.12303200E+00, -.63068200E+00, -.59589200E-01, -.17453900E+00, 0.10824800E+00, 0.29199300E+00, -.12593700E-01, 0.16603200E+00, -.34417200E+00, 0.49794300E+00, -.59953400E+00, 0.33621700E+00, -.87845900E-01, 0.27343200E+00, 0.48241500E-02, 0.14051100E-01, -.18285100E+00, -.64125900E-02, -.42098200E+00, -.18742900E+00, -.11433200E+01, 0.10768900E+00, 0.55964600E-01, 0.11818100E+00, -.64039400E-01, 0.20311200E+00, 0.76875100E-01, 0.60117100E+03, 0.13677800E+03, -.25550000E+03, -.21254000E+03, -.88351900E+03, -.21922400E+00, -.18156200E+01, 0.90199800E+00, 0.91849200E+00, 0.38288700E+00, -.36507900E+00, 0.40227600E+00, 0.38835900E+00, 0.44342400E-01, -.21791700E+00, -.65404100E+03, 0.33580500E+03, 0.31688000E+03, -.16406900E+03, 0.24795800E+03, 0.11627200E+03, -.19454300E+03, -.46482300E+03, 0.21656900E+03, 0.80957400E+03, -.40528600E+03, -.39938300E+03, -.65875200E+02, -.29562400E+03, -.62451100E+02, 0.21611200E+03, 0.14298300E+04, -.11757900E+03, 0.84187300E+04, -.41870400E+04, -.42030200E+04, -.17853200E+04, -.30552600E+04, -.81237000E+03, 0.23043500E+04, 0.15793700E+04, -.32256200E+04, 0.27429400E+04, -.13680700E+04, -.13600100E+04, -.34720600E+03, -.69617400E+03, -.71339800E+03, 0.51777500E+02, -.42989000E+03, -.76098500E+03, 0.11212000E+02, -.56709300E+01, -.50591700E+01, 0.35259500E+01, -.82404000E+01, -.35697400E+01, -.28801200E+01, 0.52750300E+02, -.52600500E+01, -.16782100E+01, 0.83256900E+00, 0.81417900E+00, 0.73928700E-01, 0.18231200E+00, 0.31268600E+00, -.92710000E+00, -.42017800E+01, 0.19836200E+00, 0.10761300E+02, -.53848000E+01, -.51178000E+01, 0.70291800E+00, -.36593300E+00, -.41122800E+01, 0.29317100E+00, 0.55650100E+02, -.12029700E+01, 0.12436400E+05, -.61801400E+04, -.62067300E+04, -.21777500E+04, -.38696000E+04, -.16810000E+04, 0.29369100E+04, 0.34482700E+03, -.38619200E+04, 0.25545300E+04, -.12600600E+04, -.12810500E+04, -.38315900E+03, -.49448300E+03, -.60847000E+03, 0.29776100E+03, -.24489000E+04, -.35125700E+03, 0.30026200E+04, -.15070300E+04, -.15009600E+04, 0.42468200E+03, -.63201300E+03, -.90186700E+03, -.25210500E+03, 0.70099200E+03, -.79962000E+03, -.86793900E+03, 0.42687400E+03, 0.44817800E+03, 0.21116900E+03, 0.34067100E+02, 0.27584600E+03, 0.89911300E+02, 0.34068400E+03, 0.69992200E+02, 0.26460200E+04, -.13258600E+04, -.13236200E+04, 0.11252500E+03, -.62164400E+03, -.60444200E+03, 0.30820600E+02, 0.17494500E+04, -.83918400E+03, -.22579300E+04, 0.11281200E+04, 0.11318000E+04, 0.28183600E+03, 0.51700900E+03, 0.61489500E+03, -.26655300E+02, 0.33386000E+03, 0.61116600E+03, -.41617800E+03, 0.20260000E+03, 0.22638500E+03, 0.22062500E+03, 0.26447900E+03, -.55158400E+02, -.14160500E+03, 0.20111400E+04, 0.18014500E+03, 0.13179800E+03, -.58666700E+02, -.67390700E+02, 0.87494400E+02, 0.19523400E+03, -.15582600E+03, -.11553000E+03, -.52601800E+03, 0.55973200E+03, 0.32002000E+03, -.14593600E+03, -.17317600E+03, -.42164100E+03, 0.93688200E+02, 0.22290400E+02, -.41995300E+02, -.17134500E+04, -.14956400E+02, 0.24207000E+04, -.12173200E+04, -.12158400E+04, -.47572200E+03, -.10376000E+04, 0.18372700E+02, 0.11752800E+04, 0.14959400E+04, -.11836000E+04, 0.60747300E+04, -.30400700E+04, -.29851800E+04, -.94725900E+03, -.22970600E+04, -.66873800E+03, 0.15202900E+04, 0.21819900E+04, -.21188300E+04, 0.85388800E+03, -.42261200E+03, -.43059200E+03, -.35961900E+03, -.89509800E+02, -.12029300E+03, 0.19425400E+03, -.82882000E+03, -.20185900E+03, -.81535900E+03, 0.40692700E+03, 0.38942400E+03, -.22330000E+03, 0.17602000E+03, 0.15721600E+03, -.49591500E+03, -.35418800E+03, 0.34545500E+03, 0.23090400E+02, -.16765000E+03, 0.88390400E+00, 0.48819000E+01, 0.49263800E+03, 0.17231200E+01, -.10011300E+03, -.78364200E+03, 0.50544400E+03, 0.10303000E+03, -.50004200E+01, 0.30024600E+01, -.13757700E+02, 0.16094800E+03, -.28048900E+04, 0.76922400E+03, -.15737600E+04, -.18898100E+04, -.86556700E+02, -.52844400E+03, -.23894500E+03, 0.35339500E+03, -.16958300E+03, 0.13762800E+04, -.37158400E+03, 0.29324600E+03 },
            { -.17509300E+01, 0.40886700E+00, 0.78279900E+00, -.10323200E+01, -.97797300E+00, -.99375800E-01, 0.49481200E+00, 0.12914700E+00, -.41735800E+00, -.19912700E-01, 0.28330800E+00, 0.84311400E+00, -.91212500E+00, -.31151600E+00, 0.54066300E+00, -.14954300E+00, 0.20818400E+00, -.30865300E+00, -.37631100E+00, -.47558900E-01, 0.77096100E+00, 0.10869100E+00, 0.13871300E+00, -.16206300E+00, 0.22806600E-01, 0.62970400E+00, 0.13680300E+00, -.22941000E+00, -.23670600E-01, -.64013000E+00, 0.97635300E+00, -.75782200E+03, 0.73467900E+03, 0.93580800E+03, 0.18149600E+04, -.21133000E+03, -.78315900E+00, 0.41176300E+00, 0.32537800E+00, 0.42203700E-01, -.15432800E+01, 0.15566900E+01, 0.19351100E+01, 0.18486100E+01, -.93120700E+00, -.89819500E+03, 0.41481800E+03, 0.47587800E+03, -.12568100E+03, -.16330900E+03, 0.22914200E+03, 0.13737500E+03, 0.13147300E+04, 0.61147100E+02, -.54598600E+03, 0.27802300E+03, 0.26297400E+03, 0.20815400E+03, 0.66520600E+03, -.22413700E+03, -.64389400E+03, -.21916500E+04, 0.34308700E+03, -.18040100E+05, 0.89392100E+04, 0.87947000E+04, 0.39535300E+04, 0.53129000E+04, 0.24103100E+04, -.27321300E+04, 0.13491000E+04, 0.58954700E+04, -.15760000E+04, 0.78948900E+03, 0.81286200E+03, 0.42986600E+03, -.11678900E+03, 0.47112300E+03, 0.16969200E+03, 0.83515600E+02, 0.20477300E+03, -.30500600E+02, 0.15580500E+02, 0.18798100E+02, -.23864900E+02, -.18925100E+02, 0.21501800E+02, 0.83882400E+01, -.75842500E+02, -.29317300E+02, 0.15091400E+01, -.73739400E+00, -.71730600E+00, 0.37953000E-01, -.41005200E+00, -.49731200E+00, 0.17270500E+01, 0.65970500E+01, -.48847100E+00, -.20367900E+02, 0.10227100E+02, 0.10479300E+02, -.15046000E+02, 0.11370300E+01, 0.14708600E+02, -.98684600E+01, -.82288500E+02, -.48004000E+01, -.15273300E+05, 0.75039300E+04, 0.75799100E+04, 0.30020400E+04, 0.62245600E+04, 0.12518700E+04, -.39015800E+04, 0.24415500E+04, 0.57665400E+04, 0.27518200E+04, -.14505000E+04, -.13479000E+04, -.15563400E+04, -.87509000E+03, -.28963900E+03, 0.49882800E+03, 0.44910900E+04, -.13006100E+04, -.51867000E+04, 0.26479500E+04, 0.25886800E+04, 0.31652100E+03, -.16435400E+03, 0.21890700E+04, 0.24479400E+04, 0.63488300E+03, 0.74367300E+03, 0.20898300E+04, -.98605200E+03, -.96790100E+03, -.16630700E+03, 0.21474800E+03, -.67430200E+03, -.72907700E+02, -.72165400E+03, -.59324900E+02, -.37759200E+04, 0.19572700E+04, 0.18787400E+04, 0.10220200E+04, 0.14549600E+04, 0.75340000E+03, 0.13040900E+03, -.22794400E+04, 0.17228100E+04, -.35277000E+03, 0.15108700E+03, 0.20890700E+03, -.41674600E+03, 0.19407300E+03, 0.16400500E+03, 0.30268700E+03, 0.47129600E+03, 0.13123500E+03, 0.27089800E+03, -.10904000E+03, -.23403600E+03, -.27289900E+03, -.90171600E+02, 0.41177800E+03, -.68896400E+02, -.30952200E+04, -.20834300E+03, 0.71162700E+03, -.38977000E+03, -.32020000E+03, -.12332300E+04, 0.45664800E+03, -.21387600E+03, -.95455900E+03, 0.18124200E+03, -.41511500E+03, 0.60323800E+03, -.36554600E+03, -.21291600E+03, -.10990800E+01, 0.36039200E+02, -.49667900E+03, -.34664800E+03, 0.22367300E+04, 0.36628200E+03, -.44659000E+04, 0.22684300E+04, 0.18261000E+04, 0.17335300E+04, 0.23006100E+04, -.20833200E+03, -.19840300E+04, -.15927200E+04, 0.23491300E+04, -.11285300E+05, 0.56547100E+04, 0.55484000E+04, 0.23107000E+04, 0.38946700E+04, 0.11702800E+04, -.20086300E+04, -.14652200E+04, 0.35363300E+04, -.31585700E+04, 0.15637300E+04, 0.16085100E+04, -.24459400E+02, 0.78063500E+02, 0.70568600E+03, -.29796500E+03, 0.20025400E+04, 0.59547800E+03, 0.19068500E+04, -.95114900E+03, -.88635400E+03, -.51190100E+03, -.53321600E+02, -.57422700E+03, 0.86883100E+03, 0.51906900E+03, -.57452300E+03, -.21861200E+02, -.29930200E+03, -.78667200E+02, -.75283900E+01, 0.74317300E+02, 0.16736000E+02, -.70781300E+03, 0.60550100E+03, 0.13108100E+03, 0.54817300E+03, 0.16729700E+02, -.48316900E+01, 0.25265900E+02, -.25939300E+04, 0.35649700E+04, 0.10023100E+04, 0.27289900E+03, -.49257500E+02, 0.59361000E+03, 0.98242500E+03, 0.79724500E+03, 0.36420800E+02, 0.28484000E+03, -.10912900E+04, 0.74612700E+03, -.63405700E+03 },
            { -.13028800E+01, 0.23439600E-01, 0.17330800E+00, -.38651200E+00, 0.59867000E+00, 0.27000900E-01, 0.65079200E-01, 0.23547500E+00, 0.93147500E-01, 0.20323500E-01, -.49475700E+00, -.71089800E+00, 0.96793600E+00, -.26428800E+00, 0.90140000E+00, -.21199300E+00, 0.26169300E+00, -.13186800E+01, 0.68029100E+00, 0.19759200E-01, 0.98730600E-01, 0.18982600E+00, -.56560000E+00, -.85497200E+00, 0.67635700E-01, -.16231600E-01, 0.28349000E-01, -.17909200E+00, -.15710900E-01, -.13021400E+00, -.24685900E+00, -.47362100E+00, 0.60389600E+03, 0.11071400E+04, 0.39034400E+03, -.44952600E+02, 0.21574400E+01, -.10797400E+01, -.10909200E+01, 0.32199900E+00, 0.41690800E+00, -.24933400E+00, 0.42777100E+00, -.32564700E+00, 0.37427000E-04, -.34034500E+04, 0.16848600E+04, 0.17047000E+04, 0.81681700E+02, 0.12442700E+03, 0.10366300E+04, 0.36942700E+00, 0.20823600E+04, 0.17477900E+03, -.53883800E+03, 0.27111400E+03, 0.26737700E+03, 0.27233600E+02, 0.22698200E+03, 0.14312300E+03, 0.16985300E+03, -.88208400E+03, -.28578300E+03, -.93840600E+04, 0.46527500E+04, 0.45843200E+04, 0.22890200E+04, 0.28316700E+04, 0.12842900E+04, -.15961800E+04, 0.15073900E+04, 0.33645900E+04, -.22733000E+03, 0.11582000E+03, 0.12981200E+03, 0.66419800E+03, 0.20606300E+03, 0.63806300E+02, 0.17897900E+03, 0.44799500E+03, 0.32811600E+03, -.22605600E+02, 0.11276900E+02, 0.13530700E+02, -.13083700E+02, -.23668800E+02, 0.32963700E+02, 0.29784900E+02, -.22672200E+02, -.24977500E+02, 0.17958400E+01, -.88903900E+00, -.85420200E+00, -.80211800E+00, -.63054900E+00, -.71928400E-02, 0.13102600E+01, 0.34400500E+01, -.75784800E+00, -.76653500E+01, 0.37615700E+01, 0.41083900E+01, -.24427100E+01, -.11736600E+02, 0.15252000E+02, 0.37890300E+01, -.34267700E+02, -.62780700E+01, -.67173300E+04, 0.32962100E+04, 0.33416000E+04, 0.10836100E+04, 0.22364800E+04, 0.95266000E+03, -.13860100E+04, 0.31324200E+04, 0.18450600E+04, 0.36901700E+04, -.18747300E+04, -.18226300E+04, -.15477800E+04, -.15155500E+04, -.29378900E+03, 0.79828200E+03, 0.29195800E+04, -.20919900E+04, -.55049600E+04, 0.27637800E+04, 0.27508700E+04, -.75328900E+03, 0.22660500E+03, 0.28054400E+04, 0.36491500E+04, 0.22393300E+04, 0.39833200E+03, 0.13975900E+04, -.66287300E+03, -.64219700E+03, -.74994400E+01, 0.28819800E+03, -.61407100E+03, -.35258400E+03, -.79532700E+03, 0.28031100E+03, -.41129900E+04, 0.20710500E+04, 0.20505800E+04, -.55263300E+02, 0.70775500E+03, 0.15842400E+04, 0.16160900E+04, 0.54973600E+03, 0.98279100E+03, -.24114900E+03, 0.11284400E+03, 0.14486500E+03, -.42163600E+03, 0.49148800E+02, -.65959600E+02, -.30520600E+03, -.45766400E+03, 0.20770200E+03, -.20898500E+03, 0.11319700E+03, 0.75960500E+02, 0.12700800E+03, -.14407800E+03, 0.39592200E+03, 0.13806600E+03, -.14248600E+04, 0.13997600E+03, 0.51468300E+03, -.27468100E+03, -.24744300E+03, -.10874000E+04, -.29742500E+03, 0.13768000E+03, -.36282900E+03, 0.67066700E+02, -.13531800E+04, 0.25178100E+04, -.12835400E+04, -.12273000E+04, -.46710700E+03, -.52247100E+03, -.87521000E+03, -.66362500E+03, 0.54131300E+03, -.47616200E+03, -.13881000E+04, 0.71489400E+03, 0.48510500E+03, 0.10476400E+04, 0.10855000E+04, -.61771900E+03, -.15568800E+04, -.10652400E+04, 0.14172500E+04, -.73568900E+04, 0.36823300E+04, 0.36843500E+04, 0.12683000E+04, 0.20326200E+04, 0.13297800E+04, -.56551800E+03, 0.64488100E+03, 0.18100600E+04, -.24949900E+04, 0.12386200E+04, 0.12561500E+04, -.75172000E+02, 0.55596300E+02, 0.53590400E+03, -.70662900E+03, 0.17703700E+04, 0.34747900E+03, -.87903100E+03, 0.43643000E+03, 0.47048700E+03, -.47339800E+03, -.11573000E+03, 0.35658100E+03, 0.53758500E+03, 0.14320000E+04, -.37446800E+03, -.23271200E+02, 0.30425100E+03, -.69319100E+02, -.52454500E+01, 0.82979900E+03, -.31976400E+01, -.91213800E+03, 0.88400500E+03, 0.48426800E+03, 0.57602100E+02, 0.18483200E+02, -.29950300E+01, 0.77155400E+01, -.18886000E+04, 0.11807700E+04, 0.13528500E+04, 0.11819600E+04, -.92071900E+03, 0.62815900E+03, 0.29721600E+03, 0.10043500E+04, -.27702200E+02, 0.64692300E+02, 0.40301200E+03, 0.12671100E+04, 0.37198400E+03 },
            { -.56739100E+00, -.56997500E-01, -.38737100E+00, 0.10885500E+01, 0.20446400E+01, 0.17271000E+00, 0.28608400E+00, -.50268800E-01, -.43800400E+00, 0.29081700E+00, 0.26140100E+00, -.53207300E+00, -.45212600E-01, 0.45489700E+00, 0.11399800E+00, -.41050900E-01, 0.15748200E+00, 0.50500000E-01, -.12305400E+01, 0.42826400E+00, 0.10248500E+01, 0.13017000E+01, -.38073300E-01, 0.19349900E+01, -.10410300E+00, 0.13378100E+00, -.34759300E+00, 0.55676400E-01, -.23714600E+00, -.47737200E+00, 0.73110100E+00, 0.65734900E+00, 0.26359500E+00, 0.11018100E+04, 0.23900500E+04, 0.19433500E+03, 0.18319100E+01, -.91743700E+00, -.92255600E+00, 0.83756100E+00, 0.10989000E+01, -.12086500E+01, -.59708800E+00, 0.66866700E+00, 0.96194400E+00, 0.10368400E+04, -.48537100E+03, -.50714100E+03, 0.66620700E+03, -.10055900E+03, -.29455100E+03, 0.24094200E+03, -.20052700E+03, 0.13678200E+03, -.26642700E+04, 0.13240400E+04, 0.13654800E+04, 0.17941500E+03, 0.55873400E+03, 0.38177300E+03, -.97651400E+03, -.19257500E+04, 0.79825200E+03, -.70078300E+04, 0.35556500E+04, 0.35142500E+04, 0.17710800E+04, 0.36142100E+04, 0.23199700E+03, -.30010900E+04, -.50610200E+04, 0.33230200E+04, -.40438600E+04, 0.20126700E+04, 0.20306700E+04, 0.95306200E+03, 0.10256800E+04, 0.10449500E+04, -.29823600E+03, 0.63206800E+03, 0.11486500E+04, 0.16740400E+02, -.84959500E+01, -.10616300E+02, -.11833100E+02, 0.19709100E+02, -.39338200E+02, -.56644400E+02, -.87544500E+02, 0.20913700E+02, 0.87790000E+00, -.45624300E+00, -.68347600E+00, 0.10134900E+01, 0.57860200E+00, -.67573200E+00, 0.27548200E+00, 0.42907500E+01, 0.64201200E+00, -.19853500E+01, 0.10312800E+01, 0.21325400E+01, -.15503700E+02, 0.35097400E+01, -.16591500E+02, -.22400800E+02, -.75435500E+02, 0.19788300E+01, -.16636600E+05, 0.84097100E+04, 0.81646800E+04, 0.35409900E+04, 0.61358400E+04, 0.12868100E+04, -.51766300E+04, -.51529800E+04, 0.60216300E+04, -.75627800E+04, 0.38297600E+04, 0.36694700E+04, 0.21562800E+04, 0.23937900E+04, 0.73008100E+03, -.17698900E+04, 0.13563900E+04, 0.25611500E+04, -.40229900E+04, 0.19872600E+04, 0.20257200E+04, -.12554500E+03, 0.15291200E+04, 0.61184200E+03, -.13251800E+04, -.24485000E+04, 0.17584600E+04, -.14478000E+03, 0.22424600E+01, -.31085200E+02, 0.48186400E+02, 0.14930700E+03, -.18086400E+02, 0.63309700E+02, -.67994100E+02, -.44550700E+02, -.25462000E+04, 0.12430900E+04, 0.13099800E+04, -.11023100E+03, 0.14177600E+04, 0.22808800E+03, -.11184100E+04, -.39369500E+04, 0.12782300E+04, 0.42890200E+04, -.21237300E+04, -.21479400E+04, -.78860600E+03, -.96561800E+03, -.99647600E+03, 0.61916000E+03, -.34010000E+03, -.13508000E+04, 0.97604800E+03, -.50520700E+03, -.38776400E+03, -.10515300E+04, -.43477600E+03, -.31097800E+03, -.99369700E+02, -.24051100E+04, -.59615300E+03, 0.93253300E+03, -.43448600E+03, -.48626800E+03, 0.30101600E+03, -.34494600E+03, -.78036900E+03, -.27537400E+02, 0.45904700E+03, -.16206000E+03, -.27959200E+04, 0.14500800E+04, 0.13620500E+04, 0.15150800E+04, 0.34726400E+03, 0.90634700E+03, 0.12354800E+04, 0.29217500E+04, 0.63264500E+03, -.30663300E+04, 0.14885900E+04, 0.18192900E+04, -.16555000E+02, 0.82038700E+03, 0.49438600E+03, -.91285200E+03, -.20186100E+04, 0.95731100E+03, -.58854500E+04, 0.29107700E+04, 0.28966900E+04, 0.24277000E+03, 0.20607100E+04, 0.32438800E+03, -.30172800E+04, -.46253000E+04, 0.21434800E+04, -.20460300E+03, 0.11459500E+03, 0.11522000E+03, 0.10341800E+04, 0.30308500E+03, 0.51025500E+02, 0.61507600E+03, 0.52655000E+03, 0.39848500E+03, 0.22109100E+03, -.10826600E+03, -.19805400E+03, 0.52133800E+03, 0.15454200E+03, -.23681100E+03, -.74800700E+03, -.11342700E+04, 0.73245800E+02, -.14785100E+02, 0.13489100E+03, 0.14248600E+03, -.33373100E+01, 0.94477100E+03, -.95484300E+01, 0.13246800E+04, 0.87226000E+03, -.14240400E+04, 0.36080800E+03, -.26297900E+02, -.24933700E+01, 0.32631100E+01, 0.19150800E+04, 0.37002200E+04, -.15379900E+04, 0.87800500E+03, 0.44690500E+04, 0.64963000E+03, 0.66998400E+03, 0.24716800E+03, -.71768800E+03, 0.24888000E+03, -.38483400E+04, -.48522800E+03, -.10648600E+03 },
            { 0.20254700E+01, 0.79953400E-01, -.93980600E+00, 0.65224100E+00, 0.40368000E-01, -.52312600E-02, -.50830600E+00, -.40604100E+00, 0.45262000E+00, -.18074200E+00, 0.77119800E+00, 0.10791600E+01, -.32894900E+00, 0.21851600E+00, -.13712500E+01, 0.56088400E+00, -.96906200E+00, 0.89966600E+00, -.33267100E+00, 0.15051000E+00, -.64632800E-02, -.18323500E+01, -.16517800E+00, -.22208800E+01, -.22604700E+00, -.46354600E+00, -.27118800E+00, 0.21702200E-01, 0.13299100E+00, 0.49353200E+00, 0.53376500E+00, 0.72759500E+00, -.11918400E+01, 0.79946200E+00, -.21391100E+04, -.59808300E+03, -.39061000E+01, 0.19414100E+01, 0.18952200E+01, -.59981400E-01, -.16004000E+00, 0.10324700E+01, 0.24369400E+00, -.77823200E+00, -.57772600E+00, -.28794900E+04, 0.13793500E+04, 0.13724000E+04, 0.30638900E+03, 0.53978400E+03, 0.59366700E+03, -.50196400E+03, 0.12154500E+04, 0.38192400E+03, 0.18216300E+04, -.90214700E+03, -.99788800E+03, -.13219400E+03, -.61195200E+03, -.17252100E+03, 0.99760700E+03, 0.98951700E+03, -.89216000E+03, 0.26896300E+04, -.14329100E+04, -.12967100E+04, -.86581400E+03, -.24872200E+04, 0.66706200E+03, 0.15488100E+04, 0.30862700E+04, -.20677200E+04, -.97224800E+03, 0.48729600E+03, 0.49125400E+03, -.30771100E+03, -.22459300E+03, 0.19156200E+03, 0.29284200E+03, 0.59933700E+03, -.29302400E+03, -.36465200E+01, 0.19266900E+01, 0.15864100E+01, 0.24585600E+02, -.41979200E+01, -.51212300E+01, 0.28371300E+02, 0.24091000E+01, 0.11961800E+01, -.28009900E+00, 0.16547000E+00, 0.36504400E+00, -.10817300E+01, -.11268800E+01, 0.63175700E+00, -.12129200E+00, -.50352500E+00, -.11438700E+01, -.56008300E+01, 0.27173800E+01, -.67579200E+00, 0.25748900E+02, 0.11846800E+02, -.76151300E+01, 0.13970000E+02, 0.39422500E+01, 0.19154200E+02, 0.70744300E+04, -.36937000E+04, -.32999800E+04, -.21489800E+04, -.34194000E+04, -.35450200E+02, 0.19689200E+04, 0.37186000E+04, -.32367700E+04, 0.39210900E+04, -.20336800E+04, -.17678600E+04, -.22501100E+04, -.16736300E+04, -.69312000E+02, 0.12148200E+04, 0.35154500E+03, -.19142500E+04, 0.10362300E+04, -.49744000E+03, -.55984000E+03, 0.46962900E+02, -.11398500E+04, 0.85576600E+03, 0.26820100E+04, 0.30062200E+04, -.21594000E+04, 0.23240700E+04, -.10571500E+04, -.10745700E+04, -.10966600E+03, -.34290100E+03, -.60827600E+03, 0.40388100E+03, -.28121700E+03, -.14627100E+03, 0.88985300E+03, -.41424300E+03, -.52791200E+03, 0.37281600E+03, -.92977300E+03, 0.48649400E+03, 0.18160600E+04, 0.31508100E+04, -.11082100E+04, -.79300700E+03, 0.37658300E+03, 0.33074600E+03, 0.44584600E+03, 0.36750000E+03, 0.19913000E+03, -.35587600E+03, -.35792000E+03, 0.76247800E+03, -.31717300E+03, 0.18389800E+03, -.51339600E+02, 0.11583800E+04, 0.75539100E+03, -.33068300E+03, 0.17122300E+03, 0.10558800E+03, 0.10113800E+04, -.15971700E+04, 0.75414800E+03, 0.87831200E+03, -.75380000E+03, 0.54592800E+03, 0.38525200E+03, -.12378100E+03, -.11011700E+04, 0.25205300E+03, 0.12572900E+04, -.71253600E+03, -.58228400E+03, -.12927700E+04, -.47503800E+03, -.96189000E+02, -.11344100E+03, -.30138300E+03, -.64597500E+03, 0.22901200E+04, -.10763700E+04, -.14456900E+04, 0.14285800E+03, -.44162500E+03, -.32402600E+03, 0.20087800E+03, 0.47795500E+03, -.46280900E+03, 0.20192700E+04, -.96331500E+03, -.11392200E+04, 0.48911100E+03, -.56898900E+03, -.17158900E+03, 0.11152900E+04, 0.18644600E+04, -.61638300E+03, -.21986000E+04, 0.10759500E+04, 0.10498700E+04, 0.80794800E+02, 0.46957100E+03, 0.43561400E+03, -.40095200E+03, 0.84737000E+03, 0.45681200E+03, -.14715100E+04, 0.73090100E+03, 0.79629800E+03, -.12093100E+03, -.28927900E+02, 0.47598400E+03, 0.70983900E+02, 0.18678500E+04, 0.37691900E+03, 0.67848900E+01, 0.10843600E+03, -.55561100E+02, -.17666100E+00, -.26171100E+03, 0.93973400E+01, -.45997500E+03, -.24823900E+03, 0.42798900E+03, 0.23000900E+03, 0.11075500E+02, 0.34767800E+00, 0.72468100E+01, -.83220200E+03, -.27877000E+04, 0.15928400E+04, -.22292500E+03, -.44226300E+04, -.84896300E+02, -.18577600E+03, -.90002700E+01, -.19111500E+03, 0.17400900E+02, 0.15110000E+04, 0.78383100E+03, 0.75118700E+03 },
            { -.20488500E-01, 0.57868900E+00, 0.17748500E+00, -.18682300E+00, -.73080700E+00, -.15161200E+00, -.40535200E-01, 0.32468900E-01, 0.17552600E+00, -.46966600E-01, 0.22864300E+00, 0.24291500E+00, -.18940700E+00, -.23630800E-01, 0.45272800E-01, 0.24598700E-01, -.40880500E-01, -.60479300E-01, 0.23855600E-01, 0.21159200E+00, -.26249000E-02, 0.23894600E+00, -.30378800E+00, 0.40120200E+00, -.60921900E-02, -.55776800E-02, 0.48644100E-01, 0.21644100E-01, 0.22551900E-01, 0.16935800E-02, 0.16421200E+00, 0.11778500E+00, 0.75759400E-01, 0.17904600E+00, 0.59716200E-01, -.18868400E+03, -.33994800E+00, 0.17211800E+00, 0.16083100E+00, -.44918000E-01, -.16738000E+00, 0.18145800E+00, 0.25100600E+00, 0.15890800E+00, -.26404100E+00, 0.16918700E+03, -.87528500E+02, -.84100600E+02, -.12032800E+03, 0.55728400E+01, -.54245600E+02, -.18429900E+02, -.14293300E+03, -.58452000E+02, 0.25270400E+03, -.12592000E+03, -.12681400E+03, -.21323500E+02, -.15929300E+02, -.81778100E+02, -.12777300E+02, 0.16363600E+03, -.38796100E+02, 0.10744500E+04, -.53965100E+03, -.56462500E+03, -.17030400E+03, -.35637900E+03, -.14573100E+03, 0.38445900E+03, 0.16230300E+03, -.37818100E+03, 0.51081600E+03, -.25429500E+03, -.24815200E+03, -.14065400E+03, -.10557200E+03, -.15470700E+03, -.11469500E+02, -.22173100E+03, -.20801600E+03, 0.16573000E+01, -.82538200E+00, -.18880800E+00, -.86034000E+00, -.26447700E+01, -.69456600E+00, 0.13629700E+00, 0.62664700E+01, -.21569500E+01, -.19870700E+00, 0.10072600E+00, 0.93931100E-01, 0.13670500E-01, 0.50440800E-02, 0.34194800E-01, -.56640100E-01, -.42233700E+00, -.70295600E-01, 0.22371000E+01, -.11161800E+01, -.10182500E+01, 0.40567300E+00, -.71319800E+00, -.77952000E+00, -.14377400E-01, 0.63712900E+01, 0.73798800E+00, 0.18730800E+04, -.94088300E+03, -.93892600E+03, -.22202700E+03, -.35907000E+03, -.40179700E+03, 0.26337400E+03, -.26697400E+03, -.42192600E+03, 0.26381400E+03, -.13392800E+03, -.13083000E+03, -.57453800E+02, 0.24494800E+02, -.80695200E+02, -.21999700E+02, -.40160400E+03, -.10647400E+02, 0.27884700E+03, -.13939000E+03, -.14007000E+03, 0.82391100E+02, -.15487700E+03, -.33454800E+02, 0.11361700E+03, 0.25973700E+03, -.34328100E+03, 0.18264800E+03, -.81617500E+02, -.76418800E+02, -.31801900E-01, 0.27478500E+02, -.82111000E+02, -.69159300E+02, -.84906100E+02, 0.34375500E+02, 0.44145800E+03, -.21601700E+03, -.22179100E+03, 0.57181300E+02, -.10501600E+03, -.10319600E+03, 0.49843500E+02, 0.22261000E+03, -.17760900E+03, -.32115700E+03, 0.15785800E+03, 0.16540600E+03, 0.10701900E+03, 0.72692300E+02, 0.87315400E+02, -.91870000E+01, 0.15002400E+03, 0.17006200E+03, 0.11631200E+03, -.56004900E+02, -.69589200E+02, 0.64212200E+02, -.18433500E+02, -.39691600E+02, -.54326100E+01, 0.23451900E+03, 0.52701700E+02, -.15820800E+02, 0.71575400E+01, 0.13862600E+02, -.66485600E+00, 0.11727100E+03, -.44754200E+02, -.10947000E+03, -.13328900E+03, 0.13936400E+03, 0.28307000E+03, -.14503400E+03, -.13152200E+03, -.70263500E+02, 0.81539700E+02, -.87197900E+02, 0.10222200E+02, -.23417400E+03, -.10557500E+01, 0.42503000E+03, -.20989300E+03, -.27244400E+03, 0.31027200E+02, -.74501600E+02, -.57711900E+02, 0.10531300E+03, 0.11756000E+03, -.16278500E+03, 0.96431300E+03, -.47969500E+03, -.48462500E+03, -.11758900E+03, -.28750300E+03, -.18720700E+03, 0.15068900E+03, 0.63915400E+02, -.29632200E+03, 0.42880100E+03, -.21489100E+03, -.21149300E+03, -.13672900E+03, -.22317200E+02, -.11137400E+03, 0.29400100E+02, -.26032900E+03, -.78776200E+02, 0.33893300E+02, -.16833100E+02, -.12577900E+02, -.48578400E+02, 0.13279500E+02, -.66178100E+02, -.14039900E+03, -.15062600E+03, 0.15623000E+03, 0.30591500E+01, -.75422400E+02, -.92675900E+00, 0.44849700E+00, 0.10215800E+03, 0.15499200E+01, -.76979700E+02, -.15850100E+03, 0.73576800E+02, -.52833900E+02, -.65676700E+00, 0.26265400E+00, -.23518800E+01, 0.75794600E+02, -.42992100E+03, 0.89929700E+02, -.15451200E+03, -.39502700E+03, -.96603500E+02, -.11146500E+03, -.35572100E+02, 0.32761700E+02, 0.25658100E+02, 0.29754000E+02, -.89385000E+02, 0.12966300E+03 },
            { 0.18382300E+00, -.30746700E-01, -.69241800E-01, -.21644700E-01, -.25737700E+00, -.26325000E-01, -.79845000E-01, -.31180100E-02, 0.57824700E-01, -.53108000E-01, -.32734900E-01, -.67232500E-01, -.45597600E-01, 0.62914900E-02, -.30774100E-01, 0.36803000E-01, -.93098200E-01, 0.21904100E-01, 0.12247900E+00, -.21406200E-01, -.12577000E+00, -.60837500E-01, -.12539900E-01, 0.29972900E-01, -.37268100E-01, -.34369000E-01, 0.11831700E-01, 0.67889300E-02, -.22064200E-02, 0.29611000E-02, 0.71653500E-02, 0.13001200E-01, -.44939700E-01, -.69767700E-02, 0.15810600E-01, 0.30398700E-01, 0.22114500E+01, 0.57451700E-03, -.18703200E-02, 0.94671300E-02, 0.88221200E-03, 0.69250300E-02, 0.82028800E-02, 0.41162300E-02, -.52550600E-02, -.10592300E+03, 0.50153200E+02, 0.54099100E+02, 0.14443300E+02, 0.17454900E+02, 0.17409600E+02, -.28702200E+02, 0.70116100E+02, 0.20935000E+02, -.11537600E+02, 0.61223400E+01, 0.46609300E+01, 0.13844700E+01, 0.15344000E+02, -.74744600E+01, -.12576900E+02, -.12403500E+03, 0.62503300E+01, -.73926800E+03, 0.36480400E+03, 0.36861300E+03, 0.14531000E+03, 0.20752000E+03, 0.10709600E+03, -.16388600E+03, -.76109300E+02, 0.22716700E+03, -.10587600E+03, 0.52810500E+02, 0.52145800E+02, 0.40356200E+02, 0.38288000E+02, 0.90299600E+01, -.27337000E+02, 0.19029900E+01, 0.42265800E+02, -.10654400E+01, 0.54403200E+00, 0.47215700E+00, -.36958000E-01, -.14668500E+00, 0.21336300E+00, 0.47168700E+00, -.45177900E+01, -.51355100E+00, 0.12543000E+00, -.61347000E-01, -.61784900E-01, -.35994900E-01, -.50672500E-01, -.11519400E-01, 0.76098200E-01, 0.37218900E+00, -.51232300E-01, -.10382400E+01, 0.51819800E+00, 0.47430200E+00, 0.24346400E+00, 0.26173000E+00, 0.10647700E+00, -.22388200E+00, -.48528100E+01, 0.10226200E+00, -.10358700E+04, 0.50950600E+03, 0.51709400E+03, 0.16671100E+03, 0.28850900E+03, 0.15638800E+03, -.24095000E+03, 0.45747300E+02, 0.30178700E+03, -.16492000E+03, 0.78697800E+02, 0.83624000E+02, -.13234500E+02, 0.97922000E+01, 0.51703500E+02, 0.22329800E+01, 0.24182900E+03, 0.59527400E+01, -.21063500E+03, 0.10645700E+03, 0.10496600E+03, 0.10759300E+02, 0.34027500E+02, 0.72720100E+02, 0.38897400E+02, -.42465500E+02, 0.19661800E+02, 0.44227700E+01, 0.12602600E+01, -.50783600E+01, -.69602300E+01, -.17228100E+01, -.23027100E+01, 0.80322900E+01, -.65343900E+01, 0.60283300E+01, -.20608300E+03, 0.10408000E+03, 0.10242400E+03, 0.20774800E+02, 0.44206300E+02, 0.52102700E+02, -.22738600E+01, -.11230600E+03, 0.45043900E+02, 0.64306900E+02, -.32691200E+02, -.32004000E+02, -.26629200E+02, -.24917800E+02, -.66410100E+01, 0.15825300E+02, -.55349000E+01, -.17027400E+02, 0.35768600E+02, -.16579400E+02, -.20532300E+02, 0.97376800E+00, -.52491900E+01, -.60716000E+01, 0.42815600E+00, -.17951500E+03, -.97241700E+01, -.27266100E+02, 0.11632700E+02, 0.14810200E+02, -.23393100E+02, 0.24651500E+01, 0.66392700E+01, -.77664100E+01, 0.20871100E+02, -.15943400E+02, -.24887700E+02, 0.84929500E+01, 0.14189900E+02, -.48006100E+01, -.11174700E+01, 0.36383000E+01, -.33442100E+01, 0.15261800E+03, 0.13738100E+02, -.21995100E+03, 0.11271600E+03, 0.10773300E+03, 0.50206400E+02, 0.82055300E+02, 0.19086500E+02, -.70427300E+02, -.10041600E+03, 0.87359200E+02, -.50250500E+03, 0.25308300E+03, 0.24267300E+03, 0.10117900E+03, 0.16773400E+03, 0.63323100E+02, -.10889300E+03, -.14503900E+03, 0.15786500E+03, -.19903800E+03, 0.98300500E+02, 0.99849600E+02, 0.24251200E+02, 0.37221300E+02, 0.36141700E+02, -.41404600E+02, 0.10561100E+03, 0.53178700E+02, -.93828800E+01, 0.45306800E+01, 0.57265300E+01, -.80310900E+01, -.19797000E+01, 0.39156600E+01, 0.13353900E+02, 0.71741600E+02, -.46691400E+01, -.16400500E+01, 0.32818800E+01, -.23103300E+01, -.45241300E+00, -.32628100E+01, 0.35204400E+00, -.16050600E+02, 0.52319200E+02, -.54054100E+02, 0.11209000E+02, 0.53820000E+00, -.26997000E+00, 0.12701500E+01, -.27002800E+02, 0.20636100E+03, -.30984800E+02, 0.87099100E+02, 0.76266700E+02, 0.22613000E+02, 0.48833000E+02, 0.16569100E+02, -.15341700E+02, 0.16968200E+02, -.89843600E+02, 0.29898200E+02, 0.76590400E+01 },
            { -.91549700E-01, -.30752000E-01, 0.24266000E-01, 0.71372900E-02, 0.53337300E-01, 0.25079400E-02, 0.35748400E-01, 0.88545800E-03, -.23725700E-01, 0.43806900E-01, 0.51721500E-01, 0.10126700E+00, -.18252400E-01, -.19577700E-01, 0.48485100E-01, -.24567400E-01, 0.15870700E-01, -.15025000E-03, -.49655400E-01, -.33076500E-02, 0.50544100E-01, 0.92771400E-02, 0.51767800E-02, -.12330200E-01, 0.61692700E-02, 0.76387500E-02, -.10223700E-01, 0.17206500E-02, -.10232500E-01, 0.19005600E-02, 0.85395600E-02, 0.19159700E-01, 0.11033900E-01, -.25104600E-02, -.22259000E-03, -.77471300E-02, 0.18562400E-01, 0.28016000E+01, -.18898500E-01, 0.68777400E-02, 0.14326800E-01, -.21360200E-01, -.17214100E-01, -.25181700E-01, 0.65826800E-02, 0.39130700E+02, -.18766400E+02, -.19936000E+02, 0.11784300E+02, 0.48774900E+01, -.15250600E+02, -.76849200E+01, -.40994800E+02, -.10269400E+01, -.15665200E+02, 0.77424100E+01, 0.80287400E+01, -.13316800E+02, -.39856200E+01, 0.95361000E+01, 0.45545900E+01, 0.12121500E+02, -.76747900E+01, 0.15242100E+03, -.75016500E+02, -.70424100E+02, -.33529100E+02, -.37500400E+02, -.27792700E+02, -.24086400E+01, -.74140900E+02, -.38473400E+02, -.46998300E+01, 0.22617600E+01, 0.12110800E+01, 0.11667300E+02, 0.87522700E+01, -.13048800E+01, -.63689200E+01, -.67025800E+01, 0.48189900E+01, 0.38102700E+00, -.19182700E+00, -.31088200E+00, 0.26692400E+00, 0.35464500E-01, -.24059900E+00, -.37592300E+00, 0.84157700E+00, 0.48456000E+00, -.24978200E-01, 0.12098800E-01, 0.12304900E-01, 0.24884900E-01, 0.10618600E-01, 0.79886700E-02, -.13312200E-01, -.26866700E-01, 0.14724500E-01, 0.27588800E+00, -.13693100E+00, -.15244900E+00, -.66341900E-01, -.10504000E+00, -.21754600E+00, -.26459500E+00, 0.45680700E+00, 0.18769100E+00, -.44752800E+02, 0.24203000E+02, 0.23194500E+02, -.52905900E+01, -.12307300E+02, 0.23734700E+02, 0.34572800E+01, -.63257000E+02, -.43788100E+01, -.13489000E+03, 0.68086800E+02, 0.66710700E+02, 0.32076000E+02, 0.32588000E+02, 0.27551200E+02, -.10895100E+02, -.17837700E+02, 0.34338400E+02, -.12485700E+03, 0.62264600E+02, 0.62581600E+02, -.21058900E+02, 0.12092200E+02, 0.39532100E+02, -.19066800E+01, 0.11069800E+02, 0.18647400E+02, -.80071800E+01, 0.24385900E+01, 0.13662100E+01, 0.58683100E+01, -.80608400E+00, 0.39873900E+01, -.64229700E+00, 0.26480300E+01, -.82144400E+00, -.43278400E+02, 0.21175300E+02, 0.21997100E+02, -.11445900E+02, 0.88693300E+01, 0.11383800E+02, -.90762200E+01, -.95973800E+01, 0.10902200E+02, 0.28938400E+02, -.14149100E+02, -.15727600E+02, -.11973600E+02, -.10885600E+02, -.41363200E+01, 0.68579900E+01, -.11937100E+00, -.14690600E+02, 0.43529700E+01, -.25135000E+01, 0.19595400E-01, -.85687700E+01, -.23076700E+01, -.73588300E+01, -.95432900E+01, 0.12749200E+02, 0.59277300E+01, -.17645000E+01, 0.13237200E+01, -.20395700E+00, 0.41166100E+00, -.11148700E+02, 0.63749500E+01, 0.20729000E+02, 0.24649900E+02, -.13850500E+02, -.20511600E+02, 0.11241200E+02, 0.81748400E+01, 0.12792500E+02, 0.11109200E+02, 0.34906400E+01, -.64506200E+01, -.12021800E+02, -.69849300E-01, 0.70276700E+02, -.35790400E+02, -.23017100E+02, -.16978400E+02, -.21535000E+02, -.15140000E+02, -.26493400E+01, -.18753300E+02, -.13930500E+02, 0.46034000E+02, -.23516700E+02, -.21850800E+02, -.21245000E+02, -.26033900E+02, 0.90599800E+00, 0.30818900E+01, -.17480800E+02, -.18630400E+02, 0.42178200E+02, -.20772300E+02, -.21724000E+02, 0.17088800E+02, 0.41924600E+01, -.15634700E+02, -.53601900E+01, -.36520000E+02, -.47143900E+01, -.42265900E+02, 0.21127400E+02, 0.19893000E+02, 0.12487200E+02, 0.70378600E+01, 0.10983500E+02, -.77082900E+01, -.99258500E+01, 0.62221900E+01, 0.28819100E+00, -.13641400E+01, 0.40542000E+01, 0.70917200E-01, 0.36827800E+01, -.21511500E+00, 0.38443800E+02, -.10186600E+01, -.21024200E+02, -.21540500E+01, -.35285200E+00, 0.36177000E-01, -.41962700E+00, 0.47880500E+02, 0.33329200E+01, -.11661000E+02, -.36908600E+02, 0.29461600E+02, 0.41693000E+01, -.93487700E+01, 0.16944000E+01, -.53963600E+01, -.30525200E+01, -.88495600E+01, -.27508300E+02, -.28484400E+01 },
            { -.89564200E-01, 0.13008700E-01, 0.65897000E-01, -.21239400E-01, 0.54005100E-01, 0.13241100E-01, 0.48700700E-01, -.16555200E-02, -.41517300E-01, 0.17523900E-01, 0.29147600E-01, 0.10924000E+00, 0.23114100E-02, -.23648200E-01, 0.24121800E-01, -.23963000E-01, 0.36727300E-01, -.67979600E-02, -.65180900E-01, -.13875200E-01, 0.58061900E-01, 0.17057200E-01, 0.18453400E-01, -.44015800E-01, 0.16271600E-01, 0.22977900E-01, -.69262500E-02, -.32065700E-02, -.38450600E-02, 0.28369500E-02, 0.72781300E-02, -.27741700E-02, 0.17940400E-01, -.19213900E-01, -.92420500E-02, -.28269000E-01, -.11295900E-01, 0.43959200E-02, 0.18218700E+01, -.36601400E-03, -.36689100E-03, 0.47013500E-02, -.76599700E-02, -.87479300E-04, 0.61557700E-02, 0.34797000E+02, -.16196900E+02, -.17908200E+02, 0.10965500E+02, -.65238200E+01, -.70190800E+01, 0.11305600E+02, -.33788400E+02, -.70645000E+01, -.44132300E+01, 0.20608400E+01, 0.22979800E+01, -.59732300E+01, -.50456300E+01, 0.70026800E+01, 0.50161000E+01, 0.44397800E+02, -.13257100E+02, 0.23072600E+03, -.11353400E+03, -.11605900E+03, -.44858000E+02, -.65813800E+02, -.34815300E+02, 0.44681400E+02, 0.22113100E+02, -.61473300E+02, -.42521600E+02, 0.21221300E+02, 0.21833000E+02, -.11112300E+02, -.16206500E+02, 0.27824600E+02, 0.24999400E+02, 0.28100400E+02, -.10075400E+02, 0.48543200E+00, -.24558100E+00, -.22003100E+00, 0.68812000E-01, 0.15978300E+00, -.25961300E+00, -.57403300E+00, 0.14332600E+01, 0.62805700E+00, -.45295600E-01, 0.22090900E-01, 0.21306100E-01, 0.26275500E-01, 0.18493800E-01, -.42081000E-03, -.30869100E-01, -.12576200E+00, 0.23504500E-01, 0.38010800E+00, -.18915300E+00, -.18066200E+00, -.85833800E-01, 0.41046900E-01, -.13553200E+00, -.16507100E+00, 0.14720000E+01, 0.40146800E+00, 0.29843000E+03, -.14599600E+03, -.14962900E+03, -.54506600E+02, -.82740700E+02, -.41750600E+02, 0.79304100E+02, -.44711100E+01, -.90386600E+02, 0.53764400E+02, -.25392800E+02, -.27321700E+02, 0.34092800E+01, -.71293500E+00, -.16809700E+02, 0.11677800E+01, -.70465300E+02, -.89553400E+01, -.28330900E+02, 0.13498200E+02, 0.14182600E+02, -.25678300E+02, -.10494300E+02, 0.20381800E+02, 0.22945500E+02, 0.47984000E+02, -.49640100E+01, 0.61569500E+02, -.31220400E+02, -.30161300E+02, 0.17140900E+01, 0.57036800E+01, -.22014300E+02, -.13152300E+02, -.23902800E+02, -.27084100E+01, 0.24924500E+02, -.12540400E+02, -.12336500E+02, -.16627400E+02, -.51376200E+01, 0.15973200E+01, 0.17528800E+02, 0.43507700E+02, -.39153500E+01, 0.33196700E+02, -.16474700E+02, -.16452400E+02, 0.69183100E+01, 0.10768500E+02, -.18721400E+02, -.14683700E+02, -.19551200E+02, 0.58433200E+00, -.21819000E+02, 0.10377000E+02, 0.11166300E+02, -.56819000E+01, 0.62093300E+01, 0.50143600E+01, -.86190500E+00, 0.57859800E+02, 0.18778600E+02, 0.10620100E+02, -.44821800E+01, -.51712700E+01, 0.13584400E+01, 0.51679700E+01, -.28753200E+01, 0.41537400E+01, 0.79718700E+00, -.95812800E+01, 0.56977500E+01, -.13001600E+01, -.28606000E+01, 0.13663700E+02, 0.54468600E+00, -.48396500E+01, -.61009600E+01, -.54204400E+02, -.10018200E+02, 0.12123000E+03, -.61697900E+02, -.61740500E+02, -.89131200E+01, -.22727400E+02, -.33289200E+02, -.58194300E+01, 0.64248600E+01, -.18918000E+02, 0.13259500E+03, -.67254000E+02, -.65950200E+02, -.33679300E+02, -.43149100E+02, -.15643200E+02, 0.28273100E+02, 0.50708800E+02, -.41715900E+02, 0.58538500E+02, -.28774000E+02, -.29367200E+02, 0.10590800E+02, -.12586300E+02, -.12722900E+02, 0.12443000E+02, -.41920000E+02, -.17551900E+02, -.30548600E+02, 0.15325300E+02, 0.14835500E+02, 0.22635000E+01, 0.74850700E+00, 0.14910700E+02, 0.15003600E+02, -.11002500E+02, -.26683100E+01, 0.56638800E+00, 0.19517200E+01, 0.12722300E+01, 0.17503300E+00, -.39859700E+00, -.84045700E-01, 0.33669000E+02, -.10124900E+02, 0.18634500E+02, 0.92106600E+01, -.41357400E+00, 0.10630400E+00, -.55112200E+00, 0.26415600E+01, -.58701300E+02, 0.72588900E+01, -.24159100E+02, -.19994600E+02, 0.59528500E+01, -.18753200E+02, -.70153200E+00, -.15704100E+01, -.47997100E+01, 0.27039700E+02, -.17469500E+02, -.25483300E+01 },
            { -.95044600E-02, -.82090400E-02, -.10150800E-01, 0.25847200E-01, 0.28591600E-01, 0.40510700E-02, 0.58949700E-02, -.14919600E-02, -.62281800E-02, 0.84888800E-02, 0.10171500E-02, -.17369800E-02, 0.15364600E-01, -.27052100E-02, 0.64836900E-02, -.57369200E-02, 0.13519600E-01, -.21209300E-02, -.13006700E-01, 0.31422800E-03, 0.12542900E-01, -.32155200E-02, 0.18037600E-02, -.99062700E-02, 0.43345300E-02, 0.71019900E-03, -.23217800E-02, 0.20808000E-03, -.15272300E-02, 0.38720800E-02, -.67320400E-03, 0.15729800E-03, 0.13575200E-02, -.79073100E-03, 0.65469600E-03, -.14022600E-01, 0.54696400E-02, -.21830100E-02, -.30715500E-02, 0.12208500E+00, 0.23393200E-02, -.46639200E-02, -.16842900E-02, -.40130200E-02, 0.37615000E-03, 0.17859700E+02, -.88237500E+01, -.91129100E+01, -.15387400E+01, -.24281300E+01, -.46485300E+01, 0.96931400E+00, -.91572300E+01, -.29141800E+01, 0.39077800E+01, -.19629200E+01, -.18738700E+01, -.16253400E+01, -.19102200E+01, -.58389700E+00, -.57639400E+00, 0.64286300E+01, 0.61474400E+00, 0.60479800E+02, -.29969600E+02, -.28721900E+02, -.12732800E+02, -.17772000E+02, -.78692200E+01, 0.11430000E+02, -.39890400E+01, -.20937800E+02, 0.16483100E+02, -.82372700E+01, -.84334300E+01, 0.30153700E+00, -.79729900E+00, -.48922100E+01, -.22854800E+01, -.48071800E+01, -.24033700E+01, 0.12579200E+00, -.63577000E-01, -.87065100E-01, -.95230100E-01, -.10977400E-01, -.76999800E-02, -.18970100E-01, 0.43688000E+00, -.85992000E-01, -.75344200E-02, 0.37339900E-02, 0.36367300E-02, 0.27584100E-02, 0.51265100E-02, 0.13336100E-02, -.36182600E-02, -.26909100E-01, 0.34566300E-02, 0.11821900E+00, -.59063400E-01, -.60915000E-01, -.86802900E-01, -.60130200E-01, -.72967000E-02, 0.19891900E-01, 0.41956600E+00, -.12099400E+00, 0.53114600E+02, -.26104800E+02, -.26184400E+02, -.11516900E+02, -.18526700E+02, -.54878300E+01, 0.13459500E+02, -.10612500E+02, -.18340200E+02, -.83520800E+01, 0.45183800E+01, 0.39983100E+01, 0.34386300E+01, 0.27979400E+01, 0.88593900E+00, -.14343900E+01, -.14995100E+02, 0.43430300E+01, 0.10061400E+02, -.54495300E+01, -.49930000E+01, 0.83270300E+00, -.10031800E+01, -.44582300E+01, -.53898700E+01, -.72352100E+00, -.24898800E+00, -.73465600E+01, 0.36988900E+01, 0.32220400E+01, -.39940300E-01, -.19022100E+00, 0.32037700E+01, 0.16677700E+01, 0.39063200E+01, -.37348500E-01, 0.12961500E+02, -.68621000E+01, -.64083600E+01, -.16235200E+01, -.29346800E+01, -.32462300E+01, -.96406300E+00, 0.52818200E+01, -.36987300E+01, -.87859600E+01, 0.44701900E+01, 0.41516600E+01, -.51304300E+00, 0.12986500E+00, 0.32407700E+01, 0.23083100E+01, 0.30382200E+01, 0.93924700E+00, 0.12468200E+01, -.71198700E+00, 0.52770900E-01, -.14500500E+01, -.89069700E+00, -.75800200E+00, -.64710300E+00, 0.13480900E+02, -.28499400E+01, 0.25184000E+01, -.11247400E+01, -.15360400E+01, 0.67436700E+00, -.16655400E+01, -.59814500E+00, 0.62273000E+00, 0.11948900E+01, 0.23807700E+01, 0.29692200E+01, -.12691200E+01, -.20941400E+01, 0.14313000E+01, 0.83337500E-01, -.31390600E+00, 0.92934500E+00, -.10808000E+02, 0.63876100E+00, 0.72639100E+01, -.37473700E+01, -.80077600E+00, -.84273700E+01, -.76002600E+01, 0.44937700E+01, 0.11829600E+02, 0.10913400E+02, -.89590200E+01, 0.33224600E+02, -.16616500E+02, -.15861400E+02, -.10429500E+02, -.13621100E+02, -.22025200E+01, 0.72935200E+01, 0.76981100E+01, -.12880000E+02, 0.21844700E+02, -.10875700E+02, -.11117600E+02, -.18516900E+01, -.34552400E+01, -.46004300E+01, 0.34155100E+01, -.94940900E+01, -.42118900E+01, 0.49151800E+01, -.24652500E+01, -.28633200E+01, 0.24725700E+01, 0.86802200E+00, -.33218300E+01, -.54907900E+01, -.10077200E+02, 0.22500200E+01, 0.89774900E-01, -.66151800E+00, 0.49198100E+00, 0.31207200E-01, 0.11889200E+01, -.68299500E-01, 0.17388600E+01, -.39116000E+01, -.55957200E+00, -.14006800E+01, -.68339400E-01, 0.17970500E-01, -.13088400E+00, 0.82751500E+01, -.13243400E+02, 0.11122200E+01, 0.12881600E+01, -.19616700E+01, -.49842600E+00, -.33103100E+01, -.34865900E+00, 0.31020200E+01, -.19021300E+01, 0.46099200E+01, -.42509400E+01, -.74983400E+00 },
            { -.27226100E-01, -.22626200E-01, 0.18916500E-02, 0.12632900E-01, 0.65035100E-01, 0.86579200E-02, 0.13200400E-01, -.35264900E-02, -.16426500E-01, 0.12271900E-01, 0.25305000E-02, 0.97863700E-02, 0.71228600E-02, -.11488400E-02, 0.54694700E-02, -.73721600E-02, 0.13742500E-01, 0.23176600E-02, -.18221100E-01, -.37742500E-02, 0.20575900E-01, -.12631100E-02, 0.15681000E-01, -.16567500E-01, 0.31495900E-02, 0.39955000E-02, -.66145700E-02, -.29683900E-02, -.16847800E-02, -.21650000E-02, -.11601700E-01, -.28804500E-02, 0.35211000E-02, -.40142400E-02, -.24857200E-02, -.42746000E-01, 0.37773700E-02, -.14785800E-02, -.20481500E-02, 0.16736800E-02, 0.13606700E+00, -.46132500E-02, -.29387400E-02, -.49005000E-02, 0.11534200E-02, 0.17689200E+02, -.83742600E+01, -.89444500E+01, -.13754000E+01, -.91187000E+00, -.40982400E+01, 0.17921400E+01, -.14364300E+02, -.26267100E+01, 0.52039100E+00, -.31731800E+00, -.25182000E-01, -.15848800E+01, -.24082100E+01, 0.16975400E+01, 0.21740100E+01, 0.17614000E+02, -.10136400E+01, 0.11417200E+03, -.56306900E+02, -.56589400E+02, -.21848200E+02, -.30070800E+02, -.18256700E+02, 0.20706500E+02, -.10459800E+01, -.33569100E+02, 0.19529700E+02, -.97407600E+01, -.97624600E+01, -.35467000E+01, -.28484800E+01, -.46305800E+01, -.78681300E+00, -.61373500E+01, -.47830500E+01, 0.15992100E+00, -.81564700E-01, -.79218800E-01, 0.22918500E-01, 0.62151300E-02, -.98683200E-02, -.90411300E-02, 0.72919200E+00, 0.90957400E-01, -.17320300E-01, 0.84353700E-02, 0.84374700E-02, 0.62550300E-02, 0.69033300E-02, 0.33601500E-02, -.89159700E-02, -.47759400E-01, 0.70637400E-02, 0.16861800E+00, -.83975000E-01, -.76307800E-01, -.38801000E-01, -.61521800E-01, -.24596800E-01, 0.35167200E-01, 0.69057500E+00, -.19821800E-01, 0.12791100E+03, -.62633300E+02, -.63960600E+02, -.20590700E+02, -.37410800E+02, -.18035100E+02, 0.31335100E+02, -.16711500E+02, -.37825000E+02, 0.46994300E+01, -.18073500E+01, -.27143200E+01, 0.58487200E+01, 0.32403500E+01, -.32707000E+01, -.97494700E+00, -.34407200E+02, 0.44321000E+01, 0.17109400E+02, -.86463800E+01, -.84572400E+01, -.18498600E+01, -.35011400E+01, -.73230500E+01, -.82452300E+01, 0.49735700E+01, -.32323600E+00, -.46906900E+01, 0.17088900E+01, 0.24948700E+01, 0.16840400E+01, 0.49913900E+00, 0.17853800E+01, -.72469100E+00, 0.19854100E+01, -.21772900E+00, 0.25261500E+02, -.12696300E+02, -.12446300E+02, -.24880600E+01, -.47623000E+01, -.75451600E+01, -.32020200E+01, 0.11360200E+02, -.46569400E+01, -.81842300E+01, 0.41608400E+01, 0.40573900E+01, 0.19118900E+01, 0.11235500E+01, 0.21191800E+01, 0.58148600E+00, 0.39179500E+01, 0.50276700E+00, -.22450100E+01, 0.93584100E+00, 0.17893500E+01, -.74551500E+00, -.37981600E+00, -.43049000E+00, -.76167800E+00, 0.24733200E+02, 0.62848400E+00, 0.39770500E+01, -.16685300E+01, -.22995900E+01, 0.32927300E+01, -.20434800E+01, 0.16280300E+00, 0.49482800E+01, 0.32913100E+00, 0.11633800E+01, 0.12629600E+01, -.19817000E-02, -.10282700E+01, 0.11090200E+01, 0.17851300E+01, -.27693900E+00, -.63075300E+00, -.20550900E+02, -.14018800E+01, 0.32070800E+02, -.16492000E+02, -.14698800E+02, -.84566300E+01, -.12856500E+02, -.25038200E+01, 0.10237000E+02, 0.11853400E+02, -.12538800E+02, 0.71881000E+02, -.36264800E+02, -.34591500E+02, -.15149800E+02, -.24817500E+02, -.83523900E+01, 0.15035100E+02, 0.14690500E+02, -.22424700E+02, 0.30447200E+02, -.15019000E+02, -.15263500E+02, -.22319200E+01, -.37371400E+01, -.67241100E+01, 0.35408000E+01, -.19175600E+02, -.71582000E+01, -.36666000E+01, 0.18625000E+01, 0.16131100E+01, 0.26572600E+01, 0.14658300E+01, 0.33895700E+00, -.44193400E+01, -.10378800E+02, 0.17762100E+01, 0.22348000E+00, -.69541600E+00, 0.72860300E+00, 0.59844900E-01, 0.12577000E+01, -.69725000E-01, 0.50469000E+01, -.74871300E+01, 0.43334800E+01, -.30071000E+01, -.76760900E-01, 0.34831100E-01, -.20665400E+00, 0.98038100E+01, -.25697400E+02, 0.34786900E+01, -.14837900E+02, -.70015400E+01, -.38389000E+01, -.73563200E+01, -.26236500E+01, 0.17280400E+01, -.26070000E+01, 0.10643800E+02, -.72962600E+01, -.11581600E+01 },
            { -.48845900E-01, 0.12277100E-01, 0.24361700E-01, -.92780400E-02, 0.37796400E-01, 0.67489100E-02, 0.13099400E-01, 0.94421300E-02, -.16019000E-01, 0.11550000E-01, 0.92305100E-02, 0.15271800E-01, -.22134300E-02, -.12150400E-02, -.32485900E-02, -.22887100E-02, 0.14562500E-01, -.18914500E-01, -.16834200E-02, 0.10026800E-01, 0.94576800E-02, 0.18382000E-01, -.22600700E-01, 0.49406200E-01, 0.69278600E-02, 0.51797900E-02, 0.78574700E-02, 0.79644800E-02, 0.44337000E-02, -.69746500E-02, -.17684500E-03, 0.19313600E-02, 0.68723200E-02, 0.37591400E-03, -.61564600E-02, -.14303000E-01, 0.87364200E-03, -.29680700E-03, -.48009600E-03, -.29158000E-01, -.19239200E-01, 0.60546000E+00, -.24480900E-02, 0.81725700E-03, 0.56663400E-03, -.12762500E+01, 0.83730300E+00, 0.57112500E+00, -.67646400E+01, -.22548000E+01, 0.44892500E+01, 0.70309800E+01, -.39158500E+00, -.26696300E+01, -.62424500E+00, 0.27926800E+00, 0.10593300E+01, 0.30344300E+01, -.14788700E+01, 0.22716900E+01, 0.41101500E+01, 0.25042400E+02, -.14396700E+01, 0.13744100E+03, -.68232100E+02, -.71477900E+02, -.24566500E+02, -.38045700E+02, -.21298200E+02, 0.30443800E+02, 0.18511300E+02, -.40073900E+02, 0.45454300E+02, -.22651800E+02, -.21699700E+02, -.13000800E+02, -.92422900E+01, -.10618300E+02, 0.52364900E+00, -.88400100E+01, -.11445800E+02, 0.15133300E+00, -.75670600E-01, 0.32791600E-02, 0.24672500E-01, 0.66557100E-01, -.17424000E-01, -.91960200E-01, 0.79414600E+00, 0.21342800E+00, -.25457500E-01, 0.12588100E-01, 0.10481500E-01, 0.49573000E-02, 0.11424900E-01, 0.17846800E-02, -.16558500E-01, -.71406300E-01, 0.12617500E-01, 0.17625500E+00, -.87352400E-01, -.46174700E-01, 0.93661200E-02, -.59030600E-01, 0.70186700E-02, 0.70681100E-01, 0.95008700E+00, 0.39508500E-01, 0.22063600E+03, -.10948100E+03, -.11198800E+03, -.32052400E+02, -.59440400E+02, -.35484100E+02, 0.51241900E+02, -.61393500E+01, -.62231800E+02, 0.49212600E+02, -.24297500E+02, -.25889200E+02, -.55098400E+00, -.30911900E+01, -.14770400E+02, -.87508600E+00, -.51103800E+02, -.30692100E+01, 0.64788900E+02, -.32347900E+02, -.32128100E+02, 0.28797800E+01, -.10370900E+02, -.23557900E+02, -.12304000E+02, 0.38592300E+01, -.34577500E+01, 0.17867200E+01, -.11449200E+01, 0.92855100E+00, -.14044100E+00, 0.27569000E+00, -.59449500E+00, -.14581900E+01, 0.60682800E+00, -.16077500E+01, 0.58624900E+02, -.29178200E+02, -.28795400E+02, -.41705100E-01, -.12268200E+02, -.16740300E+02, -.13423400E+01, 0.20650800E+02, -.97048000E+01, -.30263900E+02, 0.15079300E+02, 0.16131100E+02, 0.77827200E+01, 0.58311500E+01, 0.74016800E+01, -.35027900E+00, 0.77945000E+01, 0.48906500E+01, -.10069600E+02, 0.49638400E+01, 0.61708500E+01, 0.27021400E+01, -.21327100E+00, 0.33344800E+01, 0.20124500E+01, 0.37505100E+02, 0.29701000E+01, 0.67828200E+01, -.32158800E+01, -.36045800E+01, 0.55946100E+01, 0.69198500E+00, -.15063900E+01, 0.16465600E+01, -.74860800E+01, 0.17483300E+01, 0.38878600E+01, -.16302300E+01, -.18400900E+01, -.16437400E+01, 0.45400500E+00, -.14397600E+01, -.32448700E+01, -.31646700E+02, -.37565600E+01, 0.47537300E+02, -.24009000E+02, -.27140400E+02, -.34771900E+01, -.15261500E+02, -.86421900E+01, 0.83542800E+01, 0.15816700E+02, -.14100000E+02, 0.11491100E+03, -.57552900E+02, -.54715600E+02, -.18901000E+02, -.34637700E+02, -.17000100E+02, 0.25838400E+02, 0.30149700E+02, -.33536200E+02, 0.27796400E+02, -.13782200E+02, -.13523300E+02, -.11014400E+02, -.71793800E+01, -.34870100E+01, 0.60315000E+01, -.13620800E+02, -.10843000E+02, 0.12524600E+01, -.60004600E+00, -.10135200E+01, -.29732200E+01, -.38255700E+00, 0.13396800E+01, 0.12163400E+01, -.78637500E+01, -.19052900E+01, 0.33055400E+00, -.14820200E+01, 0.32864100E+00, 0.84532100E-01, 0.46485200E+00, -.48385300E-01, -.59131100E+01, -.10957800E+02, 0.12855900E+02, -.58069700E+01, -.72318800E-01, 0.49275500E-01, -.23396600E+00, 0.11111600E+01, -.43139500E+02, 0.11998100E+02, -.13329000E+02, -.24681900E+02, -.10691100E+02, -.10664900E+02, -.35689900E+01, 0.26572600E+01, -.25395900E+01, 0.21256700E+02, 0.64895600E+00, -.95727500E+00 },
            { 0.93035800E-02, -.74448600E-03, 0.12849700E-02, -.28135400E-01, -.44408500E-01, -.76225400E-03, -.42176300E-02, 0.12587000E-01, 0.15016200E-01, -.79827900E-02, -.11581700E-01, -.46275100E-02, -.11476000E-02, 0.26908100E-02, 0.76377300E-02, 0.26804100E-02, -.13796400E-01, -.64081200E-02, 0.14074600E-01, -.61374500E-02, -.13934900E-01, -.22068600E-02, -.14793700E-01, -.17856700E-01, 0.27820200E-02, 0.19881600E-02, 0.13564200E-01, 0.24401900E-02, 0.15066200E-02, 0.40285000E-02, 0.15097700E-01, -.49777300E-02, -.94558000E-03, -.53350000E-02, -.25204900E-02, 0.22208800E-01, -.63725500E-02, 0.24463000E-02, 0.36239700E-02, -.26643300E-01, -.27693400E-01, 0.12735500E-01, 0.65814100E+00, 0.77897400E-02, -.10371200E-02, -.76144900E+01, 0.33518600E+01, 0.37336000E+01, 0.16791500E+01, 0.10057300E+00, 0.80296500E+00, -.81307200E+00, 0.10516300E+02, 0.13322600E+01, -.53295700E+01, 0.27198100E+01, 0.22238700E+01, -.55276900E+00, 0.26548700E+01, -.15073900E+00, -.25044500E+01, -.18119500E+02, -.73851700E-01, -.11333600E+03, 0.55843600E+02, 0.56877600E+02, 0.20191300E+02, 0.27901600E+02, 0.20346800E+02, -.20052600E+02, -.36753800E+00, 0.32806800E+02, -.29752200E+02, 0.14817400E+02, 0.14694100E+02, 0.34355200E+01, 0.18400900E+01, 0.98709000E+01, 0.95019900E+01, 0.14363800E+02, 0.50479500E+01, -.93501700E-01, 0.48562100E-01, 0.25717000E-01, 0.26721200E-01, -.14070400E-01, -.12996200E+00, -.26060700E+00, -.89139700E+00, -.10660200E+00, 0.13002100E-01, -.62901700E-02, -.57683100E-02, -.46803400E-02, -.68755500E-02, -.42546900E-02, 0.50231200E-02, 0.46263300E-01, -.65538100E-02, -.17159500E+00, 0.85290900E-01, 0.66085400E-01, 0.61782800E-01, 0.83804700E-01, -.34017300E-01, -.16376300E+00, -.78834100E+00, 0.45075900E-01, -.13476700E+03, 0.65976100E+02, 0.67914000E+02, 0.18535800E+02, 0.37687700E+02, 0.19580900E+02, -.37722900E+02, 0.15960600E+02, 0.36565400E+02, -.16644400E+02, 0.77221100E+01, 0.90961600E+01, -.67948600E+01, -.27473000E+01, 0.62123400E+01, -.20068800E+01, 0.38635200E+02, -.58760600E+01, -.43958400E+02, 0.22022100E+02, 0.21787800E+02, -.29668500E+01, 0.50572000E+01, 0.20083400E+02, 0.20696800E+02, 0.44797400E+01, 0.10227400E+01, 0.10633800E+02, -.46590300E+01, -.57078900E+01, -.10590900E+01, -.10312700E+01, -.42617500E+01, -.18843900E+01, -.47889600E+01, -.42291300E+00, -.39805100E+02, 0.19845700E+02, 0.19552800E+02, 0.59466500E-01, 0.58674600E+01, 0.14666800E+02, 0.10072200E+02, -.68393300E+01, 0.60507400E+01, 0.13324000E+02, -.66866600E+01, -.70978000E+01, -.22219600E+01, -.59458300E+00, -.48370300E+01, -.50662000E+01, -.90492200E+01, -.55243200E+00, 0.11784700E+01, -.43739700E+00, -.16229600E+01, 0.15797400E+01, 0.17044500E+01, -.37774600E+00, -.16038000E+01, -.27821200E+02, 0.15616200E+01, -.58295700E+01, 0.25491200E+01, 0.32984100E+01, -.54944700E+01, 0.28313200E+01, -.12142400E+01, -.10293800E+02, -.13009800E+01, -.37182900E+01, -.38305900E+01, 0.12610200E+01, 0.22139400E+01, -.77834500E+00, -.61706600E+00, 0.14659300E+01, 0.30361200E+01, 0.21653400E+02, 0.22540700E+01, -.22392800E+02, 0.11710100E+02, 0.10816700E+02, 0.78799900E+01, 0.11899000E+02, -.70070600E+00, -.13865300E+02, -.16472000E+02, 0.11156300E+02, -.78709700E+02, 0.39696300E+02, 0.37580200E+02, 0.14784400E+02, 0.23844400E+02, 0.94135000E+01, -.19513100E+02, -.15498900E+02, 0.21287000E+02, -.22521900E+02, 0.11057400E+02, 0.11127500E+02, 0.37934500E+01, 0.34876100E+01, 0.41601400E+01, -.18056700E+01, 0.17398900E+02, 0.66149100E+01, 0.63008700E+01, -.31880500E+01, -.29163100E+01, -.24097700E+01, -.17821800E+01, -.15058500E+01, 0.54073700E+01, 0.74639700E+01, -.19883900E+01, -.15794900E+00, -.48161400E-01, -.65046600E+00, -.52875800E-01, -.19665200E+01, 0.93062500E-01, -.25507500E+01, 0.82034000E+01, -.58168200E+01, 0.29000500E+01, -.12238500E-01, -.30995000E-01, 0.19945300E+00, -.60145600E+01, 0.22613600E+02, -.11244600E+01, 0.57558400E+01, 0.40263100E+01, 0.47290700E+01, 0.75362400E+01, 0.63327600E+01, -.30689500E+01, 0.32266300E+01, -.16239700E+02, 0.57429800E+01, 0.23161800E-02 },
            { -.25209500E-01, 0.15018000E-01, 0.76637700E-02, -.93572300E-02, -.81975800E-03, -.15948500E-02, 0.57007800E-02, 0.91526900E-03, 0.19477200E-03, 0.21619200E-02, 0.93116100E-02, 0.17722500E-01, -.52156000E-02, -.28747800E-02, 0.59861200E-02, -.35484600E-02, 0.11830400E-01, -.62762400E-02, 0.23307100E-02, 0.81256200E-02, 0.12394000E-01, 0.27115100E-02, -.55792200E-02, 0.95662900E-02, 0.26929300E-02, 0.49918100E-02, 0.19803800E-02, -.25475500E-02, 0.46706200E-02, -.51248600E-02, -.38629500E-02, -.28167100E-02, 0.97029600E-02, 0.59326500E-02, 0.15769700E-03, 0.28150400E-01, -.54527500E-03, 0.22893900E-03, 0.33902600E-03, -.10938600E-01, -.15750000E-01, 0.33273000E-03, 0.17068700E-02, 0.47208100E+00, -.73989300E-03, 0.89813200E+01, -.43587900E+01, -.46407000E+01, -.36604200E+01, -.15528100E+01, -.10647200E+01, 0.28520000E+01, -.45924100E+01, -.26954100E+01, 0.15502000E+01, -.78194600E+00, -.46538800E+00, 0.59558900E+00, -.87869900E+00, 0.28956300E+00, 0.96750700E+00, 0.12856000E+02, -.14967700E+00, 0.76358100E+02, -.37995400E+02, -.39757100E+02, -.13817500E+02, -.21408600E+02, -.11424700E+02, 0.18150300E+02, 0.87815900E+01, -.23340000E+02, 0.22422800E+02, -.11155000E+02, -.10638400E+02, -.60907800E+01, -.43858200E+01, -.58272800E+01, -.99830400E+00, -.67877400E+01, -.60477600E+01, 0.78981000E-01, -.39340400E-01, 0.79987800E-02, -.28221800E-01, 0.24431900E-01, 0.30434900E-02, 0.12597200E-01, 0.44903000E+00, 0.35187900E-01, -.13516500E-01, 0.66777200E-02, 0.59925700E-02, 0.25824100E-02, 0.58353300E-02, 0.11737300E-02, -.67817700E-02, -.37906400E-01, 0.56674500E-02, 0.95639500E-01, -.47487500E-01, -.28039800E-01, -.13038300E-01, -.27692000E-01, 0.68397000E-02, 0.68745100E-01, 0.51550800E+00, -.21733000E-01, 0.11751000E+03, -.58459600E+02, -.59374600E+02, -.18919000E+02, -.30808200E+02, -.19309200E+02, 0.25141300E+02, -.73772100E+01, -.32638800E+02, 0.16983500E+02, -.84778100E+01, -.89552100E+01, -.64311100E+00, 0.63847600E+00, -.59868700E+01, -.12009100E+01, -.28532000E+02, 0.63607700E+00, 0.28143400E+02, -.13912000E+02, -.13967900E+02, 0.16124600E+01, -.60375400E+01, -.96487200E+01, -.42361100E+01, 0.44478300E+01, -.25221600E+01, 0.64005000E+01, -.30866500E+01, -.19739400E+01, -.20096600E+00, 0.16382700E+01, -.26587900E+01, -.24996000E+01, -.32460000E+01, 0.65439700E-01, 0.31396700E+02, -.15357500E+02, -.15492900E+02, -.16272900E-03, -.63390000E+01, -.84025900E+01, 0.45273600E+00, 0.11308900E+02, -.56531300E+01, -.14271500E+02, 0.70292900E+01, 0.76158000E+01, 0.36820300E+01, 0.27560600E+01, 0.38030700E+01, 0.60415500E+00, 0.56356900E+01, 0.31171900E+01, -.34875900E+01, 0.17331600E+01, 0.20973700E+01, 0.17904800E+01, -.25890200E+00, 0.12754500E+01, 0.14430200E+01, 0.19910000E+02, 0.30761200E+00, 0.32830000E+01, -.15983900E+01, -.16859900E+01, 0.13332100E+01, 0.97731200E+00, -.92915700E+00, 0.10969000E+01, -.38555300E+01, 0.23418900E+01, 0.26518200E+01, -.12311000E+01, -.11769000E+01, -.93938500E+00, 0.68927300E+00, -.10425300E+01, 0.41016700E-01, -.16347100E+02, -.83205900E+00, 0.19421200E+02, -.97949700E+01, -.12186500E+02, -.35228200E+01, -.76602200E+01, -.13661600E+01, 0.64877100E+01, 0.10860000E+02, -.78805200E+01, 0.57270600E+02, -.28730700E+02, -.27168000E+02, -.11393400E+02, -.18552600E+02, -.76320300E+01, 0.12093600E+02, 0.14814100E+02, -.17815900E+02, 0.21933700E+02, -.10894300E+02, -.10824100E+02, -.57125400E+01, -.40608400E+01, -.43082200E+01, 0.34974100E+01, -.10869800E+02, -.62917600E+01, 0.36791700E+01, -.18198500E+01, -.18878300E+01, -.50347300E+00, 0.22296500E+00, -.14022500E+01, -.24068700E+01, -.73150400E+01, 0.33013600E-01, 0.17548700E+00, -.13505800E+01, 0.11353800E+00, 0.43234600E-01, 0.33828700E+00, -.29780900E-01, -.19684900E+01, -.66136000E+01, 0.61582700E+01, -.28522300E+01, -.13761300E-01, 0.24973000E-01, -.10275400E+00, 0.32445700E+01, -.25227900E+02, 0.74320100E+01, -.54514000E+01, -.14870300E+02, -.53768300E+01, -.52673500E+01, -.18431100E+01, 0.20314200E+01, -.12533600E+01, 0.89861900E+01, -.17287600E+01, -.12157300E+01 },
            { -.32109400E-01, -.10515100E-01, 0.44195800E-02, 0.15233200E-01, 0.61726300E-01, 0.58184200E-02, 0.18658400E-01, -.38120300E-02, -.42103400E-01, 0.10593700E-01, 0.12038500E-01, 0.26223900E-02, 0.66304500E-02, 0.78308300E-03, 0.42043300E-02, -.71056800E-02, 0.16536200E-01, -.47729100E-02, -.20605100E-01, 0.57851000E-02, 0.27987900E-01, 0.25827500E-02, -.31489800E-02, 0.21875500E-01, 0.50652100E-02, -.10574400E-02, -.56742800E-02, 0.53067500E-02, -.19079800E-02, 0.74042200E-03, -.13566900E-01, 0.30381900E-02, 0.25726700E-02, 0.46503200E-04, -.11639800E-02, -.50150600E-01, 0.11787900E-01, -.46103800E-02, -.70612100E-02, 0.14984400E-01, 0.29878900E-01, -.19406900E-01, -.11025600E-01, -.24822100E-01, 0.30836000E+00, 0.14376100E+02, -.68431500E+01, -.70734000E+01, -.34306000E+01, 0.55723000E+00, -.28151700E+01, 0.49570500E+00, -.14262600E+02, -.11285600E+01, 0.14590700E+01, -.77169400E+00, -.58268700E+00, -.91043700E+00, -.22990600E+01, 0.17073300E+01, 0.23081800E+01, 0.18323600E+02, -.59885300E+00, 0.14311800E+03, -.70873000E+02, -.70744700E+02, -.27608600E+02, -.36699400E+02, -.24518900E+02, 0.21603900E+02, -.13076600E+02, -.41023000E+02, 0.52799900E+02, -.26354000E+02, -.26565600E+02, -.23098500E+01, -.56894100E+00, -.18373700E+02, -.11114600E+02, -.21812500E+02, -.53252800E+01, 0.16931700E+00, -.85115800E-01, -.72686400E-01, 0.17421300E-01, -.86023300E-02, 0.31920800E-01, 0.38704100E-03, 0.94305800E+00, 0.12158100E+00, -.21021500E-01, 0.10311500E-01, 0.11145900E-01, 0.73167500E-02, 0.98067000E-02, 0.53872100E-02, -.11196000E-01, -.52142100E-01, 0.98901000E-02, 0.21343700E+00, -.10579100E+00, -.98858200E-01, -.55306400E-01, -.13122500E+00, -.13989200E-01, 0.43247800E-01, 0.85444300E+00, -.60946700E-01, 0.13536800E+03, -.66590500E+02, -.67177300E+02, -.20391900E+02, -.42565900E+02, -.18571600E+02, 0.33840500E+02, -.30590000E+02, -.41155600E+02, -.12377000E+02, 0.65341200E+01, 0.56893500E+01, 0.12448800E+02, 0.92234600E+01, -.13887900E+01, -.51549000E+01, -.42331300E+02, 0.12081300E+02, 0.25364200E+02, -.12538300E+02, -.12540700E+02, -.49774100E+00, -.32573300E+01, -.13577900E+02, -.18132100E+02, -.35346600E+01, 0.42317500E+01, -.23482500E+02, 0.10758300E+02, 0.12175400E+02, 0.14430100E+01, -.12913900E+01, 0.89256600E+01, 0.24822300E+01, 0.97478400E+01, -.11923300E+01, 0.34113200E+02, -.17088300E+02, -.16771100E+02, -.23422100E+01, -.70926800E+01, -.12046500E+02, -.87577700E+01, 0.68201800E+01, -.48960500E+01, -.26369700E+02, 0.13252100E+02, 0.13647400E+02, -.32270000E+00, -.15540200E+01, 0.10610900E+02, 0.77243900E+01, 0.14809700E+02, -.15266900E+01, -.16486300E+01, 0.69315300E+00, 0.12064700E+01, -.10406300E+01, -.33183000E+01, -.63521200E+00, -.11117300E+01, 0.30311400E+02, -.13648000E+01, 0.70187600E+01, -.32707900E+01, -.37797700E+01, 0.65239700E+01, -.48832700E+01, 0.33667100E+00, 0.74347900E+01, 0.21886900E+01, 0.40092200E+00, -.25815400E+01, 0.17882100E+01, 0.12711500E+01, 0.20151900E+01, 0.43623600E+01, 0.29098700E+00, -.38489300E+01, -.23398600E+02, -.20241000E-02, 0.40351000E+02, -.20550000E+02, -.19970400E+02, -.97745100E+01, -.17007700E+02, -.34875000E+01, 0.11621100E+02, 0.97467800E+01, -.17400400E+02, 0.95078400E+02, -.47717700E+02, -.46703900E+02, -.19107600E+02, -.32572800E+02, -.11742200E+02, 0.18392300E+02, 0.10539900E+02, -.29778200E+02, 0.34561000E+02, -.17110900E+02, -.17252700E+02, -.49907600E+01, -.28613000E+01, -.77663000E+01, 0.14180000E+01, -.21871400E+02, -.76725700E+01, -.80545300E+01, 0.40550200E+01, 0.44754600E+01, 0.32076200E+01, 0.27587900E+01, 0.12598100E+01, -.74174800E+01, -.10963500E+02, 0.36186100E+01, 0.26548400E+00, -.22560700E+01, 0.13893800E+01, 0.67696500E-01, 0.23036700E+01, -.11447200E+00, 0.40044700E+01, -.94913100E+01, 0.13991500E+01, -.76871100E+01, -.90312000E-01, 0.37438100E-01, -.28205300E+00, 0.18012500E+02, -.26754200E+02, 0.13713500E+01, -.16393300E+02, -.29158900E+01, -.84010200E+01, -.96443800E+01, -.33875800E+01, 0.27731700E+01, -.12979100E+01, 0.96347500E+01, -.99921700E+01, -.74667800E+00 },
            { -.75106900E+00, -.17113800E+01, -.28252000E+00, 0.31739900E+00, 0.91284900E+00, 0.51388000E-01, 0.29628700E+00, -.22600400E+00, -.38117900E-01, 0.50849100E-01, -.87454300E+00, -.49573000E+00, -.35613300E+00, 0.60317500E+00, 0.70640700E+00, -.22599100E+00, -.35368400E+00, 0.74300800E+00, -.96156600E+00, -.51454800E+00, 0.59345400E+00, 0.86981400E+00, -.64584000E-01, -.86718000E+00, -.18038900E+00, -.41494400E-01, -.30129500E+00, -.36711200E+00, -.14958800E+00, -.29652700E-01, -.25189600E+00, -.29152200E+00, 0.67177900E+00, -.13141800E+00, -.73471100E-01, -.13216300E+01, 0.89324500E-01, -.33803300E-01, -.53011300E-01, -.13862300E+01, 0.24753300E+00, 0.97234300E-01, 0.42303200E+00, -.48791300E+00, -.63730600E-01, 0.26843100E+04, -.13369800E+04, -.13346000E+04, -.18183100E+03, -.33691900E+03, -.66270500E+03, 0.42573900E+03, -.16578900E+04, -.59523800E+03, -.61788000E+03, 0.30964400E+03, 0.30898200E+03, -.37491800E+03, -.13248400E+03, 0.35353600E+03, 0.27075700E+03, 0.19764900E+04, -.31831300E+03, 0.93081600E+04, -.46568400E+04, -.46403200E+04, -.13795700E+04, -.23944100E+04, -.15566700E+04, 0.18300100E+04, 0.35925600E+03, -.24330100E+04, 0.14341700E+04, -.71554300E+03, -.72798200E+03, -.23661700E+03, -.37476900E+03, -.14580600E+03, 0.44755200E+03, -.33976700E+03, -.53096800E+03, 0.19554000E+02, -.95936000E+01, -.10529300E+02, 0.49820800E+01, -.15868900E+01, -.10893900E+02, -.19002800E+02, 0.54170700E+02, 0.15324000E+02, -.15365000E+01, 0.76276900E+00, 0.77156800E+00, 0.37940400E+00, 0.48503400E+00, 0.21057100E+00, -.65651600E+00, -.41432900E+01, 0.71225100E+00, 0.17370100E+02, -.86007000E+01, -.88530500E+01, 0.17170400E+01, -.33263500E+01, -.70305800E+01, -.79249200E+01, 0.54600300E+02, 0.67801900E+01, 0.11512100E+05, -.57688600E+04, -.57539300E+04, -.19169800E+04, -.31522600E+04, -.18155300E+04, 0.24124500E+04, -.87713300E+03, -.33392700E+04, 0.13237900E+04, -.69691500E+03, -.65902600E+03, -.28679100E+03, -.44344500E+03, -.16536400E+03, 0.32999600E+03, -.22194000E+04, -.58626700E+03, -.77101900E+03, 0.44198700E+03, 0.38498800E+03, -.54271100E+03, -.11891200E+03, 0.75008800E+03, 0.13225200E+04, 0.22057500E+04, -.39564300E+03, -.25578400E+03, 0.10979300E+03, 0.10466500E+03, 0.37149700E+02, -.32672800E+02, 0.98704500E+02, -.10210800E+03, 0.12386300E+03, 0.10859500E+03, 0.29434500E+03, -.92162300E+02, -.14788200E+03, -.38239100E+03, -.29938000E+03, 0.28648500E+03, 0.82478400E+03, 0.21608600E+04, -.34923700E+03, -.13679700E+04, 0.67335100E+03, 0.66235200E+03, 0.75769000E+02, 0.26787600E+03, 0.30397200E+03, -.43699100E+02, 0.41499900E+03, 0.33121900E+03, -.24467000E+03, 0.12907200E+03, 0.11429400E+03, 0.19023900E+03, 0.12550600E+03, -.71634400E+02, -.25259000E+03, 0.19920100E+04, 0.44544800E+03, 0.64613300E+01, -.13884000E+02, -.60839100E+01, -.26158600E+03, -.65879900E+02, 0.66561900E+02, 0.41527900E+02, 0.50083600E+02, -.43302100E+03, -.12435400E+03, 0.48540400E+02, 0.58770900E+02, -.20434800E+02, 0.18314300E+03, 0.37365200E+02, 0.24216500E+03, -.17856500E+04, -.24992500E+03, 0.34766100E+04, -.17287000E+04, -.16837300E+04, -.33005900E+03, -.93621300E+03, -.78044700E+03, 0.17081900E+03, 0.46136500E+03, -.59084600E+03, 0.48581500E+04, -.24291900E+04, -.24333800E+04, -.10132400E+04, -.17680000E+04, -.60561000E+03, 0.84749300E+03, 0.14913900E+04, -.15084000E+04, 0.36158200E+04, -.18027800E+04, -.18058200E+04, -.19635000E+03, -.46430800E+03, -.83836900E+03, 0.66998400E+03, -.21023900E+04, -.84116300E+03, -.46230400E+03, 0.23273700E+03, 0.22955900E+03, -.11298300E+03, 0.42996600E+02, 0.28698100E+03, 0.32698400E+03, -.55921800E+03, -.10415900E+03, 0.20358400E+02, -.10013900E+03, -.82427000E+01, 0.48503900E+01, 0.22717600E+02, -.47835400E+01, 0.35066900E+03, -.69030100E+03, 0.63975800E+03, -.24731400E+03, -.15492600E+02, 0.28428900E+01, -.22747100E+02, 0.53278600E+03, -.27151200E+04, 0.12189800E+04, -.18571800E+03, -.17103300E+04, -.11425700E+03, -.74310300E+03, 0.22443400E+03, -.22121400E+03, -.25955700E+03, 0.67478700E+03, -.39485500E+03, -.12090800E+03 },
            { -.51739500E-01, 0.14063000E+00, 0.32351000E+00, -.15406700E+01, -.35329700E+01, -.15088100E+00, 0.53219300E-01, 0.27800100E+00, 0.16052300E+00, -.41473800E+00, 0.17811700E+00, 0.26569800E+01, -.29834400E+00, -.62371100E+00, 0.26881500E+00, 0.93148200E-01, -.77663700E+00, -.26753200E+00, 0.38788600E+00, -.13870200E+00, -.31710000E+00, -.67339900E+00, -.11875200E+01, -.17202000E+01, 0.25452500E+00, 0.17715200E+00, 0.84215400E+00, 0.22285800E+00, 0.14906700E+00, 0.12366200E+00, 0.62813700E+00, 0.39546900E-01, -.25378100E+00, -.10019200E+01, -.13587200E+00, 0.49122500E-02, 0.22871400E+00, -.87033200E-01, -.13586400E+00, 0.63550700E+00, 0.27886600E+01, -.45696500E+00, -.69760400E+00, -.88138400E+00, 0.53114800E+00, -.17173800E+00, -.34553800E+02, -.11550300E+02, 0.30965200E+03, -.76870200E+02, -.43797800E+02, 0.15947900E+02, -.16677000E+03, -.92619700E+02, -.43724100E+03, 0.22371300E+03, 0.23959400E+03, -.20183100E+03, -.54596700E+02, 0.19335200E+03, 0.55433500E+02, -.25078900E+02, -.21498400E+03, 0.21163500E+03, -.16381400E+03, -.17561700E+03, 0.11394500E+03, 0.12744300E+02, -.81137700E+02, -.54646800E+03, -.13639500E+04, 0.18701700E+03, -.12700500E+04, 0.63382300E+03, 0.66885100E+03, 0.17903000E+03, 0.17186400E+03, 0.41934100E+03, 0.15154900E+03, 0.22386700E+03, 0.13842400E+03, 0.68923500E+01, -.31278200E+01, -.25189600E+01, 0.15251900E+01, 0.25810500E+01, -.90158000E+01, -.10606200E+02, -.63455700E+01, 0.12190700E+02, 0.21908100E+00, -.94964200E-01, -.23904900E+00, 0.13353500E+00, -.66125000E-02, -.74031700E-01, 0.18205800E-01, 0.66832300E+00, 0.87204500E-01, 0.30890800E+01, -.14696800E+01, -.55523300E+00, 0.11900800E+01, 0.10060000E+01, -.54470400E+01, -.76958600E+01, -.89806600E+01, 0.82377600E+01, -.30225000E+04, 0.14013000E+04, 0.14328200E+04, 0.16195300E+03, 0.57440700E+03, 0.64180400E+03, -.55691900E+03, -.98973200E+03, 0.61781000E+03, -.23532200E+04, 0.11111000E+04, 0.11414600E+04, 0.38025500E+02, 0.38037700E+03, 0.56377300E+03, -.16712600E+03, 0.48472700E+03, 0.23196600E+03, -.28061700E+04, 0.14414600E+04, 0.14074700E+04, -.40567100E+03, 0.22870700E+03, 0.12610500E+04, 0.10432800E+04, 0.76930100E+03, 0.90524800E+02, 0.11979600E+04, -.55243000E+03, -.59964000E+03, -.77945300E+02, 0.24594400E+02, -.37295100E+03, 0.27989000E+02, -.37937000E+03, 0.21100300E+02, -.12188800E+04, 0.65278500E+03, 0.61833900E+03, -.15247600E+03, 0.21362200E+03, 0.56342100E+03, 0.53579800E+03, 0.16220400E+02, 0.22869700E+03, 0.83701900E+03, -.43229300E+03, -.41003200E+03, -.21680500E+03, -.15601800E+03, -.19351300E+03, 0.94117600E+02, -.96943500E+02, -.15846800E+03, 0.25877800E+03, -.10741500E+03, -.74841400E+02, -.31123300E+02, 0.48536400E+02, -.13804100E+03, -.11827800E+03, -.30641200E+03, 0.25279100E+03, -.38064300E+03, 0.16068500E+03, 0.18645700E+03, -.35730200E+03, -.70627200E+02, 0.11977400E+03, 0.45340800E+02, 0.27199800E+03, -.46081600E+03, -.58333500E+03, 0.23266900E+03, 0.27273700E+03, 0.18502300E+03, -.44530700E+02, 0.13581100E+03, -.17254200E+03, 0.38262500E+03, -.16098100E+03, 0.68018200E+03, -.29946300E+03, -.34046100E+03, 0.51792600E+02, -.13456100E+02, -.36103100E+03, -.33455500E+03, -.81523100E+03, 0.29689300E+03, -.60884700E+02, 0.58466300E+02, 0.83268700E+02, -.13318300E+03, 0.16815800E+03, -.25401300E+02, 0.21855100E+02, -.91369700E+03, 0.18196000E+03, -.51452200E+03, 0.24434500E+03, 0.26216500E+03, 0.38981600E+03, 0.54439500E+02, 0.79625900E+02, 0.27852300E+02, 0.33213900E+01, 0.43235400E+02, -.41729700E+03, 0.20766800E+03, 0.15145800E+03, -.29984900E+02, -.38611000E+02, 0.25328300E+03, 0.44432800E+03, 0.25316200E+03, -.14819300E+03, -.36438800E+01, 0.12819200E+03, 0.22447900E+02, -.50638700E+00, -.74802600E+01, -.30397900E+01, 0.47846200E+03, 0.24896400E+03, -.43111900E+03, 0.57007000E+02, -.91115400E+01, -.29826100E+00, -.58136200E+01, 0.67688000E+03, 0.13189800E+03, 0.23842100E+03, 0.79918600E+03, -.62455300E+02, 0.20586100E+03, -.50190800E+02, 0.30085700E+03, -.25304300E+03, -.39203600E+02, -.29575200E+03, 0.36599600E+02, 0.48281100E+02 },
            { 0.26444900E+00, 0.49163200E-01, 0.11078300E+00, -.32548100E+00, -.41714900E+00, -.31427600E-01, -.45838600E-01, 0.41063400E-02, 0.13640800E+00, -.25869200E-02, 0.17302400E+00, -.78800000E-01, 0.16870100E-02, -.26359800E+00, 0.10849700E+00, -.53088900E-01, 0.83932500E-01, -.99625200E-01, 0.27775800E+00, -.11757600E-01, -.22103900E+00, -.58927400E-01, -.77457600E-01, 0.28651300E+00, 0.12512000E-01, -.19931900E-01, 0.27968200E-01, -.48484600E-01, 0.49935000E-01, 0.73033200E-01, 0.67046200E-01, -.13130200E+00, 0.11092600E+00, 0.39823300E-01, 0.66169400E-01, 0.15114200E+00, -.15444700E+00, 0.59971700E-01, 0.92622100E-01, -.43680100E+00, -.65278600E+00, 0.22447300E+00, 0.13397700E+00, 0.25808800E+00, -.12505700E+00, 0.30094700E-01, 0.89893400E-01, -.14366600E+02, 0.23250800E+02, -.28464000E+00, 0.19339800E+02, 0.10116800E+03, 0.79771000E+02, -.33612300E+01, 0.15310900E+03, -.76349200E+02, -.81674000E+02, 0.36576400E+02, 0.70984300E+01, -.59038100E+02, -.57812000E+02, -.38645500E+02, 0.20173100E+02, -.57973400E+03, 0.29005300E+03, 0.29247500E+03, 0.18385800E+02, 0.21666700E+02, 0.17104000E+03, 0.75328500E+02, 0.45845300E+03, 0.35750800E+02, 0.20707500E+02, -.10507900E+02, -.38294000E+01, -.82185100E+02, -.11998500E+03, 0.52053400E+02, 0.10045600E+03, 0.11038700E+03, -.71062300E+02, -.28424700E+01, 0.14113500E+01, 0.14751300E+01, 0.28218000E+01, -.20896500E+01, 0.43578200E+01, 0.74094700E+01, 0.49880500E+01, -.63403400E+01, -.10405200E+00, 0.51973200E-01, 0.56158200E-01, 0.41915200E-01, 0.14473600E-01, 0.63983900E-02, 0.54426600E-01, -.14461500E+00, -.24429000E-01, -.13760600E+01, 0.67891100E+00, 0.51169300E+00, 0.86249900E+00, -.26469400E+00, 0.23494600E+01, 0.34292900E+01, 0.39571600E+01, -.27476300E+01, -.11964500E+03, 0.61458000E+02, 0.70779300E+02, -.21444000E+02, -.72829500E+02, 0.10991200E+03, 0.21288500E+03, 0.63294800E+03, -.53287000E+02, 0.59107500E+03, -.29195200E+03, -.28666500E+03, -.13285300E+03, -.20244300E+03, -.56661800E+02, 0.24507900E+03, 0.18358200E+03, -.19692900E+03, 0.22498600E+03, -.11738900E+03, -.11504300E+03, 0.37209400E+01, -.73556100E+02, -.72181200E+02, -.31925900E+02, -.61021900E+01, -.47686800E+02, 0.84120500E+02, -.42237600E+02, -.25409100E+02, -.13334700E+02, -.50175000E+02, -.32133000E+02, -.44870000E+02, -.16721100E+02, -.24473800E+02, -.16571400E+03, 0.75524100E+02, 0.78930700E+02, -.14003200E+02, -.66883300E+02, 0.59392000E+02, -.31719700E+02, 0.15415500E+03, -.21309000E+02, -.15403200E+03, 0.78550600E+02, 0.73009700E+02, 0.48510800E+02, 0.87969500E+02, -.19356000E+02, -.13070500E+03, -.86266800E+02, 0.11005100E+03, -.59942400E+02, 0.28334100E+02, 0.22336300E+02, 0.26420200E+02, 0.15460200E+02, 0.49007200E+02, 0.25087200E+02, 0.61481200E+02, -.43279900E+02, -.50480300E+02, 0.25323300E+02, 0.30115400E+02, 0.14714000E+02, 0.43467800E+02, 0.28219900E+02, 0.51036200E+02, 0.65592800E+02, 0.73212400E+02, 0.40383900E+03, -.20026200E+03, -.20248000E+03, -.14753500E+03, -.48510900E+02, -.14182800E+03, -.52193800E+02, -.18350300E+03, 0.17397100E+02, -.26109400E+03, 0.13027500E+03, 0.11544600E+03, 0.10392800E+02, 0.79231300E+02, 0.83755400E+02, 0.55088500E+02, 0.21116900E+03, 0.41513500E+01, -.46316900E+03, 0.23196700E+03, 0.22981300E+03, 0.16388700E+03, 0.77550700E+02, 0.14434600E+03, 0.78327400E+02, 0.39100900E+03, 0.28414200E+02, 0.99684200E+02, -.50070200E+02, -.56937600E+02, -.59335400E+02, -.69388100E+02, -.81137400E+01, 0.67102900E+02, 0.72744900E+02, -.19260700E+02, 0.38293100E+02, -.19670700E+02, -.20369200E+02, 0.48535400E+02, 0.44887400E+01, -.31688100E+02, -.90873800E+01, -.48589200E+02, 0.43976800E+02, 0.11868700E+01, -.18743600E+02, -.40137900E+01, 0.15540600E+00, -.52582400E+02, 0.12017200E+01, -.25852100E+02, -.18966100E+02, 0.80968700E+02, 0.42214000E+02, 0.46251900E+01, 0.81215600E-01, 0.23844100E+01, -.32834900E+03, 0.14789300E+03, -.87222700E+02, -.11658500E+03, -.51120400E+02, 0.33997500E+02, 0.19557900E+02, -.82599400E+02, 0.12943900E+03, -.28394600E+01, 0.28503800E+03, 0.39903300E+02, -.34633800E+02 },
            { 0.18268200E+00, 0.65463400E-01, 0.15278600E+00, -.72886500E+00, 0.65663400E-01, -.77692500E-01, -.76689800E-01, -.23163900E-01, -.56667800E-01, -.30511800E-01, -.45663700E-01, -.72858700E-01, 0.18345500E+00, -.14837000E-01, 0.43381200E-01, -.43204800E-02, 0.13961700E-01, -.19708000E+00, 0.58625300E+00, -.16602200E-01, -.10579100E+00, -.55050700E+00, -.91332300E-01, -.27353200E+00, -.33026400E-01, -.98320400E-01, 0.53435200E-01, -.15684200E-01, 0.15213800E+00, -.26851800E-01, -.14284900E+00, -.17493500E+00, -.12781200E+00, 0.23539900E+00, 0.15704200E+00, -.49650400E+00, -.16495000E+00, 0.65159900E-01, 0.90867600E-01, -.92262300E+00, -.10194500E+01, 0.26001400E+00, 0.20300000E+00, 0.57746100E+00, -.20341200E-01, -.23930100E+00, 0.60773200E-01, -.11455200E+00, -.23793900E+03, -.11112000E+03, 0.89088800E+02, 0.17910700E+03, 0.17013300E+03, -.11342600E+03, 0.14290500E+03, -.71076400E+02, -.81157200E+02, 0.15302900E+03, 0.70156500E+02, -.55900400E+02, -.16032800E+02, 0.36760600E+03, -.17254500E+02, 0.65233800E+03, -.32857200E+03, -.37735400E+03, -.29260500E+02, -.25264600E+03, -.80467800E+02, 0.61038000E+03, 0.14386900E+04, -.19109400E+03, 0.12886700E+04, -.64164700E+03, -.63688700E+03, -.21897700E+03, -.32867800E+03, -.29533500E+03, 0.86953900E+02, -.18213700E+03, -.29779500E+03, -.50303000E+01, 0.25152500E+01, 0.40186000E+01, 0.13579600E+01, -.45601200E+01, 0.10647000E+02, 0.10709300E+02, 0.15810500E+02, -.45330900E+01, -.29884400E+00, 0.14937600E+00, 0.20415700E+00, -.12676900E+00, 0.12578300E+00, -.41559500E-01, -.99412000E-01, -.12935500E+01, 0.12435300E+00, 0.50366700E+00, -.26316200E+00, -.37901300E+00, 0.25578100E+01, -.26687600E+01, 0.58988300E+01, 0.59189700E+01, 0.18466300E+02, -.19111400E+01, 0.44315200E+04, -.22175100E+04, -.21912800E+04, -.49942000E+03, -.10241200E+04, -.80155000E+03, 0.11132200E+04, 0.11123700E+04, -.11647900E+04, 0.29876300E+04, -.14971500E+04, -.14677600E+04, -.47589400E+03, -.60668400E+03, -.62137100E+03, 0.42188300E+03, -.57217400E+03, -.75020800E+03, 0.66717600E+03, -.32531600E+03, -.33746800E+03, -.11409500E+03, -.34842200E+03, -.19516600E+02, 0.51747200E+03, 0.79939800E+03, -.29041800E+03, -.11210900E+03, 0.58142800E+02, 0.10284300E+03, -.16063900E+02, 0.81954300E+01, 0.20973500E+02, -.67899900E+02, 0.27038100E+02, 0.30708900E+02, 0.22294700E+03, -.10386200E+03, -.12015200E+03, -.79542500E+02, -.30017400E+03, 0.11650500E+03, 0.41845600E+03, 0.10627500E+04, -.21684200E+03, -.12741400E+04, 0.63317500E+03, 0.64899400E+03, 0.16473100E+03, 0.29586400E+03, 0.27014600E+03, -.14660000E+03, 0.16187600E+03, 0.33948000E+03, -.32750100E+03, 0.16412200E+03, 0.11984100E+03, 0.19042000E+03, -.10546500E+02, 0.21175800E+03, 0.96917000E+02, 0.67585400E+03, 0.66844500E+02, 0.25324800E+03, -.12934200E+03, -.11244300E+03, 0.25066500E+02, 0.11383000E+03, -.24639900E+02, -.52613300E+02, -.21187400E+03, -.42235000E+02, 0.75479500E+03, -.37933600E+03, -.34823400E+03, -.25639300E+03, -.59313200E+02, -.30573300E+03, -.18165100E+03, -.82458200E+03, -.11303900E+03, 0.34127800E+03, -.16874400E+03, -.33725400E+03, 0.18682500E+03, 0.13072300E+02, -.14587500E+03, -.44920500E+02, 0.41131100E+03, -.61709000E+02, 0.10528200E+04, -.52618100E+03, -.53742200E+03, -.17024200E+01, -.34393100E+03, -.74732300E+02, 0.51072500E+03, 0.11592700E+04, -.39993100E+03, 0.55382500E+03, -.27655400E+03, -.27439700E+03, -.38519400E+03, -.24711800E+03, -.69611500E+02, 0.96402800E+02, -.12140800E+03, -.24729600E+03, 0.27886800E+02, -.13946300E+02, 0.19877400E+02, -.15216600E+03, -.59405700E+02, 0.81719200E+02, 0.23628300E+03, 0.63353900E+02, -.51628700E+02, 0.42377400E+01, -.14887700E+02, -.47385100E+02, 0.10717700E+01, -.40518800E+02, 0.67886200E+00, -.41762100E+03, -.14821600E+03, 0.57886300E+03, -.68885500E+02, 0.72420500E+01, 0.66771000E+00, -.17605100E+00, -.77051600E+03, -.69926500E+03, 0.33893600E+03, -.53290900E+02, -.91867800E+03, -.11456500E+03, -.17518000E+03, -.63286200E+02, 0.16565400E+03, 0.41945000E+01, 0.76996200E+03, 0.21467500E+03, 0.31766700E+02 },
            { -.92630200E+00, 0.12600100E+00, 0.34169800E-01, -.11612000E+00, -.35561500E+00, -.52122000E-02, 0.31159200E-01, 0.28331300E-01, 0.25474100E-01, -.12770900E+00, -.29786300E+00, -.29940700E+00, -.24809600E+00, 0.12603200E+00, -.31923400E+00, 0.24137100E-01, 0.28381300E+00, 0.30589300E+00, 0.43120100E-01, -.31870300E+00, 0.15279700E+00, -.81517800E+00, -.34342700E-01, -.10432500E-01, 0.66476400E-01, -.10405100E+00, -.12460400E+00, 0.19375800E+00, 0.20054100E+00, 0.30455000E+00, 0.27577600E+00, 0.70229900E-01, 0.12735800E+00, 0.46083600E-01, 0.19424700E+00, 0.90844300E+00, 0.23217400E+00, -.90480100E-01, -.13751600E+00, 0.65363800E+00, 0.31163800E+01, -.73100700E+00, -.10203900E+01, -.11251400E+01, 0.11125100E+01, 0.62111900E+00, -.22544100E+00, 0.11294200E+01, -.11096400E+01, -.27960000E+03, 0.13033500E+03, -.24092500E+02, -.70827100E+02, -.23947200E+03, -.16223400E+03, 0.80273200E+02, 0.79700900E+02, 0.24267300E+03, -.33398700E+02, 0.16819100E+03, 0.33377100E+03, 0.10488100E+04, -.19115700E+03, 0.56592300E+04, -.28173600E+04, -.28698900E+04, -.96839900E+03, -.15200500E+04, -.97042800E+03, 0.10008400E+04, 0.91743000E+03, -.15024600E+04, 0.61073500E+03, -.30317100E+03, -.28766900E+03, -.23234600E+03, -.31353500E+03, -.77365400E+02, -.92373100E+02, 0.77136000E+02, -.26961100E+03, 0.16074600E+01, -.82311700E+00, 0.17363800E+01, 0.30667400E+01, 0.91867400E+01, 0.62938800E+01, 0.62305000E+01, 0.33162600E+02, 0.28995400E+02, -.73399400E+00, 0.36787200E+00, 0.38972300E+00, 0.35988900E+00, 0.71784500E+00, -.17919100E+00, -.98041600E+00, -.35489500E+01, 0.90019300E+00, 0.66366700E+01, -.33069500E+01, -.29134900E+01, 0.16668500E+01, -.13372100E+01, 0.34177900E+01, 0.83673600E+01, 0.38920600E+02, 0.11875800E+02, 0.94468000E+04, -.47011300E+04, -.46901500E+04, -.14278200E+04, -.26764600E+04, -.13085200E+04, 0.25217800E+04, 0.23648400E+03, -.27071500E+04, 0.27381500E+04, -.13506300E+04, -.13626300E+04, 0.11362800E+03, -.15304900E+03, -.79506500E+03, 0.10599400E+03, -.22768400E+04, -.17944800E+03, 0.25647400E+04, -.13021800E+04, -.12827900E+04, -.29995100E+02, -.25164900E+03, -.97432300E+03, -.62197700E+03, 0.22534500E+03, -.18626600E+03, 0.48362800E+03, -.22285100E+03, -.18914300E+03, -.62028600E+02, -.45628200E+01, -.49634900E+02, 0.20404600E+03, 0.57952700E+02, -.94534100E+02, 0.20862000E+04, -.10521200E+04, -.10468900E+04, -.21779700E+03, -.44144300E+03, -.53091000E+03, 0.11560500E+03, 0.10775700E+04, -.41918900E+03, -.39162100E+03, 0.19423700E+03, 0.23873500E+03, 0.19046200E+03, 0.23666800E+03, 0.69102600E+02, 0.21030200E+02, -.29653300E+02, 0.63769100E+02, -.76323800E+03, 0.38008300E+03, 0.37163900E+03, -.27972500E+01, 0.59758100E+02, 0.29433400E+03, 0.26037500E+03, 0.16519700E+04, 0.41730200E+03, 0.46934400E+03, -.22699200E+03, -.22275400E+03, 0.28128300E+03, -.45346800E+02, 0.10343600E+03, 0.51365700E+03, -.18866000E+03, -.19598100E+03, 0.13041000E+03, -.58866500E+02, -.44535400E+02, 0.37036600E+03, -.54470600E+02, -.24016100E+03, -.54294100E+03, -.16465000E+04, -.42986400E+03, 0.23901500E+04, -.11986600E+04, -.13939900E+04, -.10429100E+03, -.68806700E+03, -.55311700E+03, 0.61556100E+02, 0.41096500E+03, -.45501900E+03, 0.52045000E+04, -.25988200E+04, -.25723300E+04, -.10232900E+04, -.14296600E+04, -.60753000E+03, 0.13986800E+04, 0.14739900E+04, -.13205900E+04, 0.87321400E+03, -.43520800E+03, -.43274000E+03, -.10790100E+03, -.39289900E+03, -.13528800E+03, -.14312800E+03, -.61115900E+03, -.58203600E+03, -.67003400E+03, 0.33497000E+03, 0.35435700E+03, -.17091000E+03, -.82463000E+02, 0.47044800E+03, 0.46253000E+03, 0.20265600E+03, -.26179100E+03, 0.84229700E+01, 0.15772800E+03, 0.14630900E+02, 0.44066000E+01, 0.23896400E+02, -.80464100E+01, 0.28200800E+03, -.18864100E+03, 0.64497600E+03, 0.12298500E+03, 0.40393600E+00, 0.27135300E+01, -.93292000E+01, -.19301700E+03, -.16051600E+04, 0.29966600E+03, 0.44118200E+03, -.60945100E+03, -.52825300E+02, -.49606100E+03, -.28789500E+03, 0.30263800E+02, -.97372000E+02, 0.12893200E+04, -.29074600E+02, 0.69060700E+02 },
            { -.45190600E+00, -.28871200E-01, 0.16283200E+00, 0.18714600E+00, 0.31941800E+00, -.15150700E+00, -.65483800E-02, -.25374600E+00, -.39598000E+00, 0.16379500E+00, -.39393000E-01, 0.37116600E+00, -.24421200E+00, 0.74592100E-01, -.62918600E+00, -.35911600E-01, 0.21331800E+00, -.29400200E+00, 0.73535300E+00, -.14500300E+00, -.17497300E+00, -.34016700E+00, 0.79594100E-02, -.15826200E+00, -.98111900E-01, -.12452200E+00, -.10667000E+00, 0.19883100E-01, 0.89295300E-01, 0.16822100E+00, -.39415800E+00, -.99371000E-01, 0.59253400E-01, -.21851000E+00, 0.83073000E-01, -.84744800E+00, 0.11134700E+00, -.42739200E-01, -.67637500E-01, 0.32786800E+00, 0.24823700E+00, -.22006100E+00, -.77912900E-01, -.44503300E+00, 0.24320000E+00, 0.38731900E+00, -.40926400E+00, 0.46601100E+00, -.52457800E+00, 0.32661400E+00, 0.61858500E+02, 0.25702400E+03, -.45995800E+02, 0.10744300E+02, 0.15668500E+03, -.78319200E+02, -.63445100E+02, 0.46965300E+01, -.52702900E+02, -.16982500E+02, -.55776900E+02, 0.21258700E+03, -.67636700E+02, 0.20884800E+04, -.10414700E+04, -.11053900E+04, -.35984100E+03, -.61737900E+03, -.30556100E+03, 0.31859300E+03, -.36653800E+03, -.58063200E+03, 0.56787700E+03, -.28252900E+03, -.25944600E+03, -.12792700E+03, -.58265300E+02, -.14052300E+03, -.37903400E+02, -.30326900E+03, -.94552500E+02, 0.40562300E+01, -.20018000E+01, -.64580300E+00, -.22183300E+00, -.28087300E+01, 0.54896700E+00, 0.44365700E+00, 0.16762700E+02, -.16387300E+01, -.17103500E+00, 0.85026400E-01, 0.76413500E-02, 0.85081000E-01, 0.75657700E-01, 0.52237900E-01, -.12664000E-01, -.56469000E+00, 0.45413600E-01, 0.43676300E+01, -.21627200E+01, -.13495100E+01, -.45305600E+00, -.21393700E+01, -.49433100E+00, -.30906700E+00, 0.14265200E+02, -.77294500E+00, 0.16864400E+04, -.84094500E+03, -.88889500E+03, -.23321500E+03, -.47583600E+03, -.25658500E+03, 0.43134900E+03, -.72374400E+03, -.55120700E+03, -.39800500E+03, 0.19753500E+03, 0.17185400E+03, 0.14934600E+03, 0.22893300E+03, -.11846100E+02, -.15294900E+03, -.62364400E+03, 0.15646100E+03, 0.41945400E+03, -.20625300E+03, -.20561500E+03, -.81650200E+01, -.16411000E+03, -.12965600E+03, -.73121900E+02, -.12301200E+01, 0.24097700E+02, 0.75685100E+02, -.37490200E+02, -.24162000E+02, -.38263700E+02, -.19992100E+02, -.34642500E+02, -.29724200E+02, 0.54152700E+01, -.28170800E+02, 0.76117000E+03, -.37337300E+03, -.37291100E+03, -.19340600E+02, -.14932100E+03, -.21590100E+03, -.48184700E+02, 0.77262500E+02, -.43625800E+02, -.31820400E+03, 0.15597400E+03, 0.17936300E+03, 0.29534900E+02, 0.53676900E+01, 0.94468600E+02, 0.24199600E+02, 0.20639000E+03, -.63129600E+00, 0.46995200E+02, -.22036400E+02, 0.53917700E+01, -.28817800E+01, -.38766200E+02, -.15095200E+01, 0.29488400E+01, 0.51554200E+03, 0.12486400E+02, 0.12366700E+03, -.61384200E+02, -.61633900E+02, 0.66186400E+02, 0.10707900E+02, -.61340900E+02, -.32340200E+02, -.53316600E+01, -.78979200E+02, 0.16171500E+03, -.80851800E+02, -.81931900E+02, -.31812600E+02, 0.17117900E+01, -.71940200E+02, -.15714100E+03, -.30389000E+03, -.17609600E+02, 0.83665800E+03, -.41932600E+03, -.47977800E+03, -.46893600E+02, -.20276000E+03, -.22041500E+03, 0.14194100E+02, -.11006400E+03, -.18383000E+03, 0.14723200E+04, -.73605800E+03, -.69882500E+03, -.26278600E+03, -.47891800E+03, -.18734400E+03, 0.36177100E+03, -.76341000E+01, -.51946000E+03, 0.15908400E+03, -.78810000E+02, -.71119000E+02, -.74787000E+02, -.60370500E+02, -.45810100E+01, 0.14763600E+03, -.16178100E+03, -.42740800E+02, -.18997100E+01, 0.15868100E+01, -.24254700E+02, 0.42514500E+01, 0.32439300E+02, 0.77673800E+01, 0.85041500E+02, -.14394700E+03, 0.74110800E+01, 0.21726800E+01, -.24284000E+02, 0.55609600E+01, 0.59521200E+00, -.16418400E+01, -.80875500E+00, 0.34471100E+02, -.11245500E+03, -.65229800E+02, -.12388600E+03, -.26175900E+01, 0.34116300E+00, -.62760100E+01, 0.34591100E+03, -.44076800E+03, 0.96096700E+02, 0.80357100E+02, -.21171800E+03, -.14177800E+03, -.17100300E+03, 0.23919200E+02, 0.77127000E+02, 0.27416300E+01, 0.13940700E+03, -.50582100E+02, -.23764300E+02 },
            { 0.71474900E+00, -.47021300E-01, 0.10762900E+00, -.33730200E+00, 0.42017900E+00, 0.19765600E+00, -.50518200E-01, 0.15579400E+00, 0.29685000E+00, -.15495900E-01, -.27669000E+00, -.11216000E+01, -.73073000E+00, 0.47805000E+00, 0.38787100E-01, -.54300700E-01, 0.34803200E+00, 0.98376300E+00, -.26601900E+00, -.49377300E-01, 0.14548500E+00, 0.58648100E+00, 0.58843600E+00, 0.78352000E+00, 0.62235000E-01, 0.27848300E+00, 0.11710400E+00, 0.15677000E-02, 0.16779100E-02, -.23679100E+00, 0.53404900E-02, 0.15715000E+00, -.57620700E+00, 0.59193300E-01, -.11309500E+00, -.96208300E+00, 0.93252900E-01, -.34875100E-01, -.58062400E-01, 0.40591700E+00, -.16116900E+00, 0.23624800E-01, 0.18316400E+00, 0.52630900E+00, -.21092100E+00, -.49759000E+00, -.14401200E+00, -.95311500E+00, 0.59766800E+00, 0.37041400E+00, -.66047600E-01, 0.23155500E+03, 0.12754100E+03, 0.74707600E+02, 0.35164700E+03, -.17427000E+03, -.16263300E+03, -.16354700E+03, -.32584500E+02, -.16956200E+03, -.33621200E+03, -.50441600E+03, 0.40920900E+02, -.23505900E+04, 0.11647400E+04, 0.11583300E+04, 0.36135700E+03, 0.51190100E+03, 0.53060300E+03, -.20998100E+03, 0.15647000E+03, 0.52191400E+03, -.29234800E+02, 0.14792900E+02, 0.16418800E+02, 0.60902000E+02, -.74359800E+01, 0.90494800E+02, 0.18732600E+03, 0.16987000E+03, -.18463500E+02, 0.67756800E+00, -.26479500E+00, -.94430700E+00, -.87218800E+01, -.10034100E+02, 0.12748700E+01, -.19307600E+01, -.25183800E+01, -.21296200E+02, 0.41612800E+00, -.20869800E+00, -.25547000E+00, -.19576600E+00, -.27330900E+00, 0.39792600E-01, 0.48200800E+00, 0.92763600E+00, -.41081300E+00, 0.47814400E+00, -.21602000E+00, 0.14103000E+00, -.45844200E+01, -.30361800E+01, 0.52443500E+00, -.47074100E+01, -.58781000E+01, -.98550200E+01, -.27943200E+04, 0.13781600E+04, 0.13439400E+04, 0.33713600E+03, 0.88785600E+03, 0.32784700E+03, -.70153400E+03, 0.28094000E+03, 0.76734200E+03, -.47933300E+03, 0.21869200E+03, 0.21531500E+03, -.17754300E+03, -.80349400E+02, 0.14388100E+03, -.33607700E+02, 0.82058300E+03, -.16808600E+03, -.17978400E+04, 0.92688500E+03, 0.90370100E+03, -.21975500E+03, 0.93646400E+02, 0.88277400E+03, 0.88274300E+03, 0.39637800E+03, -.20657300E+03, 0.96204300E+02, -.55005600E+02, -.61813700E+02, -.90416500E+01, 0.10511700E+03, -.11204200E+03, -.18532000E+03, -.21109900E+03, 0.12375500E+03, -.11765900E+04, 0.61523400E+03, 0.59960600E+03, -.12586200E+03, 0.15165000E+03, 0.52210500E+03, 0.38161000E+03, 0.27579400E+02, -.14403000E+02, -.13896600E+03, 0.64880000E+02, 0.53674500E+02, -.59347700E+02, 0.22562500E+02, -.10247800E+02, -.58160900E+02, -.86112400E+02, 0.15709300E+03, 0.29110400E+03, -.14037800E+03, -.11860100E+03, -.58313900E+02, -.21985600E+02, -.53263200E+02, -.13915100E+03, -.41072600E+03, -.22399900E+03, -.46822700E+02, 0.16758100E+02, 0.99596200E+01, -.17776000E+03, 0.55074200E+02, -.16043600E+03, -.47546600E+03, 0.82697500E+02, 0.38418300E+02, 0.46063300E+03, -.23954100E+03, -.24397700E+03, -.18577800E+03, -.11640100E+03, -.19806900E+01, 0.14288400E+03, 0.42521000E+03, 0.15957900E+03, -.10621100E+04, 0.53592600E+03, 0.62403300E+03, 0.81849300E+02, 0.32359700E+03, 0.22966200E+03, 0.11668100E+03, 0.62773700E+02, 0.23266400E+03, -.22718000E+04, 0.11329300E+04, 0.11576800E+04, 0.30172700E+03, 0.51917500E+03, 0.34673400E+03, -.31269000E+03, -.76563700E+02, 0.41924500E+03, -.70197000E+03, 0.34975400E+03, 0.35463400E+03, 0.17566800E+02, 0.11195500E+02, 0.25492500E+03, 0.33041200E+03, 0.56776800E+03, 0.26870900E+03, 0.28537900E+03, -.14229400E+03, -.16228800E+03, -.30677400E+02, 0.23969800E+02, -.11711300E+03, 0.10507700E+03, -.78764400E+02, 0.90410300E+02, -.48210100E+01, -.13056000E+02, -.30423500E+02, -.15124300E+01, 0.11426200E+02, 0.20711500E+01, -.25395900E+03, 0.15392900E+03, -.12192800E+03, -.25775000E+02, -.15329400E+01, -.85621400E+00, -.97373100E+00, -.17336000E+03, 0.45412800E+03, -.28010400E+03, 0.34398300E+03, 0.22612900E+03, 0.14557900E+03, 0.14257100E+03, 0.23895200E+03, 0.16270000E+03, -.27406500E+02, -.18272200E+03, 0.16747900E+03, 0.27051300E+02 },
            { 0.12145900E+01, 0.35657600E-01, -.34892800E+00, -.15887000E+00, 0.75658800E+00, 0.22890600E+00, -.26233200E+00, 0.94448100E-01, 0.28886100E+00, -.41847500E-02, 0.45449800E+00, -.86731000E+00, -.82798700E+00, 0.31988700E+00, -.28863400E+00, 0.15846000E+00, 0.68146500E-01, 0.11079800E+01, -.40759300E+00, 0.44741100E-01, 0.49122100E+00, -.34342300E+00, 0.60805500E+00, -.42625000E+00, -.21248100E+00, 0.36955600E+00, -.72184900E-01, -.29185400E+00, 0.67431500E-01, -.55758200E-01, 0.17823300E+00, 0.78619600E+00, -.71507500E+00, 0.33785900E+00, 0.37599100E+00, -.11385700E+01, 0.38758300E+00, -.14959000E+00, -.23241000E+00, 0.83845400E+00, 0.12284100E+01, -.46714000E+00, -.21533500E+00, -.67323200E+00, 0.29015700E-01, -.21078700E+00, -.27052400E+00, 0.88438200E-02, -.26558000E+00, 0.18540600E+00, 0.49025500E+00, 0.10265900E+00, -.40196800E+03, 0.72796600E+02, 0.58233200E+03, -.28987800E+03, -.27744000E+03, -.93664200E+02, -.12704300E+03, -.21094200E+03, -.19812300E+03, 0.19344800E+03, 0.34321700E+02, 0.20047200E+04, -.10060100E+04, -.10333700E+04, -.22605300E+03, -.31915800E+03, -.40377600E+03, 0.40214100E+03, -.49593000E+03, -.52918300E+03, 0.92003900E+03, -.45845600E+03, -.45112600E+03, 0.10488300E+03, 0.44895300E+02, -.30064500E+03, -.24648300E+03, -.70026400E+03, -.50676000E+02, 0.10709400E+02, -.52469700E+01, -.51678500E+01, -.97298900E+01, -.36551600E+01, -.61331000E+01, -.10188700E+02, 0.17039600E+02, -.97395000E+01, 0.10998700E+00, -.55502300E-01, -.10650800E+00, -.15660700E+00, -.87781800E-01, 0.12729900E+00, 0.23492200E+00, -.24366600E+00, -.15420400E+00, 0.83122000E+01, -.41053300E+01, -.36136400E+01, -.47677900E+01, -.37091200E+01, -.40129300E+01, -.58138100E+01, 0.12770900E+02, -.83793900E+01, 0.15604200E+04, -.79009500E+03, -.82461900E+03, -.11792100E+03, -.13992600E+03, -.51274500E+03, 0.11059100E+03, -.11684000E+04, -.17272200E+03, -.49004700E+03, 0.22805200E+03, 0.22056200E+03, 0.53887500E+02, 0.11273900E+03, 0.44143700E+02, -.12541600E+03, -.50987000E+03, 0.19765800E+03, -.11284800E+03, 0.82316800E+02, 0.60978600E+02, -.11698000E+03, 0.39070800E+01, 0.19165700E+03, 0.36548900E+03, 0.40466300E+03, -.28267400E+03, -.15257600E+03, 0.72460100E+02, 0.77636100E+02, -.26892000E+02, 0.67261300E+02, 0.55349300E+02, 0.14483100E+02, 0.99121300E+01, 0.62265100E+02, 0.44616800E+02, 0.67175600E+01, -.12117600E+02, -.10025100E+03, -.26565100E+02, 0.10032200E+03, 0.25915200E+03, 0.31046800E+03, -.25539500E+03, -.52895300E+03, 0.25773800E+03, 0.25875100E+03, -.77716500E+02, -.49846900E+02, 0.21826500E+03, 0.28521900E+03, 0.49548600E+03, 0.65423900E+02, 0.47476500E+03, -.23144100E+03, -.21383900E+03, -.83810400E+02, -.13117400E+03, -.17676100E+03, -.14151100E+03, 0.37910300E+03, -.30264100E+03, 0.66353500E+02, -.36899900E+02, -.42107900E+02, -.17926300E+02, -.47393300E+02, -.17475800E+03, -.30203400E+03, 0.17847200E+02, 0.19859300E+03, -.44912900E+03, 0.21636600E+03, 0.21649700E+03, 0.71218600E+02, 0.13445400E+02, 0.30383000E+03, 0.34748500E+03, 0.12633800E+03, 0.16522100E+03, -.44089700E+03, 0.22264700E+03, 0.25456900E+03, -.17852500E+03, -.38810200E+02, 0.29145000E+03, 0.51486400E+03, 0.38746900E+03, -.14835300E+03, 0.76207700E+03, -.38218800E+03, -.34755900E+03, -.20373800E+03, -.15656900E+03, -.26113900E+03, -.10324800E+03, -.33568400E+03, -.15294900E+03, -.39351400E+03, 0.19671200E+03, 0.20194900E+03, 0.45623300E+02, 0.52386500E+02, 0.21220800E+03, 0.27158900E+03, -.31550000E+03, 0.15404700E+03, 0.15943600E+03, -.78418900E+02, -.97504200E+02, 0.37586100E+02, -.17006300E+01, -.79348300E+02, -.12281300E+03, -.18207500E+03, 0.11506800E+03, -.90773200E+00, 0.39274700E+02, -.65485300E+01, -.19524500E+00, 0.69176700E+02, -.20978900E+01, 0.23430900E+02, -.16551300E+03, -.94035900E+01, -.18529400E+03, -.10433100E+02, -.89523900E-01, -.10469300E+02, 0.47196500E+03, -.52375900E+03, -.59711100E+02, 0.39223400E+03, -.49263000E+02, -.79389400E+02, -.12052600E+03, 0.10801200E+03, 0.20931800E+02, -.58056500E+02, -.31841300E+03, -.23700100E+03, 0.91387300E+02 },
            { 0.35224000E+00, -.53153500E-01, 0.17400000E+00, -.12958700E+01, -.24443500E+01, -.94489800E-01, -.26257200E-01, 0.65220200E+00, -.22381300E+00, -.19504200E+00, 0.26506200E+00, 0.24799400E+00, -.32096400E+00, 0.23304700E-01, -.97104700E-01, 0.14652800E+00, -.66626000E+00, -.52821000E+00, 0.15016500E+00, 0.43045500E-01, 0.67866100E+00, 0.20730800E+00, -.10945000E+01, -.18858000E+01, 0.38742500E+00, 0.53951600E+00, 0.82609600E+00, -.13133000E+00, -.88939000E-01, 0.61540400E-01, -.38407800E-02, 0.51508500E-02, 0.38606300E+00, 0.23568800E+00, 0.17169100E+00, 0.23510000E+00, -.13876000E+00, 0.47359000E-01, 0.94249000E-01, -.15850100E+01, -.36762100E+01, 0.60276900E+00, 0.12510000E+01, 0.97877300E+00, -.85762600E+00, 0.66968800E+00, 0.26691900E+00, 0.17318100E+01, 0.16571700E+01, -.14182900E+01, -.18911800E+01, -.14812100E+01, -.88964100E+00, 0.26268200E+03, 0.12325200E+04, -.61468400E+03, -.54566400E+03, -.91110800E+02, -.24810900E+03, -.45310700E+03, -.57580800E+03, -.96316700E+03, 0.25714200E+03, 0.24354200E+04, -.12103300E+04, -.12799700E+04, -.71446100E+03, -.81125700E+03, -.63606400E+02, 0.19726100E+02, -.27115600E+04, -.11352700E+04, 0.11817300E+04, -.58681400E+03, -.54264200E+03, 0.10196100E+03, 0.39660200E+03, -.62567100E+03, -.78324400E+03, -.86321200E+03, 0.30438000E+03, 0.16525000E+02, -.82187400E+01, -.69646100E+01, -.34440500E+02, -.48820700E+00, -.86319700E+01, -.15311300E+02, 0.10327700E+02, -.29242300E+02, 0.10026200E+01, -.49761500E+00, -.79259100E+00, -.16938200E+00, 0.52762700E-01, 0.90876900E-02, 0.20897500E+00, 0.60320400E+00, -.46874900E+00, 0.10251700E+02, -.50758200E+01, -.22136800E+01, -.17918900E+02, -.64451700E+01, -.41272100E+01, -.50201000E+01, 0.71585200E+01, -.23321300E+02, -.24236200E+04, 0.12197700E+04, 0.10457100E+04, 0.84635800E+02, 0.64539300E+03, 0.37295100E+03, -.10179500E+04, -.35226100E+04, 0.46110600E+03, -.52715500E+04, 0.26503800E+04, 0.25049300E+04, 0.11355200E+04, 0.17475900E+04, 0.52024600E+03, -.16459400E+04, -.85786500E+03, 0.18452300E+04, 0.24415500E+04, -.12550900E+04, -.11974100E+04, 0.85908000E+03, 0.10616400E+03, -.12347000E+04, -.15637800E+04, -.22723800E+04, 0.12467700E+03, 0.28945600E+03, -.85773800E+02, -.17764900E+03, -.18532800E+03, 0.20640500E+03, -.96877000E+02, 0.11228600E+03, -.94280400E+02, -.27859400E+02, 0.33278000E+04, -.16609600E+04, -.16187600E+04, 0.23470900E+03, -.89291200E+02, -.11475100E+04, -.62901200E+03, -.18297900E+04, -.40971300E+03, 0.29227800E+03, -.15351200E+03, -.11835700E+03, -.34044000E+02, -.43428100E+03, 0.19432500E+03, 0.57385300E+03, 0.40324000E+03, -.32875000E+03, 0.77346900E+03, -.38372300E+03, -.20255200E+03, -.43390900E+03, -.33130300E+03, -.16759600E+03, 0.16585300E+03, 0.28185800E+03, -.86358400E+03, 0.56475300E+03, -.27197100E+03, -.32665500E+03, 0.26766100E+03, -.52632500E+02, -.58392500E+03, -.84962900E+03, -.24324500E+03, 0.45718600E+03, -.19349400E+03, 0.99555300E+02, 0.24969200E+02, 0.54547700E+03, -.14611300E+03, 0.26719100E+03, -.98431900E+02, 0.59956900E+03, 0.52699500E+03, -.84831600E+03, 0.41907600E+03, 0.60795600E+03, -.72838500E+03, -.41195400E+03, 0.78718400E+03, 0.12251400E+04, 0.14697500E+03, -.72959700E+03, 0.21157700E+04, -.10584500E+04, -.85328500E+03, -.12038100E+04, -.80303800E+03, -.27839100E+03, 0.27080500E+03, -.15898900E+04, -.10953800E+04, -.13602400E+04, 0.67938100E+03, 0.69900700E+03, 0.12790800E+03, 0.96810300E+02, 0.45467300E+03, 0.78563200E+02, 0.59816100E+03, 0.54621600E+03, 0.13838600E+04, -.69005400E+03, -.82040200E+03, 0.17174000E+03, 0.16604100E+03, -.72258000E+03, -.66465000E+03, -.92802300E+03, 0.24573700E+03, -.13104500E+02, -.33690500E+02, 0.70078800E+02, -.11662800E+01, 0.18103900E+03, -.69812900E+01, 0.39765900E+02, 0.54813400E+02, -.11380300E+04, -.34333500E+03, -.16907800E+02, -.60046900E+00, -.12052700E+02, 0.20413200E+04, -.22749100E+03, -.58870600E+03, 0.14830400E+04, 0.11086100E+04, -.40917100E+03, 0.91952000E+02, 0.27566500E+03, 0.62913100E+03, 0.23541900E+02, -.90803800E+03, -.49488500E+03, -.45320600E+02 },
            { -.16555400E+01, 0.10256100E+01, 0.61413900E+00, -.51679700E+00, -.79661400E+00, -.14255900E+00, 0.40785100E+00, -.45933700E-01, 0.16629700E+00, 0.36557800E+00, 0.13944400E+01, 0.18468200E+01, -.95129200E+00, -.27973500E+00, 0.49971400E+00, -.23222500E+00, 0.58951700E+00, 0.73439300E+00, -.12523600E+01, 0.45200400E+00, 0.30415400E+00, 0.11805800E+01, 0.59175800E+00, 0.14603300E+01, 0.16088700E+00, 0.41484000E+00, -.20882800E+00, -.12819400E+00, 0.52426200E-01, -.91963700E-01, 0.33522900E+00, -.74435700E-01, 0.31982700E+00, -.19521900E+00, -.11664600E+00, -.32382700E+00, 0.40827500E+00, -.15233800E+00, -.23766500E+00, 0.15924800E+01, 0.46033200E+01, -.73838300E+00, -.66188400E+00, -.12615800E+01, 0.82033600E+00, 0.58767800E+00, -.46011000E+00, -.10533500E-01, -.31875800E+00, 0.77293500E+00, -.13941400E+01, 0.99316000E+00, 0.53593200E+00, -.24338800E+00, 0.92521200E+03, -.46408200E+03, -.34660600E+03, 0.86198900E+02, -.28650500E+03, -.34643200E+03, -.19462500E+03, -.25967100E+03, 0.34148600E+03, 0.31992000E+04, -.15796600E+04, -.20056200E+04, -.67870000E+03, -.62885000E+03, -.46753700E+03, 0.16899300E+03, -.25568900E+04, -.11527400E+04, -.12663800E+04, 0.63555500E+03, 0.79030500E+03, -.16136900E+03, 0.62285600E+03, 0.46596800E+02, -.78465500E+03, -.80470200E+03, 0.35019300E+03, 0.15379200E+02, -.76742300E+01, 0.10180500E+01, -.22810100E+02, 0.13525000E+02, -.17844600E+02, -.94502000E+01, -.44987800E+01, -.63014200E+01, 0.68022200E+00, -.33833600E+00, -.86422800E+00, -.80505700E-01, -.13135100E+00, 0.91965600E-01, 0.29395400E+00, 0.94949400E+00, -.44696900E+00, 0.56340100E+01, -.27536600E+01, 0.31420900E+01, -.10350300E+02, 0.41888600E+01, -.94900000E+01, 0.82372500E+00, -.45228900E+01, -.10481900E+02, 0.14805200E+02, 0.23383400E+02, -.33853200E+03, -.21253300E+03, 0.42218800E+03, -.26628700E+03, -.71814800E+03, -.41758300E+04, 0.44584900E+03, -.45346200E+04, 0.22936100E+04, 0.20731500E+04, 0.81679300E+03, 0.18173600E+04, 0.44642500E+03, -.15208300E+04, -.16015300E+04, 0.20688400E+04, 0.29648300E+04, -.15202900E+04, -.14497700E+04, 0.88492000E+03, -.58455100E+03, -.15777400E+04, -.19291500E+04, -.18894200E+04, 0.33911300E+03, 0.21452200E+04, -.10181400E+04, -.96764800E+03, -.16146800E+03, 0.35359700E+03, -.77694700E+03, -.84336700E+02, -.86457800E+03, 0.22849700E+02, 0.47227800E+04, -.23550800E+04, -.23004600E+04, 0.65980100E+03, -.72882500E+02, -.18818500E+04, -.95508800E+03, -.21944100E+04, -.59305100E+02, 0.21800400E+04, -.10988200E+04, -.98158200E+03, 0.33872100E+02, -.63422700E+03, -.33151500E+03, 0.58759300E+03, 0.45893800E+03, -.53248000E+03, 0.10426700E+04, -.51727900E+03, -.30298600E+03, -.17733300E+03, -.15206900E+03, -.41753400E+03, 0.17911500E+03, -.24836600E+01, -.63702400E+03, 0.69542000E+03, -.33019100E+03, -.36945600E+03, 0.14019900E+03, 0.15063600E+03, -.51620600E+03, -.22031900E+03, -.72446800E+03, 0.91926100E+03, -.99863400E+03, 0.51038800E+03, 0.47047800E+03, 0.37624800E+03, -.13528100E+03, 0.55183400E+03, 0.44293600E+03, 0.96878800E+03, 0.17650100E+03, -.20109300E+04, 0.98693600E+03, 0.70934400E+03, -.83113400E+03, -.27253000E+03, 0.12970300E+04, 0.16212800E+04, 0.93653200E+03, -.52725900E+03, 0.33403100E+04, -.16736700E+04, -.13360600E+04, -.12036000E+04, -.59268100E+03, -.81534900E+03, 0.12363600E+03, -.21841200E+04, -.62332300E+03, -.41616600E+03, 0.21050300E+03, 0.26756200E+03, -.32447100E+02, 0.15194400E+03, 0.12473200E+03, 0.67382300E+02, -.89747900E+02, 0.15421000E+03, 0.17890400E+04, -.89073500E+03, -.10693800E+04, 0.34150400E+03, -.36301500E+02, -.95680400E+03, -.11054000E+04, -.10422000E+04, 0.19835600E+03, -.90066100E+01, 0.13153400E+03, 0.53551300E+02, -.14338600E+01, 0.20237600E+03, -.43474200E+01, 0.33880800E+02, -.14592800E+03, -.80159700E+03, -.25852900E+03, -.12987500E+02, -.79192600E+00, -.28147900E+01, 0.20558700E+04, -.80756600E+03, 0.43740300E+02, 0.89473500E+03, 0.17392700E+03, -.49334300E+03, 0.15994200E+03, -.12507000E+03, 0.41734100E+02, -.61348900E+02, -.11048100E+04, -.17968700E+03, 0.25377200E+02 },
            { 0.11417000E+01, -.33586600E-01, -.42130100E+00, 0.69933100E+00, 0.10412700E+01, 0.13102900E+00, -.20935800E+00, -.20454600E+00, 0.21820300E+00, 0.55792800E-01, 0.18821300E+00, 0.17003500E+00, -.36015600E+00, 0.66695800E+00, -.90688300E+00, 0.19670900E+00, -.60371100E-01, 0.10414000E+01, -.87766000E-01, -.20966800E+00, -.32812400E+00, -.61740500E+00, 0.47303400E+00, -.98197100E-01, -.20869600E+00, -.47085200E-02, -.54142500E-01, -.46588200E-01, 0.28322700E+00, 0.32445900E+00, 0.11018800E+00, -.10867700E+00, -.37954600E+00, -.29406500E+00, 0.85250700E-02, -.72759700E+00, -.12334300E+00, 0.55588300E-01, 0.65903800E-01, 0.11922200E+00, 0.16994200E+01, 0.44432700E-01, -.19255200E+00, -.75774900E+00, 0.42573200E+00, 0.75893700E+00, -.20116500E-01, 0.52410100E+00, -.41506200E+00, 0.55771300E+00, 0.11693600E+00, -.19388300E+00, 0.31310000E+00, -.74751900E-01, -.29863400E+00, -.24771100E+01, 0.51104300E+02, 0.48530900E+02, -.17587400E+03, -.19997700E+01, 0.14439500E+03, 0.26338200E+03, 0.23039500E+03, 0.76377800E+03, -.36778200E+03, -.61503700E+03, 0.80466100E+01, 0.16121500E+03, -.28061500E+03, 0.42657300E+02, -.74890600E+03, -.13795800E+03, -.19536000E+04, 0.97601400E+03, 0.10585200E+04, -.17440900E+03, 0.41363600E+03, 0.47361100E+03, -.11405600E+03, -.23892600E+02, 0.20558700E+03, 0.84725800E+01, -.42411700E+01, 0.15379700E+00, -.10982800E+02, 0.90183000E+01, -.16620100E+02, -.93792100E+01, -.18570200E+02, 0.43812200E+01, 0.59179500E+00, -.29489900E+00, -.55750400E+00, -.19367400E+00, -.38526700E+00, 0.41662300E-01, 0.28586300E+00, 0.11196600E+01, -.53713600E+00, 0.84880400E+00, -.38819900E+00, 0.23229000E+01, -.42913700E+01, 0.76379000E+01, -.87621800E+01, -.26864300E+01, -.16652500E+02, 0.22061300E+01, 0.62161800E+03, -.28616600E+03, -.48339000E+03, -.34085400E+02, 0.49036700E+03, -.53815500E+03, -.59418700E+03, -.17286200E+04, 0.43666600E+03, -.99291500E+03, 0.51262600E+03, 0.40963000E+03, 0.94663400E+02, 0.46299600E+03, 0.71388900E+02, -.64620700E+03, -.54112600E+03, 0.63403000E+03, 0.27940100E+04, -.14081900E+04, -.13840600E+04, 0.59244100E+03, -.43200300E+03, -.13004500E+04, -.11639300E+04, -.10750700E+04, 0.11565000E+03, 0.11598000E+04, -.57306500E+03, -.51746200E+03, -.98053900E+02, 0.20481700E+03, -.42322300E+03, -.23808800E+02, -.48093000E+03, -.22891900E+02, 0.30563000E+04, -.15230800E+04, -.15025600E+04, 0.54556800E+03, 0.10967900E+03, -.13393400E+04, -.72678500E+03, -.14189900E+04, 0.14331100E+03, 0.17146200E+04, -.86012000E+03, -.81168500E+03, 0.86857300E+02, -.33162200E+03, -.36856100E+03, 0.24637400E+03, 0.11591800E+03, -.35361500E+03, 0.60869900E+03, -.30116400E+03, -.22703200E+03, -.57315800E+02, 0.10726200E+03, -.32567600E+03, 0.29720600E+01, -.45667000E+03, -.12236800E+03, 0.34763400E+03, -.16217000E+03, -.17342500E+03, 0.80190400E+02, 0.19103400E+03, -.34203200E+03, -.29684700E+03, -.75410600E+03, 0.63579900E+03, -.83412400E+03, 0.42526400E+03, 0.41934400E+03, 0.17290600E+03, -.75716100E+02, 0.47777900E+03, 0.53562000E+03, 0.99264000E+03, -.72698300E+01, -.10038900E+04, 0.48842100E+03, 0.30597800E+03, -.31443500E+03, -.78820600E+01, 0.55125000E+03, 0.74795500E+03, 0.51873000E+03, -.78908800E+02, 0.81583300E+03, -.41152100E+03, -.28191800E+03, -.28296600E+03, 0.15803800E+03, -.54366100E+03, -.27940600E+03, -.12796900E+04, 0.24390400E+03, -.39969900E+03, 0.20176800E+03, 0.23134600E+03, 0.38411100E+02, 0.17461100E+03, 0.10800000E+03, 0.90208200E+02, -.16370300E+02, 0.10291500E+03, 0.13858900E+04, -.68952200E+03, -.77042200E+03, 0.11135700E+03, -.99016700E+02, -.64129400E+03, -.64052300E+03, -.61461500E+03, -.17813400E+02, -.67404600E+01, 0.10280200E+03, -.72073500E+01, -.15823400E+01, 0.11960300E+03, 0.18387000E+01, -.84951400E+02, -.18724800E+03, -.86751800E+02, -.53250100E+02, -.93522300E+01, -.79323700E+00, 0.10912500E+01, 0.62328500E+03, -.48298400E+03, 0.24729400E+03, 0.43741700E+03, -.46715600E+02, -.23342000E+03, 0.19442400E+03, -.80903500E+02, -.25110800E+03, -.80784000E+02, -.78832100E+03, 0.78212700E+02, 0.37373700E+02 },
            { 0.96327000E-01, 0.27707200E+00, 0.34233300E-01, -.37567300E+00, 0.44193600E+00, -.51766800E-01, -.11306600E+00, -.14524200E-01, 0.17066500E+00, -.10334600E+00, -.17625800E+00, -.19277100E+00, 0.58660200E-01, 0.14736200E+00, -.63467300E-01, 0.45044700E-01, 0.27320000E-01, 0.13670900E+00, 0.75290000E-01, 0.10721100E+00, -.28782400E+00, 0.45176100E+00, 0.10458100E+00, 0.50642400E+00, 0.33080300E-03, 0.80069600E-02, 0.76368000E-01, 0.63999900E-02, -.19158300E-01, -.80940200E-02, -.31792700E+00, -.16283800E+00, 0.10731700E+00, -.30143800E-01, -.74046200E-01, 0.46877900E+00, -.57007200E-01, 0.23907000E-01, 0.32954800E-01, -.13522800E+00, 0.14563900E+00, 0.55676900E-01, -.12474100E-01, 0.63014200E-02, 0.60680000E-01, -.10204500E+00, -.11311900E+00, -.51501000E-01, -.99778200E-01, -.63937200E-01, 0.44696600E+00, -.28904700E+00, 0.27175500E+00, -.17352200E+00, -.11222200E+00, -.46064300E-01, 0.25460200E+02, -.30625500E+02, -.65590400E+02, -.50273000E+01, -.65637500E+01, -.55507300E+02, 0.75449300E+02, 0.25562500E+03, -.12789600E+03, -.20153400E+03, -.55692900E+02, 0.43251600E+02, -.26620400E+02, -.37372000E+02, -.35378400E+03, -.73936600E+02, -.64926000E+03, 0.32531100E+03, 0.35267200E+03, -.85005600E+02, 0.14971300E+03, 0.17294400E+03, 0.30307800E+02, 0.15300900E+03, 0.81282000E+02, 0.33995700E+01, -.16634000E+01, -.36888300E+00, -.67897100E+01, 0.27211400E+01, -.59780400E+01, -.58483300E+01, -.81106300E+01, 0.70856300E+00, 0.24667300E+00, -.12256000E+00, -.23473000E+00, -.35155100E-01, -.12260300E+00, 0.53343300E-02, 0.28887900E-01, 0.32409200E+00, -.15092000E+00, 0.58504400E+00, -.26648100E+00, 0.90468400E+00, -.28024600E+01, 0.16601200E+01, -.30727200E+01, -.24773300E+01, -.69982000E+01, -.35771400E+00, 0.12654600E+03, -.63793200E+02, -.13734400E+03, -.38402100E+02, 0.15113000E+03, -.13323700E+03, -.26142600E+03, -.68932300E+03, 0.11329100E+03, -.58969400E+03, 0.29391500E+03, 0.25205800E+03, 0.11235300E+03, 0.27693700E+03, 0.81364600E+01, -.37945800E+03, -.24410400E+03, 0.31821400E+03, 0.33665500E+03, -.16910800E+03, -.16103600E+03, 0.14901400E+03, -.95625800E+02, -.19665000E+03, -.28245300E+03, -.27622000E+03, 0.79399900E+01, 0.72592200E+03, -.33893600E+03, -.35078000E+03, -.14025700E+02, 0.15211800E+03, -.28622200E+03, -.85494600E+02, -.34540400E+03, 0.48381200E+02, 0.10267600E+04, -.49586500E+03, -.49917000E+03, 0.19744700E+03, 0.95727000E+02, -.41686000E+03, -.19244700E+03, -.55915800E+03, -.74799200E+00, 0.68621500E+03, -.34929700E+03, -.32989600E+03, 0.52949800E+02, -.12947700E+03, -.16488400E+03, 0.40862400E+02, -.10532600E+03, -.10880500E+03, 0.16426900E+03, -.78567000E+02, -.32341600E+02, -.48466800E+02, 0.26375500E+02, -.95936400E+02, -.93254100E+01, -.19336100E+03, -.68470900E+02, 0.18825600E+03, -.91817900E+02, -.10277300E+03, 0.18222700E+02, 0.37912400E+02, -.16223800E+03, -.18969400E+03, -.27682500E+03, 0.16875600E+03, -.24864600E+03, 0.12200300E+03, 0.11270400E+03, 0.10330400E+03, -.48004600E+02, 0.17550800E+03, 0.13620400E+03, 0.32004400E+03, 0.84219600E+01, -.29772500E+03, 0.14752500E+03, 0.13214800E+03, -.10809000E+03, -.47825800E+02, 0.18449300E+03, 0.29263400E+03, 0.12953000E+03, -.27084600E+02, 0.33870700E+03, -.17218300E+03, -.98217400E+02, -.23116800E+03, -.55133500E+02, -.13884300E+03, 0.47317500E+01, -.39963600E+03, -.98071800E+01, -.29167200E+03, 0.14613600E+03, 0.15748900E+03, 0.44234400E+02, 0.58615100E+02, 0.88029200E+02, 0.41037000E+02, 0.10827100E+03, 0.68143200E+02, 0.37279200E+03, -.18518400E+03, -.22632100E+03, -.13073800E+02, -.24994400E+02, -.16139400E+03, -.12595200E+03, -.17115300E+03, -.26997700E+02, -.26735300E+01, 0.59754200E+02, 0.27429300E+01, -.42165900E+00, 0.70756800E+02, -.74251500E+00, -.20370700E+02, 0.29328400E+02, -.88563500E+02, -.64675400E+02, -.43002700E+01, -.18048200E+00, -.22449000E+00, 0.32528000E+03, -.19201500E+03, 0.26617600E+02, 0.15796800E+03, 0.39596900E+02, -.10181600E+03, 0.81361700E+02, 0.48834500E+02, -.39642000E+02, -.47765400E+02, -.24460000E+03, 0.22503200E+02, 0.25264100E+02 },
            { -.39462800E+01, -.26290900E+00, 0.28111000E+01, -.78288600E+00, 0.17049100E+01, 0.67149100E+00, 0.19447600E+01, -.44962600E-01, -.19116100E+01, 0.44980900E+00, -.15639900E+00, 0.29897300E+01, -.17515000E+01, 0.35536100E+00, 0.12787100E+00, -.56837000E+00, 0.59200800E+00, 0.15296500E+01, -.37665200E+01, -.17158400E+01, 0.23634900E+01, 0.12152800E+01, 0.17804900E+01, -.14082100E+01, -.14587300E+00, 0.12722600E+01, -.81262500E+00, -.13107600E+00, -.56424700E+00, 0.19668600E+01, 0.17705600E+01, 0.12890000E+00, 0.11222700E+01, -.29096800E+01, -.67041400E+00, -.47297600E+01, 0.33531600E+00, -.12431400E+00, -.28662200E+00, 0.34997900E+01, 0.95451400E+01, -.13314300E+01, -.27610700E+01, -.50431800E+01, 0.33307100E+01, 0.23622200E+01, -.43768500E+00, 0.52612000E+01, -.10219600E+02, 0.28175200E+01, -.32823500E+01, 0.26559200E+01, 0.11829400E+01, 0.63375600E-01, -.37425300E+00, 0.18859200E+01, -.79248300E+01, 0.65519500E+03, 0.31653100E+03, -.52694200E+02, -.57043900E+02, -.16943800E+03, -.24512700E+03, 0.25064300E+04, -.12737200E+04, -.21271300E+04, 0.68842800E+02, 0.39162600E+03, -.91205800E+03, 0.96893600E+02, -.15759000E+04, 0.10835300E+04, -.19637200E+04, 0.99894800E+03, 0.12247300E+04, -.94578100E+03, 0.51164200E+03, 0.23602100E+03, -.99825400E+02, -.80621100E+03, 0.53839700E+03, -.23244700E+01, 0.14392900E+01, 0.19269000E+02, -.30195700E+02, 0.19897700E+02, -.12150200E+02, -.46141200E+02, -.60819000E+02, 0.45360100E+02, 0.63922900E+00, -.31069400E+00, -.65673800E+00, -.44326700E-02, -.46893600E+00, -.48781600E+00, -.77268100E+00, 0.13236600E+01, -.15102500E+00, -.51962100E+01, 0.27048100E+01, 0.60975200E+01, 0.27081400E+01, 0.12881300E+02, -.40604800E+01, -.16164500E+02, -.42399900E+02, 0.34885300E+02, 0.80890500E+04, -.40804400E+04, -.42427200E+04, -.11026500E+03, 0.44832800E+03, -.29981900E+04, -.10186300E+04, -.51663500E+04, -.69481800E+03, 0.73486700E+03, -.39261900E+03, -.34341700E+03, 0.20789800E+03, 0.22987300E+04, -.17274300E+04, -.31366600E+04, -.36261300E+04, 0.10253300E+04, -.16050200E+04, 0.79569100E+03, 0.78096900E+03, -.52981000E+03, -.21482700E+04, 0.12197100E+04, 0.18761100E+04, 0.18674800E+04, 0.38353600E+03, 0.79728600E+04, -.37151800E+04, -.36854200E+04, -.33645500E+03, 0.10611300E+04, -.30076800E+04, -.12442800E+04, -.36744100E+04, -.94802200E+02, 0.68446600E+04, -.32516600E+04, -.34637600E+04, 0.10826400E+04, -.12544900E+03, -.20047100E+04, 0.95347900E+03, -.17908900E+04, 0.56539200E+03, 0.23088500E+04, -.12306300E+04, -.99623700E+03, 0.49707300E+03, -.43607500E+03, -.39237700E+03, 0.15652500E+03, 0.56937100E+03, -.90647400E+03, -.42911700E+03, 0.23768000E+03, -.67483700E+01, 0.35032500E+03, -.15420300E+03, 0.39318500E+03, 0.60565100E+03, -.28863300E+02, 0.83439900E+03, 0.26569900E+04, -.13250200E+04, -.11539800E+04, 0.15681900E+03, 0.96857700E+03, -.12589100E+04, -.14950700E+04, -.26787100E+04, -.75102500E+03, -.17500000E+04, 0.84609900E+03, 0.11163100E+04, 0.12702700E+04, 0.50955200E+03, 0.28282000E+02, -.83107100E+03, 0.57908200E+03, -.37982400E+02, 0.43359700E+04, -.21700200E+04, -.38466500E+04, 0.13381800E+04, 0.21673900E+03, -.23472200E+04, -.25121500E+04, -.31392500E+04, 0.25491500E+03, 0.70525600E+04, -.35558900E+04, -.36210200E+04, -.16941900E+04, -.10829300E+04, -.18498100E+04, 0.16581100E+03, -.31052400E+04, -.13831300E+04, -.16610900E+02, 0.14304000E+02, 0.91396400E+02, 0.89287000E+02, 0.21832000E+03, -.43208700E+03, -.93047600E+03, -.86001500E+03, -.78344500E+02, 0.37459200E+03, -.17724800E+03, -.18578100E+03, -.61245400E+03, -.34188700E+03, 0.99442200E+02, 0.82446400E+03, 0.37504900E+03, -.60505500E+03, -.35726300E+01, 0.19183900E+03, -.61338000E+02, -.10882700E+01, 0.17049500E+03, 0.37925800E+01, 0.67569500E+03, 0.29474900E+03, 0.36921600E+03, -.87812100E+03, -.13819600E+02, -.36324200E+00, 0.36377500E+01, 0.16059500E+04, -.28195400E+04, 0.16486400E+04, -.60012500E+02, -.30599300E+04, -.18084000E+04, -.14181700E+03, 0.68086900E+03, -.53264800E+03, 0.73888700E+03, -.21798700E+04, -.66874100E+03, 0.23576500E+03 },
            { -.10158800E+01, -.71421200E+00, -.34622800E-01, 0.40874000E+00, 0.59632400E+00, -.12932300E+00, 0.73522000E+00, -.22555700E+00, -.16185800E+01, -.62643600E-01, -.38796500E+00, -.89180000E+00, -.97560300E-01, 0.60366000E+00, 0.90108500E+00, -.23994500E+00, -.13163600E+00, -.16726300E+00, -.77473300E+00, -.19648600E+00, 0.10065800E+01, -.61386800E+00, -.97467200E+00, 0.29230600E+00, 0.75900300E-01, -.54981500E+00, -.50522700E+00, 0.24910400E+00, -.16724600E+00, 0.55864100E+00, 0.44613000E+00, -.69965000E-01, 0.88175200E+00, -.51070900E-01, -.12575100E-01, 0.40655600E+00, 0.29448600E+00, -.12086400E+00, -.17557700E+00, -.11788200E+01, 0.21367900E+01, -.49636800E+00, -.19914000E+00, -.11042800E+01, 0.93928200E-01, 0.11880600E+01, 0.70971100E+00, 0.14132500E+01, -.14443000E+00, -.10314400E+01, -.11260600E+01, -.17658800E+01, -.96467600E+00, 0.79096400E+00, 0.17624700E+00, -.49370300E+00, -.17005200E+01, -.79569800E-01, -.13877900E+03, 0.31686000E+02, 0.93929800E+02, 0.24723300E+03, 0.92681500E+02, 0.55889200E+03, -.28259500E+03, -.41190200E+03, -.11399400E+03, 0.17232800E+03, -.22684800E+03, 0.81116600E+02, 0.59188300E+03, -.52082300E+02, -.66189200E+03, 0.33236600E+03, 0.36548200E+03, -.30140700E+03, 0.16934100E+03, 0.21544800E+03, 0.40285700E+02, 0.26501000E+03, -.12396300E+03, -.59264400E+00, 0.39274800E+00, 0.32540400E+01, -.40794500E+01, -.11649400E+01, -.33873800E+01, 0.97150500E-01, -.19653500E+01, 0.70683000E+01, -.55599000E-01, 0.27439200E-01, -.52332500E-02, 0.87769200E-01, -.21064300E+00, 0.74892700E-01, 0.17891700E-01, -.80053000E-02, -.15386300E+00, 0.21733700E+00, -.49913500E-01, 0.46083300E+00, -.15942400E+01, 0.11155100E+01, -.30914000E+01, -.29133900E+01, -.40544100E+01, 0.30344800E+01, 0.22693300E+04, -.11410900E+04, -.11590600E+04, -.33888400E+03, -.32045400E+03, -.60526000E+03, 0.34522800E+03, 0.95071400E+02, -.32474100E+03, 0.10491100E+04, -.54256000E+03, -.52701900E+03, -.25766700E+03, -.10844200E+03, -.25251000E+03, -.28970000E+02, -.45786900E+03, -.40592700E+02, -.81262800E+03, 0.43817400E+03, 0.40455300E+03, -.24618900E+03, -.44148300E+03, 0.35101900E+03, 0.20797700E+03, 0.62808900E+03, -.17895900E+03, 0.12820700E+04, -.62952800E+03, -.57034500E+03, 0.18045900E+02, 0.22396700E+03, -.47145800E+03, -.12470300E+03, -.60732600E+03, 0.66641900E+02, 0.10035200E+04, -.44848200E+03, -.50307100E+03, 0.28302600E+03, 0.88059900E+02, -.42241300E+03, -.14511800E+03, -.24032300E+03, -.58788700E+01, 0.37309400E+03, -.20130900E+03, -.16323400E+03, 0.93084800E+02, -.12806400E+03, -.49225600E+02, 0.21348200E+03, 0.20019000E+02, -.47869500E+02, 0.22666900E+03, -.10307000E+03, -.16011100E+03, 0.72231400E+02, 0.14899200E+03, -.21697300E+03, -.26105500E+03, -.25198200E+03, 0.83753000E+02, 0.19231000E+03, -.97197200E+02, -.71000700E+02, -.36401600E+02, -.30077600E+02, -.88977800E+02, 0.33685700E+02, -.34933200E+03, 0.27044900E+03, -.35309900E+03, 0.16753200E+03, 0.22240200E+03, -.27571900E+02, 0.26466400E+02, 0.25788800E+03, 0.22157400E+03, 0.31403900E+03, -.91451000E+02, -.40902500E+03, 0.20276500E+03, -.62802000E+02, 0.31241300E+02, -.26287300E+02, 0.21782000E+03, 0.48502700E+03, 0.57016000E+03, 0.96021000E+02, 0.26400700E+03, -.13897400E+03, -.14435500E+03, -.49480800E+02, 0.48965600E+02, -.23415900E+03, 0.13945200E+03, 0.23146600E+02, 0.29288700E+03, -.56298400E+03, 0.28203600E+03, 0.29530100E+03, 0.26190200E+02, 0.76321900E+02, 0.20351600E+03, 0.14812600E+03, 0.24849600E+03, 0.46298900E+02, 0.49123700E+03, -.24264300E+03, -.22620200E+03, -.35284900E+00, -.13871600E+03, -.19066500E+03, -.15160800E+03, -.25462200E+03, -.61749800E+02, 0.19558500E+01, 0.19725700E+03, -.98504200E+01, 0.10493700E+00, 0.17442200E+03, -.14879300E+01, -.77195800E+02, 0.35491500E+02, 0.41457000E+03, -.21501600E+03, -.14567700E+01, 0.13225400E+00, -.88174400E+00, -.20675700E+03, -.49120100E+03, 0.43934900E+02, -.48030600E+03, -.47727800E+03, -.24415400E+03, 0.26523800E+02, -.44473700E+02, -.16640700E+03, -.11385300E+03, 0.12248500E+03, 0.16551300E+03, 0.17884600E+03 },
            { -.99302100E+00, -.93251100E+00, 0.43510000E-01, 0.40760300E+00, 0.20458300E+01, 0.19130900E+00, 0.37017500E+00, -.17607300E+00, -.32453400E+00, 0.19670300E-01, -.84064400E+00, -.11115500E+01, -.42613300E-01, 0.41222200E+00, -.35647000E+00, -.56503500E-01, 0.30931500E+00, 0.33922100E+00, -.10299500E+01, -.15381500E+00, 0.14037100E+01, 0.33274300E+00, 0.62923000E+00, -.11239500E+00, -.46215300E-01, 0.16347500E+00, -.55859600E+00, -.26722100E+00, -.33169100E+00, -.99632600E-01, -.23541200E+00, 0.23719100E-01, 0.34246200E+00, 0.10156800E+00, -.84001100E-01, 0.66133300E+00, -.72494400E+00, 0.28429900E+00, 0.44832500E+00, -.12762300E+01, -.29747200E+01, 0.10232700E+01, 0.55713000E+00, 0.75077400E+00, -.50306800E+00, 0.64346200E-01, -.43748700E+00, 0.14187300E+01, -.14999700E+01, 0.13873300E+00, -.68149200E+00, 0.11340700E+01, 0.95332100E+00, -.11836500E+01, -.10272500E-01, 0.20177300E+00, 0.18866800E+01, 0.59654900E-01, -.86911700E+00, 0.12898800E+03, 0.49113800E+02, 0.88199800E+02, -.19928600E+03, 0.32032500E+04, -.15992400E+04, -.16118100E+04, -.61043700E+03, -.11743100E+04, -.40044600E+03, 0.11944200E+03, -.95333900E+03, -.87155600E+03, 0.15035700E+04, -.74778500E+03, -.73935500E+03, -.12010200E+03, -.94964700E+02, -.57785500E+03, -.43446100E+03, -.56796300E+03, -.33735100E+02, -.12475600E+01, 0.65032500E+00, 0.20392900E+01, 0.53998900E+00, -.16046900E+01, 0.10283000E+02, 0.76018700E+01, 0.25853900E+02, 0.81154200E+00, -.34829900E+00, 0.17728900E+00, 0.16791900E+00, 0.26527800E+00, 0.41298800E+00, -.59532200E-01, -.42082300E+00, -.10587500E+01, 0.19910800E+00, 0.32256900E+01, -.16138100E+01, -.13953400E+01, 0.10696100E+01, -.40931500E+01, 0.48229700E+01, 0.42727100E+01, 0.22753900E+02, 0.19255100E+01, 0.11519000E+04, -.57704700E+03, -.54159600E+03, -.48711900E+03, -.84230200E+03, 0.23496200E+03, 0.84610000E+03, -.75852600E+03, -.10592100E+04, -.14114600E+04, 0.71164000E+03, 0.71681800E+03, 0.21223800E+03, 0.62242500E+03, 0.10546700E+03, -.18081300E+03, -.70043100E+03, 0.20062600E+03, -.15753200E+03, 0.53163800E+02, 0.76506800E+02, -.12120800E+02, -.13249100E+03, 0.20068100E+03, 0.20493900E+03, 0.16212400E+03, 0.27027700E+03, 0.30828700E+03, -.11434600E+03, -.14843500E+03, -.10128900E+03, -.10778000E+03, -.38751600E+02, 0.85579800E+02, 0.10873000E+03, -.16352400E+03, 0.82672600E+03, -.41989100E+03, -.42200900E+03, -.68406900E+02, -.35712800E+03, -.39213900E+02, 0.20914100E+03, 0.32601300E+03, 0.54891600E+01, -.85801600E+03, 0.42194900E+03, 0.44922000E+03, 0.16978900E+02, -.24338000E+02, 0.37854100E+03, 0.19580500E+03, 0.29978600E+03, -.93254900E+02, -.31741300E+03, 0.15881800E+03, 0.16371200E+03, 0.93195400E+02, -.86793000E+02, 0.23408400E+03, 0.23072900E+03, 0.95558900E+03, 0.21683300E+03, -.11989300E+03, 0.61326800E+02, 0.68812500E+02, -.96161900E+02, -.27035800E+02, 0.16480900E+03, 0.23535600E+03, 0.16667700E+03, -.59087700E+03, 0.60521400E+03, -.30240300E+03, -.30335400E+03, 0.10034700E+03, 0.41987100E+02, -.48955800E+03, -.10528900E+04, -.86330900E+03, -.48865500E+02, 0.25791100E+04, -.12888100E+04, -.13941500E+04, -.48317800E+02, -.56975800E+03, -.75727100E+03, -.33599700E+03, -.77691900E+03, -.45387000E+03, 0.33522100E+04, -.16738700E+04, -.16370700E+04, -.69656100E+03, -.11076200E+04, -.22194400E+03, 0.10827500E+04, 0.64921500E+02, -.13452700E+04, 0.47550800E+01, -.19581100E+01, -.19674300E+01, -.30658500E+02, -.10902600E+03, -.11964400E+03, -.44088500E+03, -.68320500E+02, -.58489300E+02, -.11881800E+03, 0.60110200E+02, 0.47739800E+02, 0.63314600E+01, 0.11205900E+03, 0.47945200E+02, 0.15693000E+03, -.23008900E+03, -.92810200E+02, 0.34862400E+01, -.60443500E+02, 0.61871100E+02, 0.16290800E+01, -.15154700E+02, -.37311200E+01, 0.23748500E+03, 0.30151700E+02, -.33650000E+03, -.17631600E+03, 0.23981400E+01, 0.89422200E+00, -.59717200E+01, 0.64763200E+03, -.59962600E+03, 0.56574800E+03, -.46877700E+01, -.79078400E+03, -.35929400E+03, -.31917900E+03, 0.16603800E+03, 0.37380000E+03, 0.94242300E+02, 0.58338400E+03, -.26040500E+03, -.12567500E+03 },
            { -.13760400E+00, -.50039400E-01, -.26694700E-01, 0.97345800E+00, -.16863400E-01, -.22563800E+00, -.40018200E-01, -.47371500E+00, 0.80094500E-01, 0.30193300E+00, 0.37217900E+00, 0.16500600E+01, -.53062600E-01, -.18578100E+00, -.72019200E+00, -.44438300E-01, 0.14387700E+00, 0.37422000E+00, -.25318800E+00, -.44372000E-01, -.14986200E+00, 0.45701300E+00, 0.31954900E+00, -.10256700E+00, -.97768800E-01, 0.19017500E+00, -.27709600E-01, -.22792600E+00, 0.55754900E-01, -.12706300E+00, -.35729900E+00, -.15812900E+00, 0.44442800E+00, -.29601600E+00, -.14397200E+00, -.43373400E+00, 0.97870000E-02, -.15368300E-02, -.22180700E-02, -.26575400E+00, 0.12728900E+01, -.18424500E+00, -.44237700E+00, -.43275600E+00, 0.25991000E+00, 0.62042000E+00, -.35366500E+00, 0.91825700E+00, -.76274800E+00, 0.37145800E+00, 0.77594200E-01, -.40218000E+00, -.17922300E+00, 0.11445600E-01, -.17329200E+00, 0.25311800E+00, 0.13683600E+01, 0.44413300E-01, 0.13116300E+00, 0.72026500E-01, 0.11139000E+03, -.14997000E+02, 0.59509000E+02, -.26103200E+03, 0.13170900E+03, 0.18369500E+03, 0.14371100E+03, 0.11963300E+03, -.28361400E+02, -.10385900E+03, -.41923000E+03, 0.21136800E+02, 0.42781600E+03, -.21562800E+03, -.23165700E+03, 0.21075400E+03, 0.28120400E+02, -.12780200E+03, -.45438900E+02, -.24375700E+03, -.17601500E+02, 0.24790800E+01, -.12681000E+01, -.28662900E+01, 0.42902600E+01, 0.13538000E+01, -.29333900E+01, -.11321300E+01, -.34674400E+01, -.25571500E+00, 0.15237600E+00, -.77669600E-01, -.57001500E-01, -.23602900E+00, -.67639200E-01, 0.44762400E-01, 0.23331600E+00, 0.40018100E+00, -.68189200E-01, 0.51490100E+00, -.27366800E+00, -.55719300E+00, 0.16881700E+01, 0.67483100E-01, -.13318700E+01, 0.27667100E-01, -.28005400E+01, -.24206800E+01, -.14219100E+04, 0.71218600E+03, 0.70827700E+03, 0.25866200E+03, 0.24340700E+03, 0.27654000E+03, -.27801300E+03, -.17284400E+03, 0.38522800E+03, -.71211100E+03, 0.35418100E+03, 0.35350500E+03, 0.16119300E+02, -.60775100E+02, 0.28338100E+03, 0.14271000E+03, 0.34726700E+03, 0.89457000E+02, 0.26767700E+03, -.12458900E+03, -.13210000E+03, 0.42734100E+02, 0.27618600E+03, -.12540500E+03, -.47733000E+02, -.18099600E+03, -.61538600E+02, -.12242000E+04, 0.57301700E+03, 0.58326300E+03, 0.34394400E+02, -.89983500E+02, 0.45290100E+03, 0.22781000E+03, 0.47973300E+03, 0.51772100E+02, -.94413300E+03, 0.45625700E+03, 0.47613800E+03, -.17114200E+03, -.37774100E+02, 0.34674500E+03, 0.15165800E+03, 0.26993700E+03, -.10257500E+03, -.42207100E+03, 0.21983200E+03, 0.19440700E+03, -.11258000E+03, 0.30695500E+02, 0.11881000E+03, 0.58760100E+02, 0.18368000E+03, 0.70157300E+02, 0.26466100E+03, -.13467000E+03, -.11672500E+03, 0.52649000E+01, -.42543800E+02, -.11933000E+03, -.72314800E+02, -.17379300E+03, -.15087300E+03, -.43155200E+03, 0.21359700E+03, 0.20225800E+03, -.14808200E+02, -.11644400E+03, 0.15596100E+03, 0.10236400E+03, 0.24177100E+03, 0.11052500E+03, -.24285400E+03, 0.12334400E+03, 0.10439100E+03, -.15049200E+03, -.55551000E+02, 0.17483200E+03, 0.41675900E+03, 0.31055300E+03, -.20336000E+02, -.86567300E+03, 0.43327400E+03, 0.57176600E+03, -.12690600E+03, 0.80671900E+02, 0.34184100E+03, 0.19971800E+03, 0.13157300E+03, 0.66424700E+02, -.64342500E+03, 0.32513500E+03, 0.31359500E+03, 0.27025200E+03, 0.28418700E+03, 0.54351500E+02, -.34544800E+03, -.34839500E+03, 0.32501100E+03, 0.22140300E+02, -.11746600E+02, -.16955000E+02, -.52163200E+01, 0.54994500E+02, 0.51379100E+02, 0.19456300E+03, -.20354900E+00, 0.22477700E+02, 0.10782900E+03, -.54935300E+02, -.55799800E+02, 0.94982500E+02, -.23180800E+02, -.61021100E+02, -.12118800E+03, 0.89215600E+01, 0.62266200E+02, -.22179400E+01, -.16396200E+02, -.12259600E+02, -.82710100E+00, -.66106400E+02, 0.15706200E+01, -.11750400E+03, -.41741600E+02, -.17348000E+03, 0.46252300E+02, -.11404100E+01, -.52175400E+00, 0.34751700E+00, 0.14229200E+03, 0.26046600E+03, -.17254600E+03, 0.33447300E+03, 0.31299500E+03, 0.18966800E+03, 0.46129800E+02, -.67636400E+02, -.16980700E+03, -.31113600E+02, -.24961700E+03, 0.14142100E+03, -.94184900E+01 },
            { -.96619900E+00, -.10358000E+00, 0.16073700E+00, 0.37168000E+00, 0.58185200E+00, -.46312400E-01, 0.36284800E+00, -.58638300E-01, -.14327900E+01, -.59461400E-01, -.43358600E+00, -.48731700E+00, -.83206400E-01, 0.82944300E+00, -.13344700E+00, 0.67866000E-01, -.62643500E-01, 0.56784000E+00, -.10245500E+01, 0.15172400E+00, 0.26422400E+00, 0.68508700E+00, -.60093900E-03, 0.15167500E+00, 0.14709000E+00, 0.32820200E-02, -.21757300E+00, -.20448200E-01, -.18994900E+00, -.18274400E+00, -.15881500E+00, -.31400500E+00, 0.54957300E+00, 0.42342200E+00, -.53013300E-01, -.17675200E+01, -.44367700E+00, 0.17588100E+00, 0.26396500E+00, -.72036300E+00, -.23253200E+01, 0.88967600E+00, 0.10431800E+01, 0.96230900E+00, -.63922400E+00, 0.54484500E+00, 0.28056400E+00, -.21611600E+00, 0.13332400E+01, -.25009500E+00, -.21286000E+00, -.24424200E+00, -.40295800E+00, -.11872500E+00, 0.43422700E+00, 0.83981600E-01, -.14809200E+01, -.19366200E+00, 0.48355300E-01, -.49569700E+00, -.14171500E+01, -.40430300E+03, 0.10061600E+03, 0.11138900E+03, -.57813100E+02, -.71452100E+02, -.98551100E+01, -.44886500E+02, 0.41646200E+02, -.19511200E+03, -.13372600E+04, -.76063700E+02, -.12837300E+03, 0.67747200E+02, 0.68659400E+02, -.15080200E+03, 0.11415500E+03, -.10868800E+02, 0.69844300E+01, -.75381700E+02, 0.26907100E+02, 0.79217900E+01, -.39576300E+01, -.39420500E+01, -.17270500E+02, 0.58489500E+01, -.97235900E+01, -.17971800E+02, -.18593900E+02, 0.26043800E+01, 0.66382600E+00, -.32696300E+00, -.34817400E+00, -.25705800E+00, -.21116800E+00, -.57764400E-01, 0.16876700E+00, 0.10179200E+01, -.32492700E+00, 0.19718700E+01, -.98452300E+00, -.10025500E+01, -.52490100E+01, 0.30537200E+01, -.39022700E+01, -.71677200E+01, -.14502600E+02, 0.11838300E+01, -.14116600E+04, 0.70236000E+03, 0.70043200E+03, 0.21967300E+03, 0.70928900E+03, 0.64987900E+02, -.89614100E+03, -.17295000E+04, 0.54611700E+03, -.21823900E+04, 0.11012500E+04, 0.10972100E+04, 0.28194700E+03, 0.90903400E+03, 0.13069600E+03, -.95503800E+03, -.26182700E+03, 0.86358400E+03, 0.16417300E+04, -.85157300E+03, -.82245300E+03, 0.73766400E+03, -.10572100E+03, -.76834300E+03, -.77790000E+03, -.11581400E+04, 0.16446300E+03, 0.99155500E+03, -.40591100E+03, -.51417500E+03, -.14162500E+03, 0.32171400E+03, -.40999200E+03, -.48819800E+02, -.51097300E+03, 0.77147000E+02, 0.23302500E+04, -.11441000E+04, -.11691400E+04, 0.41328600E+03, -.76497500E+02, -.80631200E+03, -.28321800E+03, -.11598400E+04, -.43063900E+02, 0.30540600E+03, -.16697200E+03, -.15809900E+03, 0.16440600E+03, -.63945800E+02, -.10295800E+02, 0.11432900E+03, 0.33459200E+02, -.99335800E+02, 0.33766600E+03, -.16545600E+03, -.16821700E+03, -.37045800E+02, -.42540200E+02, -.88694600E+02, 0.50143700E+02, -.31824700E+03, -.88791000E+02, 0.12994700E+03, -.58549500E+02, -.61570000E+02, -.15279800E+02, 0.20023600E+03, -.24394000E+03, -.53354000E+03, -.33066400E+03, 0.20309000E+03, -.31603900E+03, 0.15511100E+03, 0.15518600E+03, 0.18128500E+03, -.10920000E+03, 0.21194700E+03, 0.19556800E+03, 0.66851200E+03, -.25522400E+02, 0.14961700E+02, -.79238300E+01, -.18706200E+02, -.15600300E+03, -.56404800E+02, 0.56775300E+02, 0.96668900E+02, -.61396900E+03, -.68506800E+02, 0.78050100E+03, -.39653600E+03, -.38929500E+03, -.39849400E+03, -.84106200E+02, -.23293000E+03, -.16493000E+03, -.12892900E+04, -.15086500E+03, -.82619900E+03, 0.41311300E+03, 0.41333000E+03, 0.11404900E+03, 0.13099500E+03, 0.22079700E+03, -.20707400E+01, 0.25839000E+03, 0.14860900E+03, 0.82017300E+03, -.40794300E+03, -.42439500E+03, -.39010700E+02, -.70616700E+01, -.34497600E+03, -.15126700E+03, -.30153200E+03, -.87041000E+02, -.79510900E+01, -.92684100E+01, -.42364500E+01, -.14552000E+01, 0.26189800E+02, 0.27082900E+01, -.54416800E+02, 0.10869800E+03, -.54766300E+03, -.12756200E+03, -.10999000E+02, -.76366900E+00, -.20436900E+01, 0.87410500E+03, -.19711100E+03, 0.23918800E+03, 0.12496100E+04, -.12119100E+03, -.29681500E+03, 0.99804900E+02, 0.16074400E+03, -.12404400E+03, 0.81324600E+02, -.82130600E+03, 0.94608700E+02, -.70505300E+02 },
            { -.16187800E+01, 0.14051500E+01, 0.31319800E+00, 0.10385800E+01, -.63889500E+00, -.96143000E-01, 0.92147600E-01, 0.17880900E+00, 0.52838400E+00, 0.44985200E+00, 0.12649600E+01, 0.32143300E+00, -.95608200E+00, -.43796000E+00, -.34424800E+00, 0.38929100E-01, 0.77581100E+00, -.55299100E+00, -.10794300E+01, 0.11626000E+01, 0.21057100E+00, 0.16063200E+01, -.12092300E+01, 0.39545700E+01, 0.41332100E+00, -.76126300E-01, -.46725200E-01, 0.48963000E+00, -.22195000E+00, -.21897800E-01, 0.64373700E+00, 0.79399500E+00, 0.63586000E+00, 0.59235600E+00, -.65594800E-01, 0.40309100E+01, 0.71728900E+00, -.28374600E+00, -.40333300E+00, 0.32755000E+01, 0.32683900E+01, -.12773500E+01, -.11269300E+01, -.15436800E+01, 0.25935300E+00, 0.23688700E+00, 0.34040900E+00, -.71822300E+00, -.25724800E+00, 0.50921200E-01, 0.42842200E+00, -.31225200E+00, -.44967300E+00, 0.58262200E+00, 0.30185600E+00, -.94419200E+00, 0.48491100E+00, 0.18112700E+00, 0.11859100E+01, -.29112800E+00, 0.13228800E+01, -.87094700E+00, 0.18732600E+03, -.73381100E+03, 0.37200600E+03, 0.65547800E+03, -.34579800E+02, -.32704000E+03, 0.35940400E+03, 0.53143100E+02, 0.48370500E+02, -.41086000E+03, 0.17696200E+03, -.90946300E+02, -.15923100E+03, 0.51330200E+03, -.18340800E+03, -.62199300E+02, -.18566000E+03, 0.19934900E+02, -.92156900E+02, 0.27253600E+01, -.14721800E+01, -.65650200E+01, 0.26751900E+01, 0.11416800E+01, 0.68783500E+00, 0.79149500E+01, 0.10224700E+02, -.13571300E+02, 0.46376800E-01, -.21742500E-01, 0.76554200E-01, -.35368600E-01, 0.26610600E+00, -.49183500E-01, 0.41132700E-01, -.26002200E+00, 0.72658500E-02, 0.72604800E+00, -.41451900E+00, -.13858900E+01, -.38919700E+01, 0.12923400E+01, 0.91279800E+00, 0.68460100E+01, 0.89409400E+01, -.76495200E+01, -.26349400E+04, 0.13292000E+04, 0.14020900E+04, 0.98357200E+02, 0.13263300E+03, 0.86664000E+03, 0.23294800E+02, 0.90819300E+03, 0.39500500E+03, -.65889000E+03, 0.35645400E+03, 0.32465400E+03, 0.23387100E+03, -.35012500E+03, 0.37893700E+03, 0.45923100E+03, 0.87280300E+03, 0.51869000E+02, 0.48390000E+04, -.24623900E+04, -.24132300E+04, 0.10759300E+04, 0.52074400E+03, -.23192700E+04, -.22398100E+04, -.24445500E+04, 0.29887000E+03, -.21240600E+04, 0.10657900E+04, 0.95870400E+03, -.75446500E+02, -.15948600E+03, 0.73269700E+03, 0.18613800E+03, 0.89716100E+03, -.24629100E+02, 0.54167900E+03, -.32683800E+03, -.26173600E+03, -.26781800E+02, -.46223800E+02, -.48551700E+03, -.10265000E+04, -.56758600E+03, 0.63944500E+02, -.13807000E+03, 0.84140400E+02, 0.38210200E+02, -.28405500E+03, 0.14729800E+03, 0.25424200E+02, -.39810600E+01, -.11152800E+03, 0.10619000E+03, -.52866500E+02, 0.15945100E+02, 0.11032000E+03, -.24703500E+03, 0.79529900E+01, 0.39592200E+02, 0.15911300E+03, 0.17564600E+03, -.24488900E+03, -.43346000E+03, 0.22203100E+03, 0.16492100E+03, 0.21152300E+03, 0.11965500E+02, 0.11879100E+03, 0.14001600E+03, 0.40040600E+03, 0.45053300E+03, 0.53334300E+03, -.25606900E+03, -.34878000E+03, -.79956600E+02, -.14239900E+03, -.13980100E+03, 0.58774800E+02, -.20363200E+03, 0.11234000E+03, -.70198600E+03, 0.35212800E+03, 0.84553700E+03, -.54653400E+03, -.10396300E+03, 0.57267300E+03, 0.60082200E+03, 0.60356700E+03, -.28554800E+03, -.11085400E+04, 0.56029200E+03, 0.60285700E+03, 0.18230600E+03, 0.66579600E+02, 0.40103800E+03, -.50729800E+02, 0.60072800E+03, -.19969400E+02, 0.34467100E+03, -.17309100E+03, -.20004300E+03, -.66551800E+02, -.69455900E+02, -.65351500E+02, 0.14412700E+02, -.50901200E+01, -.33662300E+02, 0.35218300E+03, -.17838700E+03, -.18840500E+03, 0.21631100E+03, 0.18922600E+03, -.30308900E+03, -.54065000E+03, -.41417600E+03, 0.17142100E+03, -.27463800E+01, -.25282900E+03, 0.34308100E+02, 0.27267600E+00, -.13994700E+03, 0.27996800E+01, 0.12762700E+02, -.30464500E+03, -.37641700E+03, 0.64833900E+03, 0.12513300E+01, 0.12674100E+00, 0.11676900E+01, -.22676900E+03, 0.85920400E+03, -.30627300E+03, 0.11910500E+04, 0.12207200E+04, 0.79336400E+03, 0.99352900E+02, -.29703800E+03, 0.30859700E+03, -.10840500E+03, 0.34169800E+03, -.83830300E+02, -.29156400E+03 },
            { -.70741500E+00, -.38856600E+00, -.48523900E-01, 0.90129800E+00, 0.14902500E+01, 0.34595400E+00, 0.45112000E+00, -.38954900E-01, -.63025300E+00, 0.34977200E+00, 0.22876500E+00, -.45049600E-01, 0.14745600E+00, 0.13868800E+00, 0.91321100E-01, -.15183000E+00, 0.33498600E+00, -.83329300E-01, -.15038500E+01, 0.24371300E+00, 0.50278600E+00, 0.61757000E+00, -.41284300E+00, 0.13898300E+01, 0.21447100E+00, -.32102300E+00, -.49664000E+00, 0.51001200E+00, -.43524100E+00, 0.91190800E+00, 0.21031700E+00, 0.16039700E+00, -.63953400E-01, 0.19657200E+00, 0.15348000E+00, 0.89196400E+00, -.13099400E-01, 0.19158700E-02, 0.22104900E-01, -.82529900E+00, -.23009100E+00, 0.24273700E-01, -.41071400E-01, -.20310700E+00, 0.46074600E-01, -.29678100E+00, 0.10510400E+00, -.59780300E+00, -.84617800E+00, -.14060600E+00, 0.89510400E+00, 0.13193200E+00, 0.19436000E+00, -.27253200E+00, 0.30619800E+00, -.69022800E+00, -.48195700E+00, 0.50909800E-01, -.19589200E+00, 0.18012000E+00, 0.21805500E+00, -.30989400E+00, 0.35134700E+00, -.24498500E+04, 0.12209000E+04, 0.11813300E+04, 0.45073200E+03, 0.90784500E+03, 0.31263400E+03, -.12897500E+03, 0.12455800E+04, 0.93530100E+03, -.81920000E+03, 0.41100300E+03, 0.41699900E+03, -.32842100E+03, 0.17179100E+02, 0.36465200E+03, 0.43327100E+03, 0.59214400E+03, 0.21925300E+02, -.63189300E+01, 0.31594900E+01, 0.37089000E+01, -.64068900E+01, -.53809500E+01, 0.48439000E+01, 0.28676900E+00, -.10908800E+02, -.36844600E+01, 0.22115800E+00, -.10777500E+00, -.11899200E+00, -.85177800E-01, -.44939500E+00, 0.45595300E-01, 0.21857700E+00, 0.60840100E+00, -.42230700E+00, -.37451800E+01, 0.18717800E+01, 0.20093100E+01, -.94114400E+00, 0.56728200E+00, 0.26113800E+01, -.34846100E+01, -.11384200E+02, 0.13128600E+01, 0.41591300E+03, -.21000700E+03, -.23163100E+03, 0.40797100E+03, 0.45696300E+03, -.44083500E+03, -.16105200E+03, 0.11620700E+04, 0.26472200E+03, 0.30023200E+04, -.14967700E+04, -.15061900E+04, -.48187300E+03, -.61319100E+03, -.64022000E+03, 0.25817800E+03, 0.42769200E+03, -.79807800E+03, -.12334700E+04, 0.60936500E+03, 0.61711900E+03, -.22294900E+03, -.35772500E+03, 0.69156300E+03, 0.83696200E+03, 0.96043500E+03, -.27024600E+03, 0.13421800E+04, -.62748200E+03, -.65378300E+03, 0.11987100E+02, 0.18598900E+03, -.51556400E+03, -.24816400E+03, -.61925900E+03, 0.47008200E+02, -.25919500E+03, 0.15033900E+03, 0.13233700E+03, 0.27482900E+03, 0.19088000E+03, 0.85984600E+02, 0.16394100E+03, 0.29733200E+02, 0.11587900E+03, 0.26130400E+03, -.13978800E+03, -.12545300E+03, 0.22039700E+03, 0.35474500E+02, -.16287000E+03, -.21299900E+03, -.35077000E+03, 0.52803400E+02, -.25729200E+02, 0.16682100E+02, -.43160600E+00, 0.46475300E+02, 0.96295800E+02, 0.39182200E+02, -.13493800E+03, -.46009900E+03, 0.10303600E+03, 0.28825300E+03, -.14165100E+03, -.13906700E+03, -.19744400E+02, 0.14109100E+03, -.15416500E+03, -.36511500E+03, -.35685200E+03, 0.16370000E+02, 0.32483900E+03, -.16496500E+03, -.14695300E+03, -.12139500E+03, -.53873100E+02, -.24125900E+02, 0.58881100E+02, 0.26614900E+03, -.73065200E+02, -.88024700E+02, 0.43761400E+02, -.13809000E+02, 0.35275200E+03, 0.29341600E+03, -.24037500E+03, -.23300300E+03, 0.84794700E+01, 0.26943300E+03, -.16159600E+04, 0.80203800E+03, 0.78703500E+03, 0.43754400E+03, 0.54697400E+03, 0.11291500E+03, -.19247200E+03, 0.37152700E+03, 0.58451100E+03, -.61631500E+03, 0.30783600E+03, 0.31254600E+03, 0.61969600E+02, 0.28416200E+02, 0.16987000E+03, 0.21684600E+00, 0.29139200E+03, 0.10751100E+03, 0.15429300E+03, -.76247900E+02, -.67535400E+02, -.11503800E+03, -.13582200E+03, 0.28599000E+02, 0.22847300E+03, 0.14165300E+03, -.12236800E+03, -.72004700E+00, 0.16825500E+03, -.51198000E+02, -.85330200E+00, 0.37746400E+02, 0.22465600E+01, -.17821000E+03, 0.18386600E+03, 0.53606800E+03, -.22765600E+03, 0.34436800E+01, -.36371400E+00, 0.40457300E+01, -.92415300E+03, 0.18094900E+03, 0.98013300E+02, -.49900000E+03, -.55267500E+03, -.28449400E+03, 0.12204300E+03, 0.10065600E+03, -.67825000E+02, -.12957000E+02, 0.12853100E+03, 0.21221200E+03, 0.13882400E+03 },
            { -.43326200E+00, -.16077400E+00, 0.11091500E+00, 0.31528200E-01, 0.21499500E+00, 0.59030400E-02, 0.16917000E+00, 0.38717300E-02, -.10728600E+00, 0.22142000E+00, 0.28405500E+00, 0.53280400E+00, -.10425300E+00, -.10609700E+00, 0.25604900E+00, -.12354200E+00, 0.64691500E-01, -.63320800E-03, -.22776400E+00, -.19483100E+00, 0.11803600E+00, -.19696700E+00, 0.10648500E+00, -.29849800E+00, 0.27952800E-01, 0.15811900E-01, -.69867000E-01, 0.26591800E-01, -.76847600E-01, 0.80199000E-01, 0.16173400E+00, 0.99822800E-01, 0.89956300E-01, -.93265300E-01, 0.48330400E-02, 0.33851000E-01, 0.15125900E+00, -.23280600E+00, -.87404600E-01, 0.87634600E+00, 0.85008700E+00, -.24164100E+00, -.10594000E+00, -.37551800E+00, 0.11380700E+00, 0.83834900E-01, 0.16584200E+00, 0.44106300E+00, -.51080500E+00, -.14543300E+00, 0.44465900E-01, -.33225100E+00, -.41922100E-01, 0.17664000E+00, -.77183900E-01, -.91333400E-01, 0.52311400E-02, 0.41682200E-01, -.32091400E-01, -.40561300E-01, -.86659100E-01, -.12129900E+00, 0.61278300E-01, 0.19468400E+00, -.10917100E+02, 0.50887600E+01, -.38031800E+02, -.29291300E+02, -.18655300E+02, -.14553000E+02, 0.53830800E+02, -.55287400E+02, 0.11295700E+03, -.62524000E+02, -.59377700E+02, 0.59135600E+02, -.17685700E+02, -.23855400E+02, -.43055600E+02, -.26497200E+02, -.62313300E+02, -.54055200E+00, -.85742000E+01, 0.26975100E+00, 0.66540500E+00, -.22151300E+01, 0.27956000E+01, 0.48880700E+01, 0.63730600E+01, 0.89467000E+00, -.25478400E-01, -.20899900E+01, 0.30306400E-01, 0.69148600E-01, 0.72771300E-01, 0.66538700E-03, 0.57925000E-01, -.18329200E+00, 0.95620600E-01, 0.14010700E+01, -.65516200E+01, -.72439400E+00, -.60146700E+00, -.14834300E+01, 0.58030600E+00, 0.11216500E+01, 0.36761000E+01, -.20692100E+00, -.25061200E+03, 0.11845000E+03, 0.13179800E+03, -.46125000E+02, -.60100500E+02, 0.14578700E+03, 0.17243400E+03, 0.21654900E+03, 0.30793500E+02, -.46736000E+02, 0.35983100E+02, 0.26039000E+02, 0.67628500E+02, 0.44806600E+02, 0.36120900E+02, 0.10067200E+03, -.31755800E+02, 0.93739800E+02, -.59068700E+03, 0.25230800E+03, 0.29582200E+03, -.14432800E+03, -.34773200E+02, 0.15222300E+03, -.80789400E+02, 0.40968100E+02, 0.19368000E+02, -.17259500E+03, 0.90144400E+02, 0.90521700E+02, 0.52056000E+02, 0.62665900E+02, 0.50185100E+02, -.43376600E+01, 0.88961900E+01, 0.46453000E+02, -.40745200E+03, 0.15986600E+03, 0.20430500E+03, -.12892700E+03, -.32183200E+02, 0.11721600E+03, -.43875600E+02, 0.89253300E+02, -.16396400E+01, -.31373900E+02, 0.38572100E+02, 0.14473400E+02, -.40000900E+02, 0.27237000E+02, -.18825200E+01, 0.20040800E+02, 0.75136100E+01, 0.12740900E+02, 0.54914900E+02, -.48571000E+02, -.27990100E+02, -.16810400E+02, -.37315000E+01, -.31440200E+02, -.63762700E+02, 0.32108300E+02, 0.42391000E+01, 0.11893400E+03, -.55649300E+02, -.62449700E+02, 0.44853500E+02, -.29098200E+02, 0.29291500E+02, 0.19166300E+03, 0.15302500E+03, 0.31167600E+02, 0.18397300E+03, -.67779500E+02, -.92780100E+02, -.16759100E+02, 0.69102900E+01, -.70155800E+02, -.95449300E+01, -.14580800E+03, -.64603700E+02, -.23907700E+03, 0.10206000E+03, 0.12371100E+03, -.30861200E+02, 0.31246600E+02, 0.98775900E+02, 0.66285000E+02, 0.16252300E+03, 0.38637500E+02, -.34906700E+03, 0.14049700E+03, 0.18420800E+03, -.15404000E+01, 0.27416900E+02, 0.13772800E+03, 0.40685500E+02, 0.22484900E+03, 0.95550500E+02, 0.10125100E+03, -.52292500E+02, -.51420400E+02, -.12502400E+02, -.28688600E+02, -.83718700E+01, 0.37016600E+02, -.47057700E+00, -.57353400E+02, -.18550500E+03, 0.91697300E+02, 0.98640100E+02, 0.48962600E+02, 0.13173300E+02, 0.51998100E+02, -.36831400E+02, 0.22403900E+01, 0.49950400E+02, -.13152100E+00, 0.75939400E+01, 0.11574300E+01, -.82955700E-01, 0.36183900E+02, -.21975500E+01, 0.10899200E+02, 0.11314400E+02, 0.35068400E+01, 0.47735800E+02, -.19586800E+01, 0.94288400E-01, -.41515800E+01, -.98623600E+02, 0.17418200E+03, -.24124000E+03, -.14684600E+03, 0.21631300E+03, 0.95426400E+02, -.41602700E+02, -.97447000E+02, -.37685800E+01, -.34768800E+02, 0.18981000E+03, 0.30847900E+02, 0.28718200E+02 },
            { 0.10954400E+01, -.93552800E+00, -.11887800E+00, -.28783600E+00, 0.42964900E+00, 0.29812300E+00, -.24817300E+00, 0.32589200E+00, 0.64862100E+00, -.95403700E-02, -.89300800E+00, -.21899500E+01, -.45887200E+00, 0.80047800E+00, 0.47922700E-01, -.10513600E+00, 0.63780000E-01, 0.79982900E+00, 0.13460700E-01, -.69042200E+00, -.19534300E+00, 0.14146800E+01, 0.28702500E+00, 0.25834800E+00, -.10097600E+00, 0.17923300E+00, -.90901500E-02, -.30302800E+00, 0.24917900E-01, -.16847600E+00, 0.83898900E-01, -.32280600E+00, 0.11914500E+00, -.17606700E+00, -.27588700E+00, -.12456100E+01, -.52420600E+00, 0.20883600E+00, 0.31515300E+00, -.11550600E+01, -.12133300E+01, 0.92933300E+00, 0.69404200E+00, 0.90831500E+00, -.78990000E-01, 0.35099000E+00, -.20821600E+00, -.36552600E+00, 0.28675500E+00, 0.31408800E+00, -.77248100E+00, 0.10673600E+01, -.37626000E-01, -.40463700E+00, 0.27722500E+00, 0.49790600E+00, -.87320300E+00, -.66688500E-03, 0.17930100E+00, -.13944700E+00, -.53957500E-01, 0.44229300E+00, -.42012300E+00, -.18134500E-02, -.22484200E+00, 0.20125600E+03, -.51597800E+01, -.25141700E+03, 0.19255200E+03, 0.11273200E+03, 0.68238800E+02, -.18589300E+03, -.23131300E+03, 0.11275800E+03, 0.68389800E+02, 0.33808100E+03, -.87084600E+02, 0.86443600E+02, 0.78489000E+02, 0.25641400E+03, 0.16779300E+03, 0.29101900E+01, -.35353100E+01, -.53108200E+01, 0.32516800E+01, 0.25031500E+01, -.26754300E+01, -.28506600E+01, -.24742600E+01, -.33412000E+01, 0.79609300E-01, -.51070900E+00, 0.19031100E-02, -.78853500E-01, 0.11540900E+00, -.96904800E-01, -.17812300E+00, -.17727900E+00, 0.43513700E-02, -.23862700E+00, -.12512400E+01, -.63315300E+00, 0.31268900E+00, 0.15325000E+01, -.57031800E+00, 0.14413800E+01, 0.80059400E+00, -.61112000E+00, -.36008500E+03, 0.18517800E+03, 0.23564500E+03, 0.75049200E+02, -.15802100E+03, 0.27378400E+03, 0.27701100E+01, 0.44061300E+03, -.14536400E+03, 0.27079900E+03, -.11081000E+03, -.13315300E+03, 0.15170400E+03, -.27652400E+03, -.23251900E+01, 0.11687800E+03, 0.28746000E+03, -.24493300E+03, 0.22406400E+04, -.11712900E+04, -.11183100E+04, 0.38508900E+03, 0.36222400E+03, -.95352600E+03, -.72319700E+03, -.85922700E+03, 0.45838800E+02, -.10574600E+04, 0.54656100E+03, 0.43299400E+03, 0.27388200E+00, -.17419800E+03, 0.37585000E+03, 0.90556500E+02, 0.54177800E+03, -.55734300E+02, -.10994900E+03, -.26065600E+00, 0.55421000E+02, -.12368300E+03, 0.26362600E+02, -.48108200E+01, -.17112800E+03, 0.63663600E+02, -.12649300E+02, 0.33442000E+03, -.15202000E+03, -.19575600E+03, -.11726500E+03, 0.72331200E+02, -.16718300E+03, -.24548800E+03, -.37956900E+03, -.15691200E+02, -.34963300E+03, 0.16185600E+03, 0.24035600E+03, -.11684100E+03, 0.16274900E+02, 0.13253400E+03, 0.18628900E+03, 0.16255600E+03, -.17536100E+01, -.93179400E+02, 0.50782300E+02, 0.13897000E+02, 0.15196800E+03, 0.20268500E+02, -.21078300E+02, -.13651800E+03, -.41189000E+02, -.70431500E+01, 0.65531200E+02, -.20924100E+02, -.98405500E+02, 0.67497300E+02, -.80391300E+02, -.43272200E+02, -.59180100E+02, -.33412300E+02, 0.41580300E+02, 0.48059300E+03, -.24138200E+03, 0.11940300E+03, -.18293700E+03, -.16758600E+03, -.26569400E+02, 0.42046800E+02, -.36735700E+02, -.22201200E+03, -.22451300E+03, 0.10938200E+03, 0.14469900E+03, 0.46064300E+02, -.12158600E+03, 0.17817000E+03, 0.37043400E+02, 0.43676900E+03, -.18109900E+03, 0.23196500E+03, -.11706700E+03, -.13585000E+03, 0.40912700E+02, 0.17561600E+02, -.98960700E+02, -.97706500E+02, -.63743400E+02, 0.21480000E+02, -.72418800E+02, 0.33872800E+02, 0.65625900E+01, -.31029100E+02, 0.88408700E+02, 0.14329700E+02, 0.19475400E+01, 0.34518500E+01, -.32090600E+02, -.16020200E+01, -.10220000E+03, 0.12743600E+02, 0.17054200E+00, -.10432700E+03, 0.44276200E+00, 0.66121400E+02, -.10750800E+03, -.13970900E+03, 0.36360700E+03, -.22835200E+01, 0.17017500E+00, -.81162000E-02, -.62236300E+02, 0.19377600E+03, -.10128100E+02, 0.38986600E+03, 0.51305400E+03, 0.43374000E+03, 0.30650700E+02, -.11784100E+02, 0.10804300E+03, -.31198600E+02, 0.13623200E+03, -.10450300E+03, -.16939400E+03 },
            { -.38455300E+00, -.73025100E-01, -.80039800E-01, 0.38563900E+00, 0.12581500E+01, 0.15151700E+00, 0.17183300E+00, 0.38042700E-02, -.30697200E+00, 0.21451800E+00, 0.30804400E+00, 0.15248100E+00, 0.43714400E+00, -.10083900E+00, 0.95046900E-01, -.16967000E+00, 0.54492200E+00, -.10744700E+00, -.32269400E+00, 0.29123800E+00, 0.15244800E+00, 0.77922400E+00, 0.28174000E+00, 0.35957100E+00, 0.46006300E-01, 0.22334300E+00, -.52931100E-03, -.58007600E-01, -.76699500E-01, -.21879000E+00, 0.68701800E-01, 0.10058700E+00, 0.17155300E+00, 0.26528500E+00, -.21175300E+00, 0.15054800E+00, 0.43963500E-01, -.19819200E-01, -.11330200E-01, 0.20901500E+00, 0.48929300E-01, -.16682700E+00, -.17931200E+00, 0.98563100E-02, 0.33763900E-01, -.16696300E+00, -.26977600E+00, -.51069900E+00, -.31811700E+00, 0.28392200E-01, 0.51122100E+00, 0.11231400E+00, 0.57268800E-03, -.37788600E-01, -.20060300E+00, -.70842000E-01, 0.49786600E+00, 0.12298000E+00, 0.36658400E+00, -.12939300E+00, 0.25132000E-01, 0.27361800E-01, 0.25997800E+00, -.19275600E+00, -.20757300E+00, 0.54025900E+00, -.12704100E+03, -.67337900E+01, -.22657700E+02, -.12534800E+02, 0.98055900E+02, -.90259300E+02, 0.32024900E+03, -.16167200E+03, -.16656500E+03, -.10384200E+03, -.51181200E+02, -.30103300E+02, 0.11310800E+03, 0.10286400E+01, -.72863300E+02, -.33204800E+01, 0.87711300E+00, 0.20324600E+01, 0.57080300E+01, -.37433400E+01, 0.79011600E+01, 0.13240700E+02, 0.12716600E+02, -.44328800E+01, -.14726900E+00, -.10908500E+00, 0.11582700E+00, -.78718800E-02, 0.21300900E-02, 0.10578500E+00, 0.14038100E+00, -.27916300E+00, 0.29032100E-01, 0.37424400E-01, -.53295400E+00, -.12862600E-01, 0.19952300E+01, -.37310700E+01, 0.34746200E+01, 0.46851000E+01, 0.85511400E+01, -.48183500E+01, -.35889400E+03, 0.17918700E+03, 0.19766200E+03, 0.16672000E+02, -.17110200E+03, 0.22449400E+03, 0.32399600E+03, 0.30920500E+03, -.47480000E+02, -.40447800E+02, 0.15528800E+02, 0.33189500E+02, 0.19636600E+02, -.14114700E+02, 0.10494900E+03, 0.28779300E+03, 0.21246000E+02, 0.21744600E+02, -.17236300E+04, 0.87199700E+03, 0.86152700E+03, -.33977900E+03, 0.15931300E+02, 0.65533700E+03, 0.38456700E+03, 0.55130200E+03, -.38718200E+02, -.63275100E+03, 0.27721600E+03, 0.31307100E+03, 0.20206900E+03, 0.47324600E+02, 0.18668400E+03, 0.58677500E+02, 0.15656000E+03, 0.12162300E+03, -.11826100E+04, 0.57812900E+03, 0.58892000E+03, -.18711500E+03, -.71382000E+02, 0.46060200E+03, 0.19890900E+03, 0.47995300E+03, -.89510400E+02, -.29947800E+03, 0.15782900E+03, 0.14678200E+03, 0.78858900E+02, 0.34986200E+02, 0.32387200E+02, -.98385000E+02, 0.25054400E+02, 0.88649300E+02, 0.17020900E+03, -.87822100E+02, -.84175500E+02, 0.47246000E+02, -.51398800E+02, -.46416600E+02, -.10163300E+03, 0.68639700E+02, -.10739800E+03, -.13112100E+03, 0.62925900E+02, 0.60101700E+02, 0.27638700E+01, -.15707200E+03, 0.19608500E+03, 0.33986600E+03, 0.35370200E+03, -.23581600E+02, 0.43472100E+03, -.21365600E+03, -.22032200E+03, -.23661400E+03, -.83676900E+02, -.11123000E+03, -.25073800E+02, -.27756100E+03, -.10971700E+03, -.57736500E+03, 0.28684800E+03, 0.27043700E+03, -.85097300E+02, 0.40510800E+02, 0.25816500E+03, 0.20251400E+03, 0.32415200E+03, -.54388600E+02, -.68049600E+02, 0.34158700E+02, 0.66501900E+02, 0.11250800E+03, 0.48062300E+02, 0.86810500E+02, 0.16094500E+03, 0.14176600E+03, 0.43708300E+02, 0.13100900E+03, -.65853800E+02, -.66613900E+02, -.46595800E+02, -.92221500E+02, 0.24832700E+02, 0.10441400E+03, 0.22632000E+02, -.74566400E+02, -.30981700E+03, 0.15399300E+03, 0.16341100E+03, 0.17719900E+03, -.84142100E+01, 0.97275900E+02, 0.33319700E+01, 0.58663300E+02, 0.15367000E+03, 0.17439800E+01, 0.85817500E+02, -.54361100E+01, 0.15970300E+00, -.43942600E+01, -.18772700E+01, -.10108000E+03, 0.93041700E+02, 0.19741200E+02, -.16545300E+03, 0.63684500E+01, 0.74187900E-01, 0.36177300E+00, -.10904700E+03, 0.22289500E+03, -.28668700E+03, -.83210500E+03, 0.50177600E+02, -.13064700E+03, -.43776400E+02, -.12986400E+03, 0.46447600E+02, -.52448900E+01, 0.34251800E+03, 0.14020400E+03, 0.90209400E+02 },
            { 0.75958300E+00, -.70563600E+00, -.57296500E+00, 0.75791500E+00, -.48495800E+00, 0.82204600E-01, -.28049100E+00, -.65738900E-01, -.37331800E+00, -.44709000E+00, 0.19025000E-01, -.12473100E+01, -.12574400E+00, 0.38434500E+00, -.58039600E+00, 0.27701400E+00, -.11540800E+00, 0.51101400E+00, -.89822000E-02, 0.18758500E-01, -.55774900E+00, 0.39666500E+00, 0.84832800E-01, 0.19150400E+00, -.51237300E-01, -.15250500E+00, -.47430200E-01, -.22941900E-01, -.33619200E-01, 0.47574000E-01, -.98750400E-01, 0.41946800E-01, 0.25982400E+00, 0.10488500E+00, 0.17403200E-02, 0.10298000E+01, 0.24219500E+00, -.92243100E-01, -.13511700E+00, 0.11533400E+01, 0.30982200E+01, -.48500100E+00, -.32435400E+00, -.97774500E+00, 0.65625200E+00, 0.49362800E+00, -.44941800E+00, 0.14234100E+00, -.87640000E+00, 0.18924900E+00, -.46907000E+00, -.46445800E-01, 0.39699100E+00, -.44842100E+00, 0.47263400E-01, 0.27438100E+00, 0.11207200E+01, -.32380500E-01, -.28279600E+00, 0.37332400E+00, -.45952300E+00, 0.14913000E+00, -.15013700E+00, -.16073600E-01, -.34121800E+00, 0.44505700E+00, -.42586900E+00, 0.14586300E+03, -.13307400E+03, -.15954100E+03, -.40692200E+02, 0.31265200E+02, 0.10687300E+04, -.53649800E+03, -.53968700E+03, 0.12418900E+03, 0.72239800E+02, -.34182400E+03, -.20096600E+03, -.37718000E+03, -.15961300E+03, -.33910100E+01, -.75519400E+00, 0.20001000E+01, 0.65655100E+01, -.69629500E+01, 0.95532200E+01, 0.17401600E+02, 0.16898000E+02, -.14306500E+01, 0.59554700E-01, -.61570700E+00, 0.11809100E-01, -.22144900E-01, 0.38823500E-01, 0.79417200E-01, 0.22067600E+00, -.25954100E+00, 0.12901700E+00, 0.24027800E+01, -.28096100E+01, -.11376300E+01, 0.21130500E+01, -.62405000E+01, 0.27251300E+01, 0.43478900E+01, 0.91290000E+01, -.44453300E+01, -.66283700E+03, 0.33344500E+03, 0.33432800E+03, 0.13004800E+03, -.63811900E+02, 0.24902800E+03, 0.34124000E+03, 0.28637400E+03, 0.14753900E+03, 0.14818400E+03, -.75986400E+02, -.77626200E+02, 0.73867900E+02, -.63896600E+02, 0.80097400E+02, 0.39437300E+03, 0.42599800E+02, 0.37607000E+02, -.23857900E+04, 0.11997700E+04, 0.11957200E+04, -.46664900E+03, -.37893100E+02, 0.86841600E+03, 0.38346500E+03, 0.75397300E+03, -.27834700E+02, -.10252200E+04, 0.46703800E+03, 0.52452700E+03, 0.14203700E+03, 0.77984000E+02, 0.33800800E+03, 0.14439100E+03, 0.26745800E+03, 0.18507600E+03, -.14731600E+04, 0.72288000E+03, 0.74293900E+03, -.24471400E+03, -.14848800E+02, 0.49710600E+03, 0.10200500E+03, 0.46268100E+03, 0.16739900E+01, -.83546200E+03, 0.42817600E+03, 0.42767000E+03, -.15791400E+03, -.24755100E+02, 0.27058900E+03, 0.17048400E+03, 0.31850700E+03, 0.83304800E+02, 0.32015000E+03, -.16454100E+03, -.15945800E+03, 0.45392200E+02, -.89294200E+02, -.13386500E+03, -.20313700E+03, 0.15367500E+02, -.10972900E+03, 0.11875100E+03, -.59224400E+02, -.66040800E+02, 0.74433400E+02, -.23953600E+03, 0.14762900E+03, 0.46863300E+03, 0.39262800E+03, -.79092900E+02, 0.43090200E+03, -.20697600E+03, -.20936400E+03, -.22147000E+03, 0.13226400E+02, -.13821600E+03, -.91677900E+02, -.35553100E+03, -.11927500E+03, -.87517400E+03, 0.43019100E+03, 0.42235900E+03, -.57573200E+02, 0.74019100E+02, 0.31635800E+03, 0.23726500E+03, 0.36357300E+03, 0.10641200E+03, -.40817200E+03, 0.19618100E+03, 0.20741800E+03, 0.12885200E+03, 0.51389100E+02, 0.19900700E+03, 0.23530600E+03, 0.21405600E+03, 0.17087800E+03, 0.45724900E+02, -.23579600E+02, -.23316700E+02, -.88917000E+02, -.76983700E+02, 0.62625100E+02, 0.13594900E+03, 0.44126400E+02, -.79205200E+02, -.39394700E+03, 0.19621900E+03, 0.21880400E+03, 0.16990700E+03, -.21510800E+02, 0.13341700E+03, -.63851800E+00, 0.11697800E+03, 0.16579700E+03, -.99003500E+00, 0.10178100E+03, -.79408700E+01, -.75159900E-01, 0.67386000E+02, -.50657900E+01, -.83905800E+02, 0.11141300E+03, 0.57224300E+02, -.18237100E+03, 0.51400100E+01, -.25032400E-01, -.35616100E+01, -.15571200E+03, 0.38034800E+03, -.39739500E+03, -.15695000E+03, 0.26581200E+03, 0.54385600E+02, -.92967600E+02, -.14766700E+03, 0.24787000E+02, -.58775500E+02, 0.46860100E+03, 0.13585700E+03, 0.18066900E+03 },
            { -.10811100E+01, 0.66286300E+00, 0.66634300E+00, -.60032400E+00, -.22391700E+01, -.46421300E+00, 0.41380200E+00, -.27337700E+00, 0.13809200E+00, 0.25839900E+00, 0.90415000E+00, 0.33235300E+01, -.72427500E+00, -.66177900E+00, 0.31921500E+00, -.19298800E+00, -.35067100E+00, 0.25848100E+00, -.13271400E+01, 0.31593500E+00, 0.85622900E+00, 0.15383300E+01, -.13235200E+00, -.61342700E+00, 0.91243400E-01, 0.43181900E+00, 0.45467300E-01, -.19921800E+00, -.14107600E+00, -.53223200E+00, 0.54641100E+00, 0.60308500E+00, 0.57303400E-02, -.11477500E+00, -.59818500E-01, -.25613400E+00, -.15484800E+00, 0.58281600E-01, 0.91885900E-01, 0.39938900E+00, -.63243700E-01, 0.12697400E+00, -.21345300E+00, 0.20959900E+00, 0.15939100E+00, 0.50132200E-01, 0.32815500E-01, 0.69306500E+00, -.30539700E+00, 0.25266400E+00, -.12191400E+00, 0.32516200E+00, -.21778500E+00, -.26777200E-01, -.29336400E+00, 0.71905800E-01, 0.79340900E-01, 0.18630200E-02, 0.33053000E+00, -.11775500E+00, 0.36325600E+00, 0.31865800E+00, -.39181800E+00, -.11315300E+00, -.53815400E+00, 0.65390600E+00, 0.52547800E+00, -.73771300E+00, -.10372500E+03, -.22220800E+03, -.18079100E+03, -.28338900E+02, 0.38286700E+03, -.19542200E+03, -.19062200E+03, 0.11976600E+03, 0.99685400E+02, -.20063100E+03, -.40921000E+03, -.35286000E+03, -.89967400E+02, -.28991900E+00, -.46891600E+01, 0.28814600E+00, -.24787700E+01, -.11197300E+01, 0.60533200E+01, 0.14867000E+02, 0.16124500E+02, -.11758600E+01, 0.17635500E+00, -.12466400E+01, -.78735400E-01, 0.13962600E+00, 0.18496600E+00, -.21794600E-01, 0.15248900E+00, -.34743700E+00, 0.19787100E+00, 0.30075200E+01, -.46881300E+01, -.14521200E+01, -.22113100E+01, -.26792900E+01, 0.13251600E+01, 0.56686400E+01, 0.86900600E+01, -.30053700E+01, -.11209300E+04, 0.56788000E+03, 0.55772500E+03, -.66861400E+02, -.56649800E+02, 0.45463000E+03, 0.48362200E+03, 0.41289500E+03, 0.15812900E+03, 0.85280600E+02, -.25530000E+02, -.50227500E+02, 0.83351900E+02, 0.19844000E+03, -.88043200E+01, 0.22941100E+03, -.11768400E+03, 0.23468300E+03, -.13574800E+04, 0.64761600E+03, 0.68079700E+03, -.11490400E+03, -.33863100E+03, 0.33737300E+03, -.25087600E+03, 0.15647800E+03, 0.19087800E+03, 0.14583000E+03, -.71142200E+02, -.62901900E+02, 0.64893000E+02, 0.26601300E+03, -.98293600E+02, -.34529000E+02, -.15405500E+03, 0.16686200E+03, 0.21980900E+03, -.13525200E+03, -.10494300E+03, 0.42693600E+02, 0.24240500E+02, -.21011100E+03, -.30772700E+03, -.29592600E+03, 0.19035200E+03, -.16744600E+02, 0.22441600E+02, 0.19750100E+02, -.11498700E+03, -.43414500E+02, 0.43572900E+02, 0.21156200E+03, 0.16831400E+03, -.34162900E+02, 0.16233100E+03, -.93906000E+02, -.80119700E+02, -.31103900E+02, -.65640800E+02, -.64511600E+02, -.20161600E+02, 0.10546400E+03, -.79535400E+02, 0.50285100E+03, -.24407400E+03, -.25285400E+03, 0.56325000E+02, -.22901300E+02, -.42441600E+02, 0.44441900E+03, 0.23933900E+03, 0.44784700E+00, 0.58935000E+03, -.27614800E+03, -.28941300E+03, 0.44522600E+02, -.22943500E+02, -.28131000E+03, -.30141500E+03, -.55885700E+03, -.79179400E+02, -.69165500E+03, 0.33122700E+03, 0.33464400E+03, -.15899000E+03, 0.70651300E+02, 0.28353200E+03, 0.22852000E+03, 0.38127600E+03, 0.61771500E+02, -.16798500E+03, 0.65103100E+02, 0.75459300E+02, -.21626400E+03, 0.31003600E+02, 0.18772200E+03, 0.28478500E+03, 0.32826000E+03, 0.14740900E+02, 0.37377400E+03, -.18750600E+03, -.18651100E+03, -.83000700E+02, -.11266800E+03, -.94433000E+02, -.35233400E+02, -.12428700E+03, -.10774600E+03, -.19162000E+03, 0.95097400E+02, 0.10586100E+03, 0.17066500E+03, 0.25793300E+02, -.14732000E+01, -.17606100E+03, -.69198700E+02, 0.16457900E+03, -.36226900E+01, 0.41523200E+02, 0.11760100E+02, 0.15616300E+00, 0.11959500E+03, -.48284700E+01, 0.63079300E+02, 0.48407700E+02, -.64668700E+02, 0.39573400E+02, 0.87963500E+00, 0.18310600E+00, -.41002800E+01, -.15768000E+03, 0.34931800E+03, -.18789100E+03, 0.18838800E+03, 0.14858000E+03, 0.12552700E+03, -.60625300E+02, -.15655500E+03, 0.18052100E+03, -.65913800E+02, 0.47685500E+03, -.76703400E+02, 0.12341000E+03 },
            { 0.42540500E-01, -.52208000E-02, 0.67578600E-02, -.13429200E+00, -.21504400E+00, -.40923300E-02, -.19064700E-01, 0.60374900E-01, 0.70880800E-01, -.34784700E-01, -.48451500E-01, -.12605400E-01, -.12263000E-01, 0.17869700E-01, 0.35949900E-01, 0.11189900E-01, -.67324700E-01, -.33003700E-01, 0.68362100E-01, -.28343200E-01, -.62417300E-01, 0.41973500E-02, -.83680800E-01, -.85572800E-01, 0.11588800E-01, 0.11149200E-01, 0.66263800E-01, 0.78539600E-02, 0.80037300E-02, 0.19454800E-01, 0.69373100E-01, -.24722600E-01, 0.49256300E-02, -.27243200E-01, -.15715600E-01, 0.11454800E+00, -.35499100E-01, 0.13639500E-01, 0.20334500E-01, -.89055500E-01, -.68163800E-01, 0.58847700E-01, -.16252300E+00, 0.71795500E-01, 0.53022600E-02, -.74688200E-02, 0.70405500E-01, -.73179500E-02, 0.51512800E-01, -.27979400E-01, -.61595600E-01, 0.26428800E-01, -.66714700E-01, 0.32817300E-01, -.15355100E-01, 0.45095100E-01, -.18890400E+00, 0.93604000E-03, 0.20383000E-01, -.39418700E-01, 0.10131400E-02, 0.21310500E-01, -.39627500E-01, -.26573800E-01, 0.80438300E-03, 0.42827700E-01, 0.65955100E-01, -.62175900E-01, -.39231100E-01, -.18992600E+02, 0.33966400E+00, -.17478400E+01, 0.40773600E+02, -.20480800E+02, -.19930500E+02, 0.11714300E+02, 0.62642600E+01, -.17114100E+02, -.23850100E+02, -.16323000E+02, -.84312500E+01, -.16125800E+00, -.11801900E+00, 0.99172300E-01, -.15453000E+00, -.11888600E+00, -.79801000E-01, -.22554700E+01, 0.47099800E+00, -.44284600E-01, -.46166500E-02, -.45486000E-01, 0.11086400E-02, 0.12954800E-01, 0.11016900E-01, -.26227900E-02, -.50567800E+00, -.32765200E-01, 0.17235800E-01, 0.50004700E-01, -.15563200E+00, -.16211100E-01, -.45854100E-01, -.59210900E-01, -.18402800E+00, -.15272400E+01, 0.19607000E+00, -.74767000E-01, -.25887000E+02, 0.13402900E+02, 0.12470800E+02, -.58158100E+01, -.27497300E+01, 0.86795500E+01, -.98896700E+00, 0.23069500E+02, 0.52777000E+01, 0.33223400E+02, -.15239300E+02, -.17942800E+02, -.23098500E+01, -.18305200E+00, -.10190500E+02, 0.58145200E+00, 0.27031800E+01, 0.35008300E+01, -.61233300E+02, 0.27752100E+02, 0.30792900E+02, -.20396400E+01, -.22896400E+02, 0.20344100E+02, -.80209300E+00, 0.21889100E+02, 0.75860000E+01, 0.41456900E+02, -.17272200E+02, -.19387000E+02, -.65232400E+01, 0.10464600E+02, -.15901300E+02, -.99723100E+01, -.16663200E+02, 0.47510500E+01, 0.28415000E+02, -.14850400E+02, -.13691500E+02, 0.11191500E+02, 0.46421700E+01, -.16777100E+02, -.14172300E+02, -.18375600E+02, 0.13929700E+02, -.21503800E+02, 0.10848200E+02, 0.12090400E+02, -.16735800E+02, -.56357500E+01, 0.12650400E+02, 0.21709300E+02, 0.11674600E+02, -.11980500E+01, 0.26733900E+01, -.18281600E+01, -.14609900E+01, 0.31699600E+01, 0.20065800E+01, -.85291000E+01, -.18137300E+02, -.95437100E+00, 0.37511200E+00, 0.30349500E+02, -.14559000E+02, -.14906100E+02, 0.55499200E+01, 0.57668000E+01, -.15790200E+02, -.10051800E+02, -.63901000E+01, 0.32774100E+01, 0.89910300E+01, -.37504300E+01, -.37387700E+01, 0.99923600E+01, 0.11136800E+02, -.63844100E+01, -.60195600E+01, -.32821500E+02, 0.76233700E+01, -.18478600E+02, 0.85963500E+01, 0.75448000E+01, -.77486500E+01, -.35851700E+01, 0.10321700E+02, 0.28039300E+00, 0.19494900E+02, 0.30670600E-01, -.95518900E+01, 0.37633900E+01, 0.29684400E+01, -.18983200E+02, -.15578100E+02, 0.10314700E+02, -.55268100E-01, 0.31149700E+02, -.10945100E+02, -.39650700E+01, 0.19471400E+01, 0.21175100E+01, -.40251200E+01, -.24345000E+01, 0.15587400E+01, -.38390800E+01, -.12923800E+01, 0.21795500E+00, 0.12075500E+02, -.60343700E+01, -.54553000E+01, 0.46699600E+01, -.23723200E+01, -.73948100E+01, -.77657700E+01, -.72772100E+01, 0.30188400E+01, 0.25744700E-01, 0.35871600E+01, -.14873800E+01, 0.56824700E+00, 0.67236100E+01, 0.17248800E+00, 0.67135500E+01, 0.42876500E+01, 0.10249400E+01, 0.41475100E+01, -.15782500E+01, 0.33154400E+00, -.12006600E+01, -.56295800E+00, -.17791200E+01, 0.75446700E+01, 0.33881300E+02, -.11622000E+02, 0.16532400E+02, -.47494200E+01, 0.57004300E+01, 0.52582200E+01, 0.36073700E+00, 0.34469700E+01, -.10033600E+02, 0.72602900E+01 },
            { -.12128400E+01, 0.82265100E-02, 0.45653800E+00, -.93912000E+00, -.60880000E+00, -.44333700E-01, 0.25670400E+00, 0.70465800E-01, -.19504600E+00, -.29302700E+00, -.72268600E+00, -.26187400E+00, -.10422200E+01, 0.21041800E+00, 0.17844800E+00, -.46207800E-01, 0.16174100E+00, -.20632500E+00, 0.34142700E+00, -.23210300E+00, 0.31607200E+00, 0.13966400E+00, 0.43183200E+00, 0.13482600E+00, 0.13388300E-01, 0.16982200E+00, 0.93832900E-02, -.10733000E+00, 0.24967700E-01, -.43669100E+00, -.50986900E+00, -.38573400E+00, 0.27692900E+00, 0.30283900E+00, -.38694300E-01, -.61876000E+00, -.62434600E+00, 0.24729300E+00, 0.36288000E+00, -.53172400E+00, -.16070000E+01, 0.10042400E+01, 0.82654500E+00, 0.13741600E+01, -.44334400E+00, -.37282900E-01, -.61408700E-01, -.13745900E+01, 0.20741900E+00, 0.68723900E+00, -.17844500E+00, 0.14089800E+01, -.12943900E+00, -.44810200E+00, 0.86898500E-01, 0.53760400E+00, -.88724400E+00, 0.64898300E-01, -.22697600E+00, -.18344400E+00, -.65428900E+00, 0.20603900E+00, 0.51767700E+00, -.44285100E-01, -.85820900E-01, -.51906900E+00, 0.52644900E+00, -.10000000E+01, -.33930500E+00, 0.16518200E+01, 0.44005100E+03, -.57399400E+02, 0.90802600E+03, -.45797700E+03, -.45869600E+03, -.86326400E+02, -.10293100E+03, -.20601900E+03, 0.48601900E+02, -.99166200E+01, -.29402600E+03, -.46984700E+01, -.28221900E+01, 0.25511400E+01, 0.71710200E+01, -.60046000E+01, 0.10346300E+02, 0.23939100E+02, 0.15954400E+02, -.20498700E+01, -.57471100E-01, -.11991400E+01, 0.62287100E-01, 0.91340700E-01, 0.15785600E+00, -.20893500E-01, 0.86024400E+00, -.69418700E+00, 0.22513700E+00, 0.13469800E+01, -.40818100E+01, -.56619800E+00, 0.26943500E+01, -.49060000E+01, 0.37168600E+01, 0.85881800E+01, 0.10562000E+02, -.39877900E+01, 0.42877100E+03, -.20457000E+03, -.22297800E+03, -.17190700E+03, -.50326200E+03, 0.23171400E+03, 0.81672400E+03, 0.10031300E+04, -.34296500E+03, 0.10129300E+04, -.48227400E+03, -.52185300E+03, -.14035000E+03, -.23627300E+03, -.10733100E+03, 0.57501900E+03, -.52296200E+02, -.21216100E+03, -.21535100E+04, 0.10277600E+04, 0.10814200E+04, -.39668500E+03, -.23135500E+03, 0.83369900E+03, 0.38989000E+03, 0.90612400E+03, -.11460900E+03, -.32834300E+03, 0.17340700E+03, 0.17660300E+03, 0.86034600E+02, 0.90283700E+02, 0.96927600E+02, 0.74095700E+02, 0.58369100E+02, 0.15720300E+03, -.10439500E+04, 0.47705400E+03, 0.53406600E+03, -.14967500E+03, -.11505300E+03, 0.39531200E+03, 0.73504900E+02, 0.62738600E+03, -.45798700E+02, -.10444400E+04, 0.53764500E+03, 0.53604500E+03, -.47476900E+02, 0.99334100E+02, 0.27416500E+03, 0.15999800E+02, 0.12486400E+03, 0.21270100E+03, 0.13811200E+03, -.83580000E+02, -.67403900E+02, 0.12316500E+03, 0.13258600E+02, -.70973700E+02, -.14152400E+03, 0.10583600E+03, -.27042000E+02, 0.18153800E+03, -.83115500E+02, -.97758700E+02, 0.16264900E+02, -.16904500E+03, 0.11861800E+03, 0.46569000E+03, 0.26911900E+03, -.10931100E+03, 0.72955500E+03, -.34444000E+03, -.35418900E+03, -.28708600E+03, 0.21791300E+02, -.32136600E+03, -.35131300E+03, -.72054000E+03, -.90807800E+02, -.59753200E+03, 0.28468700E+03, 0.29210200E+03, -.22679700E+02, -.11362500E+02, 0.26635600E+03, 0.30394900E+03, 0.49550900E+03, 0.10157100E+03, -.95892800E+02, 0.29379100E+02, 0.27992600E+02, 0.66372500E+02, -.18905000E+03, 0.28840500E+03, 0.67141000E+03, 0.89116000E+03, -.77484000E+02, 0.10072200E+03, -.52304400E+02, -.50600800E+02, -.11717600E+03, -.14075200E+03, 0.17465200E+02, 0.40262900E+02, 0.25812700E+02, -.85497100E+02, -.12582500E+03, 0.61095100E+02, 0.88036800E+02, 0.93931500E+02, -.45081300E+02, 0.46339400E+02, 0.28089200E+02, -.12248700E+02, 0.93364400E+02, 0.49573600E+00, 0.74050700E+02, -.26630600E+00, -.38252900E+00, 0.72973400E+02, -.68300800E+01, -.38094300E+02, 0.94322700E+02, 0.17504800E+03, -.16103000E+03, 0.88125500E+01, -.12774700E+00, -.36346800E+00, -.46490900E+03, 0.16499400E+03, -.16000400E+03, -.92393900E+02, -.17281100E+03, 0.49674800E+01, -.79456600E+02, -.13325800E+03, 0.21844600E+03, -.11453500E+03, 0.97831700E+03, 0.32286700E+02, 0.14973400E+03 },
            { 0.11414100E+01, -.51182900E-01, -.46054900E+00, -.35305400E-01, 0.66729800E+00, 0.13184000E+00, -.26502900E+00, 0.33015900E-01, 0.67854600E-02, -.64194200E-01, 0.47293600E+00, -.51909500E+00, -.81200500E+00, 0.25156400E+00, -.43061500E+00, 0.22288100E+00, -.21863600E+00, 0.11819600E+01, -.54543500E+00, 0.16617900E+00, 0.48246700E+00, -.76549600E+00, -.91545400E-01, -.17222600E+01, -.17958000E+00, 0.25405700E-01, -.23308300E+00, -.25302000E+00, -.79434500E-01, 0.18919300E+00, 0.60923900E+00, 0.75623600E+00, -.17417300E+00, 0.36556400E+00, 0.42732500E+00, 0.42820400E+00, 0.26711700E+00, -.10615500E+00, -.15431600E+00, 0.33148700E+00, 0.13124900E+01, -.45439100E+00, -.45644300E+00, -.11248300E+01, 0.14267500E+00, 0.13261400E+00, 0.21905500E+00, 0.62294000E+00, -.99150600E+00, -.38680400E+00, 0.40993800E+00, -.83384000E+00, 0.76857700E+00, 0.52141600E-01, 0.59189000E-01, -.47014700E-01, -.13501600E+01, -.21976000E-01, 0.23056200E+00, -.10477700E+00, -.20417400E+00, 0.30343100E+00, 0.23581900E+00, 0.88267000E-01, 0.11367700E-01, -.12438800E+00, -.88881400E-01, 0.45494300E+00, -.83516000E+00, 0.41154300E+01, 0.36879100E+00, 0.62380800E+02, -.82181200E+03, 0.40983600E+03, 0.41230600E+03, 0.81017200E+01, 0.82853000E+02, 0.19356800E+03, -.44687100E+02, 0.15055600E+03, 0.26348200E+03, 0.13109400E+01, -.10730700E+01, -.99167500E+00, -.49094200E+01, 0.53567200E+01, -.11190100E+01, 0.51890600E+01, -.48568700E+01, -.24437200E+00, 0.69118600E-01, -.13717400E+00, -.55398700E-01, 0.27695500E-01, 0.14186100E-01, -.26883500E-01, 0.16773600E+01, 0.87995600E-01, -.53109700E-01, -.11870200E+01, 0.31145100E+00, 0.46902500E+00, -.21461400E+01, 0.22558300E+01, 0.58132800E+00, 0.67052100E+01, -.26046200E+01, 0.24273500E+00, 0.15299000E+03, -.75936000E+02, -.72216200E+02, -.99054100E+02, -.61131500E+02, 0.87388100E+01, 0.86030500E+02, -.84926600E+00, -.12133800E+03, 0.12965700E+03, -.62782400E+02, -.50593700E+02, 0.40408300E+01, 0.13740600E+03, -.10428100E+03, -.17013800E+03, -.19164400E+03, -.27981700E+01, 0.38542300E+02, -.22151200E+02, -.22881100E+02, -.25703900E+02, -.74435900E+02, 0.51138500E+01, 0.45799600E+02, -.15220000E+02, 0.68257500E+02, 0.63436700E+03, -.31631900E+03, -.33352000E+03, 0.61356200E+02, 0.78296700E+02, -.23869800E+03, -.10353800E+03, -.22752600E+03, -.11447800E+02, 0.52474900E+03, -.26493700E+03, -.27173700E+03, 0.72528600E+02, 0.87745900E+02, -.16706600E+03, 0.85298500E+02, -.21231200E+03, 0.49702800E+02, 0.98947400E+03, -.49184400E+03, -.51144800E+03, 0.10033000E+03, -.59705300E+02, -.31729300E+03, -.13355700E+03, -.27534500E+03, -.14224000E+03, -.24209600E+03, 0.11846200E+03, 0.12059300E+03, -.69442600E+02, -.19666600E+02, 0.13366300E+03, 0.23581100E+03, 0.53005100E+02, -.60100000E+01, 0.18345700E+03, -.91671600E+02, -.88347900E+02, -.44715900E+02, 0.64816800E+02, -.66349500E+02, -.24680700E+01, -.16197200E+03, -.59242300E+02, -.14904700E+02, 0.96639100E+01, -.29786800E+01, 0.18366500E+03, -.11195900E+03, -.19197200E+02, -.63613200E+02, 0.62116100E+02, -.77424400E+01, 0.20384200E+03, -.10331200E+03, -.82083900E+02, -.27128500E+02, 0.15390000E+02, -.67637800E+02, -.15142500E+02, -.22031200E+02, -.73825200E+02, 0.33629400E+03, -.16901500E+03, -.15224700E+03, -.19165800E+03, 0.83143200E+02, -.11356400E+03, -.53767400E+02, -.11272700E+03, -.55737200E+02, 0.43461500E+03, -.21665400E+03, -.21741700E+03, 0.43503500E+02, -.10264600E+02, -.17482000E+03, -.92403500E+02, -.11424700E+03, -.26887900E+02, -.22563600E+03, 0.11268200E+03, 0.92132800E+02, -.21542700E+02, 0.35055700E+02, 0.78676500E+02, 0.18973600E+01, 0.23885400E+02, 0.12181600E+02, -.13289900E+01, -.45725200E-02, 0.18919800E+02, -.18245800E+01, 0.16619200E+02, -.11552800E+01, 0.73160500E+02, -.19352100E+01, -.89526000E+00, 0.91283200E+02, 0.41324700E+01, -.10145600E+01, 0.56940900E+01, 0.11118600E+02, -.11594500E+03, 0.99139700E+02, -.37545200E+03, -.82887400E+02, -.51475800E+02, 0.61088900E+02, 0.34429400E+02, 0.52998100E+02, 0.28596600E+01, -.10205200E+03, -.96305200E+02, -.21779500E+02 },
            { -.22291800E+01, 0.61744900E+00, 0.10011600E+01, -.34559000E+00, 0.24253500E-01, -.35904900E-01, 0.61926100E+00, 0.34829000E+00, -.13905500E+01, 0.70698400E+00, 0.18985900E+01, 0.25361100E+01, -.40588900E+00, -.65004200E+00, -.32549000E+00, -.94668100E-03, 0.20326300E+00, -.99256700E+00, -.53058800E+00, 0.60401200E+00, 0.52285700E+00, -.20780300E-01, -.15585600E+01, -.25915200E+00, 0.51941400E+00, -.50028700E-01, 0.26433900E+00, 0.36522800E+00, 0.55251700E-01, -.11088800E+00, 0.87107400E+00, 0.73149700E+00, 0.18215600E+00, 0.49757000E+00, -.84970200E-02, -.61198800E+00, 0.38039200E+00, -.15399300E+00, -.21418400E+00, -.11303400E+00, -.49020600E+00, -.66578300E+00, -.38327000E+00, -.29592500E+00, 0.16064800E-01, -.21624300E-01, 0.30318500E+00, 0.20734200E+01, 0.13960200E+01, -.73048600E+00, 0.40656100E+00, -.21839400E+01, -.25964400E+00, 0.57384000E+00, -.28312400E+00, -.70669100E+00, 0.33301500E+01, -.23361200E+00, -.19058000E+00, -.32193600E-01, -.50177500E+00, 0.15119300E+00, -.39303500E+00, -.18661400E+00, 0.15278600E+00, -.11878300E+00, 0.82920800E+00, 0.22420700E+00, 0.10625800E+01, -.68340100E+01, -.13255700E+01, 0.76680500E+00, 0.13781100E+04, -.68772500E+03, -.68804800E+03, 0.76970100E+02, -.91659600E+02, -.42632900E+03, -.10750300E+03, -.33517100E+03, -.45014400E+03, -.84977900E-01, -.41241200E+00, 0.58697800E+00, 0.35002400E+01, -.39536000E+01, -.55820400E+01, -.29353100E+02, -.28683000E+01, 0.85065100E+01, -.46778100E+00, 0.13438100E+00, 0.26431700E+00, 0.15936500E+00, 0.13469900E+00, -.54532500E-02, -.37926600E+01, -.57009800E-01, 0.24095000E+00, 0.10651300E+01, -.82159100E+00, -.26389800E+00, 0.50749500E+00, -.69362100E+00, -.34108400E+01, -.19373500E+02, -.11299700E+01, 0.48027500E+01, -.13378800E+03, 0.69501900E+02, 0.49741200E+02, 0.63108600E+02, 0.15982800E+03, -.14484600E+03, -.38453300E+03, -.21647800E+02, 0.22409700E+03, -.35980200E+03, 0.19136200E+03, 0.13422000E+03, -.44408700E+02, -.14231200E+03, 0.11805800E+03, 0.34226400E+02, 0.31937500E+03, 0.43912700E+02, 0.28666800E+03, -.17304200E+03, -.13354600E+03, 0.13208000E+03, -.11232700E+00, -.14922400E+03, -.17226500E+03, -.19296400E+03, -.73738700E+01, -.12845500E+03, 0.10746300E+03, 0.12004700E+03, -.27933800E+03, -.10371500E+03, 0.98257200E+02, 0.10240100E+02, 0.17119600E+02, -.95220400E+02, -.27214400E+03, 0.12670400E+03, 0.16331600E+03, -.34813300E+02, -.12581200E+03, 0.49688200E+02, -.18981300E+03, 0.13904400E+02, 0.55973000E+02, -.17460100E+04, 0.86866000E+03, 0.90782600E+03, -.35767500E+03, 0.27858400E+02, 0.69460500E+03, 0.53049700E+03, 0.67094600E+03, 0.11556000E+03, 0.19119900E+03, -.97378100E+02, -.10729300E+03, 0.63030800E+02, 0.70836500E+02, -.17330100E+03, -.42571000E+03, -.12395000E+03, 0.14163100E+03, -.18335100E+03, 0.95099900E+02, 0.86670200E+02, 0.14596500E+02, -.65948600E+01, -.15572900E+02, -.19588300E+03, 0.79633200E+02, 0.11020600E+03, -.66578500E+03, 0.33437000E+03, 0.36465200E+03, -.75577100E+02, 0.37332100E+03, 0.19098800E+03, 0.22538000E+03, 0.15232700E+03, 0.15999800E+03, 0.27435400E+03, -.13692200E+03, -.17203000E+03, 0.10489500E+03, -.98651200E+02, -.11859500E+03, -.17165000E+03, -.11807900E+03, 0.18238800E+03, -.69493200E+03, 0.34345900E+03, 0.29094100E+03, 0.19708700E+03, -.16690900E+03, 0.14247800E+03, -.21004300E+03, 0.30560300E+03, 0.13577300E+03, -.40799200E+03, 0.20249700E+03, 0.20566200E+03, -.55816900E+02, 0.72132100E+02, 0.15449700E+03, 0.12162900E+03, 0.14223900E+03, 0.24037100E+02, 0.51882400E+03, -.26017200E+03, -.20625600E+03, -.70359000E+02, -.80192700E+02, -.18651300E+03, -.99671500E+02, -.19816300E+03, -.11143300E+03, 0.62575100E+01, -.11352300E+03, -.50534900E+01, 0.42178900E+01, 0.18542700E+02, 0.38450100E+01, 0.19120300E+02, -.10776100E+03, 0.28031300E+02, -.61184400E+02, -.15389800E+02, 0.22785100E+01, -.11460500E+02, 0.22723600E+02, 0.52306300E+02, 0.18452000E+02, 0.10362000E+04, 0.34312200E+02, 0.14623300E+03, -.97806700E+02, 0.59103700E+02, -.21344100E+03, -.22001100E+02, -.16464500E+03, 0.26571800E+02, -.97349800E+01 },
            { -.33730700E+01, -.36616300E+00, 0.10289100E+01, -.11919600E+00, 0.84194000E+00, -.11548000E+00, 0.76928700E+00, 0.19529900E+00, -.10633400E+00, 0.23467100E+00, -.21399400E+01, 0.19378300E-01, 0.14597400E+01, 0.91922100E-01, 0.13522400E+01, -.56892000E+00, 0.63358200E+00, -.11598200E+01, -.61995800E+00, 0.74026100E-01, 0.62149800E+00, 0.19312000E+01, -.19922200E+00, -.25097300E+01, 0.42716400E+00, 0.34502700E+00, 0.30284800E+00, -.42116000E+00, -.43811300E+00, -.68741800E+00, -.29362300E+00, -.83314600E+00, 0.14318500E+01, 0.35576900E+00, -.55455100E+00, -.17453400E+01, -.41138600E+00, 0.15561600E+00, 0.23748900E+00, -.20392400E+01, -.22202400E+01, 0.92513800E+00, 0.91513000E+00, 0.72257200E+00, -.93319800E+00, -.20521000E+00, 0.75046000E+00, -.22890200E+01, 0.24545300E+01, -.35240800E+00, -.13092800E+00, 0.26770100E-01, 0.59930400E+00, -.29269500E+00, 0.92348900E-01, 0.15817700E-01, -.12399500E+01, -.13168300E+00, 0.59711200E+00, -.10842200E-01, -.28912600E+00, 0.69457000E+00, 0.84811600E+00, 0.51113400E+00, -.12237900E+01, -.69329800E+00, 0.19015000E+00, -.70170000E+00, -.48048900E+00, 0.29945500E+01, 0.63285800E+00, -.57881200E+00, -.56413700E+00, -.13778500E+02, -.11164100E+01, 0.32846000E+03, 0.22519500E+03, -.22100600E+03, -.39883500E+03, -.45044600E+03, 0.29438700E+03, 0.10263900E+01, -.13393700E+02, -.98847000E+00, 0.43497700E+00, 0.24659200E+01, -.18833400E+00, 0.99823200E+00, 0.50377800E-01, 0.35313000E-01, 0.90758300E-01, -.30730400E+01, -.53967400E-01, 0.46584000E-01, 0.87922900E-01, -.32556000E-01, -.95856700E-01, 0.80005800E-02, 0.74502000E-01, 0.34153600E+00, -.86326700E+01, -.28149500E+00, -.34108500E+00, -.11725900E+00, -.21526100E-01, 0.20630000E+01, -.16230800E+00, -.10747500E+01, -.73069300E+02, 0.64309500E+02, 0.31345100E+02, -.48516300E+02, -.51294200E+02, 0.98493500E+02, 0.11400400E+03, 0.92389700E+02, 0.53324800E+02, 0.41308800E+02, 0.46595100E+02, -.20069900E+02, 0.22547000E+03, 0.15912200E+03, -.62187000E+02, -.51541700E+02, -.23108600E+03, 0.16275200E+03, -.29458700E+03, 0.14906300E+02, 0.14665800E+03, -.18034500E+03, 0.38712500E+01, -.19305600E+02, -.31326800E+03, -.13102800E+03, 0.45808100E+02, -.22732200E+03, 0.12209100E+03, 0.11754300E+03, 0.22647500E+02, -.10833500E+03, 0.13140900E+03, 0.95494600E+02, 0.16926100E+03, -.63910000E+02, -.49972900E+03, 0.10627300E+03, 0.24980100E+03, -.25352600E+03, -.45893400E+02, 0.16333800E+03, 0.61028400E+02, 0.93992900E+02, -.41650400E+02, 0.39839700E+03, -.14590700E+03, -.21700900E+03, -.18451500E+03, -.16912400E+03, -.32181000E+02, 0.99055000E+02, 0.18641300E+03, -.16985900E+03, -.11746500E+03, 0.10514700E+02, 0.47506900E+02, -.59177700E+02, -.65601400E+02, 0.61708000E+02, 0.10903700E+03, 0.57485500E+02, -.86598800E+02, 0.43473200E+03, -.19864100E+03, -.21703500E+03, 0.16874800E+03, 0.12576500E+02, -.11173000E+03, 0.13984900E+03, -.25076000E+02, 0.24656400E+02, -.25306500E+03, 0.18513900E+03, 0.12638200E+03, 0.17271600E+03, 0.23606200E+02, 0.18522600E+02, -.40517200E+02, 0.17813200E+02, 0.58451000E+02, -.47093900E+03, 0.20118000E+03, 0.26746000E+03, -.67679200E+02, 0.24515000E+02, 0.19719100E+03, 0.54981800E+02, 0.28753500E+03, 0.92622100E+00, -.91776600E+02, 0.41711000E+01, 0.41995800E+02, -.92296100E+02, 0.12911500E+03, 0.10041800E+01, -.10563900E+03, 0.74440000E+02, 0.10312400E+03, 0.58693000E+03, -.29403100E+03, -.29251600E+03, -.28901900E+02, 0.82713900E+01, -.22338200E+03, -.11884100E+03, -.27213200E+03, -.38903900E+02, -.33779700E+03, 0.16628700E+03, 0.16803200E+03, 0.13185000E+02, 0.67906300E+02, 0.84241400E+02, -.10822300E+03, 0.56688000E+02, 0.47668300E+02, -.19825100E+01, -.14389800E+02, 0.13740400E+02, -.26413700E+00, 0.35472400E+02, -.36298100E+01, 0.10743500E+03, -.20527300E+02, 0.22009400E+01, 0.74055500E+02, -.45716400E+01, 0.71552300E-01, -.34128600E+01, -.49034800E+02, 0.17745900E+03, -.33938100E+03, -.71750100E+02, 0.47739800E+03, 0.10772000E+03, 0.57797700E+01, -.99420700E+02, 0.11841300E+02, -.27921000E+02, -.35124400E+02, -.17873700E+03, -.19643000E+02 },
            { -.42390900E+00, 0.77048300E-01, 0.31577600E+00, -.10131100E+00, 0.26577100E+00, 0.63812200E-01, 0.23335900E+00, -.77526600E-02, -.19542200E+00, 0.85202700E-01, 0.15166900E+00, 0.52874500E+00, 0.20246000E-01, -.11592900E+00, 0.11930400E+00, -.11704800E+00, 0.18345300E+00, -.39521100E-01, -.30525600E+00, -.50348600E-01, 0.28543100E+00, 0.82973800E-01, 0.73279300E-01, -.21945300E+00, 0.85086200E-01, 0.10831700E+00, -.28018000E-01, -.15145300E-01, -.14577800E-01, -.17309000E+00, 0.62692400E-01, 0.11786000E+00, 0.99883000E-02, 0.62946200E-01, 0.64801000E-02, -.47597300E-01, -.43238800E-01, 0.16131000E-01, -.18004200E+00, 0.54174000E-01, -.24795800E+00, 0.30621500E-01, -.44551100E-02, 0.17050200E+00, 0.40160900E-01, -.38088600E-02, -.26616900E+00, 0.18891300E+00, -.30196000E+00, 0.31442100E+00, 0.14444800E+00, 0.46144100E+00, 0.19386300E+00, -.21625600E+00, -.42656300E-01, 0.48108400E-01, 0.11308900E+01, 0.43977400E-01, -.34295700E+00, 0.22105700E+00, 0.11723000E+00, -.17697900E+00, 0.26293000E-01, 0.74947500E-01, -.98766800E-01, -.22983200E-02, 0.30933300E+00, -.50241300E+00, 0.41863300E+00, -.16139800E+01, 0.22267800E+00, -.47486700E+00, -.27695700E-01, 0.24162500E-01, -.41530300E+02, 0.71742300E+02, -.16669600E+02, 0.12698000E+02, 0.23440900E+02, 0.67058800E+02, 0.29370200E+02, 0.42004500E+00, 0.85820600E+00, -.55425100E+01, 0.51365400E+00, 0.92916600E+00, -.23142400E+01, -.70746200E+01, -.28801000E+01, 0.16905900E+01, -.10856200E+00, 0.30947400E+00, -.13206300E+01, 0.12522400E-01, 0.16289400E-01, 0.26587500E-02, -.31299900E+00, 0.29002200E-01, 0.23173800E-01, -.49689400E+00, 0.95957100E+00, -.30099000E+01, -.35671600E+00, 0.39497600E+00, -.78794900E+00, -.28184800E+01, -.10812800E+01, 0.81750000E+00, -.81215800E+02, 0.38716900E+02, 0.25343100E+02, 0.40964700E+02, 0.19550300E+02, -.12253800E+02, -.13582000E+03, -.29521900E+02, 0.23115100E+02, -.49112700E+02, 0.18881700E+02, 0.20302500E+02, -.35018700E+01, -.51640700E+02, 0.29700000E+02, -.34225800E+02, 0.79260700E+02, -.34612900E+02, 0.78366600E+02, -.26004900E+02, -.40262500E+02, -.13674600E+02, 0.81295900E+02, -.15327400E+02, 0.37514500E+02, -.32335200E+02, 0.16711400E+02, -.13818900E+03, 0.55382800E+02, 0.50302100E+02, 0.62958100E+01, -.60833200E+02, 0.68393000E+02, 0.25880600E+02, 0.95430200E+02, -.51899200E+02, -.16737700E+03, 0.88882400E+02, 0.82226400E+02, -.23864000E+02, 0.35486900E+02, 0.66056900E+02, 0.56972200E+02, 0.38588300E+02, 0.15516300E+01, 0.63025500E+02, -.32217100E+02, -.16504600E+02, -.15266100E+02, 0.23136600E+02, -.36641300E+02, -.30085500E+02, -.86944100E+02, -.10181800E+02, -.79041800E+02, 0.41598500E+02, 0.30914100E+02, -.33688900E+02, -.55165200E+01, 0.10523100E+02, -.25928800E+02, -.11940600E+02, 0.14550900E+02, -.11157400E+03, 0.53268700E+02, 0.53382000E+02, -.14487200E+02, -.14330400E+02, 0.19955000E+02, -.52019900E+02, 0.14190400E+02, 0.18387500E+02, -.21773500E+03, 0.10520300E+03, 0.11716900E+03, 0.42743000E+02, 0.11445900E+02, 0.10126800E+03, 0.15444100E+03, 0.15418400E+03, 0.88701300E+01, 0.14388600E+03, -.68554300E+02, -.67562000E+02, -.26292000E+02, -.19633300E+02, -.30394300E+02, -.25433800E+02, -.48792900E+02, -.57966900E+02, -.16995000E+03, 0.89593600E+02, 0.44904600E+02, 0.49589800E+02, 0.56738800E+02, -.14864000E+02, -.21037300E+03, -.62835400E+02, 0.73127500E+02, 0.82090600E+02, -.40776000E+02, -.47723500E+02, 0.31369900E+02, 0.27962200E+02, -.12976700E+02, 0.55082600E+02, 0.28095300E+02, -.10636500E+02, -.10038100E+03, 0.50112500E+02, 0.56599900E+02, 0.33631800E+01, 0.63626800E+01, 0.32275900E+02, -.12712400E+02, 0.98774100E+01, 0.94704300E+01, 0.13509000E+01, -.18461500E+02, 0.76722900E+01, -.39730700E+00, -.12784600E+02, 0.13117900E+01, 0.15792200E+02, -.17301400E+02, 0.38394200E+01, 0.66513200E+02, -.39209400E+01, -.14045900E+00, -.17874500E+01, 0.35832100E+02, -.67993000E+01, -.47344700E+01, -.15061700E+03, 0.55723000E+02, 0.88324200E+02, -.17365400E+01, 0.26217700E+02, -.88973700E+02, 0.29763200E+02, -.19585600E+03, 0.24532800E+02, -.19973000E+02 },
            { 0.32859000E+00, 0.12569500E+00, 0.45286100E-01, -.67716100E+00, -.10300800E+01, -.20471200E+00, -.37517100E+00, 0.11877200E+00, 0.33354300E+00, -.24640400E+00, -.39432800E+00, -.95531700E-01, -.17932200E+00, 0.75541600E-01, -.13395600E+00, 0.15620100E+00, -.42597700E+00, -.25858500E+00, 0.15405500E+01, -.33358500E+00, -.13883700E+01, -.91944900E-01, -.16875600E-01, 0.86194600E+00, -.51608600E+00, -.97084100E-01, 0.14617700E+00, -.19343600E-01, 0.26113000E+00, -.14067000E-01, 0.17401000E+00, -.16223800E+00, -.22379000E+00, -.22658900E+00, -.53226200E-01, -.17506900E+00, -.39108100E+00, 0.15601600E+00, 0.21776200E+00, -.16776800E+01, -.19566800E+01, 0.62618700E+00, 0.14262400E+00, 0.10041800E+01, -.10164400E+00, -.36931700E+00, -.41564400E-01, -.27042200E+00, 0.15135000E+00, 0.33605000E+00, 0.68290600E+00, 0.32337500E+00, 0.31899800E-01, -.36265500E+00, -.11128100E+00, 0.17722900E+00, 0.10454500E+00, -.13058200E+00, -.48696100E+00, 0.53539600E-01, -.13324800E+00, 0.28423300E-02, -.56070100E+00, -.18042200E+00, 0.36433900E+00, -.39497200E+00, -.63493600E+00, -.48576600E+00, 0.30027300E-01, -.12475200E+01, -.14884100E+00, -.47914800E+00, -.59988800E-01, -.77882700E-02, 0.12942500E+00, -.28623600E+03, -.13339200E+03, 0.10913300E+03, 0.12932600E+03, 0.14682300E+03, -.94438300E+02, 0.15840300E+01, -.14037400E+01, -.51764700E+00, -.34650700E+01, 0.32105100E+01, -.16574000E+01, 0.82232700E+00, -.96982100E+00, -.86002100E+00, 0.47458600E-01, -.16186800E+00, 0.16319300E+00, -.38570200E-01, 0.18732300E-01, -.36152000E-01, 0.18069200E+00, -.12143600E+00, -.22752800E-01, 0.20573900E+00, -.50613700E+00, 0.13704200E+00, -.44926100E+00, 0.60675600E+00, 0.20933800E+00, 0.20533500E+01, 0.12995100E+01, -.10935300E+01, 0.62500900E+02, -.29566100E+02, -.18765900E+02, -.25536800E+02, -.21250300E+02, 0.70291900E+00, 0.13075700E+03, 0.79702300E+02, -.47076300E+02, 0.28768500E+03, -.13757600E+03, -.12289000E+03, -.73756400E+02, 0.79638700E+02, -.10993800E+03, 0.13868700E+02, -.90337900E+02, 0.51390800E+01, -.73827900E+02, 0.25299500E+02, 0.33808200E+02, 0.98915600E+02, -.17889800E+03, 0.51606800E+02, 0.72969200E+01, 0.11980200E+03, -.38073400E+02, 0.29231600E+03, -.13290400E+03, -.16696100E+03, 0.76095100E+02, 0.17935000E+03, -.16514400E+03, -.44780700E+02, -.19591500E+03, 0.10320600E+03, 0.58112200E+03, -.29556500E+03, -.29888300E+03, 0.14723700E+03, -.53206000E+02, -.16857500E+03, -.22518000E+02, -.85127900E+02, -.44909700E+02, -.60484800E+02, 0.31856400E+02, -.27771400E+00, 0.28401100E+03, 0.13127500E+03, -.87502600E+02, -.11835100E+03, -.12138100E+03, 0.11506000E+03, 0.93911600E+01, -.72687100E+01, -.81731800E+01, 0.28317300E+02, -.16545300E+02, 0.33859200E+02, 0.73308900E+02, 0.67870900E+02, -.34166700E+02, 0.98888900E+02, -.47480100E+02, -.51254900E+02, -.35530000E+01, 0.83436000E+02, -.67958900E+02, -.15859300E+02, -.68248700E+02, 0.24043600E+02, 0.22560700E+03, -.10980100E+03, -.12560500E+03, -.69625900E+01, -.80848400E+02, -.78862700E+02, -.14110500E+02, -.13305300E+03, -.32790100E+02, -.46835900E+02, 0.22326800E+02, 0.54062300E+02, -.37831200E+02, 0.14536200E+02, 0.29355200E+02, 0.56241100E+02, 0.51166300E+02, -.39828000E+02, 0.20084200E+03, -.10269600E+03, -.64723700E+02, -.10125900E+03, 0.25675500E+02, -.43262800E+02, 0.70901000E+02, 0.16037000E+02, -.60831300E+02, -.24611400E+02, 0.12171900E+02, 0.11827300E+02, 0.32085800E+01, -.57686000E+02, 0.26305600E+02, 0.45942100E+02, 0.37214600E+02, -.21125500E+02, 0.10458500E+03, -.52484900E+02, -.66478300E+02, 0.36009000E+02, -.78218700E+01, -.48043800E+02, -.91907800E+01, -.79732500E+02, 0.25843900E+02, -.70546200E+00, 0.21069500E+02, -.25679100E+01, -.50742100E-01, 0.12250100E+01, -.37719700E+00, -.21578400E+02, 0.24204200E+02, 0.33924000E+01, -.69326400E+02, -.95822700E-01, -.15985300E-01, 0.90760600E+00, -.54490100E+02, -.68106300E+02, 0.12406200E+03, -.10461000E+03, -.31505100E+03, -.20999100E+03, 0.46120500E+00, -.10130000E+02, 0.57971900E+02, -.73695700E+01, 0.66368600E+02, 0.34421600E+02, 0.70106100E+01 },
            { 0.20500800E+01, -.64373100E+00, -.13045300E+01, 0.40398800E+00, -.36393600E+01, -.27477700E+00, -.82171200E+00, -.51449600E-01, 0.24893700E+00, -.55702400E+00, 0.13407900E+01, -.62142100E+00, -.11307600E+01, 0.51929800E-01, -.22268800E+00, 0.40040000E+00, -.96979200E+00, 0.36323100E+00, -.22400900E+00, 0.82646200E+00, -.86219300E+00, 0.11326000E+01, -.75849900E+00, 0.39157800E+01, -.18697200E-01, -.73100300E+00, -.14359400E+00, 0.71687300E+00, -.38308500E+00, -.11874400E+00, -.51955000E+00, 0.38852100E+00, -.35839500E+00, 0.70791200E+00, 0.35508100E-01, 0.39168100E+01, 0.21955300E+00, -.89752400E-01, -.11476000E+00, 0.25502100E+01, 0.53889300E+00, -.37586100E+00, -.29795600E+00, -.21787700E+00, -.21880200E+00, -.11741800E+01, 0.65233200E+00, -.44825200E+01, -.17929500E+00, -.69548500E+00, 0.27616400E+01, -.56374200E+00, -.10075800E+01, -.15932800E+00, 0.51185300E+00, -.21047000E+01, 0.10363300E+01, 0.14477500E-01, 0.27298200E+00, -.12397000E+01, 0.25415700E+00, -.91339400E+00, 0.11579000E+01, 0.42490400E+00, 0.73267400E+00, -.11695300E+01, -.10730000E+01, -.71638000E+00, -.43670800E-01, 0.33659500E+00, 0.70001400E-01, -.25140400E+00, 0.68166700E+00, -.87710400E-01, 0.52032100E-01, 0.15826300E+00, 0.20763500E+03, -.12889900E+03, -.84772800E+02, -.24013500E+03, 0.59898300E+03, -.50821800E+01, 0.35169700E+01, 0.39784400E+01, 0.27559900E+01, -.40873400E+01, 0.18038200E+02, 0.42685400E+02, 0.18608700E+02, -.19810800E+02, 0.83282100E+00, -.20375000E+00, -.34277300E+00, -.48311600E+00, -.42232200E+00, 0.20400300E+00, 0.34488800E+01, 0.33861400E+00, -.69969900E+00, -.90515800E+00, 0.10684200E+01, 0.70161800E+00, 0.53217700E+01, -.43754000E+01, 0.80464100E+01, 0.21719000E+02, 0.83217500E+01, -.10325300E+02, 0.13986600E+03, -.74237500E+02, -.22384700E+02, 0.13022800E+02, -.26382300E+03, 0.25458000E+03, 0.64823400E+03, 0.19223100E+03, -.42264100E+03, 0.37622900E+03, -.20412000E+03, -.16107100E+03, -.55662600E+02, 0.81166500E+02, -.25636800E+02, 0.22939300E+03, -.17166000E+03, -.31642100E+03, -.21859900E+04, 0.11261900E+04, 0.10894400E+04, -.45760200E+03, 0.14162600E+03, 0.10904600E+04, 0.12627700E+04, 0.12643800E+04, -.31321300E+03, -.12482300E+04, 0.56483900E+03, 0.59183100E+03, 0.30111200E+03, 0.24866300E+02, 0.38822200E+03, 0.26275600E+03, 0.49822100E+03, 0.23831000E+03, -.16937000E+04, 0.84856200E+03, 0.83574300E+03, -.31948400E+03, -.52503300E+02, 0.86780100E+03, 0.96824800E+03, 0.10449800E+04, -.29459100E+03, 0.58051100E+03, -.28762200E+03, -.28484900E+03, 0.24218700E+03, -.18392300E+03, -.21316400E+03, -.35801300E+03, -.19025500E+03, -.78928500E+02, -.51584000E+02, 0.30454600E+02, 0.41457700E+02, 0.15907200E+03, -.12840400E+03, 0.15918300E+03, 0.36822800E+03, 0.23663100E+03, -.18984600E+03, 0.15187300E+03, -.80729500E+02, -.75418000E+02, -.68918200E+02, -.90985700E+02, 0.13780000E+03, 0.18435000E+03, 0.11076900E+02, -.35559600E+03, 0.13937600E+04, -.70023300E+03, -.71017900E+03, -.36467100E+03, -.52899000E+03, -.35763800E+03, -.52687600E+03, -.32719500E+03, -.29709300E+03, -.22999100E+03, 0.11474000E+03, 0.36756700E+02, -.12718100E+03, -.13552600E+02, 0.17630900E+03, 0.34974400E+03, 0.17983100E+03, -.35610000E+03, 0.98007100E+03, -.48262200E+03, -.42174800E+03, -.37924300E+02, -.10946500E+01, -.57999600E+02, 0.70271800E+03, -.11057400E+03, -.38436600E+03, -.34448000E+03, 0.17317300E+03, 0.17068200E+03, 0.15377600E+02, -.73302800E+02, 0.97616500E+02, -.17077800E+03, 0.91204700E+02, 0.11042200E+03, -.67372000E+03, 0.33844200E+03, 0.32164200E+03, 0.14150100E+03, 0.76418000E+02, 0.30847600E+03, 0.35904700E+03, 0.34697500E+03, 0.15833900E+03, -.97655300E+01, 0.23497300E+03, -.21231500E+02, -.43610400E+01, -.85941800E+02, -.49784900E+01, -.28651100E+03, 0.22529400E+03, -.19337800E+02, -.33782000E+03, 0.21545300E+02, -.22916200E+01, 0.10094000E+02, -.11604400E+03, -.33924200E+01, 0.15258700E+02, -.62695900E+03, -.34130800E+03, -.45373500E+03, 0.14530800E+02, -.34691100E+01, 0.34288800E+03, 0.68073600E+02, 0.65722200E+03, 0.20056400E+03, 0.96300900E+02 },
            { -.33925100E+00, -.46948900E-01, 0.35590800E-01, 0.95500100E+00, 0.14719700E+01, 0.40742400E-01, 0.25207000E+00, -.45612800E+00, -.43019900E+00, 0.47864000E+00, 0.96092300E+00, 0.90809200E+00, 0.10469400E+00, 0.67440200E-01, -.37828000E+00, -.11174200E+00, 0.48058800E+00, 0.31951200E+00, -.12314900E+01, 0.51016400E+00, 0.15221800E+01, 0.33871500E+00, -.28296500E+00, -.13359900E+00, 0.27749700E+00, 0.23089000E-01, -.31820400E+00, -.10277000E+00, -.71519100E-01, -.22615400E+00, -.30150700E+00, 0.27834800E+00, 0.30668000E+00, 0.71741400E+00, 0.27676400E+00, -.30566400E+00, 0.35059100E+00, -.13745700E+00, -.18906200E+00, 0.13886700E+01, 0.19396000E+01, -.58803100E+00, -.33455400E+00, -.75441200E+00, 0.14680300E+00, 0.59814100E+00, -.13199100E+00, 0.17630800E+01, 0.67860500E+00, -.12885700E+00, -.17500900E+01, -.58475800E+00, 0.35009500E+00, 0.30571900E+00, 0.15287600E+00, -.17824000E+00, 0.18584400E+01, -.51090500E-01, -.14909200E+00, 0.47493900E+00, 0.17446000E+00, -.23848700E+00, -.13807300E+00, 0.18607800E+00, 0.63818000E-01, 0.27044300E+00, -.66426500E-01, 0.80971800E+00, 0.85061000E+00, -.41399000E+01, -.40760600E+00, 0.55896000E+00, 0.13901800E+00, -.34641000E+00, -.49620100E-01, -.21880100E+00, 0.37120100E+00, -.85185000E+02, -.35081000E+03, -.65201900E+02, -.27070300E+03, 0.34245900E+01, -.21499300E+01, -.20406500E+01, -.82121500E+01, 0.63126600E+01, -.14472000E+02, -.39607800E+02, -.19624600E+02, 0.18890000E+02, -.47835400E+00, 0.17418600E+00, 0.19502400E+00, 0.20531900E+00, 0.13761000E+00, -.47786800E-01, -.35768000E+01, 0.15726600E+00, 0.30820700E+00, -.64842000E+00, 0.82998200E-01, 0.25990500E+00, -.49901200E+01, 0.57286000E+01, -.63890900E+01, -.19628600E+02, -.10607200E+02, 0.10999500E+02, 0.66464700E+03, -.32738900E+03, -.35097900E+03, -.27027700E+02, 0.29989200E+03, -.48717900E+03, -.61222500E+03, -.56509500E+03, 0.30577700E+03, -.49531500E+03, 0.26204500E+03, 0.22730300E+03, 0.92150500E+02, 0.13382200E+03, -.34640400E+02, -.44878200E+03, -.12488400E+03, 0.41270600E+03, 0.27719000E+04, -.14157500E+04, -.13821000E+04, 0.61743000E+03, -.11866600E+02, -.12867800E+04, -.12078600E+04, -.13700000E+04, 0.19605300E+03, 0.55704800E+03, -.23589200E+03, -.25288300E+03, -.26923000E+03, -.67654800E+02, -.13952100E+03, -.35577500E+02, -.20397000E+03, -.20416100E+03, 0.18062500E+04, -.91591900E+03, -.89270100E+03, 0.29198600E+03, -.71471800E+02, -.80657500E+03, -.66279900E+03, -.90413700E+03, 0.64103200E+02, -.33513100E+03, 0.16825200E+03, 0.18098600E+03, -.16032400E+03, -.21780300E+02, 0.29627200E+03, 0.61143400E+03, 0.36729300E+03, -.90853100E+02, 0.10907800E+02, -.10655000E+02, -.11083000E+02, -.89812900E+02, 0.11791000E+03, -.99289900E+02, -.19114500E+03, -.21518100E+03, 0.18302000E+03, -.15912200E+03, 0.83430900E+02, 0.77991000E+02, 0.29404000E+02, 0.16070600E+03, -.12463900E+03, -.25802000E+03, -.17150900E+03, 0.36634400E+03, -.12909000E+04, 0.64989500E+03, 0.65824800E+03, 0.31344200E+03, 0.34068900E+03, 0.40706600E+03, 0.38832100E+03, 0.52246800E+03, 0.15857700E+03, 0.32008300E+03, -.15863300E+03, -.15285200E+03, 0.10093600E+03, -.54537200E+02, -.16274700E+03, -.22877600E+03, -.23385900E+03, 0.19639700E+03, 0.57893800E+02, -.31160800E+02, -.64581900E+02, -.74458800E+02, -.30625400E+02, -.22450100E+03, -.50291500E+03, -.24968700E+03, 0.23086000E+03, 0.68213500E+02, -.33829000E+02, -.33440400E+02, 0.22612200E+02, 0.13498000E+03, -.42061400E+02, 0.44392400E+02, -.58200800E+02, -.31189500E+02, 0.60882500E+03, -.30481100E+03, -.28449600E+03, -.14875900E+03, -.99241800E+01, -.25988200E+03, -.26406000E+03, -.22472700E+03, -.16458500E+03, 0.57536100E+01, -.15741300E+03, 0.31131100E+01, 0.38448700E+01, 0.61983300E+02, 0.66237900E+01, 0.10590900E+03, -.15968900E+03, -.32049100E+00, 0.23378000E+03, -.20282900E+02, 0.20801700E+01, -.84953600E+01, 0.18586500E+03, -.16935500E+03, 0.88525700E+02, 0.87471600E+03, 0.18734100E+03, 0.14716900E+03, 0.13638200E+02, -.51753400E+01, -.36637000E+03, -.99769100E+01, -.69168100E+03, -.54140900E+02, -.99724700E+02 },
            { 0.56090300E+00, 0.26413500E-01, -.18167000E+00, -.26210700E+00, -.14521000E+01, -.12949900E+00, -.23574700E+00, 0.92809800E-01, 0.57624300E+00, -.16071500E+00, 0.13098500E+00, 0.10414300E+00, -.22527500E-01, 0.96198700E-01, 0.64091100E-01, 0.11612100E+00, -.40501600E+00, -.20508000E-01, 0.92531600E-01, 0.87712200E-01, -.15113600E+00, -.42128200E-01, -.75667300E+00, -.14220700E+00, 0.29908400E+00, -.93724800E-01, 0.31558700E+00, 0.14689500E+00, 0.57971900E-01, 0.17601200E+00, 0.13034000E+00, -.24126300E+00, 0.88442400E-02, -.24952300E-01, 0.98661600E-01, 0.90565900E+00, -.38529800E-01, 0.12581100E-01, 0.21224000E-01, -.62984600E+00, 0.97581300E+00, 0.10274800E+00, -.14452900E-01, 0.39322300E+00, 0.24451400E+00, 0.22574400E+00, 0.30780800E+00, 0.80777700E+00, 0.74779900E+00, 0.19175400E+00, -.13898800E+01, 0.42783900E+00, -.59776100E+00, 0.25912400E+00, -.45238900E-01, 0.41102400E+00, -.45157700E-01, -.52602200E-01, -.54367400E-01, -.19216600E+00, -.21357100E+00, 0.44219300E+00, -.56372200E+00, -.26913400E+00, -.96582300E-01, 0.69093800E+00, 0.45438600E+00, 0.23825700E+00, 0.23565500E+00, 0.31849900E+01, -.58687000E+00, -.44882600E+00, 0.10990000E+00, 0.45790500E-01, -.36785200E-01, 0.73967000E-01, 0.80053200E-01, 0.33553300E+00, 0.11386100E+03, 0.10229400E+03, 0.87231800E+02, 0.13733800E+00, 0.68796300E+00, -.86072400E+00, 0.33729000E+01, 0.65812600E+00, 0.22223300E+01, 0.22015700E+02, 0.20801500E+01, -.26580200E+01, -.95391800E-01, 0.22460000E+00, -.32718500E-01, 0.32925600E-01, 0.50671000E-01, 0.22176300E-01, 0.40753200E+01, -.92045700E-01, 0.25865100E-01, -.28715300E+00, 0.63425300E+00, -.55856300E-01, 0.80466100E+00, -.74314500E+00, 0.17225100E+01, 0.14254200E+02, 0.21815500E+01, -.26285100E+01, -.55701100E+03, 0.27535500E+03, 0.25961700E+03, -.10466200E+02, -.14109700E+03, 0.25842200E+03, 0.18625500E+03, 0.30748100E+03, -.10673300E+03, 0.26286600E+02, -.19461500E+02, -.20209100E+02, -.14096000E+03, -.16786000E+03, 0.11215600E+03, 0.29096500E+03, 0.23804800E+03, -.21471800E+03, -.87716200E+03, 0.44970100E+03, 0.43829800E+03, -.25041200E+03, 0.62495800E+02, 0.44859100E+03, 0.44202100E+03, 0.44683400E+03, -.33683100E+01, -.44742900E+02, 0.10156100E+02, 0.25796800E+02, 0.82211600E+01, -.26330900E+03, 0.15683200E+03, 0.33195800E+03, 0.26508000E+03, -.15603200E+03, -.84840000E+03, 0.42660700E+03, 0.42549700E+03, -.65330000E+02, -.12398300E+02, 0.37476400E+03, 0.24672700E+03, 0.37689100E+03, -.12491200E+02, -.93441700E+02, 0.46993000E+02, 0.38462700E+02, 0.18685700E+02, 0.49598100E+01, -.74599800E+01, -.15831700E+03, -.12972000E+03, 0.25974500E+02, -.39502300E+02, 0.21179800E+02, 0.14359400E+02, 0.26481900E+02, -.13379200E+02, 0.27480600E+02, 0.10269100E+03, 0.29520200E+02, -.40642100E+02, -.20865900E+03, 0.10093100E+03, 0.10663000E+03, -.14036100E+03, -.12014200E+03, 0.14711600E+03, 0.25448100E+03, 0.14810100E+03, -.13222900E+03, 0.22749100E+03, -.11658400E+03, -.11231900E+03, -.10501000E+03, -.79899000E+02, -.74182400E+02, -.71991600E+02, -.95392500E+02, -.41168500E+02, -.17088800E+03, 0.88043100E+02, 0.12291700E+03, -.22787700E+02, 0.54470500E+01, 0.75221600E+02, 0.17100400E+03, 0.93293100E+02, -.49257600E+02, -.14458600E+03, 0.77011800E+02, 0.46094400E+02, 0.96878500E+02, 0.67593200E+02, 0.78251300E+02, 0.94257200E+02, 0.67524600E+02, 0.85250600E+01, 0.29061800E+03, -.14558600E+03, -.14456900E+03, -.23258100E+02, -.31071000E+02, -.81696700E+02, 0.11245200E+02, -.46921400E+02, -.16753900E+02, -.96116000E+02, 0.47228000E+02, 0.43232500E+02, 0.49654000E+02, -.18078200E+02, 0.32869900E+02, -.45983300E+01, -.94204100E+01, 0.53329200E+02, 0.10457700E+01, 0.15064900E+02, 0.34030700E+02, -.41930100E+01, -.99815800E+01, -.52533500E+01, -.14767900E+02, 0.19528800E+02, 0.47169200E+01, -.58633800E+02, 0.14427500E+02, -.24559200E+01, 0.99806200E+01, -.74850100E+02, 0.71397200E+02, 0.57617900E+02, -.45378100E+03, -.20416200E+03, -.45105700E+02, 0.28539900E+02, -.18505600E+01, 0.86682500E+02, -.32685800E+02, 0.21143500E+03, -.93848000E+01, 0.28769200E+02 },
            { 0.65128200E+00, 0.60739000E-01, -.16776900E-01, -.10532300E+01, -.21861700E+01, 0.32094600E-01, -.30593300E+00, 0.51581700E+00, 0.78263700E+00, -.44419700E+00, -.32493800E+00, -.50557600E+00, 0.65814200E+00, -.60298100E+00, 0.28541100E+00, 0.98121600E-01, -.23281900E-01, 0.56402000E+00, 0.97393900E-01, -.85327300E-01, -.81410600E+00, -.99850500E+00, -.37037000E+00, -.17980200E+01, 0.64548100E+00, -.65065900E-02, 0.74147400E+00, 0.34880100E+00, 0.75426100E-01, 0.52247300E+00, 0.61835500E+00, -.50773400E+00, -.59500600E-01, -.19121600E+00, 0.11096600E+00, 0.81017400E+00, -.10423700E+00, 0.38576800E-01, 0.77875400E-01, -.73791000E+00, -.66580800E+00, 0.24588600E+00, 0.34548800E+00, 0.33450300E+00, -.64614400E-01, 0.30337500E+00, 0.41373600E+00, -.10474100E+01, 0.54252000E+00, -.11005400E+00, -.73777400E-01, -.25229200E+00, -.94219200E+00, 0.61446800E+00, 0.10151300E+00, 0.12151600E+00, -.27378200E+01, 0.50893500E-01, 0.28479000E+00, -.10598100E+01, -.74793400E+00, 0.80927400E+00, 0.52586000E+00, 0.45709800E+00, -.58910100E-01, 0.16246400E+00, 0.13464300E+01, -.10728100E+00, -.30108600E+00, 0.76183300E+01, 0.28408800E+00, 0.60837700E+00, -.55005800E-01, 0.31835600E-01, 0.35114500E-01, -.46912600E+00, -.37758200E+00, -.17556300E-01, 0.13839600E+01, -.15979300E+03, 0.13060600E+03, -.12254600E+01, 0.24257100E+01, 0.25061000E+01, 0.75904100E+01, -.25480200E+01, -.27425900E+00, -.10363400E+02, -.13222600E+01, -.21843000E+00, 0.25946500E+00, 0.28141100E+00, 0.16457300E+00, -.14983400E+00, -.19609600E+00, -.41812400E-01, -.22616400E+01, 0.31708000E+00, -.22486100E+00, -.69394900E+00, 0.15113400E+01, 0.87862600E+00, 0.55387400E+01, 0.18057900E+00, -.91546400E+00, -.84992300E+01, -.35186900E+01, 0.26327000E+01, 0.51800400E+03, -.26287400E+03, -.20457500E+03, 0.37014800E+02, 0.79842300E+02, -.21395100E+03, -.44053100E+02, -.33638100E+03, 0.22836500E+02, -.41955700E+03, 0.18924700E+03, 0.24530300E+03, 0.21285700E+03, 0.52259600E+02, 0.56470600E+02, -.15858900E+03, -.82194700E+02, 0.69815100E+02, 0.78089900E+03, -.34737300E+03, -.39271200E+03, -.33210000E+02, 0.39280600E+03, -.32927200E+03, -.14937000E+03, -.26440700E+03, -.27060300E+03, -.10822100E+04, 0.47683500E+03, 0.54532500E+03, 0.48348400E+02, -.23574700E+00, 0.23991500E+03, -.25188600E+03, 0.19452800E+03, 0.14511000E+03, -.48728200E+03, 0.25329300E+03, 0.23342300E+03, -.31746400E+03, 0.53745400E+00, 0.20514600E+03, 0.11756200E+03, 0.23224200E+03, -.25614600E+03, 0.15827000E+03, -.79481500E+02, -.86353900E+02, 0.46639900E+02, -.50864300E+02, -.64195500E+02, -.58073800E+02, 0.70912400E+02, -.12352300E+01, -.53428600E+02, 0.34648200E+02, 0.28518900E+02, 0.38362900E+02, 0.74632100E+01, 0.28307800E+02, -.25266800E+02, -.59230500E+01, 0.36896800E+02, -.62152800E+02, 0.26310100E+02, 0.25010300E+02, 0.20585500E+03, 0.66614700E+01, -.12619800E+02, -.21738000E+03, -.97403700E+02, -.10392200E+01, -.26236300E+03, 0.12188300E+03, 0.12035400E+03, -.37017300E+02, 0.10687500E+02, 0.10138000E+03, -.96728800E+02, 0.19844500E+03, 0.35050800E+02, 0.33127600E+03, -.16178600E+03, -.22749900E+03, 0.16991800E+03, -.57831400E+02, -.12964300E+03, -.13876000E+03, -.17634800E+03, 0.41727500E+01, 0.59981000E+03, -.29043500E+03, -.20767000E+03, 0.10348500E+03, -.96756400E+02, -.19658100E+03, 0.16303300E+03, -.25625500E+03, -.10792700E+03, -.84344500E+03, 0.42215200E+03, 0.42014400E+03, 0.60515300E+02, 0.95758100E+02, 0.22469000E+03, -.89984900E+02, 0.13907800E+03, 0.14696800E+03, -.98005300E+02, 0.51197800E+02, 0.55788200E+02, -.15487700E+03, 0.58064500E+02, 0.10429600E+03, 0.28211000E+03, 0.20345800E+03, -.14356600E+03, -.23584300E+01, 0.15249600E+02, -.34512200E+02, 0.20939700E+01, -.10266500E+03, 0.44507500E+01, -.34261700E+01, -.14864600E+01, -.99658500E+01, -.45389400E+02, -.56181200E+01, 0.12610800E+01, -.43161200E+01, 0.69075400E+02, 0.48206200E+02, -.37013000E+03, 0.13427500E+03, 0.59094700E+03, -.60420900E+02, -.19021800E+02, -.37569500E+02, -.15231000E+02, 0.46482000E+02, -.11867500E+02, -.96740900E+01, -.11848300E+03 },
            { -.82753700E+00, 0.13637400E+00, 0.33347100E+00, 0.20945300E+00, 0.35157600E+00, 0.83237400E-01, 0.23002800E+00, 0.55849700E-01, -.18106200E+00, 0.30258500E+00, 0.35793800E-01, 0.38723200E+00, -.24597500E+00, 0.16483300E+00, -.14697900E+00, 0.31724100E-01, -.35752700E-02, -.12252900E+00, -.69265300E+00, 0.14619900E+00, 0.89512300E+00, 0.35714400E+00, -.35498700E+00, 0.59220700E+00, 0.27119000E+00, 0.13572200E+00, 0.11345300E+00, 0.23193600E+00, -.11600500E+00, -.32825800E+00, 0.90378600E-01, 0.27034800E+00, 0.25962900E-02, -.83262900E-01, -.23281500E+00, -.82335900E+00, 0.19891600E+00, -.76475200E-01, -.11772600E+00, 0.95703700E-01, 0.30246500E+00, -.23620400E+00, -.11505500E+00, -.24133300E+00, -.14739600E+00, -.11364800E+00, -.12077500E-01, 0.47235000E+00, 0.18002500E+00, -.39684300E+00, -.24922600E+00, -.63467300E+00, 0.42409100E+00, 0.60167700E-01, -.49882300E+00, 0.45370400E+00, 0.20753900E+01, 0.10370900E+00, -.41653000E+00, 0.27018700E+00, 0.12992700E+00, -.19151300E+00, 0.95136600E-01, -.20306300E+00, -.17962900E+00, 0.28244100E-01, 0.48152300E+00, 0.48345700E+00, 0.39479500E-01, -.72149700E+00, 0.33937800E+00, 0.28328700E+00, 0.13355400E+00, -.16220800E+00, 0.23160100E-01, -.44840100E+00, 0.42025800E-01, 0.40288400E+00, -.11473700E+00, -.20976800E+00, 0.16547000E+03, 0.18384400E+01, -.70728800E+00, -.11142300E+01, 0.23172600E+00, 0.43179800E+00, -.72164500E+00, -.10543100E+01, -.20724900E-01, -.17615700E+01, 0.14516000E+00, -.32657700E-01, 0.67825700E-01, -.10363500E+00, -.62988500E-01, 0.17246100E-01, 0.65522500E+00, 0.12946700E+00, -.10918200E+00, 0.58926200E+00, -.16788200E+00, -.13191700E+00, 0.62880400E+00, -.64398400E+00, 0.12139100E+00, 0.61283800E+00, 0.25756300E+00, -.84521500E+00, 0.32990100E+02, -.17907300E+02, -.12915300E+02, 0.34664500E+02, -.20056200E+02, -.13376000E+02, 0.29795500E+02, -.13758300E+02, -.40207600E+02, -.74215600E+02, 0.28875000E+02, 0.56242600E+02, 0.47387500E+02, -.60972800E+01, 0.17278400E+02, -.51043800E+02, 0.19711100E+02, -.52903500E+02, 0.28139700E+03, -.11929100E+03, -.14596200E+03, 0.19682200E+02, 0.23799700E+03, -.75958000E+02, 0.77073700E+02, -.79858500E+02, -.14919900E+03, -.81274700E+03, 0.37247100E+03, 0.37428100E+03, 0.61487100E+02, -.40463400E+02, 0.28639500E+03, 0.42001700E+02, 0.20846400E+03, 0.74980200E+02, -.16553600E+03, 0.90198600E+02, 0.71934600E+02, -.95714400E+02, 0.23069000E+02, 0.11116900E+03, 0.16518400E+03, 0.11234100E+03, -.16871700E+03, 0.29391700E+03, -.14534600E+03, -.19440000E+03, 0.13554100E+03, -.99803200E+01, -.13907400E+03, -.12009700E+03, -.13793700E+03, 0.17315600E+01, -.12217800E+03, 0.63106000E+02, 0.51971600E+02, -.34301100E+02, -.41280700E+02, 0.74391500E+02, 0.77949300E+02, 0.69233400E+02, -.37496600E+02, -.62667700E+02, 0.29388800E+02, 0.34271700E+02, 0.19658900E+02, -.20763500E+02, 0.12159700E+02, -.79732100E+02, 0.20754800E+02, -.54285100E+02, -.77943900E+02, 0.36971900E+02, 0.23774500E+02, 0.21792200E+02, -.87332400E+02, 0.75305100E+02, 0.56343500E+02, 0.15339700E+03, -.99402600E+01, 0.28841300E+02, -.14618800E+02, 0.45556100E+02, 0.70276400E+02, 0.75450200E+01, -.57536000E+02, -.30272200E+02, -.38362900E+02, -.17088900E+02, 0.11893600E+03, -.58069800E+02, -.36861300E+02, 0.38245400E+02, 0.10518100E+03, -.99107000E+02, -.91761900E+02, -.12168500E+03, 0.24799200E+02, -.28641000E+03, 0.14370800E+03, 0.14393500E+03, 0.66232100E+02, 0.44030800E+02, 0.91125700E+02, 0.24446900E+01, 0.10271500E+03, 0.76242000E+02, -.31441400E+03, 0.15805600E+03, 0.12866500E+03, -.59324300E+02, 0.46573800E+02, 0.16373900E+03, 0.19341600E+03, 0.17877200E+03, -.31959600E+02, -.17362400E+01, 0.15308100E+02, -.18550200E+01, -.83870300E+00, -.57920400E+02, 0.21308300E+00, -.18637300E+02, 0.99247400E+01, -.45765700E+01, -.10746200E+02, 0.12290000E+00, -.46775900E+00, 0.18970800E+00, -.74172100E+01, 0.24425600E+02, -.10385100E+03, -.39612600E+01, 0.18562100E+03, -.70908800E+02, -.26135500E+01, 0.28206300E+02, -.17183900E+02, -.22878100E+01, -.73596500E+02, 0.31972500E+02, -.54050900E+02 },
            { 0.87015400E+00, -.17660000E+00, -.33375100E+00, -.10264500E+00, -.12430900E+01, -.12684300E+00, -.38335600E+00, -.14992400E-01, 0.27055800E+00, -.25644100E+00, -.18114400E+00, -.33399500E+00, -.23346500E+00, 0.35445500E-01, -.15446100E+00, 0.18050600E+00, -.45928500E+00, 0.11748600E+00, 0.57861600E+00, -.20038300E+00, -.64078300E+00, -.42076100E+00, -.28454800E-01, 0.67824900E-01, -.18312700E+00, -.17264700E+00, 0.45809500E-01, 0.50344700E-01, -.23451500E-01, -.69414600E-01, 0.12551200E+00, 0.14420800E+00, -.26291700E+00, 0.24049000E-01, 0.11555500E+00, 0.13830100E+00, -.18818600E+00, 0.65125700E-02, -.17637200E-01, 0.71568500E+00, 0.35733000E-01, 0.46364800E-01, 0.86389800E-01, 0.89973600E-01, -.95753400E-01, -.24860200E+00, 0.45600000E+00, -.91203600E+00, 0.30293700E+00, -.28905100E+00, 0.17135600E+00, -.18664400E+00, -.31431400E+00, 0.93606400E-01, 0.19063800E+00, -.32625000E+00, -.56505800E+00, -.11914200E-02, -.28733000E-03, -.25434300E+00, 0.23290200E+00, -.23087800E+00, 0.16166800E+00, 0.34520000E+00, 0.57403700E+00, -.39997600E+00, -.73479000E+00, -.46906300E+00, 0.27862700E+00, -.73761700E+00, 0.21264600E+00, -.42916600E+00, -.10675900E+00, -.63842100E-01, 0.66808200E+00, 0.14393100E+00, 0.23265400E+00, 0.25105600E+00, 0.63117000E+00, 0.49968500E+00, -.37784800E+00, -.65792600E+01, 0.15921000E+01, 0.29394300E+01, -.31646000E+01, -.29902800E+00, 0.21240500E+01, -.26239200E+01, 0.40176700E+01, -.27042900E+01, -.15919000E+01, 0.39764400E+00, 0.80460000E+00, -.12306000E-01, 0.51081700E-01, 0.18381900E-02, -.10626900E+01, -.13926000E+00, 0.32857800E-01, -.35198000E+01, 0.64928800E+00, 0.17653600E+01, -.17283400E+01, -.13692200E+01, 0.12682700E+01, -.16607700E+01, 0.34350100E+01, -.24055200E+01, -.30634600E+02, 0.19029300E+02, 0.93587200E+01, 0.11262800E+02, -.13584700E+02, 0.32591000E+02, 0.19904800E+02, 0.85076000E+02, -.13121000E+02, 0.22067600E+03, -.96811200E+02, -.10606000E+03, 0.15331600E+02, 0.24840600E+02, -.73103200E+02, -.14555800E+02, -.55729000E+02, -.43710900E+01, 0.86157600E+02, -.70225500E+02, -.45768300E+02, 0.12677300E+03, -.87132200E+02, -.68836500E+02, -.11145100E+03, -.74659200E+02, 0.34324100E+02, 0.22432700E+02, 0.17533600E+02, -.44533200E+02, 0.59372100E+02, 0.15849300E+03, -.58377100E+02, -.82725100E+02, -.12886800E+03, 0.11290600E+03, 0.45873900E+03, -.23929000E+03, -.23484800E+03, 0.10663100E+03, 0.19889100E+02, -.18902200E+03, -.10812500E+03, -.16650500E+03, 0.32684200E+02, 0.89658500E+02, -.43590300E+02, -.65019300E+02, 0.37382100E+02, 0.98709500E+01, -.35969300E+02, -.32884000E+02, -.29886000E+02, 0.10280400E+02, -.34158400E+02, 0.11955700E+02, 0.18243800E+02, -.40301700E+02, -.36829100E+02, 0.40384100E+02, 0.25530100E+02, 0.87959800E+02, -.55842300E+02, 0.15060100E+03, -.70892400E+02, -.72130500E+02, 0.23521700E+02, 0.13598100E+02, -.42597900E+02, -.27811700E+02, 0.20020800E+02, -.28735200E+02, 0.21203500E+03, -.98821900E+02, -.11448600E+03, 0.45620800E+02, -.28487500E+02, -.75217300E+02, 0.30135100E+01, -.11954600E+03, 0.15405500E+02, -.11209700E+03, 0.51005600E+02, 0.90628600E+02, -.32959600E+02, 0.15969600E+02, 0.55406700E+01, -.61117500E+02, 0.47046000E+02, 0.13832000E+02, -.21529100E+03, 0.99066100E+02, 0.10380400E+03, -.80422400E+02, 0.16524700E+02, 0.80863800E+02, -.56378000E+02, 0.13503400E+03, -.12731800E+02, 0.95024200E+02, -.47513200E+02, -.47330600E+02, -.46131200E+01, -.48213300E+02, -.23979400E+02, -.12090900E+02, -.82355700E+01, -.21099600E+02, -.16380200E+03, 0.81468000E+02, 0.59404000E+02, 0.24942700E+02, 0.21596100E+02, 0.61874400E+02, 0.15776000E+02, 0.43876000E+02, 0.33458400E+02, 0.13684500E+02, 0.11617200E+02, -.98764400E+01, 0.22378800E+01, 0.19554900E+02, 0.10027800E+01, -.53082500E+01, 0.14996100E+02, -.40197400E+01, -.30559900E+01, 0.10505600E+01, 0.83621200E+00, 0.75385200E+00, -.21494200E+02, -.34534700E+01, 0.78575700E+02, 0.87241900E+02, -.48593400E+02, -.18316100E+02, -.10467300E+02, 0.27776200E+02, 0.48278600E+02, -.69699100E+01, 0.19474300E+00, -.18363700E+01, 0.18728000E+02 },
            { -.10437600E+01, 0.62675400E+00, 0.36019200E+00, -.37764100E+00, -.56147700E+00, -.33421300E+00, 0.28082600E+00, -.16095800E+00, 0.74403600E+00, 0.70279700E+00, 0.12891300E+01, 0.33983000E+01, 0.27502100E-01, -.99864600E+00, 0.71383700E+00, -.34413700E+00, -.74318700E-01, -.26347900E+00, -.74634900E+00, 0.17868400E-02, 0.87740200E+00, -.76494000E-01, 0.95165200E-01, -.50741900E+00, -.42146900E-01, 0.26604900E+00, -.27426800E-01, -.90025900E-01, 0.20196500E+00, 0.97990200E-01, -.30817700E+00, 0.22451200E-01, 0.12870500E+00, -.84625800E-01, 0.17177300E+00, 0.50376700E+00, 0.56011300E+00, -.22065000E+00, -.33699700E+00, 0.98421900E+00, 0.22954800E+01, -.10539500E+01, -.11448700E+01, -.12363500E+01, 0.47184500E+00, 0.56016400E-01, -.43989300E+00, 0.88465900E+00, -.14074100E+01, 0.10259000E+01, 0.13866600E+01, 0.65017700E+00, 0.72983200E+00, -.35065800E-01, -.17124600E+00, -.69945700E-02, -.30403400E+00, -.57620800E-01, -.85255100E-02, 0.26357600E+00, 0.17648100E+00, -.26731200E+00, -.38400500E+00, -.36665300E+00, -.11841100E+00, 0.92764600E-01, 0.69599300E+00, 0.68473700E-02, -.10946700E+00, -.23831400E+01, 0.23644900E+00, 0.43334300E+00, -.19898500E+00, -.16439300E+00, -.96582000E-01, -.20660100E+00, -.16336300E+00, 0.15787600E+00, -.33259800E+00, -.97120600E-01, -.41235900E+00, -.77164900E+00, -.27495700E+01, -.80530800E+00, -.10300700E+02, 0.22486600E+01, -.57474500E+01, -.17126700E+02, -.26516300E+01, -.13042000E+01, -.11750700E+01, -.60437200E-01, 0.56221300E+00, 0.83918400E-03, 0.34918800E-02, 0.33851500E-03, -.12755600E+01, 0.26322300E-01, -.12179100E-01, -.14279600E+01, -.10857700E+01, 0.59189900E+00, -.44218800E+01, 0.78037400E+00, -.23059700E+01, -.76249200E+01, -.71638000E+00, -.65621900E+00, 0.10875200E+03, -.46877600E+02, -.63338100E+02, -.14489100E+02, 0.11408700E+03, -.12267400E+03, -.20341000E+03, -.10593400E+03, 0.65401800E+02, 0.20541400E+03, -.76694000E+02, -.10198400E+03, 0.32097000E+01, 0.18304200E+03, -.15626100E+03, -.26890500E+03, -.14767900E+03, 0.12480100E+03, 0.28318400E+03, -.19492000E+03, -.14484600E+03, 0.23390200E+03, -.21213100E+03, -.13217300E+03, -.15748800E+03, -.14220500E+03, 0.43217500E+02, 0.48783800E+03, -.17421800E+03, -.27015600E+03, -.37224600E+02, 0.24106500E+03, -.19828600E+03, -.10238100E+03, -.33643100E+03, 0.88824400E+02, 0.10916600E+04, -.55757000E+03, -.54971200E+03, 0.24756700E+03, 0.62672400E+02, -.41961200E+03, -.12886900E+03, -.46211900E+03, 0.66124900E+02, 0.33080000E+03, -.16566900E+03, -.20252700E+03, 0.75922900E+02, 0.24723200E+02, -.10918900E+03, 0.74767400E+01, -.85136900E+02, -.19272300E+02, -.11142600E+03, 0.46970900E+02, 0.41537900E+02, -.70181500E+02, -.27997200E+02, 0.25039500E+02, -.54403600E+01, 0.26608700E+02, -.29689200E+02, 0.20985800E+03, -.95581700E+02, -.99254000E+02, 0.69582600E+01, 0.17038000E+03, -.19422400E+03, -.30722700E+03, -.12003100E+03, 0.97078000E+02, -.99474400E+02, 0.61455600E+02, 0.44132000E+02, 0.19072700E+03, -.46192000E+02, 0.10936500E+03, 0.22779200E+03, 0.18393400E+03, 0.26157000E+02, -.32962200E+02, 0.79840400E+01, 0.74576200E+02, -.44541600E+02, 0.54085200E+02, -.53713200E+02, -.10576900E+03, -.17618000E+02, 0.10120800E+02, -.50246300E+03, 0.23582000E+03, 0.24093400E+03, -.16246900E+03, 0.17249300E+03, -.31841600E+01, -.36389100E+03, -.33547600E+02, 0.12970300E+03, -.21568900E+03, 0.10794700E+03, 0.10937600E+03, 0.63302200E+02, 0.31293900E+02, 0.79111900E+02, 0.56569600E+02, 0.92767300E+02, 0.43595800E+02, 0.90213900E+02, -.44932000E+02, -.68259300E+02, -.10590500E+02, -.60121700E+01, -.42716500E+02, -.34770000E+02, -.43120900E+02, -.15066300E+02, 0.99706100E+01, -.96275600E+01, -.52783200E+01, 0.20330100E+01, 0.12937200E+02, 0.28996500E+01, 0.23974100E+02, -.84219400E+01, -.19858600E+01, 0.64684700E+02, -.81322800E+01, 0.86270200E+00, -.30681800E+01, 0.55256500E+02, -.14170200E+03, 0.16341600E+03, 0.49399400E+03, -.18589400E+03, 0.68605800E+01, 0.20697800E+01, 0.10163700E+03, -.68315900E+02, 0.68247700E+00, -.37194500E+03, 0.11870100E+02, -.19146800E+02 },
            { -.11541300E+01, 0.25167200E+00, 0.88769800E+00, -.26296500E+00, 0.73950000E+00, 0.17153500E+00, 0.65033300E+00, -.52214700E-01, -.58598000E+00, 0.21905100E+00, 0.44276000E+00, 0.15477900E+01, 0.91001900E-01, -.35348200E+00, 0.29454100E+00, -.32180500E+00, 0.53282000E+00, -.99500100E-01, -.85228800E+00, -.12834400E+00, 0.71584800E+00, 0.28559000E+00, 0.31038400E+00, -.62648200E+00, 0.20461300E+00, 0.31781300E+00, -.10125600E+00, -.71178500E-01, -.53261500E-01, 0.94397300E-01, 0.43392500E-01, -.69382800E-01, 0.25855900E+00, -.27828000E+00, -.13790700E+00, -.37023400E+00, -.13416000E+00, 0.52302200E-01, 0.76889000E-01, -.50845900E-01, 0.21580300E-01, 0.68531500E-01, -.19250800E+00, -.58872900E-01, 0.27098100E+00, 0.16830300E+00, -.45294600E+00, 0.94966700E+00, -.12877000E+01, 0.69653200E+00, 0.29043800E-01, 0.91584500E+00, 0.40442000E+00, -.34993400E+00, -.11312700E+00, 0.22213900E+00, 0.35377500E+00, 0.95517900E-01, -.22084800E+00, 0.25257400E+00, -.94350300E-01, 0.69178400E-02, -.48024000E-01, -.10003600E+00, -.10023100E+00, 0.13037800E+00, 0.54083500E+00, -.29412100E+00, 0.65306900E-01, -.40887700E-01, -.18536800E-01, -.20358800E+00, 0.30921900E-02, 0.72061500E-01, -.36999300E-01, -.86603400E-01, -.16460300E+00, -.16615500E+00, -.21972900E+00, -.34760000E+00, 0.38132100E+00, 0.14152200E-01, -.33613200E+00, 0.21798400E+01, -.20821600E+01, 0.14185500E+01, -.27233700E+01, -.47622700E+01, -.25543300E+01, 0.23202000E+00, -.37064900E+00, 0.18653600E+00, 0.17616300E+00, -.12924800E-01, -.25245200E-01, -.19407400E-01, -.26174300E+00, 0.55086400E-01, -.54766800E-01, -.94599400E+00, 0.47240700E+00, 0.49936500E+00, -.42705100E+00, 0.95907900E+00, -.11884700E+01, -.18676000E+01, -.16575100E+01, 0.66463200E+00, 0.10394000E+03, -.51093600E+02, -.43747700E+02, -.26915400E+02, 0.35632900E+02, -.52385900E+02, -.32437400E+02, -.58765800E+02, -.17894500E+01, 0.66142200E+02, -.29526000E+02, -.35959300E+02, -.65003100E+01, 0.77111000E+02, -.54467500E+02, -.93658400E+02, -.67951800E+02, 0.39080200E+02, -.14032500E+03, 0.62080300E+02, 0.71684900E+02, -.90831200E+01, -.98694600E+02, 0.62382200E+02, 0.35405800E+02, 0.88199500E+02, 0.12394400E+02, 0.26733300E+03, -.12119300E+03, -.12029600E+03, -.18027000E+02, 0.92007900E+02, -.12453700E+03, -.69398000E+02, -.14291100E+03, 0.13197800E+02, 0.17889900E+03, -.92026900E+02, -.86234300E+02, 0.18320700E+02, 0.10280900E+02, -.51360800E+02, 0.45331900E+02, -.50996300E+02, 0.26447200E+02, 0.11779200E+03, -.59318300E+02, -.45210900E+02, 0.88704000E+01, 0.82379000E+01, -.38199100E+02, 0.59225400E+01, -.32120000E+02, -.20651400E+02, -.32782400E+02, 0.15494200E+02, 0.17209800E+02, 0.57804800E+01, -.35236300E+01, -.49972600E+01, -.12123800E+01, -.17723500E+02, 0.13618500E+02, 0.71341500E+02, -.34542100E+02, -.36965000E+02, 0.15397400E+02, 0.74889800E+02, -.74518000E+02, -.11435500E+03, -.10254700E+03, 0.52600600E+02, -.39973400E+02, 0.20587400E+02, 0.24930100E+02, 0.32117500E+02, -.31148200E+02, 0.41086200E+02, 0.28002600E+02, 0.76542900E+02, -.24535700E+02, 0.67977200E+02, -.34004100E+02, -.65873500E+02, -.40743700E+02, 0.19777000E+01, 0.10629900E+01, 0.30196400E+02, -.63534300E+01, -.58386200E+02, 0.55921000E+01, -.30901000E+01, 0.27125400E+01, -.49563800E+02, 0.30724800E+02, -.40770500E+02, -.26564300E+02, -.51231300E+02, 0.61664800E+01, -.99079100E+02, 0.49553000E+02, 0.49419000E+02, 0.21148700E+02, 0.20843800E+02, 0.32873900E+02, 0.19316200E+02, 0.34545300E+02, 0.11935400E+02, 0.16577800E+03, -.82653300E+02, -.71274400E+02, 0.15594400E+02, -.10562300E+02, -.83106600E+02, -.51968600E+02, -.91627900E+02, 0.15572300E+01, 0.32692000E+01, -.93933600E+00, 0.13667000E+01, 0.45439000E+00, -.20665100E+01, 0.13855800E+01, 0.11717100E+02, -.15871700E+01, -.10187800E+01, 0.23866700E+02, -.16933400E+01, 0.16914900E+00, 0.28338600E+00, 0.19763300E+02, -.66972900E+02, 0.29574400E+02, 0.10541100E+03, -.71490700E+02, 0.76278000E+01, 0.48571200E+01, 0.13985100E+02, -.22129400E+02, 0.22269400E+02, -.79158300E+02, 0.82056800E+01, -.12533700E+02 },
            { -.11823500E+01, -.48136300E+00, 0.26800100E+00, 0.13467100E+00, 0.55746400E+00, -.72583400E-02, 0.45746000E+00, -.18589700E-01, -.31692600E+00, 0.63508100E+00, 0.84338100E+00, 0.15789500E+01, -.29946700E+00, -.32878100E+00, 0.72456900E+00, -.34645600E+00, 0.16437800E+00, 0.23184400E-01, -.61234400E+00, -.78315600E-01, 0.57136900E+00, 0.12320800E-01, 0.13967900E+00, -.26893200E+00, 0.41891100E-01, 0.69872200E-01, -.16485700E+00, 0.22728800E-01, -.15372600E+00, 0.50857200E-01, 0.15674900E+00, 0.32446500E+00, 0.10629600E+00, -.28102300E-01, 0.32886800E-01, -.10750600E+00, 0.34642600E+00, -.13769500E+00, -.19826000E+00, 0.11927900E+01, 0.18981900E+01, -.61532300E+00, -.44908400E+00, -.87706400E+00, 0.34495600E+00, 0.17438900E+00, -.23620300E+00, 0.61104300E+00, -.12577000E+01, 0.70928700E-02, -.12864400E+00, -.16943300E+00, 0.24303800E+00, -.14193200E+00, -.88480000E-02, -.29448400E+00, 0.97416100E+00, 0.36870600E-01, -.20322400E+00, 0.26827000E+00, -.23920500E+00, -.67931500E-01, 0.37126800E-02, 0.59667200E-01, -.98945600E-01, 0.77447900E-01, -.74578500E-01, 0.37611900E+00, 0.50091200E+00, -.46010800E+01, -.11302200E+00, -.13215500E+00, 0.16839700E+00, -.26437100E-01, 0.73063600E-02, -.26408000E+00, -.12382500E+00, -.14075600E+00, -.41406900E-01, -.87445200E-01, 0.42056300E+00, 0.19241400E+00, -.14125000E+01, -.35921200E+00, -.15446200E+02, 0.34447300E+01, -.91073100E+01, -.32874200E+02, -.64709200E+01, -.17871400E+01, -.15171700E+01, 0.10410200E+00, 0.73905600E+00, -.27717100E-01, -.53533900E-01, 0.10871200E-01, -.33656300E+01, 0.13612000E+00, -.10459800E+00, -.25345000E+01, -.57274100E+00, 0.11274400E+01, -.60023300E+01, 0.20528700E+01, -.37858700E+01, -.15989300E+02, -.30932700E+01, -.27105400E-02, 0.32766900E+03, -.15461000E+03, -.16329200E+03, -.38557700E+02, 0.20224600E+03, -.26278600E+03, -.40138700E+03, -.29951000E+03, 0.84754800E+02, 0.24408900E+03, -.89649400E+02, -.11714900E+03, -.22383200E+02, 0.33789700E+03, -.24859500E+03, -.50780600E+03, -.28680200E+03, 0.20816600E+03, -.10326500E+03, -.16353300E+02, 0.48275400E+02, 0.18232800E+03, -.41314700E+03, 0.57212500E+02, 0.14700800E+02, 0.46903800E+02, 0.81187200E+02, 0.96340000E+03, -.39233400E+03, -.50157400E+03, -.57635900E+02, 0.34522400E+03, -.38032400E+03, -.16073200E+03, -.52879100E+03, 0.74721200E+02, 0.13663100E+04, -.70285200E+03, -.68763800E+03, 0.29400800E+03, 0.59476300E+02, -.47131700E+03, 0.22460600E+02, -.52500200E+03, 0.10871500E+03, 0.45979000E+03, -.22980200E+03, -.26725600E+03, 0.92778600E+02, 0.40102900E+02, -.14482900E+03, 0.36029300E+02, -.11445000E+03, -.45552700E+02, -.14754700E+03, 0.62562700E+02, 0.56416600E+02, -.63059000E+02, -.30339700E+02, 0.17422800E+02, -.59074400E+02, -.10836300E+02, -.86103600E+01, 0.36084000E+03, -.16959600E+03, -.17528900E+03, 0.28107500E+01, 0.31367900E+03, -.33764800E+03, -.56343200E+03, -.29641200E+03, 0.19264500E+03, -.15929500E+03, 0.93474100E+02, 0.74283700E+02, 0.25899900E+03, -.72093400E+02, 0.18344800E+03, 0.36112000E+03, 0.33369600E+03, -.20364200E+01, 0.31452400E+02, -.23859600E+02, 0.29835200E+02, -.11783400E+03, 0.69089200E+02, -.60828300E+02, -.13504800E+03, -.33456400E+02, -.76984700E+02, -.60711900E+03, 0.28805200E+03, 0.30694100E+03, -.26178000E+03, 0.21988700E+03, -.51682000E+02, -.54565700E+03, -.15504700E+03, 0.15608700E+03, -.31525100E+03, 0.15787200E+03, 0.15903100E+03, 0.93468700E+02, 0.63116100E+02, 0.11307600E+03, 0.80088000E+02, 0.13144400E+03, 0.52155300E+02, 0.29338500E+03, -.14657000E+03, -.16622800E+03, 0.19652500E+02, -.31396900E+02, -.14269600E+03, -.11136600E+03, -.16381000E+03, -.45569400E+01, 0.13105800E+02, 0.60459500E+01, -.16665900E+02, 0.43540400E+01, 0.24768600E+02, 0.66924900E+01, 0.78877800E+01, 0.74883500E+01, -.52579900E+01, 0.10413500E+03, -.16092100E+02, 0.21120500E+01, -.66618200E+01, 0.15076100E+03, -.32251700E+03, 0.22819100E+03, 0.52148600E+03, -.39776500E+03, 0.14214300E+02, 0.26643000E+01, 0.16436400E+03, -.15427900E+03, 0.46841200E+02, -.64426300E+03, 0.59352600E+02, -.12725100E+02 },
            { -.30420200E+01, 0.25621500E+00, 0.14666000E+01, -.80282800E+00, 0.16668800E+01, 0.34068800E+00, 0.96892300E+00, 0.47296800E+00, -.12058800E+01, 0.53096300E+00, 0.11665000E+00, -.17832600E+00, -.11463700E+01, 0.14602300E+00, 0.10276200E-02, -.27730300E-01, 0.11292300E+00, -.88327800E+00, -.13645900E+01, 0.55201000E+00, 0.20794300E+01, 0.98237000E+00, -.14019900E+01, 0.37216200E+01, 0.56756300E+00, 0.79291200E-01, 0.43038800E-01, 0.80985900E+00, -.11804600E+00, 0.11846900E-01, -.18679200E+00, 0.40315600E+00, 0.20738200E-01, -.26300300E+00, 0.15355800E-01, -.13443500E+01, 0.54859600E+00, -.21256000E+00, -.33719700E+00, -.71778700E+00, 0.19128800E+00, -.72879200E+00, -.36444800E+00, -.10263400E+01, 0.18871900E+00, -.81425700E-01, -.39987000E+00, -.26384700E+00, 0.44052100E+00, -.28349900E+00, 0.54118900E+00, -.74532600E+00, 0.75781400E+00, -.14639600E+00, -.26248600E+00, -.22988500E+00, 0.44727500E+01, -.42602600E-01, -.13987000E+01, 0.10935200E+01, 0.43297200E+00, -.70711000E+00, 0.30165600E+00, 0.17660600E+00, 0.33413100E+00, -.15367000E+01, 0.49806100E+00, 0.29163400E+00, -.14825500E+01, 0.82594600E+01, 0.21987100E-01, 0.14150900E+01, 0.42131700E+00, 0.34352500E+00, -.16484400E+00, -.49581300E+00, -.84011800E-01, -.64617500E+00, -.29908500E+01, -.16907500E+01, 0.53289200E+00, -.65849400E+00, -.16680400E+01, -.79449400E+00, 0.39063700E+00, 0.75866700E+01, -.14254100E+02, 0.13301000E+02, -.12733400E+02, 0.10963100E+02, -.27766600E+01, 0.16205800E+01, 0.13204700E+01, 0.12825600E-01, 0.82250100E-01, -.14246200E+00, 0.73533100E+01, 0.11786800E+00, 0.11313300E+00, -.41176400E+01, 0.27617600E+01, 0.19170300E+01, -.38778200E+00, 0.27078000E+01, -.56462500E+01, 0.14343100E+02, -.70331800E+01, 0.55939100E+01, 0.10435100E+03, -.55592700E+02, -.81880600E+02, -.13184000E+03, -.70388800E+02, -.44463100E+02, 0.21784900E+03, 0.20671900E+02, 0.31213500E+02, -.28291500E+03, 0.12437100E+03, 0.12344400E+03, 0.12628700E+03, 0.33903300E+02, 0.10136800E+02, -.96538500E+02, -.62624600E+02, 0.13690200E+03, 0.97405000E+03, -.45111700E+03, -.48782000E+03, 0.37258100E+01, 0.27014000E+03, -.44003500E+03, -.46548700E+03, -.47259400E+03, -.41720200E+01, -.10448100E+04, 0.48905700E+03, 0.49412700E+03, -.59268500E+02, -.10861900E+03, 0.40505500E+03, 0.26652000E+03, 0.29294600E+03, -.17945900E+00, 0.32851400E+03, -.13580400E+03, -.15911000E+03, -.11919400E+03, 0.46781500E+02, -.15088100E+03, -.14471900E+03, -.25404100E+03, -.58484600E+02, 0.32226800E+03, -.16453100E+03, -.19323900E+03, 0.66391100E+02, 0.10432400E+02, -.12938900E+03, -.20370500E+02, -.11047200E+03, -.31490900E+02, -.19963200E+03, 0.10702100E+03, 0.85037800E+02, -.80199500E+02, -.11209700E+02, -.19985300E+00, 0.13502900E+03, -.63346400E+02, 0.68516500E+02, -.89528800E+02, 0.42517100E+02, 0.50567600E+02, 0.56677200E+02, -.52582500E+01, -.62099100E+02, 0.26078400E+02, -.51730100E+02, 0.62317300E+02, -.68167100E+03, 0.33231900E+03, 0.34245300E+03, 0.16941500E+03, -.22589000E+02, 0.29982400E+03, 0.35829200E+02, 0.39973900E+03, -.36690000E+02, -.59768400E+02, 0.31868100E+02, 0.10681500E+03, 0.92512500E+02, 0.25110800E+02, -.70396700E+02, 0.20540400E+03, -.40000000E+02, 0.13161000E+03, 0.22389500E+03, -.10831600E+03, -.16125400E+03, -.16926600E+02, 0.18331200E+03, -.25035500E+03, 0.70954000E+02, -.14042200E+03, 0.20529800E+03, -.53055900E+03, 0.26506000E+03, 0.26716600E+03, 0.83836600E+02, 0.15088400E+03, 0.16903600E+03, 0.77688700E+02, 0.12186900E+03, 0.99017800E+02, 0.19329700E+03, -.95164300E+02, -.11474000E+03, -.13492100E+03, 0.16607700E+02, -.63986000E+02, 0.65991200E+02, -.88281900E+01, -.11154000E+03, 0.24329700E+02, -.98729500E+02, 0.61206800E+02, -.61619100E+01, -.56253100E+02, -.33436400E+01, 0.14132600E+03, -.10907300E+03, -.13432400E+02, 0.98781200E+02, 0.17036900E+02, -.43677700E+01, 0.18122500E+02, -.69122500E+02, 0.10698200E+03, -.26647200E+03, 0.79019300E+03, 0.54431800E+03, 0.72178200E+02, 0.40159100E+02, -.70841200E+02, -.83253500E+02, -.12493200E+03, -.46077900E+01, -.76566800E+02, -.13064300E+03 },
            { -.23183400E+00, 0.69033400E-01, 0.11808700E+00, -.44341500E-01, 0.18675400E+00, 0.32830300E-01, 0.63857400E-01, 0.45233500E-01, -.75377100E-01, 0.56985400E-01, 0.53677300E-01, 0.79153600E-01, -.93396600E-02, -.41012100E-02, -.14220000E-01, -.12033800E-01, 0.72352300E-01, -.94081100E-01, -.78627700E-02, 0.60462900E-01, 0.50200400E-01, 0.10379800E+00, -.11670200E+00, 0.27042600E+00, 0.33287900E-01, 0.24365400E-01, 0.37864500E-01, 0.39138900E-01, 0.21814000E-01, -.37367700E-01, -.22716500E-01, 0.84965600E-02, 0.30930100E-01, 0.15782300E-01, -.18331000E-01, -.52305200E-01, 0.30104100E-01, -.11611900E-01, -.17600400E-01, -.17824200E+00, -.11489900E+00, -.24249400E+00, -.12976600E-01, -.51903400E-02, -.10365400E-01, -.45648400E-02, -.52206500E-01, 0.19833800E-01, 0.13794400E+00, 0.99560900E-02, 0.15417100E+00, -.86120800E-01, 0.67748100E-01, -.18745600E-01, -.57482000E-01, 0.17316600E-01, 0.48046100E+00, -.15827000E-01, -.87504200E-01, 0.62964000E-01, -.16799200E-02, -.27274700E-01, 0.11099100E-01, -.33307000E-01, 0.11653100E-01, -.80634100E-01, 0.95659200E-01, 0.53478300E-01, -.14351300E-01, -.86074300E+00, 0.51428100E-01, 0.19923100E+00, 0.40821400E-01, -.22941400E-01, -.27095100E-01, -.65109200E-01, -.34444200E-01, 0.53647100E-01, 0.17399600E+00, 0.46445500E-01, -.22810500E-01, 0.22416200E-01, 0.54148800E-01, 0.19530700E-01, 0.30923000E-01, 0.30217300E-01, -.19535700E+01, -.52064300E+01, -.47929800E+00, -.33251500E+00, 0.26711500E+00, -.12114700E+00, -.15104200E+00, -.16502600E-01, -.15296800E-01, -.46387900E+00, -.10109700E+01, 0.63501800E-02, -.20505800E-01, 0.96702900E-01, -.12712200E-01, -.62094300E-01, 0.26793300E+00, 0.14087500E+00, -.12522700E+01, -.32113800E+01, -.40399700E+00, 0.28102700E-01, 0.93182100E+02, -.46375600E+02, -.44269100E+02, 0.86541500E+01, 0.10619800E+02, -.44118400E+02, -.43295700E+02, -.31858800E+02, -.40149100E+01, 0.47040100E+02, -.23245600E+02, -.23917200E+02, 0.40587300E+01, -.52387500E+01, -.24578300E+02, -.38111400E+02, -.70054300E+01, -.75755300E+01, 0.11351300E+03, -.56828400E+02, -.56489300E+02, 0.37523400E+02, -.29034900E+01, -.40044100E+02, -.57763800E+01, -.21606700E+02, -.30342400E+01, 0.38945300E+02, -.18606700E+02, -.18847000E+02, 0.89590800E+00, 0.27162400E+02, -.37844800E+02, -.54022400E+02, -.32560700E+02, 0.16367300E+02, 0.70912000E+02, -.34989000E+02, -.35255100E+02, 0.87758800E+01, 0.30000600E+01, -.24482200E+02, 0.71449900E+00, -.16919800E+02, 0.42316000E+01, 0.15946500E+02, -.82024600E+01, -.18646000E+01, 0.56280300E+00, -.13613800E+01, -.34153900E+01, -.14688700E+01, -.44434500E+01, -.93178500E+00, 0.65954600E+01, -.30803900E+01, -.85732500E+00, 0.64870900E+01, 0.30621300E+01, -.93807000E+01, -.18736300E+02, -.74959800E+01, 0.11379800E+01, 0.29118000E+02, -.14271300E+02, -.14617700E+02, 0.19596700E+02, 0.19102000E+02, -.31077800E+02, -.69935400E+02, -.45120700E+02, 0.10985700E+02, -.14488500E+02, 0.70597300E+01, 0.79081000E+01, 0.53764800E+01, 0.99881900E+01, 0.11628600E+02, 0.11729200E+02, -.45004100E+01, 0.14533000E+02, 0.44080100E+02, -.22006900E+02, -.33929400E+02, -.46081600E+01, -.49788400E+01, -.18933900E+02, -.26211400E+02, -.14013000E+02, -.17212300E+02, 0.49794800E+02, -.24883100E+02, -.23500000E+02, -.93882800E+01, -.25545700E+02, -.20736200E+02, -.19491300E+02, -.21245000E+01, -.31001100E+02, -.36297100E+02, 0.18211500E+02, 0.17938800E+02, 0.13905700E+01, 0.14946800E+01, 0.99463000E+01, -.58112700E+01, 0.34271500E+01, 0.75199000E+01, 0.27452500E+02, -.13543200E+02, -.12234100E+02, 0.18551600E+01, 0.56113400E+00, -.11177700E+02, 0.15488800E+01, -.16635700E+01, -.20662100E+01, -.23391300E+01, 0.35010100E+01, -.38439500E+01, 0.65660600E+00, -.52925200E+01, 0.10054900E+01, -.18094000E+01, 0.29091200E+01, 0.37307700E+01, -.25110200E+01, -.52688800E+01, 0.55614900E+00, -.39577100E+01, 0.16687900E+02, -.31834700E+02, 0.27694200E+02, 0.25477800E+02, -.90396600E+01, -.25283800E+01, -.63549700E+01, 0.20137400E+02, -.45239400E+01, 0.11023300E+02, -.43064700E+02, -.32560200E+01, -.30665800E+01 },
            { -.31217900E+00, -.28492100E+00, -.37537600E+00, 0.93979500E+00, 0.67230800E+00, 0.97829100E-01, 0.18345400E+00, -.50299100E-01, -.25996600E+00, 0.10682000E+00, -.34952600E+00, -.13834200E+01, 0.48813300E-01, 0.65739000E+00, 0.24698500E+00, -.12714300E+00, 0.34570900E+00, 0.12468000E-01, -.57409000E+00, 0.14540300E+00, 0.11408000E+01, -.16927600E+00, -.26731700E+00, 0.24069900E+00, 0.13606900E+00, -.15847600E+00, -.38797900E+00, 0.46813300E-01, -.15571400E+00, -.10403500E-01, 0.94269200E-01, -.25386500E-01, 0.22206300E+00, 0.22661400E+00, -.35432300E-01, 0.12938400E+01, -.26085600E+00, 0.99164200E-01, 0.17170600E+00, -.10909400E+01, -.96876200E+00, 0.43909000E+00, 0.43628600E+00, 0.39564000E+00, -.36900600E+00, 0.11715400E-01, 0.40592600E+00, 0.54778600E+00, 0.21135500E+00, -.64404700E+00, -.35086700E+00, -.47161600E+00, -.30853800E+00, 0.19554400E+00, -.57839800E-01, -.14046200E+00, 0.44653200E-01, 0.12584800E+00, 0.28262800E+00, -.46844600E-01, 0.19319100E+00, -.28320800E+00, 0.24994200E+00, 0.32694200E+00, -.42740100E-01, 0.46212300E+00, 0.21100500E+00, -.28462200E+00, 0.57320800E+00, -.29624000E+01, 0.73037400E-01, -.63070700E+00, -.16278300E+00, -.19200800E+00, 0.16045200E-02, -.16878000E-01, 0.17072900E+00, 0.12181200E+00, -.24348900E-01, 0.32100600E+00, -.22977900E+00, -.97103900E-01, 0.39286700E+00, -.25996800E+00, -.17916600E+00, 0.15848000E+00, -.40157200E+00, -.10513500E+02, -.21023000E+00, -.91063700E+00, 0.31702300E+00, -.29077400E+00, -.20492300E+00, 0.31554200E-01, 0.57577200E-01, -.14573800E+00, -.20437200E+01, -.67512900E-01, 0.70989200E-01, 0.34311400E+00, -.58112400E+00, -.36944100E+00, -.13240400E+00, -.62641200E+00, 0.23826600E+00, -.56072900E+01, 0.13952600E+01, -.15368900E+01, -.95709900E+02, 0.50462900E+02, 0.49338800E+02, -.77905900E+01, -.63500000E+00, 0.24706500E+01, -.16250800E+03, 0.16011300E+01, -.15572500E+01, -.86663000E+02, 0.55304100E+02, 0.50945000E+02, -.90935200E+02, -.14909500E+02, 0.42447300E+02, 0.19683900E+02, 0.67313500E+02, -.24294900E+02, -.24481700E+03, 0.99259000E+02, 0.12126000E+03, 0.91669400E+02, -.65731500E+02, 0.14925200E+03, 0.18490600E+03, 0.15177800E+03, -.19096900E+02, 0.62156800E+03, -.28114000E+03, -.29643400E+03, -.27797000E+02, -.42197400E+02, -.15785800E+03, 0.31853800E+02, -.81557100E+02, -.81068300E+02, 0.48716100E+02, -.35922800E+02, -.28448300E+02, 0.11349500E+03, -.29512800E+02, 0.15195300E+02, 0.55433000E+02, 0.53113100E+02, -.54553300E+01, -.12443900E+03, 0.64435000E+02, 0.57261700E+02, 0.77793600E+01, 0.79193500E+01, 0.51407300E+02, 0.27234700E+02, 0.48597800E+02, 0.15086000E+02, 0.68487800E+02, -.39419500E+02, -.38997100E+02, 0.17779600E+02, -.87461300E+01, -.17225800E+02, -.53150300E+02, 0.53276300E+01, -.37369600E+02, -.11078400E+03, 0.57369800E+02, 0.55808800E+02, -.69690400E+02, -.18927100E+02, 0.38502400E+02, 0.51322300E+00, 0.55846800E+02, -.88041500E+01, -.12460800E+03, 0.67639100E+02, 0.60207200E+02, 0.33090300E+01, 0.36478000E+02, 0.43560000E+02, 0.18966700E+03, 0.93505400E+01, 0.54730200E+02, -.13436200E+03, 0.66368800E+02, 0.76476000E+02, -.45897300E+02, 0.20570000E+02, 0.48844200E+02, -.75086100E+02, 0.59760000E+02, 0.78830200E+01, -.18215800E+03, 0.88396000E+02, 0.10035200E+03, 0.44666900E+01, 0.50262300E+02, 0.22355000E+02, -.27850400E+03, 0.82134200E+00, 0.45270300E+02, 0.24516600E+03, -.12230200E+03, -.12280900E+03, -.13675000E+01, -.29101400E+02, -.60122800E+02, 0.59341900E+02, -.33627100E+02, -.29124300E+02, -.79389000E+02, 0.38759100E+02, 0.38894200E+02, 0.49077000E+02, -.16281900E+02, 0.29586300E+02, -.51255800E+02, 0.13842600E+02, 0.37164600E+02, -.24522400E+01, 0.98388400E+01, -.46099100E+01, 0.18602100E+01, 0.93876900E+01, 0.69802000E+00, -.26490900E+02, 0.13660700E+02, 0.47090200E+01, -.29214600E+02, -.68906200E+01, 0.12021800E+01, -.51972900E+01, 0.62143600E+02, -.92576100E+02, 0.19489800E+03, -.22045200E+03, -.29980600E+03, -.43159100E+02, -.14931000E+02, 0.53329600E+02, -.66632000E+02, 0.13253600E+02, -.20088800E+03, 0.27997900E+02, 0.36722200E+02 },
            { -.12079400E+00, 0.81508100E-01, 0.39328200E-01, -.44538500E-01, 0.43822300E-02, -.66852000E-02, 0.29180200E-01, 0.49547400E-02, 0.15430000E-02, 0.13356100E-01, 0.53166200E-01, 0.89757300E-01, -.25316600E-01, -.11608100E-01, 0.31461100E-01, -.18954200E-01, 0.61691900E-01, -.30238300E-01, 0.93795500E-02, 0.53536600E-01, 0.69172200E-01, 0.33864200E-01, -.33033900E-01, 0.55415700E-01, 0.13689700E-01, 0.27174500E-01, 0.11465100E-01, -.16467700E-01, 0.23208600E-01, -.28781700E-01, -.31779500E-01, -.12921700E-01, 0.51301800E-01, 0.34021700E-01, 0.35768200E-02, 0.13536500E+00, 0.69945100E-02, -.26228600E-02, -.41408900E-02, -.57335900E-01, -.69829000E-01, -.90152900E-02, 0.98286400E-02, -.21011400E+00, -.14939200E-01, 0.25024600E-01, -.26094600E-01, 0.64867300E-01, 0.64064300E-01, -.16172800E-01, 0.13604800E-02, -.59931700E-01, 0.23310300E-01, 0.89111400E-02, -.60842200E-02, -.10113100E-01, 0.17366800E+00, -.22716800E-02, -.13273300E-01, 0.27498800E-01, 0.30838500E-02, -.23313200E-01, 0.51751900E-02, -.20427600E-01, 0.16981000E-01, -.31386200E-01, 0.33418800E-03, 0.22293700E-01, -.14623600E-01, -.37251900E+00, -.13800600E-01, 0.61916600E-02, -.47045000E-02, 0.14362300E-02, 0.17231100E-02, -.84706900E-03, -.24732400E-02, -.44647500E-04, -.42667800E-01, 0.17192200E-01, -.51677100E-01, -.51389800E-01, 0.47903500E-01, -.79261300E-02, 0.50936100E-02, 0.28659900E-02, -.88139800E-01, -.69726800E-02, -.12616600E+01, -.11841500E+00, -.82932600E-02, 0.68239600E-02, 0.74037500E-02, 0.53506600E-02, 0.14211000E-01, -.41988800E-01, -.60233100E-01, -.38098300E+00, 0.12563000E-01, 0.11999600E+00, -.52162000E-01, -.46741400E-01, -.79837200E-01, -.15549600E+00, 0.20561800E-01, 0.90139800E-01, -.61819300E+00, -.22034300E+00, 0.12280100E+01, -.68013700E+00, -.22016400E+01, 0.70759000E+00, -.10708900E+02, 0.28985100E+01, 0.67964200E+01, 0.14985600E+02, -.89090300E+01, 0.13430800E+02, -.68410600E+01, -.79582000E+01, -.16497700E+01, -.44989600E+01, -.40473500E+01, 0.47134100E+01, -.30864100E+01, -.63146100E+01, -.18370400E+02, 0.96779800E+01, 0.93772600E+01, 0.13536400E+01, -.10261500E+00, 0.10592900E+02, 0.13145200E+02, 0.11181300E+02, 0.12596100E-01, 0.14239100E+02, -.72126900E+01, -.65937800E+01, 0.22717200E+01, -.39128900E+00, -.30114200E+01, 0.29795300E+01, -.58848200E+01, -.26866700E+00, -.33844600E+01, 0.22160900E+01, 0.22793300E+01, -.11677600E+01, -.24023000E+01, 0.56947800E+01, 0.87998000E+01, 0.11237700E+02, -.11008100E+01, -.14453500E+01, 0.74205400E+00, 0.12980400E+01, 0.77961100E+00, 0.53276400E+00, -.94988400E+00, -.35719400E+01, -.81875200E+00, 0.13459900E+01, 0.66536600E+01, -.32686500E+01, -.31166600E+01, -.25959600E+01, -.39119500E+01, 0.55674600E+00, 0.33496300E+01, 0.96536900E+00, -.53562200E+01, -.76558600E+00, 0.31454800E+00, 0.28702400E+00, -.27933700E+01, -.44909900E+01, 0.17901400E+01, 0.61953200E+01, 0.10938400E+01, -.41346500E+01, 0.15800100E+01, -.87098100E+00, -.27128500E+00, -.75424600E+00, 0.24382600E+01, -.38919800E+01, -.14222700E+01, -.10030900E+02, 0.35217700E+01, -.49475300E+01, 0.25382100E+01, 0.37536700E+01, -.42683100E+01, -.16331000E+01, 0.41247400E+01, 0.40713700E+01, 0.94297000E+00, -.38371200E+01, 0.19411400E+02, -.96594200E+01, -.12285400E+02, -.30649400E+01, -.58269200E+01, -.19066900E+00, 0.17152000E+01, 0.93647100E+01, -.88495400E+01, 0.23903500E+02, -.11968800E+02, -.11884900E+02, -.20306600E+01, -.37722600E+01, -.64979800E+01, 0.71092100E+00, -.39695400E+01, -.29915800E+01, -.78954000E+01, 0.39044600E+01, 0.46141300E+01, 0.51255900E+01, -.94894700E-01, 0.27664200E+01, -.15196700E+01, -.19462100E+00, 0.48122900E+01, 0.97725500E-01, 0.11170700E+01, 0.42134000E+00, 0.41332400E+00, 0.55140100E-01, -.46234800E+00, -.21065900E+00, 0.15696500E+01, -.39486000E+01, -.39490100E+01, 0.59728800E+00, 0.23691100E+00, 0.68222700E+00, 0.24832000E+01, -.57414900E+01, 0.72896800E+01, -.12441300E+02, -.86422300E+01, -.31030500E+01, 0.11417200E+01, 0.16006600E+01, 0.19947200E+01, 0.27949600E+01, 0.48026900E+00, -.12455600E+01, 0.28989800E+01 },
            { 0.35127900E+01, 0.45193100E+00, -.14941100E+01, 0.42199000E+00, -.17084600E+00, 0.10133200E+00, -.10366600E+01, -.34284500E+00, 0.65314800E+00, -.49533700E+00, 0.12335100E+01, -.47133500E+00, -.67619500E+00, 0.33917600E+00, -.16449700E+01, 0.71634400E+00, -.90797600E+00, 0.67194400E+00, 0.10713200E+01, 0.14934900E+00, -.72459500E+00, -.22716400E+01, -.13013700E+00, 0.73053400E+00, -.40236200E+00, -.79707200E+00, -.35064600E+00, 0.37020400E+00, 0.47432200E+00, 0.52933800E+00, 0.12005200E+00, 0.37742100E+00, -.16253200E+01, 0.67609700E+00, 0.95483300E+00, 0.84177000E+00, -.10442400E+00, 0.44537700E-01, 0.55495900E-01, 0.10013800E+01, -.31890400E+00, 0.13533500E+00, 0.26208000E+00, 0.60654300E+00, 0.53110000E-01, -.46133500E+00, -.44590800E-01, -.99769900E+00, 0.79974700E+00, 0.11746200E+00, 0.55380200E+00, -.27146900E+00, -.46635500E+00, -.18043700E+00, -.35438600E+00, -.14871400E+01, 0.57788500E+01, 0.16196800E+00, 0.12686900E+00, -.30394400E+00, 0.72832300E+00, -.11877300E+01, 0.29150000E+00, -.35090600E+00, -.13318900E+01, -.57840300E+00, -.89141000E+00, -.18636200E+01, 0.33813800E+01, -.19036400E+02, -.13024200E+01, -.25828300E+01, 0.69303800E+00, 0.80963300E+00, 0.10349300E+00, 0.13994700E+01, 0.41306400E+00, -.11042700E+01, -.46279900E+00, -.14682400E+01, -.20392700E+00, 0.12637000E+01, -.82331700E+00, 0.10029400E+01, -.78436100E+00, -.92457000E+00, 0.12281700E+02, -.25716300E+00, 0.17737800E+02, 0.26820200E+02, -.56627500E+01, 0.23064600E+01, 0.31370600E+01, 0.97387900E-02, -.38040600E+00, 0.64184200E+01, 0.10049100E+02, 0.79041800E+01, -.17735700E+00, -.82769600E+01, 0.26452500E+01, 0.41368700E+01, -.36631900E+00, 0.71113200E+01, 0.26970700E+01, 0.28005400E+01, -.49415300E+01, 0.21062300E+02, 0.98518800E+02, -.53433900E+02, -.15332500E+02, -.47753100E+02, 0.67050900E+03, -.48721700E+03, -.74627300E+03, -.13392200E+04, 0.61163900E+03, -.26321800E+04, 0.12917800E+04, 0.13778100E+04, 0.22784700E+03, 0.37063900E+03, 0.61709600E+03, -.50691200E+03, 0.14306400E+03, 0.62691800E+03, 0.18872200E+04, -.90881600E+03, -.95730100E+03, -.25949200E+03, 0.74070600E+03, -.81751300E+03, -.60431500E+03, -.11084400E+04, -.20421500E+03, -.29491700E+04, 0.13840700E+04, 0.14439100E+04, -.35810700E+03, -.78093400E+03, 0.13951700E+04, 0.76432800E+03, 0.11919200E+04, -.39586400E+03, -.53472600E+03, 0.26417800E+03, 0.23883800E+03, -.36648300E+03, -.37847000E+02, 0.11252500E+03, -.15127400E+03, -.27275000E+03, -.33136300E+03, 0.27587400E+02, -.88980200E+01, -.16025100E+03, -.22211300E+02, -.94151500E+02, 0.14038400E+03, 0.45707300E+03, 0.20172700E+03, -.17376800E+03, -.32109700E+03, 0.16424500E+03, 0.10088300E+03, -.49269300E+02, 0.20293900E+03, -.55986100E+02, -.24599300E+03, -.32518700E+03, 0.45707000E+03, -.11494900E+04, 0.56991900E+03, 0.58050800E+03, -.15236100E+03, 0.18731300E+02, 0.29463900E+03, -.14608200E+03, 0.29492000E+03, 0.26906200E+03, -.19820800E+04, 0.99169600E+03, 0.95767300E+03, 0.17893800E+03, 0.12633000E+03, 0.89564100E+03, 0.62213000E+03, 0.18892700E+04, -.17234300E+03, 0.47075000E+03, -.24231300E+03, -.77969300E+02, 0.51564100E+03, 0.21336100E+02, -.38962600E+03, -.18766300E+03, -.58459500E+03, 0.48098800E+03, -.76838300E+03, 0.37725200E+03, 0.48038600E+03, 0.43876300E+03, 0.55231800E+03, -.37202200E+03, -.62183800E+03, -.12405500E+04, 0.98511600E+03, -.22036500E+04, 0.11012100E+04, 0.11029700E+04, 0.31696100E+03, 0.55158400E+03, 0.65769800E+03, 0.17837000E+03, 0.63785800E+03, 0.32162600E+03, 0.53362500E+03, -.26402900E+03, -.31995700E+03, -.52004200E+03, -.13336900E+02, -.69977900E+02, 0.27399300E+03, 0.83847400E+02, -.49691800E+03, 0.51932200E+02, -.20997700E+03, 0.15506500E+02, -.11469800E+02, -.11073700E+03, 0.10751600E+02, 0.24828400E+02, -.24177900E+03, -.16455100E+01, 0.26840100E+03, 0.28167700E+02, -.94838100E+01, 0.26728500E+02, 0.24185000E+03, 0.17732200E+03, -.79254000E+03, 0.10822700E+04, 0.10332200E+04, 0.14882100E+03, 0.29985600E+02, -.11253100E+03, -.72604500E+03, -.16003400E+03, -.77887700E+03, 0.29197800E+03, -.32346800E+03 },
            { 0.65345300E+00, -.13062700E+00, -.25073500E+00, -.78816100E-01, -.93821500E+00, -.96186500E-01, -.28848700E+00, -.11065500E-01, 0.20554800E+00, -.19387100E+00, -.13811800E+00, -.25168300E+00, -.17576600E+00, 0.28085600E-01, -.11623800E+00, 0.13662000E+00, -.34644900E+00, 0.89100000E-01, 0.43447700E+00, -.10125600E+00, -.45624200E+00, -.24434300E+00, -.44108800E-01, 0.94323600E-01, -.13932300E+00, -.12456600E+00, 0.39992100E-01, 0.27269400E-01, -.88774000E-02, 0.15217100E-01, 0.51927900E-01, 0.50038400E-01, -.16530400E+00, -.27299200E-01, 0.61011200E-01, 0.63485600E-01, -.14594100E-01, 0.59553000E-02, 0.39577500E-02, 0.28478100E+00, -.74192500E-02, 0.63141900E-01, 0.53592700E-01, 0.41506900E-01, -.61498700E-01, -.13822800E+00, 0.29884100E+00, -.60195300E+00, 0.18709200E+00, -.19898200E+00, 0.15508800E-01, -.12658600E+00, -.21250700E+00, 0.47427800E-01, 0.14821100E+00, -.20074700E+00, -.70179700E+00, -.15985700E-01, 0.93801800E-01, -.19810300E+00, 0.68754100E-01, -.44996900E-01, 0.55710700E-01, 0.13032100E+00, 0.12304900E+00, -.21013700E+00, -.53108100E+00, -.12948700E+00, 0.61185900E-01, 0.18252900E+00, 0.25057600E-01, -.14573300E+00, -.15689100E-01, -.33267900E-01, 0.40256300E-01, 0.93075300E-01, 0.11257300E+00, 0.64177700E-01, 0.17363700E+00, 0.16402300E+00, -.24246200E-01, 0.59834800E-01, 0.17347000E+00, 0.44742000E-01, -.79803200E-01, -.78365000E-01, -.48211300E+00, -.12390300E+00, -.87827500E+00, -.25072000E-01, 0.22487400E+01, -.70474700E-01, -.19104900E-01, -.79026500E-02, 0.17088500E-01, -.12209500E+00, -.83711000E-01, -.17866400E+00, 0.14602000E-01, 0.20770200E+00, -.25809700E+00, -.11351800E+00, -.74405500E-01, -.32184600E+00, -.73661400E-02, 0.46549800E-01, 0.30164300E+00, -.30830600E+00, -.94513200E+01, 0.51228200E+01, 0.35105100E+01, -.32210700E+00, -.50915500E+01, 0.78281500E+01, 0.20236200E+01, 0.12849500E+02, -.38347100E+00, 0.45778900E+00, 0.15902200E+01, 0.18929700E+01, 0.62828100E+01, -.84000000E-01, 0.27151900E-01, 0.71960100E+01, -.62029300E+01, -.41792700E-01, 0.20765900E+02, -.14398000E+02, -.11119500E+02, 0.12466300E+02, 0.21951600E+01, -.14898400E+02, -.25726400E+02, -.21590400E+02, 0.53486300E+01, -.49830800E+02, 0.27388100E+02, 0.16124400E+02, 0.17540900E+02, 0.45376100E+01, 0.16547600E+02, 0.16791400E+02, 0.14869600E+02, 0.83777900E+01, 0.25519700E+02, -.16142800E+02, -.14677200E+02, 0.19421100E+00, -.96650800E+01, -.77790100E+01, -.88206200E+01, 0.19160500E+01, -.49124900E+01, -.46356200E+01, 0.31308100E+01, -.16625800E+01, 0.67986900E+01, 0.35743800E+00, 0.24690200E+01, -.44611900E+01, 0.12803400E+01, -.10807600E+00, 0.10006200E+02, -.59616800E+01, -.34828800E+01, -.51240700E+01, -.67758400E+01, 0.25574400E+01, 0.26030800E+01, 0.12733500E+02, -.82971400E+01, 0.13180600E+02, -.62300800E+01, -.59952200E+01, 0.51747900E+01, -.97662200E+01, 0.42819200E+01, 0.17500200E+02, 0.15792600E+02, -.86229900E+01, 0.90284900E+01, -.32661200E+01, -.72744800E+01, 0.54840000E+01, 0.22632700E+01, -.69330800E+01, 0.42713200E+01, -.11269400E+02, 0.10822400E+01, -.40428300E+02, 0.19744700E+02, 0.27914900E+02, -.91070100E+01, 0.17523700E+01, 0.85832800E+01, -.40884900E+01, 0.14136500E+02, 0.80996700E+01, -.25959500E+02, 0.12150300E+02, 0.13235300E+02, -.67942900E+01, 0.45014800E+01, 0.10796900E+02, -.13222700E+02, 0.19782400E+02, 0.66540900E+01, 0.35676700E+02, -.17853000E+02, -.18046000E+02, -.13247100E+01, -.77454400E+01, -.10011900E+02, -.20929600E+01, -.57789000E+01, -.84988000E+01, -.35089300E+02, 0.17318100E+02, 0.11480600E+02, 0.83591900E+01, 0.63647500E+01, 0.12535900E+02, -.19961300E+01, 0.73237500E+01, 0.82543800E+01, -.42855700E+00, 0.12239000E+00, 0.27965500E+00, 0.16735900E+00, 0.29506900E+01, -.42969000E+00, -.29692600E+01, 0.65225200E+00, -.71390900E+00, -.55951100E+01, -.38644300E+00, 0.12609100E+00, -.49520000E+00, -.28776600E+01, 0.60446700E+01, 0.63372300E-01, -.22498700E+02, 0.56885300E+01, -.98574700E+01, -.50855400E+01, -.18721200E+01, -.18011400E+01, -.55892300E+01, 0.10840900E+01, 0.43278200E+01, 0.18582800E+01 },
            { -.32537100E+00, -.11990100E+00, 0.83754800E-01, 0.24683000E-01, 0.16676900E+00, 0.53199100E-02, 0.12750300E+00, 0.28374400E-02, -.81955100E-01, 0.16623600E+00, 0.21296400E+00, 0.39787400E+00, -.76471300E-01, -.79762900E-01, 0.19109100E+00, -.93063100E-01, 0.50556600E-01, -.13270200E-02, -.17198000E+00, -.20418300E-01, 0.16902400E+00, 0.16722700E-01, 0.24915700E-01, -.52260400E-01, 0.20776500E-01, 0.22481800E-01, -.39011300E-01, 0.99195200E-02, -.38184400E-01, 0.12549800E-01, 0.35141900E-01, 0.72818700E-01, 0.36931700E-01, -.16262200E-01, 0.11681000E-02, -.14799700E-01, 0.83236300E-01, -.33113900E-01, -.47276600E-01, 0.27675600E+00, 0.47038300E+00, -.14990900E+00, -.11181300E+00, -.21594400E+00, 0.91095800E-01, 0.49178400E-01, -.71114300E-01, 0.18491300E+00, -.33026800E+00, 0.14812300E-01, -.36039300E-01, -.22337900E-01, 0.75600700E-01, -.45609000E-01, -.14699200E-01, -.53864300E-01, 0.29484200E+00, 0.10327900E-01, -.66139400E-01, 0.81028800E-01, -.63371600E-01, -.14948800E-01, -.91373300E-02, 0.50581200E-02, -.34460200E-01, 0.37743700E-01, 0.16439000E-01, 0.99329500E-01, 0.12651400E+00, -.11189900E+01, -.27531700E-01, -.17718700E-01, 0.47500300E-01, -.75884900E-02, -.23244100E-02, -.70238100E-01, -.37025100E-01, -.37651600E-01, -.23568400E-01, -.34019100E-01, 0.11354100E+00, 0.39769400E-01, -.10582000E+00, 0.32896200E-03, 0.68701600E-01, -.31358400E-02, 0.94081600E-01, 0.84435600E-01, 0.35376000E+00, 0.96043000E-02, 0.12923200E-01, 0.28709400E+01, -.13249400E-01, -.53846100E-02, -.12958600E-01, 0.12816300E-01, -.29066200E-01, 0.82363100E-01, -.16733200E-01, -.75655800E-01, 0.21317400E+00, 0.46525900E-01, 0.96589100E-01, 0.17213100E+00, -.33858400E-01, -.11053800E+00, -.19209400E+00, 0.19821300E+00, 0.24243500E+02, -.12609200E+02, -.10587700E+02, -.18323400E+01, 0.27523600E+01, -.80569700E+01, 0.12474600E+00, -.16225300E+02, -.19532300E+01, 0.32891200E+01, -.35269100E+01, -.16380600E+01, 0.16018700E+01, 0.80351900E+01, -.56571900E+01, -.14009000E+02, -.12613900E+02, 0.30758700E+01, -.63699600E+02, 0.35403200E+02, 0.32076000E+02, -.33110800E+02, -.10979900E+02, 0.27855800E+02, 0.22426800E+02, 0.27305400E+02, 0.58319300E+01, -.64341400E+01, -.10254900E+01, 0.42829800E+01, 0.25055500E+01, -.59904800E+00, -.20990600E+01, -.23013000E+01, 0.39589800E+01, -.28463800E+01, -.44425000E+02, 0.22885400E+02, 0.22554200E+02, -.17303600E+02, -.18199700E+01, 0.21253400E+02, 0.25088900E+02, 0.18538700E+02, 0.38591800E+01, 0.12367600E+01, -.77771200E+00, 0.20234300E+01, -.42325300E+01, 0.59145500E-01, -.78830300E+00, -.60598700E-01, -.21576300E+01, -.21939700E+01, -.34893700E+01, 0.24226300E+01, 0.25960700E+01, 0.50238800E+01, 0.25328600E+01, -.90554900E+00, -.20745900E+01, -.65328000E+01, 0.68392300E+01, 0.20928000E+02, -.11090000E+02, -.10821600E+02, 0.37902500E+01, 0.95623400E+01, -.10845700E+02, -.12359100E+02, -.20656400E+02, 0.59224500E+01, 0.17548400E+02, -.97781400E+01, -.83450600E+01, -.39312500E+01, -.30477700E+01, -.45766500E+01, -.13604700E+02, -.76729500E+00, -.89293200E+01, 0.16854700E+02, -.76076000E+01, -.14073700E+02, -.38652300E+01, -.25813500E+01, -.15502200E+00, 0.83526200E+01, -.23484400E+01, -.12987500E+02, 0.28704900E+02, -.12915800E+02, -.12811600E+02, -.40023800E+01, -.10444400E+02, -.52725000E+01, 0.21773900E+02, -.10718400E+02, -.10401900E+02, -.77473500E+01, 0.38793500E+01, 0.37717000E+01, -.20080000E+01, 0.26045300E+01, 0.38453900E+00, -.70646000E+01, -.28781300E+01, -.79444700E+00, 0.23253500E+02, -.11593200E+02, -.10020000E+02, 0.12872600E+01, -.21897100E+01, -.11381900E+02, -.44119400E+01, -.13048000E+02, 0.55351100E+00, -.24111200E+00, 0.26964300E+01, -.83648900E+00, -.51654300E-01, 0.12062400E+01, 0.28578700E+00, -.14978600E+01, 0.24532500E+01, 0.20634900E+00, 0.29903300E+01, -.76806900E-01, -.24014500E-01, -.15124800E-01, 0.32561700E+01, -.71450400E+01, -.16696400E+02, -.19563800E+02, 0.30454700E+01, 0.47130200E+01, 0.12999900E+01, -.22230300E+01, 0.11703100E+01, 0.44683300E+01, 0.62557300E+01, 0.11560000E+01, 0.98301300E+00 },
            { -.31837200E+00, 0.56896300E-01, 0.23669700E+00, -.74722700E-01, 0.20287500E+00, 0.48367400E-01, 0.17536700E+00, -.58706900E-02, -.14775900E+00, 0.64732200E-01, 0.11463900E+00, 0.39719900E+00, 0.16209100E-01, -.87788500E-01, 0.89820600E-01, -.88496000E-01, 0.13881700E+00, -.30409200E-01, -.22853100E+00, -.37800600E-01, 0.21165600E+00, 0.70033800E-01, 0.62998600E-01, -.15521000E+00, 0.61533500E-01, 0.82872100E-01, -.22644100E-01, -.13006300E-01, -.12168900E-01, 0.82027800E-02, 0.13330000E-01, -.12791600E-01, 0.67198200E-01, -.68042600E-01, -.35227500E-01, -.77568500E-01, -.34930800E-01, 0.13554700E-01, 0.20990400E-01, -.15426800E-01, 0.15920700E-02, 0.18955800E-01, -.45223900E-01, -.32895600E-02, 0.71307700E-01, 0.44038300E-01, -.12872000E+00, 0.25510700E+00, -.32930900E+00, 0.18892700E+00, 0.40987500E-02, 0.25660300E+00, 0.11859500E+00, -.10548600E+00, -.36573600E-01, 0.68400300E-01, 0.16985600E+00, 0.23229300E-01, -.78963700E-01, 0.83688900E-01, -.25417200E-01, 0.32548000E-02, -.23521500E-01, -.28665800E-01, -.45194700E-01, 0.62672600E-01, 0.16700100E+00, -.64362500E-01, 0.38071900E-01, -.11906200E+00, 0.22353000E-02, -.36788100E-01, 0.54149500E-02, 0.14278900E-01, -.13669800E-01, -.22366000E-01, -.51847600E-01, -.39098600E-01, -.50382900E-01, -.88199300E-01, 0.10724800E+00, 0.42269900E-02, -.91606600E-01, 0.34413500E-01, 0.34298200E-01, 0.23510500E-01, 0.53323100E-01, 0.56091600E-01, 0.12761700E+00, -.18150100E-02, -.71385900E-02, 0.10556200E-01, 0.18143800E+01, -.13036100E-02, -.11502100E-01, 0.48044800E-01, 0.11292100E-01, 0.73383000E-01, -.16349100E-01, -.10218600E+00, 0.11219100E+00, 0.60958500E-01, 0.99796800E-01, 0.17420400E+00, -.25688400E-01, -.71493700E-01, -.19527100E+00, 0.21438600E+00, 0.17380500E+02, -.88281300E+01, -.61972300E+01, -.19944400E+01, 0.87431200E+01, -.65815400E+01, 0.44678800E+00, -.14643800E+02, 0.27590100E+00, 0.32265500E+01, -.20825600E+01, -.23091100E+01, 0.79879400E+00, 0.90656500E+01, -.31209000E+01, -.85899700E+01, -.64230100E+01, 0.39563300E+01, -.32846600E+02, 0.17036900E+02, 0.16887100E+02, -.14568200E+02, -.10851300E+02, 0.12768700E+02, 0.82229800E+01, 0.17863100E+02, 0.13319800E+01, 0.19332500E+02, -.10358700E+02, -.61611900E+01, -.29322400E+01, 0.90062900E+01, -.13757400E+02, -.15298300E+02, -.13225500E+02, 0.40103500E+00, -.14698200E+02, 0.72972400E+01, 0.81881400E+01, -.75173400E+01, 0.17022700E+01, 0.53544200E+01, 0.84053900E+01, 0.43377500E+01, 0.43255800E+01, 0.11693500E+02, -.60238700E+01, -.81145900E+00, -.40453100E+01, -.10545700E+01, -.26741000E+01, 0.20373500E+01, -.27733200E+01, -.46702200E+01, -.35747400E+01, 0.20481300E+01, 0.28428600E+01, 0.44359800E+01, 0.26426200E+01, -.17037500E+01, -.16004400E+01, -.51458500E+01, 0.66113100E+01, 0.87750900E+01, -.45124500E+01, -.48476300E+01, 0.38604800E+01, 0.97693100E+01, -.67537700E+01, -.12158700E+02, -.15624200E+02, 0.68462900E+01, 0.93222500E+01, -.50341700E+01, -.33482800E+01, -.32180500E+01, -.38563600E+01, -.13520600E+01, -.11030400E+02, 0.56052200E+01, -.69869200E+01, 0.28815900E+02, -.14177400E+02, -.25088300E+02, -.23912700E+01, -.32932500E+01, -.24275400E+01, 0.68572300E+01, -.66565400E+01, -.12715000E+02, 0.15967900E+02, -.75298700E+01, -.61937500E+01, -.99433800E+00, -.55133500E+01, -.41747100E+01, 0.16764900E+02, -.97842700E+01, -.65473100E+01, -.24157200E+02, 0.12071000E+02, 0.11975600E+02, 0.13046100E+01, 0.34673200E+01, 0.62322600E+01, -.27623700E+01, 0.56607100E+01, 0.19738100E+01, 0.31614200E+02, -.15725400E+02, -.12430700E+02, 0.46099100E+00, -.13973100E+01, -.15378300E+02, -.69331300E+01, -.16169900E+02, -.16045200E+01, 0.16113600E+00, 0.25243300E+00, -.30374700E+00, -.44512700E-01, -.29703900E+00, 0.25701300E+00, 0.12610400E+01, -.17606000E-01, 0.27883400E+00, 0.29183300E+01, 0.11352900E+00, -.36860000E-01, 0.17646900E+00, 0.64053900E+00, -.35836200E+01, -.59846400E+01, 0.35384900E+01, 0.15227100E+00, 0.31683700E+01, 0.10641700E+01, -.24056300E+01, 0.15295000E+01, 0.57346900E+01, 0.48946200E+01, 0.77290900E+00, -.27017100E+01 },
            { -.33786500E-01, -.32908800E-01, -.37003700E-01, 0.91802000E-01, 0.98375300E-01, 0.14006100E-01, 0.20836400E-01, -.53719300E-02, -.21739600E-01, 0.31579100E-01, -.98364500E-03, -.39518800E-02, 0.60406000E-01, -.11781200E-01, 0.24818600E-01, -.21612100E-01, 0.49048700E-01, -.10116300E-01, -.41503300E-01, -.64133800E-02, 0.39983700E-01, -.22756100E-01, 0.12774300E-01, -.48982100E-01, 0.15367000E-01, 0.28802200E-02, -.75048000E-02, 0.10755300E-02, -.50116100E-02, 0.16487900E-01, 0.27795600E-03, -.20206400E-02, 0.28417800E-02, -.10123500E-01, 0.55926100E-04, -.58289700E-01, 0.18168800E-01, -.72756500E-02, -.10197900E-01, 0.40966000E-01, 0.69612700E-01, -.26506500E-01, -.13869000E-01, -.29031700E-01, 0.77849300E-02, 0.20785000E-01, -.22424100E-02, 0.72100900E-01, -.47082300E-02, 0.58622000E-02, -.51946800E-01, -.46744400E-03, 0.64224800E-03, 0.19532300E-01, -.69253200E-03, 0.23379300E-01, -.46182100E-01, -.27456600E-02, -.17625000E-02, 0.11261100E-01, -.15595100E-01, 0.22675300E-01, -.13076900E-01, -.11398900E-03, -.23821200E-01, 0.35676400E-01, 0.40054000E-01, 0.52557700E-01, -.81659700E-02, -.16716900E-02, -.25432300E-02, 0.44940200E-01, -.83581900E-04, -.64288300E-03, -.93295500E-02, -.17931200E-01, -.16821200E-01, 0.65310500E-02, 0.58452100E-02, 0.78353700E-02, -.90020000E-02, -.19162300E-02, 0.86978300E-02, -.13687900E-01, 0.47668200E-02, -.41857800E-02, 0.28651500E-01, -.26433900E-01, 0.57532100E-01, 0.14531700E-02, 0.25390500E-02, -.76342900E-03, -.80574600E-02, 0.12467400E+00, 0.85785600E-03, 0.31396800E-02, 0.11436600E-01, 0.11366500E-01, 0.18316000E-02, 0.21822600E-03, 0.22746000E-02, -.21807100E-01, -.18031900E-01, 0.12305900E-01, 0.34910200E-02, 0.16020600E-01, -.15802300E-02, -.15124700E-02, -.70589600E+01, 0.35507700E+01, 0.31524500E+01, -.24065200E+01, -.86248100E+00, 0.24113600E+01, -.30724800E+01, 0.11671200E+01, -.30265400E+00, -.48168900E+01, 0.25893700E+01, 0.18170000E+01, -.46274400E+01, -.11632700E+01, 0.26572900E+01, 0.14024000E+01, 0.41628800E+01, -.14014500E+01, -.29913900E+02, 0.14485100E+02, 0.14980900E+02, -.47515300E+01, -.35766300E+01, 0.15094400E+02, 0.14897800E+02, 0.14195300E+02, -.46526000E+00, 0.16576400E+02, -.72932400E+01, -.77210500E+01, -.26211700E+01, -.36518400E+01, -.27874600E+01, 0.41227300E+01, 0.62411000E+00, -.36771500E+01, -.10326600E+02, 0.51806700E+01, 0.53040500E+01, 0.27194400E+01, 0.10479400E+01, 0.46387000E+01, 0.44025900E+01, 0.27903900E+01, 0.17288900E+01, -.38749300E+01, 0.18572500E+01, 0.25267900E+01, -.94505200E+00, 0.14987700E+00, 0.15157200E+01, 0.10330800E+01, 0.72219400E+00, 0.55288600E+00, 0.58513700E+00, -.31732900E+00, -.47487500E+00, 0.47070200E+00, 0.56885700E+00, -.73976600E+00, -.90951400E+00, -.16883100E+01, 0.47975800E+00, -.80602200E+00, 0.45567100E+00, 0.63641200E+00, -.46215700E+01, -.21255600E+00, 0.50010100E+00, 0.15828800E+01, -.68036100E-01, -.69185300E+00, -.54089000E+00, 0.28920100E+00, 0.61625900E+00, -.78285600E-01, 0.10595900E+01, 0.42345400E+00, 0.38747700E+01, -.75833300E+00, 0.54735100E+00, -.75045800E+00, 0.38297000E+00, -.20232400E+00, -.53038900E+00, 0.64315700E+00, 0.27114200E+00, -.19039300E+00, 0.12303900E+01, -.61771700E+00, -.82578300E+01, 0.41063700E+01, 0.29368300E+01, -.38937500E-01, 0.11673700E+01, 0.17035100E+01, -.56452400E+01, 0.56061400E+00, 0.14523200E+01, 0.47220600E+01, -.23636700E+01, -.23345800E+01, -.21347500E+00, 0.42781900E-01, -.11600400E+01, 0.13596400E+01, -.10536300E+01, -.20211600E+00, -.24810800E+01, 0.12242400E+01, 0.12583600E+01, 0.39435600E+00, -.11882300E+01, 0.91067000E+00, -.69723400E+00, 0.43051500E+00, 0.94655400E+00, -.30699500E-01, 0.92277000E-01, 0.37033100E+00, -.29798900E-01, 0.97595800E+00, -.12986900E-02, 0.33150900E+00, 0.15293300E+00, 0.26571300E+00, 0.10897200E+00, -.22730800E-02, -.14589200E-01, 0.37432100E-02, 0.12897300E+01, -.27452600E+01, 0.47171600E+01, -.15575800E+01, -.10485900E+02, 0.59668500E+00, 0.33955400E+00, 0.15727700E+01, -.11645200E+01, 0.29765600E+00, -.35299900E+01, -.43409400E+00, 0.17673300E+01 },
            { -.96561000E-01, -.89668300E-01, 0.43713500E-02, 0.44672900E-01, 0.22106600E+00, 0.29391400E-01, 0.46347500E-01, -.12780100E-01, -.58377000E-01, 0.44232100E-01, 0.95733000E-02, 0.41386700E-01, 0.29591800E-01, -.13638700E-01, 0.22348700E-01, -.27689200E-01, 0.48856300E-01, 0.81715500E-02, -.63236200E-01, -.25692100E-01, 0.65043400E-01, -.20673800E-01, 0.71435000E-01, -.70168900E-01, 0.11987200E-01, 0.14777600E-01, -.24196400E-01, -.82853000E-02, -.65226800E-02, -.49947900E-02, -.35110200E-01, -.13934900E-01, 0.79415100E-02, -.24994600E-01, -.13390500E-01, -.16194600E+00, 0.10480800E-01, -.41445100E-02, -.55564300E-02, 0.28843300E-01, 0.56670000E-01, -.25278400E-01, -.23522500E-01, -.33179400E-01, 0.15906500E-01, 0.15576300E-01, -.39625800E-01, 0.73822800E-01, -.68498100E-01, 0.22973500E-01, 0.44180400E-02, 0.78897100E-02, 0.32991100E-01, -.15991300E-01, -.11074300E-01, -.12567300E-02, 0.12050400E+00, 0.36934500E-02, -.16004800E-01, 0.28867700E-01, -.68203000E-02, -.79461700E-02, 0.11375000E-02, -.93449800E-02, -.69592300E-02, 0.96475500E-02, 0.24380000E-01, 0.20219200E-01, 0.15020000E-01, -.24309200E+00, -.62408400E-02, -.76390600E-03, 0.48578000E-02, 0.40285700E-03, -.91013100E-03, -.96501500E-02, -.77572700E-02, -.84574100E-02, -.17169600E-01, -.14689600E-01, 0.67819600E-02, 0.71607300E-03, -.22686900E-01, -.81406700E-03, 0.14379200E-01, 0.54346300E-02, 0.35889500E-01, 0.35642400E-01, 0.10707300E+00, 0.41270000E-02, 0.40014900E-02, 0.35851500E-02, -.39260500E-03, -.10163800E-01, 0.13055800E+00, 0.13360100E-02, -.14885100E-01, 0.15862600E-01, -.39614900E-02, -.15685400E-01, 0.49336400E-01, 0.17791300E-01, 0.17461200E-01, 0.41151600E-01, -.87029700E-02, -.35930400E-01, -.50551300E-01, 0.49066300E-01, 0.61694100E+01, -.32169400E+01, -.28878900E+01, 0.50814700E+00, -.14852600E+00, -.17748500E+01, 0.22691300E+01, -.18470000E+01, -.85800600E+00, 0.44685900E+01, -.27961400E+01, -.24719300E+01, 0.10443600E+01, 0.92184500E+00, -.23511300E+01, -.27030200E+01, -.29290800E+01, 0.14248900E+00, -.79939100E+01, 0.51836700E+01, 0.41078200E+01, -.59274300E+01, -.87782300E+00, 0.34380400E+01, 0.36126100E+01, 0.38078800E+01, 0.40013400E+00, -.42937700E+01, 0.85011900E+00, 0.27360700E+01, 0.24980200E+00, 0.14829800E+01, -.27658800E+00, -.33839700E+01, -.12333700E+01, 0.10139800E+01, -.78585700E+01, 0.44509000E+01, 0.41899300E+01, -.43168100E+01, 0.62249900E+00, 0.35639800E+01, 0.44484200E+01, 0.27425700E+01, 0.61851200E+00, 0.24868900E+01, -.13264900E+01, -.61276500E+00, -.71317900E+00, 0.13494200E+00, -.13578700E+01, -.61838100E+00, -.11157900E+01, -.24907400E+00, -.14900500E+01, 0.96803200E+00, 0.85528200E+00, 0.58137700E+00, 0.52971900E+00, 0.11766900E+00, -.19388900E+00, -.12223400E+01, 0.13953600E+01, 0.33689700E+01, -.18408700E+01, -.18385100E+01, 0.13072700E+01, 0.18566100E+01, -.21154300E+01, -.32420500E+01, -.43607400E+01, 0.14441100E+01, 0.29574300E+01, -.17799100E+01, -.12149600E+01, -.12781900E+01, -.10545900E+01, -.92481400E+00, -.42218500E+01, -.19984300E+00, -.17849800E+01, 0.58042100E+01, -.27327500E+01, -.40685200E+01, 0.21785100E+00, -.55421400E+00, -.62513600E+00, 0.19281100E+01, -.14698300E+01, -.26693900E+01, 0.10537000E+02, -.49612700E+01, -.51876600E+01, -.24752500E+00, -.25605800E+01, -.19098300E+01, 0.73153200E+01, -.20719000E+01, -.30402900E+01, -.39446700E+01, 0.19705100E+01, 0.19795700E+01, -.26992300E+00, 0.79683900E+00, 0.85121400E+00, -.12156200E+01, -.12306800E+00, 0.43182300E+00, 0.49631700E+01, -.24547600E+01, -.17469300E+01, -.40763600E+00, -.42076500E+00, -.21510700E+01, 0.41375900E+00, -.20721300E+01, -.31117700E+00, -.75438800E-01, 0.48719800E+00, -.27600300E+00, -.48354000E-03, -.23284900E+00, 0.12269100E+00, -.52470100E-01, 0.38446900E+00, 0.44996100E-02, 0.10172900E+01, -.31003500E-01, 0.18528100E-02, -.15419400E-01, -.14358800E+00, -.64760800E+00, -.45528300E+01, -.20122400E+00, 0.39824100E+01, 0.16330800E+01, 0.39257200E+00, -.58164900E+00, 0.91421100E+00, 0.11378000E+01, 0.32784200E+01, -.13353600E+00, -.10951400E+00 },
            { -.17359900E+00, 0.51187100E-01, 0.88384200E-01, -.32574500E-01, 0.14032700E+00, 0.24644900E-01, 0.47832800E-01, 0.33682900E-01, -.57117700E-01, 0.42797700E-01, 0.40241700E-01, 0.59232000E-01, -.80152600E-02, -.27075900E-02, -.11597100E-01, -.86455500E-02, 0.53518500E-01, -.69718300E-01, -.75012700E-02, 0.45451300E-01, 0.39241600E-01, 0.77221400E-01, -.88260500E-01, 0.18414300E+00, 0.25415800E-01, 0.18349500E-01, 0.28621900E-01, 0.27230400E-01, 0.16260300E-01, -.26941000E-01, -.84563600E-02, 0.83562700E-02, 0.26426700E-01, 0.83713700E-02, -.19112900E-01, -.41713100E-01, 0.84628300E-02, -.31492600E-02, -.48263200E-02, -.11210200E+00, -.64294600E-01, -.17323100E-01, -.11469800E-01, 0.22135300E-02, 0.49862100E-02, 0.18286700E-03, -.27113400E-01, 0.31160300E-01, 0.93713800E-01, 0.22201400E-03, 0.94813900E-01, -.73271800E-01, 0.32438800E-01, -.29761900E-03, -.37616700E-01, 0.13093800E-01, 0.28901200E+00, -.10684300E-01, -.43382500E-01, 0.32367900E-01, 0.44333300E-02, -.21371100E-01, -.92372200E-02, -.22479800E-01, 0.48381100E-02, -.31087600E-01, 0.78941100E-01, -.60403600E-02, -.23545900E-01, -.99451600E-02, -.93485800E-02, 0.60683100E-01, 0.30390300E-01, 0.58181700E-02, -.59880800E-02, -.98296200E-02, -.11727900E-01, -.10782000E-01, -.78430600E-01, -.57053200E-01, 0.35720400E-01, -.34921200E-01, -.29363400E-01, -.27963600E-02, 0.11356400E-01, 0.28244800E-01, 0.44246800E-01, 0.24299300E-01, 0.28699500E-01, -.28049500E-02, -.14231300E-01, 0.54984600E-02, 0.10278100E-01, -.89042200E-02, -.24825900E-01, 0.64786400E+00, 0.41289800E-01, 0.29887700E-01, -.34363300E-02, -.49806000E-01, 0.26286400E-01, 0.32532700E-01, 0.37867000E-01, 0.55102600E-01, 0.57767200E-02, 0.16421200E-01, -.48570600E-01, 0.64015600E-01, 0.70335400E+01, -.35403200E+01, -.29348000E+01, 0.10086300E+01, 0.27569900E+01, -.34921200E+01, 0.14384200E+01, -.37766300E+01, 0.57235100E+00, 0.19144600E+01, -.10786800E+01, -.10593400E+01, 0.11081900E+01, 0.14555100E+00, -.10372000E+01, -.18309600E+01, 0.87055100E-01, 0.52679700E+00, 0.26359900E+02, -.13073300E+02, -.13054000E+02, 0.32851100E+01, 0.33767400E+01, -.11163500E+02, -.86799400E+01, -.87197700E+01, -.13971800E+01, 0.55703000E+01, -.25794200E+01, -.16518100E+01, -.24714300E+01, 0.34736200E-01, -.31332100E+01, -.39772500E+01, -.35148300E+01, -.68201400E+00, 0.38130400E+01, -.15780900E+01, -.16726900E+01, -.11178100E+01, -.48447200E-01, -.20497400E+01, -.18789200E+01, -.19813300E+01, -.11547600E+01, 0.28951600E+01, -.16232700E+01, -.47919500E+00, -.13746100E+01, -.98860500E+00, -.55394500E+00, 0.34629600E+00, -.70158400E+00, -.85092900E+00, -.10771900E+01, 0.70136200E+00, 0.60271900E+00, 0.95614800E+00, 0.13912100E+01, -.70233100E+00, 0.40372800E+00, -.13248100E+01, 0.14065400E+01, -.10396900E+01, 0.58083300E+00, 0.33134300E+00, 0.25216500E+01, 0.28867100E+01, -.21677100E+01, -.47468900E+01, -.36145500E+01, 0.22205300E+01, -.11162700E+01, 0.42585400E+00, 0.89591900E+00, -.19170600E+00, -.13795400E+00, 0.12171700E+01, -.36306000E+01, 0.20225200E+01, 0.58882600E+00, 0.98923600E+01, -.50108000E+01, -.70487000E+01, 0.29563600E+01, -.12782700E+01, -.27880800E+01, 0.10823600E+01, -.44462100E+01, -.71350700E+00, 0.96649700E+01, -.48967000E+01, -.42175200E+01, 0.17071800E+01, -.17830000E+01, -.41198900E+01, 0.48706800E+01, -.39973200E+01, -.25597000E+01, -.12510500E+02, 0.62464800E+01, 0.62383300E+01, 0.17519200E+00, 0.14487200E+01, 0.32206900E+01, -.16164700E+01, 0.23728500E+01, 0.23209500E+01, 0.91986200E+01, -.45352900E+01, -.35464700E+01, -.23291900E+01, 0.85281900E-01, -.33281400E+01, 0.69723200E+00, -.18727500E+01, -.29941200E+01, 0.28921800E+00, -.20845900E+00, -.59984200E-01, -.32626200E-01, -.11444700E+01, 0.52717900E-01, 0.72153000E+00, -.30965700E+00, -.34772500E-02, 0.43902300E+00, 0.19061600E+00, -.34776200E-01, 0.20419300E+00, -.98681300E+00, 0.79505600E+00, -.20653800E+01, 0.76671700E+01, 0.47600800E+01, 0.11301900E+01, 0.76573800E+00, -.88288000E+00, 0.18251900E+01, 0.74328400E+00, 0.13437200E+01, -.15588700E+01, -.21386300E+01 },
            { 0.33048100E-01, -.37395200E-02, 0.44640600E-02, -.10023700E+00, -.16358300E+00, -.36068900E-02, -.14894200E-01, 0.44718400E-01, 0.53511000E-01, -.26705100E-01, -.36953200E-01, -.89500600E-02, -.95636300E-02, 0.13710500E-01, 0.25954000E-01, 0.91287400E-02, -.51663700E-01, -.23463400E-01, 0.50743600E-01, -.21191400E-01, -.47904000E-01, 0.17450900E-02, -.63746200E-01, -.66824800E-01, 0.81753000E-02, 0.66372800E-02, 0.48635900E-01, 0.55265800E-02, 0.64196700E-02, 0.14052600E-01, 0.52060000E-01, -.17057500E-01, 0.32309100E-02, -.15841000E-01, -.66846400E-02, 0.77764200E-01, -.19237800E-01, 0.73430400E-02, 0.10896200E-01, -.10105700E+00, -.86142000E-01, 0.40901300E-01, 0.37450900E-01, 0.50747400E-01, -.88038400E-02, -.27185900E-03, 0.46191600E-01, -.12442900E-01, 0.48100100E-01, -.19915000E-01, -.47474200E-01, 0.18880900E-01, -.42971300E-01, 0.24179800E-01, -.91048800E-02, 0.33102500E-01, -.12696900E+00, 0.37662800E-03, 0.66874200E-02, -.26076300E-01, -.11737200E-01, 0.22927800E-01, -.25791300E-01, -.11481600E-01, -.70869000E-02, 0.32842700E-01, 0.66573500E-01, -.36172000E-01, -.11160400E-01, 0.35825700E+00, 0.33099400E-02, 0.11966200E-01, 0.51285700E-02, 0.47387600E-03, -.61609100E-02, -.18615000E-01, -.92036800E-02, -.32415100E-02, 0.14406700E-02, -.42432800E-02, 0.13548200E-01, -.24741400E-01, 0.78411200E-02, -.40119500E-02, -.43843100E-02, 0.71600500E-02, 0.27554900E-01, -.42058700E-01, -.12745400E-01, -.50951300E-02, -.16710800E-01, 0.15591000E-02, 0.71876000E-02, 0.29844900E-01, 0.17534000E-01, 0.51954600E-01, 0.71649600E+00, 0.19922600E-01, 0.37195700E-02, -.28212700E-01, -.28846000E-01, -.28513800E-02, -.39607500E-02, -.73809500E-02, 0.28035900E-01, 0.80143600E-01, 0.52477900E-01, -.23917800E-01, -.12542300E+02, 0.64571100E+01, 0.67052700E+01, -.50524400E+00, 0.43646400E+01, 0.76150400E+00, -.10662900E+02, -.25399700E+01, 0.37264700E+01, -.10380500E+02, 0.60271100E+01, 0.59309400E+01, -.29519900E+01, 0.64905800E+00, 0.39821900E+01, 0.19265600E+01, 0.56031400E+01, 0.11086800E+01, 0.33894700E+01, -.35135300E+01, -.18678500E+01, 0.63400900E+01, -.21665700E+01, -.12347000E+01, -.30634300E+01, -.87150400E+00, 0.40044600E+00, 0.19643300E+02, -.78041500E+01, -.98600500E+01, -.23859400E+01, -.28245200E+01, -.43742600E+01, 0.25275100E+01, -.11445300E+01, -.39128300E+01, 0.96123400E+01, -.57667400E+01, -.52907100E+01, 0.75156000E+01, -.60047400E+00, -.46217300E+01, -.55708900E+01, -.41256300E+01, 0.56488800E+00, -.54879000E+01, 0.28614500E+01, 0.20073800E+01, -.51458900E+00, -.49554300E+00, 0.32133100E+01, 0.28680100E+01, 0.26632800E+01, -.26094600E+00, 0.10511800E+01, -.86571600E+00, -.83210000E+00, 0.83041000E+00, 0.39362200E+00, -.85668000E+00, -.60682900E+00, -.49061200E+00, -.36892500E+00, -.29860900E+01, 0.16897300E+01, 0.16667500E+01, -.20933100E+01, 0.12443300E-01, 0.73412800E+00, 0.17865900E+01, 0.22792800E+01, -.33242800E+00, -.46284700E+01, 0.27231100E+01, 0.19437900E+01, 0.25458900E+01, 0.26315100E+01, 0.21549300E+01, 0.97586600E+01, 0.25855200E+01, 0.26439900E+01, -.37646900E+01, 0.17367400E+01, 0.24049800E+01, -.69637400E+00, -.13600800E+00, 0.48969500E+00, -.41570600E+01, 0.10722500E+01, 0.12375500E+01, -.24333800E+02, 0.11862100E+02, 0.13164100E+02, 0.33890900E+00, 0.35022700E+01, 0.36140500E+01, -.16988500E+02, -.84133400E+00, 0.51169500E+01, 0.10338100E+01, -.50490400E+00, -.54131100E+00, 0.74005800E+00, 0.15870800E+00, -.39617600E+00, 0.13147200E+01, 0.11535400E+01, 0.15185100E+00, 0.56859200E+00, -.32320500E+00, -.10112600E+01, 0.35502900E+00, -.70809900E+00, -.26675800E+00, -.35515100E+01, -.70160900E+00, -.50979800E+00, 0.33558700E+00, -.80425000E+00, 0.34159800E+00, -.55297300E-01, 0.65420500E+00, -.10227700E+00, 0.11956100E+01, -.60224100E+00, 0.25513100E+00, -.13479300E+01, 0.20278600E+00, -.47419200E-01, 0.19044300E+00, 0.24321900E+01, -.10376700E+01, 0.80937600E+01, -.17800800E+01, -.10950400E+02, -.21215500E+01, 0.15906300E+00, 0.96325500E+00, -.25508700E+01, -.55613700E+00, -.10886200E+02, -.71777000E+00, -.11538500E+00 },
            { -.89625100E-01, 0.60630700E-01, 0.29128100E-01, -.33128200E-01, 0.84469100E-03, -.54054300E-02, 0.21528300E-01, 0.31901700E-02, 0.11726900E-02, 0.93884500E-02, 0.38950200E-01, 0.67873900E-01, -.20055600E-01, -.79807100E-02, 0.22756400E-01, -.13789600E-01, 0.45461200E-01, -.21161700E-01, 0.66959800E-02, 0.39547000E-01, 0.50035000E-01, 0.25337100E-01, -.25441300E-01, 0.41086700E-01, 0.10270700E-01, 0.19932200E-01, 0.86155700E-02, -.12137100E-01, 0.17400000E-01, -.21658400E-01, -.23291300E-01, -.92633100E-02, 0.38780600E-01, 0.25618400E-01, 0.16129200E-02, 0.10855200E+00, 0.31908400E-02, -.11757500E-02, -.18244900E-02, -.44262100E-01, -.47694600E-01, -.52323400E-02, 0.70913100E-02, -.14244400E-02, -.93966700E-02, 0.17035300E-01, -.18163500E-01, 0.52229900E-01, 0.45866700E-01, -.12308900E-01, 0.32160500E-02, -.44300600E-01, 0.16639300E-01, 0.53271900E-02, -.64515000E-02, -.61834800E-02, 0.13228400E+00, -.15464800E-02, -.62926700E-02, 0.19324500E-01, -.86553900E-03, -.16505500E-01, 0.33728500E-02, -.20348700E-01, 0.11426300E-01, -.18473900E-01, 0.45270900E-02, 0.12355400E-01, -.13063200E-01, -.23209700E+00, -.44132400E-02, 0.46183100E-02, -.36998500E-02, -.30681000E-03, 0.14747500E-02, -.42011900E-02, 0.39381400E-02, -.19037000E-02, -.41636000E-01, -.16639200E-01, -.22899700E-01, -.23339800E-01, 0.78338200E-02, 0.43237000E-02, 0.51417600E-02, 0.10622500E-01, 0.44962100E-02, 0.40553500E-01, 0.35917100E-01, 0.17537000E-02, 0.13503700E-02, 0.18948400E-02, 0.52757400E-02, -.12842400E-01, -.37982600E-02, -.30209400E-02, -.13589000E-01, 0.47058300E+00, -.10478400E-02, 0.43509700E-02, 0.17645300E-01, 0.24143900E-01, 0.17641400E-02, 0.63528900E-03, 0.50566000E-02, -.11158500E-01, 0.56340700E-03, 0.12112900E-01, 0.38465100E+01, -.20222800E+01, -.22887100E+01, 0.26890200E+01, -.11985200E+01, -.16979300E+01, 0.26876400E+01, 0.24364700E+01, -.64247100E+00, 0.63819800E+01, -.36219100E+01, -.37207700E+01, 0.35545700E+01, -.97812400E+00, -.35094400E+01, -.10786400E+01, -.24864200E+01, -.49250200E+00, 0.14296700E+02, -.61836200E+01, -.69981300E+01, 0.53208900E+00, 0.46921100E+01, -.66402600E+01, -.53246900E+01, -.67907400E+01, -.25415700E+01, -.97012600E+01, 0.39327300E+01, 0.52261000E+01, 0.59623400E+00, 0.28010000E+01, 0.11988400E+01, -.49004500E+01, -.34263800E+01, 0.35455500E+01, -.98382600E+00, 0.11208300E+01, 0.92120700E+00, -.49546600E+01, 0.56363200E+00, 0.10228700E+01, 0.85458700E+00, 0.87871400E+00, -.23597500E+01, 0.19394500E+01, -.10541500E+01, -.86187400E+00, -.11062400E+00, -.73700100E-01, -.15849700E+01, -.14304100E+01, -.51281800E+00, 0.74580300E+00, -.98090900E+00, 0.70039200E+00, 0.52988500E+00, -.11817600E+01, 0.63092000E-01, 0.87697700E+00, 0.77309600E+00, 0.91829400E+00, -.14854300E+00, 0.30190600E+01, -.15844100E+01, -.17463900E+01, 0.33299300E+01, 0.29935800E+00, -.20142200E+01, -.20894300E+01, -.19179000E+01, 0.49893400E+00, 0.78527300E+00, -.63422000E+00, -.84045900E-01, -.26978400E+00, 0.46049300E+00, -.12648900E+01, -.31071900E+01, -.21346500E+01, 0.95095400E+00, 0.37505700E+01, -.18037900E+01, -.16042700E+01, 0.22568000E+01, -.11984300E+01, -.79842000E+00, -.13837000E+00, -.18800900E+01, -.85916800E-01, 0.88703200E+01, -.43209200E+01, -.50096300E+01, 0.19416600E+00, -.31354600E+01, -.86160700E+00, 0.50220400E+01, 0.21015800E+01, -.36078600E+01, -.45360700E+01, 0.22462900E+01, 0.23161000E+01, -.47639000E+00, 0.27481000E+00, 0.10075900E+01, -.14947400E+01, 0.21011000E-01, 0.11906500E+01, 0.10213500E+01, -.48811300E+00, 0.30991800E+00, -.17260100E+01, 0.30349500E+00, 0.44330300E+00, 0.26119700E+01, 0.81402600E+00, -.15209700E+01, -.24091400E-01, 0.14683700E+00, -.35388300E+00, 0.13264400E-01, -.91865700E+00, -.52034300E-02, 0.41874000E+00, 0.51616100E-01, -.10692600E+00, 0.90908900E-01, 0.27826000E-03, 0.74497700E-02, -.50667800E-02, -.13234700E+01, 0.24122900E+01, -.67475400E+01, 0.74520000E+01, 0.11629200E+02, 0.11585500E+01, 0.11172600E+00, -.88924500E+00, 0.18611300E+01, 0.38164300E+00, 0.32451900E+01, -.15781800E+01, -.93483900E+00 },
            { -.11414000E+00, -.41036100E-01, 0.14731700E-01, 0.54147800E-01, 0.21626400E+00, 0.20202200E-01, 0.66458300E-01, -.13668400E-01, -.14906500E+00, 0.38470600E-01, 0.44375200E-01, 0.14011800E-01, 0.28376400E-01, -.45439300E-02, 0.18060300E-01, -.26977400E-01, 0.60634900E-01, -.22222600E-01, -.67316100E-01, 0.15512300E-01, 0.94337300E-01, -.26704300E-02, -.35255300E-02, 0.71085300E-01, 0.19059100E-01, -.44346800E-02, -.19464100E-01, 0.21136500E-01, -.66523000E-02, 0.53136300E-02, -.45669100E-01, 0.99859800E-02, 0.51196700E-02, -.80212400E-02, -.74528600E-02, -.16946800E+00, 0.44606200E-01, -.17492300E-01, -.26708300E-01, 0.73745600E-01, 0.12337700E+00, -.76234100E-01, -.50879700E-01, -.94756200E-01, 0.27611800E-01, 0.11247600E-01, -.32283600E-01, 0.98032500E-02, -.25956400E-01, -.14806100E-01, 0.68357800E-01, -.93508300E-01, 0.23966500E-01, 0.14114500E-01, -.14854000E-01, -.29868700E-01, 0.11578600E+00, -.53867900E-02, -.49288400E-02, 0.17176400E-01, -.15638800E-01, -.13855800E-01, 0.17319500E-01, -.30222500E-02, 0.11834500E-01, -.50494700E-01, -.11518200E-01, 0.56081300E-01, -.30128500E-01, -.13594200E+00, -.17668400E-01, 0.53001100E-01, 0.22978400E-01, 0.10125300E-01, 0.11659800E-02, -.16524200E-01, -.26111700E-02, -.25422000E-01, -.69653500E-01, -.50078600E-01, 0.20458400E-01, -.22408500E-03, -.55417000E-01, 0.15233200E-01, 0.19803700E-01, 0.15798200E-01, 0.10786700E-01, 0.35339900E-01, 0.64728100E-01, 0.13477400E-02, 0.39122000E-02, 0.33302300E-02, 0.46450100E-02, -.39273200E-01, -.42870500E-01, 0.70017900E-02, -.34962900E-01, 0.46812200E-01, 0.29951600E+00, -.28467700E-01, 0.53491100E-01, 0.40269700E-01, 0.40715800E-01, 0.66041400E-01, -.15173000E-01, -.63530300E-01, -.89935000E-01, 0.83038100E-01, 0.13172100E+02, -.67518600E+01, -.55126900E+01, 0.74575800E+00, -.45839200E+00, -.41887000E+01, 0.56100600E+01, -.39660800E+01, -.11247300E+01, 0.52728600E+01, -.33729600E+01, -.23847100E+01, 0.39382100E+01, 0.95133100E+00, -.40333600E+01, -.54812600E+01, -.47952700E+01, 0.48956000E+00, 0.41948900E+01, -.69358400E+00, -.20076900E+01, -.82118000E+01, 0.13173000E+01, -.20652900E+01, -.98651300E+00, -.15617200E+01, 0.16420000E+01, -.24410700E+02, 0.10605100E+02, 0.13119400E+02, 0.55821000E+00, 0.68801400E+00, 0.58574600E+01, -.20446800E+01, 0.29314600E+01, 0.25759900E+01, -.80971500E+01, 0.47046400E+01, 0.42040500E+01, -.78785600E+01, -.49139500E+00, 0.38864900E+01, 0.48057400E+01, 0.24167900E+01, 0.23321400E+00, 0.15918800E+01, -.93374300E+00, -.55923400E+00, -.11648400E+01, -.30759200E+00, -.12115000E+01, -.47465200E+00, -.72539700E+00, 0.54423400E-01, -.32335200E+01, 0.19327800E+01, 0.15466100E+01, 0.80939900E+00, 0.10798100E+01, 0.65547500E+00, 0.19933900E+00, -.13727400E+01, 0.25836200E+01, 0.75140100E+01, -.39054800E+01, -.40396800E+01, 0.47572900E+01, 0.36212000E+01, -.49650700E+01, -.70145600E+01, -.82463600E+01, 0.21654400E+01, 0.63396300E+01, -.35449900E+01, -.29898400E+01, -.16702500E+01, -.20916500E+01, -.18430500E+01, -.10327800E+02, -.69144900E+00, -.32113300E+01, 0.76494100E+01, -.36924700E+01, -.57234000E+01, 0.16335400E+01, -.12442300E+01, -.11151000E+01, 0.39673700E+01, -.24032600E+01, -.39510500E+01, 0.21264600E+02, -.10332400E+02, -.90632800E+01, -.71016000E+00, -.52283500E+01, -.44668100E+01, 0.16749000E+02, -.28181700E+01, -.58559100E+01, -.11094700E+02, 0.55322600E+01, 0.55583000E+01, -.72735700E+00, 0.15829400E+01, 0.25286800E+01, -.37378800E+01, -.37479800E+00, 0.14155300E+01, 0.61433300E+01, -.30204200E+01, -.20282500E+01, -.20226000E+01, -.22628000E+00, -.16215500E+01, 0.42497300E+01, -.56741500E+00, -.13259900E+01, -.81333100E-01, 0.10887100E+01, -.67079900E+00, 0.71944300E-02, -.12472300E+01, 0.14351700E+00, -.92247400E+00, 0.82291400E+00, -.22969600E-01, 0.19022000E+01, -.37441900E-01, 0.49801200E-02, -.10820600E-01, -.85918500E+00, 0.57487600E+00, -.10190500E+02, 0.71656900E+01, 0.11869900E+02, 0.31659900E+01, 0.60195200E+00, -.14786100E+01, 0.24710800E+01, 0.15823900E+01, 0.85186800E+01, -.95097900E-01, -.29096700E+00 },
            { 0.15844900E+01, -.38761700E+00, -.59434300E+00, -.22313800E+00, -.22892500E+01, -.21075600E+00, -.70144000E+00, -.11773500E-02, 0.52153700E+00, -.46177400E+00, -.35820400E+00, -.60946400E+00, -.45008800E+00, 0.65688300E-01, -.26568900E+00, 0.33050200E+00, -.87393300E+00, 0.20420100E+00, 0.10737300E+01, -.27455300E+00, -.11083200E+01, -.60288500E+00, -.13440000E+00, 0.27612800E+00, -.33097900E+00, -.30345900E+00, 0.11523300E+00, 0.86718200E-01, -.25655500E-01, 0.37596400E-01, 0.11477400E+00, 0.10904100E+00, -.41120400E+00, -.12083400E+00, 0.12988900E+00, 0.12612700E+00, -.43900600E-01, 0.17864100E-01, 0.14610100E-01, 0.65427800E+00, -.95552100E-02, 0.16762800E+00, 0.12701700E+00, 0.10649700E+00, -.13933300E+00, -.35096800E+00, 0.73900300E+00, -.14837400E+01, 0.42670500E+00, -.47639700E+00, 0.54828700E-01, -.27076800E+00, -.49215800E+00, 0.76159300E-01, 0.34708300E+00, -.46383600E+00, -.16454600E+01, -.42400800E-01, 0.18764900E+00, -.46111700E+00, 0.16379000E+00, -.10600200E+00, 0.11073800E+00, 0.30679600E+00, 0.28973100E+00, -.49747500E+00, -.12846400E+01, -.30502500E+00, 0.14168600E+00, 0.62932100E+00, 0.69545200E-01, -.32279300E+00, -.26603100E-01, -.84896500E-01, 0.91729300E-01, 0.22968000E+00, 0.26376700E+00, 0.14473700E+00, 0.39608500E+00, 0.36643300E+00, -.13399300E-01, 0.13262200E+00, 0.40434300E+00, 0.10794400E+00, -.19315800E+00, -.18170700E+00, -.10737800E+01, -.29947100E+00, -.20335300E+01, -.60080600E-01, 0.23324300E-01, -.53572200E-01, -.20459700E-01, -.14667600E+00, 0.29407300E+00, -.38466900E+00, -.16645900E+00, -.80165700E+00, 0.10535900E+00, 0.26415600E+01, -.58889400E+00, -.23929200E+00, -.13484400E+00, -.71217600E+00, 0.12611800E-01, 0.17746500E+00, 0.70247600E+00, -.66660900E+00, -.18774100E+02, 0.10436200E+02, 0.71136600E+01, 0.11198200E+01, -.48301000E+01, 0.12887800E+02, -.15823800E+01, 0.22541700E+02, 0.19034000E+01, -.30093100E+01, 0.62113000E+01, 0.62770600E+01, 0.17324400E+02, 0.14696000E+01, -.14612200E+00, 0.13900800E+02, -.13378600E+02, 0.12349400E+01, 0.84381400E+02, -.52795400E+02, -.43851000E+02, 0.34387400E+02, 0.90166300E+01, -.50809600E+02, -.75953400E+02, -.65342100E+02, 0.91944500E+01, -.10795600E+03, 0.61432800E+02, 0.33504400E+02, 0.38267100E+02, 0.10552800E+02, 0.33921600E+02, 0.34911000E+02, 0.30822000E+02, 0.19115900E+02, 0.66928400E+02, -.41945300E+02, -.37868100E+02, -.36555800E+00, -.23838400E+02, -.21454900E+02, -.24423900E+02, 0.16203100E+01, -.14735300E+02, -.10440300E+02, 0.70257700E+01, -.29125400E+01, 0.13052200E+02, -.14795200E+01, 0.74657500E+01, -.82206000E+01, 0.45847000E+01, -.13976500E+01, 0.22204300E+02, -.13417300E+02, -.71812200E+01, -.11347300E+02, -.14313500E+02, 0.59604400E+01, 0.71531300E+01, 0.29705200E+02, -.18254000E+02, 0.34672600E+02, -.16295400E+02, -.15931000E+02, 0.16167700E+02, -.19594900E+02, 0.59866300E+01, 0.35958200E+02, 0.32650900E+02, -.18883700E+02, 0.17776500E+02, -.58569100E+01, -.15129100E+02, 0.15573600E+02, 0.81583200E+01, -.14896300E+02, 0.98137000E+01, -.23970800E+02, 0.62281800E+01, -.83974000E+02, 0.40815200E+02, 0.57390200E+02, -.18254900E+02, 0.10052900E+01, 0.16439100E+02, -.11856100E+02, 0.28085700E+02, 0.19339300E+02, -.62026600E+02, 0.28942000E+02, 0.31852700E+02, -.15422700E+02, 0.83785400E+01, 0.22679200E+02, -.34956000E+02, 0.41955100E+02, 0.13560400E+02, 0.68171300E+02, -.34125300E+02, -.34609000E+02, -.28573300E+01, -.16334700E+02, -.20344400E+02, -.93912900E+01, -.11451000E+02, -.16397900E+02, -.70394100E+02, 0.34694600E+02, 0.21370600E+02, 0.15718700E+02, 0.15289100E+02, 0.25190600E+02, -.54612200E+01, 0.14118300E+02, 0.14289000E+02, -.53214100E+00, -.10233700E+01, 0.72230200E+00, 0.32367700E+00, 0.61589000E+01, -.10367000E+01, -.48199500E+01, 0.16512000E+00, -.15609800E+01, -.13788000E+02, -.59373200E+00, 0.23138100E+00, -.84990900E+00, -.64575600E+01, 0.15687300E+02, -.34164500E+01, -.38420200E+02, 0.19254500E+02, -.22716100E+02, -.11229000E+02, -.51136800E+01, -.27169000E+01, -.12792600E+02, -.31164100E+01, 0.58842800E+01, 0.53672400E+00 },
            { -.78872300E+00, -.32306600E+00, 0.18108300E+00, 0.70543100E-01, 0.30144300E+00, -.13923700E-01, 0.30408300E+00, -.68822700E-02, -.20273000E+00, 0.42437900E+00, 0.58127300E+00, 0.10639600E+01, -.23353800E+00, -.21620700E+00, 0.50393000E+00, -.23434900E+00, 0.94848700E-01, 0.18509700E-01, -.41109100E+00, -.61161700E-01, 0.38884600E+00, 0.73023400E-02, 0.75535700E-01, -.15170800E+00, 0.29203100E-01, 0.40635600E-01, -.11081600E+00, 0.22574100E-01, -.10578800E+00, 0.38265400E-01, 0.11333000E+00, 0.21766900E+00, 0.78188900E-01, -.23424900E-01, 0.23365400E-01, -.17392800E-01, 0.23418400E+00, -.93135900E-01, -.13393800E+00, 0.84358200E+00, 0.13100800E+01, -.41461300E+00, -.30129700E+00, -.59876200E+00, 0.23910200E+00, 0.12057800E+00, -.15117700E+00, 0.41798600E+00, -.87415800E+00, 0.32800900E-02, -.10691400E+00, -.10247000E+00, 0.15983400E+00, -.98321100E-01, -.77909600E-02, -.19978700E+00, 0.66725100E+00, 0.28160500E-01, -.14566700E+00, 0.17948300E+00, -.16097500E+00, -.52768300E-01, -.27551800E-02, 0.41964900E-01, -.70829900E-01, 0.60988200E-01, -.52094600E-01, 0.24650000E+00, 0.37015700E+00, -.31940500E+01, -.78232900E-01, -.93535700E-01, 0.12455500E+00, -.23675000E-01, 0.37894700E-02, -.17843600E+00, -.77652000E-01, -.88867900E-01, -.21108500E-01, -.50746100E-01, 0.28732100E+00, 0.12846000E+00, -.25775400E+00, 0.94759500E-02, 0.17756700E+00, -.28252100E-01, 0.14336900E+00, 0.21029700E+00, 0.79793200E+00, 0.23063500E-01, 0.46638600E-01, 0.40714300E-01, -.24334900E-01, -.13316800E+00, -.24283200E+00, -.71241200E-02, -.17478900E+00, 0.40048200E+00, -.14084400E+00, -.61758200E-01, 0.33308500E+01, 0.86061800E-01, 0.23457400E+00, 0.37237700E+00, -.10272200E+00, -.30225400E+00, -.43996700E+00, 0.44160700E+00, 0.61436400E+02, -.31977900E+02, -.26832500E+02, -.63960800E+01, 0.44142100E+01, -.17949500E+02, 0.14513500E+01, -.39222900E+02, -.59322300E+01, 0.87331300E+01, -.91165400E+01, -.35256200E+01, 0.45055100E+01, 0.21801400E+02, -.14830500E+02, -.35634200E+02, -.36110600E+02, 0.82294400E+01, -.18450700E+03, 0.10111000E+03, 0.92615400E+02, -.89435800E+02, -.32080700E+02, 0.79199500E+02, 0.60384300E+02, 0.75509100E+02, 0.19507200E+02, -.31672500E+02, 0.46139100E+01, 0.16266700E+02, 0.12509900E+02, -.95563800E+00, -.13778300E+00, 0.94862700E+00, 0.16706200E+02, -.62269800E+01, -.11655200E+03, 0.59321100E+02, 0.58541700E+02, -.46230000E+02, -.75588700E+01, 0.57044100E+02, 0.67678000E+02, 0.52270600E+02, 0.10949700E+02, 0.96800100E+00, -.68559200E+00, 0.52949100E+01, -.89612700E+01, 0.93763000E+00, -.14325600E+01, -.17335100E+01, -.58126600E+01, -.59308400E+01, -.60200900E+01, 0.46206900E+01, 0.56688300E+01, 0.12526700E+02, 0.46814000E+01, -.20994800E+01, -.55732800E+01, -.14744100E+02, 0.16348300E+02, 0.61033000E+02, -.32177700E+02, -.31298000E+02, 0.10275100E+02, 0.22960300E+02, -.27809300E+02, -.27481300E+02, -.51602700E+02, 0.13607100E+02, 0.52676700E+02, -.28762400E+02, -.26071400E+02, -.98607200E+01, -.84374600E+01, -.15018900E+02, -.35111800E+02, -.61332200E+01, -.25659400E+02, 0.31029000E+02, -.13388400E+02, -.28312900E+02, -.14799900E+02, -.56066600E+01, 0.34760400E+01, 0.22494300E+02, -.35793800E+00, -.34255800E+02, 0.68378000E+02, -.30466500E+02, -.29662400E+02, -.13362500E+02, -.26468700E+02, -.10020700E+02, 0.55420500E+02, -.22537800E+02, -.25522300E+02, -.57355900E+01, 0.28820000E+01, 0.25266600E+01, -.59658600E+01, 0.43898900E+01, -.29482400E+01, -.18500200E+02, -.10147900E+02, -.59809000E+01, 0.50326900E+02, -.25144400E+02, -.22693900E+02, 0.76235900E+01, -.44882500E+01, -.26628200E+02, -.13239800E+02, -.33354700E+02, 0.58755700E+01, -.88836400E+00, 0.79590700E+01, -.21823800E+01, -.82852700E-01, 0.46920100E+01, 0.67111300E+00, -.55598500E+01, 0.75013500E+01, 0.39418200E+00, 0.67523400E+01, -.38972900E+00, -.17925700E-01, -.25046600E+00, 0.84917500E+01, -.19106100E+02, -.43338600E+02, -.66064400E+02, 0.54479600E+01, 0.97825600E+01, 0.19388200E+01, -.63433800E+01, 0.18179600E+01, 0.10802500E+02, 0.18041200E+02, 0.59143300E+01, 0.47985700E+01 },
            { -.77024700E+00, 0.17164400E+00, 0.59124300E+00, -.18979000E+00, 0.44328000E+00, 0.10721400E+00, 0.43032400E+00, -.27503200E-01, -.38300500E+00, 0.14692200E+00, 0.30491100E+00, 0.10302700E+01, 0.42347700E-01, -.23068000E+00, 0.20726500E+00, -.21494400E+00, 0.34773600E+00, -.70074200E-01, -.55980600E+00, -.87912900E-01, 0.43661600E+00, 0.23990200E+00, 0.21649400E+00, -.31780700E+00, 0.12278300E+00, 0.21169600E+00, -.69892900E-01, -.42553400E-01, -.42392100E-01, 0.49085600E-01, 0.39025800E-01, -.29042300E-01, 0.16865100E+00, -.16525600E+00, -.87555500E-01, -.22245700E+00, -.81314300E-01, 0.31619200E-01, 0.47068800E-01, 0.68352200E-03, -.89219900E-02, 0.39563600E-01, -.11850200E+00, -.27732100E-01, 0.17454200E+00, 0.10281600E+00, -.31379500E+00, 0.58265600E+00, -.84965300E+00, 0.46728900E+00, 0.52873400E-01, 0.61878400E+00, 0.27070000E+00, -.23991800E+00, -.75654700E-01, 0.13096700E+00, 0.34308000E+00, 0.65628300E-01, -.17247000E+00, 0.17409800E+00, -.53224800E-01, -.15940400E-01, -.23687900E-01, -.54622200E-01, -.70894500E-01, 0.83041100E-01, 0.38352100E+00, -.22678400E+00, 0.79635300E-01, -.20164800E+00, -.37996600E-02, -.15715000E+00, 0.13288800E-01, 0.45841900E-01, -.26131200E-01, -.64176800E-01, -.11763500E+00, -.10677100E+00, -.12498900E+00, -.22324400E+00, 0.28425400E+00, 0.17341800E-01, -.23603000E+00, 0.10011700E+00, 0.90481700E-01, 0.60599600E-01, -.69227300E-01, 0.11916100E+00, 0.57260600E-01, -.13175400E-01, 0.46768200E-03, 0.19241200E-01, 0.90832400E-03, -.72496500E-01, -.22226600E+00, 0.10825700E+00, -.77579700E-01, 0.31685300E+00, -.14189700E+00, -.78383400E-01, 0.64389400E-01, 0.19253800E+01, 0.23234600E+00, 0.31832300E+00, -.85754000E-01, -.21142600E+00, -.39505500E+00, 0.42459600E+00, 0.37594200E+02, -.19064600E+02, -.12406300E+02, -.44872000E+01, 0.18992700E+02, -.11556600E+02, 0.26253900E+01, -.29288800E+02, 0.18001500E+00, 0.10211600E+02, -.58221700E+01, -.57329900E+01, 0.33718800E+01, 0.20908800E+02, -.71955100E+01, -.16426400E+02, -.17071800E+02, 0.90113900E+01, -.66272100E+02, 0.33828500E+02, 0.34107000E+02, -.26118500E+02, -.25820200E+02, 0.23064800E+02, 0.10493100E+02, 0.35900400E+02, 0.49962500E+01, 0.32870400E+02, -.18184100E+02, -.95640700E+01, -.93820200E+00, 0.28231700E+02, -.31098400E+02, -.36893700E+02, -.31478800E+02, 0.58160100E+01, -.21300400E+02, 0.95824800E+01, 0.12128600E+02, -.17787600E+02, 0.13847300E+01, 0.80452000E+01, 0.15776700E+02, 0.10594800E+02, 0.94897100E+01, 0.27195300E+02, -.13687900E+02, -.20809500E+01, -.61619000E+01, -.11993900E+01, -.63165200E+01, 0.32215600E+01, -.67495800E+01, -.11619500E+02, -.37252000E+01, 0.22379200E+01, 0.50784800E+01, 0.95268800E+01, 0.37987700E+01, -.37493100E+01, -.32669400E+01, -.89472800E+01, 0.13265700E+02, 0.19879000E+02, -.10194400E+02, -.11153800E+02, 0.11538100E+02, 0.19870600E+02, -.12465600E+02, -.24041000E+02, -.32134500E+02, 0.14838500E+02, 0.26435600E+02, -.13766300E+02, -.10847100E+02, -.85243400E+01, -.11658600E+02, -.54235600E+01, -.25389900E+02, 0.12562200E+02, -.19448700E+02, 0.58524400E+02, -.28858400E+02, -.54235600E+02, -.10354900E+02, -.71115200E+01, -.17742400E+01, 0.15918800E+02, -.12148600E+02, -.30125300E+02, 0.29519100E+02, -.13920400E+02, -.90154800E+01, -.25868100E+01, -.92115900E+01, -.54495200E+01, 0.38926300E+02, -.19265900E+02, -.11880900E+02, -.47114000E+02, 0.23534900E+02, 0.23210500E+02, 0.35615600E+01, 0.60128900E+01, 0.12379100E+02, -.48367000E+01, 0.13227600E+02, 0.13812100E+01, 0.67370100E+02, -.33540800E+02, -.26536700E+02, 0.59146700E+01, -.11841100E+01, -.34609000E+02, -.18280400E+02, -.38135800E+02, 0.18123500E+00, -.38376300E-02, 0.10947700E+01, -.10928900E+01, -.16591200E-01, -.47869300E+00, 0.54344200E+00, 0.55671100E+00, 0.56153700E+00, 0.44742400E+00, 0.53274700E+01, -.29804400E-01, -.14709200E-01, 0.94265400E-01, 0.66276600E+00, -.71749700E+01, -.10954200E+02, 0.94081100E+00, 0.20105100E+01, 0.33577000E+01, 0.64836900E+00, -.69585300E+01, 0.21116900E+01, 0.13378200E+02, 0.14863800E+02, 0.64396300E+01, -.57284200E+01 },
            { -.20957800E+00, 0.33106400E-01, 0.10677300E+00, 0.60000500E+00, -.16222900E-01, 0.87192400E-02, 0.15098500E+00, -.12325000E+00, -.45240800E+00, 0.12378300E+00, 0.36551400E+00, 0.24442400E+00, 0.26182900E+00, -.17844400E+00, -.20882900E+00, -.49818700E-01, 0.37228500E+00, -.13837700E-01, 0.14493800E+00, -.20328000E-02, -.18678200E-01, -.30069300E+00, 0.46344000E+00, 0.55669200E-01, -.56594800E-01, 0.63270100E-01, -.16482800E+00, -.18693500E+00, 0.41552900E-02, -.57471900E-01, -.31169400E+00, -.15809300E-01, 0.24052100E+00, 0.68962200E-01, 0.10080100E+00, -.40535800E+00, -.89673100E-01, 0.32711900E-01, 0.57900400E-01, -.44630300E+00, -.84969900E+00, 0.79969900E-01, -.10485100E+00, 0.31011200E+00, 0.87177500E-01, 0.22714600E+00, -.22230000E+00, 0.14660200E+01, 0.80731300E-01, 0.42836400E-01, -.10927400E+01, 0.16808100E+00, -.45884300E-01, 0.65900100E-01, 0.12115600E+00, -.95875000E-01, 0.72195900E+00, 0.48740800E-01, -.68207200E-01, 0.22162700E+00, 0.34440000E+00, -.22879200E-01, -.25659400E+00, -.15955900E+00, -.62536000E-01, 0.32994100E+00, 0.18701400E+00, 0.94297400E-01, 0.40337000E+00, -.22286000E+01, -.35714500E+00, 0.42247400E-01, 0.17445500E+00, -.68934600E-01, 0.66699300E-02, 0.50836600E-01, 0.26985400E-01, 0.34721800E+00, 0.30114100E+00, -.91507000E-01, 0.43787900E+00, 0.10490800E+00, 0.18138500E+00, 0.26725100E+00, -.19415900E-01, -.58825000E-01, -.91491600E+00, 0.88206100E-01, -.25989200E+00, -.71188600E-01, 0.96141700E-01, -.40805300E-01, -.54127000E-01, -.55831700E+00, -.57422600E+00, 0.65153200E-01, -.20564400E+00, 0.10389000E+01, -.36148700E+00, -.10173200E+00, 0.22208700E-01, 0.68639800E-01, 0.89257200E+00, 0.67777800E+00, -.20851200E+00, -.45441400E+00, -.84821300E+00, 0.97585700E+00, 0.25618100E+03, -.12839200E+03, -.11817400E+03, -.11768400E+02, 0.10882900E+02, -.73829500E+02, 0.25342100E+02, -.11923700E+03, -.30564800E+02, 0.42232000E+02, -.23792000E+02, -.17777700E+02, 0.18274900E+02, 0.67867800E+02, -.45776800E+02, -.89687800E+02, -.10205100E+03, 0.26127300E+02, -.15093700E+03, 0.79639500E+02, 0.76117200E+02, -.11448800E+03, -.35026300E+02, 0.69857400E+02, 0.51204500E+02, 0.95602700E+02, -.19177100E+02, -.65372900E+02, 0.24068700E+02, 0.37144100E+02, 0.99511100E+01, 0.13951400E+02, -.46647200E+01, -.11105900E+02, 0.34422100E+02, 0.27676400E+01, -.15606600E+03, 0.79447100E+02, 0.77777100E+02, -.94962900E+02, -.34573400E+02, 0.10412900E+03, 0.16934800E+03, 0.12214400E+03, -.24599900E+02, 0.70475100E+01, -.41480800E+01, 0.11030700E+02, -.10839300E+02, 0.90157700E+00, 0.11917600E+01, 0.87993000E+00, -.41200000E+01, -.88806400E+01, 0.90100500E+01, -.32679300E+01, 0.21237300E+01, 0.34164300E+02, 0.15246200E+02, -.89404600E+01, 0.23947700E+01, -.25786100E+02, 0.31997000E+02, 0.11661800E+03, -.58518100E+02, -.60007700E+02, 0.46574800E+02, 0.55751300E+02, -.58045700E+02, -.70302400E+02, -.12644300E+03, 0.28989000E+02, 0.99752200E+02, -.50476200E+02, -.49532100E+02, -.27171600E+02, -.28342400E+02, -.19551100E+02, -.88576000E+02, -.70212000E+01, -.47330600E+02, 0.97149900E+02, -.49372100E+02, -.80834800E+02, -.16161400E+02, -.23477000E+02, -.84538600E+01, 0.50255700E+02, -.21323600E+02, -.52453100E+02, 0.32849800E+03, -.16433500E+03, -.15166100E+03, -.41289700E+02, -.72135300E+02, -.70547200E+02, 0.15099000E+03, -.82700500E+02, -.89684100E+02, -.14551800E+03, 0.72742600E+02, 0.71723600E+02, -.31882500E+01, 0.10014500E+02, 0.37350700E+02, -.33132500E+02, 0.24019100E+02, 0.87425900E+01, 0.14819000E+03, -.73537600E+02, -.68275000E+02, -.31810600E+01, -.53139900E+01, -.61378700E+02, -.17943300E+01, -.56162000E+02, -.16564800E+02, -.20455000E+01, 0.17656000E+02, -.50425300E+01, -.43456900E+00, -.48563700E+01, 0.10127900E+01, -.24191600E+02, 0.16333100E+02, 0.18290800E+01, 0.10839900E+01, -.12390300E+01, -.16986300E+00, -.95310800E+00, 0.12826200E+02, -.49595200E+02, -.82371300E+02, 0.87551500E+01, 0.42604200E+01, 0.28133800E+01, 0.11355600E+01, -.17680400E+02, 0.17712600E+02, 0.13022400E+02, 0.49208300E+02, 0.26353000E+02, -.70048100E+01 },
            { -.12793400E+00, -.12038900E+00, 0.51837400E-02, 0.59166800E-01, 0.29082300E+00, 0.38577300E-01, 0.60982600E-01, -.17196000E-01, -.76766200E-01, 0.58043900E-01, 0.10462600E-01, 0.53941600E-01, 0.37477900E-01, -.16546300E-01, 0.29310200E-01, -.35985400E-01, 0.63053700E-01, 0.12750200E-01, -.83960100E-01, -.35490700E-01, 0.84312500E-01, -.29332700E-01, 0.97154700E-01, -.88662300E-01, 0.15660400E-01, 0.19097800E-01, -.32945000E-01, -.98822700E-02, -.90508500E-02, -.64006600E-02, -.46383000E-01, -.21332000E-01, 0.11746900E-01, -.34129000E-01, -.18512700E-01, -.21400400E+00, 0.12285400E-01, -.48573600E-02, -.64873500E-02, 0.48963600E-01, -.11138200E+00, -.34279600E-01, -.35404300E-01, -.48292100E-01, 0.25397100E-01, 0.21083500E-01, -.53137300E-01, 0.10040400E+00, -.95494600E-01, 0.29093800E-01, 0.58655000E-02, 0.91477900E-02, 0.46962600E-01, -.25623100E-01, -.10921000E-01, -.58960200E-02, 0.15965100E+00, 0.46147700E-02, -.21194900E-01, 0.40357700E-01, -.92021500E-02, -.11469800E-01, 0.46512000E-02, -.13038000E-01, -.52799400E-02, 0.52634800E-02, 0.20402800E-01, 0.24614100E-01, 0.19041400E-01, -.37437400E+00, 0.38479000E-02, 0.18548600E-01, 0.10890400E-01, -.38904700E-02, -.43113100E-03, -.14663600E-01, -.11686400E-01, -.13635300E-01, -.16846000E-01, -.10511000E-01, 0.81344700E-02, 0.68491300E-02, -.27860600E-01, -.12039200E-02, 0.24642000E-01, -.42413200E-01, 0.40963100E+00, -.17766600E+00, 0.60105600E+00, 0.25500100E-01, -.60072700E-02, 0.56775700E-02, -.21657200E-02, 0.63807300E-01, -.63173000E+00, 0.31520500E-01, 0.44730700E-01, 0.66920400E-01, 0.61440300E-01, -.41767800E-01, 0.22512800E-01, 0.47671600E-02, -.83574500E-01, -.28644200E+00, 0.14337500E+00, 0.31105900E+00, 0.34020300E+00, -.26263400E+00, -.15408800E+02, 0.79509500E+01, 0.66486100E+01, -.84383400E+01, -.15697100E+02, 0.10508500E+02, 0.37572300E+01, 0.16529400E+02, -.81276600E+01, 0.79570200E+01, -.27459300E+01, -.36820400E+01, -.14245900E+02, -.39182400E+00, 0.19139700E+00, 0.86832300E+01, -.72285800E+00, -.28224100E+01, -.85212900E+02, 0.40467000E+02, 0.42586400E+02, -.24304700E+01, -.16554400E+02, 0.41128900E+02, 0.30185200E+02, 0.41885300E+02, -.41401400E+00, 0.10522500E+03, -.49062300E+02, -.50238600E+02, 0.11854700E+00, -.67154100E+01, -.25875500E+02, 0.20323300E+02, -.83983600E+01, -.13941200E+02, -.73042300E+01, 0.27845400E+01, 0.34732600E+01, 0.99202400E+01, -.62049400E+01, 0.12480200E+02, 0.23070900E+02, 0.19650800E+02, -.10585500E+01, -.13673100E+02, 0.70768800E+01, 0.67880600E+01, 0.41174700E+01, 0.50044000E+01, 0.23581600E+01, -.29934000E+01, 0.16551700E+01, 0.35523900E+01, 0.75119100E+01, -.43521600E+01, -.42276900E+01, 0.32798900E+01, -.54833400E+01, -.81939200E+00, 0.33628400E+01, 0.22402000E+01, -.81914000E+01, -.35937900E+01, 0.18818100E+01, 0.17650200E+01, -.79120400E+01, -.48997200E+01, 0.28587300E+01, 0.15090700E+02, 0.33252500E+01, -.48919600E+00, -.10484500E+02, 0.56636700E+01, 0.52519900E+01, 0.67672400E-01, -.19991900E+01, 0.32251900E+01, 0.15785300E+02, -.94108200E+01, 0.75365300E+00, -.46356600E+02, 0.23408800E+02, 0.25592900E+02, -.15182200E+02, 0.37958900E+01, 0.21352700E+02, 0.13054700E+02, 0.25195400E+02, -.22907300E+01, 0.91548400E+01, -.43907800E+01, -.52094200E+01, -.77039700E+01, 0.97743100E+01, -.32268500E+01, -.17839700E+02, 0.99619700E+00, 0.38110400E+01, 0.56522100E+02, -.28209600E+02, -.28297300E+02, -.26590000E+01, -.67996700E+01, -.14005500E+02, 0.11142000E+02, -.12068000E+02, -.82147500E+01, -.98133600E+00, 0.33031500E+00, 0.78818000E+00, 0.12608600E+02, -.38356100E+01, -.25696700E+01, -.14490000E+02, -.68490100E+01, 0.10256600E+02, -.93874900E-01, 0.16728500E+01, 0.27964100E+01, -.10226600E+00, 0.11800400E+01, 0.48833900E+00, -.15832000E+01, 0.23922500E+01, 0.32308200E+00, -.19800500E+01, -.12998900E+00, 0.43119700E-02, -.30431000E+00, 0.22927000E+01, -.11403400E+02, 0.19178700E+02, -.39861600E+02, -.43897700E+02, -.43458000E+01, -.14124400E+01, 0.95642500E+00, -.30918200E+01, -.29374200E+01, -.85060000E+01, 0.13478400E+01, 0.64725000E+01 },
            { -.41995700E+00, 0.14852300E+00, 0.21668700E+00, -.73348300E-01, 0.33216900E+00, 0.54392800E-01, 0.11425300E+00, 0.77388000E-01, -.16425900E+00, 0.10152900E+00, 0.11709400E+00, 0.19375800E+00, 0.24900100E-02, -.22531200E-01, -.60968800E-01, -.99555600E-02, 0.12703000E+00, -.17714200E+00, -.17362800E-01, 0.13437600E+00, 0.82145800E-01, 0.16885600E+00, -.23166400E+00, 0.33805600E+00, 0.65856400E-01, 0.42421200E-01, 0.76900800E-01, 0.57898400E-01, 0.41574500E-01, -.66958400E-01, 0.16290900E-02, 0.43159200E-01, 0.51827600E-01, 0.47745000E-01, -.37596700E-01, -.13446900E+00, 0.24659000E-01, -.93751100E-02, -.14089900E-01, -.30997300E+00, -.20147600E+00, -.48323100E-01, -.27017800E-01, 0.12973200E-01, -.72525900E-02, -.61948800E-02, -.45819200E-01, 0.10161000E+00, 0.29864400E+00, -.32285000E-01, 0.22857200E+00, -.24494400E+00, 0.58715600E-01, 0.29665800E-01, -.81885200E-01, 0.94068200E-02, 0.64785000E+00, -.33004100E-01, -.72432300E-01, 0.58947200E-01, -.19592500E-02, -.28842500E-01, -.16798700E-01, -.51030100E-01, 0.22786900E-01, -.81964500E-01, 0.19194400E+00, -.38027900E-02, -.69069400E-01, -.69477600E-01, -.46912400E-01, 0.15430000E+00, 0.72589000E-01, 0.18407300E-01, -.10561900E-01, -.22927900E-01, -.23844200E-01, -.23883100E-01, -.17380500E+00, -.12144900E+00, 0.49359700E-01, -.77995400E-01, -.51415700E-01, -.67187700E-02, 0.20812100E-01, 0.60969800E-01, 0.40683100E-01, 0.60414300E-01, -.29120900E-01, -.89618100E-02, -.30341100E-01, 0.10867300E-01, 0.26208000E-01, -.37918400E-01, -.58822500E-01, 0.12170800E+00, 0.12182400E+00, 0.95415400E-01, -.27025100E-01, -.32922400E-01, 0.77657000E-02, 0.33670100E-01, 0.65731700E-01, -.52940400E-01, 0.64171500E+00, 0.83489200E-01, 0.61666100E-02, 0.65510100E-02, 0.14596400E+01, -.76682500E+00, -.11964700E+01, 0.34551000E+01, 0.76361100E+00, -.16221300E+01, 0.82997700E+01, 0.48736300E+01, 0.11788300E+01, 0.65200000E+01, -.34005500E+01, -.38138800E+01, 0.30394500E+01, -.55937600E+01, -.87146600E+00, 0.37510200E+01, 0.47615300E+01, -.16090100E+01, 0.69970300E+02, -.34801100E+02, -.34818500E+02, 0.17161000E+02, 0.14292500E+02, -.30385700E+02, -.23200800E+02, -.27630400E+02, -.39021700E+01, -.93515700E+00, 0.10436400E+01, 0.15839800E+01, -.39318700E+01, -.17371900E+01, 0.10053600E+01, -.35194800E+01, -.51148900E+01, 0.53518300E+00, 0.19798100E+02, -.90608000E+01, -.93734800E+01, 0.30144100E+01, 0.15376500E+01, -.10839700E+02, -.14359000E+02, -.10874300E+02, -.37338400E+01, 0.48601600E+01, -.27141500E+01, -.29775400E+01, -.20646600E+00, -.16382400E+01, -.18895100E+01, -.60412500E+00, -.13255900E+01, 0.31579900E+00, -.11434400E+01, 0.85168200E+00, -.10597600E+00, -.20223900E+01, 0.61379400E+00, -.24582100E+00, 0.14429000E+01, 0.13160600E+01, -.13436100E+01, -.10799600E+02, 0.55509800E+01, 0.51262500E+01, 0.29392400E+01, -.42232700E+00, 0.92555400E+00, -.27634700E+01, 0.45087200E+01, 0.11003400E+01, -.11465800E+02, 0.55302500E+01, 0.61850300E+01, 0.10764200E+01, 0.68377100E+00, 0.46461300E+01, -.27116900E+01, 0.33038000E+01, 0.48704100E+01, 0.61233500E+01, -.32420900E+01, -.16226700E+01, 0.82056600E+01, -.30487900E-02, -.43062500E+01, 0.43477500E+00, -.57355700E+01, 0.54322200E+01, 0.11451100E+02, -.59942800E+01, -.62454900E+01, 0.59162700E+01, 0.19991600E+01, -.67205500E+01, 0.29893300E+01, -.12737700E+01, -.79702900E-01, -.15106300E+02, 0.75282400E+01, 0.76369400E+01, 0.58568400E+00, 0.16961900E+01, 0.44828400E+01, -.80775200E+00, 0.30874100E+01, 0.45519000E+01, 0.18100600E+01, -.80758900E+00, 0.29823600E+00, -.44302100E+01, 0.13385100E+01, 0.10426800E+01, 0.53241600E+01, 0.44843400E+01, -.46214900E+01, 0.65103800E+00, -.10696900E+01, 0.35295800E+00, -.18435000E-01, -.28334600E+01, 0.12445500E-01, 0.19219800E+01, -.12417500E+01, -.36306200E+00, 0.14389300E+00, 0.42031000E+00, -.40253800E-01, 0.40189200E+00, -.49209500E+01, 0.69855900E+01, -.99568500E+00, 0.17210700E+02, 0.14244300E+02, 0.14164900E+01, 0.84437400E+00, -.79129800E+00, 0.31757100E+01, -.13600500E+01, 0.29136500E+01, -.43332100E+01, -.35121100E+01 },
            { 0.84103500E-01, -.12607600E-01, 0.12707900E-01, -.24339500E+00, -.41796800E+00, -.11908900E-01, -.36897000E-01, 0.10864100E+00, 0.10018400E+00, -.59345300E-01, -.63189000E-01, 0.13137400E-01, -.30435700E-01, 0.21725400E-01, 0.44910800E-01, 0.26537800E-01, -.13323300E+00, -.59779800E-01, 0.11563500E+00, -.34177300E-01, -.93489400E-01, 0.14520800E-01, -.16917200E+00, -.19682200E+00, 0.24760000E-01, 0.32812600E-01, 0.13377900E+00, 0.91875100E-02, 0.81040200E-02, 0.24862800E-01, 0.10551800E+00, -.20994400E-01, 0.46859400E-02, -.21751500E-01, -.53173700E-02, 0.13350200E+00, -.35485200E-01, 0.13345100E-01, 0.19999100E-01, -.24475900E+00, -.26558600E+00, 0.91886100E-01, 0.11088700E+00, 0.12117000E+00, -.50544500E-01, 0.10521600E-01, 0.11758200E+00, -.37277400E-01, 0.17328700E+00, -.10195600E+00, -.11881700E+00, -.43417300E-01, -.12538400E+00, 0.89489400E-01, -.80466300E-02, 0.39521900E-01, -.29612900E+00, -.17048700E-02, 0.36557500E-01, -.71601600E-01, -.19421000E-01, 0.41596100E-01, -.32377700E-01, -.12495000E-01, -.62102900E-03, 0.35302900E-01, 0.93417200E-01, -.85675000E-01, -.36175600E-01, 0.67275200E+00, 0.13628500E-01, 0.36588600E-02, 0.39078100E-02, 0.57586500E-02, -.69878600E-02, -.36450600E-01, -.12011600E-01, -.15075500E-01, 0.45487500E-04, -.10944600E-01, 0.25099000E-01, -.40076600E-01, 0.10101400E-01, -.29013800E-02, -.48026200E-02, 0.99992600E-02, 0.11187200E-01, -.76381800E-01, -.86664500E-01, -.12726400E-01, -.32497900E-01, 0.41802500E-02, 0.18135100E-01, 0.33317900E-01, 0.22659500E-01, 0.95772100E-01, 0.17186800E+00, 0.70446300E-01, 0.14785600E-01, -.19870500E-01, -.16214700E-01, 0.13760000E-02, 0.12355400E-02, 0.84609800E-01, 0.55065700E-01, 0.75015800E+00, 0.63184000E-01, -.20249600E-01, -.15319300E+02, 0.78954200E+01, 0.85008300E+01, -.22999400E+00, 0.86991500E+01, -.10136300E+01, -.16977000E+02, -.78408600E+01, 0.68817000E+01, -.19063400E+02, 0.10638800E+02, 0.11279800E+02, -.17616200E+01, 0.25710600E+01, 0.58830200E+01, 0.60863100E+00, 0.65205400E+01, 0.30789900E+01, 0.12013900E+02, -.85323900E+01, -.64011500E+01, 0.86414900E+01, -.11895900E+01, -.59268200E+01, -.91546200E+01, -.59153300E+01, 0.13505400E+01, 0.63291200E+01, -.86448900E+00, -.45082000E+01, -.17338100E+01, -.38070400E+01, 0.32073100E+00, 0.41744300E+01, 0.27839500E+01, -.37324600E+01, 0.15850900E+02, -.95647800E+01, -.89896600E+01, 0.86408600E+01, -.17090900E+01, -.76627600E+01, -.92177600E+01, -.68135000E+01, 0.17531200E+00, -.71658900E+01, 0.38388800E+01, 0.13264400E+01, -.54775300E+00, -.12815800E+01, 0.48467500E+01, 0.48186700E+01, 0.41625200E+01, -.96931200E+00, 0.15689700E+01, -.12659200E+01, -.12558400E+01, 0.91770400E+00, 0.77738500E+00, -.11338800E+01, -.14508200E+01, -.47789600E+00, 0.93450500E-01, -.17737900E+01, 0.11412800E+01, 0.11588400E+01, -.97684900E+00, 0.62127900E+00, 0.87756700E-01, 0.80058400E+00, 0.25555100E+01, -.35489000E+00, -.63155300E+01, 0.37728100E+01, 0.20826100E+01, 0.42513600E+01, 0.37849000E+01, 0.34605100E+01, 0.13019700E+02, 0.60665300E+01, 0.30959400E+01, -.52784600E+01, 0.24109100E+01, 0.48767100E+01, -.58335600E+00, -.37854600E+00, -.39671600E+00, -.68953300E+01, 0.63998600E+00, 0.22388100E+01, -.34542800E+02, 0.16830600E+02, 0.19593200E+02, 0.16334600E+00, 0.48709900E+01, 0.43318000E+01, -.24129400E+02, -.37625900E+01, 0.76482200E+01, -.52487000E+01, 0.26354400E+01, 0.25667600E+01, 0.16069700E+01, 0.11537400E+01, 0.10637700E+01, -.47737600E-01, 0.31535500E+01, 0.92864000E+00, 0.11363200E+01, -.62579400E+00, -.24973500E+01, 0.13930300E+00, -.32214900E+00, -.26673200E+00, -.40818200E+01, -.90952900E+00, -.13738100E+01, 0.53602700E+00, -.10442900E+01, 0.18276800E+00, -.75454600E-01, 0.81711800E+00, -.21355100E+00, 0.14971600E+01, -.80255300E+00, 0.32598500E+00, -.19736300E+01, 0.32566000E+00, -.73664600E-01, 0.31496900E+00, 0.39673000E+01, -.61149000E+00, 0.82163200E+01, -.61770500E+00, -.10372100E+02, -.34874200E+01, 0.57764800E-01, 0.89616900E+00, -.41553900E+01, -.12713600E+01, -.16423500E+02, -.46900700E+00, -.87495400E+00 },
            { -.22108700E+00, 0.17067800E+00, 0.68278200E-01, -.65765300E-01, 0.31298000E-01, -.16005400E-01, 0.57185100E-01, 0.27513200E-02, -.20388000E-01, 0.26906900E-01, 0.11633100E+00, 0.19065400E+00, -.24627400E-01, -.31731300E-01, 0.45089900E-01, -.32653300E-01, 0.11684800E+00, -.55173600E-01, 0.22059800E-02, 0.11786500E+00, 0.15202300E+00, 0.54757700E-01, -.60682500E-01, 0.91157600E-01, 0.23294900E-01, 0.57356300E-01, 0.21014500E-01, -.36529800E-01, 0.45708900E-01, -.52338700E-01, -.83225200E-01, -.20552300E-01, 0.97011400E-01, 0.71202800E-01, 0.11816800E-01, 0.21648600E+00, 0.26437000E-01, -.10109700E-01, -.15994300E-01, -.12955200E+00, -.12417000E+00, -.35439700E-01, 0.12393000E-01, -.32111800E-01, -.32258000E-01, 0.57368300E-01, -.48336600E-01, 0.13126000E+00, 0.15125300E+00, -.37339100E-01, 0.53240100E-01, -.14863000E+00, 0.54693300E-01, 0.34183400E-01, -.71520800E-02, -.24556100E-01, 0.24752600E+00, -.12656200E-01, 0.97936700E-02, 0.47577200E-01, -.82898600E-02, -.37192200E-01, 0.15402000E-01, -.49389000E-01, 0.40263600E-01, -.72984000E-01, -.51418500E-02, 0.43095300E-01, -.81485500E-01, -.47114000E+00, -.76839500E-02, 0.37365200E-01, -.28265600E-01, 0.50299700E-02, 0.62831900E-02, -.60846500E-02, -.39572600E-02, -.25210300E-01, -.12407800E+00, -.67908700E-01, -.73512600E-01, -.66411100E-01, 0.18266500E-01, 0.31874400E-01, 0.16503600E-01, 0.21814800E-01, 0.22153700E-01, 0.11186200E+00, 0.89383100E-01, 0.87346900E-02, 0.94355900E-02, 0.48467300E-02, 0.15574400E-01, -.82458100E-01, -.28187200E-01, -.39701700E-01, -.65626300E-01, -.57442100E-01, -.20859300E-01, 0.14042800E-01, 0.18512900E-01, 0.39599700E-01, 0.14792600E-01, 0.12136000E+00, -.11677400E-01, -.10292700E+00, 0.44449100E+00, 0.44189900E-01, 0.19590300E+02, -.10086900E+02, -.10968200E+02, 0.10266600E+02, -.11343400E+01, -.85335800E+01, 0.11282400E+02, 0.50680100E+01, 0.46584800E-01, 0.21796300E+02, -.12331200E+02, -.12568800E+02, 0.17907400E+02, -.53588200E+01, -.11784600E+02, -.43964600E+01, -.69149000E+01, -.13645700E+01, 0.94156200E+02, -.43872600E+02, -.46644300E+02, 0.12231600E+02, 0.24089200E+02, -.44469600E+02, -.36959000E+02, -.43964900E+02, -.95648500E+01, -.71842100E+02, 0.32710000E+02, 0.36235200E+02, 0.20717300E+01, 0.10904100E+02, 0.15473000E+02, -.17527200E+02, -.46217500E+01, 0.17568300E+02, 0.14509700E+02, -.50833000E+01, -.58766300E+01, -.15203900E+02, 0.37654500E+01, -.73871600E+01, -.10901400E+02, -.87900600E+01, -.90860100E+01, 0.92505000E+01, -.49393300E+01, -.52926000E+01, -.99905700E-01, -.18445600E+01, -.55568000E+01, -.37998700E+01, -.98731500E+00, 0.23584600E+01, -.49998000E+01, 0.32501400E+01, 0.23268200E+01, -.61377000E+01, 0.43157100E+00, 0.40842600E+01, 0.34571500E+01, 0.52609200E+01, -.50678700E+00, 0.13263000E+02, -.67920700E+01, -.73536800E+01, 0.15705200E+02, 0.28539200E+00, -.76308600E+01, -.10130100E+02, -.63485100E+01, 0.49376900E+00, 0.17343700E+01, -.16613000E+01, -.17218000E-01, 0.41481600E+00, 0.60439700E+00, -.27660600E+01, -.14878500E+02, -.62300100E+01, 0.36995200E+01, 0.17101200E+02, -.83997000E+01, -.64644500E+01, 0.11258800E+02, -.45906700E+01, -.69823000E+01, -.18714400E+01, -.98978200E+01, 0.29771900E+01, 0.37672300E+02, -.18555800E+02, -.20614800E+02, 0.77240200E+00, -.11054200E+02, -.59284800E+01, 0.22044200E+02, 0.50197700E+01, -.13008100E+02, -.27732800E+02, 0.13806600E+02, 0.14067900E+02, -.82059700E+00, 0.19652600E+01, 0.69238100E+01, -.76892900E+01, 0.19205200E+01, 0.64214600E+01, -.32909300E+01, 0.17672400E+01, 0.38877600E+01, -.93903200E+01, 0.31661200E+01, 0.57988300E+01, 0.15840300E+02, 0.94261900E+01, -.74499200E+01, -.70507400E-01, 0.15836200E+00, -.16098200E+01, 0.78444700E-01, -.39383200E+01, -.12297100E+00, 0.95850500E+00, -.35092900E+00, -.41584500E+00, 0.47460600E+00, 0.30415700E-01, 0.37473500E-01, 0.20576100E-01, -.61773900E+01, 0.13156100E+02, -.25491900E+02, 0.48056700E+02, 0.54349900E+02, 0.43555400E+01, 0.21748600E+00, -.33984700E+01, 0.76651500E+01, 0.12844000E+00, 0.13807900E+02, -.58104600E+01, -.44734000E+01 },
            { -.27699900E+00, -.11040400E+00, 0.25295800E-01, 0.13529100E+00, 0.51353200E+00, 0.42851500E-01, 0.15756600E+00, -.38221200E-01, -.33404400E+00, 0.96199900E-01, 0.10187500E+00, 0.29347100E-01, 0.59421800E-01, -.10418700E-01, 0.59497400E-01, -.72220800E-01, 0.15251400E+00, -.62304200E-01, -.14056900E+00, 0.19353000E-01, 0.22087300E+00, -.18099200E-01, -.38602300E-02, 0.17023300E+00, 0.35286600E-01, -.13856000E-01, -.51970400E-01, 0.47393600E-01, -.13833700E-01, 0.20193200E-01, -.89454700E-01, 0.28674100E-01, 0.18275800E-01, -.24452200E-01, -.17632300E-01, -.33600900E+00, 0.11164600E+00, -.43796900E-01, -.66812300E-01, 0.23384300E+00, 0.39056800E+00, -.20016300E+00, -.15183100E+00, -.26340000E+00, 0.90506100E-01, 0.30210200E-01, -.70264100E-01, 0.28630300E-01, -.12618000E+00, -.19507900E-01, 0.15054700E+00, -.21307800E+00, 0.50803000E-01, 0.27820700E-01, -.40269000E-01, -.78096600E-01, 0.30431000E+00, -.69580400E-02, -.20155500E-01, 0.50609300E-01, -.13230100E-01, -.54115500E-01, 0.43586100E-01, 0.53168700E-02, 0.35526500E-01, -.12467600E+00, -.38488600E-01, 0.12690500E+00, -.40606100E-01, -.45321300E+00, -.50678000E-01, 0.11704200E+00, 0.68776400E-01, 0.18688100E-01, 0.62169000E-02, -.49403100E-01, 0.15287500E-02, -.49204600E-01, -.14964600E+00, -.97090100E-01, 0.41806500E-01, -.28678200E-02, -.12341900E+00, 0.30132000E-01, 0.49341200E-01, 0.37888000E-01, -.38664100E-01, 0.77597500E-01, 0.97765600E-01, 0.24963700E-02, 0.20748100E-01, 0.42869700E-02, 0.50545900E-02, -.10540100E+00, -.91897200E-01, -.24987700E-01, -.14149200E+00, 0.76608600E-01, -.52161100E-01, -.12240000E-01, 0.32509500E-01, 0.38924400E-01, 0.87222100E-01, -.12722400E+00, -.95100800E-02, -.93197700E-01, -.71225800E-01, 0.32265700E+00, -.32773500E+01, 0.13347400E+01, 0.28654400E+01, 0.26151500E+01, -.61926000E+01, 0.17467700E+01, 0.90888600E+01, 0.99983000E+01, -.59188100E+00, 0.14038600E+02, -.81927300E+01, -.60661100E+01, 0.49345000E+01, -.71248700E+01, -.55918300E+01, -.59488100E+00, -.93324600E-01, -.38930000E+01, 0.16340600E+02, -.57438400E+01, -.81924100E+01, -.60633900E+01, 0.34667500E+01, -.74625200E+01, -.42891400E+01, -.84649300E+01, 0.81173600E+01, -.45586100E+02, 0.20177000E+02, 0.23705500E+02, 0.39851400E+01, -.21626400E+00, 0.14000200E+02, 0.16280400E+01, 0.58136100E+01, 0.48890000E+01, -.16322300E+00, 0.11192800E+01, 0.37116600E-01, -.63620500E+01, -.11003100E+00, -.68226900E+00, -.35568600E+01, -.27622900E+01, 0.34609800E+01, -.15433100E+01, 0.66573000E+00, -.14710500E+01, 0.10823700E+01, 0.94183400E+00, -.27118400E+01, -.38347700E+01, -.16163900E+01, 0.22197100E+01, -.47536000E+01, 0.28191200E+01, 0.14591600E+01, -.10584500E+01, -.94398000E+00, 0.21724300E+01, 0.83758300E+00, 0.61536000E+00, 0.10121200E+01, 0.90220700E+01, -.48208000E+01, -.49643900E+01, 0.62210900E+01, 0.83853600E+00, -.57373700E+01, -.50988100E+01, -.59113000E+01, 0.97131100E+00, 0.11570000E+02, -.64127900E+01, -.59619800E+01, -.88218200E+00, -.17546600E+01, -.53241300E+01, -.10112800E+02, -.78600700E+01, -.39252900E+01, -.53576300E+01, 0.30441900E+01, 0.39914900E+01, 0.27108500E+00, 0.28408300E+00, 0.37085400E+01, 0.47230200E+01, 0.38237900E+01, -.56649200E+01, 0.85878500E+01, -.36631100E+01, -.14136800E+01, 0.17970000E+00, -.41079200E+01, 0.70158700E+00, 0.16947900E+02, 0.69170200E+01, -.36233200E+01, 0.52629400E+01, -.26534800E+01, -.25067000E+01, -.25854700E+01, 0.11800700E+00, -.21292700E+01, -.31681300E+01, -.62486200E+01, -.11547300E+01, -.78679500E+01, 0.39478800E+01, 0.48833300E+01, 0.34173100E+00, -.88561800E-01, 0.46573900E+01, 0.70677200E+01, 0.41484400E+01, 0.29460000E+01, -.16458400E+00, 0.17948900E+01, -.10576100E+01, 0.79543500E-01, -.17036500E+01, 0.20185400E+00, -.65357300E+00, 0.16590700E+01, -.12239700E+00, 0.28598700E+01, -.93291800E-01, 0.55200300E-01, -.98726600E-01, -.29524800E+01, 0.46564800E+01, -.10899800E+02, -.31215500E-01, 0.19169200E+02, 0.45257500E+01, 0.86575800E-01, -.17059600E+01, 0.26468500E+01, 0.19081400E+01, 0.13488100E+02, -.13133500E+01, 0.26037700E+01 },
            { -.31156400E+00, 0.25405900E+00, 0.91262400E-01, -.82019200E-01, 0.45716100E-01, -.26104900E-01, 0.75484400E-01, -.83935700E-02, -.23206800E-01, 0.23499100E-01, 0.13647900E+00, 0.27649300E+00, -.28484900E-01, -.38890500E-01, 0.47867500E-01, -.37294500E-01, 0.16671700E+00, -.58845900E-01, 0.85430600E-02, 0.17540100E+00, 0.19747000E+00, 0.45633200E-01, -.10343900E+00, 0.11050700E+00, 0.36537100E-01, 0.69559500E-01, 0.32386500E-01, -.46092800E-01, 0.73072600E-01, -.75438300E-01, -.11434400E+00, -.39715500E-01, 0.14246300E+00, 0.10017400E+00, 0.14868000E-01, 0.34071500E+00, 0.22783800E-01, -.84659500E-02, -.14303500E-01, -.17588500E+00, -.15860200E+00, -.38345100E-01, 0.65549300E-02, -.49353800E-01, -.40030100E-01, 0.81370500E-01, -.50553100E-01, 0.17025700E+00, 0.19954500E+00, -.46673800E-01, 0.91479300E-01, -.20494300E+00, 0.69109600E-01, 0.53588000E-01, 0.41327800E-03, -.37443200E-01, 0.23433800E+00, -.14096900E-01, 0.54365400E-01, 0.39963300E-01, -.76874800E-02, -.54224900E-01, 0.41064000E-01, -.74655700E-01, 0.66401600E-01, -.11103300E+00, -.23843900E-01, 0.38084100E-01, -.14116600E+00, -.56154700E+00, 0.95024400E-02, 0.33966400E-01, -.63140600E-01, 0.63250400E-02, 0.13045400E-01, -.21089100E-02, 0.93651600E-02, -.21355200E-01, -.15807900E+00, -.76511900E-01, -.12773400E+00, -.10572800E+00, 0.62478900E-01, 0.53149300E-01, 0.13720300E-01, 0.30010100E-01, -.22662900E-01, 0.17497500E+00, -.34164600E+00, 0.65509200E-02, 0.62325900E-02, 0.76232600E-02, 0.31154900E-01, -.12122400E+00, -.12274300E-01, -.63215800E-01, -.99279800E-01, -.37284300E+00, -.21417800E-01, 0.33870000E-01, 0.19695400E-01, 0.61948400E-01, -.16375200E-02, 0.28770300E+00, -.33493500E-01, -.15706000E+00, -.77341000E+00, 0.34007200E+00, 0.57559200E+02, -.29452600E+02, -.32332800E+02, 0.24317200E+02, -.27092500E+01, -.23656900E+02, 0.27610700E+02, 0.87974800E+01, -.28620900E+01, 0.50801600E+02, -.28711400E+02, -.29938500E+02, 0.40690900E+02, -.84851300E+01, -.28707600E+02, -.11473600E+02, -.21218300E+02, -.22539100E+01, 0.20529900E+03, -.95230600E+02, -.10154500E+03, 0.27153400E+02, 0.56859700E+02, -.96276800E+02, -.78284300E+02, -.93698400E+02, -.27467100E+02, -.15875000E+03, 0.71865700E+02, 0.79845200E+02, 0.43051600E+01, 0.27438000E+02, 0.32827800E+02, -.43410500E+02, -.15718400E+02, 0.41121200E+02, 0.25139300E+02, -.72872900E+01, -.91110600E+01, -.38720000E+02, 0.72885400E+01, -.10813900E+02, -.15377600E+02, -.10901800E+02, -.24988200E+02, 0.23355900E+02, -.12425500E+02, -.12467400E+02, -.10663100E+01, -.50824600E+01, -.12210100E+02, -.68379600E+01, -.11294300E+01, 0.42388400E+01, -.82925300E+01, 0.59177500E+01, 0.41886800E+01, -.13938900E+02, 0.12731300E+01, 0.81673700E+01, 0.80180200E+01, 0.10706400E+02, -.93093200E+00, 0.26849800E+02, -.13745100E+02, -.15107700E+02, 0.34505900E+02, 0.66771800E+00, -.16005500E+02, -.22482800E+02, -.15040300E+02, 0.75552100E+00, -.53577900E+00, -.14793100E+01, 0.24323300E+01, -.73817200E+00, 0.20140600E+01, -.41132600E+01, -.33852100E+02, -.10818600E+02, 0.92070900E+01, 0.48394100E+02, -.24077600E+02, -.19234500E+02, 0.26932600E+02, -.12354900E+02, -.19036300E+02, -.35879200E+01, -.27680600E+02, 0.74028500E+01, 0.10404600E+03, -.51713700E+02, -.57663600E+02, 0.16165200E+01, -.28666200E+02, -.18032500E+02, 0.51833400E+02, 0.91266800E+01, -.33903500E+02, -.72574100E+02, 0.36119700E+02, 0.36721600E+02, -.80481900E+00, 0.47886100E+01, 0.19086000E+02, -.16285200E+02, 0.98179800E+01, 0.15916800E+02, -.22449700E+01, 0.14240600E+01, 0.63982800E+01, -.21576700E+02, 0.74101500E+01, 0.11164200E+02, 0.35608300E+02, 0.19081900E+02, -.18602500E+02, 0.32798500E-01, 0.46934600E+00, -.35534600E+01, 0.28931900E+00, -.89159200E+01, -.52615700E+00, 0.15363900E+01, -.59196600E+00, -.24267500E+01, -.11766700E+01, 0.38964700E+00, 0.13310600E+00, 0.42217400E+00, -.12734100E+02, 0.26447200E+02, -.57786200E+02, 0.11182800E+03, 0.12080000E+03, 0.74037200E+01, 0.10461700E+01, -.75494800E+01, 0.16734900E+02, 0.59054200E+00, 0.29626500E+02, -.11394300E+02, -.11231700E+02 },
            { 0.85400200E+00, -.37652300E-01, -.14606700E+00, -.15480800E+01, -.30408100E+01, -.26945700E-01, -.47354800E+00, 0.89021500E+00, 0.13228200E+01, -.37790900E+00, -.28282800E+00, -.51557700E+00, -.32698900E-02, 0.28653600E+00, 0.70369600E+00, 0.31650500E-01, -.49842200E+00, 0.31022300E+00, 0.95176000E+00, -.31443100E+00, -.24859300E+01, 0.21211700E+01, -.16057500E+00, 0.25743600E+01, -.31325400E+00, 0.33762200E+00, 0.69907800E+00, 0.25857200E-01, 0.24738000E-01, 0.18619900E+00, 0.79935200E+00, -.62550200E+00, 0.23400400E+00, -.65391200E+00, -.52448000E+00, 0.64034500E+00, -.23193800E+00, 0.90013600E-01, 0.13153600E+00, -.23577100E+00, 0.14924400E+01, 0.42778100E+00, 0.10429800E+00, 0.54898200E+00, 0.45878000E+00, 0.66477300E-01, 0.48044000E+00, -.10086900E+01, 0.47572700E+00, 0.55249300E+00, -.11837900E+01, 0.19800900E+01, -.45658900E+00, -.13068800E+00, 0.49790200E+00, 0.45583500E+00, -.33166100E+01, -.16972400E-01, 0.96246900E+00, -.87308100E+00, -.78267800E+00, 0.13146400E+01, -.38189100E+00, -.58058000E+00, -.38989000E+00, 0.14444500E+01, 0.15697900E+01, -.18693500E+00, -.70197800E+00, 0.13180800E+02, -.50595400E+00, 0.52465700E+00, 0.13842200E+00, 0.38473100E+00, -.11528500E+00, 0.59688300E+00, -.23998800E+00, -.62811000E+00, 0.27923500E+00, -.10730600E+01, 0.29659700E+00, 0.38510600E+00, -.17485500E+01, 0.23703300E+00, 0.22894600E+00, -.13382000E+00, 0.54654100E+01, -.13759600E+01, 0.52667900E+01, 0.25014000E+00, -.44844200E+00, 0.17684000E+00, 0.21077700E+00, 0.14738300E+01, 0.79533700E+00, 0.12431300E+01, 0.21436600E+01, 0.57426100E-01, 0.54310000E+00, -.18408500E+00, 0.42435900E-01, 0.23944900E-01, -.13071400E+01, -.89320800E+00, 0.91077400E+00, 0.16026700E+01, 0.42177900E+00, -.30693300E+00, 0.50316800E+01, 0.74416400E+01, 0.15044300E+02, -.15892200E+03, 0.25439400E+02, 0.20088600E+02, -.11599300E+03, -.19007400E+03, 0.10308800E+02, -.35756000E+03, 0.20752800E+03, 0.18754400E+03, -.14401100E+03, 0.13990100E+03, 0.14110000E+03, -.33918300E+02, 0.21808500E+02, 0.12346200E+03, -.77432200E+03, 0.32845600E+03, 0.38492500E+03, -.21963600E+02, -.28432200E+03, 0.31982100E+03, 0.13215400E+03, 0.31593400E+03, 0.81296600E+02, 0.11301800E+04, -.49371300E+03, -.53602600E+03, -.12520300E+03, -.13688700E+03, -.28174400E+03, 0.14637900E+03, 0.10621300E+02, -.23339100E+03, 0.11054800E+03, -.84240100E+02, -.65083700E+02, 0.24561200E+03, -.12495600E+02, -.58708900E+02, 0.17636800E+01, -.65073600E+02, 0.86773600E+02, -.12706400E+03, 0.65771800E+02, 0.96917100E+02, -.43911500E+02, -.25881500E+01, 0.94379700E+02, 0.10181600E+03, 0.67973600E+02, -.31466400E+02, 0.26969700E+02, -.25982100E+02, -.11384300E+02, 0.53575000E+02, 0.61048000E+01, -.39744900E+02, -.23027400E+02, -.47459900E+02, -.20210600E+02, -.64424700E+02, 0.37404600E+02, 0.39905600E+02, -.11082400E+03, 0.27135700E+02, 0.41223800E+02, 0.70020300E+02, 0.30359500E+02, 0.33016600E+02, -.49433900E+02, 0.36985000E+02, 0.25668500E+02, 0.42327100E+02, 0.13881600E+01, 0.50027900E+02, 0.10714600E+03, 0.36286400E+02, 0.52118200E+01, -.17704900E+03, 0.87749700E+02, 0.24344100E+02, -.92962700E+02, 0.15187300E+02, 0.85830300E+02, 0.87859700E+02, 0.12744200E+03, -.23722400E+02, -.22678700E+03, 0.11030300E+03, 0.12406300E+03, -.75376100E+02, 0.60302900E+02, 0.58824300E+01, -.15604700E+03, -.71477100E+02, 0.79175300E+02, 0.26680400E+03, -.13185700E+03, -.13580500E+03, 0.10789900E+02, -.25149600E+02, -.71578400E+02, 0.54711300E+02, -.45023900E+02, -.46273200E+02, 0.15138900E+03, -.76916400E+02, -.82440000E+02, 0.34077600E+02, -.37444700E+02, -.10901200E+03, -.18923100E+03, -.95876700E+02, 0.18938500E+02, 0.39710300E+01, -.20438200E+02, 0.33077400E+02, -.25050700E+01, 0.42560800E+02, 0.25869200E+01, 0.13310100E+02, -.18462600E+02, 0.11918400E+02, -.37996400E+01, 0.94414600E+00, -.14195500E+01, 0.59691200E+00, 0.77028700E+02, -.12910300E+03, 0.27288300E+03, -.17512100E+03, -.55377500E+03, -.30480800E+02, 0.11713800E+02, 0.25444500E+02, -.26559300E+02, -.13571200E+02, -.14420200E+03, 0.64901100E+01, 0.14616400E+02 },
            { -.13728000E+01, 0.72616300E+00, 0.24223700E+00, -.16659800E+00, -.64390400E+00, -.29230000E+00, 0.44155100E+00, -.17501400E-02, -.75260400E+00, 0.50062900E+00, 0.22145700E+01, 0.27038100E+01, -.23461200E+00, -.82438100E+00, 0.50488400E+00, -.29223400E+00, 0.46403100E+00, -.42148900E+00, -.38619200E+00, 0.29398300E+00, 0.10390300E+01, -.57120000E+00, 0.14172000E-01, -.87636700E-01, 0.22068300E-01, 0.41515800E+00, -.79248100E-01, -.22744900E+00, 0.12103900E+00, -.56015700E-01, -.32820600E+00, 0.15343100E+00, 0.67350400E+00, 0.40170500E+00, 0.31610400E+00, 0.27290400E+00, 0.64257800E+00, -.25454000E+00, -.38444700E+00, 0.12709000E+01, -.23835800E+00, -.86503200E+00, -.18522100E+00, -.10182300E+01, -.82265300E-01, 0.66130700E+00, -.39354500E+00, 0.19199800E+01, -.18214500E+00, -.10263200E+00, 0.73044600E+00, -.91778100E+00, 0.42095200E+00, 0.43450300E+00, 0.19899100E+00, -.77869600E+00, 0.96573700E+00, -.82649200E-01, 0.42511900E-01, 0.31884300E+00, -.27821800E+00, -.45998700E+00, 0.55536100E-02, 0.29127000E-01, 0.32747800E+00, -.57517900E+00, -.21199400E+00, -.29403700E+00, 0.79972400E+00, -.72850200E+01, -.62720600E+00, -.23977000E+00, 0.15801800E+00, -.15940900E-01, 0.13753400E+00, 0.15851800E+00, -.37862600E+00, -.54671900E+00, -.19156600E+00, -.45959000E+00, 0.10909100E+00, -.73447700E-01, -.23837100E+00, 0.73755100E+00, 0.25807600E+00, -.17196100E+00, 0.56284400E+00, 0.51891100E+00, 0.18203000E+01, 0.25811900E+00, 0.46320400E+00, -.22518800E-01, -.14888400E+00, -.86647500E+00, 0.10816400E+00, -.18437000E+01, -.25852000E+01, -.21119500E+01, -.65154400E-01, 0.54314600E+00, 0.23984900E+00, 0.70717200E-01, 0.20062200E+00, 0.34088300E+01, -.15555100E+01, -.27924000E+01, -.14980500E+01, 0.12485700E+01, 0.39659100E+01, 0.99144000E-01, 0.17678100E+02, 0.16889800E+02, 0.38954000E+02, 0.19393700E+02, -.32429100E+02, 0.78397000E+01, 0.42512100E+02, 0.11916500E+03, -.59228500E+02, -.61449700E+02, 0.92638600E+02, -.42355100E+02, -.16357900E+02, 0.31297600E+01, 0.15551800E+02, 0.10507200E+02, 0.57995200E+03, -.29172800E+03, -.28758600E+03, 0.13242900E+03, 0.14060000E+02, -.32251000E+03, -.35222000E+03, -.29106000E+03, 0.65744000E+02, -.17981300E+03, 0.89515700E+02, 0.91645700E+02, 0.60723500E+02, 0.14822000E+03, -.52174400E+02, -.16261900E+03, -.72376600E+02, 0.10156700E+03, 0.25879300E+03, -.13827300E+03, -.12585800E+03, 0.19413100E+02, 0.50326300E+02, -.18707900E+03, -.26498500E+03, -.18469200E+03, 0.47510500E+02, 0.10035800E+03, -.49638100E+02, -.16970400E+02, -.28256000E+01, -.13872200E+02, -.29668400E+02, -.24474400E+02, -.23659300E+02, -.30634500E+02, -.32094400E+02, 0.16243800E+02, 0.30481300E+02, -.25228000E+02, -.13606400E+02, 0.19949700E+02, 0.10432700E+02, 0.47365100E+02, -.20443800E+01, 0.15663000E+03, -.78694700E+02, -.81335000E+02, 0.10441800E+03, -.58452400E+01, -.33217500E+02, -.31630300E+02, -.40600500E+02, 0.57231100E+01, 0.17645700E+03, -.89823200E+02, -.84016600E+02, 0.25658400E+02, -.16390700E+02, -.73087700E+02, -.81015000E+02, -.10814200E+03, -.28733600E+02, 0.13366600E+03, -.63169700E+02, -.13858500E+03, -.15786800E+02, -.31518700E+02, -.19702600E+02, -.37443900E+02, -.28590100E+02, -.54936400E+02, -.18114500E+03, 0.95929400E+02, 0.10571900E+03, -.28349700E+02, -.56851700E+02, 0.10243900E+03, 0.83822100E+02, 0.10524000E+03, -.25616000E+02, 0.15668700E+03, -.77884200E+02, -.79056200E+02, -.15229700E+02, -.33942800E+02, -.54253800E+02, -.28798200E+02, -.45576000E+02, -.55090200E+02, -.15375100E+03, 0.76742500E+02, 0.91045800E+02, -.47455000E+01, 0.43586700E+02, 0.47315900E+02, 0.40546000E+01, 0.30807300E+02, 0.22985200E+02, -.53466900E+01, -.97686300E+00, -.11583100E+02, 0.10404200E+01, 0.21474100E+02, -.13131900E+01, 0.10855700E+02, -.77905900E+00, 0.55874800E+01, -.72895800E+00, -.37265300E+01, 0.72478300E+00, -.36964100E+01, -.14806600E+02, 0.76868500E+02, -.26444700E+02, 0.47567900E+02, 0.22854800E+03, -.21744900E+01, -.14328400E+02, -.26723600E+02, 0.35244100E+02, 0.37504300E+02, 0.85764200E+02, -.61102000E+01, -.14265200E+01 },
            { -.44272600E-01, -.44166000E-01, -.49991600E-01, 0.12273400E+00, 0.12818200E+00, 0.18207800E-01, 0.27238700E-01, -.73241100E-02, -.28372100E-01, 0.41635000E-01, -.27382600E-02, -.54357100E-02, 0.79977900E-01, -.14775400E-01, 0.32398000E-01, -.28147200E-01, 0.64069200E-01, -.12712500E-01, -.54385900E-01, -.92989100E-02, 0.52465200E-01, -.33484500E-01, 0.13776200E-01, -.68738100E-01, 0.20471300E-01, 0.28971900E-02, -.95591200E-02, 0.18803200E-02, -.62507600E-02, 0.21956100E-01, 0.29656100E-02, -.19405200E-02, 0.35120900E-02, -.13611200E-01, 0.66228800E-03, -.76924200E-01, 0.24256300E-01, -.97192000E-02, -.13594500E-01, -.14941300E+00, 0.90053800E-01, -.36222100E-01, -.17293200E-01, -.39746200E-01, 0.79505900E-02, 0.31033400E-01, -.15788800E-02, 0.10222300E+00, -.63921000E-02, 0.83129100E-02, -.78715100E-01, 0.10161400E-02, -.16143900E-02, 0.30129900E-01, -.13717200E-02, 0.35523400E-01, -.71857500E-01, -.24409500E-02, -.14494400E-02, 0.14833900E-01, -.20725300E-01, 0.29835000E-01, -.16960900E-01, -.23890500E-03, -.34042700E-01, 0.53002100E-01, 0.67206800E-01, 0.72100200E-01, -.96208900E-02, -.23839200E-01, -.40382500E-02, 0.68499900E-01, 0.49064500E-02, -.21342600E-02, -.13537900E-01, -.19920400E-01, -.22068600E-01, 0.11774600E-01, 0.12880600E-01, 0.14467500E-01, -.15947700E-01, -.60806700E-03, 0.14579000E-01, -.23933100E-01, 0.28999400E-01, -.19200600E-01, 0.43683600E-01, -.11889700E+00, 0.13545500E+00, 0.63841100E-02, 0.27637800E-01, -.68137600E-02, -.30269700E-01, -.66137700E+00, 0.64501200E-01, -.43716700E-01, -.85313300E-02, 0.21821800E-01, 0.42797300E-01, 0.21920400E-01, 0.37640100E-02, -.46593900E-01, -.14402800E+00, -.27116700E+00, 0.24835600E-01, 0.10859000E+00, 0.87133100E-01, -.51230300E-01, 0.13525700E+00, 0.14155200E-01, 0.29395500E-01, -.14608400E+02, -.12850300E+02, 0.60884300E+01, -.16791300E+01, 0.84700400E+00, -.12478800E+02, -.11033100E+02, 0.58517600E+01, 0.51664300E+01, -.26745100E+02, -.18297700E+01, 0.80920200E+01, 0.67976900E+01, 0.66597300E+01, -.89927900E+01, -.16508500E+03, 0.81738100E+02, 0.82619500E+02, -.33210200E+02, -.20657700E+02, 0.85398100E+02, 0.84136300E+02, 0.89791400E+02, -.55893500E+01, 0.10487000E+03, -.50428900E+02, -.47901300E+02, -.73111700E+01, -.22868700E+02, -.21763100E+02, 0.25611100E+02, 0.10100200E+02, -.24889700E+02, -.80251300E+02, 0.40235800E+02, 0.40040100E+02, -.40388500E+00, -.81736600E+01, 0.45845600E+02, 0.54930200E+02, 0.51123800E+02, 0.73766800E-01, -.28556100E+02, 0.14163500E+02, 0.18091200E+02, -.28235400E+01, 0.36088000E+01, 0.93248000E+01, 0.10138900E+01, 0.37902500E+01, 0.36521200E+01, 0.12969600E+02, -.65926200E+01, -.63260600E+01, 0.10618500E+02, 0.18253100E+01, -.67057200E+01, -.26887400E+01, -.99155400E+01, 0.15291500E+01, -.91790400E+01, 0.45446200E+01, 0.49592300E+01, -.18053200E+02, -.47989900E+00, 0.41403300E+01, 0.10640500E+02, -.84797200E+01, -.13412900E+01, -.24150200E+01, 0.12744700E+01, 0.20268800E+01, -.89253000E+01, 0.10103300E+01, 0.17057500E+01, 0.90058500E+01, -.80245000E+01, -.22483600E+01, -.17542500E+02, 0.88468200E+01, 0.38622900E+01, -.12912800E+02, 0.24216100E+01, 0.12433400E+02, 0.12167500E+02, 0.14906500E+02, -.81509400E+01, 0.33754100E+02, -.16730800E+02, -.17880100E+02, -.27357400E+01, -.17595500E+01, -.78413600E+01, -.63146700E+01, -.97259600E+01, -.61610200E+01, 0.30569500E+02, -.15266200E+02, -.15434300E+02, -.32445500E+01, -.25734300E+01, -.75144300E+01, 0.72383000E+01, -.74031600E+01, -.42129600E+01, 0.12577000E+02, -.63475800E+01, -.52364300E+01, 0.99504200E+01, -.71048800E+01, -.71303300E+01, -.11133600E+02, -.91044500E+01, 0.73020900E+01, -.76979700E+00, 0.32268000E+01, 0.25169700E+01, -.32644100E+00, 0.97654300E+00, 0.34091600E+00, -.35500200E+01, 0.36670300E+01, 0.14412900E+01, -.34968100E+01, -.47057300E+00, -.11528900E+00, -.48293800E+00, 0.71433400E+01, -.24141900E+02, 0.22154600E+02, -.46275000E+02, -.67600500E+02, -.24389900E+01, 0.14303100E+00, 0.40856100E+01, -.35428300E+01, 0.21753000E+00, -.60814600E+01, 0.30248500E+01, 0.80990500E+01 },
            { 0.46424200E+00, 0.23367000E-01, 0.33117000E+00, -.91036900E+00, -.11883700E+01, -.98052600E-01, -.14040800E+00, 0.35075000E-02, 0.37331800E+00, -.11858200E+00, -.61111400E-01, 0.23286100E+00, 0.62701600E-01, -.38293300E+00, 0.10914200E+00, -.68443200E-01, -.23925000E-01, 0.69433900E-01, 0.63067500E+00, -.25188600E+00, -.68403700E+00, -.39861400E+00, 0.30003900E+00, -.63982700E+00, -.27884000E-01, -.11886600E-01, 0.10473300E+00, -.10961900E+00, 0.12253300E+00, 0.29137900E+00, -.30296600E+00, -.40296600E+00, -.21124500E+00, -.41404700E+00, 0.11534100E+00, -.20820900E+00, -.11612800E-01, 0.44195400E-02, 0.90734000E-02, -.71336300E+00, -.48284200E+00, 0.78383200E-01, 0.25595900E+00, 0.14133700E+00, -.27385500E+00, 0.16828500E+00, -.25506900E+00, -.12540100E+00, 0.15332500E+00, -.24881800E-01, -.38079900E+00, 0.24568500E+00, -.22662900E-01, -.60327800E-01, 0.30497200E+00, -.13982800E+00, -.18109100E+00, 0.31526600E-01, -.16640500E-01, 0.29356300E+00, 0.25421700E+00, -.15427600E+00, 0.11338900E+00, 0.29674100E+00, -.66652200E-01, 0.39022100E-01, 0.37588800E+00, -.37598000E+00, 0.38720600E-01, -.62392100E+00, 0.19391800E+00, -.43867000E+00, -.17538600E+00, 0.22148400E-01, -.98005200E-01, -.54137100E+00, -.26189600E+00, -.11116300E+00, -.23990800E+00, -.21640900E+00, 0.57139000E+00, 0.31638400E+00, -.33237700E+00, -.16769800E+00, 0.18773100E+00, -.92000100E-01, -.12320900E+01, -.59555500E+00, -.15560100E+01, -.11871200E+00, 0.43416500E-01, -.72948400E-02, -.92484700E-01, -.51530500E+00, -.58830700E+00, 0.86238800E-01, 0.24754700E+00, 0.86047500E+00, -.39129700E+00, -.85906000E-01, 0.47835400E-01, -.13744100E+00, 0.47210600E+00, -.29372300E+00, -.27519500E-01, 0.34813400E+00, -.10644200E+01, 0.14455800E+01, 0.14366300E+01, 0.14413000E+00, 0.74564700E-01, 0.33966800E+01, 0.67409800E+02, -.17718800E+02, -.41334300E+02, -.93395100E+02, 0.48785800E+02, -.22842000E+03, 0.11419500E+03, 0.12477100E+03, 0.44092200E+02, 0.40180000E+02, 0.65048700E+02, -.29592200E+02, 0.54786900E+01, 0.58631100E+02, 0.35842400E+03, -.17920700E+03, -.18222000E+03, 0.14250200E+03, 0.58034500E+02, -.17301800E+03, -.13242400E+03, -.17874000E+03, 0.11538500E+02, -.28230400E+03, 0.13563500E+03, 0.11762000E+03, 0.28256200E+01, -.64138400E+01, 0.12554000E+03, 0.91856700E+02, 0.88580400E+02, -.10889500E+02, 0.26646500E+03, -.13738600E+03, -.13974600E+03, 0.75369800E+02, 0.20897000E+02, -.15278800E+03, -.18787200E+03, -.18029500E+03, 0.76922100E+01, 0.57784100E+02, -.26508100E+02, -.52384100E+02, 0.59513700E+02, 0.97918600E+01, -.15047700E+02, 0.58251300E+00, -.21613900E+02, -.17223800E+02, 0.91899600E+01, -.52953700E+01, -.85898800E+01, -.25217200E+02, -.20638500E+02, 0.21292600E+01, 0.30455300E+01, 0.40603700E+01, 0.87726500E+01, -.12026700E+03, 0.60161400E+02, 0.62657900E+02, -.58000500E+01, -.49513400E+01, 0.45662500E+02, -.21144500E+02, 0.69415200E+02, 0.18564900E+02, 0.19084300E+02, -.81414400E+01, -.19147600E+02, 0.65783400E+01, -.40329900E+02, 0.28218500E+02, 0.43798500E+02, 0.13470500E+03, -.41182700E+02, 0.37792800E+02, -.19014600E+02, 0.16874900E+02, -.84288200E+01, 0.46808200E+02, -.45946200E+02, -.28636600E+02, -.56468500E+02, 0.23418200E+02, -.16253600E+03, 0.80994900E+02, 0.89711100E+02, 0.25487800E+02, 0.84520600E+02, 0.47332600E+01, -.67867200E+02, -.81593700E+02, 0.79170200E+02, -.16253200E+03, 0.81504300E+02, 0.80830100E+02, 0.29616400E+02, 0.23392600E+02, 0.63210100E+02, 0.34130600E+02, 0.84280200E+02, 0.94372300E+01, -.52090100E+02, 0.26221200E+02, 0.53859000E+01, 0.52560900E+02, 0.25750600E+02, 0.25062200E+01, -.15717600E+02, 0.10657500E+02, 0.33538000E+02, 0.21663000E+01, -.11593800E+02, -.72858200E+00, 0.49050100E+00, -.13705600E+02, -.47618800E+00, -.22023200E+02, -.14152700E+02, -.79765200E+01, 0.27894100E+02, 0.11521900E+01, 0.85742300E-01, 0.11910400E+01, 0.15684400E+02, 0.36812200E+02, 0.26189100E+02, 0.10712000E+02, 0.68452900E+02, -.18630800E+02, -.87635000E+01, -.61613700E+01, -.43072900E+02, -.42173900E+01, -.67438900E+02, 0.67283500E+02, -.16004200E+02 },
            { -.15140800E+00, -.54975800E-01, 0.19092100E-01, 0.71842600E-01, 0.28409800E+00, 0.26194100E-01, 0.88023400E-01, -.18388800E-01, -.19897000E+00, 0.50206700E-01, 0.57293800E-01, 0.17473400E-01, 0.35996400E-01, -.44038700E-02, 0.23172200E-01, -.34878200E-01, 0.78735600E-01, -.27791800E-01, -.89902900E-01, 0.20068800E-01, 0.12405800E+00, -.58290100E-02, -.62644000E-02, 0.91596600E-01, 0.25306900E-01, -.68215600E-02, -.24215400E-01, 0.29605100E-01, -.90505600E-02, 0.73055700E-02, -.57940700E-01, 0.16474700E-01, 0.10344200E-02, -.11319200E-01, -.89663700E-02, -.22933400E+00, 0.62492700E-01, -.24490500E-01, -.37452400E-01, 0.11485500E+00, 0.19420700E+00, -.10723600E+00, -.76334100E-01, -.13603100E+00, -.15651100E+00, 0.92288400E-02, -.41922200E-01, -.94040800E-03, -.41316100E-01, -.16288000E-01, 0.10160700E+00, -.12259400E+00, 0.36433900E-01, 0.21423000E-01, -.22890800E-01, -.40831200E-01, 0.15293100E+00, -.66712600E-02, -.49891200E-02, 0.23772000E-01, -.29942700E-02, -.24202400E-01, 0.22065600E-01, 0.39520600E-02, 0.17281800E-01, -.69566600E-01, -.11007700E-01, 0.69635100E-01, -.35504400E-01, -.16615600E+00, -.28742800E-01, 0.24172300E-01, 0.22593000E-02, 0.13840000E-01, -.12529200E-02, -.39161600E-01, -.24546100E-02, 0.34016200E-03, -.42282700E-01, -.30939000E-01, -.19191400E-02, -.22922800E-01, -.16415300E-01, 0.28216600E-01, 0.16206600E-01, 0.16494400E-01, -.16536200E+00, 0.66561000E-01, -.15255200E+00, -.42390400E-01, -.81371100E-01, 0.27792700E-01, 0.65692800E-01, -.85883400E-01, -.13852800E+00, 0.28536000E+00, 0.39461800E+00, 0.51612100E+00, -.83097400E+00, -.90606500E-01, 0.23063800E-01, 0.78142500E-01, 0.40510000E-01, -.54142000E+00, 0.20635100E+00, 0.20663800E+00, -.91272000E-01, -.20663600E-01, 0.38635900E+00, -.18797400E-01, 0.17885300E+00, 0.14870500E+01, 0.22486800E+00, -.11442300E+02, 0.56742700E+01, -.14727000E+02, 0.36181400E+01, -.45717500E+02, 0.22236700E+02, 0.26283400E+02, 0.82273100E+01, 0.18944200E+02, -.89748800E+00, -.23404900E+02, -.15442200E+02, 0.13255900E+02, -.16349300E+02, 0.92529000E+01, 0.72134500E+01, -.46066800E+02, 0.90636000E+01, 0.68855500E+01, 0.10494500E+01, -.19330300E+02, 0.93587700E+01, -.13098200E+03, 0.61877200E+02, 0.61052100E+02, -.47277400E+01, -.25335100E+02, 0.57765600E+02, 0.23050200E+02, 0.34228600E+02, -.37108000E+01, -.24388300E+02, 0.12696400E+02, 0.10272600E+02, -.29811200E+02, -.11479800E+02, 0.19760500E+02, 0.33116400E+02, 0.67707900E+01, -.71031400E+01, 0.22082700E+01, -.93909000E+00, -.13841400E+02, -.53493300E+01, -.43443100E+01, 0.15674000E+01, 0.14014600E+02, 0.91440400E+01, -.42938300E+00, -.26851900E+02, 0.13150100E+02, 0.94233000E+01, -.28836400E+01, 0.36514200E+01, 0.74454300E+01, -.26013500E+01, -.11885100E+01, 0.56737600E+01, -.98042900E+01, 0.47376300E+01, 0.51515700E+01, -.37453200E+01, 0.25312500E+01, -.15794300E+01, -.11953300E+01, 0.10086800E+02, -.39146200E+01, -.73722600E+02, 0.37293700E+02, 0.34327300E+02, 0.11766000E+02, 0.49590300E+01, 0.25608400E+02, 0.99535000E+01, 0.51327900E+02, 0.21462300E+01, -.21321200E+02, 0.98589000E+01, 0.27759900E+02, 0.21291900E+02, -.46073400E+01, -.41993300E+01, 0.14237500E+01, 0.11703000E+01, 0.19001900E+02, -.14790100E+00, -.95822300E+00, 0.41301500E+01, 0.36330500E+01, 0.16276500E+02, -.18574100E+02, -.47337000E+01, -.15444700E+02, 0.26639200E+02, -.41001400E+02, 0.20395600E+02, 0.20786000E+02, 0.78286200E+01, 0.14627000E+02, 0.91315100E+01, -.42233100E+01, 0.49953200E+01, 0.10146300E+02, 0.49501700E+01, -.25214100E+01, -.68445100E+01, -.29616400E+02, -.39192900E+01, 0.82967300E+01, 0.23209300E+02, 0.89269400E+01, -.22385500E+02, 0.27371700E+01, -.68781800E+01, 0.40434200E+00, -.22803200E+00, -.18331700E+01, 0.85147800E+00, 0.55629400E+01, -.76627100E+01, -.20928400E+01, 0.94635900E+01, 0.16807300E+01, -.23365700E+00, 0.16393700E+01, -.16154600E+01, 0.47209200E+01, -.42258000E+02, 0.36340200E+02, 0.32793600E+02, 0.11834600E+02, 0.40923700E+01, 0.16335000E+01, -.14390000E+02, -.93641900E+01, -.87804700E+01, -.24661800E+01, -.88057100E+01 },
            { 0.15016100E+00, -.17017900E-01, 0.75323400E-02, -.35064100E+00, -.65591000E+00, -.24770100E-01, -.67433600E-01, 0.15061800E+00, 0.16750600E+00, -.10272900E+00, -.12011600E+00, 0.15622700E-01, -.46691300E-01, 0.32839000E-01, 0.67673400E-01, 0.51475200E-01, -.22288300E+00, -.61381200E-01, 0.16416900E+00, -.53704600E-01, -.16167000E+00, -.35217700E-01, -.26112300E+00, -.31365300E+00, 0.42963300E-01, 0.34887200E-01, 0.20529600E+00, 0.32900400E-01, 0.10914500E-01, 0.49737200E-01, 0.18279700E+00, -.32316300E-01, -.12669300E-01, -.54303500E-01, -.12575900E-01, 0.23101000E+00, -.57768900E-01, 0.21880000E-01, 0.32202800E-01, -.30919800E+00, -.30373200E+00, 0.13744300E+00, 0.14775000E+00, 0.15817100E+00, -.68962200E-01, -.52424600E-02, 0.21535900E+00, -.95289300E-01, 0.22010400E+00, -.15340200E+00, -.16916100E+00, -.50159600E-01, -.19629100E+00, 0.13166000E+00, -.61802000E-02, 0.55660100E-01, -.57766200E+00, 0.12828200E-02, 0.93372800E-01, -.13349600E+00, -.34446600E-01, 0.70727300E-01, -.41099200E-01, -.15274700E-01, -.14359900E-02, 0.66065500E-01, 0.11245600E+00, -.13941000E+00, -.42224600E-01, 0.93107600E+00, 0.22499400E-01, -.40213700E-01, -.11417300E-01, 0.87249100E-02, -.92021900E-02, -.52320100E-01, -.62148100E-02, -.15328300E-01, 0.28021000E-01, 0.10857500E-01, 0.22951200E-01, -.44370900E-01, 0.32550200E-01, -.10186500E-01, -.13710900E-01, 0.32904500E-02, 0.18915800E-01, -.19145200E+00, -.11440200E+00, -.21882000E-01, -.46444000E-01, 0.91184300E-03, 0.22529200E-01, 0.84746800E-01, 0.68359800E-01, 0.15924700E+00, 0.12151600E+00, 0.15872200E+00, 0.48115900E-01, -.31532400E-01, -.38070900E-01, -.10510700E-01, -.29775600E-01, 0.16548200E+00, 0.11670800E+00, -.25733000E+00, 0.43392300E+00, -.30007400E+00, -.73467200E+00, 0.16283200E-01, -.11433100E-01, -.97784600E+00, 0.27488700E-01, 0.97127800E+00, -.32705500E+02, 0.66060500E+01, -.56316400E+01, 0.26122000E+02, -.12016100E+02, -.15613300E+02, -.19417700E+02, -.22669100E+02, 0.31232100E+01, 0.24076600E+02, 0.24143700E+02, -.20655800E+02, -.33945500E+02, 0.14781700E+02, 0.17892400E+02, 0.38412400E+02, -.90986300E+00, 0.27082700E+02, 0.39433200E+02, 0.58094500E+02, -.28820100E+02, 0.17152200E+03, -.80284600E+02, -.77824100E+02, -.30279500E+01, 0.84560700E+01, -.63359200E+02, -.14050900E+02, -.31454000E+02, -.67332500E+01, -.28048300E+02, 0.13594600E+02, 0.15754400E+02, 0.20193200E+02, 0.11738000E+01, 0.16835100E+02, 0.10406100E+02, 0.38546600E+02, -.84556100E+01, -.39948900E+02, 0.19805000E+02, 0.30886200E+02, -.50170400E+00, 0.25457600E+01, 0.13202500E+02, -.49215800E+01, 0.67859200E+01, 0.60080400E+01, 0.39321200E+02, -.19410400E+02, -.16915800E+02, 0.91070000E+01, 0.11692000E+01, -.12120800E+02, -.23850100E+01, -.42893900E+01, -.45824800E+01, 0.72162000E+01, -.32837000E+01, -.41665800E+01, 0.14299000E+00, -.25206700E+01, -.25252200E+01, -.85252500E+00, -.22496000E+02, 0.13985200E+01, 0.46646900E+02, -.23541700E+02, -.20788100E+02, -.14205200E+02, 0.71710700E+01, -.15977300E+02, 0.13472400E+02, -.51860500E+02, 0.87934400E+01, 0.14568000E+02, -.67510400E+01, -.21439400E+02, -.20533000E+02, -.16302800E+01, 0.85024100E+01, -.79287000E+01, 0.27439200E+01, -.19058000E+02, 0.28950600E+02, -.13941100E+02, -.17066200E+02, -.42901000E+01, -.25300400E+02, 0.70558500E+01, -.27974100E+02, 0.24948400E+01, -.36465400E+02, 0.33988300E+02, -.16974000E+02, -.17242200E+02, -.92500300E+01, -.13054700E+02, -.75807300E+01, 0.49153700E+01, -.41609500E+01, -.52571700E+01, 0.47875800E+01, -.23954900E+01, 0.30615200E+01, 0.27318300E+02, -.14094000E+01, -.62976000E+01, -.20704400E+02, -.76013000E+01, 0.16943900E+02, -.27039800E+01, 0.97502300E+01, -.68728900E+00, 0.67386700E-01, -.10282400E+00, -.11370300E+01, -.77061600E+01, 0.11052800E+02, 0.30185600E+01, -.18556000E+02, -.17500200E+01, 0.14402400E+00, -.15974300E+01, 0.13278000E+02, -.21433500E+02, 0.50347900E+02, -.33019600E+02, -.61320100E+02, -.17197200E+02, -.37850700E+01, 0.30222800E+01, 0.72312300E+01, 0.87704500E+01, -.20419500E+02, 0.19623500E+00, 0.11907300E+02 },
            { 0.22064800E+01, 0.42684700E+00, -.75677700E+00, -.18354100E+00, 0.12356400E+01, 0.36087600E+00, -.58175700E+00, 0.26445300E+00, 0.17862900E+00, -.26503100E+00, 0.73643200E-01, -.26818900E+01, -.78016100E+00, 0.27654400E+00, -.42915800E+00, 0.23543400E+00, 0.25744700E+00, 0.13256300E+01, 0.21967700E+00, -.53749000E+00, 0.42520800E-01, -.14442800E+01, 0.18275000E+00, -.16063500E+01, -.29920700E+00, 0.23655700E+00, -.19703700E+00, -.37466500E+00, 0.62351700E+00, 0.35540200E+00, 0.19210100E+01, 0.36243500E+00, -.23660400E+00, -.19286400E+00, 0.31875300E+00, -.16154200E+01, 0.55489900E+00, -.21470400E+00, -.34201500E+00, 0.14620500E+01, 0.49695300E+01, -.10216000E+01, -.99366400E+00, -.17455600E+01, 0.12939000E+01, 0.76537200E+00, -.77857100E+00, 0.12915800E+01, -.15762000E+01, 0.16388400E+01, -.23444500E+01, 0.20687000E+01, 0.13022700E+01, -.54614500E+00, 0.15511000E+00, 0.11528700E+01, -.89671400E+00, 0.11473800E+00, -.23279400E+00, 0.92717700E+00, 0.24153100E-01, 0.78722800E+00, -.64061800E+00, -.44615100E+00, -.91644600E+00, 0.13956500E+01, 0.63769700E+00, 0.11488200E+01, 0.53100100E+00, -.96842200E+00, -.72330300E+00, 0.67135200E+00, 0.58460400E+00, 0.25788700E+00, -.21309100E+00, 0.11001800E+01, 0.16022300E+00, 0.94877400E-01, 0.63858200E+00, -.16212900E+00, -.12615200E+01, 0.40927600E+00, -.73055000E+00, -.74916000E+00, 0.37100200E-01, -.31526100E+00, 0.67246400E+01, -.12753000E+01, 0.73438300E+01, 0.31716400E+00, -.50373200E+00, 0.17501200E+00, 0.88268200E-01, 0.27057200E+01, 0.16476800E+01, 0.16664400E+01, 0.21706800E+01, 0.70039800E+00, 0.11708600E+01, -.31773100E+00, 0.73912400E-02, -.23376200E+00, -.33397800E+01, -.45367500E+01, 0.15978100E+01, 0.24528600E+01, 0.26471600E+00, 0.15176600E+00, 0.36106500E+01, 0.75440900E+00, -.12574700E+01, 0.61246300E+00, -.55454300E+00, -.55113500E+01, 0.52053200E+01, -.27552800E+03, 0.86011700E+02, -.51849000E+03, 0.24984700E+03, 0.29359100E+03, 0.24413800E+03, 0.26551600E+03, 0.55279900E+02, -.39683900E+03, -.27887000E+03, 0.29304500E+03, 0.70718700E+03, -.32957600E+03, -.36560100E+03, -.41101100E+03, -.71239500E+02, -.46541300E+03, -.64350400E+03, -.79595500E+03, 0.38930000E+03, -.19494100E+04, 0.90001200E+03, 0.88015600E+03, 0.83911500E+02, -.25776300E+03, 0.76216400E+03, 0.28806100E+03, 0.64824100E+03, -.91694700E+02, 0.49000000E+03, -.24763000E+03, -.27120200E+03, -.12316000E+03, -.29616400E+02, -.28058200E+03, -.17295900E+03, -.50882400E+03, 0.10688100E+03, 0.43496500E+03, -.21324000E+03, -.30863800E+03, 0.41000700E+02, -.46320500E+01, -.15708700E+03, -.11335100E+02, -.10399800E+03, -.93535300E+02, -.41330300E+03, 0.20300600E+03, 0.19547000E+03, -.93697200E+02, -.37950900E+02, 0.12669000E+03, 0.22280600E+02, -.70114900E+01, 0.48647500E+02, 0.90328000E+02, -.49938400E+02, -.35112000E+02, 0.94762700E+02, 0.35613900E+02, -.28093900E+02, -.25619900E+02, 0.95480800E+02, 0.42078400E+02, -.49043600E+03, 0.24816500E+03, 0.21227400E+03, 0.21252300E+03, -.37370800E+02, 0.15389900E+03, 0.17639600E+02, 0.54988000E+03, -.83245500E+02, -.13245600E+03, 0.61781000E+02, 0.18527400E+03, 0.12792500E+03, 0.22015200E+02, -.86393200E+02, -.79987200E+02, -.41424800E+02, 0.10400500E+03, -.52346300E+03, 0.26017400E+03, 0.28935300E+03, 0.23835800E+02, 0.28274300E+03, -.43758700E+02, -.25700500E+02, -.18972200E+03, 0.39838000E+03, 0.11612100E+03, -.58119000E+02, -.56950900E+02, 0.56771300E+02, 0.96396800E+02, -.68266200E+02, -.15362200E+02, -.46608400E+02, -.68575000E+02, -.17447200E+03, 0.86584800E+02, 0.14207300E+02, -.23566900E+03, 0.27226200E+02, 0.87300400E+02, 0.93501800E+02, 0.52533800E+02, -.11725600E+03, 0.21011300E+02, -.11880300E+03, -.10423900E+01, -.14036700E+01, 0.11694600E+02, 0.12708000E+02, 0.98464200E+02, -.12455900E+03, -.26518400E+02, 0.20689300E+03, 0.11978500E+02, -.16365700E+01, 0.10999300E+02, 0.58055100E+01, 0.16264900E+03, -.58199200E+03, -.22595700E+03, 0.60510300E+03, 0.16255500E+03, 0.37650900E+02, -.55769000E+02, -.12848800E+03, -.30974300E+02, -.73998000E+02, 0.19133100E+02, -.12025200E+03 },
            { -.82019400E-01, -.90393700E-01, -.10222500E+00, 0.22980800E+00, 0.24282700E+00, 0.30953100E-01, 0.46024900E-01, -.14603300E-01, -.35841500E-01, 0.81194300E-01, -.29628900E-01, -.31183800E-01, 0.15008100E+00, -.19625900E-01, 0.70717900E-01, -.57102400E-01, 0.12471800E+00, -.20541000E-01, -.73099200E-01, -.41264800E-01, 0.89300900E-01, -.91217900E-01, 0.35773200E-01, -.14794900E+00, 0.26578900E-01, 0.54120400E-02, -.18774000E-01, -.62292800E-03, -.39941700E-02, 0.44887600E-01, 0.22300300E-01, -.67257400E-02, 0.39933200E-02, -.37212500E-01, 0.28199100E-02, -.16351100E+00, 0.45339300E-01, -.18038600E-01, -.25849800E-01, 0.10899500E+00, 0.24374200E+00, -.70674900E-01, -.45731400E-01, -.92474700E-01, 0.41776500E-01, 0.61166400E-01, 0.34498600E-02, 0.18821400E+00, -.34945900E-01, 0.21898500E-01, -.15848600E+00, 0.26916500E-02, -.43955700E-02, 0.49193400E-01, 0.22912800E-02, 0.71786800E-01, -.16292500E+00, -.49684700E-02, -.14810900E-01, 0.34202900E-01, -.29120500E-01, 0.47499500E-01, -.39909700E-01, 0.10707100E-01, -.61648400E-01, 0.85626200E-01, 0.64616700E-01, 0.14034000E+00, -.10408700E-01, -.10427400E+00, 0.81706600E-02, 0.10936200E+00, -.50133300E-02, -.86402100E-02, -.23087900E-01, -.51113100E-01, -.43795700E-01, 0.24354800E-01, 0.17027300E-01, 0.42487400E-01, -.18321500E-01, -.50868400E-02, 0.45099200E-01, -.35691900E-01, 0.39765000E-02, -.84012200E-02, 0.23253700E-02, -.50058700E-01, 0.72188700E-01, -.20834700E-02, 0.71284500E-02, -.40131700E-02, -.22146800E-01, 0.64938900E-01, -.38766100E-02, 0.19630000E-01, 0.42319100E-01, 0.87872000E-01, 0.41893300E-02, -.45717900E-02, -.14994700E-02, -.27999500E-01, 0.12262000E+00, 0.62555600E-01, 0.23215200E-01, 0.77025800E-01, 0.86477800E-01, -.21238100E+00, -.80593800E+00, -.69779500E-01, -.17568700E+00, -.46490200E+00, -.32164700E-01, -.20645400E+00, 0.96327100E-01, -.11770000E-01, 0.67061400E+01, -.10710500E+02, 0.51437200E+01, 0.20524700E+01, 0.20394500E+02, -.44971400E+01, 0.13177500E+01, -.87356700E+01, 0.22760300E+01, 0.76165400E+01, 0.85374400E+02, -.42303900E+02, -.42081400E+02, 0.79187300E+01, 0.13198300E+02, -.48125500E+02, -.53376000E+02, -.56576900E+02, 0.78720500E+01, -.73145800E+02, 0.37079600E+02, 0.38274500E+02, -.24137800E+01, 0.70055600E+01, 0.16869700E+02, -.13742400E+02, 0.33402100E+01, 0.11873200E+02, 0.31191300E+02, -.15247900E+02, -.13789100E+02, -.21125200E+01, 0.12773800E+02, -.26710700E+02, -.40658300E+02, -.39945800E+02, 0.50416800E+01, 0.14374800E+02, -.75465800E+01, -.33917300E+01, -.55331700E+01, -.53782800E+01, -.36046000E+01, 0.33412700E+01, 0.23307200E+01, -.28117300E+01, -.19138400E+02, 0.98062000E+01, 0.10053700E+02, -.11354900E+02, -.49222500E+00, 0.74443100E+01, 0.21902900E+01, 0.64701400E+01, 0.54575200E+00, 0.21020800E+02, -.10520600E+02, -.10610700E+02, 0.12972400E+02, -.27536300E+01, -.60128500E+01, -.47845600E+01, -.19373300E+01, -.10787900E+01, -.43467700E+01, 0.16267600E+01, 0.42932000E+01, 0.10566300E+02, 0.22742800E+01, -.89863100E+00, -.97671400E+01, -.26703500E+01, 0.18879100E+01, 0.24569000E+02, -.11711000E+02, -.19387300E+02, 0.12921400E+02, -.74767000E+01, -.93227000E+01, -.37690300E+01, -.87185800E+01, -.57158100E+00, -.24070000E+02, 0.12821400E+02, 0.87805600E+01, -.28167400E+01, -.74222800E+01, 0.91362000E+01, 0.14583000E+02, 0.18380100E+02, 0.12823600E+01, 0.12577100E+02, -.62572500E+01, -.60670900E+01, -.32092700E+00, 0.70785100E+00, -.54342800E+01, -.48259900E+01, -.83560000E+01, -.22463000E+01, -.36987500E+02, 0.18485100E+02, 0.21516700E+02, -.17951800E+02, 0.53234800E+01, 0.18032000E+02, 0.16850600E+02, 0.19106000E+02, -.67555100E+01, 0.21000500E+00, -.47294700E+01, -.32637700E+00, 0.21149100E-01, 0.21971700E+01, 0.66601000E-01, 0.69538300E+01, -.53815100E+01, -.37117500E+00, 0.54908700E+01, 0.26520900E+00, -.50707400E-02, 0.24108100E+00, -.28223500E+01, 0.18303500E+02, -.21779700E+02, 0.56087600E+02, 0.59860400E+02, 0.98922700E+01, 0.12615100E+01, -.23785400E+01, 0.35301000E+01, 0.37258600E+01, 0.10798400E+02, -.81774800E+01, -.31755000E+01 },
            { 0.12808100E+01, -.66958300E+00, -.85215800E+00, 0.72032600E+00, -.13384000E+01, 0.10296800E-01, -.42596600E+00, -.17867900E+00, -.25699900E+00, -.60566000E+00, 0.32776500E+00, -.74394100E+00, -.50304000E+00, 0.15495900E+00, -.76124300E+00, 0.50774100E+00, -.83613600E+00, 0.74736100E+00, -.77729600E+00, 0.59353900E+00, -.30161600E-01, 0.55436200E+00, -.16225200E+00, 0.45235100E+00, -.51190800E-01, -.32917000E+00, -.22971900E+00, 0.15066700E+00, -.37437500E+00, -.89198100E-01, -.12287300E+00, 0.71026000E+00, -.19015100E+00, 0.74887400E+00, 0.37672500E+00, 0.19035600E+01, 0.44043600E+00, -.17536000E+00, -.24562400E+00, 0.21424900E+01, 0.18175500E+01, -.64922400E+00, -.32717200E+00, -.74303300E+00, 0.16980500E+00, -.18879200E+00, -.17820600E+00, -.12910100E+01, -.12363100E+01, -.43092100E+00, 0.38677100E+00, -.19698000E+00, -.82293900E-01, -.31147000E+00, 0.38958400E+00, -.75136800E+00, -.23739600E+00, -.72025400E-01, -.32590600E+00, -.20665800E+00, -.11311800E+01, 0.29797100E+00, 0.18056800E+00, -.19577500E-01, -.20754700E-02, -.17435300E+00, -.84228400E+00, 0.14372600E+01, -.51494500E+00, -.12186000E+01, 0.17548200E+00, 0.55960200E+00, 0.51391500E-01, -.94524200E-01, 0.25091100E-01, -.20737500E+00, 0.12937300E-01, -.12408600E+00, -.20975300E+00, -.95792500E-01, 0.35819500E+00, -.12087100E-01, 0.83141200E-01, 0.20383300E+00, 0.91540400E-01, -.44789300E-01, 0.40691200E+00, 0.28205700E+00, 0.20050000E+01, -.24542900E-03, 0.38245800E-02, 0.33761000E-01, 0.28240200E-01, -.52695000E+00, -.73506400E+00, 0.49994700E+00, 0.44394200E+00, 0.17574600E+01, -.42349500E+00, -.24095300E+00, 0.14547400E+00, 0.16804200E+00, 0.90530900E+00, -.76729600E+00, 0.52050100E+00, 0.83139600E+00, 0.72476400E+00, 0.94002400E-01, -.15046100E+01, -.65103400E-01, -.33693600E+00, 0.68683500E+00, -.29883500E+00, 0.22002800E+01, 0.31987100E+00, -.12918500E+00, 0.19768500E+01, -.18306800E+03, 0.91490600E+02, 0.93812400E+02, 0.53388100E+02, -.69775600E+00, 0.39862400E+02, -.14067600E+02, 0.35017600E+01, 0.21857800E+02, 0.42480000E+03, -.21439900E+03, -.21257600E+03, 0.13383000E+03, 0.88439100E+02, -.18379800E+03, -.15863100E+03, -.21853500E+03, -.49555600E+02, -.27509200E+03, 0.13972600E+03, 0.12326100E+03, 0.29155700E+02, 0.23239900E+02, 0.80456400E+02, 0.52281000E+02, 0.59933700E+02, 0.44044100E+02, 0.20166500E+03, -.10660200E+03, -.10156700E+03, 0.32650500E+02, -.41627900E+01, -.95429600E+02, -.14324500E+03, -.10679300E+03, -.54647800E+02, 0.52374400E+01, -.18301800E+01, -.43044100E+01, 0.28999000E+02, -.23553700E+01, 0.29915100E+01, -.10196300E+01, 0.79801500E+00, 0.82843700E+01, -.64671100E+01, 0.36383900E+01, 0.71945800E+01, -.18158400E+02, -.15497900E+02, 0.14646600E+02, 0.21186600E+02, 0.18243800E+02, -.22377100E+01, -.30485300E+02, 0.15327400E+02, 0.14415700E+02, 0.32728000E+02, -.31752700E+01, -.54486200E+01, -.32268300E+02, 0.16455000E+02, 0.12453100E+02, 0.92014600E+02, -.47397500E+02, -.49271800E+02, -.12601800E+02, -.43518500E+02, -.65185500E+01, -.15166400E+02, 0.20463900E+02, -.26726100E+02, 0.15374900E+02, -.47185200E+01, -.25728100E+01, 0.31336500E+01, 0.20889900E+02, -.15907100E+02, -.48323000E+01, -.29313100E+02, 0.22969900E+02, -.71595000E+02, 0.40116700E+02, 0.38296500E+02, 0.12725700E+02, 0.21730100E+02, 0.17536500E+02, 0.38646100E+02, -.57443500E+01, 0.54475700E+01, -.62869200E+02, 0.31343800E+02, 0.31010800E+02, -.31034600E+00, 0.70336100E+01, 0.24323600E+02, 0.27569200E+01, 0.91610600E+01, 0.15044200E+02, -.23675700E+02, 0.11683900E+02, 0.71827100E+01, 0.25867300E+02, 0.19600100E+02, 0.90732200E+01, 0.18329400E+02, 0.72077000E+01, 0.10839800E+02, -.24107000E+01, 0.10631100E+02, -.62927400E+01, 0.66015700E+00, -.90800600E+01, -.71172000E+00, -.32435500E+02, 0.84452500E+01, -.41946000E+01, 0.16968200E+02, -.13746400E+01, 0.38920300E+00, -.15175600E+01, 0.27837600E+01, 0.38307300E+02, -.50930300E+02, 0.67422900E+02, 0.12658700E+03, 0.21438600E+01, -.72635800E+01, -.13990500E+02, 0.24299300E+01, -.44029600E+01, 0.16948000E+02, 0.26603700E+02, -.57127900E+01 },
            { -.72679300E+00, -.55521400E+00, -.33088600E+00, 0.84292500E+00, 0.16611500E+01, 0.20771100E+00, 0.26760200E+00, -.23871400E-01, -.51189300E+00, 0.46036300E+00, -.37144200E+00, 0.52323900E+00, 0.86626300E+00, -.23583200E+00, 0.36651500E+00, -.39703200E+00, 0.83547500E+00, -.27270200E+00, 0.36875000E+00, -.63894100E+00, 0.25056700E+00, -.11563400E+01, -.34181100E+00, -.26251200E+01, 0.18734900E+00, 0.19527600E+00, 0.24397900E+00, -.64579300E-01, 0.21780300E+00, 0.50945600E+00, 0.58844300E+00, -.22692800E+00, 0.31379700E+00, -.68600300E+00, -.16398700E+00, -.11710500E+01, -.27351200E+00, 0.10391400E+00, 0.15525100E+00, -.45079100E+00, 0.10811000E+00, 0.25656400E+00, -.11520100E+00, -.69187000E-01, 0.22650600E+00, 0.53809400E+00, 0.11050900E+00, 0.19541200E+01, -.16276100E+01, 0.22302300E+00, -.34435500E+00, -.64370800E-01, -.34941300E+00, 0.29893100E+00, -.28862700E-01, 0.44168000E+00, -.31015000E+01, 0.62690200E-01, 0.44640800E+00, -.27024000E+00, -.21890700E+00, 0.21787400E+00, -.17921200E+00, 0.12493500E+00, -.29315000E+00, 0.48388400E+00, -.39960900E+00, -.67832900E-01, 0.97779800E-01, -.41954500E+01, 0.56640800E+00, -.55928600E+00, -.22659200E+00, -.12683800E-01, -.35079600E-01, -.30730000E+00, -.34176200E+00, -.36962000E-01, 0.39804600E+00, 0.54851000E+00, 0.58578600E+00, 0.16596900E+00, 0.35810300E+00, 0.16436300E+00, 0.13819300E+00, -.84612600E-01, -.21181500E+01, 0.32441000E+00, -.25601200E+01, -.25354800E+00, -.15272100E+00, 0.76749100E-01, 0.37103400E-01, -.29342800E+00, -.10076500E+01, 0.98487800E+00, 0.75399200E+00, 0.19351000E+01, -.43884700E+00, -.52479300E+00, 0.17091300E+00, 0.20936100E+00, 0.48395300E+00, -.29913800E+01, 0.92844700E+00, 0.13355500E+01, 0.13746400E+01, -.18930600E+01, -.32987000E+01, -.46565500E+00, -.15265900E+00, 0.26326500E+01, -.22478600E+00, 0.19219300E+00, -.76886700E+00, 0.31240800E+00, -.12117300E+01, -.24399800E+00, 0.69175200E+01, -.24241200E+02, -.73762300E+02, -.45420000E+02, 0.32896000E+02, 0.10744300E+03, 0.61007200E+02, -.29844200E+02, -.49879600E+03, 0.22739700E+03, 0.25695900E+03, 0.12980500E+03, 0.12579800E+02, 0.25372200E+03, 0.26493900E+03, 0.32853900E+03, -.83177700E+02, 0.57777700E+03, -.23756600E+03, -.26107500E+03, 0.81136900E+01, 0.14851300E+03, -.24640900E+03, -.63057500E+02, -.25445900E+03, 0.65854700E+02, -.22667200E+03, 0.10724100E+03, 0.12992900E+03, 0.75756100E+02, 0.16416900E+02, 0.10147400E+03, 0.44859300E+02, 0.14995400E+03, -.19018900E+02, -.11211900E+03, 0.53607300E+02, 0.11780500E+03, -.28071900E+02, -.19366700E+02, 0.72473600E+02, 0.72363000E+02, 0.77069200E+02, 0.54097200E+01, 0.15239200E+03, -.75326900E+02, -.57853800E+02, 0.17732400E+02, 0.80077300E-01, -.54034600E+02, -.26756700E+02, -.13363200E+02, -.33407400E+02, -.11891700E+03, 0.61672600E+02, 0.53457400E+02, -.55581600E+02, -.12829100E+02, 0.38975000E+02, 0.73101300E+01, 0.20494400E+02, 0.29986800E+02, 0.15950100E+03, -.81318300E+02, -.62295300E+02, -.97334200E+02, -.37526600E+02, 0.86734000E+01, 0.50050300E+02, -.77007100E+02, -.24332000E+02, -.50925800E+02, 0.29934700E+02, -.58231700E+02, -.61267100E+02, 0.22039000E+02, 0.89337600E+02, 0.12236800E+03, 0.38482900E+02, -.88119100E+02, 0.12168500E+03, -.55976300E+02, -.83996200E+02, 0.59556000E+02, 0.13348500E+02, -.54890500E+02, -.23995600E+02, -.72988600E+02, -.34311300E+02, 0.56843300E+02, -.28226500E+02, -.29835700E+02, -.73524300E+01, -.27576400E+02, 0.12753400E+02, 0.54862600E+02, 0.15471400E+02, 0.35803900E+01, 0.32255800E+02, -.16225500E+02, 0.19390400E+02, 0.14275600E+03, -.12255300E+02, -.36213100E+02, -.64379600E+02, -.28313400E+02, 0.10343200E+03, -.37606500E+01, 0.53702000E+02, 0.27164200E+01, 0.81267500E+00, -.58652500E+01, -.27481000E+01, -.68116600E+02, 0.55876200E+02, -.10502900E+01, -.44766800E+02, -.21403000E+01, 0.60804100E+00, -.19481400E+01, 0.31104600E+02, -.48369100E+02, 0.20152300E+03, -.50021400E+01, -.22782000E+03, -.45605600E+02, -.41043500E+01, 0.34748200E+01, -.11501200E+02, 0.41914400E+02, -.36468000E+02, 0.53889700E+02, 0.68759100E+02 },
            { -.17943700E+01, 0.82335700E-01, 0.13002700E+01, -.31504900E-01, 0.72481400E+00, 0.27730500E+00, 0.10472200E+01, -.17905500E+00, -.85909100E+00, 0.48575300E+00, 0.47194100E+00, 0.25193900E+01, -.29460000E+00, -.39026700E+00, 0.48187800E+00, -.48442100E+00, 0.53800100E+00, 0.16851300E+00, -.22033800E+01, -.46673800E+00, 0.23792100E+01, 0.29800300E+00, 0.79595900E+00, -.25970100E+01, 0.53047900E+00, 0.71858900E+00, -.16811500E+00, -.11888300E+00, -.41161600E+00, 0.13113500E+00, 0.68771400E+00, 0.61041600E-01, 0.47248500E+00, -.10611700E+01, -.77474700E+00, -.14032500E+01, -.21369100E+00, 0.85618900E-01, 0.12467400E+00, 0.11639700E+01, 0.14925100E+01, 0.70868200E-01, -.42724500E+00, -.78387900E+00, 0.29967900E+00, -.71075700E-03, 0.47673900E-01, 0.40653200E+01, -.29752100E+01, -.16305800E+00, -.20760900E+01, 0.38367000E+00, 0.14048500E+01, -.38389100E+00, -.12479100E+01, 0.17586600E+01, 0.77221900E+00, 0.47734200E+00, -.49430500E+00, 0.61147000E+00, -.48325500E+00, 0.33658300E+00, -.32474500E+00, -.91954500E+00, -.71760500E+00, 0.14285000E+01, 0.20119200E+01, 0.12892300E+01, 0.52516700E+00, -.38390300E+01, 0.45622400E+00, 0.11117000E+01, 0.21706900E+00, -.60061100E+00, -.32885200E+00, -.12500100E+01, 0.15355400E+00, 0.55735000E+00, -.14141100E+01, -.51956400E+00, 0.15935000E+01, -.27646400E+00, 0.34228100E+00, 0.20464500E+00, -.32778100E+00, 0.34278200E+00, 0.58756400E+00, 0.66488400E+00, 0.19532100E+01, 0.92096300E-02, 0.18604200E-01, -.76887400E-01, -.17332000E+00, 0.64819800E+00, -.29645700E+00, 0.57453100E+00, 0.38751300E-01, 0.13044600E+01, -.37811700E-01, -.24842800E+00, -.11604100E+00, -.17045100E+00, 0.88596600E+00, -.38680500E+01, 0.10451700E+01, 0.16433800E+01, 0.29461700E+01, -.21680300E+01, -.10194700E+02, -.25537600E+00, 0.18499700E+00, -.16995800E+02, -.20462100E+01, 0.68539400E+01, 0.55602200E+01, 0.37447700E-01, -.60102500E+01, 0.59538500E+00, -.34199700E+00, -.63526000E+02, 0.41446200E+01, -.11386800E+03, 0.33975000E+02, 0.10642300E+03, 0.13935100E+03, -.71403700E+02, -.34404200E+03, 0.17691700E+03, 0.18943300E+03, 0.80027600E+02, 0.83297000E+02, 0.19102300E+03, 0.23614100E+03, 0.28213600E+03, -.15071800E+03, 0.73062800E+03, -.32617200E+03, -.17086700E+03, -.22327000E+03, -.13655500E+03, -.17409600E+03, 0.20659700E+03, -.76441500E+01, -.15380900E+03, -.35114700E+03, 0.19672200E+03, 0.21579500E+03, 0.74319100E+02, 0.12333200E+03, 0.97724400E+02, -.55808900E+02, 0.21771200E+02, 0.35860900E+01, -.20676600E+03, 0.97877400E+02, 0.25434100E+03, -.22904800E+02, 0.17363600E+02, 0.54009700E+02, 0.26597800E+01, 0.46689300E+02, 0.54510900E+02, 0.46413200E+02, -.19496600E+02, -.23977300E+02, -.32075600E+02, 0.35069700E+01, -.49737300E+01, 0.63185800E+02, -.25860400E+02, 0.19591600E+01, -.53415300E+02, 0.27963600E+02, 0.20605900E+02, -.34508000E+02, -.28661100E+02, 0.29881400E+02, 0.48194700E+02, -.84403600E+02, 0.15060200E+02, 0.15169500E+03, -.82372800E+02, -.12387700E+02, -.72124800E+02, -.21470000E+02, -.51492200E+02, -.45690000E+02, -.10665800E+03, 0.42539500E+01, 0.24986900E+03, -.11711500E+03, -.33912500E+03, -.29177000E+02, -.38584200E+02, 0.45989200E+02, 0.15635000E+03, -.55690300E+02, -.13793300E+03, 0.22937400E+03, -.10542500E+03, -.17717600E+03, 0.18435800E+02, -.68498900E+02, -.48422200E+01, 0.12479400E+03, -.16473300E+02, -.12299000E+03, 0.81717900E+02, -.40096200E+02, -.40753200E+02, -.33542900E+02, -.47223700E+01, -.63086500E+01, 0.36994800E+02, -.53973000E+02, 0.25645900E+02, -.41034300E+02, 0.21366600E+02, 0.13916500E+03, 0.52603200E+02, -.82219500E+01, -.80198500E+01, -.93311600E+01, 0.56198100E+02, 0.68310000E+02, -.97953500E+01, 0.13991100E+01, 0.25200000E+02, -.16902100E+01, -.28079900E+02, 0.19981500E+01, -.35762100E+02, -.67668400E+01, -.50934600E+00, 0.24351400E+02, -.23662200E+01, -.83524600E-01, -.29399600E+01, 0.24564600E+02, 0.39603000E+02, 0.11266700E+03, 0.50680000E+03, -.16114800E+02, 0.69767300E+02, 0.16955500E+02, -.16782900E+02, 0.43255600E+02, 0.90411500E+02, 0.27433700E+02, -.14736000E+02, 0.43447200E+02 },
            { -.20647900E+01, -.36419200E-01, 0.85054700E+00, -.13421800E+00, 0.13367500E+01, 0.37652600E+00, 0.37533200E+00, 0.43420400E+00, -.69789300E+00, 0.34044400E+00, -.40600500E+00, -.33118700E+00, -.27592300E+00, 0.22581400E+00, -.69021400E+00, 0.38248300E-01, 0.69764400E+00, 0.28846200E+00, -.22173200E+00, -.13455800E+00, -.21126500E+00, 0.72877000E+00, 0.17676500E+00, 0.77609800E+00, 0.16218800E+00, 0.47243800E+00, 0.28194000E+00, 0.21625600E+00, 0.83851100E-01, 0.19564000E+00, 0.49046300E+00, 0.22817000E+00, 0.52265700E+00, -.13004400E+01, -.65284200E+00, -.21554300E+01, 0.67658700E+00, -.26175800E+00, -.39853400E+00, 0.20565600E+01, 0.58957300E+01, -.16970000E+01, -.21147200E+01, -.27073400E+01, 0.18948000E+01, 0.10151500E+01, -.64177900E+00, 0.25467900E+01, -.35349200E+01, 0.89713400E+00, -.21598100E+00, -.96637900E+00, -.10424100E+00, 0.79371300E+00, -.62676700E+00, 0.88870800E+00, -.32759600E+00, 0.41979700E+00, 0.11956900E+00, -.62680500E+00, -.39025200E+00, 0.10691200E+00, 0.24487500E+00, -.65684500E+00, -.54372700E-01, 0.55533300E+00, 0.56595000E+00, 0.15645700E+01, -.81382700E-01, -.34399500E+01, -.35180600E+00, 0.41195200E+00, 0.34442100E+00, -.85376700E-01, 0.17487400E+00, 0.70364600E+00, 0.14036300E+00, 0.14473700E+00, 0.89368700E+00, 0.29519900E+00, -.51299000E+00, -.15395000E+00, -.36670200E-01, 0.17522600E+00, 0.18777600E-01, -.14285000E-01, 0.39029200E+01, 0.14422900E+01, 0.59267900E+01, 0.30460800E+00, -.15848900E+00, 0.15586000E+00, 0.22819600E+00, 0.73547800E-01, -.26857100E+00, 0.55491300E+00, 0.62745300E+00, 0.18069800E+00, 0.10327500E+00, -.20779500E+00, 0.30251700E+00, 0.41365100E+00, -.67302500E-01, -.45494300E+00, 0.32587500E+00, 0.47343600E+00, 0.43930600E+00, -.12386100E+01, 0.10899700E+01, -.21437400E+00, -.70439000E+00, -.37650100E+01, -.20021800E+01, -.36728400E+01, -.78167900E+00, 0.49362800E+00, 0.12054200E+01, 0.51948500E+00, 0.68331800E-02, -.15371400E+00, -.17716800E+03, -.84466200E+02, 0.69624400E+02, 0.16911600E+03, 0.14009800E+03, -.73174500E+02, -.59725400E+03, 0.30175700E+03, 0.30054800E+03, 0.13162600E+03, 0.99641500E+02, 0.37271200E+03, 0.53330500E+03, 0.51707000E+03, -.19494300E+03, 0.99310900E+03, -.47056500E+03, -.44906700E+03, -.95771000E+02, -.53830500E+02, -.25808600E+03, 0.71700200E+02, -.13016200E+03, -.10574800E+03, -.40789600E+03, 0.22028200E+03, 0.20665800E+03, 0.15454100E+03, 0.33492900E+02, 0.18565700E+03, 0.12179200E+03, 0.24912300E+03, -.72688500E+02, -.21725800E+03, 0.10530800E+03, 0.12966200E+03, 0.22468400E+02, 0.16966200E+02, 0.91453300E+02, 0.51521500E+02, 0.48838200E+02, 0.44053800E+02, 0.17211700E+03, -.83701900E+02, -.90121900E+02, 0.40088400E+02, -.14033200E+01, -.70563100E+02, -.27643100E+02, -.36208100E+02, -.23560600E+02, -.40397400E+03, 0.20290200E+03, 0.20039000E+03, -.16509200E+03, -.56694200E+02, 0.15614500E+03, 0.70058400E+02, 0.12216900E+03, -.22601800E+01, -.42953900E+02, 0.19565800E+02, 0.27942200E+02, -.93786100E+02, -.30584800E+02, 0.90945600E+02, 0.18141800E+03, 0.23622400E+02, 0.13888600E+02, 0.22746300E+02, -.99288800E+01, -.29983700E+02, -.48673900E+01, 0.69300500E+02, -.68350700E+00, 0.24386700E+02, -.35788100E+02, 0.29206100E+02, 0.19239800E+03, -.95533700E+02, -.96025300E+02, 0.82549400E+02, 0.57026300E+02, -.79847200E+02, -.18422500E+03, -.13148700E+03, 0.62368800E+01, -.14132500E+03, 0.72104000E+02, 0.69642000E+02, 0.17485900E+02, 0.82576100E+00, 0.89002900E+02, 0.12465100E+03, 0.99041100E+02, 0.38393600E+02, -.17855700E+03, 0.90622400E+02, 0.10673300E+03, 0.12869700E+03, -.13536300E+02, 0.58418500E+02, -.18005200E+01, 0.12664600E+03, 0.86135500E+02, -.17403500E+01, 0.36024600E+02, 0.14639300E+02, -.10294500E+01, -.29336600E+02, -.93784900E+00, -.67300600E+02, 0.35315400E+02, -.23637200E+01, -.62228400E+02, -.11896200E+01, -.40872800E+00, -.94849300E+00, 0.35950600E+02, -.99041700E+02, 0.31459300E+03, -.15637300E+03, -.45451200E+03, -.81553400E+02, -.97038600E+01, 0.34655500E+02, -.48672300E+02, -.23567600E+01, -.12838100E+03, 0.80358900E+02, 0.64766700E+02 },
            { -.60809800E+00, -.73189100E-01, 0.86014300E-01, 0.80223800E+00, 0.79011800E+00, -.19870500E+00, 0.16361400E+00, -.44970000E+00, -.66540300E+00, 0.32695900E+00, 0.28879200E+00, 0.10441900E+01, -.46600800E+00, 0.23410100E+00, -.76647400E+00, -.28077700E-01, 0.10571900E+00, -.95413200E+00, 0.66739100E+00, 0.24551100E-01, 0.44238500E+00, -.16078300E+00, 0.11204600E-01, 0.11130800E+01, -.36679300E+00, -.26073900E+00, -.49375300E+00, -.55536800E-01, 0.15413500E-01, -.11753900E+00, -.94380500E+00, 0.35481900E+00, 0.13599900E+00, -.88684600E-01, 0.50857200E-02, -.51044500E+00, 0.38250200E+00, -.14811300E+00, -.23352000E+00, 0.12444100E+01, 0.24940300E+01, -.86088800E+00, -.11247200E+01, -.10472100E+01, 0.82936300E+00, -.12029400E+00, -.34597500E+00, 0.16165000E+01, -.11447900E+01, 0.52703400E+00, 0.11275600E+01, -.26383200E+00, 0.56387000E+00, -.21140500E+00, -.39506700E+00, -.16340700E+00, 0.25495000E+01, -.47374400E-01, -.22533100E+00, 0.43829900E+00, 0.36673600E+00, -.58011500E+00, -.39658500E+00, -.53400600E+00, 0.91011700E-01, -.18908400E+00, -.10769800E+01, 0.63789000E+00, 0.22132100E+00, -.48543500E+01, -.35424000E+00, 0.17147200E+00, 0.34483000E+00, -.10869500E+00, 0.99004100E-01, 0.58344900E+00, 0.25198500E+00, 0.10216400E+00, -.75212300E-01, -.91243900E-01, -.28890600E+00, -.20049100E+00, 0.64404300E+00, 0.35186200E+00, -.17297200E+00, -.87279800E-02, -.57905300E+00, 0.70303400E+00, 0.79090900E+00, 0.44754400E-01, 0.23550400E+00, -.82373000E-01, -.77561800E-01, -.10299700E+01, -.75457100E+00, -.54578800E+00, -.89389100E+00, 0.24889100E+00, -.40468300E+00, 0.48499400E-01, 0.23997400E-01, 0.14181900E+00, 0.11743400E+01, 0.11116800E+01, -.34994200E+00, -.72645200E+00, 0.43927000E+00, -.69492100E+00, -.29901100E+01, -.33466700E+00, -.30881800E+00, -.65805500E+01, -.10441800E+01, 0.39261700E+00, 0.64832400E+00, 0.50051000E-01, -.20161800E+01, 0.62594200E+00, -.97164400E-01, 0.26950400E+00, 0.11819800E+00, -.48296900E+02, 0.18835600E+02, 0.13507600E+01, 0.50418700E+02, -.30511400E+02, 0.30167700E+03, -.15052200E+03, -.15254500E+03, 0.66411500E+02, 0.30940300E+02, -.12920500E+03, -.55081500E+02, -.12849700E+03, 0.30584900E+02, -.31280900E+03, 0.15341300E+03, 0.12054500E+03, 0.39396500E+02, 0.96187200E+02, 0.44830600E+02, -.13544400E+03, -.30350900E+02, 0.11503500E+03, 0.12247200E+03, -.63122200E+02, -.63593700E+02, 0.20096500E+01, 0.16756200E+01, -.73377100E+02, -.69137200E+02, -.63610000E+02, 0.21745500E+02, 0.56079600E+02, -.27789900E+02, -.41753300E+02, -.11575100E+02, -.20357000E+02, -.48911500E+01, 0.20395100E+02, 0.10680300E+02, -.12720800E+02, -.18687000E+02, 0.94137600E+01, 0.11840200E+02, -.50562800E+01, 0.51957800E+01, 0.60666400E+01, -.12367200E+02, 0.71267000E+01, 0.12313800E+02, 0.12403800E+02, -.61920500E+01, -.35844400E+01, 0.73664500E+01, -.23113800E+02, 0.97820600E+01, -.22309600E+02, 0.31701100E+01, -.32716200E+02, -.58427000E+02, 0.29230600E+02, 0.24103700E+02, 0.17681700E+01, 0.32379600E+01, 0.30611100E+02, 0.15083900E+01, 0.18831000E+02, -.13003800E+02, 0.61233200E+02, -.30832300E+02, -.18134700E+02, 0.28653500E+02, -.24224300E+01, -.52280700E+02, -.35738300E+02, -.28544400E+02, 0.21557500E+00, 0.24633800E+02, -.12360900E+02, -.13917200E+02, 0.25019700E+02, 0.16083600E+02, -.32479000E+02, 0.21317900E+01, -.25843900E+02, 0.26914600E+02, 0.20358600E+01, -.95071900E+00, -.29008300E+00, 0.15419000E+02, 0.10795900E+02, -.58784200E+01, -.89346500E+01, -.39504500E+01, 0.24746900E+01, -.13781900E+03, 0.68875300E+02, 0.52488900E+02, -.42788200E+02, 0.78006700E+01, 0.86741400E+02, 0.11831900E+03, 0.82471200E+02, -.12385500E+02, -.46129500E+00, -.25037000E+01, -.73683000E+01, -.25739000E+00, -.77636700E+01, 0.10880600E+00, 0.86445700E+01, -.18092900E+01, 0.29037300E+01, -.85855800E+01, -.42754200E+00, -.17809900E+00, -.29234700E+00, -.11384600E+02, 0.87205900E+01, 0.31833300E+02, 0.15246200E+03, 0.65648400E+02, -.55974800E+01, -.43267600E+01, 0.14002500E+02, -.25647600E+02, -.21444900E-01, 0.10417600E+02, -.43504800E+01, 0.34111900E+01 },
            { -.18366100E+01, -.47844800E+00, 0.50756300E+00, 0.58741300E+00, 0.12802300E+01, 0.15109500E+00, 0.74382800E+00, -.81573700E-01, -.59642000E+00, 0.90874400E+00, 0.21522500E+01, 0.27026300E+01, -.38254100E+00, -.33307500E+00, 0.82444300E+00, -.50578200E+00, 0.65875600E+00, 0.15451800E+00, -.20417800E+01, 0.79216000E+00, 0.13281000E+01, 0.23916700E+01, 0.59607700E+00, 0.12532200E+01, 0.32651300E+00, 0.48678400E+00, -.25981500E+00, 0.82469800E-01, -.76451400E+00, -.74490500E+00, -.55966400E-01, 0.61994800E+00, 0.60146800E+00, 0.50432000E+00, -.74669600E+00, 0.22071400E+01, -.12419800E+00, 0.40805700E-01, 0.11585600E+00, 0.15897200E+01, -.19033700E+01, 0.95900900E-01, 0.16081600E+00, 0.28013600E+00, -.92234500E+00, -.92280400E+00, 0.47052300E+00, 0.96708700E-01, -.13396600E+01, -.16988300E+01, 0.17005400E+01, -.18032100E+01, 0.27940200E+00, 0.82758200E-01, -.11708900E+01, -.68726600E+00, 0.39517000E+01, 0.52302100E+00, 0.56831800E+00, -.62127300E+00, -.10337200E+00, -.64260400E+00, 0.12366400E+01, -.50167100E+00, -.53998200E-01, 0.62282500E+00, 0.30330700E+01, -.75678200E+00, 0.69661300E+00, -.69117300E+01, 0.95413600E+00, 0.27870000E+00, 0.18452300E+00, -.80055200E+00, -.14327500E+00, -.15692800E+01, 0.38335500E+00, 0.50123100E+00, -.12371500E+01, -.34773900E+00, 0.20721500E+01, -.19788000E+00, 0.78419500E+00, -.35235000E-01, -.31550800E+00, 0.93343900E-01, -.25259900E+00, 0.66567500E+00, 0.51751600E+00, 0.41767400E-01, 0.16465600E+00, -.86432000E-01, -.19802600E+00, 0.71910800E+00, 0.28142500E+00, -.44470100E+00, -.95890100E+00, -.41198700E+00, -.24433300E-01, 0.18273800E+00, -.12221100E+00, -.33024000E+00, 0.28400400E+00, -.25668000E+01, 0.13435000E-01, 0.45047800E+00, 0.11221200E+01, 0.53124100E+00, -.25557200E+01, 0.48130000E+00, 0.20138700E+00, -.44062300E+01, 0.15903400E+00, 0.13993800E+01, -.11947800E+01, -.76980400E+00, 0.30592500E+01, -.87979000E+00, 0.31172200E+00, -.37794500E+00, -.74095300E+00, -.25495400E+00, -.35455400E+02, -.20947700E+02, -.48002200E+02, -.23388700E+02, -.47393800E+03, 0.24316700E+03, 0.24162700E+03, -.21076500E+03, 0.26276100E+02, 0.25427500E+03, 0.23659300E+03, 0.23616000E+03, -.84515200E+02, 0.30908500E+03, -.12219900E+03, -.43753200E+02, -.14664600E+03, -.29581700E+03, 0.52130300E+02, 0.43813600E+03, 0.27607200E+03, -.28356200E+03, -.37761200E+03, 0.20690400E+03, 0.19467800E+03, -.13641300E+03, -.61601100E+01, 0.21537500E+03, 0.20089300E+03, 0.17241100E+03, -.54262600E+02, -.11672100E+03, 0.56364500E+02, 0.10366700E+03, 0.53763700E+02, 0.61677700E+02, -.19554000E+02, -.10568400E+03, -.69233900E+02, 0.31613100E+02, -.19145700E+02, 0.11579200E+02, -.55830400E+00, -.42359100E+01, -.13695800E+02, 0.14717400E+02, 0.58208400E+02, -.41158400E+02, 0.49607800E+02, 0.74449600E+02, -.36620000E+02, -.43368400E+02, -.31261200E+01, 0.32997500E+02, -.44337600E+02, 0.34397400E+02, -.13473200E+03, 0.53217300E+02, 0.38657800E+02, -.23347300E+02, -.27248400E+01, -.19053400E+02, -.28783100E+02, -.35009800E+02, 0.61989800E+01, 0.45379900E+02, -.58878400E+02, 0.87907300E+02, -.40069700E+02, -.87048900E+02, -.70278500E+02, -.11802300E+01, 0.46616700E+02, 0.74729400E+02, -.19434100E+01, -.72299900E+02, 0.14129300E+03, -.63978800E+02, -.66275600E+02, -.17002200E+02, 0.21123900E+02, -.26681200E+01, 0.23550100E+02, -.96153400E+02, -.20956600E+02, 0.10760500E+03, -.53953200E+02, -.55499900E+02, -.34621400E+02, 0.29646500E+02, -.31705000E+02, 0.20404800E+02, -.61116000E+02, -.14881400E+02, 0.67212800E+02, -.33288900E+02, 0.16335800E+02, 0.68913300E+02, -.35970700E+01, -.70110200E+02, -.84008300E+02, -.93350300E+02, 0.57983500E+02, -.45069900E+01, -.16266500E+01, 0.13709700E+02, -.14583200E+01, 0.45021200E+01, 0.65745500E+01, -.13142600E+02, -.62419700E+01, -.65898200E+01, 0.83341100E+02, -.15557600E+01, -.16156600E+00, -.20469700E+01, 0.13525200E+02, -.22655800E+02, -.15490800E+03, -.10545400E+02, 0.79965400E+02, 0.83142000E+02, 0.18017200E+01, -.49390200E+02, -.28181000E+02, 0.33238500E+02, -.27656800E+02, 0.14310700E+02, 0.19824400E+02 },
            { -.40839100E+00, -.30031900E+00, 0.96032000E-01, 0.41373300E+00, 0.39662100E+00, 0.19194900E+00, 0.24963500E+00, 0.52807900E-01, -.39641300E+00, 0.18505000E+00, 0.84664000E-01, -.87825300E-01, -.66956000E-01, 0.46932200E-01, 0.75434200E-01, -.75201500E-01, 0.57006000E-01, -.20568600E+00, -.65184900E+00, 0.21759500E-01, 0.94288600E+00, -.52648200E+00, -.42712000E+00, -.17803200E+00, 0.13770300E+00, -.81599000E-01, -.19892800E+00, 0.18781800E+00, -.16206200E+00, 0.56295700E-03, 0.30931800E+00, 0.40048600E+00, -.19433300E+00, 0.28499500E+00, 0.14656600E+00, 0.36638800E+00, 0.11135200E+00, -.48061800E-01, -.53313900E-01, 0.18823100E-01, -.18813800E-02, -.17242500E+00, -.82680300E-01, -.13920400E+00, -.76220000E-01, -.18797100E+00, 0.30634600E+00, -.52471500E+00, -.75877500E-01, -.19093200E+00, 0.31325900E+00, 0.38734600E-01, -.36981600E+00, 0.12046500E+00, 0.19627700E+00, -.43368700E+00, -.76915600E+00, -.11912200E-01, -.78561900E-01, -.83247500E-01, -.32803100E-01, -.16118300E+00, 0.22893900E+00, 0.38231600E+00, -.34558500E-02, -.50461200E-01, 0.15272800E+00, -.38788300E-01, 0.64071700E-02, -.11299200E+00, 0.58555600E-01, 0.21941100E+00, 0.83026200E-01, -.72588200E-01, 0.43454300E-02, -.16546800E+00, 0.94961300E-01, -.20104200E-01, -.24328500E+00, 0.24478900E-01, -.15037500E+00, -.18484100E+00, 0.34567900E+00, 0.72342100E-01, -.17014200E+00, 0.90889500E-01, -.41643100E+00, 0.32992000E+00, -.54425700E+00, -.30723000E-01, -.19495000E-01, -.25923000E-01, 0.48822700E-01, -.29524100E+00, -.19346300E+00, 0.82125400E-01, 0.23696700E+00, 0.64925000E-01, -.11611000E+00, 0.15297600E-02, -.73959200E-01, 0.77164700E-01, 0.26170600E+00, 0.50102900E+00, -.39408700E-01, 0.90856000E-01, -.26768100E+00, 0.17636200E+00, -.10097800E+01, -.12242000E-01, -.16855000E+00, -.34387100E+01, -.43737800E+00, -.93128000E-01, 0.28632200E+00, 0.70113100E-01, -.16755300E+01, 0.43122600E+00, -.86172700E-02, 0.18735000E+00, -.78860400E-01, 0.31305700E+00, -.14584100E+00, 0.26448000E+02, 0.23997100E+02, -.14522800E+02, -.30450100E+03, 0.15224600E+03, 0.15261700E+03, -.60888500E+02, 0.26685500E+02, 0.15682900E+03, 0.16020200E+03, 0.18169000E+03, -.50303300E+02, 0.44458600E+02, -.15808200E+02, -.68875400E+01, -.27328200E+02, -.10038200E+03, 0.51686900E+02, 0.12818400E+03, 0.98219900E+02, -.77329000E+02, -.27081100E+03, 0.13943000E+03, 0.13683400E+03, 0.32048000E+00, 0.96570700E+00, 0.11988400E+03, 0.76651300E+02, 0.10512500E+03, -.22163200E+02, -.95455200E+02, 0.47014800E+02, 0.40067600E+02, 0.15068300E+02, 0.11600000E+02, 0.23088300E+02, 0.26844700E+01, 0.84770000E+01, 0.19771700E+02, 0.28873300E+02, -.13839900E+02, -.23126100E+02, 0.64443400E+01, 0.31126800E+01, -.14920600E+02, -.94781000E+01, -.10451900E+02, 0.13465300E+02, -.52523200E+02, 0.26832700E+02, 0.25291900E+02, -.23854000E+02, -.54608100E+01, 0.16306400E+02, 0.19838800E+02, 0.43202400E+01, -.52266600E+01, 0.96344900E+00, -.49318600E+00, 0.19305600E+01, -.22073800E+02, -.64467200E+00, 0.14957800E+02, 0.42835300E+02, 0.11749200E+02, -.99998100E+01, 0.16070800E+02, -.88740500E+01, 0.28505500E+01, 0.82062600E+01, 0.38072300E+01, -.47754600E+01, 0.93986300E+01, -.41575200E+01, 0.58645400E+01, 0.34185800E+02, -.18562400E+02, -.14862500E+02, 0.94396600E+01, -.96029200E+01, 0.18674100E+01, -.24569400E+02, 0.14938400E+02, -.69790100E+01, -.81712700E+02, 0.40861200E+02, 0.41383000E+02, 0.71327800E+00, 0.69913700E+01, 0.37562000E+02, 0.28623500E+02, 0.35529600E+02, 0.85698400E+01, -.43483900E+02, 0.22020000E+02, 0.28772300E+02, 0.11009500E+02, -.21875900E+01, 0.20058100E+02, 0.66558400E+01, 0.28680200E+02, 0.56517000E+01, 0.29125900E+00, 0.70225600E+01, 0.31335800E+01, -.53354600E+00, -.59382800E+01, 0.82794200E-01, -.20481200E+02, 0.51353900E+01, 0.75505100E+00, -.66703500E+01, 0.41109200E+00, -.27946400E+00, 0.47004500E+00, 0.77087700E+00, 0.13629900E+02, 0.25141900E+01, -.92464200E+02, -.71268900E+02, -.74104600E+01, -.52435600E+01, 0.10253100E+01, -.20037300E+02, -.36612800E+01, -.10654400E+02, 0.30391800E+02, 0.12420400E+02 },
            { 0.75993000E+00, 0.25717300E-01, -.37586700E+00, -.54493700E+00, -.12351200E+01, -.19028900E+00, -.29839200E+00, 0.75863300E-01, 0.63638000E+00, -.18402200E+00, 0.14220500E+00, 0.47628500E+00, -.21304300E+00, 0.99029800E-01, -.13047800E-01, 0.13261300E+00, -.58630400E+00, 0.28344200E+00, -.22892500E+00, -.88690600E-02, -.39417400E+00, 0.86076800E+00, -.67785200E+00, -.10622200E+01, 0.12890400E+00, 0.11204500E+00, 0.46462900E+00, 0.23038300E-01, 0.78127300E-02, 0.31110700E+00, 0.31547800E+00, -.25599300E+00, 0.79950800E-01, -.15376600E+00, -.58575000E-01, 0.43849300E+00, -.32488700E-01, 0.15306400E-01, 0.12288400E-01, -.23067100E+00, 0.11826400E+01, 0.11642500E+00, 0.23701500E+00, -.38176900E+00, 0.88852300E-01, 0.33768500E+00, 0.18998200E+00, -.44576200E-01, 0.69552800E-01, 0.76814100E-01, -.44848700E+00, 0.29618800E+00, 0.44252900E+00, -.78146900E-01, -.15487800E-01, 0.72627000E+00, -.17402400E+01, -.33937300E-01, 0.26778400E+00, 0.20595900E+00, -.15987900E+00, 0.33957000E+00, -.13745500E+00, 0.13116400E+00, -.45554200E+00, 0.49335900E+00, 0.60438100E+00, -.20405800E+00, -.26396600E+00, 0.45838000E+01, 0.39160600E+00, -.13758500E-01, -.40140800E+00, 0.12359300E+00, -.10912000E+00, -.22131300E+00, -.29396800E+00, 0.65823200E-02, 0.14830100E+00, 0.28855000E+00, -.12475600E+00, 0.87640200E-03, 0.12593000E+00, -.23758500E+00, -.40309800E-01, -.86279200E-01, -.52076800E+00, -.10476200E+01, -.24585900E+01, -.74407400E-01, -.74826800E-01, -.33902100E-01, -.61946800E-01, 0.94705100E+00, 0.81042300E+00, -.73433800E-01, 0.23059500E+00, -.11289400E+01, 0.52470400E+00, 0.15398200E+00, -.19543100E+00, -.28460800E+00, -.10728300E+01, -.35106500E+00, -.21283400E-01, 0.22620600E+00, 0.31921200E+00, -.76051700E+00, -.10832900E+01, -.11154400E-01, -.18259700E+00, -.44966000E+00, 0.41018100E+00, -.23642200E+00, 0.87753000E+00, 0.15484700E-01, 0.78003400E+00, -.40588700E+00, -.12207000E+00, 0.17713100E+00, -.96418400E-02, -.34803700E+00, -.15392400E-01, 0.62082500E+00, -.30433500E+02, 0.80024300E+01, 0.33291800E+03, -.16652300E+03, -.16666700E+03, 0.71284100E+02, -.32157400E+02, -.16298400E+03, -.18285200E+03, -.19640200E+03, 0.40849000E+02, -.14358800E+02, 0.30329400E+01, -.22245900E+02, 0.41748000E+02, 0.11549000E+03, -.68956000E+02, -.13807400E+03, -.11000600E+03, 0.92210500E+02, 0.22416400E+03, -.11403400E+03, -.11301600E+03, -.34219200E+02, -.32187300E+02, -.75805100E+02, -.14896500E+02, -.45505900E+02, 0.47688900E+01, 0.69191900E+02, -.33747000E+02, -.30384300E+02, -.26737400E+02, -.19648700E+02, -.48426400E+01, 0.16373600E+02, 0.12551300E+02, -.24665100E+02, -.70770800E+01, 0.28554400E+01, 0.14990000E+02, 0.86292600E+01, 0.13189600E+02, 0.17698200E+01, -.57133200E+01, 0.10209700E+02, -.97847300E+01, 0.65460000E+02, -.32896600E+02, -.33126000E+02, 0.28562600E+02, 0.65683600E+01, -.23129100E+02, -.13608000E+02, 0.13230500E+01, -.72874200E+01, -.36644400E+02, 0.19385800E+02, 0.14313800E+02, 0.58344500E+01, 0.34820300E+01, 0.11235400E+01, -.34259500E+02, -.11914800E+02, 0.79912200E+01, -.66678600E+02, 0.32518700E+02, 0.26806500E+02, -.43797100E+01, -.12833900E+02, 0.11107300E+02, -.20132600E+02, 0.13939000E+02, 0.16933700E+02, -.25718200E+02, 0.11715000E+02, 0.11964000E+02, 0.56060300E+01, 0.24382200E+02, -.12052700E+02, 0.24570900E+02, -.17163800E+02, 0.24398300E+02, 0.80169100E+02, -.40304600E+02, -.40591200E+02, -.31429700E+01, -.15174600E+02, -.37334600E+02, -.26701900E+02, -.32391800E+02, -.12798200E+02, 0.68777200E+02, -.34754200E+02, -.42728000E+02, -.32831700E+02, -.29910200E+01, -.96488100E+01, 0.24936600E+02, -.20918000E+02, -.25724200E+02, -.57395800E+00, 0.27091600E+01, -.99211400E+01, 0.74082900E+00, 0.99322000E+01, -.73618700E+00, 0.18943300E+00, 0.62389600E+01, 0.11818300E+01, -.10734100E+02, -.98729700E+00, 0.36329500E+00, -.94482200E+00, -.39938500E+01, -.10528300E+02, -.18575400E+01, 0.12130800E+03, 0.58489900E+02, -.78152800E+01, 0.26570800E+01, 0.11114700E+01, 0.73082300E+01, -.49361200E+01, 0.23295500E+02, -.11164900E+02, -.26593500E+01 },
            { 0.32346300E+00, 0.22643900E-01, 0.85867600E-01, -.17136100E+01, -.19181800E+01, 0.30199600E-02, -.13109800E+00, 0.89272200E+00, 0.84915800E+00, -.59314600E+00, -.14142200E+01, -.21729900E+01, 0.93088800E-01, 0.37883300E+00, 0.10937200E+01, 0.87391800E-02, -.31375900E+00, -.27770300E+00, 0.76877100E+00, -.70340600E+00, -.67355700E-01, -.11277200E+01, 0.10160700E+00, -.14704300E+01, 0.31124500E+00, 0.50548500E+00, 0.90062300E+00, 0.29811400E-01, 0.13739800E+00, -.33932800E+00, 0.83738000E+00, -.21065700E+00, -.17342200E+00, -.49688700E+00, -.30575800E+00, 0.11006500E+01, -.15560800E+00, 0.57617800E-01, 0.84370900E-01, -.48335400E+00, -.14637300E+01, 0.55818200E+00, 0.85636200E+00, 0.66453000E+00, -.49608000E+00, -.57298800E-01, 0.41754500E+00, -.87837900E+00, 0.43252900E+00, -.18524500E+00, -.71831600E+00, 0.60428700E+00, -.47864100E+00, 0.52501200E+00, -.16970500E+00, 0.95134300E+00, -.34891100E+01, 0.31750200E-01, 0.35513100E+00, -.46713800E+00, -.34360300E+00, 0.49423100E+00, -.19693800E+00, -.10493400E+00, -.44276200E+00, 0.60072000E+00, 0.74266300E+00, -.83558400E+00, -.27488600E+00, 0.15334600E+01, 0.45363200E+00, -.90235800E+00, -.14855600E+00, 0.33251000E+00, -.67929100E-01, -.70832600E+00, -.41911800E+00, -.43047400E+00, -.29047400E+00, -.12507900E+00, 0.99213200E+00, 0.48766400E+00, -.69409800E+00, -.16211700E+00, 0.15919600E+00, 0.71585000E-01, -.95931500E+00, -.67418100E+00, -.14686300E+01, -.21748400E+00, -.26113800E+00, 0.60303100E-01, 0.10697100E+00, 0.14222300E+01, 0.14435900E+00, 0.11408800E+01, 0.12447600E+01, 0.15623000E+01, 0.27037900E+00, -.46927900E+00, -.86311400E-02, 0.36660000E-01, -.53580300E+00, -.40739800E+01, 0.11064600E+01, 0.21113400E+01, 0.19889100E+01, -.20052500E+01, -.57632500E+01, -.46277800E+00, 0.58385900E+00, 0.51548200E+01, -.14650000E+00, 0.57083700E+01, 0.52985700E+00, -.40782900E-01, 0.19593900E+01, -.78276200E+00, 0.45946400E+00, -.24787100E+00, -.20530000E+00, -.10696100E+00, -.55215400E+00, 0.14878700E+01, 0.75955800E+00, 0.22726600E+02, -.30728000E+03, 0.16137100E+03, 0.15857600E+03, 0.66594400E+02, 0.26205200E+02, 0.14707100E+03, 0.12457800E+03, 0.21247700E+03, -.15508900E+03, 0.78998200E+03, -.37027800E+03, -.27874400E+03, -.13729100E+03, -.90893400E+02, -.19116600E+03, 0.23684000E+03, -.19359000E+02, -.17528700E+03, 0.85365400E+02, -.26861600E+02, -.35540400E+02, 0.11837400E+03, 0.12246300E+03, -.66977900E+02, -.11186000E+03, -.12026200E+03, -.24190000E+02, 0.12621700E+02, -.69593400E+01, 0.48272800E+02, 0.84239300E+02, 0.66048900E+02, -.52360400E+02, -.10061800E+03, -.89856000E+02, 0.35461900E+02, 0.17541400E+02, -.70187800E+01, -.16722800E+02, -.29135000E+02, -.45842700E+02, 0.12476000E+02, 0.90705200E+02, -.32046600E+02, -.19493200E+02, -.57146900E+02, 0.28722400E+02, 0.23074600E+02, 0.63641800E+01, 0.23061700E+02, -.38921500E+01, -.94272400E+01, -.84038000E+02, 0.98749500E+02, 0.26504400E+03, -.13728100E+03, -.11556500E+03, -.78369300E+01, -.73955500E+02, -.90018100E+02, -.48399500E+02, -.98927500E+02, -.14589600E+02, 0.11551200E+03, -.50266400E+02, -.10918900E+03, -.11019100E+03, 0.52317200E+02, 0.62488100E+02, 0.10583900E+03, -.11771300E+02, -.89623600E+02, 0.18893500E+03, -.83581200E+02, -.90579800E+02, -.91271000E+02, -.12681000E+02, 0.73754100E+01, 0.45867400E+02, -.12432700E+03, -.13019900E+03, 0.78588600E+02, -.38827400E+02, -.41060000E+02, -.35652800E+02, -.14178300E+02, 0.42839800E+00, 0.61076200E+02, -.48575600E+01, 0.22098000E-01, 0.14565200E+03, -.72338100E+02, -.23110000E+02, 0.18830200E+03, -.84605100E+00, -.14318400E+03, -.19332500E+03, -.13815300E+03, 0.12765500E+03, -.80216400E+01, 0.86722000E+01, 0.23018000E+02, 0.44602900E+00, -.17700800E+02, 0.12743300E+01, 0.22207600E+01, 0.71237400E+01, -.11959500E+02, 0.72708700E+02, -.27868100E+01, 0.92516300E+00, -.33851900E+01, 0.49229300E+02, -.27783800E+02, -.18570800E+01, 0.13812400E+00, -.18059300E+02, 0.43074800E+02, 0.10831900E+02, -.42600900E+02, 0.79834100E+02, 0.36427400E+02, -.50315800E+02, -.17256300E+02, 0.18562900E+02 },
            { 0.80405000E+00, 0.96236300E-01, -.15029900E+00, -.28077500E+00, -.50778300E+00, 0.22340700E-01, -.25586600E+00, 0.14550800E+00, 0.40561400E+00, 0.63498200E-02, 0.39392900E+00, -.77091000E+00, -.17193200E+00, -.37217200E+00, 0.36678400E+00, -.10783700E+00, 0.28783900E+00, 0.14839400E+00, 0.24283700E+00, 0.12486000E-01, -.12564100E-02, 0.44292000E+00, 0.42061700E+00, 0.55726800E+00, -.49601100E-01, 0.25357900E+00, 0.53534900E-01, -.16384300E+00, 0.73885500E-02, -.22346600E+00, -.39452200E-02, 0.14396600E+00, -.12575800E+00, -.16689200E-01, -.23354600E-01, -.13829500E+00, 0.23116200E+00, -.90143900E-01, -.13850200E+00, 0.12021800E+01, 0.41180500E-01, -.21708000E+00, 0.19934000E+00, -.20094700E+00, -.16261900E+00, -.38803400E+00, -.31697300E+00, -.63182400E+00, -.20344300E+00, -.28639200E+00, 0.28358400E+00, 0.16882500E-01, 0.56933500E+00, 0.12090600E+00, -.27439200E+00, 0.25328700E-01, 0.82667800E+00, 0.15498100E+00, -.43500300E-01, 0.22134300E+00, 0.57558400E+00, -.53463900E+00, 0.24095000E+00, 0.41552900E-01, -.17143400E+00, -.12543100E+00, 0.19084300E+00, -.31161200E+00, 0.88227100E-01, -.14495500E+01, 0.55059600E+00, -.12209200E+00, -.35288500E+00, -.62124900E-01, -.73201700E-01, -.37795800E+00, -.15381500E-01, 0.52357500E-01, -.30288700E+00, 0.64667800E-02, 0.14580100E+00, 0.16900100E-01, 0.11094300E+00, -.91752000E-03, 0.62397600E-02, -.83584900E-01, 0.53928400E+00, -.12155500E+00, 0.28698300E+00, 0.21779400E-01, -.43140300E-01, 0.20814800E-01, -.13334000E-01, 0.63436000E+00, 0.35776500E+00, 0.11754300E+00, 0.87717400E-01, -.24688300E+00, 0.24259400E+00, 0.29597900E-01, -.40467700E-02, -.88902000E-01, -.48404700E+00, -.16147200E+01, 0.36364800E+00, 0.53983800E+00, 0.75247100E+00, -.25954500E+00, -.48034900E+00, 0.29191300E-01, 0.22373500E-02, 0.88145100E+00, 0.21364800E+00, 0.58308200E+00, -.47177700E-01, -.17363500E+00, 0.16145400E+01, -.78320400E-01, -.18602600E+00, 0.52791200E-01, -.10504300E+00, -.56842500E+00, 0.14004500E+00, 0.17968000E+00, 0.10434000E+00, 0.47336900E+00, 0.36250500E+03, -.18462700E+03, -.18409700E+03, 0.36866700E+02, -.21398600E+02, -.17396200E+03, -.16946600E+03, -.21808000E+03, 0.10164100E+03, -.20008400E+03, 0.85098600E+02, 0.21393700E+02, 0.80834500E+02, 0.10014200E+03, -.42134800E+01, -.20153200E+03, -.10812500E+03, 0.12817400E+03, 0.76649300E+02, -.47431500E+02, -.42763300E+02, -.54890500E+02, -.68395300E+02, -.14563200E+02, 0.28940100E+02, 0.12851000E+02, 0.32435000E+02, 0.21730800E+02, -.99410800E+01, -.39049800E+02, -.55536600E+02, -.38766800E+02, 0.20518600E+02, 0.44359300E+02, 0.43543900E+02, -.19767400E+02, -.11600400E+02, 0.45848800E+01, 0.15289500E+02, 0.15844600E+02, 0.32805500E+02, -.36750500E+01, -.45478700E+02, 0.26883100E+02, -.50529400E+01, 0.51337400E+02, -.26010400E+02, -.22648400E+02, 0.21081400E+01, -.63485900E+01, -.47011600E+01, 0.10208600E+02, 0.55840500E+02, -.51235700E+02, -.16220900E+03, 0.83666100E+02, 0.69776800E+02, 0.68496300E+01, 0.52062500E+02, 0.49788800E+02, 0.16607000E+02, 0.33264100E+02, 0.36339200E+02, -.10974300E+03, 0.51445900E+02, 0.80741500E+02, 0.64519400E+02, -.24119900E+02, -.27902400E+02, -.64885800E+02, 0.89504300E+01, 0.72169800E+02, -.13449500E+03, 0.61881500E+02, 0.64564800E+02, 0.52729700E+02, 0.20869500E+02, -.11589100E+02, -.27269500E+02, 0.77716200E+02, 0.78779900E+02, 0.35217500E+02, -.17985000E+02, -.17018300E+02, 0.12045600E+02, -.36596900E+00, -.32826400E+02, -.50022200E+02, -.36567800E+02, 0.78246200E+01, -.47922100E+02, 0.23348500E+02, -.80486700E+01, -.12013300E+03, -.59148200E+01, 0.76793800E+02, 0.12366700E+03, 0.83285100E+02, -.85499500E+02, 0.46983200E+01, -.19826000E+01, -.14500500E+02, 0.74092700E-01, 0.14678600E+02, -.32187700E+00, -.46818800E+01, -.11001700E+01, 0.80143000E+01, -.39813300E+02, 0.11954300E+01, -.34241200E+00, 0.15406800E+01, -.30977100E+02, 0.20818700E+02, 0.31379000E+02, 0.76205000E+02, 0.22589400E+02, -.18173000E+02, -.23672700E-01, 0.21816900E+02, -.30978100E+02, -.26747500E+02, 0.26379100E+02, -.15603900E+02, -.55193500E+01 },
            { -.37131100E+01, 0.15373400E+01, 0.28978800E+01, -.16852000E+01, 0.61492700E+00, 0.24575800E+00, 0.20065200E+01, 0.28456000E+00, -.86226500E+00, 0.57511900E+00, 0.84873300E+00, 0.55226900E+01, 0.22082000E+01, -.19519100E+01, 0.20729000E+01, -.10820400E+01, 0.19052100E+01, 0.42386800E+00, -.26540200E+01, -.15784300E+01, -.18997300E+01, 0.34913600E+00, 0.33741600E+01, 0.37351300E+00, -.10434700E+00, 0.11649700E+01, -.40674700E+00, 0.29321100E+00, -.39895000E+00, 0.98722700E+00, 0.27505600E+01, -.15660700E+00, -.37876200E-01, -.77470400E+00, -.41473200E+00, -.13620900E+01, -.12761400E+01, 0.49101400E+00, 0.73261800E+00, 0.39795400E+00, -.17049600E+01, 0.12876900E+01, -.72763800E+00, 0.16985300E+01, 0.12990100E+01, -.57902600E+00, -.65145000E+00, 0.17471200E+01, -.57561500E+01, 0.40718900E+01, 0.10227300E+01, 0.67738100E+01, 0.46706200E+00, -.14503900E+01, -.35768400E+00, 0.10896100E+01, -.36180700E+01, 0.57496400E+00, -.48295700E+00, -.31456900E+00, -.65081600E+00, 0.42103500E+00, -.50439800E+00, -.96007400E-01, -.64574100E+00, 0.17311700E+01, 0.49810600E+01, -.41943000E+01, 0.14045500E+01, 0.99492400E+01, -.32835900E-01, -.24329100E+01, -.59313600E-01, 0.27906300E+00, -.33022200E+00, -.63016800E+00, -.13565600E+01, -.18645100E+00, 0.17594600E+01, -.39475200E+00, 0.30702400E+01, 0.24483700E+00, -.98248600E+00, 0.71232100E+00, 0.49924200E+00, -.55213000E-01, -.24517800E+01, -.20410900E+01, -.42964700E+01, -.29157000E+00, -.32688900E-02, -.50715600E-02, -.29590400E+00, 0.74379000E+00, -.10973900E+00, 0.30802100E+00, -.30705800E+00, 0.90277600E+00, -.24795400E+00, -.16192000E+00, -.15382900E-01, -.41072900E+00, 0.83848200E+00, 0.27836900E+00, -.63922500E+00, 0.71071400E+00, 0.80521500E+00, -.10983400E+01, -.66252300E+01, -.15407900E+00, 0.13375300E+01, 0.60369700E+00, 0.10328100E+01, 0.10793400E+01, -.18850200E+00, -.36465000E+00, -.19206000E+01, -.95733400E-01, 0.54673100E+00, 0.34589900E+00, -.42061800E+00, -.36495400E+01, -.77573200E+00, -.35230500E+01, -.21860000E+01, -.10246800E+01, -.18820900E+00, 0.20624400E+02, 0.41122100E+01, 0.60403700E+02, 0.50969300E+02, 0.18095900E+02, 0.42565000E+02, 0.38306400E+02, -.10833100E+03, 0.39399100E+03, -.17221000E+03, -.14031500E+03, -.15462500E+03, 0.40511100E+02, -.13297200E+03, -.85823400E+02, -.75170300E+02, -.57379200E+02, 0.83828400E+02, -.40561700E+01, -.34598500E+02, -.95258000E+02, 0.45718300E+02, -.12381500E+02, 0.74961600E+02, -.12603200E+02, -.25740900E+02, 0.17258700E+03, -.87737900E+02, -.64357800E+02, 0.31350300E+02, 0.19887200E+02, -.65279700E+02, -.15131000E+01, -.49891200E+02, -.59075300E+02, -.57446800E+02, 0.32201100E+02, 0.23773100E+02, -.14796800E+02, 0.11354000E+02, -.12435000E+02, 0.13149700E+02, -.85942100E+02, 0.96521400E+02, -.32615300E+02, 0.17972200E+02, 0.58983200E+01, 0.26126500E+02, -.42899900E+01, 0.56643900E+01, 0.13040400E+02, -.11118100E+03, 0.32734300E+02, -.45156300E+03, 0.22225500E+03, 0.23564000E+03, -.16007200E+02, -.52411300E+02, 0.19058600E+03, 0.17307000E+03, 0.28359700E+03, -.10110200E+03, 0.43636000E+03, -.21979000E+03, -.23653800E+03, 0.31163100E+02, -.33954300E+02, -.11869700E+03, -.46712500E+02, -.13832800E+03, -.73051500E+02, 0.26716300E+03, -.13467000E+03, -.12045200E+03, 0.62476500E+02, 0.18287500E+03, -.15787200E+03, -.14786600E+03, -.27830500E+03, 0.12491600E+03, -.10355300E+03, 0.51091000E+02, 0.52136300E+02, 0.59798200E+02, 0.80180900E+02, 0.44385800E+02, 0.15774700E+03, 0.11224600E+03, 0.15036800E+01, -.79272300E+02, 0.40804000E+02, 0.80298600E+02, -.59895200E+02, 0.32692300E+00, 0.69821300E+02, 0.16176500E+03, 0.13555400E+02, -.14430000E+02, 0.46249000E+01, -.28022700E+02, 0.39251900E+01, -.23020300E+01, -.21132300E+01, 0.85357000E+01, 0.46725800E+02, -.24862900E+02, -.15743600E+02, 0.55719800E+02, 0.50582700E+01, -.10991300E+01, 0.48723900E+01, -.27486400E+01, -.28360300E+01, -.26865100E+02, 0.43114200E+03, 0.14939500E+03, 0.19657400E+02, 0.62139800E+01, -.44873500E+02, -.15717000E+03, 0.49636900E+02, -.11900400E+03, 0.53876000E+02, 0.13828800E+02 },
            { 0.58444100E+00, 0.81607300E+00, -.12015700E+00, -.63588200E-01, -.59322300E+00, -.84101100E-01, -.19252000E+00, -.97307300E-02, 0.15217000E+00, -.41107800E+00, -.78150500E+00, -.92340200E+00, 0.34756700E-01, -.81642100E-01, -.19993200E+00, 0.13963400E+00, -.38588700E-02, 0.20682400E+00, 0.11801800E+00, 0.41789200E-01, -.52620100E+00, 0.27601400E+00, 0.23042700E+00, 0.55181800E+00, -.13102300E-01, -.32019800E-03, 0.99113900E-01, 0.11251900E-01, -.14002300E+00, -.30517100E-01, -.24751700E-01, 0.11412300E+00, -.47449300E-01, -.10946000E+00, -.10990900E+00, 0.30157000E+00, 0.14934200E+00, -.56966500E-01, -.91319100E-01, 0.14580000E+01, 0.97356200E+00, -.19065400E+00, -.62839000E-01, -.47533500E+00, 0.10998000E+00, -.14848800E+00, -.58703900E-01, -.10644300E+01, -.30524000E+00, 0.13683300E-01, 0.26042300E+00, 0.26322300E+00, 0.35076000E+00, -.35928000E+00, 0.76724000E-01, 0.95115900E-01, -.21564900E+00, -.18737200E-01, 0.23912700E-01, 0.12134300E+00, 0.14334800E+00, 0.13335700E+00, 0.13846600E+00, 0.19270300E+00, -.25460600E+00, 0.19919100E-01, -.63675700E+00, 0.40500100E+00, -.34272800E+00, 0.40828200E+01, 0.35094700E-01, -.14871300E+00, -.25819000E+00, 0.18187900E+00, 0.11190800E-01, -.20324900E+00, -.22423700E+00, -.29361100E+00, 0.13409200E+00, -.17000000E-01, 0.43619600E+00, 0.41424800E+00, -.11355000E+00, 0.42397300E+00, -.17134800E+00, -.14174200E+00, -.78417000E+00, -.59935400E+00, -.13777300E+01, -.61945800E-02, 0.19181100E+00, -.12167700E+00, -.13666800E+00, 0.33048000E+00, 0.36912700E+00, -.70250800E+00, -.11710300E+01, -.98393800E+00, 0.19125000E+00, 0.23249200E+00, -.17939100E+00, -.11435600E+00, -.17506500E+00, -.44499600E-01, -.38995500E+00, -.90952200E+00, 0.23978200E+00, -.97238700E+00, -.12268700E+01, 0.11613400E+00, 0.37960300E+00, -.35234700E+01, -.80306000E+00, 0.60441300E+00, -.16517800E-01, 0.28167000E-01, -.15552100E+01, 0.64318700E-01, 0.46463300E+00, 0.19250000E-01, -.12538300E+00, -.41494300E+00, -.28828800E-01, 0.48853900E-01, -.19786500E+00, -.46280800E+00, -.93224700E+00, 0.15957600E+00, -.20381700E+01, -.20802100E+02, -.28199100E+02, -.60691800E+00, 0.75649200E+01, -.23260200E+02, 0.13673400E+02, 0.19264200E+03, -.10401500E+03, -.12910600E+03, 0.19621000E+02, 0.68530400E+02, -.93628700E+02, -.80210000E+02, -.12806200E+03, 0.43451100E+02, -.12781300E+03, 0.63415400E+02, 0.61659300E+02, -.68755100E+02, 0.36733800E+01, 0.59953400E+02, 0.60503200E+02, 0.41884900E+02, 0.29065200E+02, -.28963600E+02, 0.15604400E+02, -.65182900E+01, -.10396500E+02, 0.56762400E+01, 0.27906700E+01, -.15676500E+02, 0.99411600E+01, 0.66332500E+01, 0.91336100E+01, -.56205300E+01, -.85664600E+01, 0.43959100E+01, 0.11415400E+02, 0.76526600E+01, -.39504900E+01, 0.96073000E+01, -.56856600E+01, 0.37394000E+02, -.18841800E+02, -.14799600E+02, -.87540300E+01, -.43041600E+01, 0.44001500E+01, 0.22234000E+02, 0.23299300E+02, -.26882600E+02, 0.53749900E+01, -.78164400E+00, -.73421700E+01, -.24569300E+01, 0.35051900E+02, -.30851000E+02, -.48896700E+02, -.43643700E+02, 0.32935400E+02, -.63589600E+02, 0.29805000E+02, 0.54403300E+02, 0.15382900E+01, 0.10843300E+02, -.13974900E+02, -.35726400E+02, 0.20319200E+01, 0.52886100E+02, -.13948300E+02, 0.34807200E+01, 0.42817400E+01, -.10852700E+02, -.15574100E+02, 0.86015000E+01, 0.41617700E+02, 0.47642900E+02, -.24100000E+01, 0.97968500E+02, -.49229300E+02, -.48471500E+02, -.20690000E+02, -.19195400E+02, -.41627000E+02, -.36663600E+02, -.50336700E+02, -.97213000E+01, -.49658700E+02, 0.24304800E+02, 0.68523100E+01, -.24165900E+02, -.46357500E+01, 0.37470600E+02, 0.41819400E+02, 0.48498300E+02, -.12616800E+02, -.29584200E+01, -.87516500E+01, -.51232700E+01, 0.49544300E+00, 0.46659000E+01, -.47295100E+00, -.13553600E+02, -.95739600E+01, 0.39838100E+01, -.11196300E+02, -.25554400E+01, 0.37067600E+00, -.22643800E+01, -.94309800E+01, 0.13399600E+02, -.66765000E+01, 0.90712500E+02, 0.46944400E+02, -.30149300E+01, -.41790800E+00, 0.91666100E+01, 0.16589000E+02, -.20758400E+02, 0.35271000E+02, -.12386600E+02, 0.99938000E+01 },
            { -.17056300E+01, 0.14911300E+01, 0.60913400E+00, 0.81694500E+00, -.14156500E+01, -.43434400E+00, 0.52050000E+00, -.17115300E+00, 0.21334200E-01, 0.32523400E+00, 0.14080600E+01, 0.18860700E+01, -.54011700E+00, -.77471400E+00, 0.24591600E+00, -.36187400E+00, 0.91128100E+00, -.15819700E+00, -.16348900E+01, 0.37753200E+00, 0.11724100E+01, 0.89541600E+00, -.68438100E+00, 0.10532900E+01, 0.30432600E+00, 0.22096300E+00, -.26738600E+00, 0.47219500E-01, -.16478100E+00, 0.33889800E+00, 0.11359300E+01, 0.53962300E+00, 0.83330600E+00, 0.55083900E+00, 0.17391900E+00, 0.33377500E+01, 0.73855700E-01, -.34689800E-01, -.25159200E-01, 0.29131600E+01, 0.15605800E+01, -.36027600E+00, -.69772100E+00, -.76182700E+00, 0.45467500E+00, 0.76339600E+00, 0.84448700E-01, 0.15710400E+01, -.18161500E+01, 0.11115000E+01, -.14959500E+01, 0.17858500E+01, -.20773400E-01, 0.95285200E-01, 0.21929500E+00, -.97834000E-01, -.14430000E+01, 0.26485900E+00, 0.44334200E+00, 0.21725600E+00, 0.91070400E+00, -.40924100E+00, 0.28660100E+00, 0.91195900E-01, -.35495000E+00, 0.71327100E+00, 0.81807100E+00, -.40202900E+00, 0.71161100E+00, -.15554200E+01, 0.33222300E-01, 0.18017800E+00, -.13052400E+00, -.11332700E+00, -.12861900E+00, -.28102400E+00, -.27531000E+00, 0.60534500E+00, 0.10551900E+01, 0.73760300E+00, -.13975600E+00, 0.17802200E+00, 0.56859200E+00, 0.25150800E-01, 0.30625600E-01, -.40819100E+00, -.12627800E+01, -.13156300E+01, -.22706300E+01, -.75882300E-01, 0.17570900E+00, -.89986400E-01, -.25820100E+00, 0.34784000E+00, 0.35973900E+00, -.58581000E+00, -.58661900E+00, -.73295500E+00, 0.61458700E-01, 0.30244500E+00, -.12965400E+00, -.44150700E+00, -.15207300E+00, 0.49945300E+00, -.66951200E+00, -.19378600E+00, -.54812400E+00, 0.34562200E+00, -.20268300E+00, -.20233300E-01, 0.21899300E+00, 0.53888100E+01, 0.11468000E+01, -.18924400E+00, -.98773800E+00, -.28740300E+00, 0.22942200E+01, -.11388700E+01, -.25022700E+00, 0.66275600E-01, -.26745600E+00, -.12013900E+01, 0.70478500E-01, -.88068500E+00, -.60476000E+00, -.52874800E+00, -.62017500E+00, 0.10093100E+00, 0.73664700E+00, 0.14864300E+03, -.18199700E+02, 0.32203900E+01, -.27500400E+01, -.31193600E+01, 0.17613400E+02, -.40014900E+03, 0.20696000E+03, 0.15908500E+03, 0.89015200E+02, 0.19131900E+03, 0.46754200E+02, -.84393400E+02, -.47172900E+02, 0.18790600E+03, 0.36791600E+03, -.18510500E+03, -.18462900E+03, 0.11631300E+03, -.34626200E+01, -.16442800E+03, -.13269300E+03, -.13083600E+03, 0.13355300E+02, 0.14515900E+03, -.72170100E+02, -.68155100E+02, 0.17370900E+02, -.28680700E+02, -.13848600E+02, 0.38115600E+02, 0.49271900E+01, -.28701300E+02, 0.33007100E+02, -.15660100E+02, -.77737100E+00, 0.91032800E+01, -.53115400E+01, -.24905100E+02, -.23733900E+02, 0.56107500E+01, 0.54532800E+01, 0.10234000E+03, -.50808800E+02, -.52586000E+02, 0.19506100E+02, 0.13417200E+02, -.54922700E+02, -.57291400E+02, -.38407000E+02, 0.80277100E+01, 0.17155600E+03, -.87220400E+02, -.91420500E+02, -.34882100E+02, -.66500300E+02, 0.16688200E+02, 0.56964600E+02, -.41634900E+02, -.84046600E+02, -.38959000E+02, 0.22560100E+02, 0.13338800E+02, -.36614600E+02, 0.26034900E+02, 0.21442500E+02, 0.35607400E+02, 0.36032600E+02, -.67467900E+02, -.40058600E+02, 0.24551600E+02, 0.20060800E+02, 0.25578400E+01, 0.51319700E+02, -.33262800E+02, -.45639200E+02, -.50352300E+02, 0.22709400E+02, -.33281500E+02, 0.16666000E+02, 0.16087100E+02, 0.18360100E+02, -.51812300E+01, 0.31485200E+02, 0.48904600E+02, 0.47610000E+02, -.33700300E+00, -.71686100E+02, 0.35680500E+02, 0.25511700E+02, 0.61536100E+02, 0.21890500E+01, 0.43537000E+02, 0.53929100E+02, 0.14363200E+01, 0.63923800E+02, 0.64222600E-01, 0.55871300E+02, -.15902800E+02, 0.13605200E+01, 0.18691800E+02, -.24804500E+01, -.39513500E+02, 0.61959700E+02, 0.89790400E-01, -.54033900E+01, -.32130000E+00, 0.56520900E+00, -.31312600E+00, 0.30631900E+01, -.13624300E+02, 0.86491700E+02, 0.99173300E+02, -.69770200E+02, -.34110000E+02, -.14342100E+02, -.98398200E+00, -.41992800E+02, 0.21016000E+02, -.24329500E+02, 0.61527600E+02, 0.64262900E+02 },
            { -.54500000E+01, 0.13194600E+00, 0.34996800E+01, -.11583600E+01, 0.29506400E+01, 0.71282600E+00, 0.28790000E+01, -.21223800E+00, -.28617700E+01, 0.93579600E+00, 0.12012100E+01, 0.59540800E+01, -.65172800E+00, -.12220500E+01, 0.73381900E+00, -.87154700E+00, 0.64541300E+00, -.47987000E+00, -.48920400E+01, -.13279700E+00, 0.63765400E+01, -.13836500E+01, -.20705600E+01, -.58242800E+01, 0.17424000E+01, 0.36149200E+00, -.44109500E+00, 0.40508800E+00, -.28274100E+00, 0.11299600E+01, 0.89718300E+00, 0.35663000E+00, 0.56327800E+00, -.88994300E+00, 0.71637400E-01, -.77242400E+00, -.11481800E+01, 0.43637500E+00, 0.74484100E+00, -.26792400E+01, -.88032200E+00, 0.10574400E+01, -.57700700E+00, 0.45950900E+00, 0.94137200E+00, 0.48700100E+00, -.31486400E+00, 0.96444600E+01, -.36965600E+01, 0.98065500E+00, -.45770700E+01, 0.22867600E+01, 0.22699600E+01, -.13020600E+01, -.12295200E+01, 0.15361400E+01, 0.33603800E+01, 0.28184400E+00, -.17730000E+01, 0.20927000E+01, -.47447600E+00, 0.87362700E+00, -.15340800E+01, -.55617800E+00, -.14398600E+01, 0.39033600E+01, 0.32518100E+01, 0.36863900E+01, 0.14950900E+01, -.11969700E+02, -.95825700E+00, 0.45725000E+01, 0.80011800E+00, -.91852500E+00, -.11263900E+01, 0.56173700E+00, 0.58480700E+00, 0.14137400E+01, -.21799500E+00, 0.13270700E+01, -.43472500E+01, -.20472000E+01, 0.22869700E+01, -.20381400E+01, -.41835100E+00, 0.54085200E+00, 0.93405500E+01, 0.24953300E+01, 0.12325800E+02, 0.44819500E+00, -.83110800E+00, 0.30389500E+00, -.20526900E+00, 0.26334200E+01, 0.90871100E+00, 0.34327600E+01, 0.50382500E+01, 0.21677500E+01, 0.51296200E+00, -.52374000E+00, 0.13511800E+00, -.61365500E+00, -.10481900E+01, -.50953200E+01, 0.27530500E+01, 0.51625800E+01, 0.17300800E+01, 0.76788100E+00, 0.66871900E+01, 0.97542900E+00, -.17213900E+01, 0.13823500E+02, 0.15507000E+01, -.28079800E+01, -.59450700E+01, -.90041200E+00, 0.61086600E+01, -.43111000E+01, -.15858600E+01, 0.12693100E+01, -.11025400E+01, -.21283600E+01, 0.40918500E+00, -.56863100E+01, -.90402600E+00, -.30414000E+01, -.25957100E+01, -.39038600E+00, 0.41623700E+01, 0.35863000E+01, 0.36790400E+03, 0.10686200E+03, 0.19947700E+03, 0.25022400E+03, -.40479200E+03, 0.61900400E+03, -.23515900E+03, -.23203800E+03, -.92016500E+02, -.67274600E+03, 0.17569500E+03, 0.81527700E+03, 0.55658500E+03, -.59904000E+03, -.79190500E+02, 0.54903600E+02, 0.36112800E+02, 0.30039400E+03, 0.53417000E+02, 0.16212700E+02, -.13315200E+03, 0.19291700E+02, -.35567800E+03, 0.43928600E+02, -.29892000E+02, 0.81490600E+01, 0.21590500E+03, 0.73840000E+02, -.81879600E+02, -.15303300E+03, -.23480300E+03, 0.82142700E+02, -.87933700E+02, 0.50920300E+02, 0.23209200E+02, -.41239800E+02, -.13092400E+03, 0.26846300E+02, 0.10357600E+03, -.19399400E+01, 0.23462600E+02, -.50769600E+03, 0.25550000E+03, 0.25904500E+03, -.36789000E+02, 0.13828600E+01, 0.74992100E+02, -.80102700E+02, -.99968000E+01, 0.17977000E+03, -.18153100E+03, 0.78922700E+02, 0.10260800E+03, 0.61423100E+02, -.16163700E+03, 0.18638100E+03, 0.31667200E+03, 0.31759200E+03, -.46542200E+02, 0.43103100E+03, -.20482000E+03, -.25194300E+03, 0.69665500E+02, 0.13715300E+03, -.11823600E+03, -.46697800E+02, -.16718400E+03, 0.15212500E+01, 0.32535600E+03, -.14248200E+03, -.16808500E+03, 0.48427900E+02, 0.17073600E+03, -.13670800E+03, -.41316700E+03, -.43213100E+03, -.16680600E+02, -.30154700E+03, 0.15291700E+03, 0.15257700E+03, 0.31156900E+02, 0.10347600E+03, 0.15015000E+03, 0.19069700E+03, 0.17277800E+03, 0.50331200E+02, -.17529400E+03, 0.90915100E+02, 0.10404600E+03, 0.27213300E+03, 0.76234900E+02, -.68080800E+02, -.21531200E+03, -.95219800E+02, 0.14792700E+03, 0.92734900E+01, 0.23309300E+02, 0.38828600E+02, -.27041300E+01, -.59957500E+02, 0.83107500E+01, 0.63798700E+02, 0.19010100E+02, -.25633400E+02, 0.12810100E+03, 0.60500900E+01, -.15374400E+01, 0.52381000E+01, 0.74500200E+02, -.61288900E+02, -.17358300E+03, -.15581800E+04, -.21607100E+03, 0.59289300E+02, -.28267900E+02, -.53039100E+02, -.66332100E+02, 0.38517000E+02, -.40709700E+03, 0.45870900E+01, -.65053500E+02 },
            { 0.13179500E+01, 0.12492800E+00, -.27875700E+00, -.56829700E+00, -.20853400E+01, -.19023300E+00, -.52455200E+00, 0.11396800E+00, 0.13791700E+01, -.21670200E+00, 0.97860400E-01, 0.38349100E+00, 0.65142800E+00, -.10703700E+01, 0.43196400E+00, -.11312400E+00, -.34455000E-01, -.16851600E+00, 0.60151400E+00, -.17333900E+00, -.62960000E+00, -.26555300E-01, 0.71291400E+00, -.18384500E+01, 0.51019000E-01, 0.15610000E+00, 0.16233100E+00, -.34277500E+00, -.61037300E-02, -.18341400E-01, 0.35137800E-01, -.49424900E+00, -.52441800E-01, 0.55763600E-02, 0.39029700E-01, 0.32500400E+01, -.25660000E+00, 0.96119500E-01, 0.17288300E+00, 0.55825300E+00, -.20437000E+01, 0.48789200E+00, 0.46938700E+00, 0.97394100E+00, -.51836000E+00, -.54973300E+00, -.35775700E+00, -.48692800E+00, -.73243900E+00, 0.41821300E+00, -.42712600E+00, 0.18338800E+01, 0.14305200E+00, -.46545100E+00, -.40881400E-01, 0.74097800E-01, 0.39495400E+00, 0.21050800E+00, -.36038500E+00, 0.19772300E+00, 0.95571400E-01, -.13417800E+00, 0.63478600E+00, 0.10452000E+00, 0.46674800E-01, 0.33273200E-02, 0.36579900E+00, -.58630700E-01, -.56162700E+00, 0.56155700E+01, 0.46782100E+00, -.56934800E-01, -.19437000E+00, -.12800700E-01, -.56995700E-01, -.29741400E+00, -.12036300E-02, -.32759200E+00, -.58488800E-01, -.25183400E+00, -.17549100E-01, 0.69160700E-01, -.51650700E+00, -.36800400E+00, 0.22246000E+00, 0.11164000E+00, -.57016200E+00, 0.36398100E+00, -.35965700E+00, 0.54082800E-01, 0.13643500E+00, 0.27917200E-01, -.86914700E-01, -.17745400E+00, -.16609800E+00, -.83011800E+00, -.87645300E+00, -.64757100E+00, -.16552900E+00, 0.33930700E-01, 0.17471800E+00, -.61730400E-01, -.49348900E+00, -.79081200E+00, -.20896300E+00, -.12278000E+01, -.14109700E+01, 0.10907700E+01, 0.21941600E+01, 0.82587000E-01, 0.78896700E+00, 0.17893400E+01, 0.18889800E+00, -.15070900E+01, -.81135400E+00, 0.22920000E+00, -.47955000E+01, -.34676600E+00, 0.31568000E+00, -.16311500E+00, -.12936600E+00, 0.16004300E+00, 0.26979400E+00, 0.13484100E+00, -.25968400E+00, 0.81417400E-02, -.73883300E-01, 0.75835000E-01, 0.67496500E+00, 0.40643700E+00, -.38802100E-01, -.40741600E+02, -.59734700E+02, -.31668500E+02, 0.10087700E+03, 0.33944400E+02, -.26600700E+02, 0.12881600E+02, -.64439000E+02, -.95767900E+02, 0.18007800E+02, -.27332400E+02, 0.39771500E+02, -.81869100E+02, 0.66312500E+02, -.39290100E+02, -.33738400E+02, 0.41161800E+02, 0.34851400E+01, -.46062100E+02, -.59000600E+02, -.50029800E+02, 0.41492600E+02, -.57473600E+02, 0.28925100E+02, 0.36018200E+02, -.26674400E+02, -.70063300E+00, 0.18974900E+02, 0.18662700E+02, 0.75291400E+00, 0.25847500E+01, -.26394300E+02, 0.12430900E+02, 0.96411400E+01, -.20797900E+02, -.13398700E+02, 0.19411200E+02, -.63194400E+01, 0.62774900E+01, -.62946500E+01, -.35220900E+02, 0.16097300E+02, 0.19073900E+02, -.12214600E+02, -.12800500E+02, 0.31058500E+02, -.88081300E+01, 0.19333300E+02, 0.21222400E+00, -.11451700E+03, 0.56474900E+02, 0.60593700E+02, 0.25575500E+02, 0.19388200E+02, 0.12475800E+02, -.29693700E+02, 0.66136400E+02, 0.22810900E+02, 0.84761200E+02, -.40036000E+02, -.52648100E+02, 0.92510200E+01, -.18426400E+02, -.15187000E+02, 0.13173400E+01, -.32024000E+02, -.49158800E+02, 0.18832700E+02, -.58601200E+01, -.11326000E+02, 0.70060100E+01, -.33571600E+02, 0.25329000E+02, 0.53668500E+01, 0.28130100E+02, -.21368100E+02, -.18491800E+03, 0.93244200E+02, 0.92376600E+02, 0.26525000E+02, 0.37424000E+02, 0.38441200E+02, -.70803300E+02, -.49348400E+00, 0.37736800E+02, 0.11978200E+03, -.59478000E+02, -.55017600E+02, -.11736700E+00, 0.84251100E+00, -.81295300E+02, -.62542000E+02, -.31660800E+02, -.19868100E+01, 0.24038200E+01, -.24579000E+02, 0.14421900E+02, -.95391000E+00, -.13209400E+02, -.21466800E+00, 0.39997700E+02, -.30923200E+02, -.15380600E+01, -.82410000E+01, 0.19679100E+01, -.56592400E+00, 0.19497300E+01, 0.90957400E+01, -.10909100E+02, 0.62666000E+02, -.18839700E+02, -.39521300E+02, 0.64591400E+01, 0.75701300E+01, 0.16398200E+02, 0.11016700E+02, 0.17634300E+02, -.48425700E+01, -.44846300E+02, -.38415900E+02 },
            { 0.11858000E+01, -.31941700E-01, -.42255500E+00, -.53749100E+00, -.22441200E+01, -.23000600E+00, -.49712200E+00, 0.20960500E+00, 0.81494400E+00, -.32172100E+00, -.17144300E+00, -.26600000E+00, -.16568900E+00, -.43869200E-01, 0.17080600E+00, 0.29485000E+00, -.97600200E+00, 0.21082000E+00, 0.28297600E+00, 0.28967600E-01, -.66217300E+00, -.15986400E+00, -.15906100E+00, -.37109700E+00, -.11996400E+00, -.24894500E-01, 0.36143100E+00, 0.35855000E-01, -.28428800E-01, 0.75496200E-01, 0.28144100E+00, 0.24428200E+00, -.58225700E+00, -.44681100E+00, -.52315300E-02, 0.31137700E+00, 0.60532000E+00, -.23411000E+00, -.37293100E+00, 0.10861700E+01, 0.35650600E+01, -.83772500E+00, -.56426400E+00, -.11932400E+01, 0.13499000E+00, -.38983500E+00, 0.65298300E+00, -.10018500E+01, 0.84416000E+00, -.49994700E+00, -.73538700E-03, -.57013300E+00, 0.20655900E+00, -.13451400E+00, -.26925500E-01, -.56501700E-01, 0.63738200E+00, -.14700000E+00, 0.28207000E+00, 0.30340400E+00, -.45611400E+00, 0.61479100E+00, -.29098500E-01, -.12716300E+00, -.31458800E+00, 0.14314300E+00, -.27072300E-01, 0.98781200E+00, -.50542200E+00, 0.32833800E+01, -.53232200E+00, 0.35118500E-01, -.91790400E-01, 0.43959200E+00, -.67410800E-01, -.10578100E+00, -.22595300E+00, -.51138100E+00, -.54730000E+00, -.74353600E+00, 0.19990900E+00, 0.10811800E+01, -.16562200E+01, -.50153000E+00, 0.25423600E+00, -.62935900E-01, 0.16198400E+01, -.10240700E+01, 0.32296700E+01, 0.14532800E+00, 0.25982800E+00, -.66804300E-01, -.22975800E+00, 0.29841500E+00, -.43815600E-01, -.22634400E+00, -.49688800E+00, 0.84586500E+00, 0.28611300E-01, 0.78536900E-01, 0.58489800E-01, -.21861700E+00, -.25216200E+00, -.18245700E+01, 0.19188100E+00, 0.35442100E-01, -.71285800E+00, 0.57736700E+00, 0.42767200E+01, 0.59026800E+00, -.86623100E+00, 0.46301000E+01, 0.46645800E+00, 0.33624600E+00, 0.87173300E+00, -.92963700E-01, 0.51770000E+01, 0.26250300E+00, -.74773100E-01, -.13666500E+00, -.14591900E+00, 0.33646500E+00, -.43543000E+00, 0.12425200E+01, 0.13683800E+01, 0.50369100E+00, 0.90651400E-01, 0.93071200E-01, 0.11969200E+00, -.36145100E+00, -.69076400E-01, -.78395900E+00, 0.71440000E+02, 0.49742900E+02, 0.10683400E+03, 0.42891800E+02, -.21041100E+02, 0.33981000E+02, -.48272800E+02, -.16984700E+03, 0.76085500E+02, 0.17719200E+03, 0.17508100E+03, -.16066300E+03, 0.76560600E+02, -.48849100E+02, -.38751600E+02, 0.13429300E+03, 0.15264500E+02, -.80532300E+02, -.15647100E+03, -.96120300E+02, 0.57248300E+02, -.57844600E+02, 0.29707000E+02, 0.33559600E+02, 0.53378100E+02, 0.46181800E+02, -.14875400E+02, -.36997000E+02, -.45270900E+02, 0.29525900E+02, -.70323700E+02, 0.33990300E+02, 0.17281700E+02, -.16457200E+00, -.43142300E+02, 0.34937800E+02, 0.20710100E+02, 0.23056200E+02, 0.45501000E+01, -.23774400E+03, 0.11645500E+03, 0.12191100E+03, -.64018800E+02, -.30490500E+02, 0.96878800E+02, -.24775500E+01, 0.62168800E+02, 0.15999200E+02, 0.38582900E+02, -.21792800E+02, -.11870100E+02, -.73981600E+01, -.60374200E+02, -.98378600E+01, -.20892100E+02, 0.94591000E+02, -.54475600E+02, 0.50736100E+02, -.18603700E+02, -.29528600E+02, -.44726400E+02, 0.30504900E+02, 0.23102600E+01, 0.24407800E+02, 0.37376700E-01, -.44695700E+02, -.11358000E+03, 0.66956200E+02, 0.53289800E+02, -.10841000E+02, -.36846800E+02, 0.10771400E+03, 0.94519900E+02, 0.58151700E+02, -.64363100E+01, -.69498600E+02, 0.35919600E+02, 0.35364600E+02, 0.24546100E+02, 0.29189000E+02, 0.26118500E+02, 0.54080200E+01, -.30734100E+01, 0.14343400E+01, 0.49809500E+02, -.24722200E+02, -.13380100E+02, 0.69428100E+02, 0.66356100E+01, -.83080500E+02, -.11578000E+03, -.38106900E+02, 0.53237200E+02, -.43461500E+01, -.11696100E+02, 0.11912700E+02, -.48047000E+00, -.15318800E+02, 0.30743000E+01, -.25351100E+01, -.20878500E+02, 0.39199800E+01, 0.42632800E+02, -.30791800E+01, 0.81643600E-01, -.31917200E+01, 0.26881900E+02, -.22624000E+02, 0.11629300E+03, -.32254900E+03, -.13489200E+03, 0.26486800E+02, -.10342300E+02, 0.18839400E+02, -.74689200E+01, 0.14002300E+02, 0.28372800E+02, 0.30695900E+02, -.22950400E+02 },
            { 0.73276500E+00, 0.50517000E+00, 0.42123800E+00, -.10531300E+01, -.17328600E+01, -.22511100E+00, -.21638900E+00, 0.12437100E-01, 0.24483600E+00, -.39956600E+00, 0.54939900E+00, -.47116000E+00, -.66932900E+00, -.40629100E-01, -.61471300E-02, 0.15734000E+00, -.49341700E+00, -.24317700E+00, 0.40006300E+00, 0.35200500E+00, -.55513200E+00, 0.10594400E+01, 0.40827300E+00, 0.35447000E+01, -.20146600E+00, -.19178500E+00, -.15930100E+00, 0.20284500E+00, -.15395100E+00, -.18505900E+00, -.94005300E+00, -.10898000E+00, -.18336400E+00, 0.19517500E+00, -.83600500E-01, 0.13832500E+01, 0.13928600E+00, -.55063100E-01, -.92010100E-01, 0.14404500E+01, -.40376900E-01, -.22867800E+00, -.28988800E+00, 0.94445500E-01, 0.27678400E+00, -.89565000E+00, -.15560500E+00, -.14262200E+01, 0.95184700E-01, 0.27246800E+00, 0.79083100E+00, 0.56751200E+00, 0.21646000E+00, -.16590900E+00, -.48442600E+00, -.81712500E-01, 0.17120800E+01, 0.97720400E-01, -.34093100E+00, -.45291300E-01, 0.42611300E+00, -.54497600E+00, -.90479800E-01, -.16744100E+00, 0.20317000E+00, -.15638100E+00, 0.11031200E+00, -.25680100E+00, 0.36858100E+00, 0.35616700E+01, -.48885000E+00, 0.38748900E-01, 0.23238900E+00, -.51847900E-01, 0.21819100E-01, 0.18832400E+00, 0.28771400E+00, 0.10302700E+00, -.21223800E+00, -.24057300E+00, -.18274600E-01, -.31187400E+00, -.99294700E-01, 0.80534800E-01, -.15449700E+00, 0.22273200E+00, -.33175000E-01, -.16913800E+00, -.10385800E+01, 0.39845000E-01, 0.50285100E-01, -.69509400E-01, -.35848900E-02, 0.40364500E+00, 0.10130000E+01, -.61079900E+00, -.10441700E+01, -.16889400E+01, 0.47278800E+00, 0.34009000E+00, -.22233900E+00, -.15014400E+00, -.26890600E+00, 0.26183100E+01, -.81425300E+00, -.14457400E+01, -.18882400E+00, -.17211400E+00, -.21142500E+01, 0.38423300E-02, 0.85072300E+00, -.66664200E+01, -.67465800E+00, 0.22654500E+01, 0.11426200E+01, -.58423600E-01, -.24093300E+01, 0.57673000E+00, -.10925100E+00, 0.30128900E-01, 0.26266300E+00, -.61942500E-01, 0.32248000E-01, -.35018700E+00, -.46765700E+00, -.26005100E+00, 0.11658100E+00, 0.25778500E+00, 0.13860200E+00, -.24166600E+00, -.11017400E+00, -.22393100E+00, -.32034900E+00, 0.40541500E+02, 0.28600100E+02, 0.85047600E+02, -.39587500E+02, 0.60127200E+01, -.77135100E+02, -.19711400E+03, 0.72622000E+02, 0.19697900E+03, 0.16967100E+03, -.17337700E+03, 0.11835000E+03, -.61179000E+02, -.60549600E+02, 0.10843300E+03, 0.17390700E+02, -.69815900E+02, -.10680100E+03, -.81295800E+02, 0.15343000E+02, -.40509700E+02, 0.19845400E+02, 0.36935500E+02, 0.39702000E+02, 0.31322400E+02, -.18180400E+02, -.64834900E+02, -.58169400E+02, 0.28346300E+02, 0.20988600E+01, -.10147300E+01, -.82485700E+01, -.96115700E+01, -.36659600E+02, 0.11834100E+02, 0.36663200E+02, -.15174200E+01, -.11668000E+02, -.51409600E+02, 0.25158500E+02, 0.29133600E+02, -.71633800E+01, 0.16953700E+02, 0.18198300E+01, -.23057600E+02, -.22467500E+02, 0.40981600E+02, 0.18150800E+03, -.92386100E+02, -.84595700E+02, 0.35791100E+02, 0.54854500E+00, -.97091900E+02, -.82094000E+02, -.58206900E+02, 0.16382100E+02, 0.17842200E+02, -.54290500E+01, -.29596900E+02, -.49874800E+02, 0.21517200E+02, 0.34039400E+02, 0.46871900E+02, 0.10285700E+02, -.64518000E+02, -.19425500E+01, 0.66420900E+01, -.38877300E+01, -.36240700E+02, -.74647100E+02, 0.69309300E+02, 0.65524400E+02, 0.38690600E+02, -.94848500E+02, -.86370300E+02, 0.43829100E+02, 0.42821100E+02, -.13271400E+02, -.25304900E+01, 0.25977100E+02, -.36537100E+02, 0.38391500E+01, 0.65206200E+01, 0.15737800E+03, -.78211800E+02, -.70673500E+02, 0.99209500E+02, 0.10093300E+02, -.13461000E+03, -.17505600E+03, -.10990000E+03, 0.60080600E+02, -.18583700E+01, -.11814800E+02, 0.17534200E+02, 0.95396700E-01, -.20622200E+02, -.15740000E+01, 0.35161300E+02, -.15285700E+02, -.24826100E+01, 0.23147400E+02, -.23315000E+00, 0.16816300E+00, -.42499300E+00, 0.23988500E+02, -.19122600E+02, 0.34537400E+02, -.18384300E+03, -.90085400E+02, 0.19559500E+02, -.41010800E+00, -.39935700E+00, 0.76025300E+02, 0.22651300E+02, 0.11752300E+02, -.43151600E+02, -.33498300E+02 },
            { 0.86849300E+00, 0.20576600E+00, -.31579200E+00, -.22029700E+00, -.18038500E+01, -.27275300E+00, -.25472200E+00, -.38960300E-01, 0.30700100E+00, -.12776200E+00, 0.69536200E+00, 0.69601400E+00, 0.27658300E+00, -.10313600E+01, 0.79409100E-01, 0.98358700E-02, -.10628500E+00, -.17058600E+00, 0.21134200E+00, 0.21902300E-01, -.82272900E-01, -.66505400E+00, -.89114000E-01, -.49310400E+00, 0.29304900E-01, -.17726500E+00, 0.62161800E-01, 0.12312600E+00, 0.13908400E-01, 0.52024900E-01, 0.30690500E+00, 0.21870000E+00, -.48806500E+00, 0.32105100E+00, 0.12639000E+00, 0.70776700E+00, -.24110000E-01, 0.87004000E-02, 0.12532900E-01, -.11617900E+00, -.76430700E+00, 0.54791000E-01, 0.21746700E-01, 0.30782200E+00, -.17039700E+00, -.60649900E+00, 0.48217500E+00, -.10175300E+01, 0.93339300E+00, -.33916600E+00, 0.40353600E+00, -.46603300E+00, -.17944200E+00, 0.76719500E-02, -.11180000E+00, -.43816100E+00, 0.58907900E+00, -.89349900E-01, -.31602700E+00, -.11078300E+00, -.27937600E-01, -.13018800E+00, 0.32509000E+00, 0.18702600E+00, 0.40816800E+00, -.95994300E+00, -.62386700E+00, 0.22131500E+00, -.44619800E+00, 0.25563400E+01, -.11937300E-01, 0.46740800E+00, 0.65489700E-01, -.39596200E-01, 0.34083500E-02, -.14074800E+00, 0.32437400E+00, 0.61651200E-01, -.24969200E+00, 0.10039800E+00, -.37760500E+00, -.32917800E+00, 0.39069600E+00, -.12548700E+00, -.13443900E+00, 0.14027300E+00, -.12072400E+01, 0.16976400E+00, -.21614200E+01, -.77872700E-01, -.33463900E-01, -.28194400E-01, 0.51295600E-01, -.24481100E+00, 0.55922700E-01, -.21489200E+00, -.17154600E+00, -.55247000E+00, -.63492000E-01, 0.36492800E-01, -.10975900E+00, 0.17783300E-01, -.24778100E-01, 0.66303900E+00, -.11407200E+00, -.57368900E+00, -.20384900E+00, 0.42481500E+00, -.19561800E+01, -.21024400E+00, 0.10065100E+00, -.22680200E+01, -.22837500E+00, 0.19301500E+00, -.11037200E+01, -.10032600E+00, -.21633600E+01, 0.17077000E+00, 0.41261200E-01, 0.22566500E-02, -.18908000E+00, 0.20409100E+00, 0.76749100E-01, 0.41706500E+00, -.66229100E-01, -.12848400E+00, -.85794900E-01, 0.52909000E-01, 0.24756700E+00, 0.80123100E-01, 0.20251900E-01, 0.39421700E+00, -.35611000E+00, 0.55888000E+00, -.62808300E+02, -.51192600E+02, 0.19810100E+02, 0.16112300E+02, 0.27606100E+02, 0.49018700E+02, -.12182800E+02, -.50509900E+02, -.30659100E+02, 0.51909400E+02, -.15720700E+02, 0.46115300E+01, 0.78637000E+01, -.25417400E+02, -.89850100E+00, 0.12009800E+02, 0.22556400E+02, 0.27006800E+02, -.39533400E+02, -.45703800E+01, 0.31160400E+01, 0.18709500E+01, -.93616000E+01, -.82124500E+01, 0.13507700E+02, 0.23827400E+02, 0.25537900E+02, 0.17448700E+01, -.99550700E+01, 0.47090300E+01, 0.78679900E+01, -.39785300E+01, 0.95244700E+01, 0.30945800E+01, -.10316300E+02, 0.12051700E+02, -.36794400E+01, 0.11180900E+02, -.59868300E+01, -.59530100E+01, 0.97254900E+01, -.83330700E+01, 0.44649400E+01, 0.36819600E+01, 0.18249000E+01, -.32747400E+01, -.55890300E+02, 0.28133100E+02, 0.26498900E+02, -.17500800E+02, -.12015000E+02, 0.36297300E+02, 0.24322900E+02, 0.45628900E+02, -.84170200E+01, -.16120200E+02, 0.83500800E+01, 0.87932700E+01, 0.27645100E+02, -.15577600E+02, -.32453000E+01, -.58005100E+01, 0.10510800E+02, 0.34408400E+02, -.61940800E+02, 0.30988700E+02, 0.30739100E+02, 0.16650900E+02, 0.20014200E+02, 0.17659500E+01, 0.87977200E+01, 0.16163100E+02, 0.38796800E+02, 0.33884600E+02, -.17146100E+02, -.17273600E+02, 0.90146500E+01, 0.86684400E+01, -.12378600E+02, 0.78286700E+01, -.12722600E+02, 0.89132900E+01, -.47580200E+02, 0.23388800E+02, 0.21251600E+02, -.41556800E+02, 0.15584200E+01, 0.38049100E+02, 0.54496100E+02, 0.34758000E+02, -.36700500E+02, -.11218000E+01, 0.85231900E+01, -.65813400E+01, -.57232700E-01, 0.74288400E+01, 0.77093300E+00, -.22014100E+02, 0.75327000E+01, 0.47418700E+01, -.19355400E+01, -.14743400E+01, 0.18910500E-01, -.13662200E+01, -.70489700E+01, 0.42441500E+01, -.36676000E+02, 0.26312800E+02, 0.39148300E+02, -.78511500E+00, -.15703100E+01, -.42092100E+01, -.27316600E+02, -.12959000E+02, 0.13146100E+02, 0.16732900E+02, -.23060000E+01 },
            { -.13230400E+01, -.29986300E+00, 0.25920700E+00, 0.62214400E+00, 0.37552700E+01, 0.46079700E+00, 0.64427700E+00, -.11779500E+00, -.78653000E+00, 0.54919500E+00, 0.40520800E+00, -.25565700E+00, -.93645800E+00, 0.94616800E+00, 0.20473600E-01, -.56648400E-01, 0.84987800E-01, 0.50132500E+00, -.13296200E+01, 0.35128900E+00, 0.12995000E+01, 0.10408200E+01, -.32076200E+00, 0.15743500E+01, -.29483400E+00, 0.76853300E-01, -.53785900E+00, -.62457000E-03, -.27408700E+00, -.13469300E+00, 0.29647100E+00, 0.84360300E+00, 0.28345500E+00, 0.42580700E+00, 0.90353400E-01, 0.76236400E-01, 0.71045300E-01, -.27898300E-01, -.42007900E-01, -.68522900E+00, -.17730200E+00, -.14922400E+00, -.28185500E-01, -.85533400E+00, -.17011700E+00, 0.40219500E+00, -.28195600E+00, 0.11570400E+01, -.14714400E+01, -.64671000E+00, 0.36336500E+00, -.11267800E+01, 0.66553700E+00, -.11941900E-01, -.26169800E+00, -.96351300E-01, 0.14664400E+01, 0.17529600E+00, -.14077700E+00, 0.55685100E+00, 0.25493900E+00, -.66820400E+00, 0.16075600E+00, 0.22237600E+00, 0.14233400E-01, -.39183200E-01, 0.46880900E+00, -.80349900E+00, 0.79191600E+00, -.79521400E+01, 0.37363200E+00, -.65482400E+00, 0.21332600E-01, -.13293200E+00, -.20189900E-01, -.43070600E+00, -.20007200E+00, -.62869600E-01, -.59446000E+00, -.17399600E+00, 0.93744800E+00, 0.34968600E+00, -.62342800E+00, -.20939700E+00, 0.41138400E+00, 0.12748900E-01, -.45386400E+00, 0.33148000E+00, 0.54731600E+00, 0.41594100E-01, 0.23821000E+00, 0.33957800E-01, -.19900600E+00, -.11817900E+00, -.29029400E+00, -.45979800E+00, -.60048600E+00, 0.31168000E-01, -.46389000E-01, 0.11370700E+00, 0.27875700E+00, -.14279100E+00, 0.30906200E+00, -.15703800E+00, -.54465900E+00, -.56916200E-01, -.45147500E+00, -.74997400E+00, 0.21469600E+01, -.13003000E+00, 0.27181700E+00, 0.66361700E+01, 0.32025600E+00, -.44060400E+00, -.75611600E-01, 0.12279300E+00, 0.45192600E+01, -.60289400E+00, 0.29542800E+00, -.25473100E+00, 0.43367600E+00, -.63471500E+00, -.70384400E-01, -.21943200E-01, -.38385000E-01, 0.12156800E+00, 0.90974100E+00, 0.82976800E-01, -.88382900E+00, 0.48980700E+00, -.14357100E+00, -.87139200E+00, 0.32193700E+00, 0.55490500E+00, 0.11194700E+01, 0.67528600E+03, -.33355200E+03, -.28137600E+03, -.99704100E+02, -.20044400E+03, -.95298300E+02, 0.22422400E+03, 0.44703100E+02, -.23488300E+03, -.91378700E+02, 0.49685900E+02, 0.46234700E+02, 0.35444500E+02, 0.52413800E+02, 0.22931300E+02, -.24385300E+02, -.50027100E+02, 0.22729000E+02, -.12059700E+03, 0.59403200E+02, 0.59933700E+02, 0.36881000E+02, 0.49835200E+02, -.39922800E+01, -.63298500E+02, -.51226600E+02, 0.36747000E+02, -.19773100E+02, 0.10180800E+02, -.11825300E+02, -.19309600E+02, -.19317000E+02, 0.26677300E+02, 0.54779200E+02, -.19060100E+02, -.19480000E+00, -.10363300E+03, 0.51949600E+02, 0.54441700E+02, -.46373700E+02, 0.35998600E+00, 0.39839100E+02, 0.18548000E+02, 0.33155700E+02, 0.44333000E+01, -.13704100E+02, 0.63239900E+01, 0.15230200E+02, 0.32109600E+02, 0.19607000E+02, -.51608500E+02, -.65456300E+02, -.23530700E+02, 0.49927300E+02, 0.10370100E+03, -.51814700E+02, -.48930700E+02, -.14418800E+02, 0.31333500E+02, -.40683300E+02, -.28959700E+02, -.80305200E+02, 0.14626200E+02, 0.18021700E+03, -.89882700E+02, -.89413800E+02, -.53550500E+02, -.32454700E+02, 0.48308200E+01, 0.62736000E+01, -.56797600E+02, -.79659200E+02, -.35026600E+02, 0.17810000E+02, 0.18660400E+02, -.29332400E+02, -.76947800E+01, 0.10817800E+02, -.18939300E+02, -.41488100E+01, -.76437900E+01, 0.35955400E+02, -.17470600E+02, -.32651800E+01, 0.57141200E+02, -.68558900E+01, -.48042500E+02, -.71080500E+02, -.10822100E+02, 0.38502600E+02, -.11190000E+01, -.37561400E+02, 0.20306700E+02, -.42452600E+00, -.37861100E+02, 0.29544500E+00, 0.24685700E+02, -.40935900E+02, -.11983300E+02, 0.24075800E+02, 0.13746500E+01, 0.85711900E-02, 0.10963300E+01, 0.20570100E+02, -.42211700E+01, 0.21242000E+02, -.23758200E+03, -.31383800E+02, 0.24067600E+02, 0.14172100E+02, 0.12063500E+02, 0.60153000E+02, 0.17892300E+01, -.31799100E+02, -.33518400E+02, -.23155400E+02 },
            { -.19171400E+01, -.54967200E+00, 0.61126300E+00, 0.61480200E+00, 0.31775200E+01, 0.40049300E+00, 0.10606400E+01, -.22074800E+00, -.20631300E+01, 0.54188000E+00, 0.68335500E+00, 0.97047400E+00, 0.83622500E-01, -.21324000E+00, -.16800000E+00, -.20506100E+00, 0.32083100E+00, -.91397800E+00, -.11421400E+01, 0.40422500E+00, 0.12186100E+01, 0.33244900E+00, -.14554700E+01, 0.34820900E+01, 0.24571700E+00, -.63882500E+00, -.44032300E+00, 0.11032200E+01, -.35392300E+00, 0.90598700E+00, -.82486200E-01, 0.53715600E+00, -.32449300E+00, 0.22108300E+00, 0.17837700E+00, -.85263000E-01, 0.88181600E-01, -.39098000E-01, -.45196400E-01, 0.87269900E+00, 0.25446900E+00, -.50243700E+00, -.94231100E+00, -.77238600E+00, 0.42880000E+00, -.10132400E+01, -.36259200E+00, -.36600600E+00, -.22274000E+01, 0.14274800E+00, 0.14139900E+01, 0.38024800E+00, 0.10912500E+01, -.10336300E+01, -.85657700E-01, -.11542300E+01, 0.31846500E+01, 0.90417100E-01, -.10693000E+01, 0.86235200E+00, 0.20574500E+00, -.95621700E+00, 0.53842500E+00, 0.68368500E+00, 0.61321800E+00, -.10550000E+01, 0.35743700E-01, -.14515300E+00, 0.19185400E+00, 0.21767000E+01, -.72307800E+00, 0.43324500E+00, 0.80501100E+00, 0.96272700E-02, -.88298000E-02, 0.87407200E-01, 0.30859600E+00, -.28960500E+00, -.93928600E+00, -.63834500E+00, 0.41895000E+00, -.38118800E+00, -.74182400E+00, 0.12849500E+00, 0.37733200E-01, 0.46226400E+00, -.44593800E+00, 0.32808800E+00, -.12747300E+01, 0.36801100E-01, 0.47373500E-01, -.16952300E-01, -.11069000E-01, -.29506800E+00, 0.51836100E+00, -.72858000E+00, -.12431400E+01, -.16802500E+01, 0.16783500E+00, 0.23621800E+00, -.71078600E-01, -.11765200E-01, 0.14148300E+00, 0.35837300E+01, -.12855800E+01, -.19072500E+01, -.89798000E+00, -.68757600E-01, 0.40481700E+01, 0.44112000E+00, 0.14944000E+01, 0.12167900E+01, -.40396500E+00, 0.74518500E+00, -.31221400E+01, -.57696200E-01, 0.22894500E+01, -.82232500E+00, 0.82028800E+00, -.65912300E+00, 0.37391600E+00, -.30881900E+00, 0.60734900E+00, 0.31420500E+00, 0.11359200E+01, -.12013200E+01, -.12030300E+01, 0.27363500E+00, 0.11748500E+01, 0.97225200E+00, -.28030100E-02, -.32806000E+00, 0.34219100E+00, 0.17155400E+01, 0.13311900E+01, 0.36187800E+00, -.32622100E+02, 0.21792400E+02, -.91417900E+01, -.96439200E+02, 0.42013500E+02, 0.54341900E+02, 0.35380700E+02, -.40484900E+02, -.32754600E+02, 0.10130600E+02, 0.16484300E+02, 0.17824200E+02, -.16328300E+02, 0.16831400E+02, 0.89819300E+01, 0.18063200E+02, 0.11418900E+02, -.52409300E+01, 0.53282000E+01, 0.42077700E+01, 0.58814200E+01, 0.75209300E+01, -.20991700E+02, -.57458100E+02, -.31064500E+02, 0.17581400E+02, 0.54362100E+02, -.28151300E+02, -.29458500E+02, -.59955500E+01, 0.11046400E+02, -.17769900E+02, 0.16287400E+02, -.23320700E+02, -.15263800E+02, 0.32441000E+02, -.15675100E+02, -.16137500E+02, -.73329400E+00, 0.38046500E+01, -.78110900E+01, 0.54255700E+02, 0.55774300E+01, -.75719600E+01, 0.20157300E+01, 0.32020500E+01, 0.14511800E+01, -.94764100E+01, 0.64368700E+02, -.34858300E+02, 0.78393900E+01, -.61450100E+02, 0.69297400E+02, -.44083700E+02, 0.15399900E+02, 0.18880000E+02, 0.15009100E+02, 0.20608700E+02, 0.58570900E+01, -.27393300E+02, -.21528700E+02, 0.27658800E+02, 0.10713100E+03, -.64108600E+02, -.50294700E+02, -.10559500E+00, -.19706300E+02, -.40135800E+02, -.94627000E+02, -.12289700E+02, -.44369300E+02, 0.47338800E+02, -.24638900E+02, -.23551200E+02, -.19839800E+02, -.20153200E+01, -.27084500E+02, -.28582200E+02, -.26274600E+02, 0.24389900E+02, 0.11205400E+02, -.58853900E+01, 0.95058600E+00, -.37707300E+01, -.13898600E+02, 0.82864900E+01, 0.89214000E+01, 0.23602900E+02, -.12251900E+02, 0.37929100E+01, -.57214300E+01, 0.60006000E+01, -.56157700E+00, -.13343600E+02, -.20103700E+01, 0.11308000E+02, -.50251900E+01, -.82446600E+01, -.14120400E+02, 0.34524400E+01, -.47470700E+00, 0.34368700E+01, -.54071700E+00, 0.72324400E+01, 0.31243400E+01, -.62294300E+02, -.42204700E+02, 0.25170300E+01, 0.13960800E+02, -.13120900E+02, 0.25820100E+02, -.30888300E+01, -.56819900E+02, -.51006100E+02, 0.26357600E+01 },
            { 0.21029900E+01, -.88923900E+00, -.13845500E+01, 0.74323600E+00, -.18566900E+01, 0.55865100E-01, -.77882900E+00, -.12609700E+00, -.22533600E+00, -.84006000E+00, 0.70931700E+00, -.16397700E+01, -.11733500E+01, 0.40776500E+00, -.10285800E+01, 0.67574200E+00, -.12050200E+01, 0.70894800E+00, -.57422500E+00, 0.10161900E+01, -.12900800E+00, 0.15645200E+01, -.60684800E+00, 0.32792200E+01, -.17824400E+00, -.61741100E+00, -.38491600E+00, 0.46288000E+00, -.51156000E+00, -.34567900E+00, -.59795000E+00, 0.88161700E+00, -.20582400E+00, 0.88625100E+00, 0.25131900E+00, 0.35659400E+01, 0.72022500E+00, -.28424100E+00, -.40317300E+00, 0.39202100E+01, 0.32173300E+01, -.11423300E+01, -.60697900E+00, -.10984100E+01, 0.32559700E+00, -.55827400E+00, -.33708300E+00, -.32824300E+01, -.18905900E+01, -.54106400E+00, 0.14957300E+01, -.40533400E+00, -.48225900E+00, -.75186000E+00, 0.50615400E+00, -.14747300E+01, 0.17634500E+01, -.10400300E+00, -.72313100E+00, -.64708600E+00, -.16616700E+01, 0.11242000E+00, 0.33484900E+00, -.25812400E+00, 0.91001700E-01, -.45692000E+00, -.14588500E+01, 0.16744100E+01, 0.17002400E+00, -.74345200E+01, 0.10777700E+00, 0.50386800E+00, 0.83838700E+00, -.26795300E+00, 0.34261600E-01, -.11353600E+00, 0.40009300E+00, -.22763400E+00, 0.62403300E-02, -.29280700E+00, 0.10921600E+01, 0.51726500E+00, -.21505800E+00, 0.32757800E+00, 0.18945900E+00, -.35673200E+00, 0.20240200E+01, 0.23895400E+00, 0.49555100E+01, 0.78965100E-01, -.48045500E-01, 0.10421000E+00, 0.27342500E-02, -.67925700E+00, -.14164100E+01, 0.10371100E+01, 0.10298900E+01, 0.32755000E+01, -.76720900E+00, -.57573800E+00, 0.35006300E+00, 0.20792700E+00, 0.14156400E+01, -.29122500E+01, 0.11874800E+01, 0.17891700E+01, 0.10306300E+01, 0.42827100E+00, -.22986300E+01, 0.19109000E-01, -.84380300E+00, -.14728200E+01, -.20195000E+00, 0.17042300E+01, 0.12723900E+01, -.28312000E-01, -.13014700E+01, 0.92666400E+00, -.10799100E+00, 0.26762100E+00, -.20316900E+00, 0.10201800E+01, 0.65053900E-01, -.23558600E-01, 0.66490400E+00, 0.38230600E+00, -.40141300E+00, -.38209600E+00, -.11233900E+01, -.70677100E+00, 0.71050200E-01, 0.28443600E+00, 0.31691600E+00, -.16432700E+01, -.86941900E+00, 0.15657800E+00, -.47590700E-01, -.57089800E+02, 0.24698600E+02, 0.44918200E+02, -.26803700E+02, -.94466100E+02, -.72574800E+02, 0.49298600E+02, 0.85552200E+02, -.42767500E+02, -.47094400E+02, 0.48572500E+01, -.15797800E+02, -.28917900E+02, -.73906300E+01, 0.67950400E+01, -.85657900E+01, 0.77620000E+02, -.39005100E+02, -.47725400E+02, -.92454200E+01, -.18633400E+02, -.14700700E+02, -.12120900E+02, -.10320200E+02, -.96843500E+01, 0.15996800E+02, -.75138000E+01, 0.48805500E+01, -.31487400E+01, 0.59665200E-01, -.10175700E+02, -.26261700E+02, 0.23123300E+02, -.38375100E+01, 0.89277800E+02, -.44669900E+02, -.42133000E+02, 0.25764200E+02, 0.59099700E+01, -.32682200E+02, -.10296400E+02, -.15925100E+02, -.60987800E+01, 0.19182400E+02, -.10853800E+02, -.18057300E+02, 0.26098900E+02, 0.30794300E+02, -.10083700E+02, -.18045600E+02, -.17903500E+02, 0.17309400E+02, -.25311700E+02, 0.14402000E+02, 0.17879300E+02, 0.31019000E+02, -.63448200E+00, -.11533500E+02, -.15962100E+02, 0.10087800E+02, 0.59678900E+01, -.12158400E+03, 0.63160900E+02, 0.56204900E+02, 0.20460900E+02, -.14233700E+02, 0.18507700E+02, 0.15966000E+02, 0.90030700E+02, 0.14248700E+02, -.12387300E+02, 0.61653900E+01, 0.54737900E+01, -.38523500E+00, -.31641600E+01, -.42899400E+01, -.32365200E+02, -.13735400E+02, 0.89334100E+01, -.61095000E+02, 0.30283000E+02, 0.57193200E+01, -.32652400E+02, 0.18529200E+02, 0.35079700E+02, 0.34717400E+02, 0.28081800E+02, -.18614900E+02, 0.10785800E+01, 0.10440700E+02, -.77678100E+01, 0.96475800E+00, 0.20690400E+02, -.23694000E+01, 0.63986800E+01, 0.96741000E+01, 0.45040100E+01, -.14309800E+02, -.35117400E+00, 0.26897700E+00, 0.46516600E-01, -.12250400E+02, 0.83703400E+01, -.78333400E+01, 0.45285700E+02, 0.68827300E+01, -.11098600E+02, -.11908800E+02, -.15162400E+01, 0.36879400E+01, 0.35253300E+01, 0.29779800E+02, -.23288800E+02, 0.19202900E+01 },
            { 0.16991300E+01, 0.30927900E-01, -.95980400E+00, 0.58694200E+00, -.12422400E+01, -.27575900E+00, -.49896300E+00, -.30741300E+00, 0.86938400E+00, -.27315100E+00, 0.54195600E-02, -.35086500E+00, 0.65866500E+00, -.14193700E-01, 0.23618000E+00, 0.28154000E-02, -.23912400E+00, 0.41456100E+00, -.13970800E+00, -.10053600E+00, -.87080600E-01, -.24737700E+00, 0.88190800E+00, -.17986600E+01, -.25178300E-01, -.19133700E+00, -.33459600E+00, -.30232300E+00, -.15678400E+00, 0.12812600E+00, 0.26748500E+00, -.24239300E+00, 0.83944200E-02, -.56987100E-01, -.62337700E-01, 0.15676800E+01, 0.15511100E+00, -.61541800E-01, -.89035000E-01, 0.11393400E+01, 0.12816300E+01, -.13867700E+00, 0.14095200E-01, 0.43809300E-02, -.16540300E+00, -.18385400E+00, 0.20597800E+00, 0.10172600E+01, -.58907100E+00, -.16593200E+00, -.16479100E+01, 0.11121100E+00, -.23129800E+00, 0.13243000E+00, -.18638000E+00, 0.11701900E+00, -.28711000E+00, 0.49908600E-01, -.64101800E-01, -.25002400E+00, -.78065300E+00, 0.67265200E+00, -.24363100E+00, -.25138900E+00, -.69812500E-01, 0.39924600E+00, -.63630900E+00, 0.13516200E+01, 0.48989500E+00, -.18886400E+01, -.54050700E+00, -.32847400E-01, 0.26808000E+00, -.14960700E+00, -.28403300E-01, -.28606800E-01, 0.21236700E+00, 0.29610600E+00, 0.11120100E+01, 0.48810900E+00, -.29910900E+00, 0.63760900E+00, 0.95466600E-01, -.20873200E+00, -.12742100E+00, -.32116700E+00, 0.29925300E+00, -.21404200E+00, 0.18621900E+01, 0.42602100E-01, 0.60464500E-01, -.27622200E-01, -.10245600E+00, 0.26603400E-01, -.51413500E+00, -.73944200E-01, 0.10063300E+00, 0.13824100E+01, -.17091200E+00, -.28001700E+00, 0.50115500E-01, -.82375300E-01, -.70406100E-01, -.21559400E+01, 0.81080100E+00, 0.31030100E+00, 0.92812300E+00, -.59025000E+00, -.36177300E+01, -.20867500E+00, 0.32988400E-01, -.31388500E+01, -.62701900E+00, 0.21141700E+01, 0.30926900E+01, 0.43177500E+00, -.68556600E+01, 0.78758300E+00, -.44546500E-01, 0.27290200E+00, 0.11271700E+00, 0.40531800E+00, 0.21117800E+00, 0.70888200E+00, 0.28182900E+00, 0.54708400E+00, 0.76825300E-01, -.23548900E+00, 0.16883700E+01, 0.13107100E+00, 0.12858000E+00, 0.78762900E+00, 0.57469900E+00, -.10037900E+01, 0.11536500E+01, -.53402600E+00, -.26645100E+00, -.11826600E+00, -.67723000E+02, -.17503700E+02, 0.90020500E+01, -.14178600E+03, -.50156700E+02, -.11690800E+01, 0.10397900E+03, -.44454100E+02, -.52936100E+02, 0.36692700E+01, 0.33625300E+02, -.40633100E+02, -.12114800E+02, -.63480300E+02, 0.31136000E+02, 0.92417000E+02, -.48762000E+02, -.38211700E+02, -.21793500E+02, -.13345500E+02, -.31635700E+02, -.23212500E+02, -.46316600E+02, -.38189100E+01, 0.40685100E+02, -.18566800E+02, -.10966100E+02, -.35230400E+02, 0.10465000E-01, -.13696800E+02, 0.17488500E+02, -.38700300E+02, -.15375600E+02, 0.24429800E+02, -.10587100E+02, -.12491200E+02, -.56571600E+01, 0.99218600E+01, -.17189500E+02, -.67117500E+01, -.71578000E+01, -.10633400E+02, -.73970600E+02, 0.36807800E+02, 0.36474500E+02, 0.84020100E+02, 0.82933700E+02, -.47237000E+02, -.32416000E+02, -.57838400E+02, 0.91058600E+02, 0.10774200E+03, -.58051500E+02, -.68964300E+02, 0.53015900E+02, -.18970900E+02, -.22830500E+02, -.31666800E+02, -.74308500E+02, -.41841700E+02, 0.17843400E+03, -.94593000E+02, -.87871500E+02, -.11607600E+02, -.43944100E+02, -.29384200E+02, -.77568600E+02, -.48833900E+02, -.75497700E+02, -.22126500E+03, 0.11028100E+03, 0.11101500E+03, 0.17261200E+02, 0.42230600E+01, 0.60066100E+02, -.26136200E+02, 0.77259700E+02, 0.30182900E+02, 0.93095500E+02, -.45555500E+02, -.47460800E+02, -.36366200E+02, 0.34659000E+01, -.42571700E+02, -.23433700E+02, -.31317400E+02, -.27326200E+02, 0.80757000E+01, -.40343500E+02, 0.13648600E+02, -.79165600E-01, -.32599400E+02, -.56003300E+01, 0.11633500E+03, -.38933200E+02, -.20596700E+02, -.23915700E+02, 0.89734700E+01, -.55454100E+00, 0.86441400E+01, 0.12316300E+02, -.12338200E+02, 0.12487800E+02, 0.17012500E+03, 0.22444300E+02, -.35740500E+01, 0.24533700E+02, 0.15310300E+02, 0.73878100E+02, 0.32776600E+02, -.40419500E+02, -.11185300E+03, -.59706300E+02 },
            { -.66443400E+00, -.32884900E+00, 0.13515600E+00, 0.30020300E+00, 0.16574800E+01, 0.24001000E+00, 0.34781200E+00, -.67093700E-01, -.55903000E+00, 0.25214100E+00, 0.76245900E+00, 0.61055200E+00, 0.11034700E+00, -.32279800E+00, 0.10300800E-01, -.20325000E+00, 0.56139800E+00, -.19041000E+00, -.44898800E+00, 0.37621200E+00, 0.44796500E+00, 0.85292900E+00, 0.52513800E+00, 0.59063600E+00, 0.94257400E-01, 0.22068700E+00, -.15932100E+00, -.36536800E-01, -.17713600E+00, -.34666300E+00, -.22660100E+00, 0.99670600E-01, 0.24607500E+00, 0.18538400E+00, -.32602500E+00, 0.26559100E+00, 0.40745200E-01, -.17955800E-01, -.69885800E-02, 0.10453900E+01, 0.50883700E-01, -.22118500E+00, -.28294300E+00, -.11051400E+00, -.14856200E+00, -.35503600E+00, -.94388300E-01, -.31247200E+00, -.42477600E+00, -.32950300E+00, 0.33387100E+00, -.33870400E+00, 0.29676400E+00, 0.71636700E-02, -.39100400E+00, -.80226800E-01, 0.11721600E+01, 0.19909700E+00, 0.39387200E+00, 0.36762300E-01, 0.25693400E+00, -.26877900E+00, 0.36747400E+00, -.29406800E+00, -.25204200E+00, 0.51965400E+00, 0.15198000E+01, -.25276600E+00, 0.19980500E+00, -.35020400E+01, 0.45351500E+00, 0.29120900E+00, -.20065100E+00, -.31056000E+00, -.10812800E+00, -.68199500E+00, 0.79590500E-02, 0.33234800E+00, -.62397900E+00, -.11726400E-01, 0.36495900E+00, -.19183100E+00, 0.76090900E+00, 0.11816500E+00, -.18659000E+00, 0.79014000E-02, -.12304600E+01, 0.50682100E-01, -.78335300E+00, -.39799700E-01, 0.25937800E+00, -.13516000E+00, -.20578500E+00, -.30876700E+00, -.33151700E+00, -.46933500E+00, -.73827700E+00, 0.85638900E-01, -.28172000E+00, 0.22208600E+00, -.12838400E+00, -.20345800E+00, 0.10541300E+01, 0.17660600E+00, -.35979200E+00, -.93495100E-01, -.74958700E-01, 0.38828900E+00, -.26436400E+01, -.40386000E-01, -.40271900E+00, -.53827900E+01, 0.80060900E-01, 0.69115900E+00, 0.13176700E+01, -.24525700E+00, 0.16562100E+01, -.35802700E+00, -.20465400E+00, 0.21911200E+00, -.14183900E+00, -.10776300E+00, 0.27330200E+00, -.20350400E+00, -.33987700E+00, -.13956000E+00, 0.89769400E-03, -.44657800E-01, -.38563000E-01, 0.12367200E+00, -.19485600E-01, -.25303000E+00, -.63647100E-01, 0.77179000E-01, 0.16943900E+00, 0.24075500E+00, -.75302700E-01, 0.31511900E+00, -.21267100E+00, 0.10496200E+03, -.49259400E+02, -.12833000E+03, -.67893400E+02, 0.72495900E+02, -.54337600E+01, 0.30108100E+01, 0.41135600E+01, -.26185100E+02, 0.10273200E+02, -.81510400E-01, -.50617200E+01, -.13184400E+01, 0.93032100E+01, 0.38172900E+02, -.19255100E+02, -.19247900E+02, -.13364100E+02, -.57894800E+01, -.10612200E+02, 0.76223700E+01, -.41600600E+01, -.65125500E+01, -.74332500E+01, 0.36401100E+01, 0.54604400E+01, 0.80016800E+01, 0.30818600E+01, -.89478900E+00, 0.18423800E+01, -.72399200E+01, 0.53602800E+01, 0.22176700E+02, -.10935800E+02, -.13226700E+02, 0.59487900E+01, 0.95724100E+00, -.10611800E+02, -.93941100E+01, -.13952500E+02, -.69346100E+01, -.20912100E+02, 0.11016600E+02, 0.10663000E+02, 0.37241700E+01, -.26755000E+01, 0.74119700E+01, 0.15761600E+01, -.59858900E+01, -.47388600E+01, 0.51567300E+02, -.27199100E+02, -.25535100E+02, 0.40848100E+01, -.10590600E+02, -.12724800E+02, -.64885400E+01, -.13060800E+02, -.10419200E+02, 0.39029800E+02, -.21097700E+02, -.16611000E+02, -.55354700E+01, -.83744600E+01, -.70641800E+01, -.45701200E+01, -.18092300E+02, -.97707200E+01, -.44594500E+02, 0.22206300E+02, 0.22802300E+02, 0.88652800E+01, 0.62835500E+00, 0.12721100E+02, 0.18339600E+01, 0.18920200E+02, -.16465300E+01, 0.23236700E+02, -.11419300E+02, -.73774700E+01, -.19979400E+02, -.35633900E+01, -.33628000E+01, 0.83637900E+01, -.10067200E+02, -.11052300E+02, 0.93307000E+00, -.24135600E+01, -.12883900E+00, -.35995800E+00, -.16788200E+00, -.24797500E+00, 0.19326600E+02, -.90856300E+00, -.15067300E+01, -.13552200E+02, 0.14590600E+01, -.25130700E+00, 0.12209200E+01, 0.76259900E+00, -.23238300E+01, -.23909100E+01, 0.11992300E+03, 0.31153400E+02, -.65552000E+01, 0.23464100E+01, 0.17504600E+01, 0.30263600E+01, 0.48479100E-01, 0.26868600E+01, -.76284300E+01, -.53113600E+01 },
            { 0.11481700E+01, 0.14530700E+00, -.30823800E+00, -.42321100E+00, -.26407700E+01, -.32930700E+00, -.42829900E+00, 0.91929300E-01, 0.67527300E+00, -.27903400E+00, 0.30344200E+00, 0.36581400E+00, 0.80678700E+00, -.11223800E+01, 0.40677600E+00, -.93281900E-01, -.22338500E-01, -.29292300E+00, 0.39198100E+00, -.10315000E+00, -.55132000E+00, -.76668200E-01, 0.48168000E+00, -.11104000E+01, 0.14217700E+00, 0.34624800E-01, 0.96855400E-01, -.15157200E+00, -.99081700E-01, -.31351600E-01, 0.82916400E-01, -.50255600E+00, 0.19714000E+00, 0.14436000E+00, -.50683100E-01, 0.12352600E+01, -.31092700E+00, 0.12031600E+00, 0.19324000E+00, 0.46771600E+00, -.24101700E+01, 0.67779600E+00, 0.87596200E+00, 0.11594000E+01, -.86856000E+00, -.29352100E+00, 0.23800000E+00, -.61801500E+00, 0.70023800E+00, -.30535600E+00, -.36800800E+00, 0.44201500E+00, -.41758400E+00, -.18271700E+00, 0.11675000E+00, -.17630900E+00, -.17347900E+00, -.40002900E-01, -.12906300E+00, -.18124100E+00, -.70577900E+00, 0.41265000E+00, 0.36879800E+00, 0.10184400E+00, 0.33697200E-01, -.29886100E+00, -.65340600E-02, -.15784300E+00, -.35493100E-01, 0.22423000E+01, 0.18557000E+00, -.45009400E+00, -.29841900E+00, 0.22276400E-01, -.62562300E-01, -.44409700E+00, -.80119500E-01, -.81625300E-01, 0.28721500E+00, 0.96167800E-01, 0.50903000E+00, 0.33556400E+00, -.15259300E+00, -.84413100E-01, 0.29476600E-01, -.73396000E-01, -.10076000E+01, -.21398700E-01, -.12349500E+01, -.20334400E-02, 0.19655800E+00, -.51189200E-01, -.18923400E+00, 0.10950600E-01, -.31767900E-01, -.73391000E+00, -.11062500E+01, -.64013700E+00, -.15200700E+00, 0.15649900E+00, 0.15778200E-01, -.20627300E+00, 0.83609300E-01, -.18025500E+00, -.47582100E+00, -.85719500E+00, -.89583500E+00, 0.14218700E+01, -.94542100E+00, -.84653200E-01, 0.14581800E+00, -.70679500E+00, 0.58443800E+00, -.51935400E+00, -.79062000E+00, -.23744700E+00, -.19495400E+01, -.28870900E+00, -.11412900E+00, 0.21165200E+00, -.42572200E+00, -.68871300E+00, -.74671700E-01, -.47776800E+00, -.22831700E+00, -.44177800E+00, -.94834700E+00, 0.46230600E-01, 0.62404100E+00, -.25355500E+00, 0.89396000E-01, 0.25013300E+00, -.26926100E+00, -.58789400E+00, -.47005800E+00, -.69432200E-01, -.17439700E-01, 0.26732100E+00, -.87328100E-02, 0.19384100E+00, -.26570000E+02, -.54939200E+02, -.69498800E+01, 0.15031400E+02, 0.79722500E+02, -.46989800E+02, -.40752800E+02, 0.32891400E+02, -.51981400E+01, -.41960100E+02, -.41001900E+02, -.33943100E+02, -.38204300E+01, 0.27558900E+02, -.13501300E+02, 0.20769700E+01, -.18332400E+02, -.13338000E+02, 0.69054400E+01, 0.25367200E+02, 0.54888300E+01, 0.12440100E-01, -.47293000E+02, 0.23455800E+02, 0.31837200E+02, -.61359400E+01, -.54166200E+01, 0.14443100E+02, -.58189800E+01, 0.18470300E+02, -.65258000E+01, -.44842200E+02, 0.20895700E+02, 0.22762700E+02, -.93888300E+01, -.96388800E+01, 0.19191100E+02, -.14489300E+02, 0.12300800E+02, 0.94190200E+01, -.59436700E+02, 0.27227900E+02, 0.29414000E+02, 0.94246400E+01, -.19827900E+02, 0.35253900E+02, 0.28332800E+00, 0.62264800E+02, -.82072700E+01, 0.15502700E+02, -.25221700E+01, -.26325900E+02, 0.16673200E+02, -.23249800E+02, 0.10241400E+02, 0.26592200E+02, 0.20239700E+02, -.12707400E+02, -.11458000E+03, 0.64993600E+02, 0.53592500E+02, 0.17098000E+02, 0.67642100E+01, 0.35176700E+02, 0.44227700E+02, 0.35653600E+02, 0.31940200E+02, 0.52913200E+02, -.26187100E+02, -.27726300E+02, 0.21291200E+02, 0.17711200E+02, -.22389700E+02, -.14923900E+02, -.44199800E+02, 0.15222300E+02, 0.21526600E+02, -.11247800E+02, -.11990600E+02, -.24820100E+02, 0.19085900E+02, -.27297100E+02, -.11296500E+02, -.26561500E+02, -.17860900E+02, -.78478800E+00, 0.54534900E+00, 0.22926600E+01, -.11560200E+00, 0.14327700E+02, 0.14788700E+01, 0.13704800E+02, -.32601400E+01, 0.52691800E+01, 0.13088600E+02, -.14392900E+01, 0.12126100E-01, -.14638000E+01, 0.41475100E+01, -.88792200E+01, 0.13051100E+02, -.36311800E+01, -.19311900E+02, 0.19559200E+02, -.12903400E+01, 0.65643700E+01, -.13451500E+02, 0.30522400E+01, 0.18876900E+02, -.28127800E+02, -.25137300E+02 },
            { -.32282100E+01, -.12360200E+01, 0.14245800E+01, -.12912200E+00, 0.48677300E+00, -.19374300E+00, 0.12297000E+01, -.56747300E-01, -.55401000E+00, 0.18251100E+01, 0.27930100E+01, 0.55405600E+01, -.12867500E+01, -.10096400E+01, 0.21148300E+01, -.94364400E+00, -.80767500E-01, 0.27818300E+00, -.23480000E+01, -.10075900E+00, 0.21813200E+01, 0.64732900E+00, 0.29425000E+00, -.69559300E+00, 0.24631300E+00, 0.27423600E+00, -.43199600E+00, 0.11322400E+00, -.65604900E+00, -.43153800E+00, -.13337200E+00, 0.81511200E+00, 0.51641200E+00, 0.35653600E+00, -.88223500E-02, 0.15587200E+01, 0.38656900E+00, -.16137800E+00, -.19006800E+00, 0.35937700E+01, 0.10400900E+01, -.78265100E+00, -.45661400E+00, -.86751400E+00, -.26401000E+00, -.90894700E-01, -.80341900E+00, 0.22507500E+01, -.46679500E+01, -.18375200E+00, 0.18432900E+00, 0.47031000E+00, 0.47062700E+00, -.89189400E+00, -.14822600E+00, -.78991900E+00, 0.33006900E+01, 0.16920100E+00, -.11424800E+01, 0.38862600E+00, -.21328800E+01, 0.30117600E-01, 0.14120900E+00, -.73711300E+00, -.29848700E+00, 0.12867100E+00, 0.10435700E+01, 0.24735200E+00, 0.19671500E+01, -.17736700E+02, 0.42500700E+00, -.10918000E-01, 0.12134300E+01, -.47894500E+00, -.41754700E-01, -.11960000E+01, -.28242400E+00, -.56845700E+00, -.47953600E+00, -.10459000E+00, 0.24369800E+01, 0.37279500E+00, -.58619200E+00, -.18007100E+00, 0.70321100E+00, 0.63200800E-02, 0.16050400E+01, 0.12149200E+01, 0.75139900E+01, 0.11141700E+00, 0.20869100E+00, 0.16476900E+00, -.23182600E+00, -.99525400E-01, -.16065000E+01, 0.97517700E+00, -.13436500E+00, 0.50661700E+01, -.83150800E+00, -.70943700E+00, 0.72519000E+00, 0.98193900E-01, 0.15702600E+01, -.52459400E+01, 0.11948000E+01, 0.21568700E+01, 0.22967300E+01, -.19598000E+01, -.57438900E+01, -.38683400E+00, -.35339600E+00, 0.48603500E+01, -.88494600E+00, 0.40641400E+01, 0.48017300E+01, 0.32355100E+00, 0.29969900E+01, 0.17633400E+01, 0.61854300E+00, -.15961700E+00, 0.14058500E+00, -.82863900E+00, -.19142100E+00, -.10568300E+01, -.19168600E+00, 0.84238500E+00, 0.45547800E+00, 0.62312100E+00, 0.15174600E+01, -.87321000E+00, -.15840600E+00, 0.95026000E-01, 0.45142200E+00, 0.53777400E+00, -.15239000E+01, -.11232900E+01, 0.10970200E+00, 0.48569900E+00, -.15844400E+01, -.11793700E+01, -.11164000E+01, -.22196200E+03, -.48739500E+02, 0.22621800E+02, 0.22664400E+03, -.12091000E+03, -.11271300E+03, 0.13726400E+03, 0.44358300E+02, -.13414300E+03, -.15898500E+03, -.16959600E+03, -.82911600E+01, 0.13050700E+03, -.70334700E+02, -.42240400E+02, -.58567100E+02, -.55610800E+02, -.66888200E-01, 0.81529600E+02, -.45843200E+02, -.95956700E+00, -.14049900E+02, 0.10181100E+02, 0.30175400E+02, -.55588400E+02, -.71593800E+01, -.18866100E+02, -.20178900E+00, -.29211900E+02, -.30953700E+02, -.12307200E+03, 0.61096000E+02, 0.55709200E+02, -.69919700E+02, -.20433100E+02, 0.20790200E+02, -.70880300E+02, 0.83224400E+02, -.23429600E+02, -.16932200E+03, 0.80423700E+02, 0.84834900E+02, 0.12847300E+03, 0.33958300E+02, 0.35633700E+02, 0.64155500E+02, 0.16875100E+02, 0.50873100E+02, 0.28553100E+03, -.14110100E+03, -.17629600E+03, 0.16793700E+03, -.75769500E+02, -.64408200E+02, 0.37112000E-01, -.14678000E+03, -.98506000E+02, 0.10093900E+03, -.47705500E+02, -.42617600E+02, -.42177600E+01, -.68603200E+02, 0.16772800E+02, -.14693600E+03, -.55451000E+02, -.52523400E+02, -.30019200E+03, 0.15083700E+03, 0.15162600E+03, 0.77642500E+02, 0.27893600E+02, 0.10275500E+03, 0.11694800E+02, 0.12169900E+03, 0.29835600E+02, -.64025600E+01, 0.44465800E+01, 0.15186400E+02, -.11909100E+03, 0.17662200E+02, -.24804800E+01, 0.21132700E+02, -.56569100E+01, -.83988800E+02, 0.21201600E+02, -.26580900E+02, 0.19850900E+02, -.70984200E+00, -.44055800E+02, -.78241800E+01, 0.17365100E+03, -.27364400E+02, -.38634900E+02, -.54112400E+02, 0.20708700E+02, -.15967000E+01, 0.19308500E+02, 0.31877300E+02, -.31959100E+02, 0.40720300E+02, -.35275000E+03, -.83152600E+02, -.19709300E+02, 0.40122400E+02, 0.58784600E+02, 0.42285300E+02, 0.58004100E+02, -.69403800E+02, -.13115100E+03, -.12142900E+03 },
            { -.55250900E+01, -.11886800E+01, 0.20292400E+01, -.82308800E-01, 0.34567500E+01, 0.42743700E+00, 0.23265700E+01, -.36865500E-01, -.23758200E+01, 0.18330100E+01, 0.23257100E+01, 0.57194100E+01, -.90612400E+00, -.11012900E+01, 0.11705600E+01, -.76198900E+00, 0.20843900E+00, -.51469200E+00, -.41320900E+01, 0.39992200E+00, 0.26644800E+01, 0.16086200E+01, -.53985500E+00, 0.20128500E+00, 0.51981700E+00, 0.34104300E-01, -.89137200E+00, 0.63098000E+00, -.10615600E+01, 0.12736800E+01, 0.86282900E+00, 0.13635700E+01, 0.23323600E+00, 0.63901200E-01, 0.18361400E+00, -.65356400E+00, 0.60784700E-01, -.34701500E-01, -.89341300E-02, -.32975000E-01, 0.47264500E+00, -.45756700E+00, -.85618200E+00, -.91407500E+00, 0.44968800E+00, -.39445900E+00, -.15242800E+01, 0.42667300E+01, -.55614600E+01, 0.38509200E+00, -.89305000E+00, 0.14940000E+01, 0.16168400E+01, -.15763000E+01, -.50504300E+00, -.27848900E+00, 0.54583900E+01, 0.33182200E+00, -.23576000E+01, 0.15900600E+01, -.13002300E+01, 0.50699800E-01, -.25446900E+00, 0.10391800E+00, -.60851900E+00, 0.59688900E+00, 0.20193400E+01, 0.75973000E+00, 0.17195200E+01, -.45109100E+01, -.92345800E+00, -.14119400E+00, 0.14516400E+01, -.11551300E-01, -.29129800E+00, -.87100600E+00, -.23028100E+00, -.58955700E+00, -.80838500E+00, -.83512900E+00, 0.20133900E+01, 0.16389200E+00, -.14772200E+01, -.39316800E+00, 0.36269700E+00, 0.77475600E+00, 0.50839300E+00, 0.16069500E+01, 0.61764000E+01, 0.12667500E+00, 0.35442700E+00, -.12447500E-01, -.41817500E+00, -.62685000E+00, -.16845600E+01, 0.13449100E+00, -.93065300E+00, 0.39699600E+01, -.80290200E+00, -.59501000E+00, 0.42764200E+00, 0.19235500E-01, 0.23258100E+01, -.19692900E+01, 0.95925500E-01, 0.47557600E+00, 0.14832300E+01, -.31102000E+01, -.30035500E+01, -.87988400E+00, 0.14473400E+01, 0.10329500E+02, -.38988800E+00, 0.57561300E+01, 0.13517100E+01, 0.29998200E+00, -.28058100E+01, -.33829500E+00, 0.28182200E+01, -.62371100E+00, -.70158100E+00, 0.15767000E+00, -.81692500E+00, -.99999600E+00, -.74727600E+00, 0.94656100E+00, 0.19598900E+01, 0.12222700E+01, 0.15673200E+01, -.92407200E+00, 0.68956700E-01, -.76616900E+00, 0.67831200E+00, 0.41678300E+00, 0.29609500E+00, -.36392600E+00, 0.15151800E+00, -.27536900E+01, 0.20718100E+01, -.42285100E+01, -.29021100E+00, -.57590100E+00, 0.24208100E+03, 0.16059300E+02, 0.60382600E+03, -.32586300E+03, -.31114800E+03, 0.46126500E+03, 0.45636000E+02, -.38415900E+03, -.57475000E+03, -.34156100E+03, -.10196100E+03, 0.79854500E+02, -.41747600E+02, -.90368800E+01, -.10548600E+02, -.44503900E+02, 0.22100400E+02, 0.67020600E+02, -.38275500E+02, 0.44906700E+02, -.19369400E+03, 0.91961800E+02, 0.11458000E+03, 0.19827200E+02, -.60809100E+02, 0.38151900E+02, -.89017000E+01, 0.13672400E+03, -.25393500E+02, 0.47869500E+02, -.28865800E+02, -.17769400E+02, -.38610200E+02, -.51742000E+02, -.29092900E+02, -.96651200E+02, 0.60081100E+02, -.47849200E+02, 0.31496200E+03, -.16226600E+03, -.15830700E+03, 0.11146900E+03, -.13049500E+03, -.12660500E+02, -.82993700E+01, -.26830600E+02, -.79449100E+02, 0.19372000E+03, -.79403400E+02, -.14232100E+03, 0.12225400E+03, -.30172000E+02, -.87987300E+02, 0.23769300E+02, -.99224300E+01, 0.11958200E+02, -.72637500E+03, 0.38517800E+03, 0.35019700E+03, -.84496900E+02, -.17988400E+03, 0.33038200E+03, 0.14236900E+03, 0.40969800E+03, -.13443600E+02, -.94900300E+02, 0.51605100E+02, 0.46743900E+02, 0.39990800E+02, 0.10414900E+02, 0.32047100E+02, -.80722300E+02, -.73066100E+02, 0.69360800E+01, -.36648300E+03, 0.18341700E+03, 0.17199900E+03, -.11560500E+03, 0.68196700E+02, 0.91571600E+02, -.41173700E+02, 0.13598900E+03, -.53308400E+02, 0.27412200E+01, 0.62170600E+02, 0.15864800E+01, 0.75319300E-01, 0.97228300E+02, -.61097400E+01, 0.78034700E+01, 0.49853000E+02, 0.15886300E+02, -.38496600E+02, 0.17139200E+01, -.53478900E+00, 0.41395000E+00, 0.95762500E+01, -.10881200E+02, 0.45874300E+02, -.39283400E+03, -.28576900E+03, -.17229300E+02, -.40109900E+02, 0.65111400E+02, 0.38584500E+02, -.20479200E+02, 0.13253800E+03, -.18911600E+02, -.27723400E+02 },
            { -.74818400E+00, -.17173700E+00, 0.16173800E+00, 0.37089700E+00, 0.16772400E+01, 0.21424000E+00, 0.39414700E+00, -.78247600E-01, -.74267400E+00, 0.30766500E+00, 0.65468300E+00, 0.58991300E+00, 0.24949700E+00, -.28854000E+00, 0.26292100E-01, -.22282800E+00, 0.64019400E+00, -.74332500E-01, -.48288600E+00, 0.28960900E+00, 0.38607300E+00, 0.82082100E+00, 0.33554200E+00, 0.10145900E+01, 0.23071000E-01, 0.21072400E+00, -.38604300E-01, 0.11138700E+00, -.15675900E+00, -.25703100E+00, -.10312500E+00, 0.27531000E+00, 0.16895300E-01, 0.15110600E-01, -.34100200E+00, -.47907000E+00, 0.20772700E+00, -.80918000E-01, -.11549300E+00, 0.15839100E+01, 0.12495500E+01, -.51658400E+00, -.64165500E+00, -.66953600E+00, 0.30094700E+00, -.49922800E+00, -.90707600E-01, -.10337600E+01, -.86660900E+00, -.10970800E+00, 0.11464900E+01, -.30098800E+00, 0.33276100E+00, -.19223500E+00, -.23820000E+00, -.30967400E+00, 0.62435100E+00, 0.13967000E+00, 0.28819200E+00, -.22817800E+00, 0.42463000E-01, -.14545300E+00, 0.44643600E+00, -.14905600E+00, -.53247700E-01, 0.75684100E-01, 0.40812800E+00, 0.40407000E+00, -.17251100E+00, -.15120900E+01, 0.16032300E+00, 0.69200800E+00, 0.12983900E+00, -.15024900E+00, -.67798500E-02, -.15172300E+00, 0.19053400E+00, 0.10405300E+00, -.53792400E+00, 0.94859600E-02, 0.12395900E+00, -.11376900E+00, 0.34257000E+00, 0.13921200E+00, -.12185500E+00, 0.15822200E-01, -.76474500E+00, 0.55980500E-01, -.10770200E+01, -.72146400E-01, -.81013000E-02, -.32842900E-01, 0.64991400E-04, -.25484600E+00, -.18377000E+00, 0.90838100E-01, 0.19786800E+00, 0.18273400E+00, -.13753900E+00, -.83859400E-02, -.77919600E-01, 0.47159700E-02, 0.42571200E+00, 0.54257400E-01, 0.15835000E+00, 0.20611300E+00, 0.25158100E+00, 0.22095500E+00, -.76530100E+00, -.61788100E-02, 0.33519500E-01, -.15166600E+01, 0.10137300E+00, 0.17937100E+01, 0.46492600E+00, -.11637400E+00, -.11905700E+01, 0.10913000E+00, -.16955700E+00, 0.22280100E+00, -.11321300E+00, 0.23673900E+00, 0.15940100E+00, -.17206700E+00, -.16073200E+00, -.20287600E+00, -.15979100E+00, -.40886700E-01, 0.13260000E+00, 0.14888600E+00, 0.89980900E-02, 0.71394500E-01, -.15929900E+00, 0.49848000E-02, -.10485500E+00, -.25327900E-01, -.92058600E-01, -.50329700E-01, -.53260500E-01, -.62181800E-01, -.90556500E-01, 0.12114900E-01, 0.69693100E-01, 0.15985900E+02, -.12052500E+02, 0.73310700E+01, 0.59580500E+01, -.11365000E+02, 0.61405000E-01, 0.74898300E+01, 0.10415000E+02, 0.26443600E+01, 0.13646400E+02, -.99610500E+01, 0.52858600E+01, 0.75408000E+01, -.34529500E+01, -.13368000E+01, 0.33015600E+01, -.48027500E+01, 0.80523200E+00, 0.49087200E+01, 0.10880400E+02, -.52483800E+01, -.39315600E+01, -.45136800E+01, 0.38234900E+01, -.25864300E+00, 0.35828900E+01, 0.11796700E+01, -.85700800E+01, -.57131900E+01, 0.31354200E+01, 0.26570700E+01, -.18262700E+01, 0.31563700E+01, 0.35722000E+01, 0.94959300E+01, 0.98467500E+01, -.81669300E+00, 0.10651400E+01, 0.40106500E-01, -.57748500E+00, 0.15301500E+00, 0.11706700E+02, -.10139200E+02, -.99598300E+01, -.19797000E+02, 0.23570700E+02, -.25609600E+02, 0.11443000E+02, 0.92607200E+01, 0.19666400E+01, 0.11290300E+01, 0.64989800E+01, -.10921000E+02, 0.10004100E+01, 0.74802700E+01, 0.14994300E+02, -.90978700E+01, -.73065500E+01, -.24500200E+01, -.37564100E+01, -.49315000E+01, -.86189100E+01, 0.26009800E+01, -.13742700E+02, 0.11578000E+01, -.92600100E+00, -.69922700E+00, -.26620700E+01, -.60393100E+01, -.16673200E+01, -.45190600E+01, 0.31912700E+00, 0.80797400E+01, 0.15371100E+02, -.77672500E+01, -.74860400E+01, 0.23974600E+01, -.25381800E+01, -.26373600E+01, 0.22846700E+01, 0.27312500E+01, -.15177300E+01, -.13084000E+00, -.10220400E+01, 0.11110200E+01, 0.15956300E+00, -.57871100E+01, -.32329200E+00, 0.15467300E+01, -.70551400E+00, -.87464800E+00, -.16090900E+01, -.23577300E+00, 0.10403400E+00, -.16274100E+00, 0.18428800E+01, -.53454300E-01, 0.32034000E+01, 0.23977300E+02, 0.15372800E+01, 0.30163800E+01, 0.34435300E+01, -.50898100E+00, 0.15692400E+02, -.69089600E+00, -.67707800E+01, -.12040600E+02, -.51138000E+00 },
            { -.37766600E+01, -.21683900E+01, 0.89806900E+00, -.80554000E+00, -.27525400E+01, -.69405900E+00, 0.15574200E+01, 0.20581800E+00, 0.27230300E+00, 0.22768900E+01, 0.40910800E+01, 0.70975600E+01, -.17188400E+01, -.19993900E+01, 0.48611800E+01, -.14591300E+01, -.50259900E+00, 0.19105500E+01, -.38541600E+01, -.32593700E+00, 0.22102700E+01, -.12045400E+01, 0.70377900E+00, -.20393000E+00, 0.34473300E+00, -.20532100E+00, -.86067400E+00, 0.79742100E+00, -.11406700E+01, 0.90006900E+00, 0.17483400E+01, 0.12410800E+01, -.19274900E+00, -.40062700E+00, 0.14013200E+00, 0.42227900E+01, 0.50215500E+00, -.21000500E+00, -.27265700E+00, 0.50147400E+01, 0.81286400E+01, -.13188200E+01, -.19606200E+01, -.28411100E+01, 0.16370000E+01, -.35066900E+00, 0.31772900E+00, 0.42696700E+00, -.78318900E+01, 0.15107400E+00, -.99495100E+00, 0.19919100E+01, 0.62033400E+00, -.20617700E+01, 0.43136100E+00, -.20869200E+01, 0.96208100E+00, 0.34066600E+00, -.96632100E-01, 0.18311900E+00, -.14449000E+01, 0.28277100E+00, -.19477500E+00, -.13987300E+00, -.22888200E+00, 0.14227500E+01, -.12512000E+01, 0.94815400E+00, 0.27767300E+01, -.11357400E+02, -.14689500E+01, -.18025300E+01, 0.97690400E+00, -.93528900E-01, 0.11786000E+00, 0.39442500E+00, 0.22354400E+00, -.67419000E+00, 0.17626600E+01, -.30859000E-01, 0.97356400E+00, 0.11451400E+01, -.15551200E+01, 0.14537900E+00, 0.59441000E+00, -.43669000E+00, 0.40695900E+01, 0.14219300E+01, 0.77401000E+01, 0.27194500E+00, -.19158600E+00, 0.35116900E+00, 0.11987800E+00, -.59247000E+00, -.12076600E+01, 0.10420200E+01, 0.93263600E+00, 0.27277400E+01, -.76129500E+00, -.69659500E+00, 0.81257700E+00, 0.38455900E+00, 0.38865700E+00, -.20926000E+01, 0.13616700E+01, 0.58441500E+00, 0.27011300E+00, 0.12401000E+01, 0.50501400E+01, 0.10335000E+00, 0.86395600E+00, 0.69105700E+01, 0.23672700E+01, 0.42143300E+01, 0.27783300E+01, 0.30530400E+00, -.89684800E+01, -.20665600E+01, -.45588600E+00, 0.68380600E+00, -.68805000E+00, -.84797700E+00, -.35700000E+00, -.89610800E-01, 0.17045200E+01, -.14620500E+00, -.26278300E+01, -.49688600E+00, 0.27429000E+01, 0.95156400E+00, 0.14513200E+00, 0.19460700E+01, -.12792700E+01, -.15116800E+01, -.22742400E+01, -.78496600E+00, -.92879200E+00, -.49009900E+00, -.43177600E+00, -.25755300E+01, 0.15851900E+01, 0.73341300E+00, 0.54619600E+00, -.95453400E+00, -.50056800E+03, 0.25096600E+03, 0.25255700E+03, -.27083600E+03, -.54843300E+02, 0.26156900E+03, 0.23572500E+03, 0.29499000E+03, 0.65169300E+02, -.14769100E+03, 0.77079400E+02, 0.39297600E+02, 0.26465300E+02, 0.58708700E+02, -.25684500E+02, -.12865700E+03, 0.10059400E+02, 0.49512800E+01, 0.84737500E+02, -.42040300E+02, -.63810000E+02, 0.26011600E+02, 0.21835000E+02, -.77218600E+01, 0.44913400E+02, -.71676200E+02, 0.36809100E+02, 0.11778700E+02, -.47990200E+01, -.85999300E+01, 0.43979300E+02, 0.21657600E+02, 0.99479900E+01, 0.15964700E+03, -.57097900E+02, 0.16855300E+02, -.24259100E+03, 0.12563500E+03, 0.12157600E+03, -.12612700E+03, 0.10149300E+03, 0.23071300E+02, 0.27542700E+02, 0.30605000E+02, 0.69797100E+02, -.94800300E+02, 0.36855600E+02, 0.88887500E+02, -.95431200E+02, 0.75978900E+02, -.13126000E+02, -.11861100E+03, 0.10738500E+02, 0.10370900E+03, 0.46345700E+03, -.24138700E+03, -.22200500E+03, 0.91618400E+02, 0.90606600E+02, -.23435400E+03, -.11661700E+03, -.23656000E+03, -.44587700E+00, 0.11751000E+03, -.61598600E+02, -.56507200E+02, -.56447100E+02, 0.64496100E+01, -.61052900E+02, 0.39518000E+02, 0.54699200E+00, 0.46986000E+01, 0.75777500E+02, -.38609800E+02, -.34364000E+02, 0.61883100E+02, -.61729300E+02, 0.27522600E+02, 0.64552900E+02, 0.15463200E+02, 0.20745500E+02, -.56895800E+01, -.48615400E+02, 0.48331100E+01, -.29552800E+01, -.42490900E+02, 0.10940900E+02, -.28249400E+02, -.40944300E+02, 0.48840200E+01, 0.20075700E+02, -.41248600E+01, -.99590500E+00, -.36018100E+01, -.32200400E+02, 0.32900500E+02, -.33704500E+02, 0.18012200E+03, 0.14138400E+03, 0.21568700E+02, 0.65944100E+01, -.84066300E+02, -.33807500E+02, -.40568200E+02, -.95237400E+02, 0.14638100E+02, 0.57337700E+02 },
            { -.49159700E+01, -.53125600E+00, 0.18340200E+01, 0.22774300E+00, 0.76913800E+01, 0.95890900E+00, 0.22240500E+01, 0.14111300E+00, -.21374200E+01, 0.14437900E+01, -.20347300E+00, 0.73230900E+00, 0.98435500E-01, 0.45592400E+00, 0.37262400E+00, -.73935700E+00, 0.19322400E+01, 0.11442800E+00, -.35141200E+01, 0.44056800E+00, 0.42848100E+01, 0.19913500E+01, 0.41938500E+00, -.14701600E+01, 0.75390900E+00, 0.13978500E+01, -.11893600E+00, -.52358200E+00, -.12193700E+00, -.28376100E+00, -.11356500E+01, 0.14622300E+00, 0.80313000E+00, 0.90100100E+00, 0.30587400E+00, -.52011800E+01, -.47175200E+00, 0.18767600E+00, 0.30952800E+00, -.29823600E+01, -.12945900E+01, 0.61229100E+00, 0.12619300E+01, -.20349500E+00, 0.19328500E-02, 0.21216100E+01, -.21297600E+01, 0.24624900E+01, 0.14466900E+00, 0.11666300E+01, -.18341300E+01, 0.14677000E+01, 0.18674400E+01, -.59899600E+00, 0.23157700E-01, 0.21902600E+01, 0.10153700E+01, 0.79580400E-01, -.66934700E+00, 0.20318100E+01, -.36019000E+00, 0.76388200E+00, 0.23949500E+00, 0.21445000E+00, -.12196500E+01, 0.11408500E+01, 0.44230600E+01, -.70314700E+00, -.98606400E+00, 0.21688100E+01, 0.10542600E+01, 0.11508200E+01, -.82238400E+00, 0.27620000E+00, -.14838200E+00, -.22553200E+01, -.95098600E+00, -.37402800E+00, -.18784000E+01, -.17531500E+00, -.12385600E+01, -.70133500E+00, 0.63764100E+00, -.39384100E+00, -.43301100E+00, 0.48400500E+00, 0.92134500E-01, 0.10392100E+00, -.14335700E+01, -.59729700E-02, -.53761900E-01, -.11980700E+00, 0.24241400E+00, 0.11564700E+01, 0.12626600E+01, 0.65368400E-01, 0.22552600E+00, -.18280200E+01, 0.62730500E+00, 0.46500100E+00, -.44324500E+00, 0.12457900E+00, -.19976100E+01, -.22517100E+01, 0.22919800E-01, 0.51230300E+00, -.17013700E+01, 0.14351700E+01, 0.69758800E+01, 0.79642700E+00, -.11580100E+01, 0.69718000E+01, -.42008700E+00, -.72871900E+01, -.48795600E+01, -.17634200E+00, 0.11784300E+02, -.95944600E+00, -.10133100E+01, -.52395300E+00, 0.47249900E+00, -.89036600E+00, 0.30094500E+00, 0.16215000E+01, 0.32320600E+00, -.74403100E+00, -.21499100E+01, -.48549000E+00, -.11788600E+01, 0.12895400E+01, -.41670300E+00, -.35547200E+00, -.59014300E+00, 0.88641500E+00, -.12871400E+01, 0.57735200E+00, 0.13713100E+01, 0.16206400E+01, -.21145100E+01, 0.17348600E+01, -.95312400E+00, 0.46540500E+00, -.28880200E+00, -.32829100E+01, 0.45763300E+00, -.21973800E+02, 0.39589700E+01, -.35198800E+02, -.66019100E+01, 0.60683100E+01, 0.36398700E+02, -.50608100E+02, -.14850300E+01, -.11669300E+03, 0.69100000E+02, 0.63607600E+02, -.11576200E+02, -.51306500E+01, 0.70986400E+02, 0.12558000E+03, 0.49821400E+02, 0.10957500E+02, -.81778200E+02, 0.36027200E+02, 0.39603900E+02, -.21841700E+02, -.88409100E+01, 0.32456000E+02, -.41858000E+02, 0.37536000E+02, -.15768000E+01, -.18644100E+03, 0.90704600E+02, 0.90695500E+02, -.52708200E+02, 0.20339000E+01, 0.51845000E+02, -.12845300E+03, 0.41328200E+02, 0.52290500E+02, -.70201800E+02, 0.36057500E+02, 0.36151900E+02, 0.74645300E+01, -.10621000E+03, 0.65389100E+02, 0.23063100E+01, 0.16239100E+03, -.74015700E+02, 0.47689100E+02, -.15938900E+02, -.26633100E+02, 0.38812800E+02, -.60217900E+02, 0.19615400E+02, 0.72060300E+02, 0.23194700E+02, -.73344200E+02, -.20334200E+03, 0.11360400E+03, 0.10011600E+03, 0.32649900E+02, 0.61473200E+02, 0.85514900E+02, 0.12124500E+03, 0.22332500E+01, 0.69864500E+02, 0.15562600E+03, -.77043600E+02, -.77816600E+02, 0.44521100E+02, 0.21422200E+01, -.26575000E+02, 0.55216600E+02, 0.94172000E+00, -.30460400E+02, 0.13360700E+03, -.67548200E+02, -.61883200E+02, 0.18360900E+02, 0.23970500E+02, -.97332200E+02, -.58051900E+02, -.14414000E+03, 0.98237600E+01, -.17302600E+01, 0.20167500E+02, -.27437400E+01, 0.17752100E+01, 0.72433100E+01, 0.18975600E+01, -.10677400E+02, 0.16434600E+02, 0.93338600E+01, 0.40095000E+02, -.46799800E+01, 0.11744100E+01, -.42212700E+01, 0.25903700E+02, -.33049400E+02, 0.19964400E+02, -.19907200E+03, 0.13168400E+02, 0.29083400E+02, -.63014700E+01, 0.48001400E+02, -.39708500E+02, 0.26983100E+02, 0.43882600E+02, 0.46647300E+02, -.38547100E+02 },
            { -.25510700E+01, 0.49949200E+00, 0.14092900E+01, -.30690200E+00, 0.60534500E+00, 0.67956800E-02, 0.90383600E+00, 0.86148700E-01, -.78326600E+00, 0.84678600E+00, 0.83730600E+00, 0.25894300E+01, -.79025200E+00, -.28492100E+00, -.32502300E+00, -.10641300E+00, -.12748100E+00, -.37248700E+00, -.21430500E+01, 0.76263400E+00, 0.21341000E+01, 0.17840000E+01, -.15641900E+01, 0.21471100E+01, 0.74991300E+00, 0.81306700E-01, 0.13819300E+00, 0.70472800E+00, -.11700500E+00, -.48052300E-01, -.70847600E+00, -.81057700E-01, 0.37179300E+00, -.43642100E+00, -.19553100E+00, -.11464000E+01, 0.49198200E+00, -.19145800E+00, -.28991900E+00, 0.22014600E+00, 0.11345900E+01, -.94071700E+00, -.93666600E+00, -.12884600E+01, 0.43676500E+00, 0.31751800E+00, -.31910800E+00, 0.11597800E+01, -.38288500E+00, 0.58412500E-02, 0.71577600E+00, -.91922800E+00, 0.36869100E+00, 0.16450100E+00, -.22945300E+00, -.45808000E+00, 0.35681500E+01, -.26592300E-02, -.32084900E+00, 0.51263900E+00, 0.67262200E+00, -.65372500E+00, 0.10665400E+00, -.32367200E+00, 0.18306100E+00, -.69993800E+00, 0.54961600E+00, -.25725500E+00, -.35165200E+00, 0.15969100E+01, -.60489700E-01, 0.12231600E+01, 0.50505800E+00, 0.79677500E-01, -.23481800E-01, 0.94658100E-01, 0.15418300E+00, -.44751200E+00, -.15637400E+01, -.82449500E+00, -.68538000E+00, -.95318600E+00, -.39243900E+00, -.48304700E+00, 0.32662000E+00, 0.49300500E+00, 0.10680000E+01, 0.41012300E+00, 0.11066300E+01, 0.12635100E+00, 0.82027600E-02, 0.61349600E-01, 0.79145700E-01, -.78672500E+00, -.23185400E+00, -.26076100E+00, -.17480000E-01, -.77187000E+00, -.13545600E+00, 0.13527300E+00, 0.14210200E+00, 0.98524500E-01, -.10728700E+00, 0.19592400E+01, -.32760400E+00, -.72271700E+00, -.11548900E+01, 0.74163100E+00, 0.13779600E+01, -.21418700E+00, -.55486200E+00, -.37747500E+01, -.10827100E+00, -.59382200E+01, 0.35359500E+00, 0.57686400E+00, -.16510100E+01, -.10669200E-01, -.12871400E+00, 0.12450900E+00, 0.53218300E+00, 0.25451800E+00, 0.46127600E+00, -.33341200E+00, -.13021000E+01, -.13171100E+00, 0.11586500E+01, -.36441100E-01, -.10132600E+01, 0.31945800E+00, -.82369300E-02, 0.36899700E+00, -.65292000E+00, 0.73655400E-01, 0.97599500E+00, 0.43507100E+00, -.99904200E-01, -.12691600E+00, -.22112400E+00, 0.13346600E+01, 0.40621600E+00, -.52154200E-01, -.29528000E+00, 0.62579100E+00, -.29666300E+00, 0.22012200E+00, -.42803800E+01, 0.25028800E+02, -.15070700E+02, 0.41866700E+01, -.41478200E+02, 0.63198200E+02, -.30015700E+02, -.37752400E+02, 0.17058800E+02, 0.16115300E+01, 0.89390400E+01, 0.12731900E+02, -.11348300E+02, -.56608200E+02, 0.28445600E+01, 0.24977500E+02, 0.50498000E+02, -.26243000E+02, -.35542500E+02, 0.25253200E+02, -.14305000E+02, -.74083000E+01, 0.21582100E+02, 0.12779700E+02, -.17894600E+02, 0.11228700E+03, -.56639800E+02, -.51835600E+02, 0.41408800E+02, -.19234300E+00, -.43126500E+02, 0.22632200E+02, -.30686500E+02, -.19011500E+02, 0.24129900E+03, -.12048400E+03, -.12101700E+03, -.10383000E+01, 0.42276100E+02, -.11323200E+03, -.10087200E+03, -.18310200E+03, 0.34241600E+02, -.91869000E+02, 0.47149600E+02, 0.62682200E+02, -.38994200E+02, 0.42421100E+02, 0.93131800E+01, -.90339000E+01, 0.37775300E+02, 0.37939900E+02, 0.94749000E+02, -.46464000E+02, -.48663200E+02, -.50711000E+02, -.11427100E+03, 0.16280000E+02, 0.95910000E+02, 0.77741600E+02, -.10806300E+03, -.53531200E+02, 0.27418900E+02, 0.28293500E+02, -.44991200E+02, -.28715400E+02, 0.30049200E+01, -.65128400E+02, -.33682700E+02, 0.25130200E+01, -.25200400E+02, 0.12607000E+02, 0.45530400E+01, 0.15854900E+02, -.81210200E+01, 0.13736400E+02, -.28973300E+02, 0.45362900E+02, 0.73070600E+01, -.51404200E+01, 0.95911200E+00, -.77359900E+00, 0.16411300E+00, 0.51583800E+01, -.33402000E+01, -.82779400E+01, 0.10869100E+01, 0.67529700E+01, -.33863100E+02, -.20134600E+01, 0.94516300E-01, -.20689500E+01, -.10102200E+02, 0.10376600E+02, -.22008700E+02, 0.80297800E+02, -.18879300E+02, -.21682300E+02, -.12074000E+02, -.15446500E+02, 0.82450600E+02, -.23365500E+02, 0.68093100E+02, -.31439800E+02, 0.20228800E+02 },
            { -.13438300E+00, -.13501400E+00, -.14963800E+00, 0.34062800E+00, 0.40792000E+00, 0.50427100E-01, 0.73908700E-01, -.19421200E-01, -.65962300E-01, 0.12967500E+00, -.35271700E-01, -.37421500E-01, 0.23669300E+00, -.41907800E-01, 0.10920000E+00, -.91807700E-01, 0.20140600E+00, -.43108800E-01, -.10324400E+00, -.58861100E-01, 0.12272300E+00, -.10866800E+00, 0.82579800E-01, -.22833200E+00, 0.35295600E-01, 0.19534400E-01, -.28957700E-01, -.11660000E-01, -.63235600E-02, 0.65123700E-01, 0.21825700E-01, -.80292500E-02, 0.71999200E-02, -.53911400E-01, 0.77101700E-03, -.28390000E+00, 0.81802100E-01, -.32470500E-01, -.46917700E-01, 0.17205500E+00, 0.37325200E+00, -.12655900E+00, -.73712100E-01, -.15142500E+00, 0.61718500E-01, 0.96168200E-01, -.25281400E-01, 0.29281100E+00, -.64748500E-01, 0.41835900E-01, -.21072100E+00, -.56998300E-02, 0.58874000E-03, 0.70782800E-01, -.33834400E-02, 0.10819000E+00, -.18605000E+00, -.91848100E-02, -.27444200E-01, 0.61907300E-01, -.56095600E-01, 0.77359900E-01, -.53381800E-01, 0.62863000E-02, -.97582600E-01, 0.11916100E+00, 0.99052000E-01, 0.23535100E+00, -.39993300E-01, -.14566700E+00, 0.10062300E-01, 0.16723400E+00, -.11633300E-02, -.18813000E-02, -.33623000E-01, -.88827400E-01, -.80722100E-01, 0.68915800E-02, 0.34448600E-03, 0.37395200E-01, -.22406000E-02, 0.10195600E-01, 0.29660600E-01, -.52755600E-01, 0.69218900E-02, -.71828100E-02, 0.32730500E-01, -.53573900E-01, 0.16543500E+00, -.33714000E-02, 0.27054700E-02, -.25736500E-02, -.25337500E-01, 0.93208800E-01, -.41409000E-01, 0.60475000E-01, 0.82178500E-01, 0.19298900E+00, -.11650100E-01, -.25877400E-01, 0.31345300E-02, -.27968400E-01, -.79364500E-01, -.68702900E+00, 0.13101000E+00, 0.23522700E+00, 0.92317700E-01, 0.13702500E-01, -.10117700E+00, 0.22140900E-01, -.64024800E-01, 0.70368700E+00, 0.11811500E-01, -.12833800E+00, 0.63378800E-01, 0.65161400E-02, 0.13930400E+00, -.82786700E-01, 0.20415400E-01, 0.48539500E-02, -.48577100E-01, -.89361100E-01, 0.54868000E-01, -.17601200E+00, -.18001100E+00, -.47675100E-01, 0.13289200E-01, -.21374500E-01, 0.13108300E-01, 0.11774200E+00, 0.13680100E-01, -.43772900E-01, 0.68073500E-01, -.78119000E-01, 0.13757300E+00, 0.86885200E-01, -.15008600E-01, 0.62727000E-01, 0.50645900E-01, 0.16963000E+00, 0.33953600E-01, -.41965400E-01, -.26058200E-01, 0.79307600E-01, -.16683400E-01, 0.13314700E-01, -.30229300E-01, 0.90494100E+01, -.15549900E+01, -.19036700E+00, -.25057500E+01, 0.17962300E+01, -.47518200E+01, -.53304100E+01, 0.22929200E+01, 0.19632900E+01, -.15631500E+01, -.63642000E+00, 0.25152200E+01, 0.31222500E+01, 0.18200000E+01, 0.14775100E+01, 0.20343100E+01, -.10496900E+01, -.10658500E+01, 0.84646400E+00, -.75995900E+00, -.62924700E+00, 0.15724600E+01, -.15325800E+00, -.94235300E+00, 0.54761600E+01, -.27149200E+01, -.27124800E+01, 0.10063800E+01, 0.32406000E+00, -.31843400E+01, -.34120800E+01, -.93730600E+00, -.19778900E+01, 0.16815700E+02, -.83549400E+01, -.84426300E+01, 0.23894700E+01, -.66388800E+00, -.52439000E+01, -.34432000E+01, -.94749500E+01, -.15247800E+00, 0.51099800E+01, -.26089000E+01, -.18195200E+01, 0.10600000E+01, 0.86889900E+00, -.30759600E+01, 0.67316400E+00, -.49355200E+01, 0.42680400E+00, -.12305900E+00, -.23140600E+00, 0.29840400E+00, -.51748500E+01, -.65834600E+01, 0.40642300E+01, 0.36745600E+01, 0.38371000E+01, -.56332100E+01, -.19604600E+02, 0.99237300E+01, 0.99208000E+01, -.74365000E+00, -.19348800E+00, 0.56531200E+01, -.43293600E+01, 0.17240000E+01, 0.17250200E+01, -.53742000E+01, 0.27656400E+01, 0.26783400E+01, -.23787300E+01, -.89363400E+00, 0.32967900E+01, 0.28607900E+01, 0.78925400E+01, -.20636400E+01, 0.23726200E+00, 0.55976400E+00, 0.14952100E+00, -.21424900E-01, -.81551100E+00, -.26749100E+00, -.56364500E+00, 0.39089400E+00, -.89717300E+00, -.42050100E+01, 0.38824500E+00, -.36097600E-01, 0.34560100E+00, 0.54719200E+00, -.49030600E+00, -.65217800E+00, 0.72878500E+01, -.99628800E+01, -.31843100E+01, 0.31314200E+00, 0.11760300E+01, 0.49434600E+01, -.62274900E+00, 0.30828200E+01, -.66302200E+00, 0.15902000E+00 },
            { -.44256100E+01, 0.24347100E-01, 0.17103000E+01, 0.44156900E+00, -.10481500E+01, -.52010800E+00, 0.12429000E+01, -.51550100E+00, -.45502700E+00, 0.20854200E+00, -.21190600E+01, 0.37555600E+01, 0.27762100E+01, -.24752900E+00, 0.11238900E+00, -.31565400E+00, -.42723700E-01, -.30436300E+01, 0.84396000E-02, -.64060900E+00, -.80258700E+00, 0.45674600E+00, 0.47069400E+00, 0.14598200E+00, 0.61827500E+00, -.26493400E+00, 0.51090600E+00, 0.68341600E+00, -.11239400E-01, -.23471700E-01, -.20222800E+01, -.16672400E+01, -.81868000E-01, -.24239200E+00, -.27969500E+00, -.38682100E+01, -.61702700E+00, 0.24066500E+00, 0.35527800E+00, -.21362600E+01, -.46636400E+01, 0.11878000E+01, 0.11534900E+01, 0.29445100E+01, -.40534800E+00, 0.25281200E+00, -.60786800E+00, -.11818700E+01, 0.30511900E+01, 0.13956000E+01, 0.46818800E+00, 0.15203900E+01, -.28947300E+01, 0.15050200E+01, 0.18336000E+00, -.69961200E+00, -.63910300E+00, 0.33703900E-01, 0.65620700E+00, -.11408000E+01, 0.15523500E+01, -.16145600E+01, -.19439600E+00, 0.57401000E+00, 0.11123400E+01, -.64408200E+00, -.13038400E+01, -.30524000E+01, 0.18761500E+01, -.42649800E+01, -.91795700E+00, -.39958600E+01, -.38268800E+00, -.52030500E-01, 0.44145500E+00, 0.65739800E+00, 0.36878500E+00, 0.38440200E+00, 0.17564100E+01, 0.17091000E+01, -.17149600E+01, -.11203100E+01, 0.19040300E+01, 0.44539300E+00, -.38811700E+00, 0.42079300E+00, -.78490900E+01, 0.18708700E+01, -.99409500E+01, -.44070500E+00, 0.79790900E-01, -.96005800E-01, 0.31409900E+00, -.27927500E+01, -.87868700E+00, -.13002500E+01, -.15361000E+01, -.12409600E+01, -.69893100E+00, 0.12292300E-01, -.15379200E+00, 0.65205200E+00, 0.10907200E+01, 0.71592600E+01, -.15137700E+01, -.36888900E+01, -.63252800E+00, -.71459600E+00, 0.47542100E+01, -.30884000E+00, 0.25701800E+01, 0.74101000E+01, -.19150700E+00, 0.35416500E+01, -.68870600E+01, 0.95684400E-01, -.10867300E+02, -.33563800E+00, 0.17823300E+01, -.88151700E+00, 0.83956400E-01, 0.21255000E+01, -.68104900E-01, 0.86313300E+00, 0.29951500E-01, -.56163600E+00, -.16211300E+01, 0.41997800E+00, 0.12927400E+01, 0.79726100E+00, -.39843000E-01, 0.13930300E+01, -.43522200E+00, 0.37625500E+00, 0.30230800E+00, -.79873900E+00, 0.78429700E+00, -.18612100E+01, 0.25266400E+00, -.23378800E+01, -.89609200E+00, -.17684000E+00, 0.31403300E+00, -.95522200E+00, -.43767300E-01, 0.10670900E+00, 0.95272400E+00, -.45583200E+01, 0.77616900E+02, -.19896100E+02, -.19781500E+02, -.11413200E+03, 0.74530900E+02, 0.13703400E+03, -.70280900E+02, -.40210000E+02, 0.24372500E+02, 0.15245700E+02, -.67511400E+02, -.79373100E+02, -.10041300E+03, 0.10583600E+02, -.26052100E+02, 0.17370400E+02, 0.29716500E+02, -.48643200E+02, -.10190800E+02, 0.24735100E+02, 0.29729800E+02, 0.58271400E+01, -.18033200E+02, -.96350300E+02, 0.48858300E+02, 0.47895200E+02, -.71362800E+02, 0.16302100E+02, 0.36797400E+02, 0.14854500E+02, 0.32755600E+02, 0.22148100E+02, -.18823200E+02, 0.58294300E+01, 0.85828800E+01, 0.60978700E+02, 0.13911900E+02, -.61780800E+02, -.58961300E+02, 0.70616300E+01, 0.56997700E+02, 0.79067600E+02, -.40771600E+02, -.76194800E+02, 0.23219900E+02, -.26851300E+02, 0.12212300E+02, 0.94443900E+01, -.45983900E+02, -.59789100E+01, -.12800900E+02, 0.95467700E+01, 0.39704400E+01, -.34097300E+02, -.24583800E+02, 0.57836300E+02, 0.38425800E+02, 0.64699100E+01, -.38246500E+02, 0.17228700E+03, -.87515700E+02, -.87204700E+02, -.30131600E+01, -.25930700E+02, -.45598700E+02, 0.29005700E+02, 0.69608100E+01, -.29837100E+02, -.39360600E+02, 0.19795200E+02, 0.18017400E+02, 0.12501100E+02, 0.42899400E+02, -.38979700E+02, -.92528800E+02, -.66956800E+02, 0.13699300E+02, 0.19023800E+01, -.30930100E+02, 0.13412100E+02, 0.88994300E+00, 0.33735300E+01, 0.18044700E+00, 0.59066100E+02, -.32498700E+02, -.10492300E+02, 0.42010800E+02, 0.14814400E+01, 0.44594200E+00, 0.13200600E+01, 0.24593000E+02, -.20950900E+02, 0.56962800E+02, -.10442500E+03, 0.20955300E+02, 0.44229300E+02, 0.14565700E+02, 0.24735000E+02, 0.68907300E+02, 0.18859800E+02, 0.11747700E+02, -.47985400E+02, -.58056900E+02 },
            { 0.63089600E+00, 0.13717200E+00, -.14306700E+00, -.21604200E+00, -.81288200E+00, -.70014600E-01, -.21641400E+00, 0.13137800E+00, 0.32287100E+00, 0.35646100E-01, 0.49608800E+00, -.41932300E+00, 0.21595100E+00, -.70072500E+00, 0.52393000E+00, -.15378900E+00, 0.30298000E+00, -.20761000E+00, 0.46260200E+00, -.46553300E-01, -.17868300E+00, 0.74392500E-02, -.46187600E+00, 0.52967100E-01, 0.41437400E-01, -.23664200E-01, 0.15305100E+00, 0.76145600E-03, 0.12806300E+00, 0.43030100E-01, 0.60665500E+00, 0.96444700E-01, 0.73821600E-01, -.22441600E+00, -.13831100E+00, 0.85079900E+00, 0.13609300E+00, -.52998600E-01, -.79301100E-01, 0.37173400E+00, 0.90310900E+00, -.30096000E+00, -.39624000E+00, -.45682700E+00, 0.23469900E+00, -.19291000E+00, 0.15120700E+00, -.18745500E+00, -.31935800E+00, -.35317500E+00, 0.34892400E+00, -.64462600E+00, -.13835700E-01, -.43510300E-01, -.77994400E-01, -.28056900E+00, 0.91206000E+00, -.23060000E-01, -.17361500E-01, 0.11214300E-02, 0.27237000E+00, -.18610200E+00, -.78624300E-01, -.24788300E-01, 0.20205400E+00, -.11149000E+00, -.28734900E+00, 0.37739100E+00, -.23698100E+00, 0.99228900E+00, -.14515700E+00, 0.46813500E+00, 0.16075100E+00, -.72200900E-01, 0.87938600E-02, -.18565600E+00, 0.68624200E-01, -.76388600E-01, -.35832800E+00, -.26141000E+00, 0.16012500E+00, -.13523400E+00, -.68659200E-01, 0.11751100E+00, 0.86038800E-02, 0.55703800E-01, -.53553200E-01, -.65744400E-01, 0.76165400E-01, 0.20770800E-02, 0.29582400E-01, -.15915200E-01, 0.18299600E-01, -.40153500E+00, -.22475500E+00, -.10356300E+00, -.10635600E+00, 0.23002800E-01, -.17368900E+00, 0.42478900E-01, -.19034000E-01, 0.26135600E-01, 0.49869300E+00, 0.66971100E+00, -.35089900E-01, -.18313000E+00, 0.20980800E+00, 0.17125300E+00, -.17613300E+01, -.62657100E-01, 0.41154300E-02, -.35882400E+01, -.30500800E+00, 0.97982000E+00, 0.14120500E+00, -.14170700E+00, -.55201000E+00, 0.42969700E+00, -.18106900E+00, 0.59414800E-01, -.25889500E-01, 0.35436900E+00, 0.12130400E+00, 0.22046900E+00, 0.11300000E+00, 0.25517100E+00, 0.28270800E+00, -.30962700E-01, 0.29154300E+00, -.38754700E-01, 0.37132400E-01, 0.22795900E+00, 0.58367600E-01, 0.16738300E+00, 0.15531300E+00, -.25939000E+00, 0.66192100E-02, 0.10979400E+00, -.76557400E-02, 0.82362800E-01, -.35998500E+00, 0.60885400E-01, -.95891600E-03, -.25329700E+00, 0.79097400E-01, -.79002300E-01, -.17372400E+00, -.22551700E-01, -.97636100E-01, 0.31698800E+01, 0.96948900E+01, -.90401800E+00, -.10842000E+01, -.22283200E+02, 0.10915700E+02, 0.13230100E+02, -.49786300E+01, -.31583800E+01, 0.15395300E+02, 0.22134400E+02, 0.15916800E+02, 0.18315900E+01, 0.11494200E+02, -.55137400E+01, -.43804300E+01, -.33188100E+01, 0.11006700E+01, -.31278700E+01, -.43592600E+01, -.23180800E+01, -.39366900E+01, -.23911500E+02, 0.11945800E+02, 0.12100200E+02, -.39797900E+01, -.14409200E+01, 0.66728000E+01, -.13923500E+02, 0.11133700E+02, 0.76218600E+00, 0.37623700E+02, -.19223100E+02, -.18960200E+02, 0.78454500E+01, -.92694700E+01, -.73303300E+01, -.43602400E+01, -.54967800E+01, -.88999700E+01, 0.18623000E+01, -.25610300E+00, -.32942800E+01, 0.39311800E+01, -.13924800E+02, 0.86668700E+01, 0.15773500E+02, 0.71397000E+01, -.13276100E+02, -.14629000E+02, 0.85336100E+01, 0.63314500E+01, -.61723300E+01, -.45618400E+01, 0.12841300E+02, 0.19818600E+02, 0.66604600E+01, -.51568000E+00, -.46009700E+02, 0.23156900E+02, 0.22666600E+02, 0.74398300E+01, 0.48585200E+01, 0.15163400E+02, -.11419700E+01, 0.14852800E+02, 0.61784400E+01, 0.10640700E+02, -.51463600E+01, -.59853100E+01, -.19359700E+01, 0.62017700E+01, -.10476500E+02, -.10696900E+02, -.59994800E+01, -.28459200E+01, 0.25937000E+00, -.83767500E+00, -.46522200E+00, 0.22455400E+00, 0.43396300E+00, -.63510000E+00, 0.35753600E+00, -.11469900E+01, -.82310800E+00, -.27542600E+01, 0.20991100E+00, 0.92003000E-01, 0.19356300E+00, 0.22612200E+01, -.26705200E+01, 0.27334000E+01, -.64332700E+01, -.34954300E+01, -.36705600E+01, 0.11162300E+01, 0.68707600E+01, 0.52030800E+01, 0.41790600E+01, 0.13037700E+02, 0.22731800E+01, -.92201000E+01 },
            { -.41089500E+01, 0.12963200E+01, 0.24995400E+01, -.69449300E+00, 0.75837400E+01, 0.55238100E+00, 0.16194500E+01, 0.11442600E+00, -.45039800E+00, 0.11540900E+01, -.27121700E+01, 0.80390400E+00, 0.22397500E+01, 0.28243000E-01, 0.35636700E+00, -.74738600E+00, 0.19410000E+01, -.70027800E+00, 0.24900200E+00, -.14805200E+01, 0.14553100E+01, -.15794000E+01, 0.18400400E+01, -.68809000E+01, -.51070700E-01, 0.14656100E+01, 0.17998100E+00, -.14253100E+01, 0.66713200E+00, 0.32263900E+00, 0.87044300E+00, -.79471200E+00, 0.72273800E+00, -.13495100E+01, -.11091800E+00, -.79771100E+01, -.24768900E+00, 0.10567500E+00, 0.10870000E+00, -.51618000E+01, -.89761500E+00, 0.52516000E+00, 0.58570200E+00, 0.21000700E+00, 0.35682700E+00, 0.23451600E+01, -.14468800E+01, 0.72746200E+01, 0.49051900E+00, 0.12725500E+01, -.46824500E+01, 0.81358600E+00, 0.17676900E+01, 0.44805900E+00, -.76521500E+00, 0.36586600E+01, -.11077700E+01, 0.29902100E-01, -.62660100E+00, 0.23928200E+01, 0.39547700E-01, 0.11198300E+01, -.17086600E+01, -.44723300E+00, -.11075700E+01, 0.15243600E+01, 0.18701100E+01, 0.87275700E+00, -.15487900E+00, -.12041700E+01, 0.20984700E+00, 0.19296200E+00, -.12867000E+01, 0.22803000E+00, -.15002600E+00, -.15526700E+00, -.19153700E+01, -.14858300E-01, 0.35103500E+00, 0.17392000E+00, -.62588000E-01, -.59698600E-01, -.17379400E+00, -.60139500E-01, 0.34660800E+00, -.31389100E-01, -.53327100E+00, 0.74963900E-01, -.54309600E+00, 0.37948800E-01, 0.23376200E+00, 0.73348100E-02, -.21183000E+00, -.54481500E+00, -.14496400E+00, -.70100500E+00, -.93015500E+00, -.83390000E+00, -.80123100E-01, 0.26009200E+00, 0.18800200E+00, -.12581600E+00, 0.26721900E+00, 0.14423700E+01, -.73642700E+00, -.97356100E+00, -.79896400E+00, 0.44211900E-01, 0.34822000E+00, -.40982800E+00, -.88668600E+00, 0.21237800E+01, 0.73827800E+00, -.47877100E+01, -.38111600E+00, 0.21358000E-01, 0.51422500E+01, -.58373800E+00, -.35884800E+00, 0.37970000E+00, 0.99699000E-01, -.10928200E+01, -.91523800E-01, -.19384000E+01, -.24821600E+00, -.84248300E+00, 0.80573800E-01, 0.18470400E+00, -.12778700E+01, 0.12400900E+00, 0.66859500E-01, -.29732300E+00, 0.15718200E+00, 0.31867800E-01, 0.47360300E-01, 0.39293800E+00, 0.17747600E+00, 0.91571100E+00, -.10025200E+01, 0.11180500E+01, 0.22627200E+00, 0.22155100E+00, -.22368900E+00, 0.54199200E+00, -.45604400E-01, -.27106800E+00, -.14319900E+01, 0.41818100E+01, -.16155500E-01, 0.36853400E+01, -.83340400E+02, 0.72828300E+02, -.13533500E+02, -.22882800E+02, 0.14191500E+02, -.26345800E+02, 0.43155300E+02, 0.42356000E+02, -.63395800E+02, -.16393800E+03, -.51677500E+02, 0.40218700E+02, 0.41016200E+02, -.25706700E+02, -.46959100E+02, 0.52355800E+02, -.29965300E+02, 0.10938200E+02, 0.39306800E+02, 0.35313700E+02, -.28656700E+02, 0.18321600E+03, -.92889000E+02, -.86093600E+02, 0.63968400E+02, 0.91467100E+01, -.61451600E+02, 0.56245200E+02, -.55263000E+02, -.19998000E+02, 0.27385800E+03, -.13302900E+03, -.13639600E+03, -.18376500E+02, 0.82733700E+02, -.17716600E+03, -.17880200E+03, -.27676400E+03, 0.95551100E+02, -.22359700E+03, 0.11240000E+03, 0.15651900E+03, -.95832500E+02, 0.11572800E+03, 0.24080400E+02, -.49367100E+02, 0.64167800E+02, 0.11081800E+03, 0.22104100E+03, -.11162100E+03, -.11140800E+03, -.71555100E+02, -.14534300E+03, -.42249100E+01, 0.11744600E+03, 0.57908400E+02, -.17279700E+03, 0.18299300E+03, -.90585400E+02, -.88183500E+02, -.10458500E+03, -.79287900E+02, -.76614100E+02, -.10327700E+03, -.12821000E+03, -.33607400E+02, 0.48277300E+01, -.31058000E+01, -.10941300E+02, 0.82884900E+02, -.30934700E+02, 0.32610700E+00, -.73145400E+02, 0.25450100E+02, 0.50296000E+02, -.13294600E+02, 0.77596600E+01, -.34992100E+01, 0.69517500E+00, -.17293800E+01, -.41435400E+01, -.18237800E+02, 0.85332500E+01, 0.18349800E+02, -.27117500E+02, -.82445400E+01, 0.73379500E+00, -.79917100E+01, -.11611400E+02, 0.12216300E+02, -.37334000E+02, 0.71243800E+02, 0.20595300E+02, -.10682400E+02, -.24507600E+02, -.29030300E+02, 0.13275900E+03, -.54847300E+02, 0.67923300E+02, -.61116400E+02, 0.55691700E+02 },
            { 0.20443700E+01, 0.10695100E+01, -.85933400E+00, 0.47846400E+00, -.10029200E+01, 0.12050600E+00, -.65439200E+00, -.31798400E-01, 0.32297100E-01, -.12143200E+01, -.12394300E+01, -.32379600E+01, 0.66943700E+00, 0.55549500E+00, -.15067500E+01, 0.62944000E+00, 0.15259900E-01, -.16689200E+00, 0.14891300E+00, 0.49079200E+00, -.50268300E+00, 0.43167000E+00, -.59977700E+00, 0.18695700E+01, 0.20128900E+00, -.27250300E+00, 0.17389100E+00, 0.35277600E+00, -.39743900E+00, -.10824100E+00, -.61786400E+00, -.71295100E-01, 0.11717700E+00, 0.14889600E+00, -.34993200E+00, 0.39089400E+01, -.77702400E+00, 0.29798000E+00, 0.47903700E+00, -.10581800E+01, -.48697600E+01, 0.11800700E+01, 0.64957500E+00, 0.13149600E+01, -.14073900E+01, -.14405400E+01, 0.95706700E+00, -.73508600E+00, 0.16187300E+00, -.13103700E+01, 0.24468800E+01, -.82967400E+00, -.37463300E-01, -.27760400E+00, -.36390400E+00, -.13860900E+01, 0.25417200E+01, 0.20496700E+00, 0.82135400E+00, -.60247300E+00, 0.10554300E+01, -.89830500E+00, 0.11496300E+01, 0.39303400E+00, 0.54209400E+00, -.51149200E+00, 0.48916600E+00, -.24279500E+01, 0.54662600E+00, 0.57855000E+01, -.34347300E+00, -.16743200E+01, 0.15874700E+00, 0.48825700E-01, 0.12052700E+00, -.85262300E-01, 0.69058900E+00, -.27234800E+00, -.31951900E+00, -.23388200E+00, 0.48073900E+00, 0.94279900E-01, 0.15748100E-01, 0.11837800E+00, -.62207200E+00, 0.50119700E+00, -.22557800E+01, 0.11605500E+01, -.27362600E+01, 0.22375500E-01, 0.30960800E+00, -.21851700E+00, -.10206600E+00, 0.43564000E+00, 0.75102100E+00, -.16006500E+01, -.24301900E+01, -.24788600E+01, 0.38816400E+00, 0.43335600E+00, -.35923700E+00, -.36028400E-01, -.49695500E+00, 0.13121100E+01, -.12201600E+01, -.25242800E+01, -.51570500E+00, -.12022900E+01, 0.16295300E+01, 0.47690300E+00, 0.17084000E+01, -.53014200E+01, -.17648200E+01, 0.96410400E+00, -.14085400E+01, 0.14253500E+00, -.55731900E+01, 0.12259500E+00, 0.92285700E+00, -.45133800E+00, 0.14783200E+00, 0.43358900E-01, 0.16749900E+00, 0.11327200E+01, 0.32747900E-01, -.16463800E+00, -.12470000E+01, 0.12703500E+00, 0.20131600E+01, -.74626500E-01, -.12794000E+00, -.95624500E-02, 0.20871700E+00, 0.32793300E+00, 0.23613400E-01, -.38127500E+00, 0.20238200E+00, -.35691800E+00, 0.45318000E+00, -.41659800E+00, -.39149700E+00, 0.10135600E+00, 0.84960500E-01, -.10751000E+01, 0.11040200E+00, -.29989600E+00, 0.17672900E+00, -.50851300E+01, -.19933700E+00, -.11439300E+01, -.39448900E+00, -.27618300E+02, -.24295700E+00, -.20728100E+02, 0.12473700E+02, 0.12642300E+02, 0.58104800E+01, 0.27693000E+01, 0.13700600E+02, 0.32916900E+02, -.18319100E+01, 0.76314500E+01, -.39005000E+02, 0.17900600E+02, 0.17908000E+02, -.14547400E+02, -.13649500E+02, 0.21769200E+02, -.10534800E+02, 0.24712800E+02, -.59714400E+01, -.11024100E+03, 0.54055300E+02, 0.56826900E+02, -.38830600E+02, -.69089800E+00, 0.31196600E+02, -.69026000E+02, 0.32750000E+02, 0.26863600E+02, 0.25681000E+01, -.85102800E+00, -.13698300E+01, 0.79141200E+01, -.46754600E+02, 0.26840700E+01, -.41109900E+02, 0.65366600E+02, -.18600900E+02, 0.52375300E+02, -.24152600E+02, -.29535700E+02, 0.11329900E+02, -.13757700E+02, -.10926300E+02, 0.17782800E+02, -.10382100E+02, -.12531200E+02, -.10820900E+03, 0.57150000E+02, 0.50641700E+02, -.21495800E+01, -.15155800E+01, 0.68249800E+02, 0.10263500E+03, 0.31952700E+02, 0.46163900E+01, 0.50799000E+02, -.24897200E+02, -.25185000E+02, 0.15807200E+02, -.13159400E+01, -.11334200E+02, 0.74024800E+01, 0.10494900E+01, -.10889700E+02, 0.13777800E+02, -.70331900E+01, -.10718300E+02, 0.18820800E+02, 0.16620700E+02, -.35901300E+02, -.38125100E+02, -.40719900E+02, 0.89270900E+01, -.19081100E+01, 0.26495300E+01, 0.26139800E+01, 0.97489500E+00, 0.19386900E+01, 0.37236100E+00, -.42799600E+00, -.49629500E+00, 0.40834000E+01, 0.15970100E+02, -.30133500E+01, 0.64761000E+00, -.27095200E+01, 0.17294500E+02, -.20842700E+02, 0.15679600E+02, -.88075200E+02, -.17500800E+02, 0.90512100E+01, -.58307000E+01, 0.31608600E+02, 0.11649200E+02, 0.51105700E+01, 0.42903500E+02, 0.13511400E+02, -.23976900E+02 },
            { 0.66765700E+00, 0.36794300E+00, -.26265500E+00, -.78174100E-01, -.69437100E+00, -.36046900E-01, -.33090800E+00, 0.12375800E-01, 0.10292600E+01, -.26388000E+00, -.45773100E+00, -.39501200E+00, -.98212500E-02, -.16428400E+00, -.44752500E-01, 0.81800400E-01, -.31750300E-01, 0.10417100E+00, 0.18507100E+00, -.34097700E-01, -.52511800E+00, -.11775600E+00, 0.98307400E-02, 0.77367600E-03, 0.77148400E-02, -.64692900E-01, 0.12872100E+00, 0.49641100E-01, -.44745900E-01, 0.12214100E+00, 0.10181800E+00, 0.54750000E-01, -.26803600E-01, -.12485200E+00, -.63347300E-01, 0.18032000E+01, 0.70767300E-01, -.28305900E-01, -.37913200E-01, 0.84043000E+00, 0.11167500E+01, -.17469900E+00, -.21413700E+00, -.51694600E+00, 0.80852100E-01, -.13203700E+00, 0.72180600E-01, -.63721700E+00, -.78138900E+00, 0.15190500E+00, 0.29968500E+00, 0.46418600E+00, 0.74184100E-01, -.25054600E+00, 0.11695200E-02, 0.24084200E-01, -.25980900E+00, 0.82680600E-01, 0.21904800E+00, 0.14488000E+00, 0.40184700E+00, -.17851000E+00, 0.28577000E+00, 0.24997100E+00, -.16274700E+00, 0.21728900E+00, -.24290800E+00, -.56810300E-01, -.61848000E-01, 0.26403500E+01, 0.44663600E-01, -.38285900E+00, -.44208800E-01, 0.13421900E+00, 0.40616400E-01, -.12207600E+00, -.11466800E-01, -.32513800E+00, -.14893500E+00, -.34569800E-03, -.84631700E-01, 0.62347500E-01, -.24127700E+00, -.57947200E-01, -.33000700E-01, 0.14571600E+00, -.72893200E+00, 0.13082400E+00, -.10024700E+01, -.16702300E-01, 0.57216400E-01, -.30793800E-01, 0.36092000E-02, 0.87234200E-01, 0.28581900E+00, -.34725900E+00, -.47330200E+00, -.59373700E+00, 0.19250600E+00, 0.11028000E+00, -.56186600E-01, 0.11856300E-01, -.41293500E+00, 0.62156600E+00, -.18938700E+00, -.68508800E+00, -.10114300E+00, -.42621700E+00, 0.58185000E-01, -.35559500E-01, 0.49854200E+00, -.82363100E+00, -.26308000E+00, 0.10941900E+01, 0.14071700E+01, 0.25181900E+00, -.14018700E+01, 0.23719300E-01, 0.23463600E+00, -.36588100E-01, 0.17000200E+00, -.44178600E-01, -.91823300E-01, 0.34803100E+00, 0.57174200E-01, -.29226700E+00, -.60934700E+00, 0.87877000E-01, 0.48065000E+00, 0.35329200E-01, -.67636900E-01, -.64554800E-01, -.12927100E+00, 0.29518600E+00, -.32019900E+00, -.62200400E-01, 0.25074600E-01, -.13803600E+00, -.14783700E+00, -.16769300E+00, 0.21208500E+00, 0.97387200E-01, 0.26179800E-01, 0.45104600E+00, 0.11594100E+00, -.12255500E-03, 0.13914400E+00, 0.43941300E+00, 0.30666600E-01, 0.33965000E+00, -.96254300E-01, 0.20426400E+00, 0.13689600E+02, 0.17312300E+02, -.82972500E+01, -.14357000E+02, 0.83364400E+01, 0.67352600E+01, -.15122200E+02, -.20657400E+02, -.13896000E+02, -.16430600E+01, 0.46428200E+01, -.28519600E+01, -.59961900E+01, 0.86808700E+01, 0.10168200E+01, 0.12208200E+00, 0.32962700E+01, -.20138700E+01, -.34612700E+00, 0.79114700E+01, -.40619000E+01, -.34693100E+01, 0.28781000E+01, -.43539800E+00, 0.13604400E+01, 0.15167900E+02, -.29795200E+01, -.24930800E+01, 0.42900400E+01, -.19226700E+01, -.19260700E+01, -.10678100E+02, 0.43250700E+01, 0.50213700E+00, 0.99527900E+01, -.12701800E+02, 0.30293500E+01, -.33760200E+02, 0.17319000E+02, 0.23770200E+02, -.13232000E+02, 0.10851900E+02, 0.10318800E+02, 0.33445100E+01, 0.10087000E+02, 0.15304200E+02, 0.14041600E+02, -.74498800E+01, -.66136600E+01, -.56350400E+01, 0.76570200E+00, -.38625800E+01, -.15688700E+02, -.64133600E+01, -.88310700E+00, 0.21542600E+01, -.97265600E+00, -.68952700E+00, -.51086900E+01, 0.54867300E+00, -.14663100E+01, -.46001600E+01, -.14716400E+02, 0.73171300E+01, 0.44359000E+02, -.22267000E+02, -.22471000E+02, 0.35928100E+01, -.11471900E+02, -.12691600E+02, -.31837300E+01, -.68216500E+01, -.24718400E+01, -.72669800E+00, 0.25033300E+01, -.14047100E+01, -.11917100E+00, -.68421100E-01, -.30890800E+00, -.89656400E+01, 0.24365300E+01, 0.58119000E+00, -.18365200E+00, -.10114400E+00, -.32369300E-01, -.21618300E+00, -.98165400E+00, 0.14645300E+01, 0.11549500E+01, 0.15593500E+02, -.52615400E+01, -.17619100E+01, 0.40935000E+00, -.48968000E+01, -.38243800E+01, -.94879700E+01, -.84893800E+01, -.19733000E+01, 0.80427100E+01 },
            { -.51303700E+00, -.80238500E-01, -.28034500E+00, 0.13087400E+01, 0.21738200E+01, 0.34773500E+00, 0.49368900E+00, -.13667500E+00, -.47462400E+00, 0.45143200E+00, 0.94846800E+00, -.11292200E+00, 0.44375300E+00, -.16413000E+00, 0.21449600E+00, -.28401900E+00, 0.97158200E+00, 0.19352600E+00, -.17151600E+01, 0.84870600E+00, 0.11075600E+01, 0.78494000E+00, -.14907500E+00, 0.53286200E+00, 0.58043400E+00, 0.65375400E-01, -.19450100E+00, 0.10684900E+00, -.28204400E+00, 0.22541400E+00, -.21667200E+00, 0.21604300E+00, 0.34790300E+00, 0.30954100E+00, 0.34435500E-01, 0.77211400E+00, 0.81284700E+00, -.32474900E+00, -.45921400E+00, 0.24235300E+01, 0.29110800E+01, -.12727800E+01, -.47338600E+00, -.16114900E+01, 0.29899400E+00, 0.67065100E+00, -.41234100E+00, 0.84901900E+00, -.24664600E+00, -.32088700E+00, -.12833800E+01, -.36945200E+00, -.12442500E+00, 0.72288800E+00, -.61048000E-01, -.78128300E-01, -.87292100E-02, 0.19787600E+00, 0.89387400E+00, 0.34678100E-01, 0.93072000E-01, 0.28553600E+00, 0.35545700E+00, -.17024000E+00, -.73398100E+00, 0.12773400E+01, 0.13970400E+01, 0.11633500E+01, 0.14581400E+00, 0.64897900E+00, -.51283800E+00, 0.22917300E+00, -.72251300E-01, 0.22525100E+00, -.67307600E-01, -.13624100E+01, -.41257800E+00, -.13726500E-01, 0.39566100E+00, -.10779600E-01, 0.46631000E+00, 0.62631900E+00, -.53102800E+00, 0.20783300E+00, 0.12334500E+00, -.22485700E+00, -.48237500E+00, -.93246200E+00, -.56165500E+00, -.81893600E-01, 0.21354400E-01, -.18402900E-01, 0.34854900E-01, -.10100700E-01, -.22347000E+00, 0.25533000E+00, 0.23821100E+00, 0.95227200E+00, -.11008000E+00, -.81005700E-01, -.10658700E-01, 0.27055600E-01, 0.42052200E-01, -.43863700E+00, 0.26211400E+00, 0.36167800E+00, -.16226500E-01, -.37658300E+00, -.44011300E+00, -.75923500E-01, 0.46836100E+00, 0.31869600E+01, 0.12534400E+00, 0.44063300E+01, 0.14162400E+01, 0.71608700E-01, -.12271500E+01, 0.59104600E+00, 0.72208000E-02, 0.10362300E+00, 0.31429400E+00, -.70097700E+00, -.48292500E+00, 0.21337100E+00, -.26224700E+00, 0.12787700E-01, -.32949000E+00, 0.30880900E+00, 0.91588000E+00, 0.20237500E+00, -.18178400E+00, -.30499500E+00, 0.19117000E+00, 0.36770600E+00, 0.37605800E+00, -.13499800E+00, -.35845200E+00, -.50841300E+00, 0.47705800E+00, -.11723100E+01, -.47563600E+00, 0.76403500E-01, 0.17392900E+00, 0.30361700E+00, 0.93697600E-01, 0.12321800E+00, -.29482800E+00, -.32815300E+00, -.35273400E+00, 0.80838500E+00, 0.87977300E-01, 0.22950200E+00, 0.10023100E+01, 0.68826600E+02, -.36646400E+02, -.36583500E+02, 0.14479800E+02, 0.93018600E+01, -.50029200E+02, -.67664800E+02, -.47487000E+02, 0.79652800E+01, 0.10129500E+02, -.18399400E+01, -.39694100E+01, -.23513500E+01, 0.29809500E+01, -.78570500E+01, 0.60361700E+01, -.15617800E+01, -.22715400E+01, 0.59847500E+02, -.29352800E+02, -.31188900E+02, 0.30149800E+01, 0.12005200E+02, -.29234700E+02, 0.23025000E+02, -.26891600E+02, 0.10826800E+02, -.48362600E+01, 0.12626300E-01, 0.22996000E+01, -.12585900E+02, 0.25880600E+02, -.17239900E+02, -.10242100E+02, -.27039700E+02, 0.25825300E+02, -.30538000E+02, 0.14015600E+02, 0.16346700E+02, -.76754900E+00, 0.15470300E+02, 0.94730700E+01, -.81389600E+01, 0.43737000E+01, 0.11701500E+02, 0.52001200E+02, -.25061900E+02, -.22852900E+02, 0.12039900E+02, -.67098000E+01, -.24902000E+02, -.17389100E+02, -.20544700E+01, -.21631800E+02, 0.11785100E+03, -.60220700E+02, -.58664100E+02, -.21711900E+02, -.13725800E+02, -.38636300E+02, 0.10972000E+01, -.30221500E+02, -.12152100E+02, 0.19727500E+02, -.10112100E+02, -.77738900E+01, -.29949800E+01, 0.68163000E+01, -.11778700E+02, -.24148200E+02, -.31566300E+02, 0.61098000E+00, 0.10020600E+01, -.36932200E+00, 0.24783200E+01, -.35440100E+00, 0.84112100E+01, 0.16126200E+01, 0.78965800E+01, 0.75326400E+00, 0.27911400E+01, 0.33432200E+01, 0.35880500E+00, -.26900900E+00, 0.25288700E+00, -.62515600E+01, 0.80211300E+01, -.44348400E+01, 0.15475300E+02, 0.98463000E+01, 0.12598200E+02, 0.48543700E+00, -.12643200E+02, 0.15883200E+02, -.22894500E+01, -.70925900E+01, -.21215300E+02, -.40480400E+00 },
            { -.32905500E+01, -.26812500E+00, 0.22922900E+01, -.13490800E+01, -.14990100E+01, -.79604100E-01, 0.12591700E+01, 0.14361000E-01, -.49310100E+00, -.16461500E+00, -.16457100E+01, 0.10796200E+01, -.19195100E+00, -.30183800E-01, 0.12914000E+01, -.54574900E+00, 0.39082500E-02, -.49191600E+00, -.30288100E+01, -.73946800E+00, 0.67977600E+00, 0.30726800E+01, 0.15958400E+01, -.21756200E+01, 0.57266800E+00, 0.45538000E+00, -.39188400E+00, -.22580800E+00, -.10473100E+01, -.63716500E+00, 0.14604200E+00, -.37201600E+00, 0.84975000E+00, -.16475200E+00, -.57993800E+00, -.27410600E+01, -.10997600E-01, 0.13353800E-01, -.16878400E-01, 0.11374000E+01, 0.66763300E+00, 0.32257800E+00, 0.50968500E+00, -.28786300E+00, -.40765900E+00, -.56016400E+00, 0.43994000E+00, -.42433600E+01, 0.64651400E+00, 0.61150400E+00, 0.93234300E+00, 0.14682500E+01, 0.12104100E+01, -.69351700E+00, 0.38988900E+00, 0.18703000E+00, -.25279800E+01, 0.42934400E-02, 0.74085700E-01, -.12197800E+00, -.47539100E+00, 0.50906900E+00, 0.11378400E+01, 0.93342900E+00, -.21861600E-01, -.12563100E+01, 0.29552800E+00, -.13752400E+01, -.78327500E+00, 0.52929800E+01, 0.11393900E+01, -.54384900E+00, -.50012100E+00, 0.29740500E+00, -.87188800E-01, -.86686700E+00, 0.22055900E+00, 0.35947000E+00, -.29465600E+00, 0.55876000E+00, 0.62219800E+00, -.16848100E+00, 0.37923500E+00, -.75353900E+00, 0.92125900E-01, 0.37985500E+00, -.55348500E+01, -.12697300E+00, -.87844600E+01, -.46880100E+00, -.26830200E-01, -.57668400E-01, -.69635500E-01, 0.10691300E+01, 0.78100200E+00, -.66610100E-02, -.59194900E+00, -.49866100E+00, 0.32723200E+00, 0.81391800E-01, -.20918300E+00, -.29000700E+00, -.84616700E+00, -.28358000E+01, 0.60642600E-01, 0.33089200E+00, -.16444400E+00, 0.81858300E+00, -.40347000E+01, -.81406400E+00, 0.23182900E+00, 0.90271100E+01, 0.19333700E+01, -.56300100E-01, -.37916100E+00, -.35962300E+00, 0.72954600E+01, -.11742900E+01, -.15001500E+00, -.27453300E+00, -.53667200E+00, -.26054000E+01, -.20626400E+00, -.90507300E+00, -.74448600E+00, 0.50547200E-01, 0.85739700E+00, 0.32073100E+00, -.12370000E+01, -.26641900E+00, -.19492500E+00, -.92814000E+00, -.51391100E+00, 0.91541700E+00, 0.92400400E+00, 0.84568600E+00, 0.11977900E+00, 0.39828300E+00, -.44417500E+00, 0.53508800E+00, 0.15375700E+01, 0.25434300E+00, -.48032100E-01, 0.24602700E+00, 0.17229400E+00, -.15556400E+00, -.11489200E+00, 0.17496600E+01, -.31680800E+00, 0.13075100E+01, 0.99633500E-02, 0.67160000E-01, -.86393400E+00, 0.32485200E-01, 0.42722200E+01, -.11157400E+02, 0.20334200E+02, 0.13487100E+02, -.20921400E+02, -.42287800E+02, -.29449800E+02, 0.43369400E+01, 0.18140200E+01, -.40539400E+01, -.11104800E+02, 0.23316600E+02, -.11019000E+02, 0.97453300E+01, -.31722200E+01, 0.21132200E+02, -.74507700E+01, 0.98677000E+02, -.49491400E+02, -.47963500E+02, 0.24312300E+02, 0.27069200E+02, -.39669500E+02, -.27252100E+02, -.46207200E+02, 0.23378000E+02, 0.85760200E+02, -.39162200E+02, -.39209900E+02, -.24187200E+02, -.86431500E+01, -.23652000E+02, 0.13843300E+02, -.63618100E+02, 0.20902000E+01, -.10842700E+03, 0.52897900E+02, 0.64896900E+02, -.55405600E+02, 0.54488900E+02, 0.38867500E+02, 0.14695600E+02, 0.29546000E+02, 0.64271800E+00, -.80120800E+01, 0.32909100E+00, -.22392100E+01, -.52567300E+01, 0.66750400E+01, 0.22379100E+01, -.28919900E+02, -.80558600E+01, -.24830300E+02, 0.15030000E+03, -.74993900E+02, -.71445900E+02, -.33269400E+02, -.18185800E+02, -.47075000E+02, -.18816800E+02, -.85505500E+02, -.12139700E+02, 0.11144200E+03, -.56215500E+02, -.53905500E+02, 0.70548400E+02, -.35781700E+02, -.46383800E+02, -.34086800E+02, -.40043800E+02, 0.47746400E+02, -.37663000E+01, 0.25100400E+02, -.57621500E+01, 0.30684600E+00, -.14475300E+02, 0.16392600E+00, -.29794300E+02, 0.24962600E+02, 0.68682600E+01, 0.58398700E+01, -.44564700E+01, 0.39788500E+00, -.41863000E+01, 0.41608300E+01, -.28831700E+01, -.25293100E+02, -.17130800E+02, 0.32582300E+01, 0.27900000E+01, -.97850300E+01, -.89634100E+01, 0.24263800E+00, -.58775100E+01, -.35524600E+02, -.20987300E+01, 0.38934600E+02 },
            { 0.21683100E+01, 0.32649700E-01, -.14467000E+01, 0.38298000E+00, 0.17800100E+01, 0.26746500E+00, -.87396900E+00, 0.35853100E+00, 0.37726100E+00, 0.52698800E-01, 0.90124300E+00, -.22344000E+01, -.35789800E+00, 0.13315400E+00, -.64084400E-01, 0.13350900E+00, 0.46767100E+00, 0.10893900E+01, 0.13848800E+01, 0.47599800E+00, 0.41344300E-01, -.12112600E+01, -.10813800E+01, -.51937900E+00, -.36426500E+00, 0.85863300E-01, 0.13181800E+00, -.39302600E+00, 0.41802600E+00, 0.73974100E-01, 0.99842200E+00, 0.42351500E+00, 0.40482200E+00, 0.31545600E+00, 0.14405300E+00, 0.23669500E+01, -.18132300E-01, 0.37328900E-02, 0.21330400E-01, -.22325500E-01, 0.70241700E+00, -.15168000E+00, -.36927900E+00, -.71733700E+00, 0.33300400E-01, 0.72003900E-01, 0.61938100E+00, -.26148500E+01, -.11542900E+01, -.69960500E+00, 0.87293300E+00, -.61084900E+00, -.26328800E+00, -.28983200E+00, 0.72345200E+00, -.75394800E+00, -.33563500E+01, -.67100300E-02, 0.78207400E+00, -.50443500E+00, -.25785800E+00, 0.29029100E+00, 0.10155800E+01, 0.31642400E+00, 0.92523200E-01, -.76386900E+00, -.43267600E+00, -.14013400E+00, -.16450800E+01, 0.77935900E+01, 0.99904100E+00, 0.11687800E+01, 0.34719200E-01, 0.15985100E+00, 0.14105900E+00, 0.57840900E+00, 0.13265000E+00, -.19950500E+00, 0.32791800E+00, -.14821400E+00, 0.14854800E+00, 0.32985200E+00, -.17798700E+00, 0.18679600E+00, 0.22848200E-01, -.31343300E+00, 0.56692000E+00, -.60991600E+00, -.40277800E+00, 0.15942200E-01, -.76039800E-01, 0.28322000E-01, 0.91676300E-01, 0.12534600E+00, 0.25403700E+00, -.13057000E-01, 0.51369600E-01, -.61188000E+00, 0.10199600E+00, 0.53835800E-01, -.17106900E-01, -.25558700E-01, -.15458900E+00, 0.68090200E+00, -.33802600E+00, -.31434800E+00, -.12330400E+01, 0.13129400E+01, 0.13337100E+01, 0.48024000E-01, 0.57998700E-01, 0.24914700E+01, 0.62426300E+00, -.22733900E+01, -.21834100E+01, -.16669100E+00, 0.27684600E+01, 0.23830000E-01, -.18269600E+00, -.33952000E+00, 0.31612500E-01, -.37492200E-01, 0.57149600E-01, 0.21325100E-01, -.14590600E+00, 0.38377500E+00, 0.53449500E+00, 0.27623000E-01, -.94536800E+00, -.61077900E+00, -.72409900E-01, -.39978600E+00, -.16902900E+00, 0.17608700E+00, 0.69534700E-01, 0.23228900E+00, 0.11778000E+00, 0.76090800E-01, -.28651500E+00, 0.60127900E+00, 0.20722300E+00, 0.30287800E+00, -.22397700E+00, 0.33618000E+00, -.26141700E+00, 0.33085100E-01, 0.49342300E+00, -.11572100E+01, -.41749000E+00, -.23329100E+00, -.66713800E-01, 0.10604400E+00, 0.83345100E+00, 0.72049100E+00, 0.50093200E+00, 0.13558800E+02, -.69882600E+01, -.97079500E+01, 0.24554400E+02, 0.38589100E+02, 0.20686200E+02, -.11173500E+02, -.34219900E+02, 0.17322000E+02, 0.25460700E+02, -.19268600E+02, -.36486900E+01, 0.14327200E+02, -.14470700E+02, 0.13664000E+02, 0.94951700E+01, -.83873800E+02, 0.41819400E+02, 0.42353100E+02, -.81786100E+01, -.92625500E+01, 0.36432000E+02, -.54525400E+01, 0.35433500E+02, -.70365200E+01, -.11209300E+03, 0.55472100E+02, 0.52882100E+02, 0.24234800E+02, -.14046200E+02, 0.47639300E+02, 0.55242700E+01, 0.10733600E+03, -.31497600E+01, 0.96950700E+02, -.48047000E+02, -.62987300E+02, 0.35148700E+02, -.18371500E+02, -.52538000E+02, -.47865400E+02, -.41708700E+02, 0.19986500E+02, -.13320500E+03, 0.69341600E+02, 0.66839400E+02, 0.30944600E+02, 0.40375200E+02, 0.17970100E+02, 0.18863900E+02, 0.27145300E+02, 0.63656100E+02, -.94104800E+02, 0.47238900E+02, 0.41758800E+02, 0.26515100E+02, 0.16257700E+02, 0.33417500E+02, 0.16663000E+02, 0.54508100E+02, 0.51518900E+01, -.18452000E+03, 0.92595900E+02, 0.86038500E+02, -.25505000E+02, 0.32185700E+02, 0.71180400E+02, 0.50267700E+02, 0.76770400E+02, -.12299100E+02, -.20890900E+00, -.15010700E+02, -.13732900E+00, 0.28516500E+00, 0.53136100E+01, 0.16677300E+01, -.49828800E+00, -.17135600E+02, 0.80056300E+00, 0.12231300E+02, -.18495100E+01, 0.20652800E+00, -.12638700E+01, -.18869300E+01, -.15058100E+01, 0.13868400E+02, -.15727500E+02, -.61645400E+01, 0.21478800E+01, -.65802500E+01, 0.10683900E+02, -.21621500E+02, 0.59838800E+01, 0.12302300E+02, 0.29869100E+02, -.16388400E+02 },
            { -.17996600E+01, -.18709000E+00, 0.45593200E+00, 0.80473500E+00, 0.46261400E+01, 0.52562700E+00, 0.12167700E+01, -.20435000E+00, -.26217600E+01, 0.70569300E+00, 0.93574000E+00, -.19492500E+00, 0.33177700E+00, 0.46909000E+00, -.38218200E-01, -.35179400E+00, 0.12651000E+01, 0.34450100E+00, -.22589300E+01, 0.10011000E+01, 0.25086000E+01, 0.13624400E+01, -.69456800E-01, 0.15988500E+01, 0.57590500E+00, 0.37734600E+00, -.20555000E+00, 0.12608200E+00, -.18066700E+00, -.30757300E+00, -.17600400E+01, 0.80224300E-01, 0.20919200E+00, 0.73306200E+00, 0.22336500E+00, -.46732800E+01, 0.53367300E+00, -.20794000E+00, -.31390900E+00, 0.61762000E+00, -.80403900E+00, -.63702200E+00, 0.58162200E+00, -.92151300E+00, 0.77250000E-01, 0.76347900E+00, -.12527400E+01, -.13250100E-01, 0.17122300E+01, -.62462500E+00, 0.78196800E+00, -.18300900E+01, 0.72960800E+00, 0.47680900E+00, -.58418800E-01, -.10162100E+00, 0.23569800E+01, -.11579800E+00, -.27956500E+00, 0.30815800E+00, -.61340100E+00, 0.19448100E+00, 0.44180400E+00, 0.31471800E+00, -.96240000E-01, -.65902700E+00, 0.66145100E+00, 0.69532000E+00, -.56513200E+00, -.68170100E+00, -.27731100E+00, 0.10984700E+01, 0.11405300E-01, 0.36673200E+00, 0.99228800E-01, -.10457900E+01, -.58234800E-01, -.32843500E+00, -.12703900E+01, -.69135400E+00, 0.17397600E+00, 0.12668100E+00, -.91493000E+00, 0.48358900E+00, 0.16126000E+00, 0.15452700E+00, 0.83340600E+00, -.91248000E-01, -.34553500E-02, 0.61346500E-01, 0.19555100E-01, 0.15800700E-01, 0.22701200E+00, 0.51961300E+00, 0.68067800E+00, -.70769300E-01, -.10445800E+01, -.12177600E+01, 0.38026200E+00, 0.19129900E+00, -.51842800E-02, 0.34588800E+00, -.10990100E+01, -.18560300E+01, -.70715400E-01, -.48950000E+00, -.16118300E+00, -.90206800E-01, 0.31105900E+01, 0.20898300E+00, 0.34234800E+00, 0.76417000E+01, -.49763500E+00, 0.60858100E+00, -.41878900E+01, -.38676100E+00, 0.88819300E+01, 0.25703100E+00, 0.35005000E+00, -.78705600E+00, 0.20908600E+00, -.73379700E+00, -.46999800E-01, 0.86102300E+00, 0.14268100E+00, 0.41260200E+00, 0.71493300E+00, 0.37279300E+00, -.76268600E+00, 0.59424300E-01, -.38325600E+00, -.90848000E+00, 0.48576100E-01, 0.19555800E+01, 0.77429900E+00, 0.33751600E+00, 0.18716000E+00, -.22843200E-01, -.68130700E+00, -.10546400E+00, -.12679700E+01, 0.26024600E+00, -.14404100E+00, -.14393500E+00, -.11851200E+00, 0.14672200E+00, 0.11704000E+00, -.26358700E+00, -.44223600E+00, 0.10254500E+00, -.74202100E-01, 0.57822600E+00, 0.17277400E+01, -.18207200E+00, -.74431100E+00, 0.25867400E-02, 0.17719100E+02, 0.15278300E+02, -.33493100E+02, -.80057100E+02, -.38942900E+02, 0.14098000E+02, -.51197200E+01, 0.37334000E+01, 0.33108900E+01, 0.27158300E+01, -.75561900E+01, 0.41162300E+01, 0.42641500E+01, 0.12122300E+02, -.34737600E+00, 0.10163600E+03, -.50355400E+02, -.51750900E+02, 0.27960900E+02, 0.34489700E+02, -.50856000E+02, 0.17324200E+02, -.58375200E+02, 0.36376100E+02, -.40023700E+02, 0.20091400E+02, 0.22079600E+02, -.21575000E+02, 0.24855700E+02, -.12638300E+02, 0.16758900E+02, -.25977500E+02, 0.45364800E+02, -.77702200E+02, 0.35706200E+02, 0.34366600E+02, -.32679700E+02, 0.57653600E+02, 0.27291300E+02, -.25422000E+02, 0.13895300E+02, 0.12103700E+02, 0.10348000E+03, -.52938100E+02, -.54242900E+02, 0.39620000E+02, 0.40860900E+02, -.70137600E+02, -.84061300E+02, -.56711800E+02, -.20115700E+02, 0.30754400E+03, -.15502000E+03, -.15151500E+03, -.51093400E+02, -.30569600E+02, -.93641200E+02, 0.10294900E+02, -.98848700E+02, -.36444900E+02, 0.19707200E+02, -.10305000E+02, -.68885100E+01, 0.70208800E+02, 0.67629900E+01, -.29920000E+02, -.58450200E+02, -.61156700E+02, 0.61677000E+02, -.16642300E+01, 0.17078900E+01, -.27250800E+00, -.24990900E+00, -.65774400E+00, 0.47116100E+01, -.52533600E+01, 0.28537400E+01, 0.84293900E+01, 0.30170700E+02, -.45281300E+01, 0.52292500E-01, -.41236600E+01, -.72140300E+01, 0.92842000E+01, -.26037800E+02, -.18058800E+02, 0.20656500E+02, 0.37388800E+02, -.85019000E+01, -.27393700E+02, 0.52047000E+01, 0.52176500E+01, -.70790500E+02, -.24833500E+02, 0.21615900E+02 },
            { 0.32354800E+01, 0.50133800E+00, -.14064100E+01, 0.86042400E-01, -.39718700E+01, -.48261500E+00, -.15459200E+01, 0.12170100E-01, 0.14452100E+01, -.10013800E+01, 0.14327300E+00, -.14259300E+01, 0.33498600E+00, 0.57213000E-01, -.31925600E+00, 0.49043100E+00, -.84737100E+00, -.18975300E+00, 0.22556500E+01, 0.50997500E-01, -.32768100E+01, 0.69490900E+00, 0.62442900E+00, 0.35593200E+01, -.63083000E+00, -.65094800E+00, -.87532700E-01, 0.27000700E+00, -.60414100E-01, -.10245300E+00, 0.17243700E-01, -.53263700E+00, -.93671000E-01, -.38254600E+00, -.54809400E+00, 0.35361800E+01, -.17511600E+00, 0.69121200E-01, 0.85320700E-01, 0.13062600E+01, -.15160000E+01, 0.43699600E+00, -.45630400E-02, 0.14660000E+01, -.56712200E+00, -.15387900E+01, 0.65875400E+00, -.19232700E+01, -.57903400E+00, -.40489700E-01, 0.17101000E+01, 0.16509900E+00, -.11480200E+01, 0.30182800E-01, -.45711700E+00, -.97432800E+00, 0.45582700E+00, 0.14027900E+00, 0.38396600E+00, -.15799200E+01, -.55907700E+00, -.29245100E-01, 0.21520500E+00, -.64673600E+00, 0.81479800E+00, -.72850600E+00, -.19834800E+01, -.23793800E+00, 0.82342100E+00, -.25344900E+01, -.78410000E+00, -.16725500E+01, 0.60612500E+00, -.63882600E-01, 0.30348900E+00, 0.17663300E+01, 0.56353200E+00, -.18234100E+00, 0.12574000E+01, 0.35330300E-01, 0.48262900E+00, 0.10102800E+01, -.92709400E+00, 0.12137700E+00, 0.81102500E-01, -.28735600E+00, 0.12581800E+01, 0.25081900E+00, 0.35596700E+01, 0.10701600E+00, -.39382400E-01, 0.83984700E-01, 0.36802000E-01, -.35358800E-01, -.75791100E+00, 0.15740900E+00, 0.10296100E+00, 0.19470200E+01, -.22140500E+00, -.55015700E+00, 0.27746900E+00, 0.19695800E+00, 0.10576200E-01, -.24490500E+01, 0.11334900E+01, 0.12601000E+00, 0.16729900E+01, -.14957800E+01, -.40592600E+01, -.33473500E+00, 0.95777300E+00, -.38530700E+01, -.82513200E+00, 0.51339700E+01, 0.40815500E+01, 0.60595700E+00, -.11415600E+02, 0.13897800E+01, 0.17159600E+00, 0.32845100E+00, 0.38126200E+00, 0.45974200E+00, 0.42179200E-01, 0.52258400E+00, 0.42582700E+00, 0.12101800E+01, 0.10533600E+01, -.92401700E-01, 0.20590600E+01, -.36652100E+00, 0.10956800E+00, 0.10211000E+01, 0.60844000E+00, -.85286300E+00, 0.14226500E+01, -.90204500E+00, -.68654000E+00, -.71739300E+00, 0.15443900E+01, -.10060600E+01, -.27246100E+00, 0.70958400E-01, 0.14340000E+00, 0.30057100E+00, 0.45780400E-02, -.12079900E+00, -.18688400E-02, -.25117100E+01, -.21363000E+00, 0.94832500E+00, 0.22095000E-01, 0.13142700E+00, 0.55999700E+00, 0.39622300E+00, 0.85474900E+00, 0.57322800E+00, -.99126600E+00, 0.11354200E+02, -.36686900E+02, -.70918100E+02, -.36033100E+02, 0.17835100E+02, -.85574300E+00, 0.43812000E+01, 0.59229200E+01, -.95887200E+01, 0.61368400E+01, -.99730800E+01, 0.13098000E+02, -.17057300E+02, 0.53314400E+01, 0.60782900E+02, -.29380400E+02, -.33579300E+02, 0.11573400E+02, 0.19340100E+02, -.37144900E+02, 0.47925200E+02, -.42673400E+02, 0.25295800E+02, -.13495100E+03, 0.64937200E+02, 0.68213100E+02, -.14381700E+02, 0.42330000E+02, 0.18895900E+01, 0.54855700E+01, 0.43215700E+01, 0.49969700E+02, -.30459000E+02, 0.11686000E+02, 0.10933000E+02, -.13725200E+01, 0.21951300E+02, 0.18061300E+02, -.19602300E+02, 0.31905300E+01, 0.54278800E+01, 0.21141100E+03, -.10650300E+03, -.10070800E+03, 0.31306000E+02, 0.26953900E+02, -.94855200E+02, -.83773900E+02, -.86366800E+02, -.24261900E+02, 0.27886600E+03, -.14130400E+03, -.13702800E+03, -.36114400E+02, -.22343000E+02, -.87511400E+02, 0.21484600E+02, -.66934700E+02, -.35350900E+02, 0.14044700E+02, -.72816400E+01, -.85004300E-01, 0.17358800E+02, 0.20443900E+02, -.21839600E+02, -.45917700E+02, -.70942100E+02, 0.24284500E+02, 0.23122600E+01, -.12665600E+02, 0.58386900E+01, -.78392500E+00, 0.10125900E+02, 0.50841100E+01, 0.26917400E+02, -.10440600E+02, 0.29720300E+00, 0.23680600E+02, 0.47127900E+00, -.43875400E+00, 0.42479600E+00, -.82897600E+01, 0.11278000E+02, -.12554600E+02, 0.14962500E+02, 0.21770500E+02, 0.44179900E+02, 0.57362600E+01, -.29349300E+02, 0.75373900E+01, 0.71605900E+01, -.60266300E+02, -.43446700E+02, -.14510100E+01 },
            { -.10716600E+01, -.10458800E+01, -.10885500E+00, 0.64767500E+00, 0.26099400E+01, 0.29112900E+00, 0.44757300E+00, -.28195100E+00, -.81948400E+00, 0.15931900E+00, -.94075400E+00, -.47054400E+00, 0.54824900E+00, 0.10366900E+00, -.23603500E+00, -.19464400E+00, 0.79749100E+00, 0.54019300E+00, -.76171900E+00, -.74252000E-01, 0.46827100E+00, 0.92349200E+00, 0.14148200E+01, 0.10939500E+00, -.16127700E+00, 0.37689600E+00, -.33499900E+00, -.36797700E+00, -.17610600E+00, -.51956500E+00, -.63256900E+00, -.86866500E-01, -.88398100E-02, 0.14762200E+00, -.17472900E+00, -.37791200E+01, -.24766400E+00, 0.10487100E+00, 0.13473800E+00, -.46435900E+00, -.11154400E+01, 0.40328000E+00, 0.40833700E+00, 0.23531700E+00, -.21923800E+00, 0.12182200E+00, -.37787400E+00, -.16706400E+01, 0.56575800E+00, 0.32821600E+00, 0.53800400E+00, 0.37405300E+00, 0.53209800E+00, -.54972900E+00, 0.23099400E+00, 0.35276300E+00, -.60119300E+00, -.13388100E+00, -.27323400E+00, 0.17671600E+00, -.34009600E+00, 0.42561200E+00, 0.33540100E+00, -.21336100E-01, 0.85998500E-01, -.95089100E+00, -.53257900E+00, 0.26534100E+00, -.13856800E+01, 0.41522700E+01, 0.56286700E+00, 0.74892100E+00, -.29372900E+00, 0.21724900E+00, 0.85370100E-01, -.12210900E+00, -.74405400E-01, 0.85627600E-02, -.81242400E-01, 0.11160000E+00, -.31879300E+00, 0.63748000E-01, 0.32462700E+00, 0.36340000E+00, -.10915100E+00, -.17967000E+00, -.14760700E+01, -.78152900E+00, -.31199800E+01, -.13016900E+00, 0.73877000E-02, -.72038000E-01, 0.84295400E-01, -.19724700E+00, -.47681600E-01, -.17227700E+00, -.17676100E-01, -.62422100E+00, 0.29786000E-01, 0.83166600E-01, -.17314300E+00, 0.11689800E+00, -.10904900E+00, -.18992600E+00, 0.39275300E-01, -.10836600E+00, 0.20786700E+00, -.44944400E+00, -.12869800E+00, -.73354500E-01, -.49277200E+00, -.18908600E+01, -.31092700E+00, -.97839100E+00, -.68761700E+00, -.36403000E-02, 0.70886400E+00, 0.21661400E+00, 0.20124800E+00, -.10250400E+00, 0.19932200E-01, 0.53154900E+00, 0.14010300E+00, 0.11939500E+01, 0.61981900E+00, 0.38537400E+00, 0.27554900E+00, -.37412700E-01, 0.72308700E-02, -.16445600E+00, -.41943900E-01, 0.13419200E+00, 0.73828100E-02, 0.88606800E-01, 0.95389100E-01, -.16003800E+00, 0.15552400E+00, -.16332400E+00, -.13463600E-01, -.12024500E+00, -.51951200E+00, 0.32107700E-01, -.48408900E-02, 0.11271800E-01, -.13100700E+00, 0.59400100E-01, 0.78700400E-01, -.17227800E+01, -.17237100E+00, 0.40027500E+00, -.22396700E-02, 0.58237700E-01, 0.74853000E+00, 0.35270700E+00, -.15098900E+00, 0.21288300E+00, 0.99902800E-01, 0.34309100E+00, 0.11319000E+02, 0.24061200E+02, 0.85072100E+01, -.47702700E+01, -.21497000E+02, 0.93930100E+01, 0.82641100E+01, 0.24773900E+01, 0.13830400E+01, 0.99268500E+01, -.16183600E+01, 0.10396400E+02, 0.17013600E+01, -.41760500E+02, 0.20718600E+02, 0.21815900E+02, -.41563700E+01, -.93425700E+01, 0.23763500E+02, -.10803000E+02, 0.24759300E+02, -.14941700E+02, -.16979400E+02, 0.97947400E+01, 0.90261000E+01, 0.13665300E+02, -.16713200E+02, 0.10920500E+02, -.85010300E+01, 0.23455800E+02, -.12667100E+02, 0.17899600E+02, -.89414000E+01, -.87649900E+01, 0.10350500E+02, -.82983000E+01, -.17215200E+02, -.70044800E+01, -.13524100E+02, 0.12092800E+02, -.64014800E+02, 0.30586700E+02, 0.29383200E+02, -.15040800E+02, -.27421700E+01, 0.35012500E+02, 0.39509400E+02, 0.20515400E+02, 0.19057600E+02, -.12226900E+03, 0.61637900E+02, 0.61750600E+02, 0.15694100E+02, 0.89596000E+01, 0.37731400E+02, -.27675300E+01, 0.29100200E+02, 0.10593700E+02, -.34737100E+02, 0.17461400E+02, 0.16176900E+02, -.20986600E+02, -.66473100E+01, 0.26160900E+02, 0.39766700E+02, 0.48808000E+02, -.16805300E+02, -.12511000E+01, -.91334700E+00, -.16387500E+01, -.44113800E-01, -.86313900E+01, -.72763400E-01, -.46586200E+01, -.24863800E+01, 0.13534200E+01, -.35694400E+01, -.70566600E+00, 0.50597300E-01, -.73602800E+00, 0.10449800E+00, -.27248900E+01, 0.54749600E+01, 0.12690700E+02, -.60104400E+01, -.10113800E+02, -.13748000E+01, 0.10326300E+02, -.13529200E+01, -.55830600E+01, 0.28549200E+02, 0.16985300E+02, -.37118500E+01 },
            { -.12054400E+01, -.42898400E+00, 0.16131000E+00, 0.51912500E+00, 0.15101200E+01, -.10451100E-01, 0.61813400E+00, -.22251000E+00, -.14647700E+01, 0.13706100E+00, -.20055100E+00, -.10620400E+01, -.31188900E+00, 0.50678300E+00, 0.19392200E+00, -.17753500E+00, 0.28316100E+00, -.31184900E+00, -.46006100E+00, 0.31257900E-01, 0.13371300E+01, -.11165300E+00, -.29561800E+00, 0.10927800E+01, -.24312400E-01, -.23038000E+00, -.52097800E+00, 0.92496700E-01, -.16386100E+00, 0.14394400E+00, 0.29177900E+00, 0.35003800E+00, 0.23353100E+00, 0.81278700E-01, -.29681300E-01, 0.16311100E+00, 0.18826100E-01, -.82009900E-02, -.56837300E-02, -.31977400E+00, 0.61287300E+00, -.23157600E+00, -.36680400E+00, -.62902600E+00, -.19649700E+00, 0.13525200E+00, 0.14745100E+00, 0.84039900E+00, -.47209800E+00, -.76791300E+00, -.62768000E+00, -.11927000E+01, 0.30734600E+00, -.15269500E+00, 0.31400900E+00, -.73152100E+00, 0.68342400E+00, -.91372500E-01, 0.31063800E+00, 0.48432200E+00, 0.18039800E+00, -.60887400E-01, 0.27471500E+00, 0.21822900E+00, 0.27220200E+00, -.62186400E+00, -.32311500E+00, -.34913000E-02, -.22753200E+00, -.82100900E+00, -.15278900E+00, -.14003800E+00, -.95095600E-01, 0.12986100E+00, 0.54512100E-01, -.34124200E+00, 0.57645700E-01, -.24194000E-01, -.35958700E+00, -.31550300E+00, 0.19491500E+00, 0.31087800E+00, -.52510700E+00, 0.73132400E-01, 0.14011500E+00, 0.25464700E-01, -.96281600E+00, 0.16014000E+00, -.91683600E+00, -.35193900E-01, 0.10463800E+00, -.59294900E-02, 0.26107800E-01, -.30510200E+00, -.31544200E+00, -.35885400E+00, -.43206300E+00, -.63692800E-01, -.22487100E+00, 0.17720200E-01, 0.86383700E-01, 0.13950000E+00, 0.23070300E+00, -.56129800E+00, -.22026900E+00, -.48394300E+00, -.13535900E+01, 0.14770200E+01, 0.29149900E+01, 0.36006300E-01, 0.33408400E+00, 0.51837100E+01, 0.34059300E+00, -.46324100E+00, -.27729300E+01, -.15923600E+00, 0.31097600E+01, -.68276100E+00, 0.31330200E+00, -.48602200E+00, -.11701500E+00, -.39966000E-01, 0.19289600E+00, 0.49469300E+00, -.17167400E+00, 0.35941600E+00, 0.94658000E-01, -.75096700E-01, 0.41156000E+00, 0.33145100E+00, -.31388100E-01, -.14811700E+00, 0.26299000E+00, 0.13122000E+00, 0.47423500E+00, 0.82103000E-01, 0.20526600E+00, 0.28686000E-01, 0.26125700E+00, 0.22877300E+00, 0.30426700E+00, 0.18299800E-01, 0.14531000E-01, -.29508900E+00, 0.96845000E-01, -.18561000E+00, -.24665700E+00, -.75207700E+00, -.17859100E+00, 0.65110100E+00, -.56205000E-01, 0.21060000E+00, -.20794900E+00, -.23596200E+00, -.43349800E-01, -.74474800E+00, 0.30192100E-01, -.57820600E-01, 0.13075300E+00, -.88020300E+01, -.41555400E+01, -.18753400E+01, -.40037400E+02, 0.20765500E+02, 0.19912800E+02, -.41142000E+01, -.66799300E+01, 0.16792600E+02, -.83228000E+01, 0.23022100E+02, 0.10743900E+02, 0.23752100E+02, -.11528500E+02, -.11369700E+02, 0.13314300E+02, 0.10325100E+02, -.10044500E+02, -.15070300E+02, -.10178900E+02, 0.21499100E+00, -.66114900E+02, 0.32700500E+02, 0.30980100E+02, 0.18372200E+02, 0.49783200E+01, 0.77298600E+01, -.31953400E+02, 0.39143200E+02, 0.24774600E+02, 0.66046100E+02, -.33988800E+02, -.32275700E+02, 0.26746300E+02, 0.12818800E+02, -.62649100E+02, -.82753100E+02, -.48059100E+02, 0.38112300E+02, -.10109000E+03, 0.51388600E+02, 0.51952800E+02, 0.15581600E+02, 0.15802300E+02, 0.19452900E+02, 0.13714400E+02, 0.48633000E+02, 0.14069600E+02, 0.28105500E+02, -.14169200E+02, -.17056400E+02, -.51639400E+01, -.12078900E+02, -.86760200E+01, -.47447300E+01, 0.12139800E+02, -.17509100E+02, -.17045700E+03, 0.85453000E+02, 0.80516100E+02, -.14574800E+02, 0.21452000E+02, 0.71241000E+02, 0.45062700E+02, 0.68150700E+02, -.80559300E+00, -.21842900E+01, -.66985300E+01, -.10996600E+01, 0.14375000E+00, 0.64309600E+01, 0.15896000E+01, -.18192500E+01, -.73485200E+01, 0.75336000E+01, 0.47871900E+01, -.36209700E+01, 0.17941800E+00, -.30968000E+01, -.71490800E+01, 0.70905800E+01, -.29035800E+01, 0.14564700E+01, 0.29129900E+01, 0.50483300E+01, -.12921300E+02, 0.29011500E+01, 0.11886000E+02, -.19746900E+01, 0.11135800E+02, 0.12302800E+02, 0.31471900E+01 },
            { 0.45393000E+00, 0.81906700E-01, 0.86144700E-01, -.16188700E+01, -.24915200E+01, -.59381600E-01, -.34434200E+00, 0.71434900E+00, 0.81194400E+00, -.80517400E+00, -.15742500E+01, -.13356000E+01, 0.15160400E-01, -.11843100E+00, 0.72688900E+00, 0.18732800E+00, -.81168900E+00, -.49848400E+00, 0.12077800E+01, -.74401900E+00, -.14387700E+01, -.35148000E+00, 0.77577700E+00, -.68101700E+00, -.10760100E+00, 0.49300900E-01, 0.39918400E+00, 0.77146700E-01, 0.10362400E-01, -.79782500E-01, 0.20460500E+00, -.62683900E+00, -.28884800E+00, -.57384300E+00, -.40789900E+00, 0.83743900E-01, -.94166800E+00, 0.37098900E+00, 0.53763100E+00, -.25623100E+01, -.33440800E+01, 0.15777200E+01, 0.10023400E+01, 0.21159900E+01, -.54542200E+00, -.97295100E+00, 0.31390000E+00, -.25690800E+01, -.33380600E+00, 0.73363800E+00, 0.16558700E+01, 0.19557500E+01, -.20459100E+00, -.73276800E+00, -.46113300E+00, 0.11763000E+01, -.23040900E+01, 0.10822900E+00, -.14427900E+00, -.79753900E+00, -.82671700E+00, 0.79559900E+00, 0.13727900E+00, -.54604400E+00, -.37139000E+00, 0.20911100E+00, 0.17386400E+01, -.15452900E+01, -.99837600E+00, 0.86960500E+01, 0.10267600E+01, -.17963200E+00, 0.22094000E+00, 0.27763300E+00, -.21696600E+00, 0.17172900E+00, -.34006800E+00, -.10617800E+01, 0.16409400E+00, 0.11993900E+00, -.33072400E+00, -.58955900E+00, 0.18655600E+00, -.68120000E+00, 0.12528700E+00, 0.16462300E+00, 0.16189600E+01, -.27145100E+00, 0.21234300E+01, 0.93616200E-01, -.11175900E+00, 0.51534700E-01, -.14044400E+00, 0.83641700E+00, 0.51586200E+00, 0.28428200E+00, 0.85152400E+00, 0.56900900E-01, 0.34803200E+00, -.11783600E-01, 0.20871900E-01, -.36845500E+00, -.60215900E+00, -.15101400E-01, 0.23928000E+00, 0.97111400E+00, 0.97543500E+00, -.95084400E+00, -.46988400E+00, 0.49993400E-01, -.10376900E+00, -.13048000E+01, -.10286900E+00, -.10861300E+01, 0.18582700E+01, 0.19171900E+00, -.35170200E+01, -.23997100E+00, -.43839100E+00, 0.38991500E+00, 0.88047200E-01, 0.60023800E-01, -.82540900E-01, -.10717200E+01, -.31346900E+00, 0.86691200E-01, 0.38027100E+00, -.69884500E-01, -.94028500E-01, 0.58363700E-01, 0.14231600E+00, 0.48571100E+00, -.38454400E+00, -.74436700E+00, -.99167300E+00, -.17416100E+00, -.18985600E+00, -.35639700E+00, 0.20140100E+00, -.62180800E+00, 0.33247600E-01, -.19000100E+00, 0.12172200E+00, -.56850500E+00, -.34731700E-01, 0.95455800E-01, 0.34691200E+00, -.14865900E+01, 0.18572900E+00, 0.15396300E+00, -.45880100E-01, -.33744400E+00, -.41865300E+00, -.53160200E+00, 0.21795400E-02, 0.41271700E+00, -.21171800E+00, 0.88966500E-01, -.72818300E+00, -.48039200E+00, -.80238000E+01, -.15952800E+01, -.10543500E+02, 0.55166700E+01, 0.28971200E+01, -.43233300E+01, 0.36651000E+00, 0.75557400E+01, 0.44921900E+01, 0.94102600E+01, 0.23260100E+01, 0.55087300E+01, -.26431800E+01, -.26843100E+01, -.62739000E+01, -.51775100E+00, 0.45235700E+01, -.19916000E-01, -.35765300E+01, 0.28799700E+01, -.84447700E+01, 0.54472300E+01, 0.52934500E+01, -.25825200E+01, 0.42966100E+01, -.93890700E+01, -.27231800E+02, 0.19085600E+02, 0.23974600E+01, 0.79628000E+01, -.61835000E+01, -.44375600E+01, 0.74906200E+01, -.94720800E+00, -.11569600E+02, -.28547500E+01, -.83863900E+01, 0.61242900E+01, -.33218500E+02, 0.13213700E+02, 0.15574700E+02, 0.29348400E+01, -.92382200E+01, 0.17078200E+02, 0.33648500E+02, 0.15322500E+02, 0.46707900E+00, 0.91625200E+02, -.46397500E+02, -.44379400E+02, -.60957000E+01, -.65808600E+01, -.35057200E+02, -.15190200E+02, -.26526100E+02, -.12523200E+02, -.29181500E+01, 0.93850000E+00, 0.27055200E+01, -.80382600E+01, -.70267800E+01, 0.67270200E+01, 0.11689200E+02, -.54996900E+00, -.66144100E+01, -.82443000E+00, 0.10897600E+01, 0.10328600E+01, -.16420400E+00, 0.12115800E+00, 0.62448800E+00, -.17825000E+01, 0.48337600E+00, 0.20980300E+01, 0.14048800E+00, -.74875100E+00, -.47776800E-01, -.73349800E+00, 0.10386200E+01, -.22646100E+01, 0.51957500E+01, -.67243200E+01, -.49239400E+01, 0.74565000E+00, -.13806800E+01, 0.20132000E+01, 0.34847300E+01, -.35987400E+01, 0.16681800E+02, -.34909600E+01, 0.16801100E+01 },
            { 0.32105500E+01, 0.16175300E+00, -.19185300E+01, 0.49773600E+00, -.34083300E+01, -.58874600E+00, -.15823500E+01, -.11456500E-01, 0.17846400E+01, -.73058600E+00, -.61013800E+00, -.34569400E+01, -.40244700E+00, 0.67068800E+00, -.40680600E+00, 0.69232600E+00, -.14225500E+01, 0.24013300E+00, 0.10860300E+01, 0.25680000E+00, -.20314200E+01, 0.78525000E+00, 0.79282100E+00, 0.30012700E+01, -.47392300E+00, -.88940700E+00, -.39346700E+00, 0.26352200E+00, -.26588000E+00, 0.62514200E+00, -.82518900E-01, -.52483400E+00, -.26253800E+00, -.90949500E+00, -.56185000E+00, 0.20779000E+01, 0.84457100E+00, -.32129400E+00, -.55543200E+00, 0.16147900E+01, 0.37918700E+01, -.99717800E+00, -.68543000E+00, -.12365600E+01, -.84812900E-01, -.88453600E+00, 0.10433300E+01, -.30704900E+01, 0.22392300E-01, -.12477800E+01, 0.66058400E+00, -.22125300E+01, -.10552500E+01, 0.78428200E+00, -.59399500E-02, -.78187400E+00, -.21056100E+01, -.67871500E-01, 0.76987500E+00, -.13768100E+01, -.58805900E+00, 0.17576000E+00, 0.26918200E+00, -.49962600E+00, 0.10447100E+01, -.17874400E+01, -.37704900E+01, 0.21132400E+01, -.10989700E+01, 0.67876800E+00, -.67851200E+00, 0.34619100E+00, 0.69109200E+00, 0.16874200E-01, 0.16627800E+00, 0.15731200E+01, 0.73021500E+00, -.46561200E+00, 0.13801800E-01, -.57134800E-01, -.51452600E+00, 0.79372200E+00, -.53664900E+00, 0.12938800E+00, -.23034600E+00, -.69379700E-01, 0.10236100E+01, 0.25767600E+00, 0.42908000E+01, 0.10579500E+00, 0.15884000E+00, -.87269400E-01, -.12276200E+00, -.78038600E+00, -.13871900E+01, 0.10670600E+00, -.12805300E+00, 0.27484600E+01, -.35760600E+00, -.53822800E+00, 0.75539600E-01, 0.22756100E+00, 0.10269800E+01, -.34252300E+01, 0.14902300E+01, 0.43502300E+00, 0.27023500E+01, -.29389200E+01, -.95420600E+01, -.56938600E+00, -.12431600E+01, -.16716100E+02, -.25639400E+01, 0.37229600E+01, 0.86329800E+01, 0.91947800E+00, -.62438800E+01, 0.23097400E+01, -.18057100E+00, 0.74463100E+00, 0.72023000E+00, 0.20511700E+01, 0.55241800E+00, 0.20179100E+01, 0.22684200E+01, 0.12360800E+01, 0.13164600E+01, -.57065900E+00, 0.12746400E+01, -.65898100E+00, 0.21113900E+00, 0.55903300E+00, 0.14813800E+01, -.40676200E+00, 0.23627900E+01, -.99600400E+00, -.16697600E+00, 0.64980100E+00, 0.97104500E+00, 0.10800600E+01, -.92013600E+00, 0.60320700E-01, -.20793800E+00, 0.18231100E+00, -.14046700E+00, -.21577700E+00, -.34154300E+00, 0.19881500E+00, 0.71449300E-01, 0.13625600E+00, 0.24010500E+00, 0.32022400E+00, 0.15876700E+00, -.87800100E+00, -.61291900E+00, -.35701300E-01, 0.17250500E+00, 0.43402400E+00, 0.39620300E+00, -.19215000E+01, 0.40704700E+00, -.14766900E+02, -.59223400E+02, 0.30342900E+02, 0.32960500E+02, 0.11526300E+02, -.71996500E+01, 0.22144700E+02, -.19068900E+02, 0.25185800E+02, 0.16973800E+02, 0.46043500E+02, -.22203400E+02, -.24694400E+02, 0.35855400E+02, 0.23294900E+02, -.24353600E+02, -.40881900E+02, -.15845700E+02, -.75134400E+01, -.13806800E+03, 0.68882500E+02, 0.65522100E+02, 0.23427800E+02, -.10840100E+02, 0.53525700E+02, -.20851000E+01, 0.59500200E+02, 0.34626200E+02, 0.12311900E+03, -.63513400E+02, -.58364800E+02, 0.37830400E+02, 0.34538700E+02, -.11008400E+03, -.15001500E+03, -.10573100E+03, 0.77845900E+02, -.12028600E+03, 0.61397800E+02, 0.65858600E+02, 0.21835300E+02, 0.62637200E+02, -.22373000E+01, -.40756700E+02, 0.19533400E+02, 0.38296600E+02, -.83907200E+02, 0.41943000E+02, 0.36456100E+02, -.57486000E+01, -.33258300E+01, 0.30576700E+02, -.35109400E+01, 0.27309400E+02, -.45559800E+01, -.27585200E+03, 0.13874400E+03, 0.13398800E+03, -.21284900E+02, 0.24369800E+02, 0.12954600E+03, 0.11085400E+03, 0.15123200E+03, -.97731000E+00, -.25064400E+01, -.76875800E+01, -.54504000E+01, 0.14319100E-01, -.72824000E+01, 0.26189400E+01, -.16219100E+02, -.89822100E+01, 0.77112300E+01, -.35106900E+01, -.49783300E+01, 0.18319900E+00, -.42744600E+01, -.97303100E+01, 0.10398800E+02, -.16591200E+02, 0.52746500E+01, 0.21977700E+01, -.81803500E+01, -.16918500E+02, 0.53811300E+01, 0.20834000E+01, -.94859200E+01, -.22035000E+02, 0.28400100E+02, 0.13974100E+02 },
            { 0.19868400E+01, 0.14578900E+00, -.72471200E+00, 0.90010600E-01, -.85145500E+00, -.17998200E+00, -.32199700E+00, -.25393900E+00, 0.37341900E+00, -.27017700E+00, 0.58362100E+00, 0.59176200E+00, 0.11990600E+00, -.37234200E+00, -.26570700E+00, 0.28899600E+00, -.82238100E+00, -.16954600E+00, -.24985500E+00, 0.17894800E+00, 0.75002600E+00, -.19419300E+01, -.65396100E+00, -.33157500E+01, -.21088300E-01, -.48230000E+00, -.37099400E+00, -.17755300E+00, -.18533100E-01, 0.57237400E+00, 0.81960600E+00, 0.35034600E+00, -.27525800E+00, 0.94189500E+00, 0.81410500E+00, 0.20617500E+01, -.13078400E+00, 0.45703200E-01, 0.86912700E-01, -.12733100E+01, -.10537300E+01, 0.31082500E+00, 0.36495400E+00, 0.27642700E+00, -.50636000E+00, 0.99440500E-01, 0.77341100E+00, 0.13651300E+01, 0.77752500E+00, -.80412700E+00, -.10999900E+01, -.61276800E+00, -.18184300E+00, 0.19531900E+00, 0.37811900E+00, -.51279600E+00, -.15869400E+01, -.20424000E+00, 0.49324600E+00, 0.22181400E+00, 0.70246200E-02, 0.18545400E+00, -.20576100E+00, 0.22679100E+00, 0.12017300E+00, -.22630400E-01, -.63288800E+00, 0.59451200E-01, -.86188100E-01, 0.11000600E+00, -.41723000E-01, 0.83969000E+00, 0.16126900E+00, -.10356900E+00, 0.12157000E+00, -.92660000E-01, -.41716600E-02, 0.57901800E-02, 0.35859700E+00, 0.60620400E+00, -.70706100E+00, -.42424400E-01, 0.85810500E+00, 0.11270800E+00, -.24115700E+00, -.25645300E+00, -.15936100E+01, -.55937400E+00, -.18949400E+01, -.47195400E-01, 0.18004200E+00, -.11960900E+00, -.47132300E-01, -.55621800E+00, 0.21049000E+00, -.87263300E+00, -.54937600E+00, -.81553100E+00, 0.27628000E-01, 0.32184400E+00, -.20368100E+00, -.11109700E+00, -.12796900E+00, 0.28522600E+01, -.67903000E+00, -.10447600E+01, -.52579300E+00, 0.26386500E+00, 0.94065700E+00, 0.14355500E+00, 0.16190800E+00, -.24493000E+00, 0.34951600E+00, 0.12427600E+01, 0.15692100E+01, 0.32078800E-01, -.23946900E+01, -.40621800E-01, -.10945900E+00, 0.36142900E-02, -.15068500E+00, 0.13126300E+01, 0.25967400E+00, 0.64546700E+00, 0.32645200E+00, -.13432100E+00, -.61191900E+00, -.22798000E+00, -.19198100E+00, 0.33691000E+00, -.35320600E-01, 0.29884700E+00, 0.80169000E-02, -.43926700E+00, -.35095800E+00, 0.49889100E-01, 0.18472600E+00, 0.26293100E-01, -.50013400E-01, -.12374200E+00, -.36668000E+00, -.26181600E-01, 0.44436700E-02, 0.46827400E-01, 0.16039800E-02, 0.15217200E+00, -.57772800E-01, 0.77344200E+00, 0.17722200E+00, -.38954300E+00, 0.11194000E+00, -.17538200E+00, -.15421500E+00, 0.59201800E-01, -.12614700E+00, -.15515000E+00, -.13963500E+00, -.19300700E+00, -.38565600E+00, -.60349800E+00, -.81806700E-04, -.19629600E+00, -.43305600E+02, 0.22040700E+02, 0.22828100E+02, -.34120000E+01, -.67778800E+01, 0.16755700E+02, -.12545900E+02, 0.26793100E+02, 0.91391000E+01, -.98703000E+01, 0.48968000E+01, 0.43695800E+01, 0.84714800E+01, 0.56856900E+01, 0.22722000E+01, -.17159200E+02, 0.44070700E+01, 0.77457200E+00, -.70325300E+02, 0.34634500E+02, 0.33635000E+02, 0.19279500E+02, -.85474800E+01, 0.21234500E+02, -.29195600E+02, 0.63289100E+02, 0.14797600E+02, 0.63205400E+02, -.31629100E+02, -.32215900E+02, 0.29379200E+02, 0.31813600E+01, -.53803500E+02, -.65730900E+02, -.38507200E+02, 0.38155400E+02, -.12339500E+03, 0.63736800E+02, 0.61835500E+02, 0.24937100E+02, 0.29210300E+02, 0.22169800E+02, 0.39612600E+02, 0.42217500E+02, 0.38080900E+02, 0.10702900E+02, -.54029600E+01, -.75851400E+01, 0.72013700E+00, -.12854200E+01, -.26600400E+01, -.99349800E+01, -.56594000E+01, -.81671800E+01, -.22697400E+03, 0.11349100E+03, 0.11022400E+03, -.16355000E+02, 0.34888100E+02, 0.89241000E+02, 0.46836100E+02, 0.79802900E+02, -.13071900E+01, -.27942600E+01, -.60035600E+01, -.29341700E+01, 0.22717300E+00, 0.10300600E+02, 0.23768800E+01, -.74581600E+01, -.87547100E+01, 0.10491700E+02, 0.10303400E+02, -.44711500E+01, 0.25400900E+00, -.39846100E+01, -.83582400E+01, 0.57668700E+01, 0.17112200E+00, 0.45503900E+01, 0.39997800E+01, 0.10702800E+02, -.14647200E+02, 0.72990500E+01, 0.40295400E+01, -.31868500E+01, 0.26387800E+02, 0.11926700E+02, -.24722000E+01 },
            { 0.48521400E+01, 0.18530800E+01, -.12194900E+01, -.87853100E+00, 0.13175800E+00, 0.43352100E+00, -.17403300E+01, 0.48460700E+00, 0.17483000E+01, -.19242000E+01, -.22648200E+01, -.82967700E+01, 0.11021300E+01, 0.13632100E+01, -.20249100E+01, 0.73575200E+00, 0.67072300E+00, -.39378100E+00, 0.26253200E+01, -.30747800E+00, -.17391200E+01, 0.17939300E+01, 0.15389200E+01, 0.51061800E+01, -.69020000E+00, 0.25332700E+00, 0.13396700E+00, -.55718800E+00, 0.85730300E+00, -.71629100E+00, -.23360800E+01, -.15690600E+01, -.66127300E+00, 0.22691300E-01, -.23299200E+00, -.31886100E+01, -.44523200E+00, 0.19182700E+00, 0.21436500E+00, -.13229000E+01, -.52098900E+01, 0.12489200E+01, 0.13770600E+01, 0.25033600E+01, -.47363200E+00, -.12102600E+01, -.13468400E+01, -.35855500E+01, 0.45424000E+01, 0.17813100E+01, 0.22963400E+01, 0.23396400E+01, 0.82270000E+00, -.29263600E+00, -.96031400E+00, 0.18286600E+01, 0.35053100E+01, -.96180100E-01, -.13310500E+01, -.10502400E+00, 0.10870700E+01, -.65257000E+00, -.66342300E+00, -.39694200E+00, -.19649500E+00, -.61900800E+00, -.76261600E-01, -.85021100E+00, -.26169900E+00, 0.10864400E+02, -.49037300E+00, 0.35867300E-01, 0.30318200E+00, 0.36013700E+00, -.60487300E-01, 0.83014900E+00, 0.40199300E+00, 0.25342400E+00, -.12981300E+01, -.61717700E+00, -.25297300E+00, -.11024200E+00, -.13129200E+00, 0.96171300E-01, -.99383100E+00, 0.72910500E+00, -.11501400E+01, -.69397400E+00, -.25916300E+01, -.63258100E-01, 0.58555200E-01, -.36097700E+00, -.10197900E+00, 0.19057000E+01, 0.15760800E+01, -.55523100E+00, -.11688800E+01, -.15181100E+01, 0.11291600E+01, 0.12121800E+00, -.85729900E+00, -.14431800E+00, -.11423500E+01, -.10225500E+01, -.36395400E+00, -.64896600E+00, 0.15506600E+01, -.28703000E+01, -.77615100E+01, 0.19155200E+00, 0.86677600E+00, -.12756600E+02, -.39814700E+01, 0.30767700E+01, 0.13550400E+01, 0.25229900E+00, -.64169600E+01, 0.26598700E+01, 0.63576800E+00, -.89916000E-02, 0.60078300E+00, 0.10105200E+01, -.11020900E+00, -.81040700E+00, -.17146500E+01, -.59677200E+00, -.54419500E+00, 0.35031000E+00, 0.43874200E+00, -.69941900E+00, -.11213300E+00, -.10029100E+01, 0.94600700E+00, 0.66170300E+00, 0.13211900E+01, 0.22493800E+00, 0.84627700E-02, 0.36744800E+00, 0.10572600E+01, 0.76814000E+00, -.11790600E+01, -.39140800E+00, -.36922400E+00, 0.83326000E+00, -.77627100E+00, -.30755800E-01, -.18421400E+00, -.25910100E+01, -.33293000E+00, -.16051700E+01, -.13366600E+00, 0.72342900E+00, 0.19853000E+01, 0.18858700E+01, 0.23368000E+00, 0.17396200E+01, -.65060300E+00, 0.86956500E+00, 0.30148600E+00, -.39051500E+00, -.30987300E+00, 0.52253300E+00, -.54091500E+00, -.56579300E+01, -.46128200E+01, 0.90782600E+01, -.51710600E+01, 0.40892900E+01, 0.28681300E+02, -.29811200E+00, -.96200000E+01, -.19076200E+02, 0.91699000E+01, 0.10507000E+02, -.80035100E+01, -.94849000E+00, 0.57995700E+01, -.16549800E+02, 0.79106000E+01, -.90743700E+00, 0.44600400E+02, -.11840800E+02, -.17362300E+02, -.12506600E+02, 0.33412100E+01, -.37630500E+02, -.44172200E+02, -.70384200E+02, 0.13417900E+02, -.25676200E+02, 0.74965600E+01, 0.10097100E+02, -.38274400E+02, 0.98744800E+01, 0.27720100E+02, 0.35558900E+02, 0.10043600E+02, -.13617300E+02, 0.60932200E+02, -.43283600E+02, -.40348000E+02, -.48859600E+02, -.71743400E+02, 0.38715600E+02, 0.50803500E+02, 0.15441400E+02, -.73852900E+02, -.55206600E+02, 0.28634500E+02, 0.34581800E+02, -.37440500E+01, -.12396100E+01, 0.56724000E+01, -.17087400E+02, 0.69676700E+01, 0.70349800E+01, 0.10030800E+03, -.50330600E+02, -.44919100E+02, 0.28315200E+02, -.42106400E+02, -.34796200E+02, -.28703800E+02, -.14087900E+02, 0.91593400E+01, -.20828200E+00, -.45979100E+01, 0.52796800E+01, -.69205800E-01, -.26308000E+02, -.34771900E+01, 0.20195100E+02, -.32166500E+01, -.46126200E+01, -.25671800E+01, 0.16976700E+01, -.19794400E-01, 0.12486900E+01, 0.10058300E+02, -.92256000E+01, -.60705000E+01, 0.15411900E+02, -.61251500E+01, -.12982500E+01, 0.63657200E+01, 0.40520300E+01, 0.45054100E+02, -.64594400E+01, 0.23829200E+02, -.22586800E+02, 0.51180900E+01 },
            { 0.34789400E+01, 0.24301500E+00, -.21139200E+01, 0.97640500E+00, 0.67112400E+00, 0.58982100E-01, -.13020800E+01, -.24233200E+00, 0.81791400E+00, -.23700800E+00, 0.12716300E+01, -.67021800E+00, -.50155300E-01, 0.33106700E+00, -.16094900E+01, 0.73181700E+00, -.71789200E+00, 0.37172000E+00, 0.21763500E+01, 0.63337500E+00, -.16341100E+01, -.18120100E+01, -.42271000E+00, 0.20258100E+01, -.74570600E+00, -.82764400E+00, -.15098300E+00, 0.30220500E+00, 0.52147200E+00, 0.50826700E+00, -.14609500E+00, 0.39950200E+00, -.14493500E+01, 0.10584700E+01, 0.93815100E+00, 0.12494200E+01, -.12671900E+00, 0.51513500E-01, 0.80124700E-01, -.53249400E-01, -.18575500E+01, 0.21794300E+00, 0.44554000E+00, 0.97720500E+00, -.33718100E+00, -.57796700E+00, -.10332200E+00, -.15812600E+01, 0.12860400E+01, -.42994200E+00, 0.12153800E+01, -.10685800E+01, -.84129600E+00, -.10917500E+00, -.32408700E+00, -.62227600E+00, 0.45849300E+01, -.89274700E-01, -.95913300E+00, -.30110700E+00, -.46605200E+00, -.67568500E+00, 0.23531000E+00, -.19652900E+00, 0.65849200E+00, -.11704200E+01, -.11202200E+01, -.21930900E+00, 0.80684700E+00, -.72424100E+01, -.36472100E+00, -.73767800E+00, 0.72788600E+00, -.11781400E+00, 0.11295900E+00, 0.12666600E+00, 0.40057500E+00, -.32981000E+00, -.21896200E+00, -.31065400E+00, 0.46747100E+00, 0.43647500E+00, -.72952300E+00, 0.22123400E-01, 0.21852100E+00, -.60033400E-01, 0.74862800E+00, 0.40452500E+00, 0.19352000E+01, 0.68487000E-01, -.24794000E-01, 0.93786500E-01, 0.69795900E-01, -.69168600E+00, -.80269700E+00, 0.15605500E+00, 0.89602300E-01, 0.10516100E+01, -.36592000E+00, -.35387500E+00, 0.28246200E+00, 0.18280500E+00, 0.43229800E+00, -.78771300E+00, 0.45800300E+00, 0.49027800E-01, 0.83676500E+00, -.77488500E+00, -.34381400E+01, -.37917300E+00, 0.22119100E+00, -.38566000E+01, -.79274500E+00, 0.20177800E+01, 0.66321400E+00, 0.30309600E+00, -.76265100E+01, 0.57870400E+00, 0.20481100E+00, 0.25912400E+00, 0.27810500E+00, 0.12456500E+01, -.12670900E-01, 0.70277700E+00, 0.54944500E+00, 0.43827800E+00, 0.74795500E-01, -.11972800E+00, 0.34537900E+00, -.37645600E+00, 0.49239300E-01, 0.50276600E+00, -.98832900E-01, -.10956500E+00, 0.14024900E+00, -.48466200E+00, -.73364000E-01, -.86844200E-01, 0.21169100E+00, -.61717200E+00, -.50779000E+00, 0.12498500E+00, 0.84919700E-01, -.90365500E+00, 0.65054500E-01, 0.23493000E-01, -.20035700E+00, -.19318800E+01, 0.15503400E+00, 0.17881800E+01, 0.21830600E+00, -.24761600E+00, 0.16848000E+00, 0.47249500E+00, 0.27183700E-01, 0.34285400E+00, -.54249600E+00, 0.47042200E+00, 0.29903600E+00, -.27244100E+00, 0.25047900E+00, 0.54962400E+00, 0.18400300E+00, 0.34349600E+00, -.69414300E+01, -.10723000E+02, -.45538700E+01, 0.31362500E+01, -.33836000E+01, 0.12583400E+02, -.86561200E+01, -.28765500E+02, 0.12980700E+02, 0.16419400E+02, -.15050300E+02, -.11621700E+02, 0.13225100E+02, 0.10943100E+02, 0.17915700E+01, 0.17133800E+02, 0.22494400E+02, -.15085200E+02, -.65464700E+01, -.34607400E+02, -.13752800E+02, 0.88501400E+01, 0.14988400E+02, 0.18107500E+02, -.23707200E+02, -.60113800E+02, 0.36188500E+02, 0.26319600E+02, -.12050300E+02, 0.13968100E+01, 0.41215900E+02, 0.60164000E+02, 0.33833500E+02, -.26193100E+02, 0.27819300E+02, -.76543000E+01, -.27438600E+02, 0.14961100E+02, 0.12291100E+01, -.65374600E+01, 0.16949500E+02, -.75895100E+01, 0.19255400E+01, 0.14482700E+03, -.72101300E+02, -.71786300E+02, -.46697900E+01, -.48081900E+01, -.38392300E+02, 0.84298600E+01, -.54949700E+02, -.54378700E+01, 0.18596400E+03, -.93636100E+02, -.87149100E+02, 0.21279800E+02, -.10702800E+02, -.89180700E+02, -.58023200E+02, -.99692800E+02, 0.94191600E+01, -.82704100E+00, 0.15200700E+02, -.37565400E+00, 0.50100800E+00, 0.97904700E+01, -.25299500E-01, -.27996000E+02, 0.13597500E+02, 0.13031000E+01, 0.13873200E+02, -.24859000E+00, 0.30261400E+00, -.25072600E+00, 0.70963700E+01, -.67196200E+01, 0.50146700E+01, -.28430800E+02, -.34046900E+00, 0.11025200E+02, 0.81675400E+00, -.30830300E+01, -.28117200E+02, 0.87865800E+01, -.89674900E+01, 0.11106400E+02, 0.33639400E+01 },
            { 0.23751900E+01, -.57078100E+00, -.88031300E+00, -.39129900E+00, -.36173600E+01, -.33950300E+00, -.10532500E+01, 0.15041200E-01, 0.80609200E+00, -.69606600E+00, -.50947200E+00, -.90924800E+00, -.75766500E+00, 0.11322300E+00, -.34943300E+00, 0.48828600E+00, -.13454700E+01, 0.30991700E+00, 0.16058300E+01, -.44610400E+00, -.16375200E+01, -.91824300E+00, -.24956400E+00, 0.47201200E+00, -.49111800E+00, -.46797800E+00, 0.17329200E+00, 0.14869200E+00, -.38239000E-01, 0.71499800E-01, 0.20697200E+00, 0.15832200E+00, -.59732600E+00, -.19861400E+00, 0.19995300E+00, 0.29593100E+00, -.57217000E-01, 0.23335700E-01, 0.16950200E-01, 0.10932100E+01, 0.12154900E+00, 0.24012500E+00, 0.18529900E+00, 0.12331000E+00, -.17315600E+00, -.50086200E+00, 0.11295300E+01, -.21945300E+01, 0.57624000E+00, -.70291100E+00, 0.31452200E-02, -.36843700E+00, -.75056700E+00, 0.11836400E+00, 0.51789500E+00, -.68253700E+00, -.24790900E+01, -.56259900E-01, 0.25247400E+00, -.68858500E+00, 0.25149300E+00, -.17707700E+00, 0.14316500E+00, 0.46883000E+00, 0.41591100E+00, -.72011700E+00, -.19221500E+01, -.46452600E+00, 0.29067700E+00, 0.67690300E+00, 0.11060400E+00, -.46651200E+00, -.14360300E-01, -.14531100E+00, 0.13174800E+00, 0.33391400E+00, 0.40329900E+00, 0.24188200E+00, 0.60834200E+00, 0.57871800E+00, -.19096300E-01, -.15126500E+00, 0.43551800E+00, 0.53205400E+00, -.14470700E+00, -.36936100E+00, -.18846600E+01, -.65810500E+00, -.40794900E+01, -.10281600E+00, -.23803700E+00, -.39587900E-01, 0.12373500E+00, -.76293700E-01, 0.98368600E+00, -.84083600E+00, -.17967700E+00, -.21538900E+01, 0.44746600E+00, -.10604000E+00, -.30901600E+00, 0.19574700E-01, -.76186000E+00, 0.53452400E+01, -.11778800E+01, -.16356500E+01, -.73194200E+00, 0.46263700E+00, 0.31764900E+01, 0.47352700E+00, 0.18501600E+00, -.32557900E+01, 0.26364400E+00, -.86360700E+00, 0.93508700E+00, 0.66849800E-01, -.30865600E+01, 0.42836100E+00, -.20905100E-01, -.14792800E+00, -.56818400E-01, 0.93447100E+00, 0.56266400E+00, 0.84426800E+00, 0.45628700E+00, -.50308700E+00, -.80432500E+00, -.37916300E+00, 0.84237100E+00, -.16107300E+00, 0.96853800E-01, 0.70166400E+00, -.39634400E+00, -.22699600E+00, -.68804000E+00, -.65773500E+00, 0.10371100E+00, -.37117300E+00, 0.74948800E-01, -.75088400E-01, -.49576400E-01, -.21210200E+00, 0.77731000E-01, 0.24107700E+00, -.24215100E+00, -.56002500E-01, 0.40517900E+00, -.53053200E+01, 0.23615000E+00, -.14142800E+01, -.25238200E+00, -.29916400E+00, 0.22190700E+00, -.66464500E+00, -.14219300E+00, -.12603300E+00, 0.21907500E+00, 0.19301800E+00, 0.10880600E+01, -.54118600E+00, 0.10541400E+01, -.22072300E+00, 0.21274600E+00, -.23677200E+00, -.37108000E+00, -.15120100E+02, -.49812400E+01, -.42462400E+01, 0.12573100E+02, -.15663000E+02, 0.69726900E+01, -.17581300E+02, 0.91496300E+01, 0.93106900E+01, -.85205500E+01, 0.18615500E+01, -.22462300E+01, -.17779600E+01, 0.10575900E+02, -.11703800E+02, 0.37149800E+02, -.18527600E+02, -.19476000E+02, 0.64300000E+01, 0.11838000E+02, -.13006700E+02, -.85436400E+01, -.36208600E+02, 0.14997600E+02, 0.12342900E+03, -.61673900E+02, -.63022000E+02, 0.25224700E+02, 0.45087900E+01, -.69377500E+02, -.59808300E+02, -.80502200E+02, 0.98840200E+01, 0.18549900E+02, -.79647100E+01, -.94893700E+01, -.10565500E+02, -.17514400E+02, -.13998700E+01, -.15427800E+02, 0.35581000E+01, -.37231300E+02, -.13888600E+03, 0.69759100E+02, 0.66487300E+02, 0.30517200E+01, -.16353200E+01, 0.47870300E+02, 0.22877700E+02, 0.86873700E+02, 0.54665100E+01, -.58879100E+02, 0.30119600E+02, 0.28029500E+02, -.13919700E+02, 0.63789500E+01, 0.33452500E+02, 0.47155100E+02, 0.36574500E+02, -.75913000E+01, 0.75724500E+01, -.12173900E+02, 0.37232800E+01, 0.75717400E+00, -.73912900E+01, -.20154500E+01, 0.17461500E+02, -.89624200E+01, -.14201400E+02, -.93573300E+01, 0.50245600E+01, 0.92484800E-01, 0.51084100E+01, 0.80986800E+01, -.34993300E+01, 0.17589400E+01, -.30963600E+01, -.75011100E+01, -.93460000E+01, 0.63424100E+01, 0.39652500E+01, 0.23805500E+02, 0.92658800E+01, -.11798500E+02, 0.55645900E+01, -.44968200E+01 },
            { -.15815900E+01, 0.46801500E+00, 0.96243000E+00, -.25814100E+00, 0.10865400E+01, -.25008100E-02, 0.56072300E+00, 0.45465700E-01, -.18962000E+00, 0.59864500E+00, -.17580000E+00, 0.10957600E+01, 0.63924500E-02, -.16183800E+00, 0.43228700E+00, -.37139700E+00, 0.51463000E+00, -.16467900E+00, -.49869300E+00, -.96308800E-01, 0.91149000E+00, 0.95052500E+00, 0.18069500E+00, 0.10512600E+01, 0.16510600E+00, 0.46179300E+00, 0.18790600E+00, 0.23607100E-02, 0.20960600E+00, -.36737600E+00, -.78735800E+00, -.43723200E+00, 0.57949800E+00, -.68128200E+00, -.48909700E+00, -.12150900E+01, 0.25995000E+00, -.97894600E-01, -.16070000E+00, 0.28565200E+00, 0.14771700E+01, -.54066000E+00, -.51321900E+00, -.69726200E+00, 0.35044800E+00, 0.66534800E+00, -.60319300E+00, 0.10080400E+01, -.75842100E+00, 0.52886100E+00, 0.44248300E+00, -.32345200E+00, 0.14892200E+00, 0.91786200E-01, -.25847900E+00, 0.36763400E+00, 0.16623200E+01, 0.11498700E-01, -.20305300E-01, 0.12168900E+00, 0.75112200E-02, -.43997000E+00, -.11333800E+00, -.86759200E+00, 0.51860500E-01, -.22829900E+00, -.17380300E+00, 0.11752400E+00, -.29792300E-01, -.78303000E+01, 0.42759500E+00, 0.23323800E+00, 0.36209300E+00, -.10226500E+00, -.30027600E-01, 0.18725000E+00, -.17102000E-01, -.20862100E+00, -.48234200E+00, -.40152800E+00, 0.40000400E+00, -.10345600E+00, -.19665600E+00, -.18581200E+00, 0.38566400E+00, 0.32887500E-01, 0.16808600E+01, 0.82238900E+00, 0.33635900E+01, 0.33106100E-01, -.13686100E+00, 0.16725400E+00, 0.67609300E-01, -.64106700E+00, -.13715800E+01, 0.13156600E+01, 0.84998800E+00, 0.26383900E+01, -.68156500E+00, -.56053900E+00, 0.42419100E+00, 0.25894500E+00, 0.95781600E+00, -.31743700E+01, 0.10016000E+01, 0.14384300E+01, 0.28016300E-01, 0.26026300E+00, -.47292100E+00, -.19654200E+00, -.10058100E+01, 0.88771200E+00, 0.45104500E+00, -.18820600E+01, 0.12805900E+01, 0.24886800E+00, 0.19542100E+01, 0.29267300E-01, -.57016100E-01, 0.93393500E-01, 0.17901700E+00, 0.41060900E+00, -.20360900E+00, -.86480700E+00, 0.47949000E+00, -.10987600E+00, -.77446700E+00, -.17227600E+00, -.79363900E+00, -.54469800E+00, -.41087700E-01, -.30880200E+00, -.26833400E+00, 0.10361700E+00, -.15541600E+01, 0.20439700E+00, -.24084700E+00, 0.72109700E+00, -.83297700E+00, 0.47885700E+00, 0.71085500E+00, 0.31738400E+00, -.18725800E+00, 0.11962100E+01, 0.73203900E-01, -.67686300E-01, -.22850500E-01, 0.21631900E+01, -.18091500E+00, -.43499400E+00, -.14450500E-01, 0.11548500E+00, -.65733200E+00, 0.23636000E+00, 0.19070900E+00, -.36071000E+00, -.36865500E+00, 0.26273900E+00, 0.87985900E+00, 0.32094600E+00, -.89980600E+00, 0.11074100E+00, 0.19188400E+00, 0.95675900E-01, 0.86357300E-01, -.96810900E-01, 0.13251500E+02, -.81659100E+01, -.14387100E+02, -.29429300E+01, 0.94895700E+01, 0.35494100E+02, -.17981000E+02, -.18299400E+02, -.72151200E+01, -.66354800E+01, -.37063000E+01, 0.37896300E+02, -.23980900E+02, 0.43611300E+01, -.87167100E+02, 0.42838600E+02, 0.43528700E+02, -.31338400E+02, -.61491800E+01, 0.57123300E+02, 0.92368100E+02, 0.82677200E+02, -.34712000E+02, -.26232600E+02, 0.13655400E+02, 0.13835900E+02, 0.17142400E+02, -.18853500E+02, 0.22692300E+02, 0.41338200E+02, 0.29969800E+02, -.47627400E+01, -.23751100E+02, 0.12028900E+02, 0.14110800E+02, 0.38845800E+02, 0.37880000E+02, -.29385600E+02, -.55336100E+02, -.70807300E+01, 0.65187400E+02, 0.12752400E+03, -.64033400E+02, -.63899500E+02, 0.59147500E+01, 0.28917700E+02, -.44665100E+02, 0.18863000E+02, -.55518900E+02, 0.10051600E+02, 0.97276100E+01, -.51766500E+01, -.33683400E+01, -.44682800E+02, -.85720900E+01, 0.96868600E+01, 0.27093500E+02, 0.53255800E+01, -.28545300E+02, 0.38379000E+01, 0.98654700E+01, -.49079400E+01, -.70518500E+00, 0.24755900E+02, 0.29194300E+01, -.29362200E+02, 0.73719200E+01, 0.76552300E+00, 0.16149600E+02, 0.16699000E+01, -.48541900E+00, 0.16300500E+01, -.94525200E+01, 0.87420500E+01, 0.13420400E+02, 0.55394600E+01, 0.71448300E+01, 0.16443900E+02, 0.28648300E+01, -.13805400E+02, -.76579800E+02, -.45836500E+00, -.28524200E+02, 0.17294100E+02, 0.14490300E+02 },
            { -.61891100E+00, 0.21989200E+00, 0.31581700E+00, -.87718100E-01, 0.53665500E+00, 0.84630100E-01, 0.16606500E+00, 0.10636100E+00, -.24465800E+00, 0.14463400E+00, 0.14770900E+00, 0.26608900E+00, 0.90105800E-02, -.23673800E-01, -.11350900E+00, -.19444900E-02, 0.17774500E+00, -.24656500E+00, -.47143000E-01, 0.21020100E+00, 0.13155300E+00, 0.22596200E+00, -.35414200E+00, 0.51162800E+00, 0.10000300E+00, 0.55302900E-01, 0.11356100E+00, 0.95418100E-01, 0.62219400E-01, -.98014600E-01, -.12110300E-01, 0.65379300E-01, 0.66061400E-01, 0.73068000E-01, -.49125400E-01, -.23580400E+00, 0.37813300E-01, -.14214200E-01, -.21833200E-01, -.47224400E+00, -.29186800E+00, -.73942700E-01, -.46576100E-01, 0.42994400E-02, -.14470800E-01, -.12531300E-01, -.57425300E-01, 0.11478100E+00, 0.46594900E+00, -.56205200E-01, 0.37888300E+00, -.38444500E+00, 0.95366900E-01, 0.54347300E-01, -.11617400E+00, 0.91743800E-02, 0.90479000E+00, -.49142400E-01, -.87804300E-01, 0.80621800E-01, 0.18051400E-01, -.59332200E-01, -.41517100E-02, -.66157800E-01, 0.46463200E-01, -.14883900E+00, 0.25648600E+00, -.66581800E-02, -.14279400E+00, 0.17295900E-01, -.43450800E-01, 0.23754200E+00, 0.85315100E-01, 0.24813300E-01, -.12781100E-01, -.32201900E-01, -.26839600E-01, -.26808800E-01, -.26625700E+00, -.17531800E+00, 0.52493300E-01, -.13518000E+00, -.47725500E-01, -.45331500E-02, 0.23969300E-01, 0.95508900E-01, -.28365600E+00, 0.27267200E+00, 0.19443500E-01, -.10886400E-01, -.19111600E-01, 0.14813900E-01, 0.27516500E-01, -.17185100E+00, -.20879200E+00, -.35860200E-01, 0.14473700E+00, 0.20830600E+00, -.11053500E+00, -.55189100E-01, 0.38173300E-01, 0.73907200E-01, 0.24642600E+00, -.19759600E+00, -.53847600E+00, 0.15958500E+00, -.25890900E+00, 0.25731000E+00, 0.38991500E+00, -.15830500E-01, -.60301400E-01, -.22476700E+00, -.69964700E-02, -.29980200E+00, -.67163600E+00, -.64000700E-01, 0.91732000E+00, -.73823600E-01, 0.14131500E-01, -.45755300E-01, 0.24042800E-01, 0.23575700E+00, -.16968800E-01, 0.47754300E-01, 0.20757900E-01, 0.16080500E+00, 0.35169100E+00, 0.35767100E-02, -.34496200E+00, -.99605700E-01, -.77133400E-02, -.17820100E+00, -.56019700E-01, 0.22951700E+00, -.79336600E-01, 0.71673400E-01, 0.56282100E-01, 0.13182400E-01, -.57023100E-01, 0.93722200E-01, 0.77218800E-01, -.30485700E-01, 0.85198300E-02, -.29623900E+00, 0.34514500E-01, -.75339900E-01, -.76771700E-01, 0.82934600E-01, 0.53041300E-01, 0.46419300E+00, 0.18431500E-01, 0.43346200E-01, -.26764400E+00, 0.20973100E-01, 0.12468800E+00, -.10012100E+00, -.14426500E+00, -.18492800E-01, 0.88221100E-01, 0.25887400E+00, 0.93153300E-01, 0.62605800E-01, -.25999000E+00, -.22865500E-01, -.64683700E-01, 0.11985500E+00, 0.10749900E+00, -.44136200E+01, -.38168600E+01, -.13337800E+01, -.31074400E+01, -.16471400E+02, 0.80743500E+01, 0.79557800E+01, 0.29348500E+01, -.16601900E+01, 0.15707300E+01, 0.19516300E+01, 0.34763200E+01, 0.61774500E+01, -.50656900E+02, 0.25002900E+02, 0.25850100E+02, -.61566300E+01, -.19972900E+01, 0.21729900E+02, 0.94456200E+01, 0.27158400E+02, 0.42051900E+01, -.32943000E+02, 0.16806600E+02, 0.15843100E+02, -.34310400E+01, 0.47150100E+01, 0.12894800E+02, 0.81479200E+01, 0.14862700E+02, 0.17287400E+00, 0.22715400E+02, -.11120200E+02, -.12148500E+02, 0.17000100E+02, 0.21118500E+02, -.23857200E+02, -.14723400E+02, -.21123000E+02, 0.14731500E+02, 0.12486800E+02, -.63037600E+01, -.57350400E+01, 0.81370400E+00, 0.17092300E+01, -.11783300E+01, 0.34901800E+01, -.14440000E+02, 0.23626200E+01, 0.28853400E+02, -.14547600E+02, -.13258400E+02, 0.11841500E+02, 0.44489900E+01, -.19168800E+02, -.23437400E+02, -.22320400E+02, 0.70571300E+01, -.10510200E+01, -.96476200E+00, 0.11239500E+01, -.21790000E+00, -.40245900E+00, 0.83803300E+00, -.17542700E+01, -.20307200E+01, 0.36146300E+01, 0.65528200E+01, -.15230600E+01, -.36546300E-01, -.14183500E+01, -.27639100E+01, 0.19385600E+01, -.24312100E+01, -.34607600E+01, 0.42782100E+01, 0.56253200E+01, -.12716700E+01, -.10259100E+01, -.83782500E+01, -.14971000E+01, -.12548700E+02, -.24549500E+01, -.40023300E+01 },
            { -.13479200E+01, -.14537600E+01, 0.11580600E+00, 0.50361600E+00, 0.17187700E+01, 0.23915700E+00, 0.62796900E+00, -.25257400E+00, -.10823400E+01, 0.72516400E+00, 0.82214800E+00, 0.23710800E+01, 0.12587500E+00, -.40402800E+00, -.48519200E-01, -.47629400E+00, 0.72031400E+00, -.15054900E-01, -.40327500E+00, -.55912800E+00, 0.80890500E+00, -.36209500E+00, -.44914900E+00, -.24684400E+01, 0.40192100E+00, 0.23558600E+00, 0.55705900E-01, -.73582100E-01, 0.58124400E-01, 0.26985700E+00, 0.53570800E-01, -.34420400E+00, 0.83653700E+00, -.46437200E+00, -.28401500E+00, -.10523000E+01, -.52234800E+00, 0.19637100E+00, 0.33443900E+00, 0.97167500E-01, -.23831000E+00, 0.41015700E+00, -.33846700E+00, 0.17995400E+00, 0.40749800E+00, 0.94731300E+00, 0.97815200E-01, 0.35632100E+01, -.21068700E+01, 0.43688000E+00, -.14439800E+01, 0.34587700E+00, -.66080600E+00, 0.55985900E+00, -.32769500E-01, 0.19045500E+00, -.19872400E+01, 0.25396600E+00, 0.58743000E+00, -.52819800E+00, 0.18070300E+00, -.29196900E+00, -.32624500E+00, -.86936700E-01, -.49349700E-01, 0.12912700E+01, 0.98522800E+00, -.12440700E+01, 0.15442900E+01, -.82641100E+01, 0.20384400E+00, -.11775300E+01, -.19029900E+00, -.51397300E+00, -.12865900E-01, -.16656200E+00, 0.23802500E+00, 0.91914800E+00, 0.13682000E+01, 0.13152100E+01, -.49223400E+00, -.98219300E+00, 0.19788300E+01, 0.91805800E-01, 0.29464500E-01, 0.64859900E-02, -.39179100E+01, 0.13278700E+01, -.53849900E+01, -.25584300E+00, -.90240000E-02, 0.54249100E-01, 0.17541800E-01, -.89331100E+00, -.42343000E+00, -.20468400E+00, -.32466400E+00, -.48113800E+00, -.34188400E+00, 0.20066900E-01, 0.12652600E+00, 0.50914100E-01, 0.59785800E+00, 0.19455100E+01, -.58012300E+00, -.61439100E+00, -.26921100E+00, -.28387200E+00, -.14338800E+01, -.81448000E+00, 0.99332000E+00, 0.37987900E+01, 0.73347600E+00, -.87860000E+00, -.30548600E+01, 0.10114500E+00, -.46843900E+01, -.91921400E+00, 0.10992200E+00, 0.27120800E+00, 0.17234700E+00, -.66190100E+00, -.10441700E+00, -.12500900E+01, -.12053900E+01, -.18742600E+00, 0.51567300E+00, 0.18443500E+00, -.21239400E+00, 0.46517500E+00, 0.37062300E-01, 0.61809200E+00, -.12070400E+01, 0.25615000E-01, -.47847500E+00, -.11438700E+00, 0.13441800E-01, -.84603400E+00, 0.11145700E+00, -.10175400E+01, 0.41590100E+00, -.72257400E-01, 0.28471400E+00, -.94340800E+00, 0.25654800E+00, -.57139900E-03, 0.31689200E+00, -.30804300E+01, 0.17658200E+00, 0.27236600E+01, 0.65948700E-01, -.22548300E+00, -.91321600E+00, -.64880000E-01, 0.36506300E+00, -.52995000E+00, -.31165500E+00, 0.14014100E+00, 0.63725700E-01, 0.74040600E+00, 0.36455400E+00, -.22787300E-01, -.38401200E+00, 0.21864400E-01, -.28956700E+00, 0.48164000E+00, -.10303300E+00, -.10792000E+01, -.26104100E+02, 0.18910600E+02, -.12919900E+02, -.12772300E+02, 0.50850100E+01, 0.58760000E+01, 0.21923100E+00, -.51578000E+01, 0.78116000E+01, 0.63057800E+01, -.63693200E+01, 0.23954300E+02, -.68201900E+02, 0.31911200E+02, 0.35047200E+02, -.29645500E+02, -.22566500E+02, 0.55628500E+02, 0.28979000E+02, 0.83781700E+02, -.18887600E+02, -.13337200E+03, 0.70564600E+02, 0.66176700E+02, -.19021300E+02, 0.35304100E+01, 0.64197200E+02, 0.69261300E+02, 0.73306600E+02, -.64375200E+01, -.78966100E+02, 0.42845200E+02, 0.37491600E+02, 0.50631900E+02, 0.63801900E+02, -.20052600E+02, 0.73821700E+01, -.42058900E+01, 0.72313000E+02, 0.19351100E+03, -.96677100E+02, -.97079200E+02, -.17226100E+01, -.40653600E+01, -.49149300E+02, -.41285200E+01, -.95904500E+02, -.64143600E+01, 0.11949200E+03, -.60629200E+02, -.57153900E+02, 0.31277800E+02, 0.70834500E+01, -.69445500E+02, -.72602400E+02, -.90212000E+02, 0.16067700E+02, -.67144900E+01, 0.22841400E+02, -.39624700E+01, 0.40615200E+00, 0.17791700E+02, 0.20300900E+01, -.46360500E+02, 0.18122800E+02, 0.13945200E+02, 0.21133500E+02, -.62026100E+01, 0.53702100E+00, -.56809500E+01, -.69043900E+00, -.23435100E+01, 0.30383300E+01, -.26507700E+02, 0.48279800E+01, 0.18906500E+02, -.76276300E+01, -.20545200E+01, -.52156200E+02, -.38731600E+01, -.95625400E+01, 0.19027200E+02, 0.49669800E+01 },
            { -.23883000E+01, 0.11615300E+01, 0.15369500E+01, -.12469300E+01, 0.80880600E+00, 0.28048400E+00, 0.71868900E+00, 0.76138900E+00, -.58008700E+00, 0.58101000E+00, 0.69313900E+00, 0.17975300E+01, 0.11140200E+01, -.11050800E+01, 0.11527200E+00, -.13071400E+00, 0.10880100E+01, -.33327300E+00, -.52055400E+00, 0.67167600E-01, -.28883600E+00, -.16551000E+01, -.18021400E+00, -.24662300E+01, 0.74104600E+00, 0.32657600E+00, 0.49471500E+00, 0.38070000E+00, 0.24745900E+00, 0.31497400E+00, 0.22940000E+01, 0.24190200E+00, -.48595300E+00, -.19014200E+00, -.32614900E+00, -.11906100E+01, -.40137900E+00, 0.15307400E+00, 0.23684900E+00, -.12533800E+01, 0.26524200E+00, 0.21186500E+00, -.55043700E+00, 0.50101100E+00, 0.40638900E+00, -.56530300E+00, 0.10748300E+01, 0.14174200E+01, 0.88674000E+00, 0.15948800E+00, -.73631000E+00, 0.17888200E-02, -.45645900E+00, 0.16822100E+00, -.21386500E+00, 0.53076100E+00, -.13340700E+01, -.15415200E+00, 0.31377700E+00, -.49278900E+00, -.72816600E+00, 0.10629900E+01, -.91872700E+00, -.29975100E+00, -.35341200E+00, 0.13162100E+01, 0.26518500E+01, -.66074800E+00, 0.84879800E+00, 0.33924900E+01, -.11723700E+01, 0.53738300E+00, 0.69797500E+00, 0.42856200E-01, -.18384400E+00, -.21942600E+00, -.11197700E+00, 0.46320100E+00, 0.10456700E+01, 0.71093200E+00, -.24903900E+00, -.22328800E+00, 0.83412800E+00, -.32897200E+00, -.39468500E+00, -.10114600E+00, -.92691000E+00, -.16925800E+01, -.41964500E+01, -.26323500E+00, -.45874100E+00, -.35589600E-01, 0.11304400E+00, 0.11418300E+01, 0.95402700E+00, 0.11524800E+01, 0.23669600E+01, -.18691400E-01, 0.52962900E+00, -.88782200E-01, -.49460100E+00, -.32690500E+00, -.94941800E+00, 0.81322700E+00, 0.55815000E+00, 0.18781400E+01, 0.11574400E+01, -.92834800E+00, -.15641800E+01, 0.33351200E+00, -.57230700E+00, -.40084300E+01, 0.49151900E+00, -.84224000E+00, 0.16150600E+01, 0.83974200E-01, -.44470400E+01, -.69288000E-01, -.17461900E-01, 0.32558900E+00, -.14104400E+00, -.26843200E+00, -.70240900E-01, -.53373000E+00, -.18868700E+00, -.56861000E+00, -.86051900E+00, -.29733500E-01, 0.11959400E+00, -.37153800E+00, 0.12952100E+00, 0.35788200E+00, -.30657500E+00, -.99706600E+00, -.13757000E+01, -.29717600E+00, 0.14807000E+00, -.13601600E+00, 0.41716300E-01, -.33467700E-01, 0.63102900E-01, -.49584700E-01, 0.52443500E-01, 0.10053500E+00, -.91156300E-01, 0.16201400E+00, 0.20772000E+00, -.20666000E+01, 0.60747200E-03, 0.15558300E+00, -.65376900E-02, -.42852200E+00, -.10608900E+00, 0.62336500E-01, -.11513400E-01, 0.33926700E-01, 0.37505800E+00, -.35858000E-01, 0.85728900E+00, -.81096200E+00, -.19760200E+00, -.10150200E+00, 0.70916200E+00, -.23004500E+00, 0.16584600E+00, 0.64483300E+00, 0.39165200E-01, -.12084400E+01, -.39800700E-01, 0.16029600E+02, -.18054800E+01, -.56350200E+01, 0.26436900E+01, 0.30597600E+01, -.77251500E+01, -.10985800E+02, 0.10872300E+02, 0.58954400E+01, 0.31587500E+00, 0.64765000E+01, -.38799100E+02, 0.20964100E+02, 0.19149000E+02, -.13770200E+02, -.32379100E+01, -.21671400E+01, -.39527100E+02, 0.47231000E+02, -.64876200E+01, -.28006400E+02, 0.12546100E+02, 0.16155600E+02, -.64603500E+01, -.10073400E+02, 0.15200200E+02, 0.26040000E+02, 0.30767400E+02, -.15538900E+01, -.59552700E+02, 0.26208600E+02, 0.31795100E+02, 0.46139600E+01, -.15128500E+02, 0.32109600E+02, 0.69213200E+02, 0.47709100E+02, 0.12446700E+02, 0.11250400E+03, -.56571400E+02, -.54463100E+02, 0.20141900E+01, -.41929500E+01, -.43888600E+02, -.18492400E+02, -.41371700E+02, -.12589200E+02, -.25680000E+01, 0.64992300E+00, 0.96829000E+00, -.99104000E+01, -.39765900E+01, 0.89204100E+00, -.11601100E+02, -.13826100E+01, -.68805400E+01, -.70521500E+01, 0.29608500E+01, 0.20324700E+01, -.53517900E+00, 0.10269200E+02, -.23424300E+00, -.10270300E+02, 0.58442300E+00, 0.10773900E+02, 0.43277400E+01, -.43642300E+01, -.41475900E-01, -.43360600E+01, -.51512700E+01, 0.21959400E+01, 0.10423100E+02, 0.15879600E+02, -.99386600E+00, 0.38553000E+01, -.90283100E+01, 0.44154100E+01, -.24206200E+01, -.96155600E+01, 0.48061700E+02, 0.59846300E+01, 0.40337900E+01 },
            { -.42331000E+00, -.16504700E+00, 0.40064600E-01, 0.21042800E+00, 0.82003800E+00, 0.71826400E-01, 0.24079500E+00, -.57011000E-01, -.49685100E+00, 0.16156700E+00, 0.18489100E+00, 0.81295200E-01, 0.11348300E+00, -.30015700E-01, 0.90431200E-01, -.11900100E+00, 0.25364300E+00, -.10085100E+00, -.21285200E+00, 0.38815100E-01, 0.32785500E+00, 0.21720000E-01, 0.19722000E-01, 0.26008300E+00, 0.53145200E-01, -.81998400E-02, -.78200000E-01, 0.60008600E-01, -.20278700E-01, 0.18713300E-01, -.16344500E+00, 0.35987400E-01, 0.28521700E-01, -.31892300E-01, -.31100900E-01, -.55849300E+00, 0.17566000E+00, -.68885200E-01, -.10503400E+00, 0.34092100E+00, 0.59580100E+00, -.31140100E+00, -.23411500E+00, -.38434300E+00, 0.14618300E+00, 0.40958000E-01, -.14053200E+00, 0.47809800E-01, -.17638200E+00, -.40406600E-02, 0.24302200E+00, -.30160900E+00, 0.91403000E-01, 0.31195100E-01, -.67455700E-01, -.11307200E+00, 0.54808500E+00, -.12211100E-01, -.43050500E-01, 0.77282200E-01, -.32318300E-01, -.68046700E-01, 0.53384600E-01, -.82944500E-02, 0.48293900E-01, -.17092100E+00, -.36766500E-01, 0.21401200E+00, -.63445700E-01, -.63895900E+00, -.98307200E-01, 0.18484500E+00, 0.11238600E+00, 0.33105000E-01, 0.87614100E-02, -.59399200E-01, -.50463800E-02, -.84922800E-01, -.22721900E+00, -.17228400E+00, 0.69363600E-01, 0.52991400E-02, -.21871500E+00, 0.51575600E-01, 0.80976800E-01, 0.56735500E-01, 0.18156200E-02, 0.11964100E+00, 0.22654300E+00, 0.20452500E-01, 0.60648900E-01, -.10036400E-04, -.11624500E-01, -.16356300E+00, -.11912400E+00, -.14787000E+00, -.36683000E+00, -.55052500E-01, -.78331900E-01, 0.10516600E-01, 0.54189700E-01, 0.46727900E-01, 0.15766500E+00, -.92874300E-02, -.87812200E-01, -.25417900E+00, -.16602800E+00, -.44320800E+00, -.10672200E+00, -.92238800E-01, 0.17858000E+00, 0.35308400E+00, -.21651000E+00, 0.38517200E+00, -.40167600E+00, -.58942100E-02, -.12305100E-02, 0.68086800E-01, 0.49440800E-01, -.37788900E-01, 0.22802000E-01, 0.13120500E+00, -.28981800E-01, 0.57000300E-01, -.30042800E-01, 0.99342700E-01, 0.10535600E+00, 0.48366800E-01, 0.14698200E-01, 0.83067400E-01, -.33981100E-01, -.73749500E-01, 0.33080700E-01, 0.30158500E+00, 0.10552900E+00, 0.80979800E-01, -.27300600E-02, 0.34673400E-01, -.19734000E-01, -.68963100E-01, -.69637500E-01, 0.54547600E-01, -.36399900E-02, 0.21454000E-01, 0.46033600E-01, -.49019600E-01, -.11792200E+00, 0.44181000E+00, -.70822700E-01, 0.44563900E+00, 0.23143300E-01, 0.48991300E-01, -.16048900E-01, -.22334400E-01, 0.17905300E-01, -.11992900E+00, -.37671000E-01, -.19882100E-01, -.19200600E+00, 0.20132500E+00, -.14925200E+00, -.48040100E-01, 0.18392800E+00, 0.32612600E-01, 0.30368200E-01, -.72975800E-01, 0.20991300E+00, -.18753200E+00, -.53833300E-01, 0.10444900E+00, -.67923000E+01, -.10178800E+02, 0.51361400E+01, 0.49464400E+01, 0.24524700E+01, 0.23065000E+01, 0.33757700E+00, -.48849700E+01, 0.67850600E+01, -.68012400E+00, 0.52089600E+00, -.28080200E+00, 0.10511500E-01, -.19561900E+00, -.12093600E+01, 0.22154800E+01, -.54159700E+00, -.86572400E+01, 0.89984500E+01, -.18764600E+02, 0.92312000E+01, 0.89881500E+01, -.27091600E+01, 0.53477800E+01, 0.35732500E+01, -.32650900E+01, 0.20944900E+01, 0.53675400E+01, 0.69238200E+01, -.36784300E+01, -.39058600E+01, -.27031100E+00, 0.48902100E+01, -.60531100E+01, -.85335300E+01, -.80050700E+01, -.39427900E+01, -.92671400E+01, 0.46048400E+01, 0.47031800E+01, -.23893200E+01, -.68513900E+01, 0.64253600E+01, 0.27009400E+01, 0.38711600E+01, -.79670600E+00, 0.23066300E+02, -.11510700E+02, -.10918300E+02, 0.95266700E+01, 0.21089300E+00, -.12197900E+02, -.11323800E+02, -.97006500E+01, 0.42935900E+01, 0.19400900E+00, 0.59625400E+00, 0.10059700E+00, 0.19184700E+00, -.40415400E+01, 0.99448800E-01, -.29269700E+00, 0.95002100E+00, -.55541000E+00, -.17120300E+01, -.17482800E+00, 0.11101600E+00, -.71399400E-01, 0.21633300E+01, -.17449200E+01, -.24247100E+01, -.65970900E+01, -.89339900E+00, -.17794500E+01, 0.23329600E+01, 0.21512400E+01, 0.77658200E+01, -.94686400E+00, -.79625600E+01, -.83446400E+00, -.19508300E+01 },
            { -.23120600E+00, -.24603000E+00, -.30006200E-02, 0.11104500E+00, 0.48869000E+00, 0.60862100E-01, 0.10763500E+00, -.36526700E-01, -.13846000E+00, 0.10844900E+00, 0.23694600E-01, 0.10477700E+00, 0.48404700E-01, -.30976700E-01, 0.60776900E-01, -.69678800E-01, 0.11152400E+00, 0.45867800E-01, -.16155300E+00, -.87154800E-01, 0.14631300E+00, -.48869800E-01, 0.20036000E+00, -.17579400E+00, 0.17713300E-01, 0.35907300E-01, -.70559500E-01, -.25787700E-01, -.22430100E-01, -.11714900E-01, -.67508500E-01, -.31765700E-01, 0.22649200E-01, -.60002800E-01, -.30504000E-01, -.42480300E+00, 0.17451800E-01, -.68931700E-02, -.88701500E-02, 0.13601500E+00, 0.15858800E+00, -.50222200E-01, -.51266900E-01, -.86049300E-01, 0.45659800E-01, 0.49142700E-01, -.78925200E-01, 0.16185400E+00, -.19676600E+00, 0.61930200E-01, -.22460000E-01, 0.38444900E-01, 0.67052200E-01, -.40446100E-01, -.12399000E-01, -.15183800E-01, 0.24093500E+00, 0.13540800E-01, -.42063300E-01, 0.57393400E-01, -.69811700E-02, -.27497700E-01, 0.10107300E-01, -.54721800E-02, -.87870000E-02, 0.91342300E-02, 0.31353000E-01, 0.20981500E-01, 0.71231600E-01, -.71713600E+00, -.11763100E-01, -.12741900E-01, 0.15670300E-01, -.66184700E-02, 0.70222200E-03, -.23533400E-01, -.54069800E-02, 0.56342600E-03, -.46931300E-02, 0.45640000E-02, -.79281300E-02, 0.31018800E-02, -.23194100E-01, -.36553700E-02, 0.29852400E-01, 0.25184200E-03, 0.25450900E-01, 0.59802300E-01, 0.13783000E+00, 0.74461000E-02, 0.13831400E-01, 0.58839300E-02, -.45026700E-02, -.15204300E-01, -.33106800E-01, -.27615900E-01, -.76680200E-01, 0.18963800E-01, -.20252200E-01, -.18227600E-02, 0.27125700E-01, 0.90619500E-02, 0.77840500E-02, -.60747400E+00, 0.10598900E+00, 0.15291500E+00, 0.31752500E+00, -.39213400E+00, -.22494800E+00, -.44541600E-01, -.95863600E-02, 0.55637100E+00, -.96863300E-01, -.14305800E+00, -.19459400E+00, 0.34022800E-02, 0.53063400E+00, -.26456400E-01, 0.15532800E-01, -.49885200E-01, 0.54319800E-02, -.55841600E-01, -.10427400E-01, 0.12228300E+00, 0.10948700E+00, 0.37778400E-01, 0.80942900E-02, 0.35545700E-01, 0.18058700E-01, 0.11047100E+00, -.74499100E-02, 0.12323500E-01, 0.60438100E-01, 0.80946300E-01, 0.12543300E+00, 0.64723000E-01, 0.37310000E-01, 0.46886100E-01, -.68542500E-01, 0.63565700E-01, -.58619300E-01, 0.17580600E-01, -.26515000E-01, 0.72097900E-01, -.95751800E-02, 0.26678200E-01, 0.51935500E-01, 0.10843000E+00, -.13632200E-01, 0.13177300E+00, 0.25575500E-02, -.18495400E-01, 0.49288500E-01, 0.25613600E-01, -.16748300E-01, 0.10675100E+00, 0.61431200E-01, 0.38205500E-02, -.29428600E-01, -.46900400E-01, -.65304600E-01, 0.58845400E-02, -.17589300E-02, 0.46335700E-01, -.17135000E-01, 0.61771800E-01, -.15557500E+00, -.15436400E+00, 0.69942300E-01, 0.16599000E+00, 0.28256800E+00, 0.12419800E+02, -.62956900E+01, -.62797300E+01, -.13534600E+01, -.29028900E+01, -.14497400E+01, 0.98664900E+01, -.35540400E+01, -.18330600E+01, -.16714300E+02, 0.77711500E+01, 0.84025900E+01, 0.20419200E+01, 0.15855900E+01, 0.95695600E+01, 0.25804200E+02, 0.11187700E+02, -.49577100E+01, -.81860300E+01, 0.46671300E+01, 0.40899000E+01, 0.34184200E+01, -.54192300E+01, 0.68536900E+01, 0.10069000E+02, 0.62459100E+01, -.26189900E+01, -.43947400E-01, 0.72252800E+00, -.23965200E-01, 0.41919300E+01, 0.89804200E+01, -.77509600E+01, -.25466000E+02, -.52397300E+01, 0.14038300E+02, 0.26812300E+02, -.13355000E+02, -.13459800E+02, 0.19692500E+01, 0.56850100E+01, -.89378800E+01, 0.35309700E+01, -.11615900E+02, 0.13970400E+01, -.78259900E+01, 0.38965500E+01, 0.41172200E+01, -.10056400E+02, -.79902900E+00, 0.49516400E+01, 0.45986900E+01, 0.37294900E+01, -.57217600E+01, 0.18991700E+01, -.68443600E+00, 0.34375500E+00, -.27020700E+00, 0.32406400E+01, 0.90529300E+00, -.14250000E+00, -.10624800E+01, -.11567100E+01, 0.30317000E+00, 0.12304300E+01, -.19398400E+00, 0.10505600E+01, -.26896100E+01, 0.27538600E+01, 0.25042800E+01, 0.49808000E+01, 0.26162700E+01, 0.54737500E+00, 0.10231600E+01, -.28689800E+01, -.15378900E+02, -.31351400E-01, -.13116600E+02, -.19422900E+01, -.51163600E+00 },
            { -.40550300E+01, -.55428400E+00, 0.11273400E+01, 0.81056900E+00, 0.48043400E+01, 0.57104500E+00, 0.14505900E+01, 0.11451800E+00, -.12292200E+01, 0.10564500E+01, 0.18580700E+00, 0.76477500E-01, -.11626300E+01, 0.11986700E+01, 0.10104500E+00, -.39692800E+00, 0.93882900E+00, 0.14358900E+01, -.35564700E+01, 0.68651700E-03, 0.25708700E+01, 0.26505200E+01, 0.93770300E+00, 0.13856300E+01, -.84457200E-01, 0.86883800E+00, -.83074900E+00, -.59414600E-01, -.89128400E+00, -.37536700E-01, 0.89092000E+00, 0.13993100E+01, 0.10265000E+01, -.27672400E+00, -.34473400E+00, -.19369700E+00, 0.57791800E+00, -.22882000E+00, -.33376100E+00, 0.25779800E+01, 0.47972200E+01, -.13765700E+01, -.15568800E+01, -.33316500E+01, 0.12527900E+01, 0.11818500E+01, -.13461700E+01, 0.39957700E+01, -.73434800E+01, 0.66572400E+00, -.50207600E+00, 0.78936300E-01, 0.16500400E+01, -.37618700E+00, -.94266500E+00, 0.49483600E+00, 0.27125800E+01, 0.87548600E+00, -.45165400E+00, 0.63086700E+00, -.47996400E-01, -.54238500E+00, 0.82904500E+00, -.23383000E-04, -.31910000E+00, 0.87441000E+00, 0.18733100E+01, -.20806200E+00, 0.15902200E+01, -.96972700E+01, 0.86823200E-01, -.12691200E+01, 0.27833700E+00, -.62267000E-01, -.35678300E-01, -.36621600E+00, -.44733600E+00, -.44522000E+00, 0.49085800E+00, -.27557000E+00, 0.18420100E+01, 0.11467200E+01, -.23954100E+01, -.46712500E+00, 0.11153100E+01, -.19014900E+00, 0.36184600E+01, 0.84830700E+00, 0.69990600E+01, 0.45338400E+00, 0.36734800E+00, 0.24560700E+00, -.37028200E+00, 0.10060600E+01, 0.34202500E+00, -.10104200E+01, -.14463100E+01, -.78063600E+00, 0.38836400E+00, 0.22549600E+00, 0.85988400E+00, -.29803400E+00, -.10796500E+01, -.14467900E+01, -.69108900E+00, -.53933300E+00, -.63731300E+00, -.11079000E+01, 0.65891700E+01, -.88009300E-01, 0.74540900E+00, 0.13463800E+02, 0.33998000E+00, -.35416300E+01, -.56252400E+00, 0.37502000E+00, 0.37781300E+01, -.73541100E+00, 0.15447900E+01, -.69079400E+00, 0.75924100E-01, -.12309600E+01, -.25971300E+00, -.11813700E+01, -.12259500E+01, 0.69525300E+00, 0.23432800E+01, 0.65980500E+00, -.49956100E+00, -.67245800E+00, -.12322300E+00, -.77001700E+00, 0.21953500E+00, -.27487900E+00, -.30798900E+00, 0.64409600E+00, 0.29115000E+00, -.15389200E+01, 0.10640700E+01, -.15926500E+01, 0.28359600E+00, -.56373400E+00, 0.59375000E+00, -.91980800E+00, -.10347900E+00, 0.29823500E+00, 0.44544800E+00, -.59625400E+01, -.12842400E+00, 0.36306600E+01, -.16095400E+00, -.56192100E+00, 0.62252700E+00, 0.16172900E+01, 0.18218800E+00, 0.32868900E+00, -.20550800E+00, -.26348000E+00, 0.21226400E+00, 0.60316700E+00, 0.21807900E+01, 0.47916500E+00, -.12552500E+01, -.14680600E+00, -.25748000E+00, 0.55106800E+00, -.12155100E+01, 0.22683400E+01, 0.12963300E+00, -.63085800E+00, -.15582300E+01, -.31004400E+01, -.40083700E+01, 0.57094300E+00, -.31968200E+02, -.28027900E+02, 0.22477700E+02, 0.72518400E+02, -.42265500E+01, 0.45395500E+01, -.12693200E+03, 0.59131800E+02, 0.65030300E+02, -.27466400E+02, -.18225200E+02, 0.67255800E+02, 0.16445800E+03, 0.98726700E+02, -.64622500E+02, -.11671300E+03, 0.64499300E+02, 0.56639800E+02, -.38240600E+02, -.32387300E+02, 0.10652100E+03, 0.13240300E+03, 0.10407800E+03, -.40761900E+02, 0.92830000E+02, -.36533700E+02, -.47317500E+02, 0.13385400E+02, 0.53239900E+02, -.52655400E+02, -.11959900E+03, -.76410300E+02, 0.90937700E+02, 0.21947100E+03, -.10842000E+03, -.10520600E+03, 0.14784900E+02, 0.38333300E+02, -.72847900E+02, 0.33738400E+02, -.10659700E+03, 0.77220200E+01, 0.29420000E+02, -.14802200E+02, -.11729400E+02, -.19091700E+02, -.30547500E+02, -.37152200E+01, -.26951400E+01, -.13256300E+02, -.13981500E+02, 0.56022400E+01, 0.18142300E+02, -.61006800E+01, -.61981600E+00, 0.35327000E+02, 0.49281300E+01, -.30091100E+02, 0.14599400E+02, -.86892900E+01, 0.32742100E+02, 0.58188000E+01, -.46668300E+00, 0.50150100E+01, -.42799700E+01, 0.61705400E+00, 0.22347800E+02, 0.45722200E+02, 0.11723700E+02, 0.30445100E+02, 0.95670600E+01, -.19925000E+02, -.12156100E+03, 0.62110900E+01, -.72877800E+02, 0.14261600E+02, 0.33133700E+02 },
            { -.36715500E+01, 0.55401000E+00, 0.26459000E+01, -.96791200E+00, 0.50011300E-01, -.14358700E+00, 0.16414700E+01, -.28474200E+00, -.35179600E+00, 0.12403900E+01, 0.12624600E+01, 0.72527100E+01, 0.51698000E+00, -.16715200E+01, 0.16648200E+01, -.11850100E+01, 0.11106900E+01, -.41925200E+00, -.14540200E+01, -.14271100E+01, -.44128500E+00, 0.15211500E+01, 0.24142100E+01, -.22194600E+01, -.60696200E+00, 0.11852500E+01, -.41676300E+00, -.80283100E+00, -.84372600E-01, 0.23163900E+00, 0.12970900E+01, 0.34141900E+00, 0.47866100E+00, -.29220800E+00, -.32832300E-01, -.20892800E+01, -.19100600E+00, 0.71895200E-01, 0.74001100E-01, -.20615000E+00, 0.17361600E+00, -.10511000E+00, -.94715400E+00, -.28369000E+00, 0.70407600E+00, 0.39091600E+00, -.97789500E+00, 0.26790000E+01, -.33215400E+01, 0.25579600E+01, 0.79723800E+00, 0.29336900E+01, 0.12741300E+01, -.82586400E+00, -.21597100E+00, 0.31336100E+00, 0.93693400E-01, 0.18153100E+00, -.34168900E+00, 0.11127100E+01, 0.80443100E+00, -.33156700E+00, -.29887800E+00, 0.14340200E+00, -.14258100E+00, -.26863800E+00, 0.24765100E+01, -.27843700E+01, -.39822300E-01, 0.33003900E+01, 0.41579700E+00, -.14722600E+01, -.65644000E+00, 0.33301000E+00, -.22130900E+00, -.13584700E+01, -.10666200E+01, -.18044200E+00, -.10700500E+01, -.11668300E+01, 0.23303600E+01, -.47423900E-01, -.67052500E+00, 0.28162800E+00, 0.56466500E+00, 0.20856800E+00, -.58855600E+01, -.17382700E+01, -.87868700E+01, -.47015300E+00, 0.23828900E+00, -.10312400E+00, -.22562700E+00, -.51280600E-01, -.21670700E+00, -.58119000E+00, -.15085800E+01, 0.10508800E+00, -.40516900E+00, 0.10222200E+00, -.84586900E-01, -.21644600E+00, 0.61962300E+00, -.65753300E+00, -.68882000E+00, -.62616300E+00, -.42994000E+00, 0.73580800E+00, -.34744600E+01, -.27597900E+00, 0.87374600E+00, 0.64548900E+01, 0.20279200E+01, 0.74546800E+00, -.18577300E+01, -.63781600E+00, 0.36652500E+01, -.19592000E+00, 0.45429500E+00, -.14505100E+00, -.75377700E+00, -.30275100E+01, -.58022200E+00, -.12421100E+01, -.80410400E+00, -.22139600E+00, 0.59971700E+00, 0.86347300E+00, -.36275600E+00, -.29522900E+00, -.14550000E+00, -.41994100E+00, 0.34745800E+00, 0.69727500E+00, 0.17614400E+00, -.43963500E-01, 0.17333300E+00, 0.64772900E-01, -.28484700E+00, -.15810200E-01, -.72683300E-01, 0.11197300E+00, 0.35202000E-01, 0.34034100E+00, 0.16643300E+00, -.11126200E+00, -.38515000E+00, 0.12217800E+01, -.96795100E-01, 0.18934500E+01, 0.10752700E+00, 0.49006700E-03, -.14870800E+00, -.20648500E+00, -.63710100E-04, -.72898400E+00, -.71276400E-01, 0.86720400E-02, 0.10610100E+00, 0.57480000E+00, 0.32457200E+00, -.87935500E-01, 0.14554100E+00, 0.52117100E-01, -.32848600E+00, 0.23628900E+00, 0.75633600E-01, -.48798500E+00, 0.88719700E+00, -.65882000E+00, -.21366900E+00, -.39225700E+01, 0.98724200E-01, 0.33853600E+01, -.20260100E+01, -.17678800E+02, 0.10440600E+02, 0.34095700E+02, 0.60901000E+00, -.73435400E+01, -.10618800E+03, 0.51511400E+02, 0.53108800E+02, 0.17398400E+02, 0.19793800E+02, 0.23016400E+02, 0.75206200E+02, 0.27610700E+02, -.64104800E+01, -.38017000E+02, 0.20247200E+02, 0.20564200E+02, 0.51317200E+00, -.17580100E+02, 0.33656000E+02, 0.36513500E+02, 0.28232100E+02, -.15413200E+02, 0.91228900E+02, -.43457300E+02, -.46538400E+02, -.36973900E+01, 0.81342300E+01, -.29777400E+02, -.88672300E+02, -.40605100E+02, 0.26956000E+02, 0.10791500E+03, -.53818100E+02, -.54069700E+02, 0.83842400E+01, 0.19193300E+02, -.40846100E+02, 0.68174800E+01, -.39353000E+02, -.11344400E+01, -.32539100E+02, 0.16361800E+02, 0.15629500E+02, -.37139300E+02, -.81794200E+01, 0.20315400E+02, 0.23148000E+02, 0.26590300E+02, -.20451900E+02, 0.55183000E+01, -.14264300E+02, 0.57069200E+01, -.18819900E+01, -.31966300E+01, 0.33557100E+01, 0.24899200E+02, -.15131200E+02, -.37872300E+01, 0.56573100E+00, 0.38159400E+01, -.11048100E+01, 0.29925900E+01, -.11789400E+02, 0.11200500E+02, 0.62028900E+01, 0.40486700E+02, 0.11401000E+02, 0.10667000E+01, 0.25913300E+01, -.99471300E+01, -.40879200E+02, -.20560400E+01, -.45544100E+02, -.27189800E+02, -.11279300E+02 },
            { -.37395700E+01, -.12928600E+01, 0.10923000E+01, 0.24950700E-01, -.38504600E+00, -.62920200E+00, 0.12793700E+01, -.28191800E+00, 0.46364300E+00, 0.22508100E+01, 0.34590300E+01, 0.68181500E+01, -.14375700E+01, -.12800900E+01, 0.30115900E+01, -.12950900E+01, 0.77641500E-01, 0.40875200E+00, -.25754400E+01, -.57896700E-01, 0.22268900E+01, 0.10797200E+01, 0.55882000E+00, -.18458000E+01, -.11606200E-01, 0.22996100E+00, -.74766700E+00, -.40149600E+00, -.79628900E+00, -.30026500E-01, 0.10383800E+00, 0.10216300E+01, 0.94785000E+00, 0.35123500E+00, 0.53042700E-01, 0.45952100E+01, 0.49547600E+00, -.20441200E+00, -.24642500E+00, 0.21974200E+01, 0.32238200E+01, -.11262800E+01, -.11163000E+01, -.20130700E+01, -.74804900E-01, 0.15621200E-01, -.87895900E+00, 0.35992300E+01, -.55523700E+01, -.42364500E+00, 0.42436600E+00, -.12201900E+00, 0.16726200E+01, -.14159700E+01, -.53044400E+00, -.10680700E+01, 0.62704800E+01, 0.24567300E+00, -.60059400E+00, 0.15005000E+01, -.42502200E+00, -.42330300E+00, 0.19251900E+00, -.61450300E-01, -.41397700E+00, 0.70788500E+00, 0.11529300E+01, 0.22768300E+00, 0.16773500E+01, -.10454300E+02, -.55449300E-01, -.13378700E+01, 0.25726400E+00, -.15719600E+00, -.32967500E-02, -.12946500E+01, -.32385700E+00, -.30906500E+00, -.47221800E+00, -.42338200E+00, 0.20033600E+01, 0.47355100E+00, -.12003500E+01, -.30870000E+00, 0.81699000E+00, 0.23043900E+00, -.18356600E+01, 0.11851100E+01, 0.12276100E+01, 0.35107300E-01, 0.49802900E+00, 0.69662500E-01, -.29331800E+00, 0.56739200E-01, -.56921400E+00, -.10882600E+01, -.23208700E+01, 0.10515200E+01, -.32589700E+00, -.58353700E-01, 0.60536100E+00, -.13028400E-01, 0.41776300E+00, -.23072400E+01, -.22669600E+00, -.10964900E+01, 0.65788700E+00, -.13102200E+01, -.19443500E+01, -.67551900E+00, 0.13869600E+01, 0.96198500E+01, 0.50366000E+00, 0.43787700E+01, 0.77572900E+00, -.40053500E-01, -.95641000E+00, -.23739000E+00, 0.46183800E+00, -.12032400E+00, -.21536000E+00, -.19549100E+01, -.62542200E+00, -.82706800E+00, -.24971200E+00, 0.72546400E+00, 0.46919100E+00, 0.38376900E+00, 0.57081600E+00, -.25988700E+00, -.17587900E+00, -.10884100E+00, 0.45557800E+00, -.69581400E+00, -.48154300E+00, 0.14854600E+00, -.53251700E+00, -.36089400E+00, 0.34867500E+00, -.14631600E+01, 0.31239300E+00, 0.27498700E+00, 0.26704200E+00, -.23723000E+00, 0.34650500E+00, 0.11429200E+00, -.79435700E-01, 0.95110200E+00, -.37367500E+00, 0.11178200E+01, -.24699100E-01, -.18781300E-01, 0.68459300E+00, 0.99736800E+00, 0.28048900E+00, 0.82348500E+00, 0.15134500E+00, -.38751800E+00, -.95827100E+00, -.54544400E+00, 0.98793100E+00, 0.33051900E-01, -.20407900E+00, -.10506000E+00, -.34367800E-01, -.25903500E+00, -.53868700E+00, 0.15120900E+01, 0.18895200E+00, -.35126900E+00, -.16448300E+01, -.31394300E+01, -.81157000E+00, 0.35908800E+00, -.40482400E+02, -.33272100E+02, 0.26632900E+02, 0.66457200E+02, 0.61894900E+01, -.13645600E+02, -.50134100E+02, 0.20925200E+02, 0.25822400E+02, -.99369000E+01, -.15851800E+02, 0.38934100E+02, 0.17033200E+03, 0.60076700E+02, -.65477700E+02, -.44058100E+02, 0.28155300E+02, 0.21265100E+02, -.13329700E+02, -.46761700E+02, 0.68149500E+02, 0.11023800E+03, 0.61272600E+02, -.29972200E+02, 0.15069500E+02, 0.91263900E+00, -.80294800E+01, -.19675700E+02, 0.23644700E+02, -.30241900E+01, -.12262000E+03, -.17741300E+02, 0.76674000E+02, 0.21248900E+03, -.10441800E+03, -.10251500E+03, 0.19895400E+02, 0.34794700E+02, -.72963200E+02, 0.34169600E+02, -.75303100E+02, 0.18113900E+01, -.10863400E+03, 0.54803600E+02, 0.56131000E+02, -.52967100E+02, -.27054500E+02, 0.63662300E+02, 0.53245400E+02, 0.67446600E+02, -.34688200E+02, 0.11877600E+02, 0.20954100E+02, -.71487300E+01, -.48883200E-01, 0.42646200E+02, 0.36351500E+01, -.27160800E+02, 0.18283200E+02, -.17574900E+02, 0.15581600E+02, 0.10172200E+02, -.43907900E+00, 0.91916300E+01, -.27398900E+00, -.83607200E+00, 0.31201600E+02, 0.52597200E+02, 0.31175700E+01, 0.15655400E+02, 0.13383200E+02, -.10330700E+02, -.11190200E+03, 0.82905000E+01, -.63140500E+02, 0.23881800E+02, 0.38996000E+02 },
            { 0.11116700E+01, -.50649300E+00, -.72588200E+00, 0.46189500E+00, -.21266500E+01, -.14620200E+00, -.33840600E+00, -.99612000E-01, -.38740200E-01, -.26440600E+00, 0.10522900E+01, 0.28265800E+00, -.42694600E+00, -.10356500E+00, -.17449300E+00, 0.22491800E+00, -.61011900E+00, 0.28098200E+00, -.47414000E+00, 0.44708100E+00, -.11547300E+00, 0.15968200E+00, -.42754700E+00, 0.26046500E+00, 0.49485200E-01, -.38325400E+00, -.15470800E+00, 0.22132000E+00, -.26090600E+00, 0.30309200E-01, 0.17973300E+00, 0.41626500E+00, -.32740900E+00, 0.75137500E+00, 0.28252200E+00, 0.19355600E+01, -.41136500E-01, 0.11094500E-01, 0.37997100E-01, 0.60346800E+00, -.83631900E+00, 0.91150900E-01, 0.69469700E-01, 0.28760900E+00, -.33893300E+00, -.64658400E+00, 0.56760200E+00, -.14541300E+01, 0.25271600E+00, -.53489600E+00, 0.48104600E+00, -.11337300E+00, -.45452100E+00, -.49107100E-01, 0.37891000E+00, -.10828900E+01, -.56909500E+00, -.56227200E-01, 0.11970900E+00, -.47864500E+00, -.22911200E+00, 0.61678300E-01, 0.43457300E+00, 0.32459200E+00, 0.34545900E+00, -.45469200E+00, -.18228100E+00, -.50902400E-01, -.31441800E+00, 0.21408500E+01, -.17243700E+00, 0.34134300E+00, 0.16056900E+00, -.36573000E-02, 0.36800700E-01, -.22175200E+00, 0.34882700E+00, 0.10873000E+00, -.66620300E-01, 0.18883000E+00, -.26420000E+00, -.82434900E-01, 0.27878200E+00, -.25940700E-01, -.11502500E+00, 0.33292100E-01, -.11542100E+01, -.35380500E+00, -.17030700E+01, -.12289300E+00, -.60908600E-01, -.38328600E-01, 0.79391900E-01, 0.83167000E-01, 0.15519400E+00, 0.16870400E+00, 0.41198900E+00, 0.33863200E+00, 0.39989300E-01, -.93320300E-02, -.15346400E+00, 0.24997200E-01, -.21204800E+00, 0.16660600E-01, 0.33813000E+00, 0.28391100E+00, 0.39131300E+00, 0.11927000E+00, -.30317800E+00, 0.64774900E-01, 0.14241700E+00, 0.20463000E+01, 0.16990300E+00, 0.19690100E+01, 0.22125500E+00, -.89923200E-01, 0.26316700E+00, 0.44071600E+00, 0.25870800E-01, -.12168400E+00, -.83641200E-01, -.27074600E+00, 0.13229100E+00, 0.74678200E+00, -.12649100E+00, 0.12832100E+00, 0.41879100E+00, 0.47867500E-01, 0.29560400E+00, 0.28433300E+00, -.70109400E-01, 0.10049600E+00, 0.51476700E-01, 0.27178300E+00, 0.77267900E+00, -.11715400E+00, 0.23283200E-01, -.33643100E+00, 0.28108900E+00, -.11982100E+00, -.28919100E+00, -.44133300E-01, 0.27884800E-01, -.78514400E-01, 0.20239800E-01, 0.78627000E-01, 0.28619100E+00, 0.30890700E+00, 0.15769900E+00, 0.99714000E-01, -.52954000E-01, 0.25078700E+00, 0.91763800E-02, 0.84655900E-01, -.96182700E-02, -.19475400E+00, -.25304600E+00, -.97974100E-01, -.54728100E+00, 0.40201100E+00, -.15450300E-01, 0.25256800E+00, -.28834800E+00, 0.10813600E+00, 0.59015500E-01, -.31999000E-01, 0.30704800E+00, -.23172900E-01, -.15373600E+00, 0.12068100E-01, 0.42349300E-01, -.19768900E+01, 0.81716300E-01, -.15491600E+00, -.10101600E+00, -.14397400E+02, 0.10882800E+02, 0.38446900E+02, 0.54595600E+01, -.52499900E+01, -.65798200E+02, 0.31212600E+02, 0.34144000E+02, 0.67904200E+01, 0.62150700E+01, 0.31890600E+02, 0.75447800E+02, 0.30099000E+02, -.13810600E+02, -.62590600E+02, 0.33000100E+02, 0.29802100E+02, -.87496900E+01, -.71461400E+01, 0.38541000E+02, 0.38383400E+02, 0.37259700E+02, -.17860500E+02, 0.49254500E+02, -.22950800E+02, -.26736600E+02, 0.16991400E+02, 0.46479800E+02, -.46491000E+02, -.89655300E+02, -.60077400E+02, 0.51024300E+02, 0.96525700E+02, -.48174300E+02, -.47163900E+02, 0.44913200E+01, 0.11329100E+02, -.27741000E+02, 0.86308200E+01, -.45753200E+02, -.11907300E+01, -.48747800E+01, 0.21641600E+01, 0.45047200E+01, 0.11857300E+01, -.95685200E-01, 0.82258300E+00, -.38575900E+00, -.14565500E+02, 0.69077800E+01, 0.35053800E+01, -.54736200E+00, 0.77356900E+00, -.84260300E+00, 0.19373400E+01, 0.34629800E+01, 0.39410400E+01, -.11521700E+01, -.13750600E+01, 0.80279500E+01, 0.19886300E+01, -.47305900E+00, 0.14931600E+01, -.77833600E+01, 0.70182400E+01, -.31330500E+00, 0.20776400E+02, 0.11440300E+02, 0.80038000E+01, 0.16076500E+01, -.11493800E+02, -.50252000E+02, 0.28122300E+01, -.54349500E+02, -.11385300E+02, 0.60721200E+00 },
            { -.10192400E+01, -.88947800E+00, 0.31419100E+00, 0.21619800E+00, 0.16929500E+01, 0.26458200E+00, 0.42351900E+00, -.16543300E-02, -.63446300E+00, 0.35871600E+00, 0.48198400E+00, 0.55763300E+00, -.20392300E-02, -.83960000E-01, -.25525400E+00, -.86651600E-01, 0.61434200E-01, -.94077500E-01, -.10585100E+01, -.94190200E-01, 0.15198600E+01, -.26937100E+00, -.31851000E-03, 0.19615200E+00, 0.15805900E+00, 0.67174200E-01, -.36650100E+00, 0.16736300E+00, -.29082500E+00, -.24713100E+00, -.38671700E+00, 0.20619800E+00, 0.55700500E-01, 0.44082800E+00, 0.19585200E+00, 0.33471500E+00, -.43487600E+00, 0.16525200E+00, 0.28544800E+00, 0.31782400E-01, -.28976000E+01, 0.50743800E+00, 0.12996600E+00, 0.92220000E+00, -.36391800E+00, -.40939200E+00, -.55292500E+00, 0.99298800E+00, -.16686200E+01, 0.37173300E+00, 0.10077700E+00, 0.14123600E+01, 0.48266800E+00, -.87480100E+00, 0.64303100E-01, -.42776000E+00, 0.20419400E+01, 0.92977900E-01, -.99845400E+00, 0.55211900E+00, -.27133200E+00, -.25371300E+00, 0.15792900E-01, -.21043100E+00, 0.68278800E-01, -.52736700E-01, 0.79504800E+00, -.43398900E+00, 0.58041700E+00, -.36050100E+01, 0.20388300E+00, 0.57216700E+00, 0.42692100E+00, -.33316600E+00, -.50775800E-01, -.67121600E-01, 0.14503100E+00, 0.12656200E-01, -.28751300E+00, -.17874300E+00, 0.79650300E-01, -.55023200E+00, 0.44284100E+00, 0.48409400E-01, -.18104700E-01, 0.92356700E-01, 0.19901500E+01, 0.67524900E+00, 0.39712100E+01, 0.15601700E+00, 0.64197600E-02, 0.38666100E-01, -.10541700E-01, -.26715200E+00, -.34359400E+00, 0.28812000E+00, 0.10380100E+00, 0.10004400E+01, -.27664000E+00, -.10294300E+00, 0.12120000E+00, 0.44487300E-01, 0.73496200E+00, 0.27836100E+00, 0.26430600E-01, 0.40283400E+00, 0.12607500E+00, 0.57051900E+00, 0.44647000E-01, 0.23883300E+00, -.12262900E+00, -.36739200E+01, -.42081000E+00, -.64988600E+00, 0.67926100E+00, 0.22660700E-01, -.21818500E+01, 0.20335400E+00, -.31531900E+00, 0.15099900E+00, -.88475900E-01, 0.71990300E-02, 0.63117600E-01, 0.63678600E-01, -.47601900E+00, 0.41979200E+00, 0.85418600E+00, -.45064100E-01, -.12999000E-01, 0.40711200E-01, 0.79449100E-01, 0.11444400E+00, 0.17133200E+00, -.36978600E+00, -.29012400E+00, -.30840900E+00, 0.16164300E-01, 0.20759600E-01, -.55818300E-02, 0.61184300E-01, -.30343100E+00, -.41401100E-01, -.20860200E-01, -.74774400E+00, -.98530000E-01, 0.99575500E-01, 0.25374800E+00, -.11363900E+01, 0.26031900E+00, -.15551100E+01, 0.61163200E-01, -.41029000E+00, -.12129900E+01, -.78436800E+00, -.27872200E+00, 0.44805200E-01, 0.71781000E-01, -.10482600E+00, -.50977900E+00, -.77160800E+00, 0.60309900E+00, 0.69721400E-01, 0.37517400E+00, -.87721200E-01, -.57244700E-01, 0.39527900E+00, -.28581400E+00, -.68996400E+00, 0.43020200E+00, 0.10238100E+00, -.47283800E+00, 0.20988200E+01, -.47220600E-01, 0.19491200E+00, -.32668900E+00, -.89107500E-02, -.43560000E+01, -.16562900E+02, -.95220700E+01, 0.49219900E+01, 0.30299000E+02, -.15354800E+02, -.14104500E+02, -.14104500E+02, -.16220000E+02, -.32424500E+01, 0.15166700E+02, -.24454900E+02, -.17161900E+02, 0.18969300E+02, -.82236000E+01, -.11122300E+02, -.15960700E+02, 0.28295500E+00, 0.10907900E+02, 0.23355700E+02, 0.68304700E+01, -.29098300E+02, 0.58659500E+02, -.27571600E+02, -.30379700E+02, -.19482500E+02, -.22094300E+02, 0.36602700E+01, 0.31097200E+01, -.21855200E+01, -.26140400E+02, 0.37092600E+01, -.13021800E+01, 0.11792300E+01, -.27088500E+00, 0.40189800E+01, -.15126700E+00, 0.91722600E+01, -.14313700E+02, 0.23369400E+01, 0.91519300E+00, -.24641300E+00, 0.20880100E+00, 0.12368400E+02, -.12167100E+02, -.31491300E+00, 0.68084700E+01, 0.13865700E+02, 0.11973500E+02, 0.10734200E+00, 0.93595900E+01, -.18254300E+01, 0.86598500E-01, 0.10944100E+01, -.21834300E+00, -.62990900E+01, 0.86323000E+01, -.29772200E+01, 0.32583800E+01, 0.10536000E+01, 0.13138000E-01, 0.10188700E+01, 0.53695700E+01, -.46488000E+01, -.35047800E+01, 0.15559100E+01, 0.17353000E+01, 0.26032000E+01, 0.39642900E+01, 0.73904500E-01, -.35526700E+01, 0.10088700E+02, -.23813700E+01, 0.49079100E+01, 0.17081400E+02 },
            { -.19828400E+01, 0.50591700E+00, 0.11092900E+01, -.51823100E+00, 0.25824200E+00, -.10547700E+00, 0.44102700E+00, 0.16861300E+00, 0.15141900E+00, 0.96300700E+00, 0.98472100E+00, 0.39027300E+01, 0.55655200E+00, -.10608300E+01, 0.20922700E+00, -.34112000E+00, 0.48491600E+00, -.91036600E+00, 0.32910000E+00, -.12131300E+00, -.53164200E+00, 0.26944400E+00, -.26344800E+00, -.19157100E+01, 0.45694500E-01, 0.40869500E+00, 0.51853800E+00, -.21116400E+00, 0.40072600E+00, -.21116100E+00, 0.60290300E+00, 0.19945200E+00, 0.13628500E+00, -.21744800E+00, -.28535800E+00, -.12807900E+01, 0.31913000E+00, -.12519400E+00, -.18977500E+00, -.63904100E+00, 0.17777100E+01, -.88189900E+00, -.12136900E+01, -.67583400E+00, 0.51099300E+00, 0.11797500E-01, -.63469800E-01, 0.14202200E+01, 0.28656400E+00, 0.64446700E+00, 0.96252500E+00, -.70799000E+00, -.14333100E-01, 0.29473200E+00, -.33081900E+00, 0.20430900E-01, 0.17344400E+01, -.13605000E+00, 0.21728800E+00, 0.71814600E-01, 0.43465900E+00, -.14279600E-01, -.39263100E+00, -.35488300E+00, 0.15574000E-01, 0.13221800E+00, 0.13152200E+01, -.22923500E+00, 0.51958500E-01, -.23241000E+01, -.44134900E+00, 0.47362600E+00, 0.38522100E+00, -.62612900E-02, -.86328800E-01, -.19962900E+00, -.27459400E-01, 0.28017800E+00, 0.25722400E-01, 0.67293500E-01, -.33941800E+00, -.37803800E+00, 0.71483400E+00, -.23509600E+00, -.37350600E-01, 0.18670200E-01, -.18161200E+01, -.31117400E+00, -.29888800E+01, -.14662800E+00, -.61763900E-02, -.42483400E-01, -.15138200E-01, -.13700500E+00, -.19899000E+00, -.90763200E-01, 0.18447100E+00, -.12496000E+00, -.11779400E+00, -.84177100E-02, -.94215700E-01, -.68557200E-01, 0.63775800E-01, -.15908800E+00, -.86334100E-01, 0.42056600E-01, -.47949100E+00, 0.13113100E+00, 0.19757300E-01, -.11917200E+00, -.37236200E+00, 0.24994000E+00, 0.41769300E+00, -.32761900E+01, -.13100400E+01, 0.19071100E-01, -.99981600E+00, -.42110600E+00, 0.18925300E-01, -.54240700E-01, -.59312300E-01, -.73683000E-02, -.89883600E-01, -.19398600E+00, -.69761700E-01, -.62110500E-01, -.20965300E+00, 0.68155200E-01, -.49846300E+00, -.22402800E+00, 0.35309400E-01, 0.17251000E+00, 0.39741400E-01, -.56582700E+00, -.53409300E+00, 0.46692300E-02, 0.16750300E+00, 0.33381300E-01, -.36166400E-01, 0.66809500E-01, 0.98745500E-01, -.48110800E-01, -.29766800E-01, 0.47316900E+00, -.82377000E-01, 0.95042500E-01, 0.13098300E+00, 0.30633200E+00, 0.11583600E-01, 0.48650200E+00, 0.67846400E-01, -.18310900E+00, -.13182400E+00, -.15960800E+00, -.12852000E+00, -.93712300E-01, 0.20677700E+00, 0.71130600E-01, 0.47873100E+00, -.52248500E+00, -.76077300E-01, -.35904600E-01, 0.60390400E+00, -.71827400E-01, 0.11660400E+00, -.12085600E+00, 0.12467600E+00, -.39739500E+00, 0.10239300E+00, -.11367900E+00, -.14041900E+00, -.46397500E+00, 0.11592300E-02, 0.12536800E+00, 0.86070100E-01, -.13725600E+00, -.76856100E+00, -.18872100E+02, -.84706600E+01, 0.14830400E+01, 0.15630100E+02, -.68032900E+01, -.77877300E+01, -.10951300E+02, -.44913900E+01, -.23115100E+01, 0.14506000E+01, -.17664200E+02, -.51922500E+01, 0.22564600E+02, -.11632500E+02, -.10754300E+02, -.10733200E+02, 0.32802900E+01, -.56116600E+01, 0.56634700E+01, -.62575500E+01, -.15496200E+02, 0.11090600E+01, -.84013100E+00, 0.21497700E+00, -.11680700E+02, -.22742800E+02, 0.15035500E+02, 0.94345000E+01, 0.18883700E+02, -.22110100E+02, -.10941500E+02, 0.57711000E+01, 0.65751000E+01, 0.46984700E+00, 0.93505100E+00, 0.19286800E+01, 0.18108900E+01, 0.27811000E+01, 0.17778600E+01, 0.10135000E+02, -.48990400E+01, -.56667800E+01, 0.61409200E+00, -.17506900E+02, 0.43871600E+01, 0.20417500E+02, 0.23753900E+02, 0.19098000E+00, -.35824300E+00, 0.48285100E+01, 0.84338200E+00, -.12954500E+00, -.72619300E+01, -.72869000E+00, -.25183600E+01, 0.44249900E+01, -.19452300E+01, -.30504400E+01, 0.25369300E+00, -.68438700E-01, 0.32728700E+00, 0.51500200E+01, -.40873100E+01, -.55454900E+00, 0.87991900E+01, -.24165200E+01, -.24547700E+01, 0.22422900E+01, 0.35173600E+01, 0.26195200E+01, 0.31373400E+01, 0.28842100E+01, 0.44588100E+01, 0.11603600E+02 },
            { -.51531000E+01, -.15593200E+01, 0.20026400E+01, 0.26731700E+00, 0.10619100E+01, -.12256500E+00, 0.22361900E+01, -.36552400E+00, -.16076100E+01, 0.24491900E+01, 0.41300800E+01, 0.87154100E+01, -.19474300E+01, -.14137700E+01, 0.19454800E+01, -.10548900E+01, -.55547500E+00, 0.33695400E+00, -.55113300E+01, 0.31032700E+00, 0.31299000E+01, 0.24473500E+01, -.97314200E+00, 0.15032100E+01, 0.76939900E+00, -.32605700E+00, -.11601700E+01, 0.12062000E+01, -.16218900E+01, 0.10185300E+01, 0.40203800E+00, 0.11673700E+01, 0.65734600E+00, 0.45032600E+00, 0.27918300E+00, 0.33985000E+01, 0.21663100E-01, -.30489900E-01, 0.56925600E-01, 0.47247500E+01, -.39987900E-01, -.48768300E+00, -.76376900E+00, -.10111600E+01, -.53109700E-01, -.81114300E+00, -.18557600E+01, 0.44679500E+01, -.95848600E+01, 0.55687200E+00, -.98308400E-02, 0.34835700E+01, 0.17594300E+01, -.25092400E+01, -.25384200E+00, -.17958600E+01, 0.71599400E+01, 0.68935500E+00, -.21653100E+01, 0.16604300E+01, -.14546300E+01, -.76094600E+00, 0.13242600E+00, 0.47948300E+00, -.84518600E+00, 0.16273200E+01, 0.26758200E+01, -.20013200E+01, 0.57464500E+01, -.16457500E+02, -.11315300E+01, -.31088700E+01, 0.17823000E+01, -.38939700E+00, -.46306300E-01, -.76125300E+00, -.17966000E+00, -.94067500E+00, 0.92949100E+00, -.12430500E+00, 0.27518400E+01, 0.52560900E+00, -.19067900E+01, -.93510800E-01, 0.89961600E+00, 0.31362000E+00, 0.21245500E+01, 0.21248200E+01, 0.92955700E+01, 0.48810200E+00, 0.74166800E+00, 0.10931800E+00, -.61703700E+00, 0.15699500E+00, -.18696500E+00, -.18523300E+01, -.37151900E+01, 0.11459800E+01, -.60009600E-01, 0.63320700E-02, 0.88193800E+00, -.20388800E+00, 0.47297900E+00, 0.13926200E+01, -.15025100E+01, -.23782700E+01, 0.80533900E+00, -.32465300E+01, -.23697500E+00, 0.14950600E+00, 0.22977800E+01, -.13526000E+01, -.30864900E+01, 0.26286900E+01, 0.49820100E+01, 0.11752500E+01, -.10431000E+02, 0.10151900E+01, -.14585400E+00, 0.62964100E+00, 0.12605600E+01, -.19066200E+01, -.36487200E+00, -.19315200E+01, 0.59295000E+00, -.20764600E+00, -.20953100E+01, -.59777800E+00, 0.24957300E+01, 0.83699700E+00, 0.14693800E+00, 0.10710600E+01, 0.13209200E+01, -.20658100E+01, -.70284500E+00, -.25019500E+00, -.60894300E+00, 0.11861600E+01, 0.27998400E+00, -.18349300E-01, -.61585900E+00, 0.59447300E+00, -.24474000E+00, -.29853500E+01, 0.26084800E+00, 0.27659200E+00, 0.18730500E+00, -.53485800E+01, -.46061800E+00, -.41349500E+01, -.34907400E+00, -.57044300E+00, 0.79074400E+00, 0.25860300E+00, 0.21144000E+00, 0.24973600E+01, 0.76933400E+00, -.50316600E+00, -.21244400E+01, -.41323700E+01, 0.23945100E+01, -.11771300E-01, 0.57790900E+00, -.49913100E+00, -.10108700E+00, 0.45054100E+00, -.60014700E+00, 0.21630900E+01, 0.42430100E+00, 0.62903000E+00, -.42488900E+01, 0.35450800E+01, -.58387500E+00, 0.76016000E+00, 0.25700700E+00, -.24837200E+01, 0.12711000E+00, 0.23999400E+01, 0.62873600E+02, -.47936300E+02, 0.26657300E+03, -.13488500E+03, -.13136200E+03, 0.10694000E+03, 0.10733800E+02, -.13104000E+03, -.79216100E+02, -.13428600E+03, 0.22506700E+02, 0.11948600E+03, -.60519100E+02, -.65334000E+02, 0.71177500E+02, -.38744900E+02, -.67252700E+02, -.76064600E+02, -.69618200E+02, 0.35021600E+02, -.14892600E+03, 0.69434100E+02, 0.66262100E+02, -.82975700E+02, -.37951200E+02, 0.98193600E+02, 0.45775100E+02, 0.10431400E+03, -.26217600E+02, 0.53188400E+02, -.26354000E+02, -.26250600E+02, -.99186600E+01, -.57066500E+02, -.31573900E+01, 0.23362000E+01, 0.70700200E+02, -.60049000E+02, -.36148400E+03, 0.18107700E+03, 0.18363100E+03, -.18694100E+02, 0.78870400E+02, 0.12223800E+03, 0.17527800E+02, 0.62053200E+02, 0.56537400E+01, 0.65445500E+01, -.12278600E+01, -.82871000E+01, 0.27212200E+01, 0.38709600E+02, -.20162500E+01, 0.31068300E+02, 0.47237300E+01, -.83034500E+01, -.35019900E+02, 0.48130600E+01, 0.10689100E+01, 0.46517400E+01, -.35760900E+01, 0.85528200E+01, -.21160600E+01, -.53670100E+02, -.55581000E+01, -.31897000E+02, -.25694100E+01, 0.19739400E+02, 0.78301100E+02, 0.14287000E+02, 0.60434500E+02, 0.13454600E+01, -.17767600E+02 },
            { -.42123600E+01, 0.17849100E+01, 0.26870100E+01, -.14020800E+01, 0.39202000E+01, -.10796700E+00, 0.15260500E+01, 0.26750200E+00, 0.47250200E+00, 0.17086800E+01, -.14335800E+01, 0.30937100E+01, 0.24143300E+01, -.76656600E+00, 0.19939700E+01, -.13202000E+01, 0.24366500E+01, -.14449800E+01, 0.11647400E+01, -.19292300E+01, 0.16917300E-02, -.27803400E+01, 0.13610100E+01, -.60534900E+01, 0.28350000E+00, 0.12420700E+01, 0.74359700E+00, -.93036900E+00, 0.98694100E+00, 0.60923900E+00, 0.11511800E+01, -.16846700E+01, 0.37363700E+00, -.16114800E+01, -.49374200E+00, -.71906100E+01, -.13729800E+01, 0.54223400E+00, 0.77153600E+00, -.78924000E+01, -.66817200E+01, 0.22082700E+01, 0.12622300E+01, 0.22761700E+01, -.74742500E+00, 0.10444000E+01, 0.56240100E+00, 0.52738500E+01, 0.39847100E+01, 0.10423100E+01, -.22964100E+01, 0.71766100E+00, 0.74453900E+00, 0.15367800E+01, -.80809900E+00, 0.25340700E+01, -.29003900E+01, 0.23513700E+00, 0.14062800E+01, 0.11917500E+01, 0.36359700E+01, -.65171500E+00, -.25889300E+00, 0.78785600E+00, 0.23941100E-01, 0.47038500E+00, 0.27871500E+01, -.38167300E+01, -.38519700E+00, 0.14115100E+02, 0.53809000E-01, -.12830000E+01, -.16287000E+01, 0.53630400E+00, -.51986700E-01, 0.39050800E+00, -.75694200E+00, 0.46293200E+00, 0.34249800E+00, 0.77071100E+00, -.21611200E+01, -.10555900E+01, 0.41858300E+00, -.62351600E+00, -.21279100E+00, 0.65370700E+00, -.43688900E+01, -.37264500E+00, -.10302900E+02, -.14273700E+00, 0.19024000E+00, -.19085100E+00, -.79040000E-01, 0.10881900E+01, 0.27686800E+01, -.24258700E+01, -.25738100E+01, -.70209300E+01, 0.15001100E+01, 0.12548500E+01, -.59028800E+00, -.45768600E+00, -.26994100E+01, 0.66036200E+01, -.28180900E+01, -.41124700E+01, -.24831200E+01, -.85101600E+00, 0.48654800E+01, -.26092400E+00, 0.14797100E+01, 0.46525300E+01, 0.70683400E+00, -.58941100E+01, -.33155300E+01, 0.71836900E-01, 0.48482400E+01, -.21047400E+01, 0.91029800E-01, -.48308400E+00, 0.52844500E+00, -.25250100E+01, -.13379800E+00, -.78337600E+00, -.14563600E+01, -.10197800E+01, 0.98032100E+00, 0.90767300E+00, -.80054400E+00, 0.10712600E+01, -.33738000E+00, -.12004100E+01, -.27105600E+00, 0.23487000E+01, 0.16099000E+01, 0.58135000E+00, 0.46509500E+00, -.26273100E+00, -.69993500E+00, 0.49753700E+00, 0.11043400E+00, 0.11816800E+00, -.18891100E+00, 0.26162700E+00, 0.37870600E-01, 0.84716500E-01, 0.90836400E+00, 0.40399600E+01, 0.77573200E+00, -.19408100E+01, -.16761000E+00, 0.53259400E+00, -.10461800E+01, -.17681500E+01, -.21865400E+00, -.20179200E+01, 0.63768100E+00, -.10198400E+01, -.49425700E+00, 0.15409200E+01, -.76394100E+00, -.14344900E+00, -.66604300E+00, -.52490200E+00, -.16472200E-01, 0.49685800E+00, 0.97612900E+00, -.26219300E+01, 0.28537100E+00, -.53467800E+00, 0.31534900E+01, -.10645300E+02, 0.21261900E+00, 0.38981700E+00, 0.12799400E+00, 0.30725200E+01, 0.71062500E+00, 0.92119200E+00, 0.32484800E+00, 0.22735900E+02, -.28758400E+03, 0.14994600E+03, 0.13866700E+03, -.20376000E+02, 0.19429800E+02, 0.78762300E+02, -.92627800E+02, 0.21259900E+03, 0.55294200E+02, -.36997700E+02, 0.10267600E+02, 0.26034200E+02, 0.33825500E+02, 0.60768800E+01, -.28939500E+02, -.62048000E+02, 0.26241900E+01, 0.88914600E+02, -.99745700E+02, 0.41085500E+02, 0.53214200E+02, 0.94833400E+02, 0.42857700E+02, -.24361200E+02, 0.78342700E+02, 0.18307100E+02, 0.57963800E+02, -.18759500E+03, 0.91754500E+02, 0.87752800E+02, 0.21550200E+02, 0.60273400E+02, 0.22391600E+02, -.86957000E+02, -.40461500E+01, 0.61657400E+02, 0.26846000E+02, -.13987700E+02, -.25363800E+02, -.31553100E+02, 0.32077300E+02, -.31545700E+02, -.74113600E+02, -.88480100E+01, -.40898700E+02, -.10423100E+02, -.46767200E+02, 0.14717700E+02, -.27253100E+01, -.67182000E+01, 0.11038400E+01, 0.14431200E+02, -.53481500E+02, 0.28959200E+02, 0.32715800E+01, -.97186700E+01, -.10067700E+01, -.96118900E+01, -.24819400E+02, 0.16708600E+02, 0.10673000E+02, 0.15923300E+02, 0.34152400E+01, 0.36270000E+01, -.17521700E+02, 0.57136300E+01, 0.18958300E+02, -.52236500E+02, 0.53849500E+02, -.35826900E+02, -.65284000E+02 },
            { -.61633300E+01, 0.91652900E+00, 0.41995600E+01, -.89653000E+00, 0.37109000E+01, 0.83969300E+00, 0.31981900E+01, -.27416500E+00, -.26913100E+01, 0.15724100E+01, 0.26097700E+01, 0.86163900E+01, 0.52313100E+00, -.19136700E+01, 0.13396400E+01, -.14856400E+01, 0.23489900E+01, 0.15070500E+00, -.46749900E+01, -.50323300E+00, 0.26862900E+01, 0.15316700E+01, 0.88397100E+00, -.33748300E+01, 0.12643200E+01, 0.11453100E+01, -.39001300E+00, 0.18325700E+00, -.40475700E+00, -.21373400E+01, 0.23321600E+01, 0.21241500E+01, -.98384100E+00, 0.10844700E+01, 0.18577200E+00, -.36739300E+01, -.66635400E+00, 0.25017000E+00, 0.54473500E+00, 0.13068500E+01, -.13365900E+01, 0.54744400E+00, -.19622500E+00, 0.28224600E+01, 0.87362800E+00, -.10253200E+01, -.34033700E+01, 0.40723400E+01, -.28553000E+01, 0.42815900E+01, -.10257400E+01, 0.74452900E+01, 0.41399200E+01, -.38655400E+01, -.24586100E+00, 0.12432700E+01, 0.12553300E+02, 0.19349500E+00, -.42256800E+01, 0.29182200E+01, -.77575000E+00, 0.88012500E+00, -.16462100E+01, 0.67243300E-01, -.31470400E+01, 0.54111900E+01, 0.66937800E+01, -.18074900E+00, 0.51222100E+01, -.25662900E+02, 0.16557300E+00, -.12189300E+01, -.22154800E+00, -.46969100E+00, -.80530500E+00, -.86749900E+00, -.20767300E+01, 0.14006400E+01, 0.36370900E+01, 0.13542100E+01, 0.23502700E+01, 0.12507900E+01, -.27882700E+00, -.15264500E+01, 0.11722300E+01, -.12168900E+01, 0.71473100E+01, -.84839100E+00, 0.85098000E+01, 0.17814400E+00, -.68218200E+00, 0.57975800E+00, -.39662700E+00, 0.37594900E+01, 0.83536400E-01, 0.35972400E+01, 0.48552800E+01, 0.40805700E+01, -.55013900E-01, -.88678800E+00, 0.97331200E+00, -.95416500E+00, -.14919200E+01, -.11667700E+02, 0.26462900E+01, 0.70174200E+01, -.31956300E+00, 0.20612100E+01, 0.62408300E+01, 0.40227400E+00, -.28242700E+01, 0.34039300E+02, 0.58564000E+01, -.16501600E+02, -.91697400E+01, -.81175100E+00, 0.13745100E+02, -.49672200E+01, -.57463100E+00, 0.35905900E+00, -.20564500E+01, -.59504200E+01, -.40494500E+00, -.60315700E+01, -.31087000E+01, -.96946400E+00, -.60933600E+00, -.25160900E+00, -.16044900E+01, 0.84594300E+00, 0.24718000E+00, -.36132100E+00, -.29808400E+00, -.43474800E+01, -.33968200E+01, 0.16951700E+01, -.76743100E+00, 0.10338100E+01, -.11055900E+01, 0.94049600E+00, 0.37276800E+01, 0.65028000E+00, -.17013900E+00, -.11911000E+00, 0.38855400E+00, -.21793400E+00, -.13689500E+00, 0.43659100E+01, -.34729900E+00, -.30281300E+01, -.18183700E+00, -.42094500E+00, -.16259600E+01, -.47074500E+00, 0.93200500E+00, -.15430800E+00, -.11262100E-01, -.15058900E+01, -.38963800E+01, 0.40084700E+01, 0.63507200E+00, -.17881800E+01, -.80909000E+00, 0.39516500E-01, 0.57099500E-01, -.24765600E+01, -.47036300E+00, 0.56945600E+01, 0.30365600E+00, -.28715600E+00, -.79487200E+01, 0.40134100E+01, -.96349700E+00, 0.64160600E+00, -.69612000E-01, -.30011600E+01, -.18533700E+01, -.37690600E-01, 0.11635200E+01, -.15491100E+01, -.50331200E+03, 0.25707800E+03, 0.24471100E+03, -.86811800E+02, -.28064300E+02, 0.22741800E+03, 0.11742700E+03, 0.25305000E+03, 0.71707300E+01, -.11147700E+03, 0.53080900E+02, 0.67875400E+02, -.30115100E+02, 0.40840000E+02, 0.56209800E+01, -.51070800E+02, 0.44901500E+01, 0.65659300E+02, 0.21566000E+03, -.96508000E+02, -.99834200E+02, 0.83627000E+02, 0.11077800E+03, -.16810300E+03, -.15203800E+03, -.17794100E+03, 0.76928700E+02, -.80074600E+03, 0.40114800E+03, 0.39579300E+03, 0.46463000E+02, 0.16398200E+03, 0.20153200E+03, -.60094300E+02, 0.94229300E+02, 0.18268800E+03, 0.15833900E+03, -.76795000E+02, -.97276100E+02, -.30785800E+02, -.58396000E+02, -.15418100E+02, 0.71448200E+02, 0.14179100E+03, -.42142800E+02, 0.72727400E+01, -.28477900E+02, -.29345600E+00, -.26127600E+01, -.43219700E+02, 0.60310900E+01, -.41938900E+02, -.36333800E+02, -.44875700E+01, 0.14620700E+02, 0.17199700E+01, -.15058700E+01, 0.17269200E+01, -.93451500E+01, 0.35280400E+01, 0.40355600E+01, 0.15481900E+03, 0.87579700E+01, 0.14514200E+02, 0.56746600E+01, -.63923500E+01, -.77776200E+02, -.32287400E+02, -.10654600E+03, 0.22976200E+02, 0.15648900E+02 },
            { -.40855200E+01, -.13978400E+01, 0.74290100E+00, 0.49830400E+00, -.22217200E+00, -.47521700E+00, 0.15407000E+01, -.20617000E+00, -.14943600E+01, 0.21754700E+01, 0.37265700E+01, 0.67312500E+01, -.13097500E+01, -.16297100E+01, 0.26272300E+01, -.12146000E+01, 0.39018300E+00, -.11944400E-01, -.19774700E+01, 0.23648900E+00, 0.15566600E+01, 0.98903600E+00, 0.20760100E+00, 0.30308800E+00, -.18658200E+00, 0.15233500E+00, -.62688800E+00, 0.11942600E-01, -.75338000E+00, -.14788200E+00, 0.71970700E+00, 0.19152600E+01, 0.20828900E+00, 0.66579500E+00, 0.35861900E+00, -.45815700E+00, 0.13966300E+01, -.55335100E+00, -.81695900E+00, 0.46519600E+01, 0.52256400E+01, -.23432000E+01, -.15907700E+01, -.29929300E+01, 0.11194800E+01, 0.28877400E+00, -.61571800E+00, -.52261000E-01, -.34365400E+01, -.61706700E+00, 0.10677000E+01, -.17306700E+01, 0.41197900E+00, -.58909500E+00, 0.49682800E+00, -.21607100E+01, 0.29349800E+01, -.18558400E+00, -.78550400E+00, 0.40222500E+00, -.13917200E+01, -.35966900E-01, 0.11893000E+00, 0.19329900E+00, 0.22658600E+00, -.11711700E+01, -.21836400E+01, 0.18135500E+01, 0.80220400E+00, -.13053900E+02, -.71825900E+00, 0.34274100E+00, 0.97734800E+00, 0.84894700E-01, 0.29678900E+00, -.53372200E+00, -.42187700E+00, -.79567900E+00, 0.20411100E+00, -.58845600E+00, 0.20450200E+01, 0.10641900E+01, -.12543800E+01, 0.12500000E+01, 0.78380600E+00, -.54129500E+00, -.12967800E+01, 0.29932700E+00, 0.10135500E+01, -.18766800E-01, 0.39952500E+00, 0.98283300E-01, -.36341100E-01, -.24097900E+01, -.23436300E+01, -.53531600E+00, -.17397600E+01, 0.20516100E+01, -.13968100E+01, -.32854500E+00, 0.68561800E+00, 0.54390400E+00, 0.27401000E+01, -.69298700E+00, -.28184900E+00, -.11814800E+01, -.60445900E+00, 0.64912600E+00, -.23067800E+01, -.70800900E+00, 0.38626500E+00, 0.12100800E+01, 0.46338800E+00, 0.28954600E+01, -.57352700E+00, -.96910500E-01, 0.17293400E+01, -.11926300E+00, 0.55196000E+00, -.18265600E+00, -.26703000E+00, 0.21918900E+00, -.45898000E-01, 0.11069600E+01, 0.12167100E+01, 0.58349600E+00, -.32034600E+00, 0.15786300E-01, 0.69232700E+00, -.13185000E+00, -.67315500E-01, 0.27941500E+00, -.10718700E+00, 0.22402800E+00, -.71001100E-01, -.70291400E-01, -.79144200E-01, 0.66865700E-01, -.45569300E+00, -.64199400E+00, 0.62362400E+00, 0.49813800E+00, 0.81935500E-01, 0.24135000E+00, 0.30395000E+00, -.66779300E-01, -.18126300E+00, 0.24931700E+01, -.36843800E+00, -.32566800E+00, -.23229700E-02, 0.44150100E-01, 0.55705500E+00, -.13451500E+00, -.15726100E+00, -.26951200E+00, 0.16798100E+00, 0.47608000E-01, 0.22785700E+00, 0.89279100E+00, -.46083600E+00, -.32426800E+00, 0.16842600E+00, -.75964700E+00, 0.48902200E+00, -.14391700E+01, -.34085800E+00, 0.24049800E+01, -.14006600E+01, -.10811700E+00, 0.94593000E+00, 0.27629100E+01, -.10430000E-01, 0.13007500E+00, 0.20191600E+00, -.17295700E+01, -.15337100E+01, 0.58967400E+00, -.14392400E+00, -.22234400E+00, -.77482300E-01, 0.60337400E+01, 0.23781700E+01, -.16918700E+02, -.15556400E+02, 0.24158300E+02, 0.15771700E+02, -.10836500E+02, -.12968100E+02, -.28343500E+02, 0.13208400E+02, 0.98230400E+01, -.24676200E+02, 0.54498000E+01, 0.25899900E+02, 0.38922300E+02, 0.11252300E+02, -.13746500E+02, 0.88319700E+01, -.79971500E+01, -.10993800E+02, -.81272600E+01, 0.84261700E+01, -.29410600E+01, 0.18226000E+01, -.18823300E+02, 0.25396400E+01, -.97036500E+02, 0.49311600E+02, 0.51812400E+02, 0.40130700E+01, 0.24163400E+02, 0.29493600E+02, -.15261200E+02, -.36810400E+01, 0.26527100E+02, 0.26426600E+02, -.13195800E+02, -.12584600E+02, 0.37158400E+02, -.84970200E+01, -.14899500E+02, -.13934900E+02, -.10946100E+02, 0.23936900E+02, 0.23186100E+01, 0.92724500E+01, -.24512900E+01, 0.72472000E+00, -.70766600E+01, -.80998800E+00, -.14845400E+02, 0.87982100E+01, -.41772000E+01, 0.76600200E+01, 0.15055300E+01, 0.34541600E+00, 0.14879500E+01, 0.82488100E+01, -.71775500E+01, -.91331600E+01, 0.39017800E+01, 0.33828500E+01, 0.84611900E+01, 0.38978100E+01, -.43524100E+01, -.12245500E+02, 0.26518300E+01, -.10287800E+02, 0.49672700E+01, 0.12703700E+02 },
            { -.15871100E+01, -.23252200E+00, 0.43736700E+00, 0.74703500E+00, 0.53831900E+01, 0.74850800E+00, 0.97570800E+00, -.17002900E+00, -.10206500E+01, 0.85780500E+00, 0.64598300E+00, 0.27706100E+00, 0.78441300E+00, 0.31755000E+00, 0.20729900E+00, -.44391200E+00, 0.14542200E+01, 0.17092500E+00, -.16515300E+01, 0.81556700E+00, 0.20311500E+01, 0.80943100E+00, 0.23113600E+00, -.75204300E+00, 0.60701600E+00, 0.45567200E+00, -.16124000E+00, -.23731800E+00, 0.20369400E-01, -.23623000E+00, -.13085200E+01, -.24204300E+00, 0.44834400E+00, 0.42784500E+00, 0.78326200E-01, -.14924600E+01, 0.32929500E+00, -.12997700E+00, -.16873500E+00, -.55157000E+00, 0.36311900E+00, -.52418800E+00, 0.33846900E+00, -.61116000E+00, -.69590600E-01, 0.89172200E+00, -.14311900E+01, 0.22967400E+01, 0.67130400E+00, -.24818600E+00, -.72515600E+00, -.98187500E+00, 0.64323800E+00, 0.25839400E+00, -.37825500E+00, 0.48405800E+00, 0.40328400E+01, 0.20820700E-01, -.21050300E+00, 0.84489700E+00, -.33671300E+00, 0.24772100E+00, 0.74571300E-01, -.80785200E-01, -.38188500E+00, 0.65207200E+00, 0.16471800E+01, 0.85186200E+00, 0.23794900E-01, -.19066600E+01, -.42026800E+00, 0.98312000E-03, -.26534100E+00, 0.19699700E+00, 0.10222300E-01, -.11617100E+01, -.91917300E-02, -.30418400E+00, -.13375900E+01, -.99835800E+00, -.46672100E+00, -.21131700E+00, -.10649500E+01, -.75112200E-01, 0.19998700E+00, 0.48939300E+00, 0.22784100E+01, 0.14215700E+01, 0.32829900E+01, 0.19803700E+00, -.10308500E+00, 0.13209900E+00, 0.35647800E+00, 0.30254000E+00, 0.25387900E+00, 0.20328800E+00, -.29453500E+00, -.39879100E+00, 0.18534100E+00, -.78949300E-01, 0.22971600E+00, 0.55195500E+00, -.11978700E+01, -.19230100E+01, 0.59755500E+00, -.42532400E+00, -.47246900E+00, 0.12597000E+01, 0.30492200E+01, 0.81330300E-01, 0.36129700E+00, 0.25762900E+01, -.87219600E+00, -.10235500E+00, -.22455300E+01, 0.74795700E-01, 0.12193200E+01, 0.49814500E+00, 0.26012900E+00, -.45749400E+00, 0.23549400E+00, -.49490100E-01, -.19222700E+00, 0.96368600E+00, -.57484700E+00, 0.47268500E+00, 0.84134300E+00, 0.30890300E+00, -.66315900E+00, -.62054400E-01, -.20084700E+00, -.27148300E+00, -.13501400E+00, 0.97992100E+00, 0.14785700E+01, 0.48586700E+00, 0.27217300E-01, -.13753800E+00, -.22748400E+00, 0.32260400E+00, -.26508400E+00, 0.12829900E+00, -.11673100E+00, -.18689700E+00, 0.31870900E-01, 0.16391800E+00, 0.20846900E+00, 0.23386500E+01, -.55069400E-01, 0.18916200E+01, 0.29423400E-01, 0.22594600E+00, 0.66540900E+00, 0.63704600E+00, 0.27661900E+00, 0.44673500E-01, 0.55731000E+00, -.23631500E-01, 0.70585200E+00, -.12032200E-01, -.10082400E+01, -.94227100E-02, 0.51764700E+00, 0.86244700E-01, 0.17567400E+00, 0.40294500E+00, 0.11787700E+00, -.13252700E+01, -.22624600E+00, 0.25804100E+00, 0.15403700E+01, -.77746900E+00, 0.23511500E+00, -.64705400E-01, 0.22691600E-01, 0.82169500E+00, 0.10898600E+01, 0.50278100E-01, -.59461700E-01, 0.31982900E+00, -.19062000E+00, -.30965100E-03, -.29372600E+01, -.80014200E+01, 0.20478500E+02, -.91637500E+01, -.52418000E+02, 0.76340000E+01, 0.16827100E+02, -.33710900E+02, 0.17467300E+02, 0.23540900E+02, 0.39852400E+01, 0.55965200E+01, -.92516300E+01, -.24387300E+02, 0.73727800E+01, 0.17434900E+02, -.51055200E+02, 0.25426100E+02, 0.31942800E+02, 0.18272800E+02, -.59628700E+01, 0.21590800E+01, 0.27297100E+02, 0.25862500E+02, -.47541100E+01, -.44851500E+02, 0.22250100E+02, 0.18243900E+02, -.31243700E+00, -.13413200E+02, 0.12566800E+02, -.20403300E+02, 0.36576300E+02, -.14508800E+01, 0.12403400E+03, -.62216900E+02, -.64567900E+02, 0.11397800E+01, -.31494900E+01, -.49878800E+02, -.34746600E+02, -.61963900E+02, -.10575200E+02, -.21777300E+01, -.26094800E+01, 0.20093300E+01, 0.28588700E+00, -.13420700E+01, -.22055500E+01, 0.10687600E+01, -.73465500E+00, 0.48706500E+01, -.44069800E+01, -.20199700E+01, 0.19716000E+00, -.17649100E+01, -.15758100E-01, -.13380900E+00, 0.35019900E+01, -.12468900E+02, -.62603300E+01, -.43959500E+01, -.36361600E+01, 0.31486200E+01, 0.17064200E+02, -.10444100E+02, 0.20146500E+02, 0.16529700E+01, -.11214800E+02 },
            { 0.75088000E+01, -.12749700E+01, -.30534500E+01, -.35700100E+00, -.55090400E+01, 0.36949600E+00, -.29095700E+01, 0.50794200E+00, -.50138400E+00, -.30738600E+01, -.12341500E+01, -.72874200E+01, -.12891400E+01, 0.12323200E+01, -.30228700E+01, 0.20070900E+01, -.24636200E+01, 0.38163100E+00, 0.47195600E+01, 0.12700900E+01, -.46569300E+01, -.51880100E+00, -.21245700E+01, 0.80236200E+01, -.46926200E+00, -.15119100E+01, 0.88603100E+00, 0.14937100E+01, -.54528100E+00, -.38179100E+00, -.15723900E+01, 0.25629200E+00, -.16422200E+01, -.20931200E+00, -.13297300E+00, 0.14003900E+01, -.59080400E+00, 0.23492400E+00, 0.31445700E+00, 0.27231600E+01, -.56797800E+01, 0.16236500E+01, 0.19808400E+01, 0.23548900E+01, -.13968100E+01, -.25721200E+01, 0.19520500E+01, -.75259800E+01, 0.25234100E+01, -.30261900E+01, 0.20533100E+01, -.19315300E+01, -.21940900E+01, -.21277700E+00, 0.77489700E+00, -.19113500E+01, -.26499800E+01, -.10727800E+00, 0.21284200E-01, -.30972700E+01, -.21391500E+01, 0.59186300E+00, 0.79445200E+00, 0.10946700E+00, 0.12064900E+01, -.16320700E+01, -.53130400E+01, 0.22689100E-01, 0.11924400E+01, 0.20868500E+01, -.13978900E+01, -.18046000E+01, 0.13772700E+01, 0.85938900E-01, 0.42444800E+00, 0.20606600E+01, 0.12318800E+01, -.11471300E+01, 0.15394000E+01, -.23547900E+00, 0.15941200E+01, 0.20771700E+01, -.18513300E+01, 0.11839300E+01, -.39528600E+00, -.64788900E+00, 0.34587900E+01, 0.63515400E+00, 0.45568200E+01, 0.32529000E+00, -.93106500E-01, 0.73442400E-01, 0.38005200E-01, -.11594600E+01, -.41523400E+00, -.26854500E+00, 0.44149600E+00, -.68243700E+00, -.18474900E+00, -.92356700E-01, 0.12778300E+00, 0.16918100E+00, 0.98311900E+00, 0.48281200E+01, -.56603000E+00, -.12061200E+01, -.46750000E+00, -.19084100E+00, 0.54585800E+01, 0.87835500E+00, 0.13198900E+01, -.14402600E+02, -.21465400E+01, 0.30243700E+01, 0.21652600E+01, 0.81864600E+00, -.18917100E+02, 0.19477800E+01, 0.79399900E+00, 0.72336500E+00, 0.53304500E+00, 0.30966000E+01, 0.13687800E+00, 0.30045100E+00, 0.26074900E+00, -.84793400E+00, -.28186600E+01, -.63246700E+00, 0.32929800E+01, -.11702300E+01, 0.38272100E+00, 0.14888900E+01, -.13793700E+01, -.13119600E+01, -.20339000E+01, -.12185000E+01, -.48388300E+00, -.12814100E+01, 0.11713500E+01, -.22249000E+01, 0.43045400E+00, -.24568600E+00, 0.47795200E+00, -.42607700E+00, -.35767500E+00, 0.22039500E+00, 0.75276000E+00, -.15269100E+02, -.52199700E+00, -.51597100E+00, -.54373500E+00, -.48853800E+00, 0.21427700E+01, 0.19018100E+01, 0.33891300E+00, 0.16038500E+01, -.49045400E+00, 0.13296700E+01, 0.23992400E+01, -.21777500E+00, 0.13059600E+01, 0.28285600E+00, -.14597900E+01, 0.28919100E+00, -.19333800E+00, 0.10949700E+01, -.86174000E+00, -.15099100E+00, 0.57748000E-01, 0.95813400E-01, -.12597700E+01, 0.51444200E+01, -.25108900E+00, 0.24236300E+00, 0.27691200E+00, -.19889500E+01, -.16735300E+01, 0.17599500E+00, -.80868700E-01, 0.66359100E+00, -.48307500E+00, -.90373600E+00, -.21350700E+01, -.88646100E+02, -.39062500E+02, 0.61965400E+02, 0.54551000E+02, -.33996200E+01, -.56121000E+02, -.18437300E+03, 0.10224000E+03, 0.94984300E+02, -.10699500E+03, 0.35607100E+02, 0.94217700E+02, 0.70100800E+02, 0.10431100E+03, -.59820400E+02, 0.16844000E+03, -.71406800E+02, -.78746600E+02, 0.82797900E+01, 0.47830900E+02, -.98207200E+02, -.55528900E+02, -.11870600E+03, 0.75939900E+01, -.33795500E+03, 0.17137800E+03, 0.17388200E+03, 0.23125500E+01, 0.35685400E+02, 0.10865600E+03, -.93147600E+01, 0.35061500E+02, 0.64326300E+02, 0.36003700E+03, -.17995000E+03, -.18071300E+03, 0.10936800E+03, -.74289400E+02, -.12331600E+03, -.35935100E+02, -.11067200E+03, 0.62372400E+02, -.86826800E+00, 0.46505400E+02, -.19429100E+02, 0.25472200E+01, -.11054800E+02, -.14359200E+01, -.73006600E+02, 0.48433500E+02, -.10802000E+02, 0.37974300E+02, 0.50431200E+00, 0.13977400E+01, 0.13659400E+01, 0.23782400E+02, -.22462000E+02, -.18008300E+02, 0.40946900E+02, 0.66221800E+01, 0.34429200E+02, 0.11487200E+02, -.11013900E+02, -.60901400E+02, 0.21268600E+02, -.64617700E+02, 0.57579600E+02, 0.80619800E+02 },
            { 0.67629000E+01, 0.35141400E+00, -.21377800E+01, 0.19931900E+00, -.23310300E+01, 0.14336800E+00, -.15722700E+01, -.39823800E+00, 0.25474000E+00, -.32607900E+00, 0.40627000E+01, 0.39722200E+00, -.32227300E+01, -.35102800E+00, -.24689600E+01, 0.10950300E+01, -.16031400E+01, 0.23919500E+01, 0.16171800E+01, 0.59793700E+00, -.70745600E+00, -.28365700E+01, -.54931600E-01, 0.57980100E+01, -.11298100E+01, -.62652600E+00, -.48687500E+00, 0.61340700E+00, 0.63535800E+00, 0.99023300E+00, -.15576800E-01, 0.23100100E+01, -.30937100E+01, -.48253200E+00, 0.11612100E+01, 0.35923300E+01, 0.89740500E+00, -.35840100E+00, -.52670500E+00, 0.22066000E+01, 0.33201800E+01, -.18260300E+01, -.16721900E+01, -.15902000E+01, 0.14132300E+01, 0.13548500E+00, -.19635400E+01, 0.34618100E+01, -.45564700E+01, -.24919000E+00, 0.43453400E+00, -.96734500E+00, -.28522000E+00, -.58996500E+00, 0.15000300E+00, -.18266000E+01, 0.73549700E+01, 0.16521000E+00, -.84001300E+00, 0.80827100E+00, 0.12187500E+01, -.15534600E+01, -.14715900E+01, -.14200300E+01, -.78035000E-01, 0.77079000E+00, -.27905600E+01, 0.16716100E+01, 0.22751500E+01, -.17471600E+02, -.25252800E+01, -.80237500E+00, 0.12627200E+01, 0.19210100E+00, 0.20320700E+00, 0.26197800E+01, -.47590800E+00, -.22376300E+01, -.46579100E+00, -.29323700E+01, 0.33133300E+00, 0.20559400E+01, -.36428800E+01, 0.17231600E+01, 0.43464600E+00, -.14291500E+01, 0.17014400E+02, -.12654600E+01, 0.24262600E+02, 0.13634500E+01, 0.77487400E-01, 0.27890400E+00, 0.91338400E-02, -.17379300E+01, -.12544300E+01, -.25360500E-02, 0.77867200E+00, 0.40147000E+00, -.52491400E+00, -.40079100E-01, 0.78820500E+00, 0.20559800E+00, 0.15338100E+01, 0.51492000E+01, -.48329000E+00, -.89624300E+00, -.15365500E+01, 0.52250300E+00, 0.59428900E+01, 0.16922000E+01, -.11672100E+01, -.21892500E+02, -.33589400E+01, -.26261100E+01, 0.23043400E+01, 0.45856500E+00, -.91394500E+01, 0.42153400E+01, -.94828000E+00, 0.96434200E+00, 0.11972700E+01, 0.33142900E+01, -.10036800E+00, 0.18599400E+00, 0.11520600E+01, -.69800000E+00, -.25557500E+01, -.43563900E+00, 0.21254100E+01, -.89892800E+00, 0.37111000E+00, 0.13112600E+01, 0.85867600E+00, -.16076600E+01, -.26348400E+01, -.19483500E+01, -.95937400E+00, 0.12587000E+00, 0.70490600E-03, -.46486400E+00, -.28336600E+01, 0.18901400E+00, -.36616700E+00, 0.23118500E+01, -.61854000E+00, 0.35236800E+00, 0.25993800E+00, -.23772100E+01, -.31088800E+00, -.39888800E+01, -.26337500E+00, -.75246800E-02, 0.33682400E+01, 0.73284900E+00, -.19591800E+01, 0.40147600E+00, 0.38662500E+00, 0.20844500E+00, 0.30585400E+00, -.48932600E+00, 0.21395800E-01, -.63887600E-01, 0.49027100E+00, 0.29095400E+00, 0.64942900E+00, -.12674500E+01, 0.42031900E-01, 0.22282100E+01, -.52590100E+00, -.17286000E+01, -.24936600E+01, -.53681800E+00, -.27961800E-01, 0.62821100E+00, 0.45831600E+00, -.13881200E+01, -.20679400E+01, 0.28661000E+01, 0.63790000E+00, 0.35815600E-01, 0.14297000E+00, -.38974500E+00, -.16315100E+01, 0.58887700E+00, 0.49031200E+02, -.26787000E+02, -.13899500E+03, 0.60128300E+02, 0.57707500E+02, 0.32179700E+02, -.16669400E+02, -.11600000E+02, 0.38528200E+02, 0.78057800E+01, -.69458900E+02, -.74327600E+02, -.45974800E+02, 0.76082100E+02, -.30396600E+03, 0.14897600E+03, 0.14935600E+03, 0.78111900E+02, 0.14435800E+02, 0.51910700E+02, 0.12813300E+03, 0.10566300E+03, 0.35230800E+02, 0.49449400E+02, -.26094900E+02, -.29749800E+02, -.79195600E+01, -.31498000E+02, -.27835800E+02, -.56844100E+02, 0.16814100E+02, -.14878700E+02, 0.57776700E+02, -.29835100E+02, -.31389700E+02, -.40571900E+02, 0.24947500E+02, -.24237700E+02, -.14522400E+02, -.37320500E+02, -.38099200E+02, -.10920000E+02, -.25617400E+02, 0.10966800E+02, -.70008800E+00, -.90962400E+01, -.29603800E+01, 0.93851700E+01, -.25602700E+02, 0.21112900E+02, -.12226400E+02, -.91400000E+01, 0.24788400E-01, -.85444100E+01, -.10432000E+02, 0.80520100E+01, 0.17359800E+02, -.12083300E+02, -.14890500E+02, -.11956900E+02, -.16419400E+02, 0.15705800E+02, 0.46706100E+02, -.34786500E+02, 0.83664900E+02, -.15997800E+02, -.47473600E+02 },
            { -.19954800E+01, -.84401600E-01, 0.75432400E+00, -.55030300E+00, 0.58471800E+00, 0.71917700E-01, 0.30754100E+00, 0.37704700E+00, -.67011400E-01, 0.86851900E-01, -.11811800E+01, -.10799900E+01, 0.88863500E+00, -.86029000E-02, 0.11723000E+01, -.44562800E+00, 0.80367300E+00, -.12134500E+01, 0.69794800E+00, -.10670300E+00, -.44283100E+00, 0.15637200E+01, -.93567600E-01, 0.41595600E+00, 0.23140300E+00, 0.20227500E+00, 0.28457600E+00, -.11182500E+00, -.81623400E-01, -.53243600E+00, -.30942200E+00, -.98041600E+00, 0.11826600E+01, -.29801900E+00, -.79625400E+00, -.75495200E+00, -.30638100E+00, 0.12360600E+00, 0.17566000E+00, -.39296700E+00, -.98785400E+00, 0.54819100E+00, 0.51090600E+00, 0.56693900E+00, -.43322500E+00, -.27704300E+00, 0.53459600E+00, -.14067100E+01, 0.15667000E+01, -.50764100E-01, 0.13566900E+00, -.19802700E+00, -.38009500E-01, -.18716400E+00, -.19389200E+00, 0.32518800E+00, 0.25212200E+00, -.14173500E+00, -.24607600E+00, -.87690100E-01, -.65991900E+00, 0.56875400E+00, 0.38206600E+00, 0.35517900E+00, 0.82725000E-01, -.73048200E+00, 0.88773300E-01, -.20818300E+00, -.20077800E+00, 0.83392200E+00, 0.15760700E+00, -.19093100E+00, -.18577700E+00, 0.14742500E+00, -.47683600E-01, -.72099800E+00, 0.15390900E+00, 0.19921300E+00, -.41418000E+00, 0.33422600E+00, 0.15904900E+00, -.56146200E-01, 0.11457300E+00, -.47383400E+00, 0.59064800E-02, 0.33945500E+00, -.32356300E+01, 0.35363600E+00, -.47607800E+01, -.29259700E+00, -.10817300E+00, -.32664800E-02, 0.60233300E-01, 0.45358800E+00, 0.93539400E-01, 0.36673200E+00, 0.27360400E+00, 0.42204500E+00, 0.63908600E-01, -.18086500E+00, -.77533100E-01, 0.48647900E-01, -.48426500E+00, -.25673300E+01, 0.58060200E+00, 0.71418900E+00, 0.63525100E+00, -.29283300E+00, -.31162400E+01, -.52063800E+00, -.25285800E-02, 0.42237400E+01, 0.67051800E+00, 0.17548800E+01, 0.24254200E+00, -.60082300E-01, 0.15052000E+01, -.57428000E+00, 0.21314800E+00, -.47461900E-01, -.25984900E+00, -.10402200E+01, -.17236800E+00, 0.21660100E+00, -.81564300E-01, -.15154100E+00, -.51659800E-01, 0.12939600E+00, -.30057800E+00, 0.43151800E-02, -.91218900E-01, -.28962200E+00, -.19771300E+00, 0.33325200E+00, 0.10149800E+01, 0.37757700E+00, 0.46793600E-01, 0.15483900E+00, -.39236100E-01, -.62348200E-01, 0.82756100E+00, 0.36361100E-02, 0.46774600E-01, 0.14726200E+00, 0.14583300E+00, -.27935000E-02, -.18501100E+00, 0.21775700E+01, 0.16461100E+00, -.37292900E+00, 0.51701900E-01, -.19445800E-01, -.80000800E+00, -.31295700E+00, 0.21237700E+00, -.63505900E+00, -.11616300E+00, -.10044400E+00, -.34180600E+00, 0.40087200E+00, -.17441100E+00, 0.11807700E-01, -.13777000E-01, 0.47638000E-01, -.10404300E+00, -.68141600E-01, -.93665900E-01, -.80529300E-01, -.35525200E-02, 0.33101500E+00, 0.40975900E+00, -.30816800E+00, 0.12351700E+00, -.26116300E-01, -.69505300E-01, -.88709800E-01, 0.34428300E+00, -.50006300E+00, -.85306400E-02, -.22862000E-01, -.59112200E-01, -.13582100E+00, 0.35297800E+00, 0.66000500E-01, -.14456100E+00, 0.15140400E+02, 0.25196200E+02, 0.36171400E+01, -.23567300E+00, -.66440700E+00, 0.89867600E+00, -.11276600E+01, 0.69396100E+01, 0.29021300E+01, -.20857100E+01, 0.38613500E+01, -.11903300E+02, 0.60149900E+01, -.16074400E+02, 0.98717600E+01, 0.55716900E+01, 0.10892100E+02, 0.13588700E+02, -.59040700E+01, -.14681600E+02, -.82768900E+01, 0.12281700E+02, -.37599000E+02, 0.18636900E+02, 0.16404400E+02, -.21512900E+01, 0.21472800E+02, 0.96873800E+01, -.10545900E+02, -.13571900E+02, 0.20584300E+02, 0.54992700E+01, -.27058500E+01, -.42228400E+01, -.82056600E+01, -.11644700E+00, -.41417300E+00, 0.14178200E+02, 0.17703900E+02, -.49817700E+01, 0.31658700E+01, -.71503700E+01, 0.18272400E+01, -.53134700E+00, -.11612900E+02, 0.15214800E+01, -.53542600E+01, -.85905600E+01, -.11044600E+01, 0.93773100E+00, 0.12003200E+01, -.33203900E+00, 0.96193200E+00, -.16858600E+01, 0.22264900E+01, -.17394600E+01, 0.39132700E+01, 0.32970100E+01, 0.16470000E+01, 0.10526500E+01, -.16489200E+01, -.97970600E+01, -.33897700E+01, -.13744400E+02, -.88685300E+01, -.97193100E+01 },
            { -.18982300E+01, -.15841000E+01, 0.30082900E+00, 0.70534200E+00, 0.41325300E+01, 0.58879800E+00, 0.10179100E+01, -.34933400E+00, -.13620100E+01, 0.65122000E+00, 0.17983300E+00, 0.97070400E+00, 0.28812600E+00, -.31863800E+00, -.41447300E-02, -.43750900E+00, 0.79969800E+00, 0.71647600E-01, -.14961700E+01, -.25760200E-01, 0.30356100E+01, -.12668400E+01, -.16366000E+00, -.43616800E+01, 0.92563300E+00, 0.85760900E-01, -.12604200E+00, -.11204100E+00, 0.82337100E-01, -.20925200E+00, -.56461800E+00, -.12951800E+00, -.25982700E+00, -.44148300E+00, -.23909800E+00, -.23659000E+01, -.16298900E+00, 0.64469800E-01, 0.10645300E+00, -.97393800E+00, -.42131400E+00, 0.26425100E-01, -.34332600E+00, -.23725300E+00, 0.26586100E-01, -.20633600E+00, -.20449900E+00, 0.13537900E+01, -.14837600E+00, -.10508800E+00, -.32023000E+00, -.35703300E+00, 0.10980400E+01, -.47379500E+00, -.24467400E+00, -.64632900E-01, 0.23101500E+01, -.17782800E-01, -.36063600E+00, 0.60715700E+00, 0.24133000E+00, -.15734300E+00, -.10183800E+00, -.22067700E+00, 0.27574300E+00, -.75694700E-01, -.94163000E-01, 0.70078900E+00, -.30583900E+00, -.36986100E+01, -.30485700E+00, 0.62116300E+00, -.18470000E+00, -.10240800E+00, -.43116100E-01, -.41634900E+00, 0.22719900E+00, 0.50595500E-01, -.10943100E+01, -.31553000E+00, -.76640000E+00, -.29837300E+00, 0.14174100E+00, -.33175600E+00, -.61204800E-01, 0.35641900E+00, -.74939700E+00, 0.15302600E+01, -.97311600E+00, -.12913300E+00, -.24275200E+00, 0.98111500E-01, 0.28165800E+00, -.10847700E+01, -.11609400E+01, 0.10035500E+01, 0.11728600E+01, 0.14057000E+01, -.74378300E+00, -.40581000E+00, 0.12927900E+00, 0.43702600E+00, 0.84800100E+00, -.18011600E+01, 0.10074300E+01, 0.67658300E+00, -.88714400E+00, 0.24204500E+01, 0.32245300E+01, 0.16845500E+00, -.45952400E+00, 0.85573900E+00, 0.12199100E+01, 0.41440700E+00, -.23322900E+01, -.17593500E+00, -.12522100E+01, -.12213900E+01, -.14535100E-01, 0.29168500E-01, -.53535500E+00, 0.98904500E+00, 0.16866500E+00, 0.21617800E+01, 0.13941100E+01, 0.49864100E+00, -.20755300E-01, -.36559500E+00, 0.57977100E+00, 0.47991100E+00, 0.70418400E-01, 0.35846900E+00, -.16655300E+00, 0.31122200E+00, 0.33332800E+00, -.28609800E+00, 0.83781600E-01, -.11073600E+00, 0.72448000E-01, -.73107900E-01, 0.19769300E+00, 0.60475800E-02, 0.19925100E+00, -.79965800E+00, 0.36446300E+00, -.80786300E-01, -.35527800E+00, 0.73927600E+00, 0.18085800E+00, -.95815000E-01, 0.11908700E+00, -.89921500E-01, -.11390700E+01, -.60641900E+00, -.41049300E+00, -.11833700E+01, 0.23489200E-01, -.12208900E+00, 0.72317200E+00, 0.49623100E+00, -.85983900E+00, 0.27874100E+00, 0.33343300E+00, -.27321500E+00, 0.41909100E+00, 0.13867600E+00, -.24288400E+00, -.91304100E+00, -.10203000E+00, 0.35779600E+00, 0.38453100E+00, 0.68680600E+00, 0.62503200E-01, -.20225600E+00, -.99762400E-01, 0.67940100E-01, 0.56185600E+00, -.13502600E+01, -.36532300E+00, -.90643200E-01, 0.35056700E-01, 0.38775000E+00, -.31755700E-01, -.18813100E+00, 0.34341000E+00, -.39750000E+00, 0.67262300E+02, -.46161300E+02, -.15057600E+02, -.51516500E+02, 0.25742200E+02, 0.24648200E+02, -.32667200E+02, 0.11512100E+02, 0.42270700E+02, 0.33634900E+02, 0.38429900E+02, -.36090400E+02, 0.14711500E+03, -.73918800E+02, -.69906000E+02, -.29680900E+02, -.10466700E+02, -.33566900E+02, -.78075700E+02, -.36473600E+02, -.24232300E+02, 0.66268300E+02, -.33040700E+02, -.30701600E+02, -.50647300E+01, 0.59919500E+01, -.15720100E+02, 0.25157900E+02, -.23603000E+02, -.54868900E+01, 0.26728300E+02, -.13388900E+02, -.12308300E+02, 0.24398800E+02, -.24014600E+02, -.84601100E+01, -.45396600E+01, -.93316600E+01, 0.23318700E+02, 0.61088000E+01, 0.18313000E+01, -.21523100E+01, -.15538000E+00, -.47300300E+01, 0.35300700E+01, 0.80693700E+01, 0.27474300E+01, -.94335500E+01, 0.12009500E+02, 0.35794200E+01, -.23074000E+00, 0.34364600E+01, 0.21072600E+01, 0.11256600E+01, -.78571800E+01, 0.92319100E+01, 0.81816200E+01, 0.11916800E+02, 0.68465900E+01, -.82389100E+01, -.23110400E+02, 0.14300500E+02, -.53977500E+02, -.87054400E+01, 0.20326300E+02 },
            { 0.23754800E+01, -.79238000E+00, -.10443600E+01, -.22814700E+00, -.99019800E+00, 0.12142800E-01, -.75722800E+00, 0.77368900E-02, 0.11562600E+01, -.30499100E+00, -.20483500E+00, -.13215700E+01, -.15882800E+00, 0.16523200E+00, -.76003200E-01, 0.38694300E-01, -.25160400E+00, 0.78691900E+00, 0.65175700E+00, -.30456300E+00, -.30893800E+00, 0.55363400E+00, 0.13087300E+01, -.18219300E+01, -.60060700E+00, 0.22318500E+00, -.19457300E+00, -.96117000E+00, 0.22020100E-01, -.27718000E+00, -.49230700E+00, 0.12135100E+00, -.55192100E+00, 0.43884000E+00, 0.32415900E+00, -.22666700E+01, 0.50497800E-01, -.14099800E-01, -.46079900E-01, -.35000500E+00, -.62105200E+00, 0.27432400E+00, 0.56165200E+00, 0.18900200E+00, -.24245000E+00, -.14097100E+00, 0.76597000E-01, -.17232000E+01, 0.18175300E+01, -.48371800E+00, 0.18843400E+00, -.54987400E+00, 0.24579700E+00, 0.61479200E-01, 0.33643200E+00, -.21741900E+00, -.72272200E+00, -.21368800E+00, 0.11416400E-01, -.53929100E+00, -.14432000E+00, 0.24071100E+00, -.22051900E+00, 0.85893900E-01, 0.34215200E+00, -.58133800E+00, -.16737700E+01, 0.49472000E+00, -.57528400E+00, 0.26572300E+01, -.28986000E+00, 0.37461500E-01, -.21461000E+00, 0.83806200E-01, 0.17243700E+00, -.83719000E-01, 0.29893300E+00, 0.11054800E+00, -.10892000E+00, -.12275600E-01, -.39618900E+00, -.31128200E-01, 0.46256900E+00, 0.49803700E+00, -.32473200E+00, 0.27011700E-01, -.24908200E+01, 0.37819300E+00, -.33255000E+01, -.12446000E+00, 0.11805900E+00, -.11501800E+00, 0.12184300E+00, -.12741800E+01, -.61370800E+00, -.62426100E+00, -.43408800E+00, -.68373100E+00, -.37206100E+00, 0.94665500E-01, -.16707600E+00, 0.31281200E+00, 0.98682700E+00, 0.21430200E+01, -.50928800E+00, -.11496800E+01, -.69838800E+00, 0.62306200E+00, -.37859900E+00, -.13401000E+00, 0.12013000E+00, -.46371200E+01, -.34888100E+00, 0.11100100E+01, -.16471800E+01, -.23192800E+00, -.20046700E+01, 0.33248200E+00, 0.25222700E+00, -.16122500E+00, -.20734500E+00, 0.13993500E+01, 0.62824600E-01, 0.10799100E+01, 0.78543300E-01, -.14929600E-02, -.72323100E+00, -.10303100E+00, 0.38944500E+00, -.38357400E+00, 0.97058600E-02, 0.12212600E+00, -.31049400E+00, -.22653900E+00, -.31914600E+00, -.29545400E+00, 0.14021700E+00, -.39386700E+00, 0.37143200E+00, -.38401200E+00, 0.42940900E+00, -.15037700E+00, 0.11246100E+00, -.28540500E-01, -.33901300E-01, -.21320900E-01, 0.14851600E-01, -.13933300E+01, 0.10407500E-01, -.11415500E+00, -.35438900E-01, 0.26845400E+00, 0.13505200E+00, 0.64819500E-01, -.32501500E+00, -.65189900E+00, -.19819100E+00, 0.12445200E+00, 0.33970700E+00, 0.75835500E+00, -.34024400E+00, 0.24118900E+00, 0.27819100E+00, 0.65045800E-01, 0.14275000E+00, -.13716100E+00, 0.36175200E+00, -.62683500E+00, -.60864900E+00, -.41160200E-01, 0.23277400E+01, -.80668000E+00, 0.24419000E+00, 0.25344500E-01, -.30691200E-01, 0.78305100E-01, -.58326700E+00, 0.16384100E+00, -.29227700E+00, 0.14636000E+00, -.13194000E+00, -.14787800E+00, -.79423000E+00, 0.19805100E+00, 0.92388100E-01, 0.10425600E+01, -.60887900E+00, -.32678300E+02, -.10620200E+02, -.81454700E+02, 0.40653900E+02, 0.41322500E+02, -.33761200E+02, 0.33652500E+01, 0.45827700E+02, 0.40562300E+02, 0.51363300E+02, -.33827100E+02, 0.52875200E+02, -.29936800E+02, -.23741700E+02, -.25807500E+02, -.17232700E+02, -.52584900E+01, -.19306200E+02, 0.61656500E+00, -.20612300E+02, 0.27852000E+02, -.13765100E+02, -.10505300E+02, 0.24588400E+01, -.16885500E+02, -.35520600E+00, 0.14360400E+02, 0.21274400E+02, -.18954900E+02, 0.12162700E+03, -.61029100E+02, -.59351700E+02, 0.46421000E+02, -.17538300E+02, -.58297400E+02, -.65367500E+02, -.87129000E+02, 0.26073200E+02, 0.41665200E+00, 0.13618900E+02, -.66610000E+00, 0.74457500E+00, 0.36670500E+01, -.86214200E+00, 0.58214100E+01, 0.16820200E+02, -.32872700E+01, 0.27820400E+01, 0.13278400E+01, 0.35389700E+00, 0.13506500E+01, 0.58746100E+01, -.39414400E+01, -.75680000E+01, -.14273400E+02, 0.20296300E+01, 0.34123400E+01, 0.31834900E+01, -.40356100E+01, -.30826100E+01, 0.80807500E+01, -.11740200E+02, 0.95061500E+01, 0.14312400E+02 },
            { 0.71798300E+00, 0.92704100E+00, 0.33173800E+00, -.18239100E+01, -.36824500E+01, -.26411800E+00, -.43384400E+00, 0.57318400E+00, 0.15289200E+01, -.73899700E+00, -.66841900E+00, 0.15069100E+00, -.17822900E+00, 0.34082800E-01, 0.36221700E+00, 0.30680300E+00, -.95579700E+00, 0.11656500E+00, 0.18266500E+00, -.41575400E-01, -.84753000E+00, 0.30717600E+00, 0.45707100E+00, -.95021800E+00, 0.69576800E-01, 0.38399400E+00, 0.45862000E+00, -.20977600E+00, -.41629600E-01, -.19954100E+00, 0.38019700E+00, -.44318800E+00, -.26114800E-01, 0.17860000E+00, -.32221200E-01, 0.20913700E+01, -.66998900E+00, 0.25978600E+00, 0.39476100E+00, -.14311300E+01, -.43381800E+01, 0.13812300E+01, 0.15619200E+01, 0.21531400E+01, -.11481900E+01, -.51764300E+00, 0.36670900E+00, -.29182600E+00, 0.12552400E+01, -.25000600E+00, -.86373600E+00, 0.14623000E+01, -.24769100E+00, 0.18878400E+00, -.14013500E+00, 0.51003900E+00, -.16314300E+01, 0.16737200E+00, 0.34729800E+00, -.21688100E+00, -.47623500E-01, 0.51794500E-01, 0.49648300E-01, -.33693900E+00, -.44471600E+00, 0.55785600E+00, 0.13069100E+01, -.17929200E+01, 0.30310400E+00, 0.36341300E+01, 0.65411400E+00, -.12755200E+01, -.63057700E+00, 0.71943800E-01, -.11165600E+00, 0.31873500E-01, -.12507600E+00, 0.33052000E-01, 0.51966200E+00, 0.26401500E+00, 0.51170100E-01, 0.17679600E+00, 0.31027800E+00, -.20536100E+00, -.24211900E+00, -.15781900E+00, 0.94880700E+00, -.64505200E+00, -.25408500E-01, -.28570200E-01, -.26853600E+00, 0.17494600E-01, 0.39791600E-01, 0.17321100E+01, 0.99532200E+00, 0.70314100E+00, 0.11634400E+01, 0.43125400E-01, 0.64747800E+00, -.14648900E+00, -.18976400E+00, -.18179600E+00, -.12552900E+01, -.18578900E+01, 0.77056200E+00, 0.13720400E+01, 0.13071600E+01, -.30421500E+00, 0.76546900E+00, 0.45920600E+00, -.20113900E+00, -.72955800E+00, 0.66703200E+00, 0.90656900E-01, 0.18680700E+01, 0.48586900E-01, -.20655800E+01, -.43988500E+00, -.22681800E-01, 0.17527200E+00, -.19816000E+00, -.11435100E+01, -.23377600E-01, -.33224900E+00, -.63410700E-01, 0.55814200E-01, 0.44645500E-01, -.48936400E-01, 0.26835900E+00, -.21722900E+00, 0.84332600E-01, 0.10721800E+00, 0.92733900E-01, -.11550100E+01, -.35711600E+00, -.67843200E-01, -.89285800E-01, -.55657300E-01, 0.34301600E+00, 0.19214500E+00, 0.49895200E+00, -.14018600E+00, -.26730200E-01, 0.98479200E-01, -.17791100E+00, 0.15436400E+00, 0.32223000E+00, -.68764300E+00, 0.16927900E+00, -.23575500E+01, -.55606000E-01, -.25018200E+00, -.19660900E-02, -.30368100E-01, -.11128800E+00, 0.16008300E+00, 0.22051600E+00, 0.28799000E-01, 0.67736900E+00, -.93878700E+00, 0.15057500E+00, -.15194900E+00, 0.81952400E+00, -.16633800E+00, 0.10541400E+00, 0.21159700E+00, -.42325600E+00, -.13066700E+00, 0.71402100E-04, 0.10917400E+00, -.58899800E+00, 0.13976800E+01, -.11302500E+00, 0.18318000E+00, -.26711600E-01, -.46159800E+00, 0.18189800E+00, -.16136300E+00, 0.39470200E-02, -.10890300E-01, 0.37911800E-01, 0.74251100E-01, 0.48407900E-01, 0.18741100E-01, 0.42204700E-01, -.66374200E+00, 0.27838400E+00, 0.29594400E+00, 0.11277600E+02, 0.56014800E+02, -.28380600E+02, -.27841600E+02, 0.20521400E+02, 0.37401100E+01, -.30621900E+02, -.24248000E+02, -.39539400E+02, 0.17584800E+02, -.33951100E+02, 0.18113700E+02, 0.15258500E+02, 0.93038200E+01, 0.35588700E+01, 0.97593700E+01, 0.83944000E+01, 0.35125900E+01, -.15108000E+01, 0.17732900E+02, -.88995100E+01, -.11580400E+02, -.84564400E+00, 0.95789300E+01, -.72356900E+01, 0.59826900E+00, -.13804900E+02, 0.47727200E+01, -.60384800E+02, 0.30478200E+02, 0.29461600E+02, -.27448000E+02, 0.33917300E+01, 0.29538300E+02, 0.40431200E+02, 0.52492100E+02, -.14080000E+02, 0.73746100E-02, -.12092200E+02, 0.38431900E+01, -.84880900E+00, -.10855100E+02, 0.13730400E-01, 0.80520900E+01, -.13931700E+02, 0.15063800E+01, -.40052700E+01, -.12661600E+00, -.41867600E+00, -.34702000E+00, -.42064200E+01, 0.48093000E+01, 0.13815300E+01, 0.32851000E+01, -.15150900E+01, -.36998700E+01, -.13604600E+01, -.38575200E+00, 0.13507300E+02, -.50775600E+01, 0.57480200E+01, -.12711100E+02, -.12281100E+02 },
            { -.19002000E+01, -.40985400E+00, 0.52567400E+00, 0.68647700E+00, 0.34273200E+01, 0.44051800E+00, 0.11365900E+01, -.26192000E+00, -.29116900E+01, 0.50758800E+00, 0.10519200E+01, 0.13514700E+01, 0.31135400E+00, 0.24376200E-01, -.49075500E+00, -.12199900E+00, 0.49028600E+00, -.32002000E+00, -.16403100E+01, 0.78390300E+00, 0.82620500E+00, 0.12044500E+01, -.92183100E+00, 0.17551300E+01, 0.23141300E+00, -.39149600E+00, -.46862900E+00, 0.50709700E+00, -.30878800E+00, 0.80632600E+00, -.73854400E+00, 0.15822000E+00, 0.19698900E+00, 0.41570400E+00, 0.13450800E-01, -.26313200E+01, -.11427700E+00, 0.44655600E-01, 0.62594700E-01, -.15591100E+01, -.15641600E+01, 0.82805600E-01, 0.14343600E-01, 0.59769100E-01, 0.13399900E+00, -.12662100E+00, -.26061400E+00, 0.99752300E+00, 0.32264900E+00, -.43722500E+00, 0.10763200E+01, -.13838400E+01, 0.45610100E+00, -.14029600E+00, -.44980300E+00, -.25165100E+00, 0.27099900E+01, -.30138500E-01, -.75951100E+00, 0.21358900E+00, -.59424900E+00, -.18952000E+00, 0.11799400E+00, 0.15841000E+00, 0.42908100E+00, -.59862400E+00, 0.30854900E+00, 0.88491600E+00, -.25029000E+00, -.66685600E+00, -.59068300E+00, 0.18139800E+01, 0.11221800E+01, -.15606300E+00, -.80423700E-01, 0.20187400E+00, 0.38155000E+00, -.28018800E-01, -.12397200E+01, -.47876200E+00, -.57285400E-01, -.60197600E+00, -.18362200E+00, -.12629000E+00, -.95338000E-02, 0.45450100E+00, -.91970600E-01, 0.95936400E-01, -.27610000E+00, -.37887800E-01, -.71397000E-01, -.16052400E-01, 0.99487500E-02, -.51571300E+00, 0.13496800E-01, 0.28609300E+00, -.24735500E+00, 0.25702700E+00, 0.71651200E-02, -.27299100E-01, -.10529500E+00, -.21085000E-01, 0.52404300E+00, 0.21235800E+01, -.32363200E+00, -.40458900E+00, 0.91865500E+00, -.18980700E+01, 0.25700700E+00, 0.20831300E+00, 0.41074000E+00, -.10133500E+00, -.90989700E+00, 0.11981400E+01, -.67343100E+00, 0.94991100E-01, 0.23323700E+01, 0.97695600E+00, 0.30524000E+00, -.28370600E+00, 0.68569600E+00, 0.50190200E+00, 0.31136100E+00, 0.51500600E+00, 0.14717500E+01, -.10353700E+00, 0.95940700E+00, 0.28347100E+00, -.19260700E-01, 0.32315900E+00, -.50342800E-01, -.31185500E+00, 0.59538900E+00, 0.21514300E+01, 0.16745600E+01, -.13569700E+00, 0.46198400E+00, -.28845300E+00, 0.14339700E+00, -.42454000E+00, -.19548400E+01, -.99024300E-01, -.31959000E-02, 0.25191300E+00, -.12130600E+00, 0.13684300E+00, -.66429900E-02, -.89948000E+00, -.14695500E+00, -.25587700E-01, 0.10873200E+00, -.39931700E-01, 0.88178100E-01, 0.10308000E+01, -.93330800E-01, 0.80143200E+00, -.36705500E+00, -.86274700E-02, -.23091400E+00, -.15479900E+01, 0.14092100E+01, -.79461800E-01, 0.26599900E+00, 0.79405900E-01, -.54813500E+00, -.20082000E+00, -.59722100E+00, 0.25762200E+01, 0.84799900E+00, -.12504500E+01, -.29322100E+01, -.18293800E+00, -.22240100E+00, 0.52868700E+00, 0.30964700E+00, -.12843500E+01, -.10860700E+01, -.26466600E+00, -.48276800E-01, 0.13848200E+00, -.10059300E+00, -.16347700E+00, -.84674300E+00, 0.28688600E+00, -.27507700E+00, -.59362600E-01, 0.26218000E+00, 0.73996500E-01, 0.22151900E+00, 0.76366500E+02, -.39511400E+02, -.35136000E+02, 0.24097600E+02, -.60779000E+01, -.42782900E+02, -.37359800E+02, -.42555000E+02, 0.25569000E+01, -.52543400E+02, 0.24341400E+02, 0.23961500E+02, -.12753700E+01, -.13573600E+01, 0.17627300E+02, -.17134900E+02, 0.18790800E+02, -.86695800E+00, 0.11971900E+02, -.56224600E+01, -.82012800E+01, 0.69749500E+01, -.15238300E+02, -.25495900E+01, 0.82852600E+01, 0.32360700E+02, -.14428800E+02, -.48290500E+02, 0.24891800E+02, 0.22635700E+02, -.35597800E+02, 0.14309400E+02, 0.24345500E+02, 0.51730400E+02, 0.41075600E+02, -.12848800E+02, 0.10993800E+01, 0.66519200E+00, 0.14382800E+01, 0.19077700E+00, 0.78296900E+01, -.17769600E+01, 0.15712400E+01, 0.34202900E+01, -.43054400E+01, -.10306700E+02, 0.68056800E+00, 0.30266800E-01, 0.80724200E+00, 0.25855900E+01, -.11262800E+01, 0.48513600E+01, -.39283700E+01, -.88320700E+01, -.10495700E+02, -.48880200E+00, 0.86579000E+00, -.16679100E+01, 0.53446800E+01, -.58999700E+01, 0.14335000E+02, -.24490700E+00 },
            { 0.11838500E+01, 0.17849500E+00, -.40853600E+00, -.39710300E+00, -.26280300E+01, -.31815300E+00, -.82717500E+00, 0.15450600E+00, 0.16025400E+01, -.43546600E+00, -.48284300E+00, -.13114200E+00, -.12091600E+00, -.21003200E+00, 0.33176400E-01, 0.21506500E+00, -.65585100E+00, -.11571800E+00, 0.15150100E+01, -.49312900E+00, -.22119600E+01, 0.32893300E-02, 0.45158900E+00, 0.31647300E+00, -.55239800E+00, -.16749800E+00, 0.64628700E-01, -.81364800E-01, 0.38124400E-01, 0.19647200E+00, 0.10320600E+01, -.59631700E-01, -.55257200E-01, -.48339500E+00, -.26761100E+00, 0.29300900E+01, -.30820800E+00, 0.12034500E+00, 0.17596800E+00, 0.22289000E+00, 0.35905600E+00, 0.35627200E+00, -.43632600E+00, 0.59197200E+00, 0.98931500E-01, -.53103500E+00, 0.45489600E+00, -.41420800E+00, -.16791400E+01, 0.64287800E+00, -.91411700E-01, 0.14345600E+01, -.54846600E+00, -.39700600E+00, 0.20257200E+00, -.22192200E+00, -.23328000E+01, 0.92450600E-01, 0.47632200E+00, -.51063600E+00, 0.23211400E-02, 0.25432200E+00, -.95083600E-01, -.33214600E+00, 0.17243200E+00, 0.17670600E+00, -.11454500E+01, -.16985500E+00, 0.31517200E-01, 0.58415200E+00, -.98043000E-01, -.10891100E+01, -.16418000E+00, 0.41031100E-01, 0.17655500E+00, 0.11224100E+01, -.10218400E+00, -.18008900E+00, 0.11093300E+01, 0.48385300E+00, 0.15769000E-01, 0.59206300E+00, -.49098300E-01, -.30922400E-01, -.19897300E-01, -.27856100E+00, -.32781400E+00, -.83579900E-01, 0.39859700E+00, -.67738800E-01, -.91316900E-01, 0.39293100E-01, 0.30262000E-01, -.13961300E+00, -.66958600E+00, 0.45564900E+00, 0.95948500E+00, 0.16692900E+01, -.30234100E+00, -.37758300E+00, 0.10032400E+00, 0.10418100E+00, 0.16502300E+00, -.15872300E+01, 0.97762700E+00, 0.73663600E+00, 0.61148200E+00, -.22604900E+00, -.99995300E+00, -.90707800E-01, -.22334500E+00, -.10144900E+01, 0.29127000E+00, 0.12098900E+01, 0.27132900E+01, 0.37547300E+00, -.63385300E+01, 0.22279800E+00, 0.29383600E-01, 0.37836800E+00, -.19769600E+00, 0.15519200E+00, -.66183400E-01, 0.45257600E+00, 0.34525700E+00, 0.18608700E+00, -.31344100E+00, -.20671500E+00, 0.95398000E+00, 0.53415200E-01, 0.11626700E+00, 0.78927500E+00, 0.30099800E+00, -.12300400E+01, 0.32357500E+00, -.35293200E+00, -.34432800E+00, -.20663300E+00, 0.64553200E+00, -.53072500E+00, 0.31015400E+00, -.13326800E-01, 0.16037600E+00, 0.60177000E+00, 0.15416600E+00, -.29383500E-01, -.29629600E+00, 0.90702900E+00, 0.97026100E-01, -.30651900E+00, 0.12938300E+00, -.11758800E+00, -.65018400E+00, -.15231400E+00, -.36743700E-01, -.69921000E+00, -.32177000E+00, 0.95765800E-01, 0.10674900E+00, -.91166100E-02, -.73343200E-01, -.45661400E+00, 0.94376400E+00, -.67989600E-01, -.13999900E+00, -.41734500E+00, -.19968900E+00, 0.24089000E+00, 0.22400700E+00, -.53020300E+00, -.16021100E+01, 0.19187400E+01, -.19729500E+00, 0.24008900E+00, -.15817600E+00, -.52557400E+00, -.40158000E+00, -.76605800E-01, 0.39679200E-02, -.21698600E+00, 0.10462500E+00, 0.18781400E+00, 0.67362400E-01, 0.13011200E+00, 0.17632300E-02, -.56011800E+00, 0.37068000E+00, -.27589200E+00, 0.72601200E+00, -.31672000E-01, -.17647100E+01, -.59339300E+00, -.56801800E+01, -.15128300E+01, -.26312000E+01, -.14327300E+01, 0.18884800E+01, -.98129400E+00, -.43159400E+02, 0.18358700E+02, 0.20855500E+02, -.86029200E+01, -.51432900E+01, 0.17900000E+02, -.92145700E+01, 0.30267400E+02, -.12812000E+00, 0.64560000E+02, -.32608100E+02, -.32634500E+02, -.55505400E+00, -.19277500E+02, -.15865500E+02, 0.14644000E+02, 0.15236800E+02, -.18058400E+02, 0.18069100E+02, -.90896200E+01, -.88564100E+01, 0.83240000E+01, -.24940100E+01, -.94187100E+01, -.15478900E+02, -.16364700E+02, 0.37296300E+01, -.14165200E+01, 0.75362800E+01, 0.62188700E+00, 0.37967600E+00, 0.92922900E+01, -.83969400E+00, -.65573200E+01, 0.96566700E+01, -.10685300E+01, -.61675600E+01, -.59038200E+00, 0.23837300E+00, -.36918600E+00, 0.36972300E+01, -.22683100E+01, 0.99633800E+00, -.13177600E+02, -.51913200E+01, -.66555800E+01, -.77826300E+00, 0.21059500E+01, -.50821600E+01, -.44644800E+00, -.34834900E+01, 0.17693700E+02, 0.10078300E+02 },
            { -.32299300E+01, 0.52374500E+00, 0.19580600E+01, -.12824400E+00, 0.29998200E+01, 0.20845200E+00, 0.14288600E+01, -.50960000E-01, -.79781400E+00, 0.11224300E+01, -.22741300E+00, 0.29720200E+01, 0.64711100E+00, -.55451400E+00, 0.81098400E+00, -.72804000E+00, 0.89059600E+00, -.29900900E+00, -.17534400E+01, -.36626800E+00, 0.32020900E+01, -.45556400E+00, 0.42106000E-01, -.37903100E+01, 0.51843300E+00, 0.83502500E+00, 0.87099900E-01, -.39475700E+00, 0.20549800E+00, -.11990300E+01, 0.32489600E+00, 0.55791600E+00, 0.14085100E+00, 0.60508300E+00, 0.15261800E+00, -.23460600E+01, -.17643000E+00, 0.65004600E-01, 0.15249800E+00, -.10265800E+01, -.19791500E+01, 0.10346900E+00, 0.16360500E+00, 0.81531700E+00, -.26424800E+00, 0.50430300E+00, -.65409600E+00, 0.26576300E+01, 0.29371200E+00, 0.53980200E+00, -.85375500E+00, 0.60548800E+00, 0.73463600E+00, -.35048300E+00, -.79129800E-01, 0.43367700E+00, 0.11163700E+01, -.19738400E+00, -.42760100E+00, 0.94205100E+00, -.93455300E+00, 0.64774900E+00, -.47383700E+00, -.98448700E+00, -.35107500E+00, 0.51987900E+00, 0.12793900E+01, 0.62340200E+00, 0.50750100E-01, -.11784700E+02, 0.67539800E+00, 0.18364200E+01, 0.81082500E-01, -.33637300E+00, 0.93829500E-01, -.42313700E+00, -.49277000E+00, -.14709600E+00, -.96222200E+00, -.62014300E-01, -.11602600E+00, -.47155600E+00, 0.59272700E+00, -.60844900E-01, 0.99258000E-01, -.57951500E-01, 0.35265100E+01, 0.93084300E+00, 0.54618600E+01, 0.23179800E-01, -.58189100E+00, 0.27383200E+00, 0.53329900E+00, 0.40625700E+00, -.80495400E+00, 0.26826800E+01, 0.26241300E+01, 0.38261400E+01, -.42420600E+00, -.85571900E+00, 0.30533100E+00, 0.57675800E+00, 0.33073100E-01, -.57870700E+01, 0.22709100E+01, 0.34889900E+01, 0.11930200E+01, 0.95578500E+00, 0.91425900E+00, 0.42787200E+00, -.96972500E+00, 0.37962100E+01, 0.29800200E-01, 0.12080400E+01, 0.93466300E+00, 0.23222500E-01, 0.60179200E+01, 0.51041300E+00, 0.11569500E+00, -.88035200E+00, -.90407900E-01, 0.78823500E+00, 0.49741200E+00, 0.29315900E+01, 0.14731000E+01, 0.16753000E+01, 0.82494700E+00, -.59199200E+00, -.10441200E+01, -.23347800E+00, -.36001100E+00, -.20886300E+00, 0.16767900E+00, 0.68937300E+00, -.20370800E+00, -.26222500E-01, -.26921000E-01, 0.61546000E+00, -.55400500E+00, 0.80764200E-01, -.39242000E+00, 0.42611200E+00, -.12721400E+00, -.44109900E+00, 0.27157000E+00, 0.15007300E-01, -.50683100E+00, 0.57805900E+01, -.54551000E-01, -.54511000E+01, -.13663400E+00, -.10923900E+00, -.15932900E+01, -.54583500E+00, -.25312400E+00, -.17144900E+00, 0.10669700E+00, -.60807800E+00, -.79731200E+00, -.69165900E+00, -.49620300E+00, -.50090000E+00, 0.13253400E+01, -.28748200E+00, 0.58265800E+00, -.13174600E+01, 0.21630400E-01, 0.30739500E+01, -.42614400E+00, -.42270600E+00, -.44198000E+01, 0.55330900E+01, -.55436700E+00, 0.95388500E+00, -.34609900E+00, -.23009100E+01, -.46562400E+00, -.30427200E+00, 0.21810300E+00, -.26539000E+00, 0.24333900E-01, 0.40967900E+00, -.12212100E-01, 0.33119300E+00, -.30192000E+00, 0.24808600E+00, 0.31812600E+00, -.28737400E+00, 0.85582700E+00, 0.26843100E+00, 0.17652400E+01, -.45202500E+01, 0.86303100E+00, 0.32890600E+01, -.88745600E+01, -.21478000E+02, 0.15263000E+02, 0.10723200E+01, 0.14149400E+02, -.47459500E+01, -.26149600E+01, 0.11223200E+02, 0.21203800E+02, -.24894100E+02, -.39000800E+01, -.23169800E+02, 0.10215600E+02, -.38550300E+02, 0.19679100E+02, 0.23691800E+02, 0.35985200E+01, -.34187100E+00, 0.97397600E+01, -.28036100E+01, 0.10939100E+01, 0.12982200E+01, -.51612400E+02, 0.26034500E+02, 0.22126500E+02, -.35001200E+01, 0.94069100E+01, 0.21953900E+02, 0.19444400E+02, 0.11477000E+02, 0.28482500E+01, 0.10056800E+01, -.20703000E+01, -.26224300E+01, 0.10727200E+00, 0.82349300E+01, 0.27456900E+01, 0.11385500E+02, -.23908500E+01, 0.23902100E+01, 0.78898400E+01, -.40292200E+00, 0.76875800E-02, -.31357000E+00, -.37998400E+01, 0.26503000E+01, 0.12431400E+01, 0.10368400E+02, 0.13167000E+01, 0.88387100E+01, -.49909000E+00, -.12743100E+01, 0.17278400E+01, 0.47251000E+01, -.46702500E+01, -.10184300E+02, 0.31002200E+01 },
            { 0.72350100E+00, 0.14059700E+00, -.20874600E+00, -.17532000E+00, -.30428700E+00, 0.35159900E-01, -.24124300E+00, 0.13942700E+00, 0.57035000E+00, -.13861300E-01, 0.15379400E+00, -.60207500E+00, 0.10066600E+00, -.35801700E+00, 0.38362800E+00, -.90963900E-01, 0.21689100E+00, -.87835700E-01, 0.28121400E+00, -.46761000E-01, 0.50900900E-01, -.86157900E-01, 0.21741700E+00, -.47625200E+00, 0.86394700E-02, 0.15760900E+00, 0.36332100E-01, -.17906100E+00, 0.75346100E-01, -.12212100E+00, 0.50994100E+00, 0.46111000E-01, -.45593800E-01, 0.12207000E+00, 0.36808500E-01, 0.30184400E+00, 0.56291700E-01, -.23462300E-01, -.34474400E-01, 0.34872000E+00, -.56112300E+00, 0.25633800E-01, 0.25008700E+00, 0.18131700E+00, -.27865800E+00, -.35024600E+00, -.12000700E+00, -.19311500E+00, 0.32325200E-01, -.17331700E+00, -.16343700E+00, 0.28424000E+00, 0.50247300E+00, 0.13827800E+00, -.41904200E+00, 0.38945300E+00, 0.48777200E+00, 0.15813600E+00, -.99428300E-01, 0.31209100E+00, 0.50820300E+00, -.42068200E+00, 0.13611000E+00, -.85219000E-01, -.28055300E+00, 0.78025400E-01, 0.84465300E+00, -.55707800E+00, 0.61064200E-01, 0.32346700E+00, 0.65878400E+00, -.72796700E-01, -.33121400E+00, -.95631100E-01, -.12207000E+00, -.45728600E+00, -.10218700E+00, 0.20430900E+00, -.18804300E+00, -.31369600E-01, 0.35187200E+00, -.90249300E-02, 0.20471800E+00, -.39951300E-02, -.53910200E-01, -.27715000E-01, -.33615200E-01, -.21005300E+00, -.74532400E-01, 0.11178300E-01, 0.75763600E-01, -.43898000E-01, -.12266200E+00, 0.63461100E+00, 0.35697800E+00, -.19274500E+00, -.35928000E+00, -.31555900E+00, 0.22902300E+00, 0.10404300E+00, -.67741300E-01, -.19616700E+00, -.14774100E+00, -.89842100E+00, -.74428600E-01, 0.21849000E+00, 0.45190500E+00, -.37734600E+00, -.17912100E+01, -.10937600E-01, 0.88836600E-01, -.18998300E+01, -.14533200E+00, 0.36956500E+00, 0.62864900E+00, -.88571800E-01, 0.12801700E+01, -.24896600E+00, -.57552600E-02, 0.40261800E-01, 0.14560100E-01, -.52413800E+00, 0.12672100E+00, -.74005900E-01, -.31214300E+00, 0.18308800E+00, 0.76187700E+00, 0.93598700E-01, -.79243700E-01, 0.75469700E-01, -.30358900E-01, -.22984300E+00, -.14060900E-01, 0.24312900E+00, 0.22360600E+00, 0.32577600E+00, 0.75861700E-01, 0.16118600E+00, -.41314200E-01, 0.54445800E+00, 0.30723100E+00, -.66419400E-01, -.69737400E-01, -.23293600E+00, -.81851800E-01, -.75223500E-02, 0.17307800E-01, 0.41403200E+00, 0.63263200E-01, -.43009200E+00, 0.29588000E-01, 0.42227400E-01, -.11287300E+00, 0.13967200E+00, 0.13348800E+00, 0.15690000E-02, -.13204100E+00, -.44837500E-01, -.78417700E-01, 0.20076300E-01, -.75170400E-01, -.23464400E-02, 0.15049900E+00, 0.89087600E-02, 0.34704100E-01, 0.98260500E-02, 0.11590400E+00, 0.14422600E+00, -.23999000E+00, 0.32701000E-01, 0.19589900E+00, -.68602200E+00, 0.13059000E-01, -.87330000E-01, 0.29411900E-01, 0.26990900E+00, -.96910600E-02, -.94884100E-01, -.51185300E-01, -.46204100E-01, 0.30961100E-01, 0.45555300E-01, 0.25503800E-01, -.58759600E-01, -.13319700E-01, -.19557400E+00, -.11847500E+00, 0.47395900E-01, -.27557100E+00, 0.33616800E-01, 0.10417700E-01, -.20253200E-01, 0.32264100E+01, 0.11230400E+01, -.15339300E+01, 0.59141900E+00, -.26098900E+01, 0.40924400E+01, 0.39498700E+01, -.18885000E+01, -.17151800E+01, 0.15906100E+01, 0.88388500E+00, -.18790600E+01, 0.13206000E+01, -.17828300E+01, -.20396100E+01, 0.21631200E+02, -.10879800E+02, -.11783800E+02, -.22206900E+01, 0.27787700E+01, -.57301500E+01, -.63176400E+00, -.67036000E+01, -.40763000E+01, 0.11223300E+02, -.55979200E+01, -.54343900E+01, -.51405500E+01, -.29027900E+00, -.57034800E+01, -.57039000E+01, -.26852100E+01, -.30360700E+01, 0.10827100E+00, -.45567000E+01, 0.16883300E+01, -.33336400E+00, -.34085900E+01, 0.21840700E+00, 0.13473900E+01, -.50699300E+01, 0.67761600E+00, -.61665600E-02, 0.13193500E+00, -.16659800E+00, 0.18333400E-01, -.18143400E+01, 0.21899700E+01, 0.79568200E-01, -.63811100E+01, 0.87106400E+00, 0.47738900E+00, -.32796300E+00, -.66956700E+00, 0.26932600E+01, -.27940100E+01, 0.31303300E+00, -.13289700E+01, -.64553900E+01 },
            { -.70428100E+01, -.40046600E+00, 0.31038300E+01, -.80269800E+00, 0.11714900E+01, -.86653100E-01, 0.21210600E+01, 0.69540200E+00, -.13657800E+01, 0.80363400E+00, -.28043800E+01, 0.21577700E+00, 0.18270500E+01, -.49291500E+00, 0.29307900E+01, -.13653300E+01, 0.21717200E+01, -.14698400E+01, -.23090600E+01, -.59782400E+00, 0.12934200E+01, 0.41457400E+01, 0.49543300E+00, -.19912700E+01, 0.97794000E+00, 0.16623700E+01, 0.70375400E+00, -.70828700E+00, -.69928300E+00, -.89458200E+00, 0.28320300E-01, -.12153400E+01, 0.33624700E+01, -.14501700E+01, -.19558400E+01, -.23638800E+01, 0.10730100E+00, -.49728400E-01, -.51574900E-01, -.20063700E+01, 0.67818100E+00, -.17145500E+00, -.53101700E+00, -.93974200E+00, 0.11477500E+00, 0.12003900E+01, 0.30640400E+00, 0.24229200E+01, -.92574000E+00, 0.34907200E+00, -.12416300E+01, 0.91826800E+00, 0.46169400E+00, 0.10997900E+01, 0.56896200E+00, 0.30285600E+00, -.67776100E+01, 0.29647700E+00, 0.23036600E+01, 0.11889300E+00, 0.19563800E+01, 0.17964900E+00, 0.34711500E+00, 0.72350400E+00, -.13204900E+01, 0.16835700E+01, 0.30925800E+01, -.12027900E+01, -.11967800E+01, 0.11857700E+02, 0.92875000E+00, 0.28501600E+00, -.13854100E+01, 0.41758200E+00, -.47064400E-01, -.51805700E-01, -.76705700E+00, 0.74157300E+00, 0.13093000E+01, 0.93320500E+00, -.11316900E+01, -.13882300E+01, 0.23691100E+01, 0.34845300E+00, -.61522600E+00, 0.37781900E-01, -.12931700E+01, -.23439400E+00, -.21937000E+01, 0.43514100E-01, 0.35678800E+00, -.27565700E+00, -.19017600E+00, 0.21648100E+00, 0.12896600E+01, -.15745600E+01, -.18429400E+01, -.31389000E+01, 0.52298800E+00, 0.99314200E+00, -.55245300E+00, -.37988500E+00, -.23253500E+00, 0.50307700E+01, -.22141500E+01, -.20607600E+01, -.25417900E+01, 0.95912900E+00, 0.78880500E+01, 0.20542700E+00, 0.92384000E+00, 0.12690700E+02, 0.15819000E+01, -.45589100E+01, -.35471100E+01, -.54657900E+00, 0.14826100E+02, -.14157400E+01, -.28401800E-01, -.10441800E+01, -.24751100E-01, -.24223600E+01, 0.38356900E-02, -.24566900E+01, -.18164100E+01, -.74719600E+00, 0.57122500E+00, 0.62885900E+00, -.13017800E+01, 0.11459900E+01, -.18236300E+00, -.72277000E+00, -.61460500E-01, 0.54682100E+00, -.53090700E+00, 0.12015700E+01, 0.54692500E+00, -.66909500E+00, -.24324900E+00, 0.44667700E+00, 0.73088300E+00, -.43851800E+00, -.13718100E-01, 0.13485800E+01, -.47177700E-01, -.10249200E+00, 0.37794300E+00, 0.33805200E+01, -.22032900E+00, -.53034700E+00, -.24293400E+00, 0.56728100E+00, -.62298800E+00, -.83774800E+00, 0.61055000E-01, -.48305800E+00, 0.94928600E+00, -.46134800E+00, -.31317100E+00, 0.49747300E+00, -.75167000E+00, -.12010300E+01, -.25872200E+00, -.48075200E+00, 0.35577600E-01, -.18433000E+01, 0.35291800E+00, 0.23204900E+01, -.10528900E+01, -.13744900E+01, -.20356600E+01, 0.46990400E+01, -.69695100E+00, 0.60074500E+00, 0.28309700E+00, -.21356500E+01, -.31487900E+01, 0.22068200E+01, 0.19369200E+00, -.30578900E+00, 0.22844200E+00, 0.83075400E+00, -.28523000E+00, -.58159700E-01, -.25368200E+00, -.10631000E+01, -.12004000E+01, 0.99144800E-02, 0.33601200E+00, -.36949400E+00, 0.26375000E+01, 0.45985600E+00, -.27679500E+01, 0.25846600E+02, -.37327400E+01, 0.22401600E+01, -.62508900E+01, 0.35080200E+01, 0.90219200E+02, -.43252100E+02, -.47452600E+02, 0.43373100E+02, 0.43640700E+02, -.62903200E+02, 0.63894400E+01, -.94829500E+02, 0.18050300E+02, 0.12492700E+03, -.62592900E+02, -.68462300E+02, -.14349700E+02, 0.13237500E+02, -.26905600E+02, -.25850500E+02, -.10243200E+03, -.15342600E+02, -.15477600E+03, 0.77017100E+02, 0.79752500E+02, -.89367100E+01, 0.15052900E+02, 0.60832300E+02, 0.48348200E+02, 0.61223100E+02, 0.16955500E+02, -.10568700E+01, -.20474600E+02, 0.84517000E+00, -.14015100E+01, -.18305600E+02, 0.43759900E+01, 0.96349100E+01, -.26435200E+02, 0.66253400E+01, 0.23954400E+02, -.18541600E+01, -.60046900E+00, -.20740700E+01, -.12762300E+02, 0.87561800E+01, 0.10416200E+01, 0.22313200E+02, 0.12670900E+02, 0.24243700E+02, -.13003800E+01, -.26231400E+01, 0.41732700E+01, 0.23713700E+01, -.10761500E+02, -.34437700E+02, -.12463400E+02 },
            { 0.14981600E+01, 0.13759000E+01, -.16899400E+00, -.55837900E+00, -.21220300E+01, -.28072500E+00, -.64757400E+00, 0.25246600E+00, 0.11049400E+01, -.55211000E+00, -.11061700E+00, -.18973300E+01, 0.26698500E+00, -.32582500E+00, 0.56860100E+00, 0.12708700E+00, -.19267400E+00, -.92593000E+00, 0.15250900E+01, 0.98527100E-01, -.12177900E+01, -.51326500E+00, 0.14145600E+00, 0.32573600E+01, -.25732600E+00, -.43171700E+00, 0.17779100E+00, 0.56248400E+00, 0.86709400E-01, 0.14768200E+00, 0.88616800E-02, 0.22881000E+00, -.10279600E+01, -.23231100E+00, -.47822200E-01, 0.27332800E+01, 0.52955900E+00, -.20579800E+00, -.34166800E+00, 0.27559500E+01, 0.20565500E+01, -.84613600E+00, -.87128900E+00, -.52979100E+00, 0.40757600E+00, -.19265300E+01, 0.16170500E-01, -.33609300E+01, -.65756500E+00, 0.22973500E+00, 0.19842000E+01, 0.50681100E+00, 0.25994700E+00, -.37169300E+00, -.57193500E+00, -.35673700E+00, 0.14672500E+01, 0.71204400E-01, -.43000000E+00, 0.68027900E-02, 0.78753000E+00, -.97505300E+00, 0.12902800E+00, 0.14292200E+00, 0.16395600E+00, -.88496000E+00, -.14487100E+01, 0.12495500E+00, 0.14350100E+00, 0.26775500E+01, -.20736700E+00, -.21333000E+00, 0.55048400E+00, 0.12042400E+00, 0.64505400E-01, 0.25961000E+00, 0.33529000E+00, -.28710900E+00, -.62573500E+00, -.28039400E+00, 0.69378300E+00, 0.30623500E+00, -.65084400E+00, -.60534000E-01, -.22675200E+00, 0.26067500E+00, -.42282200E+00, -.24735500E+00, -.86069000E+00, -.61702300E-01, -.94347500E-01, -.57484900E-01, 0.22623800E-01, 0.80476900E+00, 0.67809800E+00, 0.11686800E+00, -.31690900E+00, 0.44864900E-01, 0.42467000E+00, -.13710700E+00, -.22358000E+00, -.41980900E-01, -.53306000E+00, -.91374400E+00, 0.30862400E+00, -.17474500E+00, 0.13932600E+01, -.15586300E+01, -.40397800E+01, 0.35018300E-02, 0.10011100E+01, -.42494600E+01, -.11981300E+01, 0.42436200E+01, 0.20319700E+01, 0.24308800E+00, -.48370800E+01, 0.63009200E+00, 0.48551100E+00, -.81313300E-01, 0.17899600E+00, 0.37472300E+00, 0.19198600E+00, -.68529300E-01, -.66744400E-01, -.38179700E+00, -.73352400E+00, 0.58752600E-01, 0.84185900E+00, -.45517800E-01, -.69821500E-01, -.12663900E+00, 0.69659500E-01, 0.63704200E+00, -.34314800E-01, 0.19406100E+00, 0.35658400E-01, 0.30757700E+00, -.61007900E-02, 0.79024100E-01, 0.84106000E-01, 0.12257200E+00, -.90388500E-01, 0.53459200E+00, -.48018800E-01, -.49864600E-01, -.14317000E+00, 0.29432000E+00, -.20814700E+00, 0.79557300E+00, -.31832600E-01, 0.45995600E-01, 0.70131400E+00, 0.98228100E+00, 0.55106800E+00, 0.99981000E+00, -.28271400E+00, 0.38190300E+00, 0.34449600E+00, -.29544300E+00, -.13035300E+00, 0.89088400E-01, -.20819800E+00, 0.35306700E+00, -.57220200E-01, 0.29429400E+00, 0.36126200E-02, -.59816400E+00, 0.90460900E-01, 0.25798700E+00, 0.25522700E+00, -.73381000E+00, 0.39725000E-01, -.12755300E+00, 0.37545100E-01, 0.53564200E+00, 0.34193800E+00, -.86167000E-01, -.24373500E-01, -.86296100E-01, 0.39431100E-01, -.20147500E+00, 0.37779800E+00, -.72232800E-01, 0.99035100E-01, -.25080000E+00, 0.58650700E-01, -.14483000E+00, 0.13570400E-01, 0.39227700E-01, -.19313000E+00, 0.50349600E+00, -.25505100E+00, -.23259500E+00, 0.10117100E+02, 0.24147000E+02, -.59483100E+01, 0.19097100E+01, 0.26777100E+02, -.15465600E+02, -.17110600E+02, -.51196700E+01, -.11762600E+02, 0.51268600E+01, 0.15374700E+02, -.29207100E+01, -.58085800E+01, 0.57359500E+02, -.28909200E+02, -.31478200E+02, -.45014000E+01, 0.84998000E+01, -.14113600E+02, -.55615300E+01, -.36623600E+02, -.18364800E+01, -.44617700E+02, 0.22018100E+02, 0.24345300E+02, 0.36271800E+01, 0.36541200E+01, 0.10739100E+02, -.11415200E+02, 0.14292500E+02, 0.40596100E+01, -.31900200E+00, -.57145300E+01, 0.21303800E+01, -.36921900E+00, -.58799000E+01, -.74944000E+00, -.15531700E+01, -.81908200E+01, 0.43346900E+00, 0.23653800E+01, 0.32297700E+00, -.15676700E+00, 0.12439300E+00, -.10963300E+01, 0.32591000E+00, -.69276200E+00, -.17705200E+01, 0.49632700E+01, 0.24723100E+01, 0.55148100E+00, -.41493600E+00, 0.14897900E+01, -.37362200E+01, 0.77717500E+01, -.76273800E+01, -.79238800E+01 },
            { -.32553400E+01, 0.83912600E+00, 0.17972600E+01, -.56985300E+00, 0.15591100E+01, 0.39767300E+00, 0.94298500E+00, 0.47410800E+00, -.95522400E+00, 0.92882200E+00, 0.13122200E+01, 0.24047300E+01, -.38373600E+00, -.33985600E+00, 0.20765100E+00, -.32600500E+00, 0.88821600E+00, -.41999500E+00, -.58221400E+00, 0.21105200E+00, -.64767000E-01, 0.13966100E+01, -.13517700E+01, 0.45460900E+01, 0.38246300E+00, 0.22001500E+00, 0.36751000E+00, 0.88755800E+00, 0.22610900E+00, -.21701000E+00, 0.72100200E+00, 0.10861300E+00, -.67188200E-01, -.35311000E+00, -.23396200E+00, -.28888000E+01, 0.83189200E-02, 0.22527800E-02, -.11366400E-01, 0.81675100E+00, 0.22363600E+01, -.29592400E+00, -.67720300E+00, -.62131000E-01, 0.12342600E+01, -.22478400E+00, -.55993000E+00, -.18543900E+01, 0.14961200E+00, 0.16396900E+01, 0.43535300E+00, 0.23326200E+01, 0.74899900E+00, -.10071400E+01, 0.57984900E+00, 0.12007000E+00, 0.63632600E+00, -.99622100E-01, -.68373300E+00, 0.71649500E-01, -.50421000E+00, 0.43212500E+00, -.26992500E+00, -.11443800E+00, -.33907800E+00, -.66504700E-01, 0.13473700E+01, -.78868000E+00, -.13081500E+00, 0.55074800E+01, -.57595100E-01, 0.61983300E+00, 0.23250400E+00, 0.31267100E+00, -.51964700E-01, 0.11828200E+00, -.45067100E+00, -.28631600E+00, -.70504200E+00, -.11414700E+01, 0.13748500E+01, 0.16350800E+00, -.13050400E+01, 0.87452700E+00, 0.81101200E-01, 0.70953300E-01, 0.18062500E+01, -.94154100E+00, -.48423600E+00, -.94622100E-01, -.57533000E+00, 0.14800500E+00, 0.37184600E+00, 0.95749800E+00, 0.39633700E+00, 0.16804200E+01, 0.19224900E+01, 0.53100900E+00, 0.23819000E+00, -.43706500E+00, -.85960300E-01, 0.31240100E+00, -.24852200E+00, -.15759600E+01, 0.87195700E+00, 0.17360400E+01, 0.74877000E+00, -.43289100E-01, 0.25336400E+00, 0.45806600E+00, 0.89078600E+00, 0.46923500E+00, -.60849400E-01, 0.23983200E+01, -.25989600E+01, -.26972900E+00, -.20371200E+01, 0.49958000E+00, 0.31189900E+00, 0.56018600E-02, -.21887800E+00, -.47358700E+00, -.10115700E+00, -.11186100E-01, -.54489400E+00, 0.58062400E-01, 0.22367600E+00, 0.10907500E+00, -.23826600E+00, -.38493500E+00, -.52313800E-01, -.31082200E+00, -.12086600E+00, 0.15359300E+00, -.12880000E+00, 0.36131800E-01, -.35923600E-01, -.81563200E-01, 0.23523700E+00, -.70473100E+00, -.19816400E+00, 0.12168600E+00, 0.55429400E-01, 0.27988400E+00, -.17738400E-01, -.14939000E+00, -.42777900E+00, -.11720900E+01, -.25483500E+00, -.59497700E+00, 0.29888100E-02, 0.48256900E-01, 0.55940300E+00, 0.69968500E+00, 0.31014700E+00, 0.81600100E+00, -.42620300E+00, 0.19138900E+00, -.77790300E+00, 0.96042600E+00, -.13101000E+00, -.11323600E+00, -.60184300E+00, 0.43434300E+00, -.10417900E-01, -.65893900E+00, -.38845800E+00, 0.74999600E+00, 0.26230000E+00, 0.28655600E+00, -.10374500E+01, 0.30258800E+01, -.20514400E+00, 0.22592900E+00, -.22152400E+00, -.11916500E+01, -.21127300E+00, -.70555400E+00, 0.16694200E+00, -.43094900E+00, 0.13283000E+00, -.16389500E+00, -.30514500E+00, 0.19926600E+00, 0.14952000E+00, 0.60957300E+00, 0.29442900E+00, -.22306900E+00, -.88398700E-01, 0.54620100E-02, 0.71492700E+00, 0.25891500E+00, 0.21830800E+01, -.20364000E+00, 0.74257600E+00, -.20001100E+02, 0.32261000E+01, -.40712200E+01, 0.22536200E+02, -.93769100E+01, -.10426600E+02, 0.47208300E+01, 0.30629900E+01, -.16072800E+02, -.82703900E+01, -.17126900E+02, 0.22658400E+01, -.13584900E+03, 0.68433400E+02, 0.71715100E+02, 0.13024900E+02, 0.56832100E+01, 0.35154800E+02, -.11849400E+02, 0.22802300E+02, 0.23759700E+02, -.43832700E+02, 0.22171800E+02, 0.20916800E+02, 0.12619500E+00, 0.44018300E+01, 0.24088700E+02, 0.35287000E+02, 0.18407500E+02, -.40941000E+00, 0.18419800E+01, 0.72005200E+01, -.53222600E+01, 0.51364000E+00, 0.54205100E+01, 0.75199700E-01, 0.79465500E+01, 0.73399400E+01, -.81106500E+00, 0.34685500E+01, 0.26631900E+00, 0.16495700E+00, 0.37346000E+00, 0.28421800E+00, -.16355800E+01, -.11989200E+01, 0.31042700E+02, 0.13597900E+01, 0.26574100E+01, 0.11475900E+01, -.76657700E+00, -.18579100E+01, 0.63436800E+01, -.42804400E+01, -.92781900E+01, 0.86158900E+01 },
            { 0.10314200E+01, 0.27202000E+00, -.34478700E+00, -.38778800E+00, -.31510800E+01, -.45339800E+00, -.65202200E+00, 0.13563900E+00, 0.69605800E+00, -.52936400E+00, -.12694000E+00, -.31381100E+00, -.48062700E+00, -.21737500E+00, -.24561900E-01, 0.24801500E+00, -.77989400E+00, -.26631700E+00, 0.12758300E+01, -.30511600E+00, -.18847000E+01, 0.21738200E+00, -.11038800E-01, 0.18111900E+01, -.50855700E+00, -.32348600E+00, 0.27499300E-01, 0.19414300E+00, -.28074700E-01, 0.22419900E+00, 0.81423200E+00, 0.11633000E+00, -.18009000E+00, -.33466700E+00, -.18739300E+00, 0.15916000E+01, -.12215400E+00, 0.48100300E-01, 0.55072400E-01, 0.66886500E+00, 0.16801900E-01, 0.16877400E+00, -.43367000E+00, 0.36621400E+00, 0.11792200E+00, -.56823600E+00, 0.54895400E+00, -.14554000E+01, -.10316500E+01, 0.47487100E+00, 0.51962800E+00, 0.94071000E+00, -.54280000E+00, -.15171900E+00, 0.68755900E-01, -.25907800E+00, -.23762100E+01, 0.55115100E-01, 0.28689500E+00, -.57344100E+00, 0.18810500E+00, -.33429300E-01, -.11089100E+00, -.25328900E+00, 0.25612300E+00, -.22030500E+00, -.11136600E+01, -.26925700E+00, -.97876100E-03, 0.11886900E+00, -.78191800E-01, -.47796200E+00, 0.58817600E-01, 0.69579300E-02, 0.11181300E+00, 0.96786100E+00, -.14039300E+00, -.63990600E-01, 0.80623400E+00, 0.39578900E+00, 0.21031500E+00, 0.46676200E+00, 0.52708100E-01, 0.14534600E+00, 0.19238700E-01, -.31357000E+00, -.99040200E+00, -.80299800E+00, -.69524800E+00, -.10261600E+00, 0.64757700E-01, -.44818700E-01, -.12024400E+00, -.43686200E+00, -.68021800E+00, 0.10454500E+00, 0.32573300E+00, 0.12938600E+01, -.34266800E+00, -.16178300E+00, -.44490800E-02, -.10590600E+00, 0.88102200E+00, -.16373400E+00, 0.24475100E+00, 0.41344200E+00, 0.56909200E+00, -.10456300E+01, -.33528000E+01, -.26571400E+00, -.10205200E+00, -.27328600E+01, 0.14737400E+00, 0.24371400E+01, 0.28823100E+01, 0.19942300E+00, -.32866500E+01, 0.15153700E+00, -.96076900E-01, 0.38322000E+00, 0.62273300E-01, 0.22932600E+00, -.54533400E-01, 0.34740800E+00, 0.45025600E+00, 0.29288000E+00, 0.44213900E-01, -.10963400E+00, 0.10728200E+01, 0.14294200E+00, 0.60629400E-01, 0.40039400E+00, 0.19031300E+00, -.22883600E+00, 0.94533900E-01, -.59102900E+00, -.27615100E+00, -.30195700E+00, 0.51736400E+00, -.66847300E+00, -.28133000E+00, -.26955100E-02, 0.16760600E+00, -.53163500E-01, 0.11245300E+00, -.61398600E-01, -.28661100E+00, -.12260800E+01, -.58074700E-01, 0.31250400E-01, 0.10096900E+00, 0.20070400E-02, -.69858100E-01, 0.98915600E-01, -.14941900E+00, -.39902700E+00, -.45143500E+00, 0.39203600E+00, 0.78203700E+00, 0.11111600E+00, 0.30973300E+00, 0.13319200E+00, -.41677800E+00, -.82443200E-01, -.20139200E+00, 0.36526000E-01, -.34886500E+00, 0.47387600E+00, 0.62940700E+00, -.30903400E+00, -.16294500E+01, 0.13823900E+01, -.12591800E+00, 0.62731100E-01, -.51082900E-01, -.64439200E+00, -.42552300E+00, -.36324600E+00, -.55164000E-01, -.12557700E+00, 0.38780700E-01, 0.10143500E+00, -.44000100E+00, 0.70350200E-01, 0.75514800E-01, -.18166300E+00, 0.42792000E+00, -.40200400E+00, -.83368600E-01, 0.19601500E+00, 0.37134500E+00, 0.18599000E-01, 0.43516300E+00, -.26893900E+00, 0.52404300E+00, 0.31181900E+00, 0.96651900E+01, -.78707000E+01, 0.15884600E+02, -.64525500E+01, -.70018000E+01, 0.12819000E+02, 0.87724400E+01, -.15774800E+02, -.48331300E+01, -.20321700E+02, 0.30548100E+01, 0.52167600E+02, -.26224000E+02, -.26562100E+02, -.35866400E+01, 0.18255600E+01, -.15905100E+02, -.36424300E+01, -.18756900E+02, -.81703500E+01, -.39975400E+02, 0.19854200E+02, 0.19939700E+02, 0.12111600E+01, 0.38504000E+01, 0.14328200E+02, 0.20064800E+01, 0.52565100E+01, 0.63628000E+01, 0.21322000E+00, -.40191100E+01, 0.31437900E+00, -.33172100E+00, 0.36908200E+00, 0.12385500E+01, 0.71498600E+01, -.40807800E+01, 0.15747500E+01, 0.37499500E+01, 0.16722300E+00, -.18279900E+00, 0.87304300E-01, -.35565400E+01, 0.27150400E+01, -.12480700E+00, -.77260900E+01, 0.16928700E+01, 0.45999800E+01, 0.29277800E+00, -.11933600E+01, 0.35028000E+01, 0.32113500E+01, -.40807300E+01, -.94519700E+01, -.50929100E+00 },
            { -.39579400E+01, 0.66401900E+00, 0.31630900E+01, -.12973800E+01, -.11127500E+01, 0.41334300E-01, 0.23099000E+01, -.37975100E+00, -.24922800E+01, 0.80836000E+00, 0.32444000E+01, 0.76518100E+01, -.10416000E+01, -.18715300E+01, 0.13925900E+01, -.11345500E+01, 0.11195600E+01, -.56265500E-01, -.38449400E+01, -.87399300E+00, 0.13615200E+01, 0.15045500E+01, 0.18366900E+01, -.10988600E+01, 0.39624900E+00, 0.82927100E+00, -.84634900E+00, -.26532900E-02, -.75055000E+00, 0.14751400E+01, 0.79183100E+00, -.23529200E-01, 0.10247100E+01, -.15606400E+01, -.51395800E+00, -.16213600E+01, 0.17278300E+00, -.71277400E-01, -.12317900E+00, 0.39526400E+01, 0.35393100E+01, -.82974800E+00, -.16493700E+01, -.21523300E+01, 0.17796700E+01, 0.66324400E+00, -.78933500E+00, 0.41607300E+01, -.68953700E+01, 0.20875000E+01, 0.80500000E-01, 0.22706800E+01, 0.85230200E+00, -.49644400E+00, -.39688400E+00, -.39165600E+00, 0.13189100E+01, 0.60518800E+00, -.81497600E+00, 0.54730800E-01, -.22460800E+00, -.90003600E+00, 0.34130300E-01, -.21475500E-01, 0.30786700E+00, -.26332800E+00, 0.10259000E+01, -.12760400E+01, 0.20236700E+01, -.84537400E+01, -.10105200E+01, -.88898800E+00, 0.11499500E+01, -.97723300E-01, -.32278600E-01, -.21755400E+00, 0.13791700E+00, -.83899000E-01, 0.44400700E+00, -.10809700E+00, 0.79629900E+00, -.38655900E+00, -.13467800E+00, 0.67203400E+00, 0.36580600E+00, 0.19929200E+00, -.18292200E+01, 0.63588000E+00, -.58060000E+00, -.20939000E-01, 0.37375700E+00, -.27828600E-01, -.22291500E+00, -.78518800E+00, -.75691300E+00, -.93676200E+00, -.25007700E+01, 0.22508300E+00, -.53923800E+00, -.12039600E-01, 0.26317800E+00, 0.13390700E+00, 0.14596700E+01, 0.48018700E+00, -.94746800E+00, -.14531600E+01, 0.81589900E+00, -.91990200E+00, -.78248400E+01, -.90509400E+00, 0.60430700E+00, -.41082200E+01, -.26785900E-01, 0.14678800E+01, 0.10651700E+01, -.18014500E+00, -.10936000E+01, -.37056900E+00, -.26638000E+00, 0.35891900E+00, -.89433500E-01, -.13156000E+01, -.47564500E-01, -.22136800E+01, -.74491500E+00, -.28360200E+00, 0.85142700E-01, 0.36126700E+00, -.13287500E+00, 0.32022500E+00, -.14917400E-01, 0.87922800E-01, 0.48819700E-01, 0.24135300E+00, 0.59376600E+00, -.11241600E+00, -.81358800E-01, 0.71889700E+00, -.40443900E+00, 0.49288500E+00, 0.89348200E-01, 0.24699700E+00, -.21573100E+00, -.30724000E-01, -.14918500E-01, -.78082500E-01, 0.18375900E+00, 0.35020800E+01, 0.23869100E+00, -.13211200E+01, 0.64104200E-01, 0.32729100E-01, -.78730900E+00, -.12677900E+01, -.18292300E+00, 0.36232200E+00, 0.77614500E+00, 0.32162800E-01, -.17334100E+00, -.24030800E+01, -.81015100E+00, 0.45025700E+00, 0.13120900E+01, -.20720100E+00, -.21003600E+00, 0.41692200E-01, 0.24903300E+00, -.13199900E+01, -.48860200E+00, 0.70903600E+00, 0.31334800E+01, -.11203900E+00, 0.24955800E+00, 0.48168700E+00, 0.93811400E-01, -.31223700E+00, 0.10608500E+01, 0.54068400E+00, 0.25093700E-02, 0.52472800E+00, -.40257500E+00, -.14688200E+00, -.18373600E+00, 0.38951300E+00, 0.47543300E+00, 0.82935300E+00, 0.11905400E+00, 0.88481000E+00, 0.79490300E+00, -.81972300E-01, 0.10545800E+00, 0.33340900E+00, 0.61857400E+01, -.35928500E+00, 0.40772600E-01, 0.77473500E+00, -.16623700E+01, -.31345900E+02, 0.86566500E+02, -.40086200E+02, -.49404000E+02, 0.16194700E+02, 0.14792500E+02, -.39341800E+02, -.33283600E+02, -.78377000E+02, 0.70680300E+01, -.68408300E+01, 0.32347700E+01, -.84191000E-01, -.57358800E+01, -.93685700E+01, 0.49651100E+01, -.83374300E+01, -.50946700E+01, 0.31387800E+01, -.67196500E+02, 0.33478800E+02, 0.36698500E+02, 0.28513700E+02, 0.66171000E+01, 0.29480000E+02, 0.15862400E+02, 0.12048100E+02, 0.27262700E+02, 0.26871300E+01, 0.14675800E+02, -.62388200E+01, 0.10684100E+01, 0.59074100E+01, 0.11286200E+01, -.85807200E+01, 0.16888400E+02, -.37695000E+01, -.55146400E+01, 0.14761300E+01, 0.40291500E+00, 0.16409000E+01, 0.63986800E+01, -.11109200E+02, -.53313000E+00, -.74371700E+01, -.60204900E+01, -.50941300E+01, 0.40919600E+01, 0.22521600E+01, -.70027900E+01, 0.20590400E+02, -.26817500E+02, -.19691400E+01, 0.23198100E+02 },
            { 0.10789300E+01, 0.14789300E+00, -.39630700E+00, -.19661700E+00, -.83294800E+00, -.57280500E-01, -.42030700E+00, -.38964200E-01, 0.12111700E+01, -.71968700E-01, 0.40434800E+00, 0.35029100E+00, 0.88386000E-01, -.58412900E+00, 0.88799300E-01, 0.10405300E-01, -.86674400E-01, -.23667300E+00, 0.72478400E+00, -.81662600E-01, -.31358000E+00, -.90233500E+00, 0.27721600E+00, -.53124200E+00, -.75674800E-01, -.13246500E+00, 0.87968700E-01, 0.38279900E-01, 0.12908400E+00, 0.39067100E-01, 0.28918900E+00, 0.19585800E+00, -.83182900E+00, 0.20627000E+00, 0.19733300E+00, 0.76246000E+00, 0.98216100E-01, -.37887900E-01, -.63883500E-01, 0.30397000E+00, 0.35875100E+00, -.13962600E+00, -.10927700E+00, 0.17446400E+00, -.56145400E-01, -.90704300E+00, 0.27404800E+00, -.12539500E+01, 0.82564200E+00, -.17842600E+00, 0.26922900E-01, 0.19292900E-01, 0.17181600E+00, 0.81632700E-01, -.13839400E+00, -.38662700E+00, 0.66829000E+00, 0.29457300E-01, 0.11742700E+00, 0.17757400E-01, 0.71245900E+00, -.48188600E+00, 0.45780500E+00, 0.18735700E+00, 0.28402900E+00, -.82427800E+00, -.74480400E+00, -.20013200E+00, -.30544300E+00, 0.18875800E+01, 0.20911300E+00, 0.33554000E+00, -.26028900E-02, 0.31859000E-01, 0.34450100E-01, -.23919900E-01, 0.27630700E+00, -.10892400E+00, -.15142500E+00, 0.22440800E+00, -.29209200E+00, 0.22281200E+00, -.44632100E-01, -.15901300E+00, -.97924500E-01, -.42094100E-01, -.67117800E+00, -.39201900E-01, -.17961900E+01, -.39762100E-01, -.65006200E-01, 0.33088100E-02, 0.40314300E-01, 0.36814400E+00, 0.35711500E+00, -.22731000E+00, 0.45268300E-01, -.87349100E+00, 0.19733400E+00, 0.36692900E-01, -.68912600E-01, -.27380000E-01, -.66220300E+00, -.49495200E+00, 0.98154800E-01, -.23847600E+00, 0.51581600E-01, 0.15973400E+00, 0.26133100E+00, 0.20136200E-01, -.55563200E-01, -.22344300E+00, 0.50217800E-01, -.89353300E+00, -.10251200E+01, 0.29440400E-01, -.20936800E+01, -.33235400E+00, 0.18539200E+00, -.27118600E-01, -.19928600E+00, 0.44479200E-01, 0.25721700E+00, 0.93932500E+00, 0.20578400E+00, -.58496400E-03, -.60254800E-01, -.10944500E+00, 0.40666800E+00, 0.17692800E+00, -.54237200E-03, 0.36100700E+00, -.22306800E+00, 0.23713900E-01, 0.69827400E+00, 0.15494200E-01, 0.92320400E-01, -.52110200E-01, 0.11039500E+00, -.12037300E+00, 0.19003300E+00, 0.36015100E-02, 0.22599800E-01, -.21310300E+00, -.53966900E-01, 0.11017300E+00, 0.12452900E+00, -.16971100E+01, 0.59538100E-01, -.58349000E+00, 0.14752400E-01, -.15285300E+00, 0.80762600E-01, 0.26457600E+00, 0.32425300E-01, 0.21807500E+00, -.13934500E+00, 0.10119000E+00, 0.23021200E+00, -.37460600E+00, 0.64866400E+00, 0.14157300E+00, 0.11684300E+00, 0.96544800E-01, -.12221400E+00, 0.14516400E+00, -.52131500E+00, 0.45380800E+00, 0.28654000E+00, -.79034300E-01, -.14735100E+01, 0.15548900E+00, 0.29940700E-01, 0.10716000E+00, -.57959800E-01, -.32604800E+00, 0.84557700E-01, -.57517900E+00, 0.21309500E-01, -.16676400E+00, 0.53191800E-01, -.96055300E-01, 0.41700400E-01, 0.10772200E+00, -.40179200E-01, 0.87261200E-01, 0.24822800E+00, -.30484500E+00, -.15723000E+00, 0.26844100E+00, 0.48015100E-01, 0.16656800E+00, 0.14697700E+01, -.65571700E-01, 0.44501900E+00, 0.22287200E+00, 0.27803100E+00, 0.59117000E-01, -.39331300E+02, 0.17874500E+02, 0.19989900E+02, -.44136600E+01, -.71451700E+01, 0.18222200E+02, 0.51044400E+01, 0.29585600E+02, -.67790800E+00, 0.19228600E+02, -.96954700E+01, -.78917500E+01, 0.55650000E+01, -.17871700E+01, -.91249800E+01, 0.52186500E+01, -.24407300E+01, 0.25901900E+01, 0.50199600E+02, -.25281900E+02, -.25621100E+02, 0.12161700E+01, -.80202600E+01, -.21362800E+02, -.13408300E+02, -.16691000E+02, -.66012900E+01, -.13996900E+01, 0.39735700E+01, 0.14176700E+01, -.12873000E+00, 0.10484100E+01, -.45950400E+00, 0.32586200E+01, 0.34237900E+01, 0.14151100E+01, -.29650000E+01, -.61206100E+00, -.17052600E-01, -.57264600E+00, 0.85932400E+00, 0.77310500E-01, 0.66105200E+00, 0.13127300E+01, -.16275200E+01, -.29294900E+01, -.93301500E+00, 0.91315200E+00, -.21267000E+01, -.17863400E+01, 0.55286900E+01, -.19555800E+01, -.11986100E+00 },
            { 0.75963300E+01, -.32460700E+01, -.35067100E+01, 0.10227300E+01, -.68108400E+01, -.35967000E+00, -.38012300E+01, -.52246800E+00, 0.29962200E+00, -.17206700E+01, -.18101400E+00, -.25271700E+01, -.39213600E+01, 0.13342800E+01, -.41064300E+01, 0.18485700E+01, -.38144100E+01, -.17962400E+01, 0.84747600E+01, 0.17243900E+01, -.48363200E+01, 0.37852000E+01, -.30212500E+01, 0.58476200E+01, -.23609700E+01, -.11875900E+01, 0.10007700E+01, -.81316600E+00, -.12891500E+00, -.24309900E+01, -.43030400E+01, 0.19412800E+01, -.90924400E+00, 0.15204900E+01, 0.62538600E+00, -.90101100E+00, 0.13749800E+01, -.52688500E+00, -.84457400E+00, 0.13362200E+01, -.57436800E+01, -.85811900E+00, 0.19102700E+01, -.11547300E+00, -.31391900E+01, -.15247800E+01, 0.89415500E+00, -.81053600E+01, 0.79067900E+01, -.59200900E+01, 0.44354900E+01, -.94216100E+01, -.84939000E+00, 0.76699600E+00, 0.11133300E+01, -.45262000E+01, 0.80046500E+01, -.79588300E+00, -.20534600E+00, -.57238100E+00, 0.93947900E+00, -.16794000E+01, 0.21024000E+01, 0.99820900E+00, 0.26248200E+01, -.62739800E+01, -.95219300E+01, 0.11894500E+01, -.10703400E+01, -.15935100E+02, -.13168300E+00, -.11423200E+01, 0.42085100E+00, 0.11004800E+00, 0.82870300E+00, 0.85871000E+00, 0.16949900E+01, -.99519000E+00, -.26608800E+01, -.12405000E+01, 0.94049700E+00, 0.14231400E+01, -.92148700E+00, 0.81368600E+00, 0.43497100E-01, -.47241700E+00, -.43548700E+01, 0.12665100E+01, -.62084400E+01, -.35498500E-01, 0.44600500E+00, -.33787100E-01, 0.20405100E+00, -.28332700E+01, -.31148200E+00, -.28096000E+01, -.30609600E+01, -.37657400E+01, -.34918000E+00, 0.60285800E+00, 0.20273800E+00, 0.54936200E+00, 0.29214100E+00, 0.50473900E+01, -.17915400E+01, -.51087800E+01, -.34229500E+01, 0.30874700E+01, 0.13058700E+02, 0.21037200E+00, 0.10088500E+01, 0.32214700E+01, 0.19155400E+00, -.26726000E+01, -.46117400E+01, 0.33274600E+00, -.47784500E+01, 0.13408300E+01, 0.79572300E+00, -.71561000E+00, 0.27933300E+00, 0.29561900E+01, 0.70477400E+00, 0.37778500E+01, 0.26079400E+01, 0.79711700E+00, -.52153100E+00, -.62527900E+00, 0.75111700E+00, -.18194000E+01, -.54192200E-01, 0.76207800E+00, -.82787300E+00, -.27798200E+00, -.18431800E+01, -.84152400E+00, 0.35352700E+00, -.88923400E+00, 0.16719600E+00, -.22230800E+01, 0.38565000E+00, 0.18827500E+00, 0.45849100E+00, 0.67640700E-01, -.23193400E-01, -.42436000E-02, 0.83088400E-01, -.12549400E+02, -.66931700E+00, 0.41474400E+01, -.15064200E+00, -.65873500E+00, 0.14972400E+01, 0.13116900E+01, 0.67971300E+00, 0.55286600E+00, -.74361600E+00, 0.12071900E+01, 0.15522400E+01, 0.12038100E+01, 0.26341800E+01, -.21213600E+00, -.11689800E+01, 0.61873200E+00, -.92742700E+00, 0.11498400E+01, -.81931100E+00, -.52483300E+00, 0.27059900E+01, -.17551900E+01, -.33133500E+01, -.36230400E+01, 0.22895400E-01, -.19915000E+00, 0.25335000E+00, 0.69446400E+00, 0.48845500E+00, 0.47881900E+00, 0.50464100E+00, -.62796400E-01, 0.43850400E+00, -.57093500E+00, 0.66022900E+00, -.46226500E+00, 0.32173300E-01, -.17936300E+01, 0.88644800E+00, -.38894900E+00, -.12242600E+01, 0.32712400E+00, -.26575600E+01, 0.16776600E+01, -.27967300E+01, -.24972700E+00, 0.13903100E+01, -.15669000E+01, -.33337500E+01, 0.27833500E+00, 0.26130800E+01, 0.10324500E+02, -.17640100E+01, 0.41579300E+02, 0.16435400E+02, -.22733300E+02, 0.39627300E+01, -.71345100E+02, 0.67595300E+01, 0.10821300E+03, -.54777700E+02, -.64529800E+02, -.23244400E+02, 0.26168500E+02, -.39267200E+02, -.28048600E+02, -.29908300E+02, -.15986500E+02, -.11310200E+03, 0.56469000E+02, 0.56669300E+02, -.45217100E+02, -.13067100E+02, 0.74477200E+02, 0.10100800E+03, 0.83139600E+02, -.72596300E+01, -.15923800E+01, -.26828600E+02, 0.42330500E+01, -.24004200E+01, -.37599400E+02, 0.61585800E-01, 0.82601600E+01, -.24130400E+02, 0.69407000E+00, 0.98501500E+01, -.26592600E+00, -.11163800E+01, -.76850900E+00, -.13701300E+02, 0.13138100E+02, -.52635400E+01, 0.63125800E+01, 0.81628900E+01, 0.10594400E+02, -.79494300E+00, -.53604800E+01, 0.19482100E+02, -.75239800E+01, -.35263800E+01, -.17895200E+02, -.10048500E+02 },
            { -.39295900E+01, 0.10288000E+01, 0.30152600E+01, -.23585800E+00, 0.21535700E+01, 0.40017300E+00, 0.22241600E+01, -.73000700E+00, -.21272000E+01, 0.60135200E+00, 0.12827900E+01, 0.54982800E+01, -.54400000E+00, -.10544500E+01, 0.24751200E+00, -.65414400E+00, 0.99765900E+00, 0.59804700E+00, -.48788100E+01, 0.49430700E+00, 0.31506900E+01, 0.93898800E+00, 0.66213700E-03, -.29794000E+01, 0.17669200E+01, 0.41357300E+00, -.39140000E+00, 0.75579000E+00, -.78359200E+00, -.53548400E+00, 0.11284300E+01, 0.80408500E+00, 0.17479600E+00, -.62645200E-01, -.34225800E+00, 0.11945300E+01, -.10581600E+01, 0.40686500E+00, 0.77607700E+00, 0.15008600E+01, -.10544100E+01, 0.97984700E+00, 0.12441700E+00, 0.18063600E+01, 0.42115300E+00, -.11464500E+00, -.19556600E+01, 0.28490200E+01, -.57232100E+01, 0.20330400E+01, -.51006600E+00, 0.42024300E+01, 0.94287500E+00, -.16618100E+01, -.11724500E+00, 0.50291800E+00, 0.41145000E+01, 0.67310100E+00, -.12422200E+01, 0.31230600E+00, -.43536300E+00, -.64612500E+00, -.19701400E+00, -.36378000E+00, -.85012900E+00, 0.36177800E+01, 0.23855600E+01, -.90186100E+00, 0.41117700E+01, -.28508500E+02, 0.69666000E+00, -.27493600E+01, 0.24874500E+00, -.12108800E+01, 0.27322500E-01, 0.55350100E+00, 0.24235600E+00, 0.10857900E+01, 0.38509200E+01, 0.24935700E+01, -.40470000E+00, -.83561400E+00, 0.28268500E+01, 0.66849400E+00, -.76102300E-01, -.73345800E+00, 0.52231900E+01, 0.30888300E+01, 0.83302000E+01, 0.26650300E+00, -.64664700E+00, 0.45926300E+00, 0.35050600E+00, 0.10724600E+01, -.24331300E+00, 0.23038800E+01, 0.16295200E+01, 0.23227400E+01, 0.55056400E-01, -.91966700E+00, 0.70107700E+00, 0.29736700E+00, -.16004700E+00, -.39939500E+01, 0.13346700E+01, 0.29211000E+01, 0.28720800E+01, -.20503700E+01, -.89112900E+01, -.12376200E+01, 0.23541500E+01, 0.25254100E+01, -.15525200E+01, 0.37097000E+01, -.18969700E+01, 0.23316900E+00, -.95803500E+01, -.18493700E+00, -.94155200E+00, 0.49157900E+00, 0.10142800E+01, -.20553900E+01, -.40389300E+00, -.43552600E+01, -.20694400E+01, -.95752300E-01, -.65996400E+00, 0.13767600E+00, 0.56036500E+00, 0.54832400E+00, 0.15268700E+00, 0.60738000E+00, -.15479000E+01, -.76513000E+00, -.27476600E+01, -.32567200E+00, -.12574400E+00, -.41003500E+00, 0.33448600E+00, -.29715500E+01, -.16098600E+00, 0.47375700E+00, 0.34169100E+00, -.13941800E+01, 0.72522900E+00, 0.13072200E+00, -.44742600E+00, 0.96266200E+00, -.30308400E+00, 0.25322500E+01, 0.33077100E-02, -.56193600E+00, -.15743000E+01, 0.66632300E+00, 0.71100700E+00, -.15497600E+00, -.77281500E+00, 0.82213500E-01, -.10700500E+01, 0.10367600E+01, -.70130400E+00, -.47141900E+00, 0.12475400E+01, 0.53071900E+00, 0.47333800E+00, -.29789100E+00, 0.32595700E+00, -.24387200E+01, 0.13106300E+01, -.56479400E-01, 0.18376400E+01, 0.26257300E+01, 0.31441200E-01, 0.44966300E+00, 0.11131000E+00, -.12120000E+01, -.40174600E+00, 0.14048300E+01, 0.12396700E+00, 0.15410300E+00, -.14877700E+00, -.19632500E+00, 0.51659600E+00, 0.37899600E+00, -.98248000E-01, 0.12753200E+01, -.59382300E+00, -.27392800E+00, 0.15253200E-02, -.21497100E+00, 0.17355000E+01, -.73119800E+00, 0.45585300E+01, 0.39874600E+00, 0.33177100E+00, 0.66244900E+00, 0.20523700E+01, 0.31569300E-01, 0.11869000E+01, -.94336700E-01, 0.82134900E+01, -.61850900E+01, 0.98469700E+00, -.33930400E+01, 0.17259400E+02, -.72902100E+01, 0.11121300E+02, -.24981700E+03, 0.12578200E+03, 0.13854700E+03, 0.88095100E+01, -.62110000E+01, 0.65234700E+02, 0.49512600E+01, 0.51637100E+02, 0.32609100E+02, -.34233500E+02, 0.17815800E+02, 0.11829400E+02, 0.64267800E+01, 0.15644900E+02, 0.17537900E+02, 0.52091300E+02, 0.26578600E+02, 0.13458100E+02, 0.43627600E+01, 0.11790400E+02, -.86816200E+01, 0.18716500E+01, 0.10991000E+02, 0.17766800E+00, -.31711000E+01, 0.12891600E+02, -.50184400E+01, 0.11992800E+00, 0.50529100E+00, 0.78370900E+00, 0.91152600E+00, 0.52597800E+01, -.77518100E+01, 0.86017900E+00, 0.48228200E+02, -.18165100E+01, -.26042400E+01, 0.19073100E+01, 0.12978200E+01, -.10544300E+02, 0.76843500E+01, 0.89500300E+01, 0.57048100E+01, 0.17563900E+02 },
            { -.40179800E+01, -.18973200E+01, 0.90584800E+00, 0.98365300E+00, 0.40147400E+00, -.28935800E+00, 0.14304500E+01, -.56799600E+00, -.13367300E+01, 0.21335100E+01, 0.30447100E+01, 0.80761300E+01, -.12452900E+01, -.17699200E+01, 0.23501000E+01, -.10476600E+01, -.90810600E-01, 0.55880500E+00, -.18286300E+01, -.11481600E+00, 0.13877600E+01, -.17400900E+01, -.12450200E+01, -.24651900E+01, 0.74803200E+00, -.33441300E+00, -.97298700E-01, 0.10629600E+01, -.61491200E+00, 0.86180300E+00, 0.18603400E+01, 0.95022600E+00, 0.25128800E+00, -.61764900E+00, 0.29899200E-01, 0.70681800E+00, 0.14696400E+00, -.74453500E-01, -.59438500E-01, 0.57736500E+01, 0.59244100E+01, -.77467200E+00, -.12572600E+01, -.16438500E+01, 0.14677000E+01, 0.59474400E+00, 0.90328200E+00, 0.15141100E+01, -.66057100E+01, -.19119100E+00, -.19327700E+01, 0.28265600E+00, -.15611700E+01, 0.25462400E+00, 0.79883500E+00, -.14151200E+01, -.63406400E+01, 0.33103200E+00, 0.79024000E+00, -.14081400E+01, -.11900000E+01, -.10365400E+00, -.35013200E+00, 0.41582600E+00, -.41668700E-01, 0.13302000E+01, -.15346200E+01, -.45984200E+00, 0.31290800E+01, -.23634200E+02, 0.45217100E+00, -.22267500E+01, 0.41271700E-01, -.82020100E+00, 0.13467400E+00, -.88254000E+00, 0.24625000E-01, 0.56883700E+00, 0.27511900E+01, 0.19641600E+01, 0.11704900E+01, 0.90829300E-01, 0.17970600E+01, 0.92760400E+00, 0.57330900E+00, -.10350400E+01, -.26168900E+01, 0.75602200E+00, -.22240500E+01, -.28363200E+00, -.13190100E+00, 0.28429200E+00, 0.80524900E-01, -.18312900E+01, -.16817400E+01, 0.96347300E+00, 0.64437000E+00, 0.25753700E+01, -.11715300E+01, -.50299600E+00, 0.66753700E+00, 0.19565100E+00, 0.25016500E+01, 0.71247300E+00, 0.31969000E+00, 0.10947100E+01, 0.17871300E+01, -.56846500E+00, -.68717300E+01, -.13741900E+01, 0.77729600E+00, 0.65564900E+01, 0.26268800E+01, 0.58547700E+01, -.85239800E+00, -.44573500E+00, 0.40079000E+00, -.21345800E+01, -.18843300E+00, 0.29899500E+00, -.42552200E+00, -.13470700E+01, -.63803200E-01, -.92431200E+00, 0.46592800E+00, 0.17510700E+00, -.25560100E+00, -.28230100E-01, 0.53419900E+00, 0.52941000E+00, 0.10997300E+00, 0.78468900E+00, -.15805900E+01, -.14620600E+00, -.22856300E+01, -.64256600E+00, 0.13024800E-02, -.32861100E+00, -.11061100E+01, -.18053200E+01, 0.14439100E+01, 0.59334700E+00, 0.42644400E+00, -.93180000E+00, 0.83630900E+00, -.21330500E+00, -.58325000E-01, 0.15075700E+01, 0.40874300E+00, 0.21341300E+01, 0.10859800E+00, -.72870200E+00, -.23406200E+01, -.17785600E+01, 0.29023600E+00, -.14687700E+01, 0.16557100E+00, -.13544600E+00, -.33153900E-01, 0.11450100E+01, -.15667700E+00, -.60320500E+00, 0.65244000E+00, -.48705000E+00, -.27476700E+00, 0.83458300E-01, 0.59682500E-02, -.17689300E+01, 0.42123100E+00, 0.58010700E+00, 0.23842100E+01, 0.32072800E+01, 0.13536400E+00, 0.15293800E+00, -.20321400E+00, -.69922700E+00, -.59558100E-01, 0.35902500E+00, -.56063700E-01, -.13773500E+00, -.52019000E-01, -.64878100E-01, 0.74564700E-01, 0.28841300E+00, 0.15946400E+00, 0.77392500E+00, -.70196100E+00, 0.95326400E+00, 0.55978900E+00, 0.26415400E+00, -.90406300E+00, 0.10422600E+01, 0.13707000E+01, -.40603600E+00, 0.13216900E+01, -.15009300E+00, -.72639800E+00, 0.26001800E+00, 0.55409800E+00, 0.63429800E+00, 0.64937800E-01, -.16364600E+02, -.10934700E+02, 0.49803700E+01, -.12753400E+02, 0.41557400E+02, -.29748700E+01, -.13202800E+02, 0.62593600E+01, 0.10340400E+02, 0.86748400E+01, -.24909200E+02, 0.11579200E+02, 0.18445800E+02, 0.11583900E+02, -.80438100E+00, 0.39337200E+02, -.19786500E+02, -.17811700E+02, 0.30976100E+02, 0.15550200E+02, -.34689300E+02, -.59991900E+02, -.54276100E+02, 0.10176100E+02, 0.93343200E+00, 0.18376800E+02, -.37936200E+01, 0.13232800E+01, 0.28276000E+02, 0.82955200E+00, -.89044500E+01, 0.17502000E+02, -.41675900E+00, -.95442200E+01, 0.35307600E+00, 0.57769900E+00, 0.62061900E+00, 0.61104400E+01, -.55994100E+01, 0.28319900E+01, -.81854800E+01, -.44629200E+01, -.10602700E+02, 0.84082600E+00, 0.33348300E+01, -.14298300E+02, 0.41960400E+01, -.25223400E+01, 0.13827700E+02, 0.94318400E+01 },
            { -.14005300E+01, -.47225900E+00, 0.19264600E-01, 0.72147200E+00, 0.25305900E+01, 0.15865000E+00, 0.69998100E+00, -.26668900E+00, -.13020100E+01, 0.33309400E+00, -.16353600E-01, 0.76629700E-02, 0.51497800E+00, -.13611800E+00, 0.22942900E+00, -.36984200E+00, 0.98419100E+00, -.71254400E+00, 0.97451100E-01, 0.10832400E+00, 0.46544000E+00, 0.13690900E+00, -.17924000E+00, 0.13771800E+01, -.15898900E+00, -.85570600E-01, -.11928500E+00, 0.16882100E+00, -.40985300E-02, 0.32592100E-01, -.15185700E+00, 0.50719900E+00, -.42227000E-01, 0.21817200E-01, -.47640300E-01, -.48160900E+00, 0.64697000E+00, -.25180000E+00, -.39846800E+00, 0.14449700E+01, 0.25368000E+01, -.12713600E+01, -.12483700E+01, -.17800800E+01, 0.72066400E+00, -.12262500E+00, -.26322200E+00, -.15117600E+01, -.10731300E+01, 0.22795300E+00, 0.18170400E+01, -.89556200E+00, 0.16959200E+00, -.14398700E+00, -.22798500E+00, -.45871300E+00, 0.12676400E+01, -.77754000E-01, -.29267600E+00, 0.35946400E+00, 0.13905200E+00, -.46724100E+00, 0.47070100E+00, 0.21763800E+00, 0.48746700E+00, -.14164900E+01, -.72429800E+00, 0.55938300E+00, -.86624800E+00, 0.13946300E+01, -.18058000E+00, 0.87468800E+00, 0.61072400E+00, 0.22850500E+00, 0.19728600E+00, -.42979600E+00, -.51082900E-02, -.39544500E+00, -.77515900E+00, -.50493200E+00, 0.48437700E+00, -.76977500E-01, -.62173100E+00, 0.45674300E+00, 0.27303900E+00, 0.23607700E+00, -.27135300E+01, -.97885000E-01, -.27079700E+01, -.12451600E+00, 0.30404200E+00, -.84441000E-01, 0.26226400E-01, -.15295500E+01, -.72537200E+00, -.85372300E+00, -.17194300E+01, -.57081900E-01, -.47076500E+00, 0.13743100E+00, 0.45493700E-01, 0.27155600E+00, 0.10783900E+01, 0.20628900E+01, -.90928500E+00, -.17466700E+01, -.98671300E+00, 0.22322900E+00, -.26034800E+01, -.54932600E+00, 0.61556100E+00, -.22286200E+01, -.96388000E+00, 0.23039400E+01, 0.77052100E+00, 0.14128300E+00, 0.12247200E+01, 0.77919400E+00, 0.39260100E+00, -.36638800E+00, 0.37995200E+00, 0.89487200E+00, -.82414900E-01, 0.86878900E+00, 0.34252300E+00, 0.17179400E+00, 0.12947600E+00, 0.28863900E+00, -.36717800E+00, -.28393100E-01, -.21534900E+00, -.30534000E+00, 0.20406500E+00, 0.15549200E+01, 0.46004900E+00, 0.22248000E+00, 0.23922500E+00, 0.21061600E+00, -.47414000E+00, 0.11911800E+00, -.60713900E+00, 0.21514000E+00, -.87698700E-01, 0.35049500E+00, 0.39621100E-01, -.13504200E+00, -.24425800E+00, 0.12426300E+01, -.24580500E+00, 0.15688600E+01, 0.30885300E-01, 0.21446100E+00, 0.50809200E+00, -.80540100E-01, 0.56234500E-01, -.12071900E+00, 0.36419400E-01, 0.13062800E-01, -.37770200E+00, 0.27878900E+00, -.33918400E+00, -.14972100E+00, 0.39022800E+00, 0.41215000E-01, 0.43401000E-02, -.13305200E+00, 0.63639900E+00, -.67465900E-01, -.36972000E+00, 0.17771900E+00, 0.96751800E+00, -.12781600E+01, 0.31415100E-01, -.11241200E+00, -.35478900E-01, 0.56569800E+00, 0.20945300E+00, 0.92415600E-01, 0.29080300E-01, 0.22590700E-01, -.88360500E-02, -.24901300E-01, 0.13482800E+00, -.32668300E-01, -.40480900E-01, 0.35386600E+00, -.24916900E+00, 0.19608000E+00, 0.23331700E+00, -.40625300E+00, 0.28855100E+00, -.30092600E+00, 0.19279500E+01, -.18170500E+00, -.33223300E+00, 0.53020100E-01, 0.34846200E+00, 0.25363000E-01, 0.53187600E-01, -.33045500E-01, -.63169800E-01, -.35058400E-01, 0.77329600E+01, -.38350300E+01, -.18448700E+00, -.11286800E+02, 0.12111600E+02, -.33969200E+02, 0.17438100E+02, 0.18407500E+02, 0.11679300E+01, -.12341900E+02, 0.13678200E+02, 0.58791400E+00, -.14526300E+01, 0.25046300E+01, -.57218600E+02, 0.28852800E+02, 0.28512900E+02, -.59825600E+01, 0.10085400E+02, 0.25898900E+02, 0.32370200E+02, 0.28569400E+02, 0.13809800E+01, 0.44020900E+00, 0.64019900E+01, -.43700200E+01, 0.71262100E+00, 0.10250900E+02, -.51796100E-01, -.80617300E+01, 0.61831100E+01, -.13788100E+01, 0.24215200E+01, -.30036900E+00, 0.33035200E+00, -.10141100E+00, 0.22473700E+01, -.40724500E+01, 0.32498100E+01, 0.24569300E+02, -.39944900E+00, 0.13169800E+01, 0.36928000E+00, 0.15820700E+01, -.67984700E+01, 0.50688200E+01, 0.18264500E+00, 0.31555400E+01, 0.10616900E+02 },
            { -.62545100E+01, -.21696100E+01, 0.20168800E+01, 0.35717500E+00, 0.19622400E+01, 0.57304900E-01, 0.26298100E+01, -.26059400E+00, -.16068100E+01, 0.31383100E+01, 0.50735700E+01, 0.91042700E+01, -.22522700E+01, -.17544600E+01, 0.34380200E+01, -.16738700E+01, 0.43871900E+00, 0.12080100E+01, -.52790100E+01, 0.20941800E+00, 0.55099600E+01, -.86760800E+00, -.14568000E+01, -.49074300E+01, 0.16600000E+01, -.17520100E+00, -.68904800E+00, 0.68987600E+00, -.73854600E+00, 0.34618500E+00, 0.17196800E+01, 0.15437200E+01, -.26521000E+00, -.50471300E+00, 0.14116900E+00, -.85871800E+00, 0.10665900E+01, -.42371500E+00, -.60160300E+00, 0.51231300E+01, 0.11972000E+02, -.22628500E+01, -.24194000E+01, -.38862900E+01, 0.23907800E+01, 0.27961800E+00, -.28523000E-01, 0.20606300E+01, -.51064300E+01, 0.11701000E+00, -.31641500E+01, 0.78842400E+00, 0.17328200E+01, -.16104700E+01, 0.10002100E+01, -.17007700E+01, 0.20984700E+01, 0.62321100E-01, -.36137600E+00, 0.72407800E+00, -.11856600E+01, 0.71147500E+00, -.82958100E+00, -.28087900E-01, -.45939700E+00, 0.15344200E+01, -.45947100E+00, 0.16995700E+01, 0.25505000E+01, -.17367500E+02, -.12830900E+01, -.64747500E+00, 0.40621500E-01, -.18652300E+00, -.68009900E-01, -.10685200E+01, -.13556700E+00, -.19079100E+00, -.21242600E+00, -.54474000E+00, 0.10291400E+01, 0.10903900E+01, -.16691300E+01, -.73762300E-01, 0.67895400E+00, -.28428900E+00, 0.28973500E+01, 0.16152200E+01, 0.41338500E+01, 0.98859900E-02, -.55899700E+00, 0.45888600E+00, 0.41348800E+00, -.72433800E+00, -.16354200E+01, 0.24431500E+01, 0.30826000E+01, 0.34642800E+01, -.11221000E+01, -.92166100E+00, 0.80497500E+00, 0.57843900E+00, 0.11989800E+01, -.51865600E+01, 0.24517700E+01, 0.27694200E+01, -.25013700E+00, 0.36121400E+01, 0.57561800E+01, 0.25740000E+00, -.24034500E+00, 0.10394000E+02, 0.44085800E+01, 0.44316600E+01, -.22745100E+01, -.72201200E+00, -.13928500E+01, -.33181600E+01, -.55010700E+00, 0.46843900E+00, -.17345800E+01, -.72883300E+00, -.74076400E-01, 0.19188500E+01, 0.17610100E+01, 0.43013900E+00, -.14505100E+01, -.80678900E+00, 0.16764700E+01, 0.67265100E+00, 0.82735600E-01, 0.71607500E+00, -.13316100E+01, -.12543100E+01, -.20869300E+01, -.40541400E+00, -.68677600E+00, -.44669900E+00, -.15943300E+00, -.22775800E+01, 0.25825600E+01, 0.54641800E+00, 0.72031700E+00, -.10377000E+01, 0.11886900E+01, -.15962500E+00, -.87019500E+00, 0.26545900E+01, 0.10705300E+00, -.75316700E+00, 0.92683000E-01, -.36496000E+00, -.17704900E+01, -.13603400E+01, -.53247000E+00, -.24951300E+01, 0.33778200E+00, -.61025100E+00, 0.19543900E-01, 0.20439100E+01, -.78000000E+00, -.17550500E+00, 0.77358500E+00, -.63060700E+00, 0.53588000E+00, -.66985400E+00, -.33787500E+00, -.27876000E+00, -.67208400E+00, 0.24683100E+00, 0.10399600E+01, 0.10178400E+01, 0.15028000E+00, 0.10590700E+00, -.95538000E-01, -.82903200E+00, -.58664900E-01, -.11433600E+01, -.28577800E+00, -.32113200E+00, 0.13561900E+00, 0.24738300E+00, -.16741300E+00, 0.63137500E-01, 0.45697400E+00, 0.20012500E+00, 0.70955600E+00, 0.44995700E+00, -.96426400E-01, -.11282000E+00, -.24993600E+01, 0.10393800E+01, -.41921600E+01, -.32256700E+00, -.44139100E+00, -.16159600E+01, -.29599000E+01, 0.21676500E+00, 0.67408200E+00, -.13221100E+00, -.58019400E+00, -.14325100E+01, -.15815200E+01, -.20366100E+02, -.27585600E+02, 0.17900100E+02, 0.12661400E+02, 0.77483200E+02, -.39286300E+02, -.33953100E+02, 0.69680600E+01, -.58075300E+02, -.52696400E+01, 0.22353200E+02, -.84620900E+01, -.34901900E+02, -.20941900E+03, 0.10492700E+03, 0.10761100E+03, 0.28485900E+02, 0.59188900E+02, 0.57147800E+02, 0.37514900E+01, 0.14132600E+02, 0.38856600E+02, 0.46185800E+01, 0.22472900E+02, -.91323800E+01, 0.21080900E+01, 0.54346400E+02, 0.15694700E+01, -.81364100E+01, 0.22264600E+02, -.39443900E+01, -.68474400E+01, 0.11726200E+01, 0.81299700E+00, 0.15759600E+01, 0.35741400E+01, -.50017300E+01, 0.63967900E+01, 0.16833700E+02, -.13431400E+01, -.97320000E+01, 0.25309500E+01, 0.29245100E+01, -.23717600E+02, 0.10688700E+02, -.13504000E+02, 0.18744700E+02, 0.28307400E+02 },
            { -.51103700E+01, 0.47391300E+00, 0.32401200E+01, -.35706300E+00, 0.24583600E+01, 0.33824600E+00, 0.26407600E+01, -.43621900E+00, -.21271900E+01, 0.14101300E+01, 0.14752900E+01, 0.77492100E+01, -.45582700E-01, -.14072700E+01, 0.83688300E+00, -.10367100E+01, 0.55175400E+00, -.26256800E+00, -.47638300E+01, 0.75750400E-01, 0.61109800E+01, -.40366500E+00, -.27572000E+01, -.46515400E+01, 0.16727200E+01, 0.31867500E+00, -.22871100E+00, 0.62377400E+00, -.21246600E+00, 0.41322500E+00, 0.63592800E+00, 0.11333100E+00, 0.70799800E+00, 0.92417200E-01, 0.33141600E+00, 0.31682500E+00, -.13887300E+01, 0.52647800E+00, 0.90193300E+00, -.14635800E+01, -.37613300E+01, 0.13792000E+01, -.17731900E+00, 0.13956000E+01, 0.43082900E+00, 0.31371400E+00, -.21776500E+00, 0.67031300E+01, -.34822800E+01, 0.11889700E+01, -.25536000E+01, 0.32938900E+01, 0.14500900E+01, -.14612300E+01, -.27926600E+00, 0.90397400E-01, 0.61303400E+00, 0.17947500E+00, -.76398700E+00, 0.16408400E+01, -.20147000E+00, 0.36898700E+00, -.98587800E+00, -.15045900E+00, -.10221300E+01, 0.30381300E+01, 0.29521800E+01, 0.38084200E+00, 0.22112500E+01, -.10789300E+02, -.27287800E+00, 0.28038900E+01, 0.13473300E+00, -.91394100E+00, -.56421000E+00, 0.56173600E+00, 0.21372700E+00, 0.69692500E+00, 0.11146000E+00, 0.94083900E+00, -.33764500E+01, -.20803300E+01, 0.24754800E+01, -.13493600E+00, -.51535500E+00, 0.10062400E+00, 0.77154200E+01, 0.22891800E+01, 0.87921300E+01, 0.44342300E+00, -.69284000E+00, 0.27936000E+00, 0.18134300E+00, 0.12674700E+01, 0.11648600E+01, 0.19426000E+01, 0.27900800E+01, -.55839600E+00, 0.43683200E+00, -.99431000E-01, 0.70022600E-01, -.78514100E-01, -.89126800E+00, 0.37605700E+00, 0.10482500E+01, 0.19279900E+01, 0.33413600E-01, 0.27148500E+01, 0.79853400E+01, 0.11186800E+01, 0.99918600E+00, 0.42359900E+01, 0.47122300E+00, 0.15958300E+01, -.53679200E+01, -.62460400E+00, -.91745900E+00, -.28775900E+01, -.75235800E+00, 0.75254400E+00, -.62335700E+00, -.18045600E+01, 0.64180300E+00, -.33079300E+01, -.10111300E+01, -.24979700E+01, -.19850700E+01, -.78412700E-01, 0.43338200E+01, 0.32789300E+01, 0.75499700E+00, 0.39876200E+00, -.59849200E+00, 0.13131300E+01, 0.95444600E+00, -.12021400E+00, 0.42875700E+00, -.43034900E+00, 0.19528300E+00, -.51616500E+00, -.58733300E+00, 0.45798200E-01, 0.15200000E+00, -.52756700E+00, 0.23468800E+00, 0.12046300E-03, -.33432300E+00, -.58297700E+00, -.15001300E+00, 0.14499500E+01, 0.21226000E-01, -.16268800E+00, 0.33557100E-01, 0.35456200E+00, -.65448000E-02, -.89648000E+00, -.25737700E+00, 0.23345300E+00, 0.10706900E+01, 0.15775200E+01, -.82100400E+00, -.40191600E+00, 0.18406300E+00, 0.51149600E-01, 0.22491600E-01, 0.75996100E+00, -.15884400E+00, -.21186600E+01, 0.75617100E+00, 0.40900600E+00, 0.14040900E+01, 0.21964100E+01, 0.87112600E-01, -.14733500E+00, -.32964200E+00, 0.36051200E+00, 0.58574800E+00, -.26323100E+00, -.22358600E+00, -.31553900E-01, -.11904600E+00, 0.12819400E+00, 0.61702700E+00, -.10115700E+00, -.53590500E-01, -.44572700E+00, 0.29165800E+00, -.10874200E+00, 0.47638400E+00, -.25208500E-01, -.70488800E-01, -.15185900E+01, -.26371100E+01, 0.91956600E-01, -.69239300E+00, -.69517800E-01, 0.26259400E+01, -.12787500E+01, -.32455700E+01, -.20326900E+00, -.10689600E+01, 0.95216500E+00, -.14259500E+01, -.37762700E+00, 0.48969400E+02, -.30572500E+02, 0.36399200E+02, -.33876700E+03, 0.17093900E+03, 0.18992900E+03, 0.16966000E+02, -.19356500E+02, 0.84573200E+02, -.72291500E+01, 0.14576400E+02, 0.58909800E+02, -.21773400E+03, 0.10984300E+03, 0.98579200E+02, -.96452400E+01, 0.35922800E+02, 0.98057300E+02, 0.15208900E+03, 0.13419100E+03, 0.16038800E+02, 0.51999100E+01, 0.24887600E+02, -.17245000E+02, 0.27921200E+01, 0.29602100E+02, 0.14740300E+01, -.84443900E+01, 0.22867900E+02, -.53972100E+01, 0.28380500E+01, -.91656700E+00, 0.11938400E+01, -.13882000E+00, 0.69955700E+01, -.16660500E+02, 0.94880700E+01, 0.13749100E+03, -.28934500E+00, -.16143000E+01, 0.22231300E+01, 0.59562900E+01, -.26960200E+02, 0.16234200E+02, 0.22420600E+02, -.12890100E+02, 0.43009500E+02 },
            { -.16182300E+01, -.10837700E+01, 0.38730600E+00, 0.58360900E+00, 0.35309200E+01, 0.53071100E+00, 0.81471200E+00, -.20300300E+00, -.12809000E+01, 0.43320500E+00, 0.20054100E+00, 0.73048800E+00, 0.15847500E+00, -.16241200E+00, -.54099200E+00, -.78236000E-01, 0.23498500E+00, 0.63260900E-01, -.18927100E+01, -.89521500E-01, 0.12497400E+01, -.26574300E-02, -.10077500E+00, 0.10758900E+01, 0.31265600E+00, -.32766500E+00, -.74294400E+00, 0.63884800E+00, -.47991400E+00, 0.69872400E+00, -.15319200E+00, 0.56888500E-01, 0.18090400E-01, 0.38001900E+00, 0.21363000E+00, 0.17162400E+00, -.76408200E+00, 0.29443200E+00, 0.49002700E+00, -.11728000E+00, -.26909300E+01, 0.93274500E+00, 0.34921900E+00, 0.10869200E+01, -.13828700E+00, -.50317300E+00, -.11861600E+01, 0.16802100E+01, -.34200000E+01, 0.11262600E+01, -.36043600E+00, 0.30012000E+01, 0.14275600E+01, -.17234100E+01, -.67022800E-01, 0.35027800E-01, 0.30003900E+01, 0.29588100E+00, -.17513700E+01, 0.12581600E+01, -.27025700E+00, -.50084900E+00, 0.15257000E+00, 0.38657000E+00, -.64517900E-01, 0.48702500E+00, 0.11166400E+01, -.23205200E+00, 0.97129700E+00, -.19290600E+01, -.11008400E+00, -.35008500E+00, 0.28981000E+00, -.31450900E+00, -.23335800E+00, 0.14958900E+00, 0.55494400E-01, 0.22447600E+00, 0.50116300E+00, 0.91856400E-01, 0.20797900E+00, -.22199500E+00, 0.95474800E-01, -.46260700E-01, -.10926100E+00, 0.10347600E+00, 0.19319500E+01, 0.71341600E+00, 0.26447800E+01, 0.17661900E+00, -.20539100E-01, 0.35757400E-01, -.17867400E+00, 0.47388500E+00, 0.30720200E+00, -.39244600E-01, -.43110400E+00, -.46647000E+00, 0.68133200E-01, 0.15156100E-02, 0.57365000E-01, -.23460400E+00, 0.14991500E+00, 0.36542900E+00, -.40766800E+00, -.21761300E+00, 0.10029900E+00, 0.13110900E+00, 0.18812800E+01, 0.47036500E+00, 0.74640400E+00, 0.90264900E+00, 0.45981700E+00, -.39454600E+00, -.27698500E+01, -.42075200E+00, -.39130300E+01, -.11618600E+01, -.25084700E+00, 0.34686100E+00, -.47941200E+00, -.76930500E+00, -.20604400E-01, -.18225300E+01, 0.54302800E+00, -.11110000E+01, -.18918700E+01, 0.21426200E-01, 0.13104800E+01, 0.38414700E+00, 0.30013500E+00, 0.91985800E-01, 0.22523900E+00, -.90415100E+00, -.16553600E+01, -.32388700E+00, 0.41433200E+00, 0.84468900E-01, 0.23855900E+00, -.10823500E+01, 0.77165600E-01, 0.36461600E-01, 0.19781000E+00, -.38765000E+00, 0.19101900E+00, 0.37544000E-01, -.37919700E+00, 0.95665900E+00, 0.19107100E+00, -.23760200E+00, 0.12954700E+00, -.40196200E+00, -.10234200E+01, -.30484300E+00, -.20083500E+00, -.19779100E+00, 0.57878400E-01, -.53874800E-01, 0.17713400E+00, -.88281100E+00, -.63949700E+00, 0.15978000E+00, 0.14251100E+01, -.11283000E+00, 0.53870000E+00, 0.10996700E+00, 0.47869100E+00, -.17445100E+01, -.38073900E-01, 0.33523000E+00, 0.17222700E+01, 0.23438400E-01, 0.82398900E-01, 0.12432200E+00, 0.58993500E-01, 0.77790100E-02, 0.42606300E+00, 0.54797400E+00, -.50559600E-01, 0.25490000E+00, -.97714900E-01, 0.11396200E+00, 0.22689900E-01, 0.16493300E-01, 0.28914300E+00, -.95566600E-02, 0.28201700E+00, 0.49240100E+00, 0.20678200E+00, 0.34157700E-01, 0.97038200E-01, -.15706800E+00, 0.40389400E+00, -.15633900E-01, 0.66498700E-01, -.23276600E-01, -.15055300E+00, 0.13979100E+00, -.72595900E+00, 0.33660000E-01, 0.38032900E+00, -.18160600E+00, -.49394600E+00, 0.11173600E+00, 0.17728500E+00, 0.16261900E+02, -.63876500E+01, 0.10605400E+03, -.53387500E+02, -.57430600E+02, -.30172200E+01, 0.25974500E+01, -.27463700E+02, 0.61467800E+01, -.25857000E+02, -.10432000E+02, 0.92710000E+02, -.46784500E+02, -.43474600E+02, -.10373300E+01, -.17980900E+02, -.36529000E+02, -.38098400E+02, -.35115700E+02, -.12462900E+02, -.27652100E+01, -.23000800E+01, 0.39936600E+01, -.61595300E+00, -.89917600E+01, -.54757300E+00, -.33878700E+00, -.36394600E+01, 0.29290000E+01, -.15009000E+01, -.71902700E+00, -.18994400E+00, -.80874700E+00, 0.61895400E+00, 0.22248500E+01, -.30724400E+00, -.23144800E+02, 0.77183400E-01, -.25739600E+00, -.14164300E+01, 0.21009200E+00, 0.29050900E+01, -.44831100E+01, -.33600600E+00, -.15335700E+01, -.94246200E+01 },
            { 0.10342500E+02, -.10705000E+01, -.49550200E+01, -.86471500E+00, -.89427600E+01, -.72233100E+00, -.48558400E+01, 0.67068800E+00, 0.36901100E+01, -.33463500E+01, -.25812100E+01, -.10680900E+02, -.36149300E+00, 0.14085700E+01, -.66312400E+00, 0.14920000E+01, -.14228000E+01, 0.51711300E+00, 0.10808600E+02, -.21465100E+01, -.80830900E+01, -.70177100E+01, 0.20921300E+01, -.18170100E+01, -.20600600E+01, -.69394500E+00, 0.14427800E+01, -.13015200E+01, 0.14284700E+01, -.13971000E+01, 0.60750500E-01, -.44365700E+00, -.12052000E+01, -.15955500E+01, -.36351000E+00, 0.13013700E+01, 0.77570500E+00, -.28370600E+00, -.54028400E+00, 0.41633100E+01, 0.73154900E+01, -.56882500E+00, 0.20798100E+00, -.76705900E+00, 0.33521300E+00, -.16754300E+00, 0.19682100E+01, -.46166300E+01, 0.39580700E+01, -.10086200E+01, -.10100300E+01, -.26567000E+01, -.23475300E+01, 0.15854600E+01, -.15292200E-01, 0.22211100E+01, -.76685700E+01, -.39434300E+00, 0.14406200E+01, -.28747700E+01, -.12778400E+01, 0.17952000E+01, -.78291600E+00, -.70066900E+00, -.42004800E+00, 0.27352800E-01, -.58160200E+01, 0.35446800E+01, -.12648500E+01, 0.45155100E+01, -.22349600E-01, -.16183700E+01, -.31489000E+00, 0.36178100E+00, 0.26238000E+00, 0.78482300E+00, 0.26236800E+00, 0.83816900E+00, 0.23455100E+01, 0.12842900E+01, 0.20258000E+01, 0.29855800E+01, -.10955400E-01, 0.51144200E+00, -.83272700E+00, -.10659100E+01, -.53560800E+01, -.26632000E+01, -.77503600E+01, -.53718600E+00, -.59480800E-01, -.28281400E+00, -.19495000E+00, 0.16625800E+01, 0.29511700E-01, 0.49090400E+00, 0.12782700E+01, 0.18361300E+01, 0.40282100E+00, -.49212200E+00, -.62169400E+00, -.35431500E+00, -.30410700E+00, -.56830700E+01, 0.13299500E+01, 0.23457900E+01, 0.32134300E+01, -.51513300E+01, -.12041200E+02, -.60978500E+00, 0.87314800E+00, 0.33877400E+00, -.24987400E+01, 0.80366500E+01, 0.17568400E+01, 0.26067400E+00, -.10685200E+02, 0.41916600E+01, 0.74238500E-01, 0.50471600E+00, 0.77483800E+00, -.63217800E-01, -.12927900E+01, -.16925800E+01, -.25257300E+01, -.57020900E+00, -.26692500E+01, -.10445100E-01, 0.16484200E+01, -.18228900E+01, -.18371500E+00, 0.11991600E+00, -.33418300E+00, -.17900900E+01, -.25495500E+01, -.38231800E+00, -.17287000E+01, -.39135100E+00, 0.78087900E+00, -.18573600E+01, 0.29711800E+00, -.15949500E-02, -.47839800E-01, 0.27071600E+01, -.60517600E+00, 0.29574200E+00, 0.28487500E+00, -.83287200E+01, -.11759600E+01, -.49995200E+00, -.58474800E+00, 0.50750400E+00, 0.48911600E+01, 0.43764600E+01, 0.14987100E+01, 0.40434500E+01, -.12563200E+01, 0.17235900E+01, 0.58612000E+00, 0.28336000E+00, 0.11295500E+01, -.94938500E-01, -.33932600E+01, 0.13332100E+01, -.98908900E+00, -.37243500E+00, -.10155500E+01, 0.18503500E+01, 0.58401200E+00, -.12444700E+01, -.43001800E+01, 0.88486600E+00, -.11808500E+00, 0.25789600E+00, 0.22435500E+00, -.13449400E+01, -.30943000E+01, 0.11980300E+01, 0.66166000E-01, -.17415900E+00, -.14961900E+00, -.91023300E+00, -.83966900E+00, 0.51843700E+00, -.88102900E+00, 0.12203700E+01, -.16447800E+01, -.19435900E+01, -.20899300E+01, 0.21693100E-01, 0.19270800E+01, -.47206000E+00, -.20542400E+01, 0.92724700E+00, -.96479000E+00, -.68085500E-01, 0.62398600E+00, -.22940400E+00, -.61782600E+00, -.61522400E+00, -.38925000E+00, 0.14472300E+01, -.13690700E+01, -.57320800E-01, 0.25507900E+00, -.40618200E+01, -.41077800E+02, 0.40260700E+03, -.20215100E+03, -.22079300E+03, -.12168700E+02, 0.85131400E+02, -.13556400E+03, -.36093600E+02, -.10625400E+03, -.21547700E+02, 0.24064300E+03, -.12167700E+03, -.11594800E+03, -.67363900E+02, -.11068700E+03, -.52472300E+02, -.19304400E+02, -.12332200E+02, -.77634300E+02, -.90947100E+01, -.44005600E+02, 0.24379800E+02, -.51236800E+01, -.89473700E+02, -.58987100E+01, 0.33759600E+02, -.46965100E+02, 0.60145300E+01, 0.14774400E+02, -.78252900E+00, -.20559400E+01, -.17457800E+01, -.51304600E+01, 0.19422600E+02, -.12521600E+02, -.73127900E+02, 0.93912300E+01, 0.23772600E+02, -.33507600E+01, -.10302400E+02, 0.47509900E+02, -.26955300E+02, -.12090100E+02, -.46301200E+02, -.52413200E+02 },
            { 0.37147800E+01, 0.40314700E+00, -.25617500E+01, 0.84265400E+00, 0.31805100E-01, -.24649400E+00, -.15564700E+01, 0.19857800E+00, 0.13459000E+01, -.21772000E+00, 0.72801700E+00, -.20302500E+01, 0.19678500E+01, -.79159400E+00, -.16390200E+00, 0.40923900E+00, -.12800700E+00, -.13082800E+01, 0.35284400E+01, 0.10416200E+01, -.12990800E+01, -.26011400E+01, -.20950100E+01, -.11892800E+01, -.20521200E+00, -.82930000E+00, 0.38511900E+00, -.16816800E+00, 0.76252200E+00, -.27242200E+00, 0.71356500E+00, -.19561900E+00, 0.16743500E+00, 0.18903300E+01, 0.66431900E+00, 0.56917900E+01, -.63961700E+00, 0.23742400E+00, 0.43000300E+00, -.29616100E+01, -.57775200E+01, 0.10435100E+01, 0.13480500E+01, 0.27694500E+01, -.16811800E+01, -.25719800E+00, 0.78255600E+00, -.76772800E+00, 0.37149600E+01, -.18638400E+01, -.15872200E+00, -.17379900E+01, -.21926700E+01, 0.37916000E+00, 0.67533300E+00, -.13512500E+01, -.54828400E+00, -.45478500E+00, 0.11811800E+01, -.38106300E+00, -.79942500E+00, 0.69277500E+00, 0.26325700E+00, -.86818600E-01, 0.48773700E-01, 0.26691200E+00, -.22796000E+00, 0.17231800E+00, -.25624400E+00, -.31857900E+00, -.24420100E-01, 0.65586600E+00, 0.22458700E+00, 0.24714100E-01, 0.22747500E+00, 0.49349300E+00, -.15847600E+00, -.44026400E+00, 0.97550200E+00, 0.37838600E+00, -.49498200E+00, 0.59509600E+00, -.65160700E-01, 0.60753400E+00, -.34096200E-01, -.58184600E+00, 0.14726300E+01, -.38770000E+00, 0.18296400E+01, 0.17974000E+00, 0.87973000E-01, 0.18093500E-01, 0.68141200E-01, -.27866700E+00, 0.11380900E+00, -.65024800E+00, -.31401800E+00, -.10633200E+01, 0.10658200E+00, 0.19954400E+00, 0.77673100E-01, 0.99162300E-01, -.47328200E+00, 0.21991100E+01, -.62285700E+00, -.10515700E+01, -.14497000E+01, 0.67339500E+00, 0.46538300E+01, 0.37602200E+00, 0.53042600E-01, 0.94236800E+00, -.25934800E+00, -.17224500E+01, -.46874700E+00, 0.29063100E+00, -.44121500E+00, -.90790600E-01, 0.14899100E+00, -.15763400E+00, 0.40945300E+00, 0.89034700E+00, 0.35260200E+00, 0.80793200E+00, 0.54302700E+00, -.42266300E+00, -.68495800E+00, -.11897200E+00, -.89841400E+00, 0.37841100E+00, -.76340900E-01, -.25965700E-02, 0.38709400E+00, -.32136200E+00, 0.80836000E+00, 0.58983500E+00, 0.46501700E+00, 0.42756100E+00, -.42557700E+00, 0.63717100E+00, -.26477200E+00, 0.18068900E+00, -.24035700E+00, 0.31480000E+00, -.24123900E+00, 0.13204100E+00, 0.78368200E-01, 0.11940700E+01, 0.14972100E+00, 0.75892200E-02, 0.30262600E+00, 0.65630300E-02, 0.83601200E+00, 0.64395700E+00, 0.27629400E+00, 0.82180500E+00, -.45385700E+00, -.13627600E+00, -.11368400E+01, -.23733000E+00, 0.11422200E+00, -.16692200E+00, 0.54097700E+00, 0.27790600E+00, 0.25343000E+00, -.47113400E+00, -.92446000E-01, 0.10805500E+01, -.21597700E+00, -.23733100E+00, -.82912300E+00, 0.31306400E+00, -.13091100E+00, -.38898500E+00, -.10895000E+00, 0.54552800E+00, 0.75022900E-01, -.15775500E-01, 0.15762200E+00, -.20462400E+00, 0.12189600E+00, 0.49268000E-01, 0.40903400E+00, -.15852100E+00, -.79535100E-01, -.29938100E+00, 0.46111500E-01, -.61795000E-01, 0.20084200E+00, -.55394000E-01, -.15308400E+00, -.41677400E+00, -.15769100E+01, 0.47424600E-01, -.32570300E+00, 0.13291900E+00, 0.56185300E+00, -.51105000E+00, -.11377900E+01, -.18871900E-01, 0.14154500E+00, 0.31212700E+00, -.29537000E+00, -.37303700E+00, -.10158000E+00, -.38981200E+00, -.24977800E+00, 0.16321200E+03, -.82032500E+02, -.87151200E+02, -.15376700E+01, 0.63775100E+01, -.47893000E+02, -.96607200E+01, -.60262800E+02, -.10901800E+02, -.17762300E+02, 0.84643500E+01, 0.15281500E+02, -.18690300E+02, -.18189600E+02, 0.12302400E+02, 0.12695000E+02, 0.25878900E+02, -.19204100E+02, -.28803300E+01, -.35754900E+01, 0.43581400E+01, -.10212500E+01, -.97281100E+01, -.76144900E+00, 0.34693200E+01, -.62392300E+01, 0.22866900E+01, 0.47330100E+00, -.80392600E+00, -.37744000E+00, -.92508400E+00, 0.67335800E+00, 0.10824800E+01, 0.21049600E+01, 0.43898700E+00, 0.17528000E+01, 0.29564600E+01, -.95173000E+00, 0.40801300E+00, 0.29975900E+01, -.44629800E+01, -.18363500E+01, -.15275500E+02, -.48879500E+01 },
            { 0.23782100E+01, 0.29562900E+00, -.61419900E+00, -.46266500E+00, 0.92506100E+00, 0.42990200E+00, -.62208500E+00, 0.34785300E+00, 0.45045200E+00, -.69918700E-01, 0.93460000E+00, -.27847200E+01, -.13250600E+01, 0.29020200E+00, -.65949800E-01, 0.96685900E-01, 0.60731400E+00, 0.14556100E+01, 0.31428200E+00, -.23944300E+00, 0.76422500E-01, -.17147900E-01, 0.93831600E+00, 0.19073700E+01, -.36874800E+00, 0.65465600E+00, -.10676300E-01, -.31802500E+00, 0.40194100E+00, -.13761500E+00, 0.38310000E+00, 0.67033000E+00, -.73988800E+00, -.28127200E+00, 0.47996800E-01, -.14470000E+01, 0.60407400E+00, -.23065000E+00, -.36583900E+00, 0.26459600E+01, 0.31937700E+01, -.85231500E+00, -.38962700E+00, -.11654800E+01, 0.47105400E+00, -.27497900E+00, -.90843200E+00, 0.42933000E+00, -.12192700E+01, 0.89183000E+00, -.22517200E+00, 0.12382400E+01, 0.16260700E+01, -.70361000E+00, -.23016400E+00, 0.41915400E+00, 0.28273500E+01, 0.12867500E+00, -.68100400E+00, 0.79472400E+00, -.91284400E-01, 0.13442900E+00, -.37394800E+00, -.26055400E+00, -.56322500E+00, 0.73089100E+00, 0.59282100E+00, 0.41921800E+00, 0.13377900E+01, -.73584300E+01, -.69599700E+00, -.44816500E+00, 0.35616500E+00, 0.10400300E+00, -.18811200E+00, 0.69040600E-01, -.57421900E-01, -.27643700E+00, -.43305300E+00, -.47526100E+00, 0.11707600E+00, 0.56474000E+00, -.10850600E+01, -.48739000E+00, 0.19348300E+00, -.17902900E+00, 0.48855300E+01, -.78097100E+00, 0.61972900E+01, 0.31371300E+00, -.10533000E+00, 0.91450600E-01, -.12467700E+00, 0.19408600E+01, 0.11460100E+01, 0.54296000E+00, 0.55253200E+00, 0.69341200E-01, 0.77949100E+00, 0.19489800E-01, 0.96755200E-01, -.34990000E+00, -.17706600E+01, -.32514100E+01, 0.66114200E+00, 0.14172400E+01, 0.49706000E+00, -.35065700E+00, -.10826700E+01, 0.18649600E+00, -.87838300E+00, -.16441500E+00, -.37049700E+00, -.20604700E+01, 0.38211200E+01, 0.26517800E+00, 0.45454500E+01, 0.38355000E+00, -.78736100E+00, 0.29060700E+00, 0.21877500E+00, -.15769700E+01, -.12039300E+00, -.85326700E+00, -.16475700E+00, -.19084400E+00, -.52203800E-02, -.53082400E-01, -.10650900E+00, 0.10624200E-01, -.22072000E-01, -.37305200E+00, 0.23020600E+00, -.56823100E-01, 0.48447500E-01, 0.22582700E+00, -.39687500E+00, 0.72906600E+00, -.24285800E+00, 0.59767900E+00, 0.17327300E+00, 0.16293300E+00, -.20076500E+00, 0.60103300E+00, 0.20736700E-01, 0.56793300E-02, -.21382400E+00, 0.16615000E+01, -.30892600E+00, -.87332000E+00, -.10866300E+00, 0.32137700E-01, 0.98490100E-01, -.14149100E+00, -.31109500E-02, 0.35111700E-01, 0.22776400E+00, -.11357100E+00, -.55129100E+00, -.38944300E+00, 0.35321300E+00, -.17190900E+00, 0.51562600E-01, 0.15198500E+00, -.29422400E+00, -.13112900E+00, -.74593300E-01, 0.55177500E+00, 0.26858700E+00, -.32668700E+00, -.10455700E+01, -.22266200E+00, -.32198100E-01, 0.33984700E+00, 0.10450200E+00, -.51216900E+00, -.19987000E+00, 0.69485500E+00, 0.32114000E+00, 0.47715700E-01, 0.13949600E-01, -.30390800E+00, 0.18948400E+00, 0.20419700E+00, -.93183800E-01, 0.38728900E+00, -.19562300E+00, -.31740500E+00, -.77503100E-01, -.30841300E-01, 0.98595600E-01, 0.23657500E+00, 0.17230200E+00, 0.10244200E+00, 0.16626900E+00, -.15399000E+00, -.30912400E+00, 0.14179600E+00, 0.10688800E+01, 0.63204200E-01, -.24765000E-01, -.98213200E-01, 0.20163800E+00, 0.70460400E-01, -.70815700E-01, -.89973800E-01, 0.37538800E-01, -.40651700E+00, 0.29879200E+01, -.95172000E+00, 0.11036100E+01, 0.31873900E+00, -.22287500E+01, -.13792300E+01, -.16910900E+01, -.72478400E-01, -.50718500E+01, 0.26506100E+01, 0.40880300E+01, -.27719100E+01, -.61426800E+00, 0.14897300E+01, 0.51300600E+01, 0.41688100E+01, -.16333300E+01, 0.61809200E-01, 0.13488900E+00, 0.27096300E+00, -.23487000E-01, -.26378600E+00, 0.22664100E-01, 0.23954400E+01, 0.18823500E-01, -.16085200E+00, -.11047600E+01, 0.64128600E-01, -.17569000E-01, 0.46738000E-01, 0.68365600E+00, -.31795500E+00, 0.40591500E+00, 0.33015900E+01, -.15599400E+00, -.27204000E+00, 0.72194800E-01, 0.19615600E+00, 0.22133500E+00, -.31605800E+00, 0.23648000E+00, -.18391200E+01, -.37001400E+00 },
            { -.11280300E+01, 0.17086200E-01, 0.35195100E+00, 0.77732800E+00, 0.24006200E+01, 0.17143600E+00, 0.24849400E+00, -.35902200E+00, -.35501600E+00, 0.48650400E+00, 0.29362500E+00, 0.30638800E+00, -.29954400E+00, 0.16703500E+00, -.56620400E+00, -.19391000E+00, 0.97691000E+00, 0.23239800E+00, -.34949100E+00, -.66186400E-01, 0.61167900E+00, 0.25412100E+00, 0.42800300E+00, -.13153400E+01, 0.14569900E+00, 0.28754100E+00, -.34024400E+00, -.39844600E+00, 0.94520900E-01, -.18262500E+00, 0.36604200E+00, -.13327600E+00, 0.62445700E+00, 0.36842100E+00, 0.84587900E-02, -.10885000E+01, -.49038700E+00, 0.19327300E+00, 0.31104400E+00, -.19686000E+01, -.11972300E+01, 0.71148200E+00, 0.52932700E+00, 0.76074400E+00, -.12737900E+00, 0.10825900E+01, -.47918800E+00, 0.21157300E+01, 0.10615000E+00, 0.33208400E+00, -.16048900E+01, 0.13309300E-01, -.12205800E-01, -.93145500E-02, 0.43500700E+00, 0.38101400E+00, -.13720000E+00, -.29251200E-01, -.24632400E-01, -.11602800E-02, 0.11118600E+00, 0.47882400E+00, -.27446600E+00, 0.36831500E-01, -.44050100E-01, 0.59079800E+00, 0.50195200E+00, 0.42745500E-01, 0.21969800E+00, -.34669600E+01, 0.19594100E+00, 0.63106000E+00, 0.45800000E-01, -.24402700E+00, -.49972200E-01, 0.79047800E-01, -.12744000E+00, 0.25134800E+00, 0.42049200E+00, 0.62075500E+00, -.65386300E+00, -.40563200E+00, 0.67620200E+00, -.17963000E+00, 0.55663000E-01, -.18041600E+00, 0.10284000E+01, -.68331700E-01, 0.73638500E+00, 0.56872400E-01, -.14223100E+00, 0.82819900E-01, 0.27244100E-01, 0.31720400E+00, 0.24725100E+00, 0.18086400E+00, 0.10453000E+01, -.59295500E+00, 0.16807500E+00, 0.10679500E+00, 0.52654500E-01, -.12520000E+00, -.48398500E+00, 0.35323900E+00, 0.18173800E+00, 0.86798200E+00, 0.59534300E+00, -.62403000E+00, -.15575300E+01, -.27214200E+00, -.88940500E+00, -.73709700E+00, 0.66985700E-01, -.41739100E+01, -.32755800E+00, 0.31452300E-01, 0.12103100E+01, -.32042700E+00, -.43607400E+00, 0.21753600E+00, -.31631100E-01, -.22108800E+00, 0.30202900E+00, -.34388700E+00, -.56961800E+00, 0.12003900E+00, 0.81755900E+00, -.23403700E+00, -.63878600E+00, 0.18202900E+00, 0.11427500E+00, 0.41950500E+00, -.29101600E+00, -.58662700E+00, 0.11423400E+00, -.18946200E+00, -.73993300E-01, 0.14744800E-01, -.28870000E-01, 0.32925100E+00, -.26705000E+00, -.31576300E-01, -.33047100E-01, -.49497400E+00, -.67948100E-02, 0.52860800E-01, 0.92102600E-01, -.21868000E-01, 0.11529600E+00, 0.56982900E+00, 0.50145200E-01, -.17879500E+00, -.42404100E+00, -.18888000E+00, 0.50730100E-01, 0.52607800E-01, 0.21749600E-01, -.24747300E+00, -.50547000E+00, -.46524200E+00, 0.95646100E+00, 0.14976600E+00, -.18525800E+00, -.41175400E-01, -.26352600E+00, 0.14144100E+00, -.29657500E+00, 0.39946100E+00, 0.42717800E+00, -.22922100E+00, -.10093200E+01, -.12693600E+01, 0.97295000E-01, 0.19224400E+00, -.14229600E-01, 0.38759800E-01, 0.62798700E-01, 0.89420900E-01, 0.15564400E+00, -.52760200E-01, 0.27597700E-01, -.13084300E+00, 0.16654800E+00, 0.57933400E-01, -.98749900E-01, 0.42139100E+00, 0.69228000E-01, -.54239500E+00, -.63844400E+00, 0.26404400E+00, -.44410400E+00, 0.20529200E+00, -.46108400E+00, -.88837400E-01, 0.34472800E+00, -.11249400E+00, 0.21108400E+00, -.19009700E-02, 0.89901700E+00, 0.39419400E-01, -.65835400E-01, -.49578800E-01, -.36590400E+00, -.16153200E-01, 0.13229400E+00, 0.49126900E+00, 0.68558700E-02, -.41524500E+00, -.16206800E-01, -.20048900E+01, 0.22664600E+01, -.55161000E+01, 0.42890100E+01, -.39518600E+01, 0.10648200E+02, -.83042300E+01, -.16854100E+02, 0.84998800E+01, 0.11401100E+02, -.17866300E+01, 0.48663200E+01, 0.29886900E+01, 0.14628300E+01, -.32995500E+01, 0.23022600E+00, -.67502400E+00, 0.29290100E+00, 0.17335900E+00, 0.54788700E-02, 0.21330000E+01, -.58033400E+00, 0.14572200E+01, 0.84610500E+00, 0.12328500E+00, 0.18778600E+00, -.62724300E-01, 0.11125500E-01, -.64694500E-01, -.50865900E+00, 0.70216800E+00, 0.50489300E+00, -.23115600E+01, 0.71303000E+00, 0.64410100E+00, 0.96872800E-01, -.15893500E+00, 0.20512700E+01, 0.17728300E+00, 0.15741500E+01, 0.46039900E+01, -.27674200E+01 },
            { -.15963600E+01, -.77601600E+00, 0.37289700E+00, 0.65481200E+00, 0.43405200E+01, 0.68376800E+00, 0.82099500E+00, -.24284600E+00, -.12979800E+01, 0.60895800E+00, 0.48844100E+00, 0.11378400E+01, 0.41999400E+00, 0.24752700E+00, -.29521600E+00, -.19313300E+00, 0.57861100E+00, -.10981600E+00, -.12056200E+01, 0.38941000E+00, 0.47490800E+00, 0.83033800E+00, -.23755500E+00, -.38800400E+00, 0.25865500E+00, -.26688200E+00, -.51373800E+00, 0.84534500E-01, -.15975400E+00, 0.66210500E+00, -.52049100E+00, -.32992200E+00, 0.38299400E+00, 0.16704100E+00, -.16765700E+00, -.13252400E+01, -.53243400E+00, 0.20794800E+00, 0.33278600E+00, -.26610600E+01, -.96182800E+00, 0.62649700E+00, 0.23282900E+00, 0.88844700E+00, 0.54559800E-01, 0.82794500E-02, -.61699900E+00, 0.30018900E+01, -.22326300E+00, 0.85922500E-01, -.66628200E+00, -.98899600E-01, 0.76122100E+00, -.57071800E+00, -.54037500E+00, 0.48882900E+00, 0.37801200E+01, 0.61995300E-01, -.72198000E+00, 0.52669500E+00, -.62107900E+00, 0.17723100E+00, -.43233400E+00, -.23612600E+00, -.26491000E+00, 0.10361000E+01, 0.13281800E+01, 0.87497300E+00, 0.70751300E+00, -.46634600E+01, -.54425800E+00, 0.28092200E+00, 0.53173600E+00, -.26286500E+00, -.27196400E+00, 0.60494900E-01, 0.15273500E+00, 0.58121800E+00, 0.19442400E+00, 0.22255100E+00, 0.29075800E+00, 0.87759200E-02, 0.23552000E+00, -.45759600E+00, -.89709400E-01, 0.19979200E+00, -.63302000E-01, 0.48081600E+00, 0.86642900E+00, -.10036800E+00, -.14286500E+00, 0.19234000E-01, -.14650500E+00, 0.26300200E+00, -.50213200E+00, 0.11449700E+01, 0.10351900E+01, 0.23497600E+01, -.23536200E+00, -.43011900E+00, 0.20736800E-01, -.15545200E+00, 0.79252400E+00, -.20064100E+01, 0.83904300E+00, 0.16496000E+01, 0.15400100E+01, -.14287400E+01, -.15652700E+01, 0.10818600E+00, -.57496900E+00, 0.34048400E+01, 0.15549000E+00, 0.11165600E+00, -.10371000E+01, -.22051900E+00, 0.24358400E+00, 0.39198200E+00, -.68439500E-01, 0.32186100E+00, -.63807000E-01, -.72796000E+00, -.20421400E+00, -.18797200E+01, 0.10348000E+00, -.60720300E+00, 0.39936500E-01, 0.26958500E+00, -.45968400E-01, 0.13434900E-01, 0.11189000E+00, -.53061800E+00, 0.89828400E+00, -.24950500E+00, 0.26459500E+00, 0.10566700E+00, 0.61902700E-01, 0.10640000E+00, 0.47092500E+00, -.52335400E+00, -.53614800E+00, -.13832300E+00, 0.50565000E-01, 0.28326800E+00, -.22403700E-01, 0.59877200E-01, -.36780100E+00, 0.17862200E+01, 0.66313200E-01, -.82033300E+00, 0.19273100E+00, -.11285900E+00, -.51598900E+00, 0.39359800E+00, -.63589200E-01, 0.48182400E+00, -.35105100E+00, -.28510700E+00, -.13753900E+01, -.75680800E+00, 0.57128700E+00, 0.10630600E+00, 0.13559100E+00, 0.13770100E+00, -.56675100E-01, -.60545200E+00, -.27828000E+00, 0.12798300E+01, 0.41585000E+00, -.11889400E+00, -.15900200E+01, -.28456900E+00, -.19333700E+00, 0.27591700E+00, 0.15273900E+00, -.99226700E+00, -.40921100E+00, -.38749600E+00, 0.18521500E+00, -.19235900E+00, 0.14459000E+00, -.77009900E-01, -.58883900E+00, 0.92260700E-01, 0.20729400E+00, 0.59370800E+00, 0.60402400E+00, 0.30489900E+00, 0.18665500E+00, 0.55403500E+00, 0.34033600E-02, -.11506700E-01, 0.27844000E+00, -.26182000E-01, 0.19137500E+00, 0.15398400E+00, -.43752000E-01, 0.78706500E-01, -.98995200E+00, -.10985400E+00, 0.15400000E+00, -.30668000E+00, -.52878200E+00, 0.12732800E+00, -.94179700E-01, -.11907100E+00, -.65898000E-01, 0.15820500E+00, 0.76119400E-01, -.78171100E+00, 0.75298200E+01, -.62009100E+01, 0.73526100E+00, 0.21442600E+01, 0.36939200E+01, 0.11502500E+01, 0.74260800E+02, -.37249100E+02, -.34827800E+02, -.38471600E+00, -.13146400E+02, -.26589000E+02, -.12285900E+02, -.26572500E+02, -.13518100E+02, -.25665400E+01, 0.77744000E+01, 0.56756400E+00, -.94285400E-01, -.30214400E+01, -.19235500E+01, 0.32761000E+01, 0.71870800E+01, 0.25695200E+01, -.18081700E+01, -.10050500E+01, 0.21838900E-01, -.10042000E+01, 0.14671100E+01, -.14945000E+01, 0.47361900E+00, 0.46394200E+01, -.53166500E+00, -.15874200E+01, -.10753500E+01, 0.14114900E+01, 0.34987800E-01, -.29418900E+01, 0.24200900E+01, -.94848200E+00, -.21636900E+01 },
            { 0.64818200E+01, -.10696100E+01, -.36556900E+01, -.15207300E-01, -.67198800E+01, -.43039900E+00, -.27819400E+01, 0.60883800E-01, 0.15072800E+01, -.23427300E+01, 0.47860100E+00, -.50574300E+01, -.13455800E+01, 0.84745500E+00, -.14081200E+01, 0.13366600E+01, -.18369300E+01, 0.59345400E+00, 0.38214800E+01, 0.33315800E+00, -.52802000E+01, -.10321800E+01, -.10253000E+01, 0.46881600E+01, -.68704300E+00, -.17211600E+01, 0.81674000E-01, 0.76727200E+00, -.14890700E+00, 0.94273100E+00, 0.16338800E-02, -.20824600E+00, -.80506400E+00, -.39602500E+00, 0.13265900E+00, 0.54595500E+01, -.12811900E+00, 0.53536900E-01, 0.56488200E-01, 0.27348500E+01, 0.24802200E+01, 0.35359900E+00, 0.32083900E-01, -.38546900E-01, 0.45795300E+00, -.14450400E+01, 0.10677300E+01, -.38475300E+01, 0.95667700E-01, -.58503200E+00, 0.96162400E+00, 0.19195300E+00, -.83426100E+00, -.19084800E+00, -.40784600E-01, -.19500400E+00, -.18921000E+01, 0.18396100E+00, 0.58239300E+00, -.14666800E+01, 0.78372400E+00, 0.29571600E-01, -.18791800E-01, 0.14253400E+01, -.48797800E+00, 0.11836800E+01, -.19454500E+01, -.27515700E+00, 0.13993800E+01, 0.16808700E+02, -.13950800E+01, -.32581200E+01, -.39884300E+00, 0.35707000E+00, 0.11248100E+00, 0.10473600E+01, 0.64701100E+00, 0.54793600E+00, 0.24290000E+01, 0.37979500E+00, 0.54800700E+00, 0.14799800E+01, -.68933300E+00, 0.81547900E+00, -.86738000E+00, -.35113600E+00, -.31170600E+01, -.14593600E+01, -.65009700E+01, 0.68043600E-01, 0.51033400E+00, -.39696300E+00, -.43724300E+00, 0.89462000E+00, 0.21563100E+01, -.35107800E+01, -.30632000E+01, -.63607000E+01, 0.12323800E+01, 0.10836300E+01, -.74135500E+00, -.69060900E+00, -.10473100E+01, 0.73922100E+01, -.30705300E+01, -.44630300E+01, -.10872900E+01, -.19931600E+01, -.63744600E+00, 0.78566700E-02, 0.34616600E+01, -.86137100E+01, -.18300100E+01, 0.29258000E+01, -.38858000E+01, -.44859900E-01, -.17175200E+02, -.31963100E+00, 0.65022700E+00, 0.40415400E+00, 0.12339600E+00, 0.38623300E+00, -.55077500E+00, -.10086800E+01, -.21079400E+01, -.12497600E+01, -.15309900E+01, 0.79988700E+00, 0.25118800E+01, -.76993800E-01, 0.34385200E+00, 0.51415400E+00, -.50558800E+00, -.19319700E+01, -.26155500E-01, -.59347200E-01, 0.20206000E+00, -.21568400E+01, 0.23088300E+01, -.21228100E+01, 0.65934300E+00, -.97092500E+00, 0.52013800E+00, 0.13246600E+00, -.48834900E+00, 0.46129100E+00, 0.10918500E+01, -.78460700E+01, 0.44576500E-01, 0.28278200E+01, -.94421800E-01, 0.31831000E-01, 0.27089700E+01, 0.11696000E+01, -.50490400E+00, 0.17719700E+01, 0.39664100E+00, 0.51572800E+00, -.40881500E+00, 0.88760900E+00, 0.32870400E+00, 0.19219700E+00, -.19614100E+01, 0.45348400E+00, 0.31409600E+00, -.64610100E+00, -.13527900E+01, -.20953600E+01, -.63819000E+00, 0.65338500E+00, 0.37036200E+01, 0.25233200E+01, 0.25906100E+00, -.25043000E+00, 0.28567100E+00, -.11646600E+01, -.25282000E+01, 0.12217800E+01, -.22757200E+00, 0.11673600E+00, -.27446300E+00, -.38986400E+00, -.16571500E+01, 0.75471400E+00, 0.56705700E+00, 0.18903400E+01, -.30919700E+00, -.31459700E+00, -.97271000E+00, -.16143400E+00, 0.21367600E+01, -.48633200E+00, 0.33774500E+01, 0.36921500E-01, 0.73992600E+00, 0.12313700E+01, 0.11251800E+01, 0.37957400E+00, 0.46978700E+00, -.23251400E+00, 0.49831400E+00, 0.37476800E-01, -.25659100E+01, -.10523700E+00, -.84275400E-01, -.11175500E+01, -.24898000E+00, -.57066900E-01, 0.23426200E+00, 0.35841400E+01, 0.79957500E+00, 0.43574800E+02, -.37139400E+01, -.59429300E+01, -.90716400E+02, 0.37742800E+02, -.20069300E+02, 0.98677800E+01, 0.15885800E+01, -.38315600E+02, -.36328300E+02, 0.43065100E+02, 0.47515900E+02, 0.91163000E+02, -.35865000E+02, 0.12236700E+01, -.12429200E+02, 0.29287200E+01, -.12409000E+01, -.30631300E+02, -.60447300E+00, -.83287800E+00, -.19600700E+02, 0.16606400E+01, 0.60732900E+01, 0.37464000E+00, -.58691400E+00, 0.35592300E-01, -.14444100E+01, 0.28164000E+01, -.71719000E+00, 0.55428800E+02, 0.75677500E+01, 0.62554600E+01, 0.10426500E+00, -.21062500E+01, 0.81264100E+01, -.49330500E+01, 0.40024800E+01, -.34957500E+02, -.44404200E+01 },
            { 0.10678400E+01, 0.48567800E-01, -.37240400E+00, -.10087700E+01, -.25951600E+01, -.29349700E+00, -.38898300E+00, 0.39001600E+00, 0.10104400E+01, -.27762200E+00, 0.13969700E+00, 0.66968900E+00, 0.10660800E+00, -.54746300E-02, 0.83517000E-01, 0.87140300E-01, -.66246200E+00, 0.68062600E-01, 0.41590800E+00, -.55955000E+00, -.43852200E+00, -.18357900E+00, -.87394900E+00, -.30991300E+01, 0.22356700E+00, 0.24961900E+00, 0.78094800E+00, -.24264000E+00, 0.32498500E+00, 0.10850600E+00, 0.84249400E+00, -.50336100E+00, 0.30939300E+00, -.89614600E+00, -.36749000E+00, 0.51910700E+00, -.51834900E-01, 0.22499400E-01, 0.22658600E-01, -.41077700E+00, 0.25343200E+01, -.10148700E+00, -.63464800E+00, -.65348800E+00, 0.74138500E+00, 0.72903900E+00, 0.26391000E+00, 0.23224100E+01, -.59913300E+00, 0.92653700E+00, -.11714000E+01, 0.11376900E+01, 0.33398200E+00, 0.12258100E+00, -.32624400E+00, 0.16324300E+01, -.30718500E+01, -.59858500E-01, 0.63210800E+00, 0.64213000E-01, -.37672700E+00, 0.12203100E+01, -.94655700E+00, -.73683400E+00, -.96230100E+00, 0.16772500E+01, 0.20169100E+01, 0.24068700E+00, -.45190600E+00, 0.78925100E+01, 0.58766900E-01, 0.10853200E+01, -.26535900E+00, 0.19128100E+00, -.21896600E+00, -.21477600E+00, -.69372600E+00, -.21694500E+00, -.22148900E+00, -.41139200E+00, 0.13746700E+00, -.84444900E-01, -.33102600E+00, -.16797200E+00, -.27260700E-01, 0.11685100E+00, 0.18119900E+01, -.59277400E+00, 0.17079600E+01, -.15793900E-01, -.28451500E+00, 0.42183300E-01, 0.72272500E-01, 0.64252700E+00, -.42425400E+00, 0.13778900E+01, 0.19557300E+01, 0.15343000E+01, -.69488700E-01, -.37010200E+00, -.60897300E-01, -.43657400E-02, 0.12678400E+00, -.30539800E+01, 0.98923100E+00, 0.22762800E+01, 0.20962800E-01, -.35071200E+00, -.80540700E+00, 0.29529300E+00, -.52413400E+00, -.16431600E+01, -.97657600E-01, 0.41623900E+00, -.10802400E+00, -.12004700E-01, 0.26162700E+01, -.72206700E-01, 0.24621900E-01, 0.27642300E-01, 0.96159300E-01, 0.73821900E+00, -.17109300E+00, 0.11586000E+01, 0.38753300E+00, 0.55393200E+00, 0.68871600E+00, -.76198700E-01, -.46155500E+00, -.34254700E-01, -.68988200E-01, -.41738200E+00, -.13441100E+00, 0.76831200E+00, 0.74125600E+00, 0.26023500E+00, -.18286300E+00, -.61077900E-02, 0.20468200E-01, 0.37731600E+00, 0.12737100E+00, -.13088200E+00, -.15232100E-01, -.28908300E+00, 0.80655200E-01, -.39712300E-01, -.11378200E+00, 0.24381600E+01, 0.23349900E-01, -.12097300E+01, -.86641500E-01, 0.32496600E+00, -.20204600E+00, -.22805500E+00, -.18827300E+00, -.40765700E+00, -.82606000E-01, -.83647500E-01, -.39403500E-01, 0.72938700E+00, -.72873800E+00, 0.15819800E+00, -.71235000E+00, -.10503100E+00, 0.15769900E+00, -.45839800E+00, 0.19498500E+00, 0.83063400E+00, -.60188500E+00, -.21707200E+00, 0.51282900E+00, 0.85681300E+00, 0.18136600E-01, -.57421700E-01, -.11326800E-01, -.12289200E+00, -.53843200E+00, 0.12239600E+00, -.22377600E+00, 0.97129300E-01, -.18516200E+00, 0.29916200E+00, -.13795200E+00, -.10389300E-01, -.13166700E+00, -.67489000E-01, -.12055200E+00, -.26308600E+00, -.31607100E-01, -.18575100E+00, 0.73651500E+00, -.79660900E-01, -.13340900E+01, 0.68389500E-01, -.60955600E+00, 0.53755800E+00, -.29016800E+00, -.10984200E+00, -.43804100E+00, -.58543300E-01, -.23947500E+00, 0.61174200E-01, -.32554000E+00, -.21947800E+00, 0.33340300E-01, 0.10629600E-01, -.37411800E-01, 0.25676700E+00, -.11581600E+00, -.32569800E+00, -.51261300E+00, -.13660900E+00, 0.61359900E+01, 0.39925100E+00, -.16136200E+02, -.52595400E+01, -.22908300E+02, 0.11409600E+02, 0.10919000E+02, -.33610300E+01, 0.95357000E+01, 0.40638000E+01, -.10481500E+02, 0.47361000E+01, 0.31684300E+01, 0.12745400E+01, -.36728100E+01, -.40729200E-01, 0.21179900E+00, 0.21899700E+01, -.54353300E+00, 0.65280200E+00, -.52445500E+01, -.18605900E+01, 0.17269500E+01, 0.59832000E+00, 0.65583200E-01, 0.62126900E+00, 0.23065400E+01, -.19370700E+01, 0.17778700E+01, -.45067500E+00, 0.41950500E+00, 0.16979000E+01, 0.92151400E+00, -.39194200E+00, 0.25316700E+01, 0.21136500E+01, -.25642400E+00, -.83131200E+00, -.59465600E+01 },
            { -.25963200E+01, -.17103100E+00, 0.12820200E+01, -.77747200E+00, 0.23122100E+01, 0.50048900E+00, 0.65721300E+00, 0.57746400E+00, -.12110700E+01, 0.42069800E+00, -.48208900E+00, -.17388900E+00, -.80576800E+00, 0.31194300E+00, -.44605900E+00, 0.97893300E-01, 0.30810900E+00, -.69713500E+00, 0.31653900E-01, 0.19379400E+00, 0.42413400E+00, 0.12173700E+01, -.65441400E+00, 0.30543900E+01, 0.34659000E-01, 0.49533300E+00, 0.42685500E+00, 0.31847700E+00, 0.81801200E-01, -.55403300E+00, -.81772200E+00, 0.23302500E+00, 0.10197000E+00, 0.32575100E+00, -.16381400E-01, -.37421800E+01, -.55729400E+00, 0.22463100E+00, 0.32560200E+00, -.22463000E+01, -.27547200E+01, 0.85416500E+00, 0.73338500E+00, 0.79930500E+00, -.25298000E+00, 0.21487300E+00, -.39438400E+00, -.15852700E+01, 0.13345500E+01, 0.53372500E+00, 0.18222300E+01, 0.31456400E+00, 0.69349800E+00, -.42280400E+00, 0.41220600E-01, 0.66891700E+00, 0.55910400E+00, -.57055000E-01, -.34199400E+00, 0.38918300E+00, 0.31732500E+00, -.34447500E+00, 0.49438100E+00, 0.19500800E+00, 0.49717200E-02, -.71894500E+00, 0.15617600E+01, -.19707200E+01, -.87827600E+00, 0.33189000E+01, 0.10832800E+01, 0.44407500E+00, -.23570900E+00, 0.19240000E+00, -.78436700E-01, -.69669200E-01, -.37119800E+00, -.58248600E+00, -.19738500E+01, -.64460000E+00, -.85734000E-01, -.84633700E+00, -.34491800E+00, -.37530200E+00, 0.16272500E+00, 0.53699700E+00, 0.74304800E+00, 0.59086900E-01, -.90262000E+00, 0.72195500E-02, -.19071900E+00, 0.60942500E-01, 0.11866000E+00, 0.62801800E+00, 0.98696900E+00, 0.34329900E+00, 0.74684400E+00, -.15701500E+01, 0.50770500E+00, 0.28383400E+00, -.93387200E-01, -.92218500E-01, -.71577700E+00, 0.11179200E+01, -.38578800E+00, 0.57417700E+00, -.32122500E+00, -.66375600E-01, 0.42382100E+01, 0.37527300E+00, 0.38726600E-01, 0.40188000E+01, 0.17848500E+00, -.27201700E+01, -.32105000E+01, -.32091600E+00, 0.57378000E+01, -.48540100E+00, -.17857400E-01, -.36951800E+00, 0.15010400E+00, -.15477600E+00, -.11113500E-02, -.25864200E+00, -.58904400E+00, -.11691600E+00, 0.71451900E+00, 0.11882800E+00, -.14589900E+01, -.78760000E-01, -.17892900E+00, -.55283900E+00, -.10073300E+01, 0.12688800E+01, -.14202800E+01, 0.19981000E+00, 0.18267300E+00, -.57117100E+00, -.71543300E+00, -.86284900E+00, -.71749000E+00, -.80591400E-01, 0.13189100E+00, -.93244800E+00, -.94510000E-02, 0.20533000E+00, 0.27627200E+00, -.20411100E+01, 0.13801500E-02, -.27998200E+00, -.12403900E+00, 0.11822800E+00, 0.40516700E+00, -.35685000E+00, -.61792900E+00, -.21132300E+00, 0.19556200E+00, 0.57536500E-01, 0.23505800E+00, 0.93838400E+00, 0.14367000E+01, -.72201700E-01, -.99634300E+00, -.48656300E-01, -.27339600E+00, -.41844600E-01, -.30668500E+00, 0.11538300E+01, 0.47880600E+00, -.61528300E+00, -.13858600E+01, -.11260300E+01, 0.93327200E-01, 0.32573500E-01, 0.73787800E-01, -.10767500E+00, -.20658200E+00, -.63273500E-01, 0.48248400E-01, -.85975100E-01, 0.70336700E-01, -.74683800E-01, -.24391100E+00, 0.13834200E+00, 0.57586000E-02, 0.22291500E+00, -.65172000E-02, -.25228500E+00, -.20654700E+00, 0.62721300E+00, -.12420500E+00, 0.34250500E+00, 0.52298400E+00, -.31071600E+00, 0.11089900E+01, 0.38363900E+00, 0.10042400E+01, -.18393100E+00, 0.75752000E+00, 0.49101600E-01, 0.42543700E-01, -.17841800E+00, -.37506900E+00, -.21645300E-01, 0.82534700E-02, 0.37375200E+00, -.12838200E+00, 0.77725000E-01, -.13969000E+00, 0.87021900E+00, -.41854800E+00, -.34302200E-01, -.53030200E-01, 0.10624700E+02, -.27868000E+01, 0.73355900E+01, 0.30722100E+02, -.15791400E+02, -.15095900E+02, -.99469800E+00, -.78341400E+01, -.29198800E+01, -.85506500E+00, -.12155600E+02, -.63833700E+01, -.10417300E+00, 0.30683500E+01, -.11753500E+01, 0.29110400E+00, -.19774500E+01, -.48175100E-01, -.20625400E+01, 0.29818300E+01, -.43774600E+00, -.12399600E+01, -.22182600E+00, 0.15972200E+00, -.14720100E+00, 0.29020000E+01, -.22003400E+01, -.10402000E+01, 0.29921200E+01, -.13688600E+01, -.28060800E+01, -.24874000E+00, 0.94303800E+00, -.26593200E+01, 0.44833700E+00, -.89774900E+00, -.20691100E+01, 0.31173100E+01 },
            { -.47684100E+01, -.22250100E+00, 0.13054300E+01, 0.96499600E+00, -.12386300E+01, -.77632000E+00, 0.12762200E+01, -.69040200E+00, -.94253300E+00, 0.36486000E-02, -.22563800E+01, 0.50113900E+01, 0.30676700E+01, -.44312500E+00, -.14517200E+00, -.13867800E+00, -.96898300E+00, -.30380600E+01, -.65992700E+00, -.22119800E+00, -.54343100E+00, -.95149500E+00, -.15097500E+01, -.48526900E+01, 0.85209900E+00, -.12947600E+01, -.37942400E-02, 0.71235700E+00, -.51078300E+00, 0.59337500E+00, -.15066700E+00, -.17773000E+01, 0.15063700E+01, 0.27582200E+00, -.74038500E-01, 0.16469200E+01, -.12066500E+01, 0.45853400E+00, 0.72795600E+00, -.43403400E+01, -.51899000E+01, 0.16168700E+01, 0.58261300E+00, 0.23587200E+01, -.41171400E+00, 0.95228600E+00, 0.13156700E+01, 0.39547600E+00, 0.16205600E+01, -.36079700E+00, -.60887400E+00, -.57766000E+00, -.34699100E+01, 0.16946400E+01, 0.33949000E+00, -.37274900E+00, -.61031500E+01, -.45641600E-04, 0.15668500E+01, -.16195800E+01, 0.72830700E+00, -.55525500E+00, 0.46891600E+00, 0.52474000E+00, 0.75394000E+00, -.46799000E+00, -.13861900E+00, -.20430500E+01, -.88626100E+00, 0.11405600E+02, 0.77310000E+00, -.52399600E+00, -.42253600E+00, -.20218700E+00, 0.34800400E+00, 0.36098600E+00, 0.28851500E+00, 0.83078700E+00, 0.19235800E+01, 0.15499200E+01, -.10028200E+01, -.12360900E+01, 0.24358400E+01, 0.63091200E+00, -.55313400E+00, 0.36971200E+00, -.85028700E+01, 0.15097700E+01, -.10816700E+02, -.51611200E+00, 0.13916300E+00, -.18122500E+00, 0.21866300E+00, -.26633900E+01, -.11661300E+01, -.11823200E+01, -.13473200E+01, -.79711300E+00, -.87401300E+00, 0.96553700E-02, -.29171800E+00, 0.53494400E+00, 0.18459800E+01, 0.63429400E+01, -.14898800E+01, -.30313000E+01, -.80262800E+00, -.27719400E+00, 0.37436500E+01, -.19429200E+00, 0.23765200E+01, 0.44126000E+01, 0.11661000E+00, 0.25977100E+01, -.69378500E+01, -.51221400E-01, -.10551800E+02, -.94802400E+00, 0.15935000E+01, -.77271400E+00, -.55354900E-01, 0.24278200E+01, 0.15265000E+00, 0.96080400E+00, -.13541000E+00, 0.50935700E-01, -.55471600E+00, 0.16987600E+00, 0.46147100E+00, 0.60144900E+00, -.22573500E-01, 0.97459600E+00, -.36136600E+00, 0.13036700E+00, 0.73607200E-01, -.39064900E+00, 0.81792700E+00, -.14368200E+01, 0.35419500E+00, -.12334800E+01, -.54105200E+00, -.22525300E+00, 0.27939900E+00, -.17817500E+01, -.49947400E-01, -.26172000E-01, 0.70838100E+00, -.47281700E+01, 0.76031700E+00, 0.91237400E+00, 0.13840800E+00, 0.41858600E-01, -.19827500E+00, 0.14056400E+00, 0.28008200E+00, 0.45521200E+00, -.28301300E+00, 0.15431800E+00, 0.45506100E+00, -.70451800E-01, -.35550000E+00, 0.20618700E+00, 0.59436000E-01, -.11443700E+00, 0.28237400E+00, 0.56687100E+00, 0.28993700E+00, -.12708300E+01, -.51619100E-01, 0.58628000E+00, 0.12911700E+01, 0.90561900E+00, -.97588800E-01, -.45308200E+00, -.24533300E+00, 0.86576200E+00, 0.53333300E+00, -.85261600E+00, -.40767700E+00, -.21938000E-01, -.53905500E-01, 0.43936800E+00, -.12160400E+00, -.39156200E+00, -.35957700E-01, -.82825500E+00, 0.95539200E-01, 0.43418500E+00, -.10828400E+00, 0.94139200E-01, -.18997400E+00, -.39902500E+00, -.77879000E+00, -.72335500E-01, -.44975100E+00, 0.17978800E+00, 0.30508000E+00, -.25690600E+00, -.18948000E+01, -.88046600E-01, 0.12638800E-01, 0.34182500E+00, -.53783300E+00, -.16370300E+00, 0.99241400E-01, -.19475100E+00, -.20059300E-01, 0.81101400E+00, 0.43508900E+00, -.19061800E+01, 0.30826100E+00, -.23325600E+00, 0.21192400E+01, -.55577700E+00, 0.34454600E+02, 0.80127500E+01, 0.18488100E+02, -.92086900E+01, -.93434500E+01, -.48368200E+00, -.16959300E+02, 0.88191200E+01, 0.28725600E+02, 0.25531000E+00, -.10188000E+02, -.29980500E+01, 0.39829700E+01, -.64730800E-01, -.52464700E+00, -.56428800E+01, 0.84137100E+00, -.60179300E+01, 0.69574500E+01, 0.37551300E+01, -.62977000E+00, -.11802500E+01, -.16217700E+00, -.12471800E+01, -.66076300E+01, 0.59951200E+01, -.35561800E+01, 0.45368800E+01, 0.12828600E+01, -.25043900E+01, -.16368700E+01, -.31290900E+00, -.13605600E+01, -.32673500E+01, 0.28782300E+01, 0.52248300E+01, 0.98545500E+01 },
            { 0.11084500E+02, -.44971800E+00, -.46966000E+01, -.61992000E-01, -.11544600E+02, -.15098000E+01, -.49130200E+01, 0.31615400E-01, 0.50782900E+01, -.26138200E+01, -.20329200E+01, -.71858200E+01, -.80195500E+00, 0.12109400E+01, -.25794200E+00, 0.11326300E+01, -.22631700E+01, 0.17264800E+01, 0.87605200E+01, -.19214100E+01, -.63418200E+01, -.48502900E+01, 0.11279200E+01, -.34420100E+00, -.16796600E+01, -.79224300E+00, 0.13887500E+01, -.78933800E+00, 0.11518000E+01, -.22103900E+01, -.93256200E+00, -.11860700E+01, -.85504200E+00, -.68670200E+00, -.39007100E-01, 0.37881700E+01, 0.72381400E+00, -.27075800E+00, -.46726400E+00, 0.75607100E+01, 0.49926100E+01, -.45943500E+00, 0.66344900E+00, -.57886800E+00, -.38288500E+00, 0.20860800E-01, 0.21252300E+01, -.71348200E+01, 0.30096100E+01, -.90689800E+00, 0.40675700E+00, -.97620500E+00, -.23529200E+01, 0.94377200E+00, 0.12918800E+01, 0.17981900E+00, -.93785700E+01, -.45698100E+00, 0.23627500E+01, -.23946400E+01, -.27441400E+00, 0.70423400E+00, -.24995800E+00, 0.16050200E+00, -.62842500E+00, -.88623500E-02, -.61742400E+01, 0.18572500E+00, 0.10450500E+01, -.56375800E+01, 0.10940600E+01, -.27236200E+01, -.12801800E+01, -.12676800E-01, 0.68129100E+00, 0.11401400E+01, -.13379100E+00, 0.44945600E+00, 0.37348400E+01, 0.21254400E+01, 0.82354800E+00, 0.23077100E+01, 0.17258900E+01, 0.18259200E+01, -.72193000E+00, -.21965200E+01, -.23417600E+01, -.31101300E+01, -.60438300E+01, -.11077900E+00, 0.21594000E+00, -.20744700E+00, -.65645800E-01, 0.10155200E+01, 0.16303300E+01, -.16798700E+01, -.10889500E+01, -.33619100E+01, 0.94781700E+00, 0.66203400E+00, -.47993800E+00, -.34543000E+00, -.20410800E+01, 0.12500600E+01, -.69048500E+00, -.13319000E+01, 0.18482100E+00, -.91616600E+00, -.62208200E+01, -.83253700E+00, 0.77132300E+00, -.27633300E+01, -.26877300E+00, 0.20223900E+01, 0.47452100E+01, 0.62813200E+00, -.50464700E+01, 0.23441100E+01, 0.98695500E+00, 0.40395000E-01, 0.32406400E-01, -.71882700E+00, -.31472300E+00, -.56765500E+00, -.36287300E+01, -.19560200E+00, 0.41550200E+00, 0.46840600E+00, -.44751100E+00, -.16303800E+01, -.31999700E+00, 0.18140400E+00, -.15992700E+01, -.64961800E+00, -.53931000E+00, 0.82966200E+00, -.12458000E+01, -.78101700E+00, -.58368400E+00, 0.19351200E+00, 0.20572600E+01, 0.19178800E+00, -.18282500E+00, 0.36100200E+01, -.50817800E+00, -.12713600E+00, 0.11615300E+01, -.30459200E+01, -.87424100E+00, 0.23529000E+01, -.57715500E+00, 0.45855000E+00, 0.34907500E+01, 0.32934700E+01, 0.23893600E+01, 0.31215100E+01, -.64561200E+00, 0.11563800E+01, 0.89517100E+00, 0.34906200E+01, -.35240400E+00, -.12161900E+01, -.43135800E+01, 0.12701300E+01, -.12438300E+01, -.21561600E+00, -.11533800E+01, 0.18108600E+01, 0.78019800E+00, 0.51465900E+00, -.47628600E+01, 0.50392000E+01, -.33943200E+00, -.39937600E+00, -.34221700E+00, -.62356900E-01, -.16808500E+01, 0.61257500E+00, 0.52925500E+00, -.12787100E+01, 0.37275400E+00, -.77219000E+00, 0.10694300E+01, 0.24157900E+00, -.64737400E+00, 0.13342800E+00, -.19735000E+01, -.76184000E+00, 0.92464900E+00, 0.16256700E-01, 0.63599300E+00, 0.25688800E+01, -.28702300E+01, -.43410400E-01, 0.27279900E+01, 0.11158100E-01, -.56416100E+00, -.37490800E+00, -.27018700E+01, -.40176600E+00, -.26287800E+00, 0.65256100E+00, -.57864300E+01, -.22090100E+00, 0.78818700E-02, -.15341700E+01, -.85033100E+00, 0.24304100E+01, 0.29471000E+00, 0.91898600E+00, -.19316800E+01, 0.79974400E-01, -.22833400E+01, -.14390200E+01, -.16330700E+01, 0.35069400E+02, 0.21637200E+03, -.10945900E+03, -.11540600E+03, -.74818000E+02, -.81878100E+02, 0.32314900E+01, 0.89987900E+02, 0.85495000E+01, -.90630900E+02, -.11727200E+02, 0.17128000E+02, -.65569300E+01, -.49990500E+00, -.29132200E+02, -.77472400E+01, -.34300500E+02, 0.18667100E+02, 0.24007000E+01, 0.14824000E+02, -.49908800E+01, 0.16723400E+00, -.45028700E+01, 0.40212700E+01, -.34504100E+00, -.16929800E+01, 0.68541500E+02, 0.21776500E+01, 0.68801400E+01, -.41195600E+01, 0.36202900E+01, -.82979400E+00, -.39244600E+01, 0.53012300E+01, 0.53663700E+00, 0.19657400E+02 },
            { -.15798600E+01, -.66620100E+00, 0.28637800E+00, 0.66972800E+00, 0.24656700E+01, 0.27074000E+00, 0.75770200E+00, -.27100900E+00, -.13506600E+01, 0.69207600E+00, 0.96139400E+00, 0.19748300E+01, 0.47612200E+00, -.44715400E+00, 0.14864900E+00, -.51896900E+00, 0.10737700E+01, -.46152500E+00, -.53659000E-01, -.25911400E-01, 0.73625100E+00, -.29982700E+00, -.14222400E+01, -.34431000E+00, 0.49156800E+00, -.81192600E-01, 0.22425300E+00, 0.43414500E+00, 0.17357800E+00, 0.52111600E+00, 0.23497400E+00, -.22330300E+00, 0.59669900E+00, -.65552100E+00, -.40330600E+00, -.36641300E+00, -.22505800E+00, 0.82759400E-01, 0.14162000E+00, 0.72086200E+00, 0.25153300E+01, -.22204500E+00, -.12347500E+01, -.67903200E+00, 0.11298600E+01, 0.45027300E+00, 0.12203500E+00, 0.22448000E+01, -.25447000E+01, 0.70842000E+00, -.49182900E+00, 0.23128100E+00, -.46861000E+00, 0.12920100E+00, -.16990100E+00, 0.81287300E-01, -.13842100E+01, 0.14614000E+00, 0.56209800E+00, -.56360700E+00, 0.85226800E-01, -.55554200E-01, -.50865800E+00, -.19433700E+00, 0.13746800E+00, 0.10702000E+01, 0.34910900E+00, -.18826100E+00, 0.87467900E+00, -.38476500E+01, -.50862100E+00, -.38944100E+00, 0.32834300E+00, -.28375300E+00, 0.34925900E-01, 0.28552800E-01, 0.27496300E+00, 0.45243700E+00, 0.67506000E+00, 0.58260600E+00, -.20820300E+00, -.79285400E+00, 0.97388400E+00, 0.31961700E+00, 0.29425800E-01, 0.15819300E+00, -.27105000E+01, 0.77705500E+00, -.40315900E+01, -.19985800E+00, -.81911600E-01, 0.44547300E-01, 0.11356800E+00, -.93077100E+00, -.30438600E+00, -.42934100E-03, -.30809300E+00, -.35871800E+00, -.24051100E+00, -.37833600E-01, 0.37630800E-01, 0.15579600E+00, 0.64722300E+00, 0.26834500E+01, -.46024200E+00, -.85024800E+00, 0.55014400E+00, -.16667100E+01, -.28867500E+01, -.64791800E+00, 0.13356600E+01, -.51387200E+00, -.44754700E+00, 0.24911600E+01, -.19123000E+01, 0.16964200E+00, -.47627700E+01, -.24377300E+00, 0.50917000E+00, 0.36116800E-01, 0.45806400E+00, 0.34336500E+00, 0.99260400E-02, -.34161000E+00, -.40490300E+00, -.24033700E+00, 0.17130100E+00, 0.27392100E+00, 0.13741700E+00, 0.37435600E+00, -.55434100E-01, 0.35168600E+00, -.86411600E+00, 0.10884100E+01, 0.69414100E-01, -.19123900E+00, 0.24298800E+00, -.70878000E+00, 0.36795400E-01, -.10606700E+01, -.20795800E+00, -.17660600E-01, 0.26252200E+00, -.98643300E+00, 0.28159200E+00, -.22690000E-01, 0.82907800E-01, -.23922100E+01, 0.10263000E+00, 0.35789100E+01, 0.12225900E+00, -.10351100E+00, -.57596900E+00, 0.54873300E+00, 0.48843700E+00, 0.42948400E-02, -.58864000E+00, 0.12920200E+00, -.34573600E+00, 0.68613400E+00, 0.39485700E+00, 0.16040300E+00, -.62019000E+00, 0.22400400E+00, -.28646300E+00, 0.24197300E+00, -.30043700E-01, -.50370600E+00, 0.53605100E+00, -.17783600E-01, 0.54391400E+00, -.10897300E+01, 0.15473000E+00, -.12688900E+00, 0.27391600E-01, 0.42207100E+00, 0.12483800E+00, -.26671100E+00, -.12654800E+00, 0.50271000E-01, -.10533600E+00, -.16021300E+00, -.34464800E-01, 0.61844500E-01, -.57663100E-01, 0.56000500E+00, -.30576900E+00, 0.18106800E+00, -.30470600E+00, 0.17404300E+00, -.14870700E+00, 0.12489600E+00, 0.60596100E+00, -.10532700E+00, 0.12198900E+00, 0.98336700E-01, -.23719800E+00, 0.75506900E-01, -.28490800E+00, -.64147100E-01, 0.23485900E-01, -.10718000E+00, 0.11433700E-01, 0.10520000E+00, 0.46771800E-01, 0.17790800E-01, -.58701200E-02, 0.25213200E+00, -.54331500E-01, 0.44198100E+00, -.54627500E+00, 0.92529600E-01, -.30941000E+00, 0.25002300E+00, 0.60172700E-01, -.42335100E-01, 0.73876600E+02, -.37106000E+02, -.37655000E+02, 0.30763200E+01, -.59313200E+01, -.31129300E+02, -.25926700E+02, -.31634400E+02, -.52884600E+01, -.12582500E+01, 0.12253100E+01, 0.52832900E+00, -.18427800E+00, -.34899700E+01, -.10454000E+01, 0.50571000E+00, 0.86390900E+00, 0.11835400E+01, -.68168300E-01, -.43210300E+00, -.54805300E-01, -.43209100E+00, 0.13513700E+00, -.20380300E+00, 0.14713300E+00, -.93398500E+01, -.96295600E+00, -.97732900E-01, -.55174800E+00, 0.47757900E+00, 0.22308100E+01, -.17563100E+01, 0.12017800E+01, 0.43256000E-01, -.69088200E+01 },
            { 0.38087600E+01, 0.37835000E+00, -.11685600E+01, -.55325200E+00, -.29224500E+01, -.23865600E+00, -.10445700E+01, 0.17241200E-02, 0.90168700E+00, -.62964700E+00, 0.10789800E+01, -.17224800E+00, 0.36206500E+00, -.11854200E+01, 0.26764000E-01, 0.30838800E+00, -.80822900E+00, -.70263900E+00, 0.17256700E+01, 0.15245100E+00, -.91970700E+00, -.19604800E+01, -.73769500E+00, -.14044400E+01, -.15302300E+00, -.63106800E+00, -.12420500E+00, -.84864700E-01, 0.25461100E+00, 0.50188900E+00, 0.88332600E+00, -.27999500E+00, -.42515100E-01, 0.53171500E+00, 0.47196700E+00, 0.44826300E+01, -.44415800E+00, 0.16782800E+00, 0.27920400E+00, -.11151300E+01, -.27899000E+01, 0.76287700E+00, 0.78575800E+00, 0.13520400E+01, -.97735700E+00, -.17306600E+00, 0.74426700E+00, 0.90362800E+00, 0.95902200E+00, -.10179000E+01, -.12719600E+01, -.37538200E+00, -.10154800E+01, -.26435300E+00, 0.55340500E+00, -.88529400E+00, -.65528600E-01, -.22091500E+00, 0.30430800E+00, 0.21639400E+00, -.51075500E+00, 0.43377400E+00, -.15131000E+00, -.82057600E-02, 0.61463400E-01, 0.86958400E-01, -.68509300E+00, 0.72337300E-01, 0.41605200E+00, -.18419200E+01, -.41966900E+00, 0.68581200E-01, 0.37237500E+00, -.23052100E-02, 0.10607600E-01, 0.66369200E-01, -.99317000E-01, -.50341100E+00, 0.15882900E+00, -.98200300E-01, 0.19170900E+00, 0.73014500E+00, -.42498100E+00, -.89885900E-01, 0.24151500E-01, -.39912000E+00, 0.84393900E+00, -.85907000E+00, 0.15831100E+01, 0.12301900E+00, 0.18157400E+00, -.44383200E-01, -.18984300E+00, -.93260700E-01, -.25955400E-01, -.64524200E+00, -.37960700E+00, -.14779000E+00, -.82479600E-01, 0.15685100E+00, 0.16292400E-01, -.28489700E+00, -.25681300E+00, 0.67901800E+00, -.33429700E+00, -.49317500E+00, -.11520100E+01, 0.13476600E+01, 0.10538900E+01, 0.33525800E+00, -.14102900E+00, -.14505800E+01, 0.62255100E+00, -.39757900E+00, 0.28004700E+01, 0.17580300E+00, -.40648600E+01, 0.12041900E+00, -.40640400E+00, 0.33545100E+00, -.10354100E+00, 0.41239200E+00, 0.19988200E+00, -.22657100E+00, 0.89846700E-01, -.54668600E+00, -.12276900E+01, -.27046300E+00, 0.20075900E+00, 0.11935100E+00, 0.42905300E-01, 0.35246400E+00, 0.10851500E+00, -.92632100E+00, -.24963700E+00, 0.26285300E-01, -.16703200E+00, 0.55591200E+00, -.77547100E-01, 0.29931100E+00, 0.16010200E+00, 0.83781600E-01, -.11119500E+00, 0.38209300E+00, -.35932800E-01, 0.86446800E-01, -.17390400E+00, 0.21523200E+01, 0.10207900E+00, -.85969400E+00, 0.11095300E+00, -.10550100E+00, 0.51643600E-01, -.57785300E-01, -.15566500E+00, 0.74152600E-01, -.16625300E+00, -.64408900E-01, -.49501700E+00, -.92012000E+00, -.14476800E-01, -.51461600E-01, 0.10371400E+01, 0.72860600E-01, 0.13644800E+00, -.50873600E-01, 0.72562700E-01, -.28490800E+00, -.96609000E-01, -.13212800E+00, 0.41446800E+00, -.15579400E+00, 0.75007700E-03, 0.96951500E-02, -.35178200E-01, 0.26478000E+00, 0.28164800E+00, 0.21048800E+00, 0.37670700E-01, 0.10940300E+00, -.52045900E-01, -.32599800E-01, 0.21840400E+00, -.12017700E-01, 0.33218500E-01, 0.41013600E-03, 0.10738400E+00, 0.13437600E+00, 0.34188200E+00, 0.18814400E-02, -.20951800E+00, 0.17813500E-01, -.17308500E+01, 0.40959200E-02, -.10292900E-01, -.12405100E+00, -.14183100E+00, -.12724100E+00, -.61258700E+00, 0.32295200E-01, 0.87669400E-01, 0.12524700E+00, -.27131700E+00, -.12784700E+00, 0.40586400E-01, 0.22476200E+00, -.60491800E-01, 0.28602300E+00, -.96522000E-03, -.19388300E-01, -.59267600E-01, -.24876500E-01, 0.35791700E-01, -.10112700E+00, 0.29867300E-01, -.29742800E-01, -.25082600E-01, 0.28157600E+01, -.11224000E+01, -.47178800E+01, -.24258100E+01, 0.15276000E+01, 0.40698500E+01, -.18116200E+00, -.40519400E+01, -.37948100E+00, -.24750900E+00, -.11721600E+00, -.21804800E-01, -.54868300E+00, -.15745600E+00, -.20202000E-01, -.48499700E+00, 0.13188000E+00, 0.11586400E+01, -.13961600E+00, 0.43075000E-02, -.11856600E+00, -.20208300E+00, 0.35080200E+00, -.13782300E+00, 0.11648200E+00, 0.52363000E+00, 0.89901500E+00, -.88362000E-01, -.27633400E+00, 0.15818500E+00, 0.17296800E+00, -.30454900E+00, 0.68801900E-01, -.11152000E+01 },
            { -.97447300E+01, 0.19503400E+01, 0.37095000E+01, 0.22095100E+01, 0.89545300E+01, 0.43763700E+00, 0.39889500E+01, -.88806700E+00, -.41355600E+01, 0.17260800E+01, 0.60439900E+00, 0.84290500E+01, 0.28311700E+01, -.68908700E+00, 0.17721100E-01, -.71537600E+00, 0.24644000E+01, -.54326800E+00, -.68749900E+01, 0.63828200E+00, 0.38306600E+01, -.33545800E+01, -.21551000E+01, -.12347300E+02, 0.30890300E+01, 0.41467300E+00, 0.89237700E-02, 0.88443900E+00, -.27816800E+00, 0.17792600E+01, 0.44885200E+01, -.47997100E+00, 0.29623400E+01, -.84834700E-01, -.50136800E+00, 0.56615200E+01, -.13853100E+01, 0.50724300E+00, 0.94372200E+00, -.43418700E+01, 0.80845800E-01, 0.74820800E+00, -.83495400E+00, 0.54769000E+00, 0.18446500E+00, 0.33650500E+01, -.82483200E+00, 0.15358900E+02, -.77075800E+01, 0.19964900E+01, -.61145600E+01, 0.29428500E+01, -.10331600E+01, 0.13893600E+01, -.54566200E+00, 0.27772900E+01, -.69163900E+01, 0.89132900E+00, 0.25122200E+01, 0.60877100E+00, -.18135600E+01, 0.22271400E+01, -.11372800E+00, -.10218500E+01, -.21180500E+01, 0.64525500E+01, 0.11474700E+02, -.19763200E+01, 0.14375300E+01, 0.23539300E-01, 0.81836400E+00, -.97549400E+00, -.72884100E+00, -.36993100E+00, -.64945300E+00, -.14809200E+01, -.17123300E+01, 0.44084000E+00, 0.35943900E+01, 0.16903900E+01, -.93198400E+00, -.13829500E+01, 0.99619400E+00, -.14974100E+01, 0.11116300E+01, -.12582000E+00, 0.56069500E+01, 0.64691800E-01, 0.10085300E+02, 0.32287000E+00, -.19099600E+00, 0.37857700E+00, -.23109900E+00, 0.16483600E+01, -.77821700E-01, 0.17359700E+01, 0.23612900E+01, 0.31613100E+01, 0.90894300E-01, -.23734700E+00, 0.77489400E+00, -.59556600E+00, -.15088500E+01, -.18066600E+01, 0.76084900E+00, 0.37996600E+01, 0.62196100E+00, -.20895300E+01, 0.41865700E+01, -.15846500E+00, -.78499000E+00, 0.19738800E+02, 0.11344600E+01, -.61848300E+01, 0.12395300E+01, 0.56168800E+00, 0.87585200E+01, -.15961100E+01, -.56100600E+00, -.74663600E-02, 0.91498400E+00, -.37999100E+01, -.11556000E+01, -.32031000E+01, -.16897100E+01, 0.94696700E+00, 0.32107100E+01, 0.84967700E+00, -.24086800E+01, 0.12502200E+01, 0.82995800E-02, -.44223900E-01, 0.87861500E+00, -.91951500E+00, 0.59358900E+00, 0.53946400E+00, 0.51413300E-01, -.54320000E+00, -.42426500E+00, 0.30272900E+00, -.10809700E+01, -.96564600E-01, -.87296300E-01, -.21089300E+01, 0.13508100E+00, 0.47238000E+00, 0.11651300E+01, 0.35051000E+01, 0.68356700E+00, 0.57832000E+00, 0.11760300E+00, -.88983500E+00, -.24800900E+01, -.18470200E+01, 0.32753200E+00, 0.39369800E-01, 0.11885700E+01, -.18181900E+01, -.33707800E+01, -.25038300E+01, 0.67358100E-01, -.66743700E+00, 0.12127900E+01, -.94282300E+00, 0.16227800E+00, 0.20860900E+00, 0.43821600E+00, -.43108500E+00, -.27525000E+00, 0.11568400E+01, -.63953700E+00, 0.20669500E+01, -.22564600E+00, 0.16061300E+00, -.11720100E+00, -.18078700E+00, 0.53388600E+00, 0.11769100E+01, 0.41107800E+00, 0.38548900E+00, -.36902300E+00, 0.91182500E+00, 0.10199800E+01, -.48200100E-01, -.58070400E+00, 0.69208600E+00, -.39994200E+00, -.19501200E+01, -.12459600E+01, -.74452900E+00, 0.20847000E+01, -.24038900E+01, 0.24772300E+01, 0.99430000E+00, -.36322900E+01, 0.79012500E+00, 0.19124000E+01, 0.50590700E-01, -.15613400E+01, -.61598000E+00, 0.45002000E+00, 0.11882500E+01, -.10183200E+01, -.46333400E+00, -.10933800E+00, -.22278700E+01, 0.20848500E+00, 0.16334500E+01, 0.33389700E+00, -.15612400E+01, 0.49170900E+00, -.86293500E+00, 0.26999700E+01, 0.27203400E+01, 0.30707000E+00, -.48856800E+00, -.20005800E+00, 0.50998600E+00, -.15420800E+02, -.62609400E+02, -.39910900E+02, 0.46191000E+02, 0.11143300E+03, 0.11110600E+03, -.45564500E+02, -.78919800E+01, -.65802200E+01, 0.29547300E+01, -.25544100E+01, -.26496000E+02, -.40689200E+01, -.60397900E+01, -.67493800E+01, 0.84984200E+01, 0.11210700E+02, -.28987100E+01, -.10590300E+01, -.33514700E+01, -.19671900E+02, 0.17519000E+02, 0.20504100E+01, 0.84129800E+02, 0.12190300E+02, 0.97036000E+01, -.38844100E+01, -.25093000E+01, 0.15891100E+02, -.91853900E+01, 0.20692700E+02, 0.30453900E+00, 0.80926100E+01 },
            { 0.47460000E+01, -.84785400E+00, -.35316000E+01, 0.61093900E+00, -.74525200E+00, -.19821600E+00, -.26400700E+01, 0.70483900E+00, 0.25586500E+01, -.39628600E+00, -.79982000E+00, -.62513900E+01, 0.90256100E+00, 0.72811300E+00, -.24015100E+00, 0.43813400E+00, -.20888500E+00, -.63129900E+00, 0.61072200E+01, 0.49626800E+00, -.31071700E+01, 0.82197400E+00, -.35582300E+00, 0.68776300E+01, -.17920300E+01, -.36028300E+00, 0.66963500E+00, -.54240000E+00, 0.88744800E+00, -.75048500E+00, -.24936400E+01, -.54020100E+00, -.77228900E+00, 0.83757400E+00, 0.23739600E+00, -.21555500E+01, 0.39426900E+00, -.14343700E+00, -.30688000E+00, -.57131200E+00, -.30965700E+01, 0.87209000E-01, 0.84522800E+00, 0.85182900E+00, -.62130000E+00, -.13031400E+01, 0.85883000E+00, -.75567800E+01, 0.62687900E+01, -.16900800E+01, 0.32877300E+01, -.29971900E+01, -.11793900E+01, 0.61713300E+00, 0.14613000E+00, -.14207100E+01, 0.88853400E+00, -.59695100E+00, -.32618400E-01, -.11860100E+01, 0.84318300E+00, -.91897600E+00, 0.18843800E+00, 0.31735400E+00, 0.13921300E+01, -.34906300E+01, -.50248500E+01, 0.34926700E+00, -.18668000E+01, 0.90331800E+01, -.42052700E+00, 0.55407600E+00, 0.15234200E+00, 0.40015700E+00, 0.43874800E+00, 0.56791000E+00, 0.74054000E+00, -.26767800E+00, -.17025800E+01, -.89853900E+00, 0.30783400E+00, 0.32768900E+00, -.34556000E+00, 0.11184400E+01, -.62556600E+00, 0.35233400E+00, -.60648200E+01, 0.14864200E-01, -.92520700E+01, -.35891900E+00, 0.21441000E+00, -.29130600E+00, 0.21627700E+00, -.19154000E+01, -.40575700E+00, -.14382700E+01, -.18572500E+01, -.19330000E+01, -.29341100E+00, 0.18175100E+00, -.53020900E+00, 0.58172600E+00, 0.13497100E+01, 0.36777400E+01, -.96197500E+00, -.32721900E+01, -.49849500E+00, 0.26085800E+00, 0.14683800E+00, 0.12274000E+00, 0.12203600E+01, -.10199400E+02, -.11742700E+01, 0.52796600E+01, -.19869500E+01, -.12761900E+00, -.69426300E+01, 0.92964100E+00, 0.12511600E+01, -.36626200E+00, -.17596100E+00, 0.30843800E+01, 0.50424100E+00, 0.30076300E+01, 0.13468000E+01, -.17589400E+00, -.11721700E+01, -.15940500E+00, 0.11333800E+01, -.48059600E+00, -.96156600E-01, 0.13161000E+00, -.15721600E+00, 0.10947100E+01, 0.58447600E+00, -.32465100E+00, 0.44855100E+00, -.43379200E+00, 0.50222700E+00, -.50768600E+00, -.14665400E+00, -.18903700E+00, 0.18256000E+00, 0.24077200E+00, -.12657600E+00, -.24696100E+00, -.45808900E+00, -.44271000E+01, -.62154300E-01, 0.14753300E+01, 0.11654600E+00, 0.53052200E+00, 0.15212900E+01, 0.11498700E+01, -.17458700E+00, -.13538500E+00, -.84258400E+00, 0.10383800E+01, 0.19744600E+01, 0.15182900E+01, 0.99240200E-01, 0.48056500E+00, -.75508800E+00, 0.47461500E+00, -.43689600E-01, 0.31371200E+00, -.10968600E+00, -.18321000E+00, 0.14910300E+00, -.44723000E+00, 0.11529800E+01, -.16443800E+01, 0.12633100E+00, -.43044500E+00, -.10506700E-01, 0.82938900E+00, 0.73230200E-01, -.12692700E+01, -.44459200E+00, -.16493400E+00, 0.16131700E+00, -.18769800E+00, -.13268900E+01, -.17878900E+00, 0.59465400E+00, -.10276200E+01, 0.41468700E+00, 0.13752800E+01, 0.37334500E+00, 0.39874300E+00, -.15660800E+01, 0.10904700E-01, 0.12849400E+01, -.65653700E+00, 0.57423700E+00, 0.13865000E+00, 0.29493200E+00, -.40285000E+00, -.93991500E+00, 0.78546200E-01, -.11966100E+00, -.18531800E+00, 0.20376400E+00, -.18194500E+00, 0.52643000E-02, 0.75369600E-01, -.32371200E+00, 0.76431600E+00, -.12517200E+00, 0.30007300E+01, -.10537000E+01, 0.42212400E+00, -.14912100E+01, 0.10297900E+01, -.37165700E+00, 0.26793900E+00, 0.64445000E+00, 0.45821000E-01, 0.32210700E+00, 0.70361400E+02, 0.35880600E+02, -.45706800E+02, -.98576700E+02, -.73288000E+02, 0.52651100E+02, 0.60765100E+01, 0.69977300E+01, -.17897600E+01, 0.17249800E+01, 0.24911300E+02, 0.31354500E+01, 0.25535000E+01, 0.69025200E+01, -.41771600E+01, -.70765000E+01, 0.20836400E+01, 0.68797000E+00, 0.23537100E+01, 0.10695600E+02, -.11867900E+02, -.13373600E+01, -.67598600E+02, -.86635200E+01, -.57201800E+01, 0.25745800E+01, 0.10747000E+01, -.14312600E+02, 0.56246900E+01, -.15334300E+02, 0.18484700E+01, 0.11993700E+01 },
            { 0.36853600E+01, -.26201800E+00, -.12874100E+01, -.12781000E+01, -.45459400E+01, -.58477700E+00, -.15986100E+01, 0.14345200E+00, 0.13290300E+01, -.13800300E+01, -.52020500E+00, -.28973500E+01, -.10332700E+01, 0.29442000E+00, -.55167700E+00, 0.78483500E+00, -.18257200E+01, 0.28204900E+00, 0.28701000E+01, -.18738500E+00, -.24521300E+01, -.27772800E+01, -.18609500E+01, 0.10086100E+01, -.35304900E+00, -.14890600E+01, 0.13344400E+00, 0.34730600E+00, 0.76316200E+00, 0.10736300E+01, -.11167300E+01, -.90855800E+00, -.67192700E+00, -.90255600E-01, 0.13111800E+01, 0.25308600E+01, 0.15989100E+00, -.58905500E-01, -.13272900E+00, -.82113200E+00, 0.23660100E+01, -.16773900E+00, -.20524100E+00, -.37708800E+00, 0.94043300E+00, 0.69301400E+00, 0.79792900E+00, -.21632200E+01, 0.24627900E+01, 0.89475700E+00, 0.29089700E+00, 0.19721700E+00, -.16913400E+01, 0.49860400E+00, 0.19097500E+01, -.16412800E+01, -.41854500E+01, -.76698800E+00, 0.29824700E+00, -.62956200E+00, 0.40795100E+00, -.18072500E+00, -.70682000E+00, 0.11297700E+01, 0.13657100E+01, -.21213400E+01, -.48631500E+01, -.62828800E+00, -.63405200E+00, 0.50192900E+01, -.13366200E+01, -.73272500E+00, -.38232300E+00, 0.61569600E+00, 0.34636100E+00, 0.17122500E+01, 0.20140700E+00, -.75590100E+00, 0.11094800E+01, 0.55533800E+00, -.35669000E+01, -.28171200E+00, 0.13043600E+00, 0.12578400E+00, -.58881900E-01, 0.10098200E+00, -.37522900E+00, 0.11950300E+01, -.10494900E+01, 0.27763300E-01, -.20812100E-01, 0.43302700E-01, 0.37859000E+00, -.18709300E+01, -.51036000E+00, -.28774300E+00, -.19064800E+00, -.10451000E+01, -.41271600E+00, 0.17457400E+00, 0.73819700E-01, 0.64928500E+00, 0.37733000E+00, 0.42284800E+01, -.75472300E+00, -.21569000E+01, -.31760800E+01, 0.26749500E+01, 0.71236800E+01, 0.26607200E-01, -.96071700E+00, 0.47363300E+01, 0.97668900E+00, -.50920300E+01, -.38365100E+01, -.48119700E-01, 0.56013000E+01, -.51239900E+00, 0.23202400E+00, -.68036900E+00, -.26325900E+00, 0.14932000E+01, 0.63296600E-01, 0.18118200E+01, 0.75084200E+00, -.18765200E+00, -.57088500E+00, -.34360800E+00, -.89211700E+00, 0.10693500E-01, -.71513700E-01, -.47227300E+00, 0.20770700E-01, 0.56491500E+00, 0.64099700E+00, 0.57641000E+00, -.43019300E-01, 0.37001700E+00, -.58695700E+00, 0.14823800E+01, 0.48141200E+00, 0.34420400E+00, -.18018300E+00, 0.13795000E+01, 0.12937400E+00, -.12531300E+00, 0.28011100E+00, 0.73389300E+00, -.87970100E-01, -.23818700E+00, -.21879600E+00, 0.18930200E-01, -.23901800E+00, -.97695900E-01, 0.29448300E+00, -.41402100E+00, 0.47973700E+00, -.23999700E+00, 0.82778300E+00, 0.48783300E+00, -.15418700E+01, 0.14068900E+00, 0.31036000E+00, -.39297700E-01, 0.26838500E-01, 0.29601500E+00, 0.33103400E+00, -.71484000E+00, -.34192100E+00, 0.74147200E+00, 0.13247900E+00, 0.39140600E+00, 0.19379900E+00, 0.42147800E+00, -.92672600E-01, -.22676500E+00, 0.31802600E+00, -.14683100E+00, -.27970100E-01, 0.11955000E+00, -.21381600E+00, -.11081000E+00, 0.24427800E+00, 0.30987700E+00, -.48300700E-01, 0.53147600E+00, -.50855400E+00, -.12362300E+00, 0.29419600E+00, -.74123000E+00, 0.11204900E+01, 0.31491800E-01, 0.48277900E+00, 0.14245200E+00, -.77538800E-01, -.33034400E-01, 0.23385500E+00, 0.82992700E-01, -.60698700E+00, -.22398100E+00, -.48589100E+00, 0.32914300E+00, 0.39037700E+00, 0.25039700E+00, 0.26585300E+00, -.30421200E+00, 0.35148000E+00, -.10272800E+01, 0.30841300E-01, 0.98632600E-01, -.12615800E+00, 0.24841500E+00, -.13305500E+01, -.80246800E+00, -.34059800E+00, 0.92695800E-01, 0.47940400E+00, 0.19765200E-01, -.18375900E+00, -.13439600E+00, 0.14975400E+02, -.12756400E+02, -.14976300E+01, -.14081000E+01, 0.87289900E+01, 0.20155800E+01, -.63718400E+01, 0.75439300E+00, -.34923700E-01, 0.49665400E+01, 0.81803800E+00, 0.53968700E+01, -.59964600E+01, -.17918200E+01, -.31479400E+01, 0.61295900E+00, -.83506600E-01, 0.57789100E+00, -.66149400E+00, 0.42085900E+00, 0.29741400E+01, 0.41480700E+02, -.35132900E+00, -.34447500E+01, 0.34816200E+00, -.30145800E+00, 0.37829700E+00, 0.15564100E+01, 0.10234900E+01, -.50309600E+01, -.49376900E+01 },
            { 0.81311100E+01, 0.28548300E+00, -.24317100E+01, -.17027300E+01, -.10990200E+02, -.13345600E+01, -.29781400E+01, -.24346300E+00, 0.25504400E+01, -.18183500E+01, 0.16218800E+01, 0.14268500E+01, 0.11872100E+01, -.26866700E+01, 0.50809900E+00, 0.64903000E+00, -.23169900E+01, -.25163400E+01, 0.66304800E+01, 0.10369600E+01, -.48571400E+01, -.38260500E+01, -.24149400E+01, -.55537900E+00, 0.21967900E+00, -.20295600E+01, 0.14681900E+01, 0.31576500E+00, 0.59028500E+00, -.30859900E+00, -.30838400E+01, -.20523400E+01, -.14244300E+01, 0.84909900E+00, 0.32301900E+00, 0.73648700E+01, -.16776700E+01, 0.64982600E+00, 0.10193200E+01, -.42252200E+01, -.13849700E+02, 0.35658600E+01, 0.37878800E+01, 0.71997600E+01, -.43769900E+01, -.40499300E+01, 0.30316300E+01, -.67125700E+01, 0.11171400E+02, -.40386700E+01, 0.34694300E+01, -.20261200E+01, -.23471400E+01, -.72404500E+00, 0.10613600E+01, -.32575400E+01, 0.23762400E+01, -.13674300E+01, 0.10341500E+01, -.13139500E+01, -.64219000E+00, 0.51025400E+00, -.53069200E+00, -.14712000E+00, 0.13139700E+01, -.16895500E+01, -.37918700E+01, -.10278500E+01, -.72091500E+00, 0.12983100E+02, -.12135200E+01, -.72502700E+00, 0.11475600E+00, 0.11768900E+00, 0.30881900E+00, 0.57976700E+00, 0.13489000E+01, -.21676300E+00, -.10851100E+01, -.38999800E+00, -.10919800E+01, -.96580500E+00, 0.15877400E+01, 0.76434200E+00, -.12408000E+01, 0.72760300E+00, -.73335500E+01, 0.80486300E+00, -.11485400E+02, -.59391800E+00, -.22538500E+00, -.28354100E+00, 0.51335500E+00, -.20806100E+01, -.52514500E+00, -.14083400E+00, -.33019400E+00, -.45994100E+00, -.72553100E+00, -.15150700E+00, -.86842800E+00, 0.62674000E+00, 0.19200600E+01, 0.52386700E+01, 0.62621200E-02, -.24819200E+01, 0.65171500E+00, 0.13962800E+01, -.76625000E+01, -.93425700E-01, 0.18471400E+01, -.20449700E+02, -.28625600E+00, 0.13384800E+02, 0.11803100E+01, -.54945700E+00, -.19420900E+02, 0.10961900E+01, 0.85116100E+00, 0.36746900E+00, -.13998500E+01, 0.30008100E+01, -.59569800E-01, 0.19371300E+01, 0.62196200E-01, -.65540800E+00, -.28868300E+01, 0.98730400E-01, 0.25040100E+01, -.90621400E+00, 0.58045400E-01, 0.90851600E+00, -.12325300E+01, 0.60047200E+00, 0.68009200E+00, -.11998000E+01, 0.75542700E-01, -.83995700E+00, 0.96956900E+00, -.11561100E+01, 0.34621300E+00, -.13404400E+00, 0.33135800E+00, 0.84711900E+00, 0.58134200E-01, 0.32211000E+00, 0.33619200E+00, 0.44435700E+00, -.15974400E-01, -.17151300E+01, -.15048100E+00, 0.14624000E-01, 0.59027300E-01, 0.73175700E+00, -.55138300E+00, -.53140200E+00, 0.82179300E+00, -.18381100E+00, 0.25914400E+01, -.40133600E+00, -.14928400E+01, 0.31304800E+00, 0.34703600E+00, -.67853100E+00, 0.11834500E+01, -.35801700E+00, -.43402800E+00, -.52132800E+00, -.15090700E+01, 0.28213500E+00, 0.15916500E+01, 0.13068600E+00, 0.42539900E+00, -.44124700E+00, 0.90074000E-01, 0.92568800E-01, -.61676400E+00, 0.61268000E+00, -.35598200E+00, 0.18386600E+00, -.10908200E+00, 0.61244600E+00, 0.63009600E+00, -.19585600E-01, 0.11434000E+00, -.38375800E+00, 0.71872600E+00, -.48717400E+00, 0.12808500E+01, -.32193200E+00, 0.15597500E+01, -.62899400E+00, -.16112000E+01, 0.73395900E-01, -.82953400E-01, 0.52466800E+00, 0.14137200E+01, -.26857500E+00, -.71785700E+00, -.29410800E+00, 0.52511100E+00, -.33385500E+00, -.30212400E+00, -.12435000E+00, -.27521400E-01, 0.55017200E+00, -.91000800E-01, 0.76222900E+00, -.29601700E-02, -.12907000E+01, 0.49913100E+00, -.21663400E+00, 0.10885600E+01, -.48184600E+00, 0.60495000E+00, -.29620300E+00, -.14312600E+01, -.20995900E+00, 0.24165600E+00, 0.94906100E-01, 0.22019700E+00, 0.13939900E+02, -.24407400E+02, -.22852600E+02, -.26141900E+01, -.21116900E+01, -.21720800E+01, -.77718900E+00, -.15469400E+00, -.15043000E+02, -.93702900E+00, 0.17860700E+00, -.17628800E+01, 0.11120700E+01, 0.72164800E+01, -.98407300E+00, -.18413500E-02, -.97204800E+00, 0.13321000E+01, -.37434300E+00, -.37524600E+01, -.76275600E+01, 0.27239300E+01, 0.59347200E+01, -.10001800E+01, 0.10095800E+01, 0.20123200E+01, -.87654400E+00, 0.19436800E+01, 0.65834200E+00, -.10418700E+02 },
            { -.11892800E+01, -.43701800E+00, 0.50048900E+00, 0.22250100E+00, 0.15938600E+01, 0.20030700E+00, 0.57226600E+00, -.79781700E-02, -.12128000E+01, 0.39528500E+00, 0.47633300E+00, 0.48114000E+00, 0.34492400E-01, -.95272200E-01, 0.26076600E-01, -.16001800E+00, 0.13317600E+00, -.77834300E+00, -.28920500E+00, 0.11549500E+00, 0.13493600E+01, -.32273300E+00, -.66060600E+00, 0.11944300E+01, 0.11347400E+00, -.12819800E+00, -.16562400E+00, 0.37691100E+00, -.14138800E+00, -.17409500E+00, -.15487900E+00, 0.47433900E+00, -.15785100E+00, 0.26039700E+00, 0.10016200E+00, -.58560900E+00, 0.73144900E-01, -.32613400E-01, -.32905700E-01, 0.41156500E+00, -.71170100E+00, -.33995700E+00, -.57314000E+00, -.67125700E-01, -.98530300E-01, -.61846500E+00, -.35897300E-01, 0.10618000E+00, -.58103300E+00, -.31448200E+00, 0.83207200E+00, -.60200200E+00, 0.20266600E+00, -.28279900E+00, -.62788700E-02, -.96554700E+00, 0.22885700E+01, -.73596300E-01, -.56230000E+00, 0.15002000E+00, -.20208100E+00, -.32532800E+00, 0.11938400E+00, -.18023900E+00, 0.45137700E+00, -.87349100E+00, 0.23126500E+00, -.18015500E+00, 0.19611200E+00, -.30517400E+01, -.18602400E+00, 0.41702600E+00, 0.44155500E+00, -.16332100E+00, 0.73840700E-02, -.23640600E+00, 0.27468700E+00, 0.10171400E+00, -.47519700E+00, -.29480200E+00, 0.20317900E+00, -.44569100E+00, 0.23107500E+00, 0.90889900E-01, 0.26741400E-01, 0.17206000E+00, 0.23629000E+00, 0.56564400E+00, 0.12842200E+01, 0.17725300E-01, 0.61305500E-02, 0.17547800E-01, 0.57413100E-01, -.53331500E+00, -.49266300E+00, 0.18319800E+00, 0.42904700E-01, 0.87205500E+00, -.36129000E+00, -.12173600E+00, 0.80311500E-01, 0.15913500E+00, 0.93544800E+00, 0.34531300E+00, -.97248200E-01, 0.81982000E-01, -.43876000E+00, 0.79473300E+00, 0.56449700E+00, 0.77748900E-01, 0.14045100E+00, -.84245200E-01, -.34322000E+00, -.17888000E+00, -.17090800E+01, -.14397200E+00, 0.14441100E+01, -.91382800E-01, 0.17576900E+00, -.36240200E+00, -.11752700E-01, 0.12173700E+00, 0.26017000E+00, 0.19118200E+00, -.51555600E+00, 0.55735000E+00, 0.75949800E+00, -.53931200E-01, 0.43323300E+00, 0.81777400E-01, 0.16848100E-01, -.18394400E+00, 0.26166900E+00, 0.16250900E+00, 0.14530300E+00, -.34745200E+00, 0.27147100E+00, -.15552300E+00, 0.31596200E+00, 0.14880200E-01, -.12437000E+00, -.26484700E-02, 0.35642800E-01, -.11977900E+01, 0.13703500E-02, -.74012600E-01, 0.65735600E-01, -.29924000E+01, -.63665600E-01, 0.83931600E-01, -.77668700E-01, -.75041100E-01, -.62243400E+00, -.57980600E+00, -.13511400E+00, -.43728500E+00, -.55386400E-01, 0.22635600E-01, -.24317300E+00, 0.72722700E+00, 0.73794300E+00, 0.16480800E+00, -.16688000E+00, 0.40168000E-01, -.11701900E+00, 0.37473200E+00, -.15272300E+00, -.49235000E+00, 0.25640200E+00, 0.26823100E-01, -.11708900E+00, 0.13800900E+01, 0.77092000E-01, 0.97995400E-01, -.26393000E+00, 0.63063100E-01, 0.66831100E+00, -.43595200E-01, -.32633600E-01, -.14226600E+00, 0.72223300E-01, -.59467000E-01, -.10728200E+00, -.23724600E-01, 0.39986900E-01, -.10229700E+00, -.35650000E+00, -.14073100E+00, -.55385500E+00, -.26928400E+00, 0.10648000E-01, -.46431900E-01, 0.83759100E+00, 0.83564200E-01, 0.39171900E+00, 0.21633900E+00, 0.45273000E+00, 0.91161500E-01, 0.73439100E+00, -.35247100E-01, 0.52276200E-01, 0.18143800E+00, 0.65984900E+00, -.74812000E-01, -.14858500E+00, -.24536600E+00, 0.12325500E+00, -.38492700E+00, -.75994400E-01, 0.27798600E-01, 0.69100800E-02, -.73518400E-01, -.88962300E-01, -.53311500E-01, -.17268500E+00, 0.91822800E-01, -.24392100E+00, 0.40047800E-01, 0.12206700E-01, 0.11223100E+00, 0.34150600E+00, -.39740600E-01, 0.67385700E+01, 0.15068300E+01, 0.12645500E+01, -.55418500E+00, -.19404500E+01, 0.16425000E+01, -.33126800E+00, -.60994400E+01, 0.19319400E+00, 0.10505100E+01, -.19357700E+01, 0.14838400E+01, -.13323900E+01, -.43370600E+00, -.13244700E+00, -.52220700E+00, -.19550200E+01, 0.19448600E+01, -.28143400E+00, -.12018800E+02, -.28034800E+00, -.14704100E+01, -.77893300E+00, 0.51265900E-01, -.40732800E-01, -.28038800E+01, 0.14594800E+00, -.77406200E+00, -.42513600E+01 },
            { -.76350900E+01, -.59921400E+00, 0.23656100E+01, 0.11332600E+01, 0.61381800E+01, 0.51467800E+00, 0.21036800E+01, 0.40268600E-03, -.18220200E+01, 0.12060100E+01, -.23874400E+01, 0.73394600E-01, -.52778800E+00, 0.24362200E+01, -.17842500E+00, -.59266700E+00, 0.17244500E+01, 0.13494700E+01, -.34354800E+01, -.55734000E+00, 0.17113600E+01, 0.35685900E+01, 0.16133800E+01, 0.24108500E+01, 0.33638200E+00, 0.12881700E+01, 0.25519400E+00, 0.18002500E+00, -.34655300E+00, -.88610200E+00, -.15234400E+01, 0.38034500E+00, 0.55870100E-01, -.11603600E+01, -.91612400E+00, -.97808400E+01, 0.92842400E+00, -.35039900E+00, -.58671500E+00, 0.24281300E+01, 0.62183100E+01, -.16128700E+01, -.16770900E+01, -.27512300E+01, 0.22317200E+01, 0.57057000E+00, -.15810000E+01, -.16597600E+01, -.18196400E+01, 0.25650900E+01, 0.21761900E+01, 0.12935700E+01, 0.18586000E+01, 0.76537300E+00, -.10761600E+01, 0.19430700E+01, -.51978600E+00, 0.49585400E+00, -.45556600E+00, -.50065400E+00, 0.13089500E+01, -.98333200E+00, 0.21989100E+00, 0.38582800E-01, -.23375300E+00, 0.12049600E-01, 0.16397800E+01, -.50202200E+00, -.51314600E+00, 0.30540600E+01, 0.73971100E+00, -.33754100E+00, -.73385000E+00, 0.32931600E-01, -.33604400E-01, 0.60360100E-01, 0.24194500E+00, 0.11290400E+01, -.70135100E-01, 0.36510500E+00, -.83388400E+00, -.15971600E+01, 0.10583000E+01, 0.10706700E+00, -.12215300E+00, 0.76037800E+00, -.10191600E+01, 0.15194700E+01, -.26916500E+01, -.20991200E+00, -.42619600E+00, 0.89372300E-01, 0.40536200E+00, 0.48502800E+00, 0.41107700E+00, 0.13678900E+01, 0.90087400E+00, -.46268300E-02, 0.36663400E+00, -.27511300E+00, -.98028100E-01, 0.52218100E+00, 0.26966200E-01, -.11940900E+01, 0.62894200E+00, 0.10525800E+01, 0.22260800E+01, -.26829400E+01, -.16097400E+01, -.63501500E+00, 0.26322400E+00, 0.42106100E+01, -.11912600E+01, -.16642200E+00, -.56901800E+01, -.29463400E+00, 0.91349600E+01, -.41239800E+00, 0.59205000E+00, -.71551200E+00, 0.33463500E+00, -.11084000E+01, -.38166700E+00, 0.23990000E+00, -.25937100E+00, 0.98194900E+00, 0.24275800E+01, 0.52932300E+00, -.60695800E+00, 0.68981100E-01, -.10371700E+00, -.67125200E+00, -.22943200E+00, 0.19995400E+01, 0.63126700E+00, 0.23775900E-01, 0.28165900E+00, -.10033400E+01, -.40695600E-01, -.40148900E+00, -.35407800E+00, -.10453300E+00, 0.12150100E+00, -.66735000E+00, 0.70121400E-01, -.29071500E+00, 0.34627400E+00, -.37302700E+01, -.14796000E+00, 0.15379000E+01, -.19741300E+00, 0.33692200E+00, -.27021100E+00, -.20585300E+00, 0.30623700E+00, -.25516900E+00, 0.45518900E+00, 0.81632900E-01, 0.74787500E+00, 0.16296200E+01, 0.74797400E-01, -.20596800E-01, -.17698500E+01, -.13144800E+00, -.38311600E+00, 0.85107900E-01, 0.50255500E-01, 0.42934300E+00, 0.32305000E+00, 0.18113200E+00, -.86584500E+00, 0.51778600E+00, -.11121300E+00, 0.92154400E-01, 0.72921600E-01, -.59748400E+00, -.52388400E+00, -.29344600E+00, -.17785800E-01, -.19885100E+00, 0.10469700E+00, 0.49641400E-01, -.35014600E+00, 0.38288600E-01, -.12463300E+00, -.20487700E-01, -.31178200E+00, -.24740800E+00, -.73740000E+00, 0.71742300E-01, 0.56865500E+00, 0.25787200E-01, 0.38528000E+01, 0.10824200E-01, 0.13943800E+00, 0.31294300E+00, 0.25163700E+00, 0.27787300E+00, 0.15737600E+01, 0.26419100E-01, -.15640500E+00, -.16930500E+00, 0.72368600E+00, 0.21287800E+00, -.10008300E+00, -.39859900E+00, 0.12759000E+00, -.70444900E+00, 0.51488100E-01, 0.16225900E+00, 0.17981900E+00, 0.73857800E-01, -.13390300E-01, 0.34708300E+00, 0.49163100E-03, 0.27580400E-01, 0.74253000E-01, 0.49234100E+00, -.25012000E+00, -.65343900E-01, -.38599200E-01, 0.30532900E+00, 0.29873500E+01, 0.27734600E+02, -.33893300E-01, 0.18636200E+01, 0.54828000E+01, -.38400400E+01, 0.62348500E+00, 0.20895500E+02, -.70097900E+00, -.45048000E+01, 0.59416600E+01, -.38174600E+01, 0.93215500E+00, 0.14561500E+01, 0.18936200E+00, 0.15927500E+01, 0.22208000E+01, -.33639400E+01, 0.33343700E+01, 0.55792300E+02, 0.77319800E+00, 0.23022200E+01, 0.22159100E+01, -.38415600E+00, 0.19344100E+01, 0.68421200E+01, 0.34168000E+01, 0.19387600E+01, 0.21124200E+02 },
            { -.14918300E+01, -.18886600E+00, 0.22976500E+00, 0.79559100E+00, 0.33354100E+01, 0.34473200E+00, 0.78553900E+00, -.12613100E+00, -.17118100E+01, 0.43873000E+00, 0.42822700E+00, -.82026200E+00, -.86265900E+00, 0.10879200E+01, -.13086400E-01, -.52615500E-01, 0.18671000E+00, 0.30860100E+00, -.13685800E+01, 0.33029100E+00, 0.13596700E+01, 0.97996800E+00, -.44746300E+00, 0.32624100E+01, -.27712100E+00, -.41572300E-01, -.63230400E+00, 0.30464600E+00, -.29175600E+00, -.15091900E+00, 0.36761300E+00, 0.90913500E+00, 0.20623000E+00, 0.48815800E+00, 0.86311100E-01, -.32430600E+01, 0.26193400E+00, -.99124600E-01, -.18129300E+00, -.26618000E+00, 0.53956300E+00, -.30187300E+00, 0.13398400E+00, -.96156000E+00, -.13666000E+00, 0.62677800E+00, 0.13301500E+00, 0.11818600E+00, 0.12099600E+00, -.97113000E+00, 0.13886200E+00, -.19764700E+01, 0.19644200E+00, 0.44602600E+00, 0.93548200E-01, -.30499900E+00, -.28230400E+00, -.49119300E-01, 0.12560800E+00, 0.15048000E+00, -.51512100E-01, -.38909200E+00, -.14083100E+00, 0.26470100E+00, 0.75401900E-02, -.53895200E+00, -.18187300E+00, -.95886600E+00, 0.93247900E+00, -.94822500E+01, 0.26658200E+00, -.55543500E+00, -.21616000E-01, -.64805200E-01, -.80584800E-01, -.43116900E+00, -.31099600E+00, 0.71314600E-01, -.45473400E+00, -.12757700E+00, 0.12872100E+01, 0.71486600E+00, -.41282500E+00, 0.21528900E+00, 0.22251900E+00, -.34141100E+00, -.28271700E+00, -.82063700E+00, -.22731800E+00, -.33510800E-01, 0.16403300E+00, -.25572400E-01, -.24635200E+00, -.55791300E-01, -.29988000E+00, 0.10208700E-01, -.61136900E-01, 0.42684300E+00, -.12046700E+00, 0.11267000E+00, 0.75844700E-01, -.28586600E+00, 0.80118500E+00, 0.14973000E+00, -.47765900E+00, 0.83616000E+00, -.14702400E+00, 0.22801200E+00, 0.68470800E+00, 0.57585200E-01, -.32918800E+00, 0.38383700E+01, 0.68115900E+00, 0.61554900E-01, -.30780400E+00, -.17795600E+00, 0.55788100E+01, -.35563800E+00, -.45474000E-01, 0.12138100E+00, 0.21833500E+00, -.70733200E+00, -.12793800E+00, -.10430000E+00, 0.92558300E-01, -.11834700E+00, 0.39456200E+00, -.50906200E-01, -.54903200E+00, 0.19384700E+00, 0.22575700E-01, -.10943600E+01, 0.24999300E-01, 0.24487800E+00, 0.73982300E+00, 0.70186500E+00, 0.58347800E-01, 0.15758000E+00, -.64100200E-01, 0.34606700E+00, 0.37326200E+00, -.23997000E-01, -.47505700E-01, -.23791500E+00, -.91489700E-01, -.29315200E-01, 0.69788000E-01, -.20170000E+01, 0.30442200E-01, 0.19642100E+00, -.58395200E-02, -.75538000E-01, 0.13926400E+00, 0.19919500E+00, 0.10356700E+00, 0.14072400E+00, -.25438100E+00, 0.26446200E+00, 0.31484200E+00, 0.11132400E+00, 0.16973800E+00, -.79000200E-01, 0.73531200E-01, 0.18397500E+00, -.15662800E+00, 0.17943700E+00, -.20227100E+00, 0.14655500E+00, 0.24304000E+00, -.47856900E-01, -.11555800E+01, 0.98320500E+00, -.66038100E-01, -.24540300E-02, -.88343500E-01, -.11274400E+00, 0.76557000E-01, -.43565500E+00, 0.12862000E-01, -.10095000E+00, 0.51909500E-01, -.81221500E-01, -.10531500E+00, 0.98072700E-01, 0.55072900E-01, -.26048500E+00, 0.23803800E+00, -.20283200E+00, -.78745400E-01, 0.58102700E-01, 0.41931000E+00, -.38966000E-01, 0.21793400E+01, -.96198300E-01, 0.26307700E+00, 0.26888200E+00, 0.46515100E+00, 0.13429300E+00, 0.54425800E+00, -.21608800E-01, 0.15933900E-01, 0.12051000E+00, 0.34898500E+00, -.44047100E-01, 0.26779500E-02, -.14863400E+00, 0.56803800E-01, -.79376100E-01, 0.13840900E-01, 0.23999800E+00, -.25887100E+00, -.43134900E-01, -.41013600E-01, 0.62602400E-01, -.14021700E+00, 0.74161800E-01, 0.10447800E+00, 0.58890800E-01, -.22323400E-01, -.91051100E-02, -.14426500E+00, -.18025900E+00, -.35181400E+00, 0.19515400E-01, 0.60626500E+01, -.45026600E+00, -.23964400E+01, 0.12541000E+01, -.29325100E+00, -.38140700E+01, 0.18218200E+00, 0.12325800E+01, -.23734100E+01, 0.11413500E+01, -.13938600E+01, -.34588500E+00, -.12494500E+00, -.41540000E+00, -.18516400E+01, 0.16484500E+01, -.31661300E+00, 0.86301200E+00, 0.30717300E+00, -.13445900E+01, -.64077500E+00, 0.38286200E-01, -.70597000E-01, -.25191700E+01, 0.86037900E+00, -.83114800E+00, -.52495600E+00 },
            { 0.80738500E+01, -.22738900E+01, -.31762600E+01, -.24493100E+01, -.10690700E+02, -.82147900E+00, -.34058400E+01, 0.10503400E+01, 0.33568900E+01, -.19915100E+01, -.16476900E+01, -.73357000E+01, -.28132100E+01, 0.13927400E+01, -.37483400E+00, 0.12928300E+01, -.38466800E+01, 0.27139700E+00, 0.52440100E+01, -.22743600E+01, -.47366200E+01, -.23059400E+00, 0.26855100E+01, 0.44355200E+01, -.31523200E+01, -.57370900E+00, -.38334200E+00, -.13972000E+01, 0.23027300E+00, -.10146600E+01, -.13731800E+01, 0.11574300E+01, -.23022600E+01, 0.31593400E+00, 0.11593000E+01, -.31886100E+01, 0.25435500E+01, -.96799200E+00, -.15881000E+01, 0.19332600E+01, 0.54686600E+01, -.28561200E+01, -.62415700E+00, -.36216500E+01, -.25629100E+00, -.12646900E+01, 0.21683700E+01, -.92021200E+01, 0.88469000E+01, -.26580900E+01, 0.32376600E+01, -.52524200E+01, 0.94712400E+00, 0.35858800E+00, 0.88930500E+00, -.20333600E+01, 0.55103700E+01, -.93836300E+00, -.16991800E+01, 0.14358400E+01, 0.20183400E+01, -.11808300E+01, 0.14977000E+01, 0.20155100E+01, 0.13270900E+01, -.62800900E+01, -.52228500E+01, 0.26784100E+01, -.40403400E+01, 0.17780500E+02, 0.52755200E+00, 0.51243600E+01, 0.19559600E+00, 0.59655400E+00, 0.15481000E+00, -.45558300E-02, 0.23171600E+00, -.52066500E+00, -.47214700E+01, -.20731300E+01, -.38892500E-02, 0.86523900E+00, -.24468400E+01, -.99853700E+00, -.17214000E+00, 0.39874700E+00, -.95634300E+00, -.26074700E+01, -.30584900E+01, 0.20842800E+00, 0.80119900E+00, -.46247800E+00, -.46624300E+00, 0.25126400E+00, 0.18623900E+01, -.36244900E+01, -.26654200E+01, -.56170600E+01, 0.84806100E+00, 0.15948000E+01, -.72398000E+00, -.75642300E+00, -.11218500E+01, 0.30855700E+01, -.24180300E+01, -.34500100E+01, -.50130900E+01, 0.47616100E+01, 0.88008500E+01, 0.11019100E+01, -.20796700E+01, 0.15488400E+01, 0.11558200E+01, -.10075400E+02, -.76282500E+00, -.72941700E+00, 0.19664200E+02, 0.82732100E+00, -.97723400E+00, -.95484600E+00, -.58865600E+00, 0.13828500E+00, 0.13203600E+01, 0.22794200E+01, 0.97371500E-01, -.56713500E+00, 0.10635900E+01, -.43120400E+00, -.11349700E+01, 0.54473800E-01, -.19809000E+00, -.11817700E+01, 0.12600900E+01, 0.13206000E+01, 0.28760200E+01, 0.13309700E+01, -.10449100E+00, 0.13214100E+01, -.72977500E+00, 0.38103300E+01, 0.25862400E+00, -.13024300E+00, -.79014000E+00, 0.41084500E+01, -.10034800E+01, -.11982600E+00, 0.77407600E-01, 0.47153100E+01, -.52793200E+00, -.47929600E+01, -.27903400E+00, 0.99011200E+00, 0.29940600E+01, -.16650700E+00, -.50094500E+00, 0.36089000E+00, 0.57762300E+00, 0.26078700E+00, 0.11710800E+01, 0.41270900E+00, 0.29571600E+00, -.13971500E+00, -.17927300E+01, -.13014000E+00, -.39442400E+00, -.50956100E+00, -.21392200E+00, 0.33076200E+01, -.72977300E+00, -.15127800E+01, -.36200200E+01, -.33801400E+01, -.17872600E+00, -.14512200E+00, 0.23357900E-01, 0.81146300E+00, -.11414800E+01, -.45736400E-01, 0.11848400E+00, -.41605800E+00, 0.39161100E+00, 0.23387600E+00, 0.23574800E+00, -.52047800E+00, -.35390700E+00, -.15193000E+01, 0.33064900E+00, -.15565000E+01, -.11648500E+01, 0.86825300E-01, -.97752400E+00, 0.40696000E+00, -.74593300E+01, 0.19938000E+00, -.19134700E+00, -.11848900E+01, -.38388800E+00, -.54810100E+00, 0.34364700E+00, 0.30452600E+00, -.46354600E+00, 0.98740900E+00, -.11242000E+01, -.72204900E+00, -.89698100E-01, -.17471900E+00, -.17864300E+00, 0.22718600E+00, 0.12663200E+00, -.98333900E+00, 0.13109900E+01, -.15779800E+00, 0.71961800E+00, -.17982000E+01, 0.17839900E+00, -.70910400E-01, -.27571000E+01, -.26199800E+00, 0.34530600E+00, 0.25536700E-01, 0.58720500E+00, 0.81181400E+00, 0.95936500E+00, -.82295200E+00, -.27527200E+00, 0.46385500E+01, 0.15209000E+02, -.94756500E+01, 0.25158600E+01, 0.41776200E+02, -.20441000E+01, -.10781600E+02, 0.15886300E+02, -.12370300E+02, 0.39978800E+01, 0.28057000E+01, 0.10808200E+01, 0.35563900E+01, 0.15281500E+02, -.13443000E+02, 0.16056000E+01, 0.14504600E+02, -.55025600E+01, 0.40155700E+01, 0.53307900E+01, -.88718100E+00, -.61590700E+01, 0.15576300E+02, -.14369400E+02, 0.68586200E+01, 0.34095100E+02 },
            { -.58536800E+01, 0.11688500E+01, 0.22467900E+01, 0.70060200E+00, 0.84104300E+01, 0.86287700E+00, 0.25834700E+01, 0.10163100E+00, -.18407600E+01, 0.17364200E+01, 0.12325000E+01, 0.22435000E+01, 0.15734400E+01, -.24898200E+00, 0.10439700E+01, -.12245800E+01, 0.31043800E+01, -.80055500E+00, -.38865000E+01, 0.90376700E+00, 0.40871600E+01, 0.21891800E+01, 0.39896200E+00, -.84434500E+00, 0.12455100E+01, 0.11183800E+01, -.35757800E+00, -.24696700E+00, 0.80777700E-01, -.13774300E+00, -.46544400E+00, -.44819500E+00, 0.14805700E+01, 0.24408300E+00, -.54696200E+00, -.57680100E+00, 0.13135200E+00, -.53565900E-01, -.35885300E-01, -.25619200E+01, 0.57757200E-01, -.56492600E+00, -.47695500E+00, -.37072400E+00, 0.54918400E+00, 0.12386800E+01, -.26791200E+01, 0.53857300E+01, -.16708300E+01, 0.17812700E+01, -.13159200E+00, 0.11290200E+01, 0.19038300E+01, -.42606100E+00, -.13287300E+01, 0.17974500E+01, 0.62987700E+01, 0.14166300E+00, -.84571400E+00, 0.17770300E+01, -.61584500E+00, 0.40214700E+00, -.49946600E+00, -.11650700E+01, -.11007400E+01, 0.18743600E+01, 0.47512900E+01, 0.11635800E+01, -.55376200E+00, -.16162500E+01, -.22547900E+00, 0.13097300E+01, 0.14442800E+00, 0.29969200E+00, -.36052700E+00, -.83431900E+00, -.10088600E+01, -.57710300E+00, -.15607900E+01, -.14718000E+01, 0.22033600E+00, -.53515300E+00, -.15564200E+01, -.40083200E+00, 0.71429500E+00, 0.70335000E+00, 0.43079300E+01, 0.11053800E+01, 0.78562700E+01, 0.22326300E+00, -.14624400E+00, 0.21601100E+00, 0.94980100E-01, 0.57361400E+00, -.11280500E+01, 0.16521300E+01, 0.91348700E+00, 0.31832800E+01, -.41155200E+00, -.66143300E+00, 0.54923900E+00, 0.36492300E+00, 0.34035700E+00, -.61009000E+01, 0.16343000E+01, 0.23422100E+01, 0.88868600E+00, -.46452600E+00, -.25505600E+01, -.32512100E+00, -.48464300E+00, 0.27789000E+01, -.60340200E+00, 0.68621600E+00, -.36925900E+00, -.19035500E-01, 0.37176800E+01, -.37784900E+00, -.20971400E+00, 0.18243200E+00, 0.21802000E+00, -.52924700E+00, -.50845800E+00, -.80990700E+00, -.48493800E+00, 0.76363100E+00, 0.13300600E+01, 0.28842100E+00, -.11735800E+01, 0.26945400E+00, -.94142800E-01, -.90176800E+00, 0.58533100E+00, 0.32839300E+00, 0.93922000E+00, 0.74478400E+00, -.13596200E+00, 0.47036800E+00, 0.80373100E-01, 0.44452500E+00, -.14729500E+00, 0.93414600E-01, -.13181000E+00, -.58638300E+00, 0.22923600E+00, -.66610600E-02, -.56189100E+00, 0.67239200E+01, -.10657800E+00, 0.14286900E+01, 0.29361100E+00, 0.29710200E+00, -.64391900E+00, 0.45158000E+00, 0.16917800E+00, -.18947700E+00, -.37091900E+00, -.36567100E+00, -.13486500E+01, 0.42074000E+00, -.99898300E+00, 0.22236300E+00, 0.44798700E+00, 0.17668900E+00, 0.48558100E+00, -.90634000E+00, 0.43283700E+00, 0.81019400E+00, -.42885400E+00, 0.76549400E-01, 0.12763800E+01, -.58738800E+00, 0.29794700E-01, 0.11680800E-01, 0.11562000E+00, -.91799200E-01, 0.37794100E+00, -.35782700E+00, -.64780100E-01, 0.85049900E-01, -.82872100E-01, 0.16111000E+00, 0.28177700E+00, -.15823900E-01, 0.28018600E-01, 0.30487300E+00, 0.17409500E+00, 0.16387700E+00, 0.12143700E+00, -.43842000E-01, 0.64059400E+00, -.40288500E+00, 0.15943200E+01, -.37479700E-02, -.23923700E+00, 0.51868100E+00, 0.33320100E+00, 0.49620800E-01, -.27016400E+00, -.39403400E-01, 0.15180700E+00, -.26178000E+00, 0.60441400E+00, -.28627800E-01, -.30450100E-01, 0.40154900E+00, -.11429500E-01, -.16445000E+00, -.11641800E+00, -.31105900E+00, 0.39325300E+00, 0.37497900E-01, 0.19007100E+00, 0.11706100E+00, 0.10663900E+00, -.10486700E+00, 0.55100500E-01, -.24175400E-01, 0.64490800E-02, 0.25055300E-01, 0.20939100E+00, 0.31362100E-01, -.19778000E+00, -.31877700E-01, -.11969000E+00, 0.48090900E+00, -.77001200E+01, 0.47754700E+01, -.11695100E+01, -.20919000E+02, 0.14639000E+01, 0.55454500E+01, -.81407200E+01, 0.58626300E+01, -.28596300E+01, -.76164000E+00, -.56528800E+00, -.12123800E+01, -.76183400E+01, 0.67986900E+01, -.69928400E+00, -.17105300E+02, 0.24899900E+01, -.27885500E+01, -.22527400E+01, 0.82271100E-01, 0.34033900E+01, -.82953800E+01, 0.76418600E+01, -.35881000E+01, -.17304500E+02 },
            { -.23720300E+01, -.18677300E+01, 0.22558300E+00, 0.15761500E+01, 0.71958000E+01, 0.99580400E+00, 0.10676300E+01, -.51476900E+00, -.22814300E+01, 0.79253800E+00, -.75694300E+00, -.77273000E+00, -.76607000E+00, 0.22077600E+01, -.73852900E+00, -.12421200E+00, 0.55252200E+00, 0.63076300E+00, -.12255600E+01, 0.17344000E+00, 0.15252700E+01, 0.66695300E+00, -.11388100E+00, 0.66968800E+00, -.11690300E+00, -.42614200E-02, -.69090300E+00, -.24483200E+00, -.45991700E-01, -.22497700E+00, -.11607400E+01, 0.10918000E+00, 0.54472800E+00, 0.11294900E+00, 0.11142300E+00, -.44503200E+01, 0.21781900E+00, -.80883300E-01, -.12095000E+00, -.13818100E+01, 0.10599600E+01, -.31317900E+00, 0.20536800E+00, -.87657800E+00, 0.94893600E-01, 0.13735900E+01, -.69983100E+00, 0.19632000E+01, 0.65896400E+00, -.30892700E+00, -.33142800E+00, -.14295200E+01, 0.74428200E+00, -.90050900E-01, 0.31856100E+00, 0.12146600E+00, 0.16975200E+01, -.19467000E+00, -.10273200E+00, 0.80791800E+00, -.44788800E+00, 0.37075000E+00, -.41897900E+00, 0.96516600E-01, -.40567800E+00, 0.51586300E+00, 0.43847300E+00, 0.62484300E+00, 0.57171000E+00, -.10739000E+02, -.14238900E+00, 0.15723500E+00, -.10706300E+00, -.14436100E-02, -.48635200E-01, -.34105200E+00, -.44866600E+00, 0.95320000E-01, -.53486100E+00, -.20831400E+00, 0.31351000E+00, 0.43467300E+00, -.34718900E+00, 0.10465400E+00, 0.30592000E+00, -.28476100E+00, 0.10788800E+01, -.42842400E+00, 0.21407300E+01, 0.47052700E-01, 0.73347200E-01, 0.45231100E-01, -.68970900E-01, -.14178400E+00, -.36243800E+00, 0.41706100E+00, 0.58949400E+00, 0.10460700E+01, -.79017800E-01, -.33755600E-02, 0.19252300E+00, -.24964300E-01, 0.29625100E+00, -.10374000E+01, 0.12060200E+00, 0.12976100E+01, -.90718500E-01, -.41781800E+00, 0.22291900E+01, 0.29085900E-01, -.85740100E+00, 0.80481500E+01, 0.55349600E+00, -.83195800E+00, -.26264400E+00, -.13509900E+00, 0.97327200E+01, 0.11874000E+00, -.18465100E+00, -.14042600E+00, 0.25535400E+00, -.30829400E+00, -.15044300E+00, 0.83674500E-01, 0.25335500E+00, 0.45849100E+00, 0.12812200E+01, -.48252100E-03, -.15037500E+01, -.65678800E-01, -.11222400E+00, -.11583600E+01, 0.65495800E+00, 0.12919900E+00, 0.22002800E+00, 0.42551800E+00, 0.59453900E-01, 0.83053600E-01, -.10607500E+00, 0.86983000E-01, -.52021100E+00, -.23611100E-01, -.51862400E-01, 0.18707800E+00, -.31525700E-01, 0.90074500E-02, -.24890600E+00, 0.13139100E+01, -.41617300E-01, -.49829600E+00, 0.64365500E-01, 0.72372500E-01, -.34335800E+00, -.25884800E+00, -.21794300E+00, -.57468300E+00, 0.22896300E-01, -.39050900E+00, -.10524500E+01, 0.77676300E+00, 0.32604300E+00, -.23597500E+00, -.18078100E+00, 0.96157500E-02, -.21465100E+00, -.47037200E+00, -.12299400E-01, 0.13129400E+01, 0.13203700E+00, -.24958500E+00, -.55133500E+00, -.50776700E+00, -.24004100E-01, 0.11682700E+00, 0.49758900E-01, -.39177500E+00, -.47667800E+00, 0.27999200E+00, 0.22441800E+00, -.81101800E-01, 0.55477700E-01, -.13121700E+00, -.21651000E+00, 0.12471600E+00, -.11767800E+00, 0.70722400E+00, -.23910700E+00, 0.36639600E-01, -.26338200E+00, 0.18468900E+00, -.11328800E+00, -.19906800E-01, 0.16971000E+00, 0.85459600E-01, -.17595300E+00, -.22612700E-01, -.32605400E+00, 0.62454400E-01, 0.23445400E+00, 0.88586600E-01, 0.41350900E-01, 0.78588200E-01, -.24274800E+00, -.34826100E-01, -.74821200E-01, -.49295300E-01, -.63314700E-01, 0.21047700E-01, 0.23360000E-01, -.41071900E-01, 0.13546100E+00, -.48517300E-02, 0.31540900E-01, 0.16870500E-01, -.85762100E-01, 0.84338400E-02, -.92118100E-01, 0.17777100E-01, 0.17428100E-01, -.29196000E-01, 0.57674600E-01, 0.22249900E-01, 0.10357200E+00, 0.46757500E-02, -.28418100E-01, 0.38772900E-01, -.43077300E+00, 0.20253700E+01, -.53843700E+00, -.91102000E+01, 0.63606800E+00, 0.86165500E+00, -.75613500E+00, 0.30230500E+01, -.16151300E+01, -.30854400E+00, -.26898500E+00, -.52842700E+00, -.34673600E+01, 0.31833100E+01, -.66784900E+00, -.10062800E+02, 0.14974900E+01, -.15947300E+01, -.10318900E+01, 0.50259900E-01, 0.15477700E+01, -.42716900E+01, 0.33986900E+01, -.83764800E-01, -.70075900E+01 },
            { -.48624800E+00, -.37359100E-01, 0.16944000E+00, 0.23632500E+00, 0.78879500E+00, 0.97801100E-01, 0.24250900E+00, -.42877000E-01, -.25580600E+00, 0.19980100E+00, 0.14491400E+00, 0.31934200E+00, 0.15977000E+00, -.93598000E-01, 0.89745800E-01, -.13220700E+00, 0.28652400E+00, -.37547000E-01, -.39831700E+00, -.68981600E-02, 0.34376200E+00, 0.83487400E-01, 0.13473200E+00, -.97482400E-01, 0.90947200E-01, 0.73829600E-01, -.88252200E-01, 0.21721900E-02, -.32758000E-01, 0.17036100E-01, -.37441000E-01, 0.11735500E-01, 0.65642100E-01, -.55125800E-01, -.42062900E-01, -.35989300E+00, 0.37343900E-01, -.14850700E-01, -.18851800E-01, 0.98313800E-01, 0.26646100E+00, -.10410500E+00, -.12424100E+00, -.12752300E+00, 0.10069500E+00, 0.84881300E-01, -.21516700E+00, 0.43071600E+00, -.35071600E+00, 0.21186000E+00, 0.54441800E-03, 0.18005700E+00, 0.18470300E+00, -.86822400E-01, -.66996200E-01, 0.10251100E+00, 0.41364300E+00, 0.13206000E-01, -.10473400E+00, 0.15585300E+00, -.47733800E-01, 0.26386700E-01, -.31091400E-01, -.32663500E-01, -.10248300E+00, 0.12889400E+00, 0.27236700E+00, 0.10472200E+00, 0.32456800E-01, -.46596900E+00, -.15003900E-01, 0.82047500E-01, 0.22871500E-01, 0.16046600E-01, -.30474300E-01, -.54392300E-01, -.89714200E-01, -.32433800E-01, -.61789500E-01, -.89267500E-01, 0.91878300E-01, 0.20172500E-01, -.12670200E+00, -.16698700E-01, 0.62520600E-01, 0.23071700E-01, 0.20976600E+00, 0.59940100E-01, 0.44956500E+00, 0.12370200E-01, 0.69261700E-02, 0.13193200E-01, -.16653400E-01, 0.32196500E-01, -.11398700E+00, 0.78725600E-01, -.80732300E-02, 0.22719800E+00, -.55694300E-01, -.44348100E-01, 0.49356300E-01, 0.65254100E-02, 0.68612100E-01, -.54351900E+00, 0.81168400E-01, 0.13993100E+00, -.13184500E-01, 0.10451400E-01, -.18827900E+00, -.29264600E-01, -.22815600E-01, 0.67895400E+00, 0.30519700E-01, -.16122200E+00, -.30868700E+00, -.19474100E-01, 0.27192900E+00, -.71458800E-01, -.35955800E-03, 0.22341500E-01, -.22797500E-01, -.79021200E-01, -.37531500E-01, -.14493100E+00, -.92264000E-01, 0.10869600E-01, 0.33971400E-01, 0.18765100E-01, -.67647900E-01, 0.18099200E-01, -.12603100E-02, -.65372000E-01, 0.13153300E-01, -.15661200E-01, 0.14055100E-01, 0.63283400E-01, -.14677000E-01, 0.36443500E-01, -.21389200E-04, 0.21086200E-01, 0.47501300E-01, 0.10966700E-01, -.71133700E-02, -.20400500E-01, 0.16545100E-01, 0.10684900E-02, -.35406300E-01, 0.46472300E+00, -.18288300E-01, 0.14535700E+00, 0.18426300E-01, 0.16344200E-01, -.30462300E-01, 0.78247500E-01, 0.36995500E-01, 0.21911200E-01, -.47466500E-01, -.71709700E-02, -.72781900E-01, 0.59912200E-01, -.52195800E-01, 0.28165500E-01, -.12040800E-01, 0.26415000E-01, 0.27307600E-01, -.69837700E-01, 0.14526300E-01, 0.95930300E-01, -.20626300E-02, -.22647900E-01, 0.98183600E-02, -.44135500E-01, 0.56940000E-03, 0.90661000E-02, 0.20511500E-01, -.37282600E-01, -.63200700E-02, -.13217500E-01, 0.35107900E-03, 0.48649200E-02, -.52213300E-02, 0.23833500E-02, -.24039200E-02, 0.10063200E-01, 0.10338700E-01, 0.44801400E-02, 0.23936800E-01, 0.32619800E-02, 0.74373500E-02, 0.10022400E-01, 0.52197000E-01, -.10452300E-03, 0.12219800E+00, -.81672500E-02, 0.31532700E-01, 0.47240900E-01, 0.11046700E-01, 0.11928200E-01, -.31790200E-01, -.64167200E-02, 0.22453400E-01, -.33028500E-01, -.58739200E-02, 0.31379400E-02, -.39524000E-06, 0.51775200E-01, -.40477000E-02, -.64624600E-02, -.13417800E-01, 0.20714800E-02, -.12550700E-02, 0.46995400E-02, -.13516200E-01, 0.38869100E-02, -.93439100E-02, 0.21528800E-02, 0.27346600E-01, -.28226000E-02, -.70217700E-02, -.28436200E-02, 0.75273500E-02, -.48113100E-02, 0.25739900E-01, 0.28956400E-02, 0.79316100E-02, 0.36024100E-01, 0.68654700E-01, -.29979600E-01, 0.24006800E+00, -.30154600E+00, 0.77990300E-01, -.34227400E-01, -.36153100E-02, 0.16684500E-02, 0.25469900E-01, -.34394900E-02, 0.59551200E-02, -.40067000E-02, -.45869700E-01, 0.25906000E-01, -.51605100E-01, 0.22105700E+00, 0.92802600E-01, 0.45301600E-01, -.14334200E-01, -.24477300E-02, -.53244900E-01, 0.14784000E-02, 0.62042900E-01, 0.89638300E-01, -.19542300E+00 },
            { -.35657400E+00, -.36622500E+00, -.56837500E-03, 0.17166300E+00, 0.76373100E+00, 0.95211800E-01, 0.17014000E+00, -.53763600E-01, -.21801300E+00, 0.18298100E+00, 0.84130600E-01, 0.21135000E+00, 0.89629300E-01, -.62442500E-01, 0.95682400E-01, -.11718500E+00, 0.18894500E+00, 0.40468700E-01, -.22987400E+00, -.11865800E+00, 0.22294800E+00, -.41797900E-01, 0.30410500E+00, -.28780300E+00, 0.28149400E-01, 0.61154000E-01, -.10512200E+00, -.50118400E-01, -.32790800E-01, -.20831900E-01, -.12475300E+00, -.45397200E-01, 0.45724800E-01, -.82457900E-01, -.45648400E-01, -.62587400E+00, 0.48067300E-01, -.19126500E-01, -.25721300E-01, 0.20463200E+00, 0.27405900E+00, -.10956500E+00, -.93501100E-01, -.14370800E+00, 0.76070600E-01, 0.82690100E-01, -.15287000E+00, 0.30907900E+00, -.29937700E+00, 0.91679400E-01, -.40439700E-01, 0.27631600E-01, 0.10287900E+00, -.50147500E-01, -.27300400E-01, -.34494900E-01, 0.48203400E+00, 0.20219900E-01, -.66318400E-01, 0.97533400E-01, -.21305600E-01, -.40587100E-01, 0.84912300E-02, -.21148100E-01, -.19689300E-01, 0.33920900E-01, 0.75140400E-01, 0.55446300E-01, 0.12587200E+00, -.12316800E+01, -.43698800E-01, -.26858600E-01, 0.38769000E-01, -.60510000E-02, 0.17733800E-02, -.29684800E-01, -.17058300E-01, -.13011200E-01, -.12346000E-01, -.19283200E-01, 0.83248500E-02, 0.17188900E-01, -.76731900E-01, -.56175400E-02, 0.61189900E-01, 0.21230500E-01, -.59173500E-01, 0.20361200E+00, 0.14574600E+00, 0.90436800E-02, 0.33497000E-01, 0.11612200E-01, -.97472900E-02, -.78413800E-01, -.14347900E+00, -.60182400E-01, -.17353100E+00, 0.59866800E-01, -.80245300E-01, -.84525400E-03, 0.60609600E-01, 0.26725500E-01, 0.74066800E-01, -.31334000E+00, -.59366700E-01, -.20202900E+00, -.29347400E+00, 0.35993400E+00, 0.23575300E+00, -.48174300E-01, 0.22216600E-01, 0.46582000E+00, 0.12516900E+00, -.11012600E+00, -.20935100E-01, 0.10136000E-01, -.22489300E-01, -.12763300E+00, -.27478900E-01, 0.27410000E-01, 0.42228600E-02, -.10599600E+00, 0.56821300E-02, -.15584700E+00, -.10962800E+00, 0.14880900E-01, 0.36682100E-01, -.12448200E-01, 0.80862500E-02, 0.22053300E-01, -.12462900E-01, -.52521200E-02, -.50400500E-01, -.22501800E-01, -.23249000E-01, -.37498600E-03, -.44779800E-01, -.38755700E-02, -.14476300E-01, -.78680600E-01, 0.91337200E-01, 0.47981300E-01, 0.18050500E-01, -.12905000E+00, 0.51719400E-01, -.24007800E-01, -.48785600E-01, 0.18207200E+00, -.59232500E-02, 0.17074400E+00, 0.13044400E-01, 0.29852000E-01, -.37126700E-01, 0.39558000E-01, 0.79107900E-01, -.39489900E-01, -.42610200E-01, 0.25502500E-01, 0.86678000E-01, 0.24385200E-01, 0.30534600E-01, 0.17522700E-01, -.30991900E-01, -.16962700E-01, -.66219000E-02, -.75735200E-01, 0.19373800E-01, 0.34044000E+00, 0.19587300E-01, -.19795400E+00, -.51413600E+00, -.49245200E+00, -.75887900E-02, 0.28432600E-01, 0.30267900E-01, -.70248100E-01, -.87370000E-02, 0.44393300E-01, 0.68204000E-02, -.75340400E-02, -.13233500E-01, 0.28473800E-01, 0.14391400E+00, 0.17037800E-01, -.14394100E-01, -.69179000E-01, 0.23506200E-01, -.98149500E-01, -.87289800E-02, 0.36025900E-01, 0.15278300E+00, 0.70277100E-01, 0.22265400E+00, -.64564400E-01, 0.20482600E+00, 0.93364400E-01, 0.72070600E-01, 0.15040000E-01, 0.33398200E-01, 0.22115900E-01, 0.26731300E-01, -.26657800E-01, -.21231700E-01, -.16752000E-01, 0.13806900E-01, 0.10809400E+00, -.33694700E-02, -.41361700E-01, -.28272100E-01, 0.36567700E-01, 0.23641500E-01, 0.17054400E-01, -.99657400E-04, -.31646000E-01, -.12025100E-01, 0.75336700E-02, -.63638500E-01, -.63405700E-02, -.13642500E-01, 0.96283400E-03, 0.69623100E-01, -.37599800E-03, -.56267700E-01, -.12569700E-01, -.69613800E-01, -.91229100E-02, 0.53630600E-01, 0.79730500E-01, 0.39585300E-01, 0.15543500E+01, 0.77344300E+00, -.17234500E+00, -.65255900E-02, -.42376300E+00, 0.93601300E+00, -.73652400E-02, 0.20629800E-01, -.53165900E-01, 0.39816100E+00, -.42944600E+00, 0.45350500E+00, -.89434700E+00, -.25343600E+00, 0.10751400E+01, -.17055900E+00, 0.19049100E+00, 0.32340400E-01, 0.48744600E+00, -.50701000E+00, -.51147700E-01, 0.10808400E+01 },
            { 0.55681900E-02, 0.54713200E-02, 0.25392700E-02, 0.90848700E-01, 0.55129800E-01, 0.67998700E-02, 0.13773500E-01, -.24574600E-01, -.34096500E-01, 0.17207900E-01, 0.15744000E-01, 0.28675500E-01, 0.35220900E-01, -.23680600E-01, -.90764300E-02, -.11560100E-01, 0.30753200E-01, 0.93881700E-02, -.59802400E-01, -.10918600E-01, 0.20580900E-01, -.82445800E-02, 0.33311700E-01, -.50129100E-02, 0.19540500E-02, -.48667700E-02, -.27456300E-01, 0.58949500E-02, -.14904900E-01, 0.16464000E-01, 0.65833600E-02, 0.19733200E-01, -.14989500E-01, -.13543700E-01, 0.37344100E-02, -.67659500E-01, 0.53072900E-02, -.20957500E-02, -.28861400E-02, 0.93035800E-01, 0.82976900E-01, -.15334100E-01, -.28867300E-01, -.24210300E-01, 0.19430200E-01, 0.65526400E-03, -.16667200E-01, 0.25991800E-01, -.82233300E-01, 0.47237700E-01, -.79068100E-02, 0.64194300E-01, 0.19849500E-01, -.20058500E-01, 0.10407800E-01, 0.98658300E-02, -.62554900E-01, 0.13998100E-02, -.10416800E-01, 0.10562600E-01, -.63934500E-03, 0.12430400E-01, -.49183800E-03, 0.19815300E-01, -.20182300E-01, 0.17306700E-01, -.57377700E-02, 0.15426000E-01, 0.13892700E-01, 0.12654500E-01, 0.38709500E-02, 0.50612600E-02, -.29702500E-02, 0.57213500E-03, -.46366000E-02, 0.59897500E-02, -.11459500E-01, 0.66671700E-02, 0.30642700E-01, 0.11416100E-01, 0.18052000E-01, 0.27091500E-01, -.31012600E-02, -.71303900E-03, -.31326800E-03, -.12860600E-01, -.22011100E-01, -.24168900E-01, -.34085600E-01, -.46358900E-03, 0.69857200E-02, -.26765000E-02, -.11842500E-01, 0.13366500E-01, -.49792700E-02, -.15441700E-01, -.23419800E-01, -.59968700E-02, -.38284800E-02, 0.26408800E-02, -.40186000E-03, -.13343900E-01, 0.29315600E-02, -.68034100E-01, -.12035000E-01, -.78955200E-03, -.34386400E-01, 0.89947800E-02, -.14631600E-02, 0.29440200E-02, -.36281200E-02, 0.20884700E+00, 0.22565200E-01, -.12202600E+00, -.13098300E+00, -.69956300E-02, 0.12734100E-01, -.13241800E-01, 0.28678400E-02, 0.51450200E-02, -.13046700E-01, -.11076800E-01, -.11875000E-02, -.37428200E-01, -.29140200E-01, -.19739700E-01, -.23381400E-01, -.11165500E-03, -.12771300E-02, 0.15218000E-02, 0.24583100E-02, -.47379700E-02, -.49513500E-02, -.20472000E-01, -.10856800E-01, 0.74153200E-02, -.10842900E-02, 0.95649700E-03, 0.61645600E-02, 0.28941900E-02, 0.15434100E-01, -.35116000E-02, -.93695600E-03, 0.13630600E-01, -.39923400E-02, 0.27070800E-02, 0.13721000E-02, 0.12014700E-01, -.43785200E-02, 0.21745600E-01, 0.83829600E-03, 0.34964700E-04, 0.88164100E-02, 0.25396900E-01, 0.70069800E-02, 0.14809300E-01, -.12325100E-01, 0.83771100E-02, 0.55085600E-02, 0.72752400E-02, 0.51046700E-02, 0.78540800E-02, -.99606800E-02, 0.89555600E-02, 0.78239800E-03, -.59035300E-02, -.50269700E-02, 0.11070700E-01, 0.10096200E-01, -.16758700E-01, -.29334300E-01, -.91073600E-02, -.56160100E-03, 0.28558400E-02, 0.73057300E-02, -.12715600E-01, -.15361300E-01, 0.27342300E-02, 0.52571000E-03, 0.23496000E-02, -.55826700E-03, -.27832600E-02, -.12738800E-01, 0.54818000E-02, 0.41906000E-02, -.92577200E-02, 0.77480200E-02, -.37320000E-02, 0.34236200E-03, 0.38130400E-02, 0.18521300E-01, 0.29748200E-02, 0.35212900E-01, -.16881200E-03, 0.13118700E-01, 0.10940500E-01, 0.12114000E-02, 0.54195700E-02, -.37967800E-02, -.32171800E-02, 0.94072200E-02, -.10626600E-01, -.10772400E-01, 0.20928800E-02, 0.58929400E-03, 0.14978600E-01, -.10469300E-02, 0.97846600E-03, -.34199900E-02, 0.86674700E-02, -.11665700E-01, 0.15472100E-02, -.10706900E-01, 0.21645700E-02, -.43572100E-02, 0.21425000E-02, 0.16228600E-01, -.51561200E-03, -.31276500E-02, -.23924700E-02, -.22717300E-02, -.27821800E-02, 0.21347100E-01, 0.12757100E-02, 0.78273900E-02, 0.25383500E-02, -.14168500E-02, -.16383300E-01, 0.25436500E-01, -.10588000E+00, 0.91098000E-01, -.34542600E-01, 0.73521000E-03, -.41498000E-01, 0.11941600E+00, -.70566100E-02, 0.23507900E+00, -.11387000E-01, 0.20542500E-01, -.36618500E-01, 0.25207300E-01, -.43959600E-01, 0.19519400E-01, 0.14751800E+00, -.30438600E-01, 0.24387500E-01, -.17350900E-01, 0.47315800E-01, 0.32165300E-02, 0.39777800E-01, 0.81081300E-02 },
            { -.64875700E+01, -.25653100E+00, 0.29840100E+01, -.11243200E+00, 0.91901600E+01, 0.11391900E+01, 0.31653700E+01, -.14838700E-01, -.29791600E+01, 0.17174800E+01, 0.68150200E+00, 0.21370600E+01, -.35810900E+00, 0.19796100E+00, 0.22400300E+00, -.91535800E+00, 0.23650000E+01, 0.35730200E+00, -.55462700E+01, 0.71316400E+00, 0.68189300E+01, -.13831400E+00, -.13896300E+01, -.57093900E+01, 0.18206100E+01, 0.12816100E+01, 0.54904300E-01, -.35567900E+00, 0.19383600E+00, 0.61810300E-01, -.73173900E+00, 0.30496500E+00, 0.77899100E+00, 0.13087500E+01, 0.81754600E+00, -.43045500E+01, -.17312800E+00, 0.62300200E-01, 0.16374800E+00, -.31464700E+01, 0.14278400E+00, -.16608200E+00, 0.50702400E+00, -.15069300E+01, 0.66528600E+00, 0.28651400E+01, -.19227600E+01, 0.47045600E+01, 0.13155900E+01, 0.76261200E+00, -.23178100E+01, 0.65754700E+00, 0.20807500E+01, 0.14200300E+00, 0.18285600E+00, 0.18025500E+01, 0.22969800E+01, 0.67110400E-01, -.12179300E-02, 0.25384000E+01, 0.15072600E+01, -.45183400E+00, -.22262600E-01, 0.60150900E+00, -.15233000E+01, 0.25338200E+01, 0.67624200E+01, -.14310100E+01, -.50618300E+00, 0.41425700E+01, 0.90003500E+00, 0.21548900E+01, -.90632600E+00, 0.28427700E+00, -.70130400E+00, -.28322300E+01, -.60844000E+00, 0.31494200E+00, -.24274400E+01, -.46945900E+00, -.20299800E+01, -.23914300E+01, 0.29428300E+00, -.11350300E+01, 0.56410600E+00, 0.83563000E+00, 0.25133400E+01, -.37245000E+00, -.17878000E+01, 0.14751700E+00, -.21765200E+00, 0.12999200E+00, 0.79035100E-01, 0.18737300E+01, 0.32065300E+01, -.39673700E-03, 0.48439600E+00, -.55761900E+01, 0.14401200E+01, 0.12580600E+01, -.17286400E+00, -.57230000E+00, -.26417100E+01, 0.59207200E+01, -.22661300E+01, -.10875800E+00, -.35364400E+01, 0.34495100E+01, 0.13865800E+02, 0.64753700E+00, -.70125000E+00, 0.19233400E+02, 0.31497400E+01, -.90618400E+01, -.84952100E+01, -.12708000E+01, 0.22247900E+02, -.37534000E+01, -.13042400E+01, -.50908400E+00, -.24530500E+00, -.28973200E+01, -.77527800E+00, -.34193900E+01, -.24057400E+01, -.21241200E+01, -.21489400E+00, 0.87754500E+00, -.50251300E+01, 0.13371900E+01, -.34426200E+00, -.22276200E+01, -.18028100E+01, 0.21222800E+01, -.24645200E+01, 0.21156600E+01, 0.48980600E+00, 0.17321400E+00, -.27724200E+01, 0.38248200E+00, 0.56294000E+00, -.17798700E+00, -.18976500E+00, 0.21707100E+00, -.18791400E+00, 0.27455400E+00, 0.85788400E+00, 0.41374100E+01, 0.53564400E+00, 0.20483800E+00, -.22827200E-02, -.31106700E+00, -.76373400E+00, -.22181800E+00, 0.93110700E+00, 0.11880500E+01, 0.28553600E+00, -.46226500E+00, -.11212700E+01, 0.43783800E-01, -.16285800E+01, -.43233300E+00, 0.24895200E+00, -.12342900E+00, 0.85342500E+00, -.62412900E+00, 0.59429600E+00, -.85179300E+00, -.20189600E+01, 0.10115700E+01, 0.38991300E+01, -.18577800E+01, 0.38708300E+00, -.88184000E+00, 0.14448700E+00, 0.17188900E+01, 0.17382200E+01, 0.67999400E+00, 0.12052900E+00, 0.33719400E+00, -.41315100E-01, 0.13084700E+00, 0.15552700E+01, -.24879600E+00, 0.17235900E+00, 0.10733200E+01, -.48571400E+00, 0.76608400E+00, 0.56561400E+00, -.17418600E+00, -.12034800E+00, -.51346300E+00, 0.15550900E+01, 0.35500700E+00, -.91096600E+00, -.12118100E+00, -.30541200E+00, -.46231900E-01, -.13144000E+01, -.34991800E+00, 0.53493000E+00, -.62944000E+00, 0.68094000E+00, 0.64038200E-01, -.29774800E+00, -.45113300E-01, -.24025800E+00, 0.14452500E+01, -.12983900E+00, -.33062800E+01, 0.65568300E+00, -.42541500E+00, 0.91851400E-01, -.93079600E+00, 0.36384200E-02, 0.91926400E-01, -.40407500E+00, -.34684500E+00, -.61390000E-01, 0.91177000E-01, -.49279000E+00, 0.64748500E+00, 0.30866400E+01, -.71138200E+00, -.10687800E+01, 0.72036000E+00, -.37995400E-01, -.44246800E+00, -.43004200E+01, 0.54417200E-01, 0.17684800E+02, 0.11701700E+02, 0.41252200E-01, 0.54039900E+01, -.10642200E+02, 0.80746800E+00, -.47597800E+01, 0.36006700E+00, -.11516100E+02, 0.98283400E+01, -.19940700E+01, 0.93454200E+02, 0.77132500E+01, -.73399100E+01, 0.39207300E+00, -.11129000E+01, 0.96507100E+01, -.36287000E+01, 0.20043400E+02, -.11254200E+02, 0.13608900E+01 },
            { -.21261200E+01, -.17640500E+01, -.24733300E+00, 0.18144100E+01, 0.59533800E+01, 0.71447600E+00, 0.10145200E+01, -.60558600E+00, -.26684900E+01, 0.63671100E+00, -.17767100E+00, 0.28271900E+00, -.11675800E+00, 0.13439700E+01, -.90800700E+00, 0.96484500E-01, -.37992400E-01, 0.62315100E+00, -.21286800E+01, 0.47198700E+00, 0.21763400E+01, -.14041700E+00, -.76223200E+00, -.19659700E+01, -.29107500E-01, -.21881600E+00, -.86001700E+00, -.31895800E+00, -.25948500E+00, -.47905200E-01, -.75813100E+00, 0.66051500E+00, 0.47243700E+00, 0.10428600E+01, 0.84616500E+00, -.45680500E+01, 0.21635200E+00, -.86547600E-01, -.11064800E+00, -.20708700E+01, -.66275500E+00, -.17357200E+00, 0.44880800E+00, -.41513500E+00, -.26852900E+00, 0.14090200E+01, -.53815400E+00, 0.22176500E+01, 0.87448000E+00, -.75535600E+00, -.46172800E+00, -.14451100E+01, 0.40425400E+00, 0.18377000E+00, 0.71144900E+00, -.35493600E+00, -.30090300E+00, -.23629400E+00, 0.15468400E+00, 0.57073000E+00, -.72643700E+00, 0.61216000E+00, -.48169500E+00, 0.10124200E+00, -.42692600E+00, 0.79899000E+00, 0.77611000E+00, 0.75491700E+00, 0.89651500E-01, -.71674900E+01, 0.57293200E-01, 0.56489400E+00, -.21562500E+00, -.94713400E-01, -.39425600E-01, -.23501700E+00, -.52668100E+00, 0.34054600E+00, -.68967500E-01, -.10220500E-01, 0.54842200E-01, -.77909600E-01, 0.38252700E+00, 0.28494200E+00, 0.20054200E+00, -.26454000E+00, 0.32131200E+00, -.37429200E+00, 0.12665300E+01, 0.24862500E-01, 0.16915200E+00, -.15269600E-01, -.10076900E+00, -.69972600E+00, -.47410000E+00, 0.48007800E-01, 0.11819600E+00, 0.63064000E+00, -.21745800E+00, 0.15935100E+00, 0.10741300E+00, -.42672800E-01, 0.82277900E+00, 0.11023000E+01, -.47196000E+00, 0.52408400E+00, -.68238700E+00, -.16211900E+00, 0.33412500E+01, 0.84797100E-01, -.58273700E+00, 0.71043900E+01, 0.39861900E+00, -.15424800E+01, -.12301100E+01, -.20033800E+00, 0.97340400E+01, 0.16825900E+00, -.15335400E+00, -.27156700E+00, 0.30231500E+00, 0.18715000E+00, -.96080100E-01, -.21534700E+00, 0.10370600E+00, 0.50290000E+00, 0.14537900E+01, 0.56633400E-01, -.15792600E+01, 0.34287200E-01, -.87347100E-01, -.10204000E+01, 0.55215700E+00, 0.34206000E+00, -.86976500E-01, 0.40834000E+00, 0.17603800E+00, -.12513100E+00, -.13049700E+00, 0.14545000E+00, -.76934000E+00, -.85617300E-01, -.22770700E-01, -.33919800E-01, -.31968000E-01, -.64193300E-01, -.16714300E+00, 0.62673000E+00, -.11591100E+00, 0.30867600E+00, 0.33960900E-01, 0.14657600E+00, -.27162200E+00, -.24090500E+00, -.15777400E+00, -.40543800E+00, 0.11307700E+00, -.39823100E+00, -.81396400E+00, 0.83523800E+00, 0.67690000E-01, -.35898200E+00, -.26757400E+00, -.12958200E+00, -.14866800E+00, -.41997600E+00, 0.28404500E+00, 0.10980000E+01, -.54896600E-02, -.30931600E+00, 0.35193700E-01, -.21777000E+00, -.13601800E+00, 0.37490400E-01, 0.10996500E+00, -.20714700E+00, -.69128000E+00, 0.54253200E+00, 0.14049200E+00, 0.19852500E-01, 0.44598400E-01, 0.83248700E-01, -.38812400E+00, -.23200100E-01, -.11033200E+00, 0.14162800E-01, -.35721800E+00, 0.21248500E+00, -.24109200E+00, 0.10226800E+00, -.67550200E-01, -.12891700E+00, -.44102500E+00, 0.13844100E+00, -.41871500E+00, -.80174300E-01, -.39892600E+00, 0.30470900E-01, -.24941800E+00, 0.10313600E+00, 0.44924000E-01, 0.93928700E-01, -.16272500E+00, -.57710800E-01, -.59305900E-01, 0.29818600E-02, -.65582400E-01, 0.63201000E-01, 0.19373200E-01, -.17607300E-01, 0.90119500E-01, 0.37088800E-02, 0.67904100E-01, 0.28758600E-01, -.58638200E-01, 0.14183300E-02, -.41663300E-01, 0.22224000E-01, 0.30587800E-01, 0.17534200E-02, 0.45013500E-01, 0.48332100E-01, 0.23710300E+00, 0.32767700E-01, -.66364400E-01, 0.36561100E-01, -.38135700E+00, 0.83486800E+00, -.43694200E-02, 0.36857100E-01, 0.71415800E+00, -.61046500E-02, 0.12800600E+01, 0.14984000E+00, -.44542400E+00, -.15056500E-01, -.19842500E+00, -.11597100E-01, -.19810600E+00, 0.85220400E-01, -.10653000E+00, 0.12513600E+01, 0.10980500E+00, -.53566400E+00, 0.14841200E-01, 0.61342000E-01, 0.10425800E+00, -.16147800E+00, 0.39388600E+00, -.79271100E-02, 0.12552600E+00 },
            { 0.18967900E+01, 0.17314500E+01, 0.33000600E+00, -.26621800E+01, -.60966200E+01, -.72073000E+00, -.10592300E+01, 0.62584800E+00, 0.18568200E+01, -.74919400E+00, 0.71968700E+00, -.78920300E+00, -.12268000E-01, -.13235000E+01, 0.10189900E+01, 0.82509200E-01, -.44877500E+00, -.13906000E+01, 0.32282900E+01, 0.12886800E+00, -.25711400E+01, -.24648300E+00, -.58325700E+00, 0.35685700E+01, -.14458200E+00, -.17148800E+00, 0.77072800E+00, 0.31958200E+00, 0.33763700E+00, 0.24748600E+00, 0.48538000E+00, -.67794100E+00, 0.44025000E-01, -.57720200E+00, -.41056700E+00, 0.55659700E+01, -.47052500E+00, 0.18094000E+00, 0.26586800E+00, -.28407900E+00, -.13989100E+01, 0.53854200E+00, -.84631900E-01, 0.11898100E+01, 0.36469500E-02, -.12827200E+01, 0.90815700E+00, -.79417400E+00, -.15909800E+00, -.31784100E+00, 0.58666000E+00, 0.26037300E+00, -.12802000E+01, -.34639100E+00, -.26607900E+00, -.48797500E+00, 0.76999100E+00, 0.35932700E-01, -.47189800E-01, -.55871200E+00, -.15654000E-01, -.13575900E+00, -.16978700E+00, -.42067700E+00, 0.22105600E+00, -.15069500E+00, -.65465700E+00, -.25333900E+00, 0.21345100E+00, 0.59368000E+01, -.76102700E+00, -.62431100E+00, 0.60539500E+00, 0.17837500E+00, 0.66374600E-01, 0.66200600E+00, 0.28953100E+00, -.53912100E+00, 0.62198400E-01, -.33985800E+00, 0.38609100E+00, 0.23938900E+00, -.69086300E+00, -.16999800E+00, -.21794500E+00, 0.12543700E+00, 0.12747300E+01, -.50696400E+00, 0.45027800E+00, 0.81353500E-02, -.30661200E+00, 0.24594300E-01, 0.15014300E+00, 0.88741600E+00, 0.62439900E+00, 0.59973900E+00, 0.91735700E+00, 0.20982500E-01, 0.35108200E+00, -.21316600E+00, -.19504500E+00, -.20350600E-01, -.55377900E+00, 0.36003700E+00, 0.51308900E+00, 0.31513200E+00, 0.10391900E+01, -.39428400E+00, -.40051800E+01, 0.13143900E+00, -.29019900E-01, -.10266100E+02, -.60525000E+00, 0.14183400E+01, 0.31588700E+01, 0.23093000E+00, -.73717700E+01, 0.83742500E+00, -.33843600E-01, 0.30113900E+00, 0.47417800E-01, -.73812300E-01, 0.16900200E-01, -.74450100E+00, -.31139400E+00, -.73198900E+00, -.15191600E+01, -.11725800E-01, 0.96762400E+00, -.60771700E+00, 0.76932300E-01, 0.38798700E+00, -.25832300E+00, -.51646400E+00, -.49106300E+00, -.39263700E+00, -.29880300E+00, 0.26179400E+00, 0.10421900E+00, 0.21228200E+00, 0.43751600E+00, 0.13904800E+00, -.97471300E-01, 0.73789900E+00, -.12348000E+00, 0.85186400E-01, 0.20247000E+00, -.44431800E+00, -.20639600E+00, -.63118400E+00, -.12710900E+00, -.18392500E+00, 0.58769900E+00, 0.67642000E+00, 0.22236800E+00, 0.78694400E+00, 0.14478200E+00, 0.25472300E+00, 0.98187800E+00, -.11279000E+01, 0.24089300E+00, 0.66741700E-01, 0.42686900E+00, 0.43334900E-01, 0.12930500E-01, 0.35581700E+00, -.43998400E+00, -.44838800E+00, 0.51849000E-01, -.92994300E-01, -.29741800E+00, -.15806900E+00, 0.84445600E-01, 0.26489200E+00, 0.49242600E-01, 0.62644300E-02, 0.43683400E+00, 0.23743500E+00, 0.24750300E-01, 0.13185600E+00, -.45210100E-01, -.20274000E+00, 0.36302300E+00, 0.11012200E+00, 0.11109400E+00, -.31977000E+00, 0.19909900E+00, 0.13678300E+00, 0.94015200E+00, 0.52298500E-01, -.36460400E+00, 0.51749000E+00, -.21349700E+01, -.11647400E+00, 0.65041900E+00, -.23697200E+00, -.38658700E+00, -.69180500E-01, 0.91370900E-01, 0.31674000E-01, -.75280000E-01, -.86835500E-01, -.12994000E+00, 0.29866900E-01, 0.17898600E-01, 0.98083800E-01, 0.14651500E-02, -.10739100E+00, -.42028600E-01, 0.34156500E+00, -.16514000E+00, -.60155600E-02, -.23171100E+00, 0.19021300E+00, -.80275600E-01, -.82652000E-03, 0.31446200E-01, 0.27942900E-02, -.14460500E-01, 0.95036600E-02, -.28854100E-01, -.72829200E-01, -.62465200E+00, 0.41923500E-01, 0.13492000E+00, -.70102300E-01, 0.30325700E+00, -.35581800E+00, 0.25068700E+00, 0.23728400E+00, -.32402100E+01, 0.24045700E+00, -.98013600E-01, -.20294600E+01, 0.23257800E+01, -.37193300E-01, 0.19088000E+01, 0.78560500E-01, 0.38022200E+01, -.29791600E+01, -.29740600E-01, -.27575100E+02, -.24666100E+01, 0.19844200E+01, 0.27426600E+00, 0.21375400E+00, -.30303200E+01, 0.12971300E+01, -.63146900E+01, 0.10246100E+01, -.53349100E+00 },
            { 0.82049600E+01, -.16192900E+01, -.24713500E+01, -.13537300E+01, -.67644600E+01, -.66587000E-01, -.34791800E+01, 0.34884100E+00, 0.34850800E+01, -.26956000E+01, -.49471900E+01, -.72151300E+01, -.11868900E+01, 0.16537700E+01, -.21553300E+01, 0.18552300E+01, -.38288000E+01, 0.10008100E+01, 0.55314600E+01, -.69140600E+00, -.34075400E+01, -.24850500E+01, -.11132400E+01, 0.48178300E+00, -.10819900E+01, -.98390600E+00, 0.10983400E+01, 0.64116300E-01, 0.38824600E+00, 0.79236600E-01, -.11280200E+01, -.85724300E+00, -.18143200E+01, -.15006200E+01, 0.78878500E-01, 0.64713500E+00, -.98328600E+00, 0.40168000E+00, 0.53680000E+00, -.40668800E+01, -.19864200E+01, 0.21300300E+01, 0.16487900E+01, 0.15366600E+01, -.15394100E+01, -.12403500E+01, 0.29902000E+01, -.53220300E+01, 0.44649000E+01, -.24789100E+01, -.20535500E+01, -.10835500E+01, -.56683200E+00, -.33175200E+00, 0.98975000E+00, 0.87096500E+00, -.70100100E+01, -.35010500E+00, 0.27626400E+00, -.26483700E+00, 0.10849000E+01, 0.51937800E+00, 0.11881800E-01, 0.81008300E+00, 0.63315000E+00, -.11348600E+01, -.47810400E+01, 0.12104700E+01, -.28655600E+01, 0.14193800E+02, 0.17147500E+01, 0.59279600E+00, -.16280600E+01, -.31942600E+00, -.83215400E-01, 0.64908100E+00, 0.88911400E+00, 0.68205900E+00, -.85505600E+00, 0.82257800E+00, -.15326000E+01, -.27669500E+00, 0.18742700E+01, -.10674800E+01, -.10881600E+01, 0.54840100E-01, -.19501800E+01, -.12000500E+00, -.60019600E+01, -.29713900E+00, -.55604000E+00, -.99433800E-01, 0.15695000E+00, 0.30358500E+00, 0.10088100E+01, 0.10071000E+01, 0.35991300E+01, -.98309800E+00, 0.52278900E+00, 0.13076700E+00, -.74607300E+00, -.35830300E+00, -.99771500E+00, 0.19070800E+01, 0.11791500E+01, 0.16207900E+01, 0.16365600E+00, 0.14198400E+01, 0.54322300E+01, 0.98946700E+00, -.17649800E+01, -.69363100E+01, 0.11445000E+01, -.28690000E+01, 0.20211200E+01, 0.11159500E+00, -.78250400E+01, 0.16355000E+00, -.45344700E+00, 0.74581800E+00, -.74496700E+00, 0.23384500E+01, 0.59861100E+00, 0.15410200E+01, 0.11577800E+01, -.78014300E+00, -.15242700E+01, -.11291200E+01, 0.95980200E+00, -.83539400E+00, 0.42108500E+00, 0.98137700E+00, -.92830600E+00, -.16896100E+01, -.25776600E+01, -.10349900E+01, -.10790200E+00, -.33534400E+00, 0.50240200E+00, -.58736100E+00, 0.49683500E+00, -.50925700E+00, 0.48569500E+00, 0.95278600E-01, 0.16989000E+00, -.34152900E-01, -.48288500E+00, -.48416800E+01, 0.34306600E+00, 0.91386100E+00, -.34023100E-02, -.48719700E+00, -.74844700E+00, -.30423000E-01, -.28606900E+00, -.70798600E+00, -.54131100E+00, 0.25218500E+00, 0.14679200E+01, 0.40341200E+00, 0.13617700E+01, 0.38366300E+00, -.14007700E+01, -.28605500E+00, -.40897800E+00, 0.10884600E+01, -.67035700E+00, -.16329800E+01, 0.10535500E+01, 0.33937900E+00, -.22564500E+01, -.26472900E+01, 0.14354200E+00, -.48816300E+00, -.17465900E+00, 0.12617800E+01, 0.88310300E+00, -.15948500E+01, -.88551900E-01, -.40122300E+00, 0.46467900E+00, 0.19289500E+00, -.52081400E+00, -.36358600E+00, 0.54838700E+00, -.46830700E+00, 0.10367200E+01, -.35088900E+00, -.16605300E+00, 0.38237100E+00, -.11252300E+01, 0.63537700E+00, 0.11650100E+01, -.60650400E+00, 0.90305200E+00, -.15767900E+00, 0.77868900E+00, 0.10604600E+00, 0.97450500E+00, -.37836000E+00, -.23253100E+00, -.94056500E+00, -.89995800E+00, 0.53662000E+00, 0.37705800E+00, 0.77896300E+00, -.16930500E-02, 0.28233700E-01, 0.22810400E-01, 0.30163800E+01, -.26485600E+01, -.25974200E+00, -.51555400E-01, 0.27872200E+01, -.20640800E+00, 0.21178600E+00, 0.16098600E+01, 0.20625600E+00, -.17559400E+00, -.12514400E+00, -.17810200E+01, -.88304400E+00, 0.11770400E+01, 0.58962200E+00, 0.59175000E+00, -.77454200E+00, -.76426800E+00, -.12308900E+01, -.15099600E+01, -.91353600E+01, 0.56707900E+02, 0.18000700E+00, -.80783700E+00, -.10086200E+00, 0.15429800E+02, -.57750800E+00, -.12404600E+02, -.75744700E+00, 0.49201100E+00, -.54440400E+00, -.17652300E+00, 0.29651900E+02, 0.35202100E+01, 0.14430900E+02, -.14724400E+01, -.74385600E-01, 0.46619600E+00, 0.82894400E+00, -.39181600E+01, -.39518700E-01, 0.40047900E-01 },
            { -.20922200E+01, -.19860400E-01, 0.94624200E+00, -.14426800E+00, 0.19342300E+01, 0.31336400E+00, 0.86405000E+00, 0.22050800E+00, -.61028300E+00, 0.68785500E+00, 0.56654100E+00, 0.15404600E+01, 0.20487700E+00, -.26785800E+00, 0.51218900E+00, -.41675700E+00, 0.69864700E+00, -.38960200E+00, -.10388900E+01, 0.23106900E-01, 0.99091800E+00, 0.56481700E+00, -.12770600E+00, -.30648700E+00, 0.38019000E+00, 0.36971300E+00, 0.63320900E-01, 0.60664300E-01, -.30872600E-01, -.24988700E-02, 0.16587600E+00, 0.24350400E-01, 0.35474500E+00, -.16450300E+00, -.20971600E+00, -.60731100E+00, 0.60298200E-01, -.25074400E-01, -.26056600E-01, -.53783400E+00, 0.31798800E+00, -.20573100E+00, -.23397100E+00, -.20597300E+00, 0.28939000E+00, 0.28803500E+00, -.56845700E+00, 0.14669800E+01, -.76649900E+00, 0.48590700E+00, 0.31201100E-01, 0.33903000E+00, 0.48096300E+00, -.18621900E+00, -.37360300E+00, 0.40724800E+00, 0.18827900E+01, 0.34366800E-01, -.41973000E+00, 0.48223000E+00, -.22398000E+00, 0.76323600E-01, -.21785700E+00, -.24593200E+00, -.30226400E+00, 0.45315400E+00, 0.13550700E+01, 0.91310900E-01, 0.10605400E+00, -.10335000E+01, -.84043300E-01, 0.29723700E+00, 0.19787400E+00, 0.64646900E-01, -.11391700E+00, -.33257700E+00, -.34075300E+00, -.19836800E+00, -.43368600E+00, -.47548100E+00, 0.49454700E+00, -.13494500E+00, -.52013100E+00, -.68312700E-01, 0.25775100E+00, 0.19707800E+00, 0.91140000E+00, 0.23879300E+00, 0.16732700E+01, 0.13467200E-01, -.91583200E-01, 0.83317100E-01, 0.34716900E-01, 0.98470600E-01, -.43683700E+00, 0.66411900E+00, 0.50233300E+00, 0.11748100E+01, -.20522100E+00, -.25980300E+00, 0.17696000E+00, 0.10058100E+00, 0.36819800E+00, -.16537600E+01, 0.49950300E+00, 0.91002900E+00, 0.40557700E+00, -.20065900E+00, -.14938800E+01, -.13585000E+00, -.72795200E-01, 0.71770500E+00, 0.90479200E-01, 0.48597200E+00, -.15880200E+00, -.67333100E-01, 0.92824600E+00, -.23693200E+00, 0.39777700E-02, 0.66901000E-01, -.51666700E-01, -.23291300E+00, -.15296400E+00, -.36749700E+00, -.17016200E+00, 0.17653600E+00, 0.30267400E+00, 0.67016800E-01, -.33044500E+00, -.30457400E-01, -.11931600E-01, -.24065800E+00, 0.66185800E-02, 0.78233200E-01, -.19332900E-01, 0.18079600E+00, -.43568400E-01, 0.14268500E+00, -.82485800E-01, 0.68211700E-01, 0.16818400E+00, 0.75455000E-01, -.10753500E-01, -.21733900E+00, 0.11165100E+00, -.30060900E-01, -.16419300E+00, 0.18041200E+01, -.32836500E-01, 0.30828100E+00, 0.55496000E-01, 0.36475700E-01, -.28153500E+00, 0.97215500E-01, 0.11773600E+00, -.78327500E-01, -.12621800E+00, -.11994400E+00, -.31171600E+00, 0.26251900E+00, -.18862200E+00, 0.52289900E-01, -.19925700E-02, 0.44421800E-02, 0.93059400E-01, -.20216600E+00, 0.12020400E+00, 0.40053100E+00, -.95815400E-01, 0.35065600E-01, 0.32443200E+00, -.30059900E+00, 0.22845000E-01, 0.36010300E-01, 0.37034500E-01, -.82569600E-01, 0.69640500E-01, -.92856400E-01, -.10348000E-01, -.44616000E-04, -.15884100E-01, 0.22199200E-01, 0.27187300E-01, -.39286800E-02, 0.14826300E-01, 0.10662900E+00, 0.16367600E-02, 0.11463200E+00, 0.14463000E-01, 0.35479700E-01, -.77385600E-01, 0.26787600E-01, 0.10307800E+00, -.58037200E-01, 0.76089400E-01, 0.86668700E-01, -.35317000E-01, 0.55723300E-02, -.10346500E+00, 0.15214200E-01, 0.49703500E-02, -.57288900E-01, 0.35216000E-01, 0.73462200E-02, 0.31059200E-02, 0.18737900E+00, -.12087100E-01, -.42025400E-01, -.33983300E-01, -.72097600E-01, 0.32384800E-01, -.47793900E-02, 0.40163200E-01, -.10425700E-01, -.72528500E-02, -.19944000E-02, -.21785600E-01, -.78988300E-02, -.54851100E-02, 0.10507400E-01, 0.64709200E-01, 0.25130100E-02, -.51348500E-01, -.21006700E-03, -.55862300E-02, 0.13253700E+00, 0.28529300E+00, -.11149600E-01, 0.17954100E-01, -.10946300E+00, 0.12013500E+01, 0.97966000E-02, -.48021100E-01, 0.63909700E-01, -.81041600E-02, 0.34209000E+00, -.46815500E+00, 0.94875300E-01, -.14399900E+00, 0.16834800E+00, -.16923300E+00, 0.87773900E+00, 0.11584500E+00, -.13487400E+00, 0.15527500E+00, -.20515100E+00, 0.86120800E-01, 0.22878100E-01, -.12108400E+00, -.44480800E-01, 0.67500500E-02 },
            { -.22243700E+01, -.74871200E+00, 0.51320500E+00, 0.87748100E+00, 0.38264000E+01, 0.40868800E+00, 0.13748500E+01, -.39088400E+00, -.26453300E+01, 0.65909800E+00, 0.94234400E+00, 0.88091100E+00, 0.24918500E+00, -.29502700E+00, 0.74237100E-01, -.43749600E+00, 0.89377300E+00, -.39738000E+00, -.18078800E+01, 0.35545100E+00, 0.36186600E+01, -.20044100E+01, -.16891900E+01, -.28908400E+01, 0.12015100E+01, -.50099100E+00, -.20193900E+00, 0.58555200E+00, 0.12622300E+00, 0.34962600E+00, -.21638100E-01, 0.18390400E+00, -.12470700E+00, -.45985500E+00, -.13614800E+00, -.26237600E+01, 0.55321800E+00, -.21362600E+00, -.33733900E+00, 0.85298800E-01, 0.45517100E+01, -.11941300E+01, -.12619500E+01, -.20195400E+01, 0.72025000E+00, 0.24340800E+00, 0.32515400E+00, 0.15567900E+01, -.55334700E-01, -.57433700E+00, -.67852500E+00, -.19942700E+01, 0.55401300E+00, 0.40356100E-01, -.27864900E+00, -.13492900E-01, 0.16080300E+01, -.21969600E+00, -.86031500E-01, 0.63377500E+00, -.68609500E-01, 0.12550400E+00, -.54949600E+00, -.19122300E+00, 0.39201000E-03, -.16718400E+00, -.38975000E+00, 0.15351800E+01, -.54627800E-01, -.35649700E+01, -.59848100E+00, 0.13702300E+01, 0.22768500E+00, -.61332400E-01, -.77149500E-01, -.52455600E+00, 0.11630700E+00, 0.84238400E-01, -.15077800E+01, -.33467300E+00, -.40322500E+00, -.20003600E+00, -.55232400E-01, -.36246000E+00, -.17185800E+00, 0.39813500E+00, -.62016700E+00, 0.70597100E+00, -.10888300E+01, -.13869900E+00, -.22467500E+00, 0.18592400E-01, 0.19221800E+00, -.75483600E+00, -.69672700E+00, 0.10129700E+01, 0.12934100E+01, 0.12552700E+01, -.34474800E+00, -.30044000E+00, -.74748700E-01, 0.22697500E+00, 0.94361000E+00, -.62500300E+00, 0.86497800E+00, 0.98571700E+00, 0.49680300E+00, 0.36998600E+00, -.12206700E+01, -.49057800E-01, -.60653000E+00, -.41074100E+01, 0.45930400E+00, 0.31554400E+01, 0.31132500E+00, -.11495800E+00, -.94952000E+00, -.28339400E+00, -.10994200E+00, 0.28340100E+00, -.14342600E+00, 0.13101200E+01, 0.15060000E-01, 0.23617500E+01, 0.15256300E+01, 0.32747200E+00, 0.13083400E+00, -.33055500E+00, 0.34168200E+00, -.12388200E+00, 0.56174000E-01, -.22443800E+00, -.39381000E+00, 0.52164100E+00, 0.30122000E+00, -.27554300E+00, -.92032100E-02, -.44004300E+00, 0.23146100E+00, -.54182000E+00, 0.33086600E+00, -.96650200E-01, 0.28316500E+00, -.76319200E+00, 0.32642500E+00, -.19801200E-02, -.28215200E+00, 0.46349300E+00, 0.22188200E+00, 0.89896800E+00, 0.14826000E+00, -.58880500E-01, -.23126500E+00, 0.37784200E+00, -.30308300E-01, -.36811700E+00, -.34913200E+00, 0.81957900E-01, 0.71324300E+00, 0.42547500E+00, -.13789100E+00, 0.51872900E+00, -.60522800E+00, -.83515800E-01, 0.11340100E+00, 0.27170400E+00, -.48674200E+00, -.10877300E+00, -.69552200E-01, 0.26057600E+00, 0.80212500E+00, -.45911400E+00, 0.23549700E+00, -.23447000E+00, 0.43027000E-01, 0.15484400E+00, 0.42490700E+00, -.14171700E+01, -.41251500E+00, -.10305900E+00, -.42761700E-01, 0.14603500E+00, -.55017500E-01, -.92816800E-01, 0.17639300E+00, -.49002000E-01, 0.39805200E+00, -.33547100E-01, -.22981100E+00, 0.10569900E+00, -.37795600E+00, 0.33524500E+00, 0.19792200E+00, -.11838400E+00, 0.49432400E+00, 0.22583700E+00, -.18889600E+00, -.26059700E+00, -.40586000E-01, -.24256700E-01, -.32885300E+00, -.14394400E+00, -.27148800E+00, 0.97272700E-01, -.77072900E-02, -.19770800E+00, -.62120300E-01, -.13989500E+00, -.85882200E-01, 0.31032100E+00, 0.14430900E-01, 0.10702600E+00, -.45360900E+00, 0.15358500E+00, -.71412100E-01, 0.36469300E-01, 0.22326700E+00, -.30961700E-01, -.46642800E-01, 0.83239500E-01, 0.11459600E+00, 0.97110500E-02, 0.89177200E+00, 0.38606200E-01, 0.35761800E+00, 0.19507200E+00, 0.45666500E-01, -.82781200E+00, -.31190800E+00, -.53106900E+01, 0.47942600E+02, 0.11945900E+00, -.24477500E+00, 0.26160100E+00, 0.37029200E-02, 0.70442300E+00, -.10796900E+02, 0.11357500E+00, 0.11677400E+01, -.44256700E+00, 0.88993100E+00, -.11710300E+02, -.19691800E+01, -.48181500E+00, 0.34373000E+00, 0.18837900E+00, 0.12918400E+01, 0.11625900E+01, -.56567800E+00, -.73083100E+00, -.38579700E+00 },
            { -.21046300E+01, -.19061700E+00, 0.85379500E+00, 0.34108300E-01, 0.23916900E+01, 0.35502200E+00, 0.87857700E+00, 0.16306200E+00, -.62348600E+00, 0.73526400E+00, 0.49774400E+00, 0.13802200E+01, 0.29778800E+00, -.24431800E+00, 0.48938900E+00, -.43977500E+00, 0.77923100E+00, -.30387500E+00, -.11508100E+01, -.34799300E-01, 0.10557400E+01, 0.53552200E+00, 0.10959700E+00, -.46518100E+00, 0.37489000E+00, 0.37548600E+00, -.27847800E-01, 0.13307800E-01, -.45646400E-01, -.20938600E-01, 0.83002600E-01, -.29550200E-01, 0.35699400E+00, -.17653400E+00, -.22642500E+00, -.88176700E+00, 0.47763200E-01, -.20109600E-01, -.15967800E-01, -.48911100E+00, 0.35044800E+00, -.20009700E+00, -.23546000E+00, -.19169200E+00, 0.29144000E+00, 0.31877400E+00, -.66293400E+00, 0.16005200E+01, -.86530800E+00, 0.56138600E+00, -.36097100E-01, 0.44312600E+00, 0.53714300E+00, -.22770800E+00, -.38381200E+00, 0.44434300E+00, 0.20516200E+01, 0.47949500E-01, -.43688600E+00, 0.52990500E+00, -.21467900E+00, 0.80587700E-01, -.21899000E+00, -.26084000E+00, -.34076300E+00, 0.54032300E+00, 0.14207400E+01, 0.13401800E+00, 0.15913100E+00, -.13879600E+01, -.83714000E-01, 0.28291300E+00, 0.18306900E+00, 0.55145200E-01, -.11721000E+00, -.31999400E+00, -.34279200E+00, -.17184700E+00, -.37540300E+00, -.42582500E+00, 0.42226900E+00, -.11877800E+00, -.50985500E+00, -.10692600E+00, 0.26193600E+00, 0.18549000E+00, 0.10440100E+01, 0.26188200E+00, 0.19244900E+01, 0.29809600E-01, -.78127700E-01, 0.83588900E-01, 0.21923900E-01, 0.15326800E+00, -.41526600E+00, 0.62787400E+00, 0.45047400E+00, 0.11481000E+01, -.18701900E+00, -.25008600E+00, 0.18776500E+00, 0.85660200E-01, 0.29666700E+00, -.18200700E+01, 0.50488600E+00, 0.90386600E+00, 0.39164400E+00, -.21577000E+00, -.14175400E+01, -.14147100E+00, -.11346900E+00, 0.10021200E+01, 0.79308000E-01, 0.21827600E+00, -.19916800E+00, -.53439700E-01, 0.10473700E+01, -.26772500E+00, -.25151100E-01, 0.68644600E-01, -.33353000E-01, -.28856000E+00, -.14962200E+00, -.40348300E+00, -.19772000E+00, 0.17769300E+00, 0.31750700E+00, 0.69399100E-01, -.33940100E+00, 0.14071100E-01, -.16329500E-01, -.24056000E+00, 0.29515200E-01, 0.46168800E-01, 0.25672000E-01, 0.20360200E+00, -.51966200E-01, 0.15256800E+00, -.82911200E-01, 0.84622200E-01, 0.16527900E+00, 0.79790000E-01, -.19058700E-01, -.22762100E+00, 0.11106200E+00, -.21236100E-01, -.15289600E+00, 0.19412900E+01, -.27260100E-01, 0.30568700E+00, 0.60591900E-01, 0.41115500E-01, -.27799300E+00, 0.10533800E+00, 0.12381100E+00, -.55928600E-01, -.11710800E+00, -.12028600E+00, -.32627300E+00, 0.22192900E+00, -.20511500E+00, 0.47953300E-01, 0.23207300E-01, 0.12250700E-01, 0.98867100E-01, -.22521000E+00, 0.10458500E+00, 0.40475700E+00, -.86411200E-01, 0.16848600E-01, 0.26700100E+00, -.23713900E+00, 0.17053500E-01, 0.42257300E-01, 0.40566000E-01, -.99687700E-01, 0.70623400E-01, -.76862900E-01, -.45583000E-02, -.99116400E-03, -.17246800E-01, 0.30408500E-01, 0.69750000E-01, -.17387600E-02, 0.82688500E-02, 0.93482500E-01, 0.11421400E-01, 0.83898300E-01, 0.14916800E-01, 0.39321000E-01, -.30350900E-01, 0.23267200E-01, 0.98842200E-01, -.49637800E-01, 0.77389400E-01, 0.95209500E-01, -.22070300E-01, 0.38083300E-02, -.94789500E-01, 0.16468300E-01, 0.10666500E-01, -.52050200E-01, 0.21254000E-01, 0.31005700E-03, 0.15002500E-03, 0.16754600E+00, -.12881900E-01, -.43391300E-01, -.33866300E-01, -.75777100E-01, 0.58546000E-01, 0.12161600E-02, 0.43079500E-01, -.18125100E-01, -.20381700E-02, -.57708300E-02, -.21387700E-01, -.83818000E-02, -.53798600E-02, 0.91779100E-02, 0.74706300E-01, 0.59507300E-02, -.59535700E-01, -.11836400E-02, -.38240200E-02, 0.13656900E+00, 0.29036200E+00, -.15767300E-01, 0.40258300E-01, -.86376900E-01, 0.22819000E+01, 0.67594700E-02, -.39486300E-01, 0.47347100E-01, -.20034500E-01, 0.28363600E+00, 0.66248400E-01, 0.28419700E+00, -.96350900E-01, 0.99927200E-01, -.15298700E+00, 0.97877700E+00, 0.12302700E+00, -.67878300E-01, 0.10131400E+00, -.14309800E+00, -.61357800E-01, -.80677500E-01, -.19325400E+00, 0.14770400E-01, 0.30353400E-02 },
            { 0.18996800E+01, -.10256100E+01, -.20837800E+01, 0.74895300E+00, -.53554100E+00, -.22212700E+00, -.98218700E+00, -.35666500E+00, -.10114700E+00, -.52412000E+00, -.30078500E+00, -.22104800E+01, -.18194100E-01, 0.50832500E+00, -.37545800E+00, 0.34083500E+00, -.18107400E+00, 0.30769800E+00, 0.22376600E+01, 0.16745800E+00, -.19435800E+01, -.62678400E+00, 0.61887700E+00, 0.13493900E+01, -.75106400E+00, -.39485000E+00, -.80848400E-01, -.29296400E+00, 0.16420600E+00, -.51994500E+00, -.87599500E+00, 0.48048400E-01, -.23812100E+00, 0.59599200E+00, 0.17112500E+00, -.80155700E+00, 0.34941100E+00, -.13322400E+00, -.22734100E+00, 0.90104400E+00, -.50617600E-01, -.27825100E+00, 0.41436300E+00, -.26553600E-01, -.54469700E+00, -.25861200E+00, 0.56800700E+00, -.27834700E+01, 0.24483000E+01, -.13778800E+01, 0.11287500E+01, -.24371000E+01, -.94606300E+00, 0.66998700E+00, 0.53175600E+00, -.11184400E+01, -.72810900E+00, -.18762400E+00, 0.79679800E+00, -.93892800E+00, -.12658400E+00, -.35418000E+00, 0.53265500E+00, 0.26778800E+00, 0.73074800E+00, -.13535200E+01, -.24596200E+01, 0.21455200E-01, -.96836800E-01, -.32410300E+01, -.99381200E-01, -.10158100E+01, -.48000600E-01, -.16010800E-01, 0.34216900E+00, 0.32707600E+00, 0.42124300E+00, 0.17502100E+00, 0.58385000E+00, 0.44861700E+00, 0.23023000E+00, 0.55159600E+00, 0.44447000E+00, 0.58482000E+00, -.16305900E+00, -.41802300E+00, -.33680400E+01, -.53516300E+00, -.46114600E+01, -.13890300E+00, 0.30032100E+00, -.14191500E+00, -.34205400E-01, -.86682400E+00, 0.22620800E+00, -.13904500E+01, -.17573400E+01, -.14470000E+01, 0.59155300E-01, 0.38517900E+00, -.16244000E+00, 0.18493200E-01, 0.18011900E-01, 0.32155600E+01, -.10950100E+01, -.22034600E+01, -.46707800E+00, -.30616200E+00, 0.81392600E+00, -.14683800E+00, 0.49868200E+00, -.19381200E+00, -.43438600E+00, 0.49629600E+00, 0.64074300E+00, 0.19801300E+00, -.64379100E+00, 0.14429700E+01, 0.39345400E+00, -.33207200E+00, 0.39495100E+00, 0.11253000E+00, 0.58756100E-01, 0.61209900E+00, 0.16418700E+00, 0.81810800E-01, 0.42650300E+00, 0.24124100E+00, -.34692400E+00, -.48212000E+00, -.17404300E+00, 0.61629300E-01, 0.28041100E+00, 0.29817900E+00, 0.50487500E+00, -.14377900E-01, 0.52277500E-01, -.26794800E+00, 0.10179300E+00, -.27266500E+00, -.53204900E+00, -.49220500E-01, -.17421500E-01, 0.78342700E+00, -.19512300E+00, 0.40673900E-01, 0.21045500E+00, -.23686500E+01, -.15491200E+00, 0.38509900E+00, -.39346600E-01, -.14021200E-01, 0.71152000E+00, 0.61828500E+00, 0.18106200E+00, 0.68720300E+00, -.42651800E-01, 0.15531700E+00, -.89617500E-01, -.12619200E+00, 0.73200000E+00, -.29445600E+00, -.44638600E+00, 0.18585600E+00, -.42125900E+00, -.19306200E-01, -.38749100E+00, 0.73933100E+00, 0.52919700E+00, -.27742500E+00, -.17754900E+01, 0.54027700E+00, -.17887300E+00, 0.10553900E+00, 0.36034800E-01, -.41512300E+00, -.65329700E+00, 0.26948800E+00, 0.20555900E+00, -.20637000E+00, 0.12928800E+00, -.20345800E+00, -.19536800E+00, 0.86479600E-01, -.88983000E-01, 0.28100000E-01, -.13897800E+00, -.56000600E-01, 0.89634600E-01, 0.30125300E+00, -.84189900E-01, 0.29304500E+00, -.57014800E+00, 0.78022600E-01, 0.41515600E+00, -.18730300E+00, -.16028400E-01, -.21443300E-01, -.24464400E+00, -.27037400E-01, 0.64899900E-01, 0.11804400E+00, -.59355700E+00, -.15550900E-01, -.10803300E+00, -.49429100E+00, -.10423900E+00, 0.33038100E+00, 0.10840200E+00, -.14412200E+00, 0.28625800E+00, 0.29492500E-01, -.40989700E+00, -.25172400E+00, -.16106600E+00, 0.10090100E+00, -.21076900E+00, -.33161400E-02, 0.43455900E-01, 0.21296000E-01, 0.20153100E-01, 0.34330300E-01, -.15673200E+00, -.59964900E-01, -.12814100E+00, -.94893200E-01, -.20150400E+00, 0.26866400E+00, 0.38770700E-01, 0.13735200E+01, -.10829200E+02, -.33638900E-01, 0.12148000E+00, -.45762700E+00, 0.21826800E-01, -.24209100E+00, -.31633400E+00, 0.13683000E+00, 0.18699900E+01, -.14139700E+01, 0.20715400E+00, -.13028400E+02, -.12535600E+01, -.16578900E+00, 0.14632500E+00, 0.20260100E+00, -.79688400E+00, 0.69696700E+00, -.19696600E+01, 0.27015400E+00, -.26517900E+00 },
            { -.25421000E+01, -.95562200E+00, -.57462800E-02, 0.54542200E+00, 0.21837800E+01, 0.32984500E+00, 0.10913600E+01, -.19262600E-01, -.11149200E+01, 0.82614000E+00, 0.37303200E+00, 0.15129400E+01, 0.55367300E-01, -.13562300E+00, 0.29973600E+00, -.37328600E+00, 0.39512500E+00, -.48108400E+00, -.22496200E+01, 0.36135000E+00, 0.22764300E+01, 0.69196700E+00, -.91757700E+00, 0.76608100E+00, 0.47746900E+00, 0.13712100E-01, -.33142400E+00, 0.51205500E+00, -.32712100E+00, 0.38875400E+00, 0.41107700E-01, 0.34503700E+00, 0.44885800E-01, 0.33953200E+00, 0.14328700E+00, -.22917300E+00, 0.22077700E+00, -.91989700E-01, -.11358900E+00, -.72553400E+00, -.10383900E+00, -.46718400E+00, -.43021600E+00, -.65359000E+00, 0.51426000E-01, -.11271800E+00, 0.90537700E-01, -.13088200E+00, -.51982200E+00, -.21758500E+00, 0.95441800E+00, -.34331900E+00, 0.16636200E+00, -.35577500E-01, 0.26191100E+00, -.10050400E+01, 0.75366900E+00, -.24114800E-01, -.28366800E+00, 0.42759400E+00, 0.27674100E+00, -.62988200E+00, 0.47845500E+00, 0.56946500E+00, 0.27290800E+00, -.61057100E+00, 0.61677800E+00, -.32612100E+00, -.28119300E+00, -.12209000E+01, 0.13906800E+00, 0.88266300E+00, 0.22476300E+00, -.79950000E-01, -.40685700E-01, -.31688800E+00, 0.10456400E+00, -.20096100E+00, -.99373000E+00, -.28982500E+00, -.57165600E+00, -.76050600E+00, 0.29216800E+00, -.12102500E+00, 0.62674100E-01, 0.32359000E+00, 0.19587900E+00, 0.71985500E+00, 0.32295300E+00, 0.14767900E-01, -.31847500E-01, 0.34529200E-01, 0.10207400E+00, -.69798500E+00, -.38498800E+00, 0.18851000E+00, 0.22709600E+00, 0.97172600E-01, -.26509800E+00, 0.18041000E-01, 0.61706100E-01, 0.17776500E+00, 0.40242200E+00, 0.85426400E+00, -.68599700E-01, -.97129500E-01, -.95363400E+00, 0.10936800E+01, 0.95192400E+00, 0.34033100E-02, -.48418300E+00, -.26267400E+01, -.12349300E-01, -.19415900E+01, 0.94758200E-02, 0.11808800E+00, 0.17745800E+01, -.26638600E+00, -.43664700E-02, 0.25578400E-01, -.91814400E-02, 0.29935300E+00, 0.20536200E+00, 0.10719800E+01, 0.16134100E+00, 0.84437800E-01, 0.60888200E+00, -.71882800E-01, -.21270600E+00, 0.39317800E+00, -.92325700E-02, -.14064400E+00, -.63130200E-01, 0.77677100E+00, 0.72244800E+00, 0.12417600E+00, 0.19227100E+00, 0.13983000E+00, -.29048100E+00, 0.72353100E+00, 0.15915800E-02, 0.91217200E-01, -.95658000E-01, -.36303100E+00, 0.47315800E-01, -.73129200E-01, 0.80651100E-01, 0.19770100E+00, 0.33769300E-01, 0.23585900E+00, 0.22082300E-01, 0.64794500E-01, -.51877000E+00, -.49827300E+00, -.10485100E+00, -.79984200E+00, -.21600400E-01, -.12705000E+00, 0.12732900E+00, 0.44737300E+00, 0.56513200E-01, 0.81643200E-01, 0.16992800E+00, -.12361800E+00, -.16541200E-01, 0.30472500E+00, 0.23165200E+00, -.13768100E+00, 0.10899900E+00, -.30146100E-01, 0.33624100E+00, -.73441200E+00, 0.56332400E-01, -.57132400E-01, -.10906100E+00, 0.48899000E+00, 0.58235800E+00, -.33244200E+00, -.37013200E-01, 0.26471700E-01, 0.31315000E-01, 0.67061100E-01, 0.12189300E+00, -.13229600E+00, -.12695100E-01, -.35940300E+00, 0.99928700E-01, 0.58237700E-01, 0.11086700E-01, -.88374100E-01, -.51037800E+00, -.12691900E+00, -.42014100E+00, -.73207000E-01, -.76726300E-01, -.11834800E+00, 0.91146600E-01, -.11812300E+00, 0.32752300E+00, 0.93322200E-01, -.10898500E+00, -.11936400E-01, 0.69336600E+00, -.19007200E-01, -.19526600E-01, 0.25739800E+00, 0.22036800E-01, -.23576000E+00, -.38709500E-01, -.12038800E+00, -.45495100E-01, -.65644900E-01, 0.63973300E-01, 0.45018600E-01, 0.26853700E-01, -.16414600E-01, -.83496900E-01, 0.18163100E-01, -.97719500E-02, 0.27642000E-01, 0.75965000E-01, -.24904700E-01, -.20082400E-01, 0.43882600E-01, 0.35179200E-01, -.19118300E-01, 0.44889300E-01, 0.40757900E-01, 0.95016500E-01, 0.98665300E-01, 0.22973000E+00, -.11879400E-01, -.74088900E-01, 0.74138300E-01, -.28826200E-01, 0.12627700E+00, 0.51524300E-01, 0.54968900E-01, 0.43194400E-02, 0.11673400E+01, -.34649500E+00, 0.85541600E+00, 0.60000900E+00, 0.51850500E-01, 0.35214300E-01, -.17952100E+00, 0.31517300E-01, -.10540700E+00, -.13678000E+00, -.63721200E-01, -.10136300E-01 },
            { 0.43228500E+01, 0.10082200E+01, -.92261100E+00, -.13698300E+01, -.37762200E+01, -.57171600E+00, -.19650100E+01, -.15531600E-01, 0.30065100E+01, -.11978100E+01, 0.23224000E+00, -.10272800E+01, -.82327900E+00, 0.54714700E-01, -.49885100E+00, 0.66724000E+00, -.13175400E+01, 0.11804700E+01, 0.21061800E+01, 0.39743700E-01, -.33121000E+01, 0.63988600E+00, 0.59811700E+00, 0.62993800E+00, -.56738200E+00, -.35210800E+00, 0.39228700E+00, -.28260800E+00, 0.17003100E+00, -.14761300E+00, -.75615900E+00, -.59406300E+00, -.10865300E+00, 0.52815200E-01, 0.57697000E-01, 0.34741500E+01, -.20851000E+00, 0.88720200E-01, 0.11364800E+00, 0.19146500E+01, 0.80990100E+00, 0.48225700E+00, 0.55697700E+00, 0.52365200E+00, 0.12876800E+00, -.21063900E+00, -.46238300E+00, -.18617200E+01, -.35751400E+00, 0.60150400E+00, -.11142100E+00, 0.15351300E+01, 0.16469000E+00, -.86191700E+00, -.19664500E-01, 0.66399800E+00, 0.45202900E+00, 0.67456200E-01, -.21580100E+00, -.24062600E+00, -.30239100E+00, 0.31306700E+00, -.22900100E+00, -.41165900E+00, -.34913500E+00, 0.60135000E+00, -.11379700E+01, 0.45241600E+00, 0.18491800E+00, 0.35974300E+01, 0.95300700E-01, -.55086400E+00, 0.87831500E-01, 0.64517200E-01, -.53448800E-02, 0.66448400E+00, 0.16846800E+00, -.82673900E-01, 0.78609300E+00, 0.22961600E+00, 0.31331400E+00, 0.66757500E+00, -.50144600E+00, -.95796500E-01, -.13955900E-01, -.36551500E+00, 0.17009300E+01, -.13583500E+01, 0.16376200E+01, 0.12925800E+00, 0.26290000E-01, -.29181000E-01, -.19649900E+00, 0.12582100E+01, 0.11354500E+01, -.29909200E+00, -.30808400E+00, -.75514300E+00, 0.68562800E+00, 0.16969000E+00, -.11182500E+00, -.43512600E+00, -.12371600E+01, 0.49487000E-01, -.99743100E-03, -.46576500E-01, 0.14026000E+01, -.15866300E+01, -.38240500E+00, 0.23757100E+00, 0.28716000E+00, -.31931100E+00, 0.65309300E-01, 0.14361600E+01, 0.30867700E+01, 0.13546500E+00, -.42723000E+01, 0.44103300E+00, -.44447200E+00, 0.42898600E+00, 0.10167300E+00, -.74064200E+00, -.24416800E+00, -.11965900E+01, 0.20095500E+00, -.32789700E+00, -.53683900E+00, 0.46157200E-01, 0.39402600E+00, -.40084900E+00, 0.60106300E-01, 0.23477400E+00, 0.12946500E+00, -.10434100E+01, -.11328500E+01, -.34813800E+00, -.39288700E+00, -.19682300E+00, 0.23457300E+00, -.90141900E+00, -.30266800E+00, -.98620700E-01, 0.78383000E-01, 0.59174900E+00, -.17351400E+00, 0.26763400E+00, 0.32668700E+00, -.18014400E+01, 0.17163900E-01, -.62147000E+00, -.25254300E-01, -.33259200E+00, 0.93448600E+00, 0.53490900E+00, -.55587100E-01, 0.13471300E+01, 0.19766200E-01, 0.15885200E+00, -.55542300E+00, -.16602500E+01, 0.95392600E+00, 0.27189500E-01, 0.56900100E-01, 0.18575300E+00, -.16283600E+00, 0.51843400E-01, -.54055300E+00, 0.94728800E-01, 0.30541500E+00, -.23888200E+00, -.14374300E+01, 0.10386700E+01, -.10516300E+00, 0.13644100E+00, 0.50706900E-01, -.45880800E+00, -.20676000E+00, 0.14395300E+00, 0.24453900E-01, -.84418700E-01, 0.25745500E-01, -.14708400E+00, -.15439600E+00, 0.87872400E-01, -.48302100E-01, -.12545600E-01, -.13054400E-01, -.27458000E+00, -.11387500E+00, 0.14484200E-01, 0.38050200E+00, -.88885400E-01, 0.48256300E+00, 0.20854800E+00, -.16257300E+00, -.54744200E-01, -.63811100E-01, 0.12088000E+00, 0.46918600E+00, -.78574800E-01, 0.82335200E-01, 0.38756900E-01, -.10681600E+00, 0.14469900E-01, -.36560900E-01, -.46246200E+00, 0.59843000E-01, -.66875500E-01, 0.44088600E-01, 0.30849500E+00, 0.13856800E+00, 0.10259900E+00, -.71532700E-01, -.16944700E-01, 0.67596100E-01, -.35465600E-01, 0.10044900E+00, 0.12290700E-01, 0.62170400E-02, -.21048900E-01, 0.67890400E-02, 0.46999400E-02, 0.52819500E-01, -.10290600E-01, 0.35802400E-01, -.58016000E-01, -.12258400E+00, 0.51617400E-01, 0.18072600E+00, 0.76625400E+00, -.11491800E+02, -.77770400E-01, 0.64325800E-01, 0.24760000E-02, -.20433600E-01, -.45115600E+00, -.17458500E+00, -.32842200E+00, -.11847400E+00, -.29547700E+00, 0.26956900E+01, 0.42069400E+01, -.76439600E+00, 0.31025600E+00, -.20038400E+00, 0.53100100E+00, 0.61912300E+00, 0.26344300E+00, 0.13791400E+01, -.19052900E+00, 0.16467400E+00 },
            { 0.12558200E+02, -.20663200E+01, -.54788000E+01, -.12210300E+01, -.14360400E+02, -.15938000E+01, -.58426100E+01, 0.42908400E+00, 0.39335400E+01, -.38860600E+01, -.39652200E+01, -.85024100E+01, -.15478800E+01, 0.12482800E+01, -.21806800E+01, 0.24595200E+01, -.49952200E+01, -.76772900E+00, 0.11508100E+02, -.56066000E+00, -.11904500E+02, 0.13904900E+01, 0.20392700E+01, 0.12974700E+02, -.48313000E+01, -.97758500E+00, 0.77191200E+00, -.68228700E+00, -.41079900E+00, -.89086700E+00, -.32805000E+01, 0.55648500E+00, -.70952900E+00, 0.11420700E+01, 0.57603800E+00, 0.63858400E+01, 0.81986300E-01, -.35047400E-01, -.10016400E+00, 0.63951300E+00, -.13143200E+02, 0.12082400E+01, 0.27760300E+01, 0.21749000E+01, -.42270400E+01, -.21218400E+01, 0.35816600E+01, -.10977300E+02, 0.54088300E+01, -.57971700E+01, 0.86820100E+01, -.83938000E+01, -.44436900E+01, 0.23027300E+01, -.11095800E+00, -.48219600E+01, 0.17045100E+00, -.15785300E+00, 0.16724000E+01, -.26391300E+01, 0.24327700E+01, -.36086500E+01, 0.38397100E+01, 0.18988600E+01, 0.37132900E+01, -.71218200E+01, -.89475700E+01, -.27684000E+01, -.15171600E+01, -.10321800E+01, 0.13492200E+01, -.17243800E+01, 0.97539600E+00, -.23536100E+00, 0.10206300E+01, 0.23840000E+01, 0.20841200E+01, -.63476000E+00, 0.73759700E+00, 0.10536700E+01, -.40640500E+00, -.14936300E+00, 0.12416800E+01, 0.68351600E+00, 0.66744100E-01, -.67227100E+00, -.63450300E+01, -.39755100E+00, -.84602200E+01, 0.19726500E+00, 0.13274600E+01, -.34818100E+00, -.51232000E+00, -.21767000E+01, 0.22232100E+01, -.68875200E+01, -.82299900E+01, -.97043900E+01, 0.94548100E+00, 0.22229000E+01, -.16664900E+00, -.56671900E+00, -.14444900E+01, 0.15612600E+02, -.60275900E+01, -.10214000E+02, -.35888500E+01, 0.18308700E+00, 0.71560200E+01, -.60787500E+00, 0.22772200E+01, -.20138700E+00, -.10052200E+01, -.74158900E+01, 0.25362700E+00, 0.67295400E+00, 0.29149200E+01, 0.12848500E+01, 0.26787700E+00, -.12435000E+01, 0.16847500E+01, 0.59752900E+00, 0.12455200E+01, -.10667100E+01, 0.55761200E+00, -.85193400E+00, 0.31596600E+00, 0.39784000E+00, -.79160800E+00, -.25352100E+00, -.13943300E+00, 0.11643800E+01, -.79263100E+00, 0.18900500E+01, 0.41738400E+00, -.89814900E-01, 0.10082100E+01, -.17898900E+00, -.13438300E+01, 0.90701000E+00, -.10838300E+01, 0.72829000E-01, -.36240800E+00, 0.11378000E+01, -.74221700E+00, 0.19152500E+00, 0.20067300E+01, -.10193300E+02, -.16706000E+00, 0.51525100E+01, -.31354100E+00, -.13375100E+00, 0.24355500E+01, 0.15304600E+01, 0.13090300E+01, 0.28082000E+01, -.42110800E+00, 0.13499400E+01, 0.21605800E+01, -.20648700E+01, 0.34792500E+01, 0.13851800E-01, -.19153700E+01, 0.45127500E+00, -.16885900E+01, 0.22920700E+01, -.22136800E+00, 0.50746700E+00, 0.24134200E+01, -.20464700E+01, -.21283900E+01, -.66403400E+01, 0.12971500E+00, -.17373800E+00, 0.54304300E+00, 0.24687100E+01, 0.42227300E+00, 0.21953400E+01, 0.47437700E+00, 0.77813400E+00, -.74452700E-01, -.85374200E+00, 0.61596400E+00, -.21678500E+00, -.69978900E+00, -.17498700E+01, -.98119000E+00, -.33058200E+00, 0.18835500E+00, 0.79337900E+00, -.38578200E+01, 0.31189400E+00, -.53712900E+01, 0.10073100E+00, 0.37448700E+00, -.17784500E+01, 0.65617300E+00, -.47192100E+00, 0.17028300E+01, 0.69327200E-01, -.34096600E+00, 0.24356600E+00, -.19961500E+00, -.22923200E+00, -.26198800E+00, -.16230900E+01, -.27512600E+00, 0.63895400E+00, -.69554800E-01, 0.10690800E+01, -.17357000E+01, -.48826300E+00, -.54259900E+00, 0.12102900E+01, -.85385600E+00, 0.53767100E+00, 0.12402400E+01, 0.29061100E+00, -.11324300E+00, 0.86192100E-01, -.18844400E+01, -.89547400E+00, 0.23011500E+01, 0.10301600E+01, 0.85312400E+00, 0.71149700E-01, 0.99816900E+00, -.70338500E+00, 0.76272600E+00, -.62220200E+01, 0.58262500E+02, 0.13354200E+00, 0.19317100E+00, 0.11401700E+01, -.49017500E+00, -.19987600E+00, 0.19591400E+01, -.14971800E+01, 0.24852700E+00, -.12629100E+00, -.68982600E+00, 0.13487100E+03, 0.61678400E+01, 0.29302600E+00, -.10442600E+01, 0.37098400E+00, -.82017200E+00, -.20621200E+01, -.13257000E+01, 0.49982500E+00, 0.28544200E+01 },
            { -.38834400E+01, -.71359900E+00, 0.75739500E+00, 0.11498800E+01, 0.17346500E+01, 0.27733900E+00, 0.17900900E+01, 0.41911500E-01, -.22689700E+01, 0.15223000E+01, 0.88787800E+00, 0.25743200E+01, -.41867700E+00, -.71555800E+00, 0.16208200E+01, -.91862100E+00, 0.85591600E+00, -.77739700E+00, -.19962900E+01, 0.51096300E-01, 0.27183100E+01, -.19929800E+00, -.58411100E+00, 0.52851200E+00, 0.40098800E+00, 0.13037500E+00, -.46811800E+00, 0.38685800E+00, -.21770900E+00, 0.67984100E-01, 0.82910000E+00, 0.10648800E+01, -.85855100E-01, 0.45574800E-01, 0.89017600E-01, -.34051000E+01, 0.12931700E+01, -.51057100E+00, -.75910800E+00, 0.24357700E+01, 0.48648200E+01, -.20258100E+01, -.11686000E+01, -.23937400E+01, 0.89249100E+00, 0.67994900E+00, -.29043300E-01, -.44475300E+00, -.28833000E+00, -.12557900E+00, -.12158700E+00, -.11297100E+01, -.37808400E+00, 0.68599800E+00, 0.43756600E+00, -.55007100E+00, -.13293600E+01, -.20978500E+00, -.23690700E+00, 0.18438800E+00, -.48877100E+00, -.12303500E-01, 0.11635000E+00, 0.30384300E+00, -.15175100E+00, -.56987700E+00, -.65404600E+00, 0.17339400E+01, -.56271600E+00, -.53827300E+01, 0.95793500E-01, 0.11622600E+01, 0.67507800E-01, 0.24178300E-01, -.23554500E-02, -.72404500E+00, -.37426800E+00, -.31209700E+00, -.78333500E+00, -.47140200E+00, 0.41810200E+00, 0.86305000E-01, -.54791400E-01, 0.53516200E+00, 0.13345100E+00, -.95049300E-01, -.39129200E-01, 0.37452600E+00, 0.43705800E+00, -.62448500E-01, -.30747500E-01, 0.51359100E-01, 0.13103300E+00, -.10193900E+01, -.13768500E+01, 0.68144400E+00, 0.32252900E+00, 0.15995800E+01, -.78503900E+00, -.34463500E+00, 0.19552300E+00, 0.40169800E+00, 0.13638700E+01, -.26427700E+01, 0.62809600E+00, 0.73559800E+00, -.46250800E+00, 0.83923600E+00, -.26327400E+01, -.22215600E+00, -.73851400E+00, -.25215300E+01, -.45918400E+00, -.61225500E+00, -.22313800E+01, -.16653900E+00, 0.36751400E+01, -.51647200E-02, 0.61041800E+00, -.23185000E+00, -.37712000E+00, 0.90574000E+00, 0.24197500E+00, 0.11045800E+01, 0.23228800E+00, 0.14795800E+00, -.37156800E+00, -.11010300E+00, 0.21045200E+00, -.72546100E-02, -.35935900E-02, -.19549900E+00, -.72048000E-01, 0.66969800E+00, 0.42432800E+00, 0.29756100E+00, 0.19747000E+00, 0.50582300E+00, -.37924800E+00, 0.70780500E+00, 0.42684400E+00, 0.24070800E+00, -.11997600E+00, 0.57943800E-01, 0.15896400E+00, -.19504100E+00, -.51948500E+00, 0.38220500E+01, -.31181300E+00, 0.78531000E+00, 0.31262100E-01, 0.83960500E-01, -.45699800E+00, 0.67608100E-01, 0.17146100E+00, -.90420200E+00, -.31812900E-01, -.22571000E-01, 0.72426200E+00, 0.15012300E+01, -.11496300E+01, -.18359800E+00, 0.35633400E+00, -.10247200E+00, 0.25289800E+00, -.45607000E+00, 0.64195700E+00, 0.53695000E+00, -.63784400E+00, 0.10584500E+00, 0.15399900E+01, 0.49777300E+00, 0.44284100E-01, -.27683100E-01, 0.58487600E-01, -.34541300E+00, -.55521700E+00, 0.68756600E-03, -.93556400E-01, -.43619200E-01, -.58751200E-01, 0.12660800E+00, 0.61360600E-01, 0.89246100E-02, -.41480400E-01, -.10709900E+00, -.24004100E+00, 0.28853100E+00, -.12672500E+00, 0.96820500E-01, -.35754000E+00, 0.26962700E+00, -.84814400E+00, -.97786900E-01, 0.43306500E+00, -.69770400E-01, -.24068000E+00, -.79292900E-01, -.28009100E+00, 0.17804700E+00, 0.35861300E-01, 0.20749600E+00, -.34156800E-02, -.58004100E-01, 0.62911200E-01, 0.67085900E+00, 0.33824700E-02, -.20290900E+00, -.59207800E-01, 0.23439900E-01, -.19496500E-01, 0.17984900E-01, -.19511100E+00, -.35169300E+00, -.88395600E-01, 0.32904000E-01, -.31733900E+00, -.17654100E-01, 0.11901400E-01, 0.30954000E-01, 0.37143100E+00, 0.43884200E-01, -.59809700E+00, -.96449400E-01, -.90901400E-01, 0.50139100E-01, 0.11069600E+00, 0.31141800E+00, 0.42667300E+00, 0.12372600E+01, -.83502500E+01, -.10502000E+00, 0.23262100E-01, -.28858700E+00, -.98200300E-02, 0.25302800E+00, -.18921200E+00, 0.37564700E+00, 0.28332200E+00, 0.50044000E+00, -.39848800E+00, -.78845700E-01, 0.29986200E+01, 0.27705700E-01, 0.11526500E+00, -.56223900E-02, -.28902500E+00, -.41772900E-01, -.39211600E+00, 0.15251200E-01, -.12096100E+00 },
            { 0.98550100E+01, 0.71556400E+00, -.37437000E+01, -.49320300E+00, -.16009700E+02, -.20016600E+01, -.44872000E+01, -.28802500E+00, 0.43191100E+01, -.27622100E+01, 0.10337200E+00, -.10699100E+01, -.39181500E+00, -.10648100E+01, -.54182300E+00, 0.14466600E+01, -.41754300E+01, -.20109800E+00, 0.74484000E+01, -.99741900E+00, -.85490300E+01, -.42229200E+01, -.91438100E+00, 0.25864700E+01, -.17384200E+01, -.27919800E+01, 0.30356900E+00, 0.94890100E+00, 0.18681000E+00, 0.50605900E+00, 0.24056700E+01, 0.10616400E+00, -.18701600E+01, -.19011800E+01, -.49346300E+00, 0.95371100E+01, 0.11423300E+01, -.45188600E+00, -.74407800E+00, 0.58571000E+01, 0.33962300E+01, -.14716900E+01, -.26643800E+01, -.64538300E-01, 0.86273000E-01, -.42331400E+01, 0.42685700E+01, -.53915300E+01, -.33489800E+00, -.26462100E+01, 0.32617900E+01, -.32665200E+01, -.34610700E+01, 0.83407300E+00, 0.26564000E+00, -.42237500E+01, -.28055000E+01, -.36434900E+00, 0.77871500E+00, -.36477800E+01, 0.27378400E+00, -.10940000E+01, -.75282400E+00, -.29288800E+00, 0.24119900E+01, -.26740500E+01, -.10235800E+02, 0.27089800E+01, 0.12347900E+01, -.30293600E+01, -.19352800E+01, -.16780900E+01, 0.16020800E+01, -.10970300E+01, 0.32855300E+00, 0.37424200E+01, 0.18664700E+01, 0.97373800E+00, 0.36206200E+01, 0.84216700E+00, 0.31119200E+01, 0.14017400E+01, 0.21359900E+01, 0.16681500E+01, -.11926600E+01, -.79254400E+00, -.56218800E+01, 0.13362200E+01, -.16010200E+01, -.36473900E+00, 0.36089000E+00, -.30186300E+00, -.58133400E+00, -.34070100E+01, -.42686100E+01, -.10694200E+00, -.16945800E+01, 0.63465100E+01, -.23003900E+01, -.13888200E+01, -.58712100E-01, 0.15575800E+00, 0.60808700E+01, -.11051900E+01, 0.80315500E+00, -.87398000E+00, 0.40448800E+01, -.32354800E+01, -.18146600E+02, -.59656000E+00, 0.79997800E+00, -.31743700E+02, -.27157300E+01, 0.10725500E+02, 0.92067400E+01, 0.76252000E+00, -.27465800E+02, 0.30587200E+01, 0.89495200E+00, 0.16031200E+01, -.63263000E+00, 0.32927200E+01, 0.46263100E+00, 0.32334700E+00, 0.39337200E+01, 0.42370000E+00, -.25980100E+01, -.11219800E+01, 0.50668400E+01, -.19223200E+01, 0.10029100E+01, 0.24704500E+01, 0.22533800E+01, -.38942900E+01, 0.10809900E+00, -.21713600E+01, 0.16105500E+00, 0.20658800E+01, 0.19234300E+01, 0.13881500E+01, 0.14163400E+01, -.97082000E-01, -.15470000E-01, -.64858200E+00, 0.39020600E-01, -.68865600E+00, -.10234500E+01, -.57796800E+01, 0.22220800E+00, -.39450300E+01, -.27503800E-01, -.93786800E+00, -.18323700E+01, -.28825700E+00, 0.11190200E+01, 0.22988500E+01, -.21541800E+01, 0.64927900E+00, -.13039600E+01, -.87774900E+00, -.19784700E+01, 0.85177800E+00, -.21147700E+01, 0.16323400E+00, 0.69229100E+00, 0.21688700E-01, 0.12362500E+00, -.72005800E+00, -.63030200E+00, 0.20110400E+01, 0.13795700E+01, 0.56967700E+01, -.71483700E+00, -.94469200E+00, -.38814900E+00, -.90252600E+00, -.12830300E+01, -.12030300E+01, -.46992600E+00, -.36022200E+00, 0.23456000E-01, 0.24188200E+00, -.23886400E+01, -.87307600E+00, 0.74537000E-01, -.45435500E+00, 0.35575600E+00, 0.68238300E+00, -.94752400E+00, -.11191200E+01, -.14965400E+01, -.14857800E+01, -.50857800E+01, 0.59391400E+00, -.31150900E+01, -.96075400E+00, -.15441500E+01, 0.31072700E-01, -.57372800E+01, -.38609000E+00, -.28945100E-01, 0.87011000E+00, 0.15279500E+00, 0.16308000E-01, 0.31988900E+00, -.78521000E+00, 0.54474700E+00, 0.75675500E+00, 0.33765000E+00, -.34566800E+01, 0.10241800E+01, 0.83084400E-02, 0.56829300E-01, -.40729200E+01, -.21771600E+00, 0.22189000E+00, -.47436200E+00, -.20471100E+00, 0.43613600E-01, 0.32054700E+00, -.67584700E-01, 0.38411200E+00, -.15432300E+00, -.46655500E+00, -.60659300E+00, 0.24004700E+00, 0.49649300E+00, 0.44279700E+00, -.17448700E+01, 0.83821200E+01, -.45673100E+02, 0.26931800E+00, -.18728600E+00, -.83945500E+00, -.12288200E-01, -.64970000E+00, -.11782200E+01, 0.90476000E+00, -.13139800E+01, -.16485500E+00, -.31551600E-01, -.26640300E+00, -.67700900E+00, -.76440500E+01, 0.78291400E+00, -.76631100E+00, -.30174400E+01, 0.30052900E+01, -.67243200E+01, 0.11501100E+01, -.16707200E+00 },
            { -.33308600E+01, -.13842600E+01, 0.15133400E+01, -.30489800E+00, 0.29675100E+01, 0.59651200E+00, 0.13209200E+01, 0.28091100E+00, -.97201900E+00, 0.12305500E+01, 0.60986200E+00, 0.29930800E+01, -.90338900E-01, -.51767300E+00, 0.63669000E+00, -.61695400E+00, 0.67145000E+00, 0.23677300E+00, -.22857600E+01, -.53060700E+00, 0.11681500E+01, 0.12446300E+01, 0.10250700E+01, -.18005300E+01, 0.49501800E+00, 0.72225400E+00, -.17134000E+00, -.13575700E+00, -.38297500E+00, -.22197700E+00, 0.39089600E+00, 0.43523000E-01, 0.33562600E+00, -.40264100E+00, -.46424100E+00, -.36987300E+01, -.37289700E+00, 0.14523200E+00, 0.24235100E+00, -.73164700E+00, -.56291000E+00, 0.42962700E+00, 0.20120000E+00, 0.47739300E+00, 0.21480300E+00, 0.39787400E+00, -.77577300E+00, 0.20030700E+01, -.14007100E+01, 0.77067300E+00, -.72909500E+00, 0.12135300E+01, 0.71991400E+00, -.71551700E+00, -.27216700E+00, 0.58304100E+00, 0.25587500E+01, 0.95042100E-01, -.85473600E+00, 0.52630100E+00, -.59030000E+00, 0.46350900E+00, -.30889500E+00, -.30343800E+00, -.55894900E+00, 0.78941700E+00, 0.17864500E+01, -.16433300E+00, 0.56638200E+00, -.29568300E+01, 0.38453600E-01, 0.10577300E+00, 0.22505700E+00, 0.32810600E-01, -.16573300E+00, -.40156900E+00, -.36017200E+00, 0.32960900E-01, 0.15851200E+00, -.77127400E-01, 0.59718200E+00, 0.11376100E+00, -.33040400E+00, -.18288300E+00, 0.24630900E+00, -.94889300E-02, 0.95358800E+00, -.73663700E-01, 0.10937800E+01, -.56962400E-01, -.25494800E+00, 0.13002500E+00, 0.56684800E-01, 0.62768300E+00, -.51517500E+00, 0.12554100E+01, 0.14440700E+01, 0.17205800E+01, -.20041200E+00, -.46823300E+00, 0.18943100E+00, 0.53345700E-01, 0.18974200E+00, -.37821500E+01, 0.11479200E+01, 0.21029600E+01, 0.12121200E+01, -.81962500E+00, -.25349900E+01, -.19651000E+00, -.65854200E+00, 0.20075100E+01, 0.63747400E+00, -.12334800E+01, -.11642500E+01, -.14806300E+00, 0.90138600E+00, -.74368500E+00, -.45994700E-01, 0.16296100E+00, -.25973100E+00, -.82421000E+00, -.10028500E+00, -.49098600E+00, -.15816900E+00, 0.29503600E+00, 0.34909100E+00, 0.49561400E-02, -.13138300E+00, -.44827900E-02, 0.31915100E-01, 0.57815900E-01, -.19802600E+00, -.51343900E+00, -.24458800E+00, 0.43790300E-01, -.11743500E+00, 0.44304900E-01, -.13937800E+00, -.12862300E+00, 0.39064000E+00, 0.17599100E+00, 0.12918900E-01, -.41843600E+00, 0.11670600E+00, 0.49753800E-01, 0.36604700E-01, 0.10937800E+01, -.27967300E-01, -.26571800E+00, 0.33473200E-01, -.58428500E-01, -.19966900E+00, 0.20131900E+00, 0.11124000E+00, 0.82103300E-01, 0.26728300E-01, 0.15920200E-01, 0.40332400E+00, 0.32300600E-01, -.89062100E-01, 0.60878500E-01, -.11588400E-01, -.81732400E-01, 0.63936400E-01, -.20239800E+00, -.19516200E+00, 0.64368200E+00, 0.86457800E-01, -.99696100E-01, -.21384800E+00, 0.42014600E+00, 0.41409300E-02, 0.21515300E+00, 0.93341500E-01, -.56144600E+00, -.11588900E+00, 0.97437200E-01, 0.18391400E-01, -.14440900E-01, -.37954000E-01, 0.50063100E-01, 0.10840900E+00, 0.51009800E-01, 0.26358900E-01, -.48457500E-01, 0.97921500E-01, 0.12890300E-01, -.52594500E-01, 0.25304800E+00, -.28222300E+00, 0.30821500E+00, -.94684000E+00, -.45114300E-01, 0.41704000E+00, 0.44653100E-01, -.31094400E+00, 0.11884500E-01, -.11833700E+00, 0.86724600E-01, 0.45256300E-02, 0.31431100E-01, -.54770200E+00, -.11462500E-01, 0.71769300E-03, 0.17859900E+00, -.18475300E-01, -.61548300E-01, -.32470000E-01, -.17301600E+00, 0.16158000E+00, 0.11399600E-02, 0.34909700E-01, -.20348100E+00, -.32432700E-01, 0.11330800E-01, -.15109600E+00, -.15425600E-01, -.42428900E-02, 0.74282500E-02, 0.19529300E+00, 0.41658600E-01, -.19847500E+00, -.13695400E-01, 0.31353400E-02, 0.16365000E+00, 0.34668800E+00, 0.33193400E-01, 0.19627800E+00, 0.37018900E+00, 0.27586500E+01, -.13520300E-01, -.14149700E-01, 0.52974500E-01, -.10144800E+00, 0.42747600E+00, 0.17253700E+00, 0.32787600E+00, -.18599000E-01, 0.55127800E-01, -.12100600E+00, 0.80637500E-02, 0.15711700E-01, 0.36469500E-02, 0.57256900E+00, -.15360300E+00, -.33069900E+00, -.17564800E+00, -.65009800E+00, 0.31570000E-01, -.68919500E-01 },
            { 0.38083200E+01, 0.14679700E+01, -.88380500E+00, -.48692500E+00, -.39404200E+01, -.60711600E+00, -.15771000E+01, -.26012400E+00, 0.20638000E+01, -.13547000E+01, -.79094200E+00, -.19808200E+01, -.31168400E+00, 0.24872200E+00, -.72701100E+00, 0.77421300E+00, -.12278100E+01, 0.97001900E+00, 0.14149700E+01, 0.20832900E+00, -.22305600E+01, -.42889500E+00, 0.66476000E+00, 0.15259200E+00, -.48053300E+00, -.48307900E+00, -.15456300E-01, -.23905400E+00, 0.20165700E+00, -.32655900E-01, -.33446600E+00, -.39475300E+00, -.46777800E+00, 0.35334400E+00, 0.35301000E+00, 0.22983100E+01, -.17418200E+00, 0.71263600E-01, 0.89203500E-01, 0.56420800E+00, -.78253200E+00, 0.56600700E+00, 0.68310600E+00, 0.93542900E+00, -.32609900E+00, -.37001000E+00, 0.20076300E+00, -.22461900E+01, 0.11725600E+01, 0.16725500E+00, -.65412200E-01, 0.10563000E+01, -.49137500E+00, 0.16907000E+00, 0.25935700E+00, 0.35635300E+00, -.30381100E+01, 0.38648900E-01, 0.52163900E+00, -.74856800E+00, 0.10459100E+00, 0.23953600E+00, 0.21022800E-01, -.72461400E-01, -.67805000E-01, 0.26702500E+00, -.85086300E+00, -.37200500E-01, -.46540200E+00, 0.58373500E+01, 0.40481200E+00, -.34813500E+00, -.53392600E+00, -.15040000E-01, 0.69099500E-01, 0.59671900E+00, 0.20395600E+00, 0.21624000E+00, 0.72042100E+00, 0.50831200E+00, -.64151000E+00, 0.53367200E-01, 0.53053300E+00, -.65569000E-03, -.31113300E+00, -.24657600E+00, 0.73310700E+00, -.76709600E+00, 0.10215800E+00, 0.72516200E-01, -.57553700E-03, -.75729300E-01, -.35906900E-01, 0.69371600E+00, 0.10628700E+01, -.38421400E+00, -.12094000E+00, -.12566100E+01, 0.61821800E+00, 0.28488900E+00, -.26137700E+00, -.22564000E+00, -.10655400E+01, 0.16360700E+01, -.25146200E+00, -.45569400E+00, 0.51250100E+00, -.78479000E+00, 0.64161300E+00, 0.25711800E+00, -.96639300E-01, -.18297800E+01, -.27278100E+00, 0.24711500E+00, 0.17862000E+01, 0.73750000E-01, -.10508400E+01, 0.66221500E+00, -.28010000E+00, 0.12124700E+00, 0.14270500E+00, -.17507100E+00, -.43443400E-01, -.73574900E-01, 0.15034100E+00, -.25603600E+00, -.64462700E-01, 0.46366500E-01, -.12801900E+00, -.20460600E+00, -.43475100E-02, 0.10017500E+00, 0.11716000E+00, -.33001000E+00, 0.58648600E-02, -.12395600E+00, -.11217800E+00, -.16492500E+00, 0.13897000E+00, -.11892900E+00, -.37450200E+00, -.16762800E+00, -.17289100E-01, 0.33343400E+00, -.20112400E+00, 0.16598400E+00, 0.27899700E+00, -.68772500E+00, 0.16547400E+00, -.10657900E+01, 0.79152100E-02, -.66122200E-01, 0.47074000E+00, 0.90631900E-01, -.13492200E+00, 0.58195800E+00, 0.13862000E+00, -.11373700E+00, -.50781300E+00, -.89167400E+00, 0.28113900E+00, -.18778300E-02, -.35576200E-01, 0.73007800E-02, -.30198100E-01, 0.20150700E-01, -.19599300E+00, -.47411700E-01, -.12457000E+00, -.55744200E-01, -.48165000E+00, -.14418900E+00, -.30545700E-01, -.88865500E-01, -.13740300E-01, 0.22656400E+00, 0.31466200E-01, 0.59070000E-02, 0.18927800E-01, -.21595000E-01, 0.40530100E-01, 0.19538400E-01, -.21777700E-01, -.41710500E-01, -.36679400E-01, -.15616000E-01, -.79165400E-01, -.16948400E+00, -.10543000E+00, -.11466200E+00, 0.25509100E+00, -.24685700E+00, 0.87961100E-01, 0.20980800E+00, -.44144300E+00, -.61077300E-01, 0.48845200E-01, 0.30449300E-01, 0.19984300E+00, -.90135700E-01, 0.49554200E-01, -.90591400E-02, 0.67227700E-01, -.12288500E-02, -.41842600E-01, -.29393200E+00, 0.31727400E-01, 0.29195300E-01, 0.33289800E-01, 0.85718900E-02, 0.67631900E-01, 0.15370700E-01, 0.47618400E-01, 0.62748700E-01, 0.94509100E-01, -.62333800E-01, 0.76202100E-01, -.24261900E-02, 0.13363500E-01, -.42544000E-01, -.73699800E-01, 0.47587300E-01, 0.25239700E+00, 0.12037700E-01, -.35437700E-01, -.90680900E-01, -.29716000E+00, -.17447600E-01, -.11707500E+00, -.40406300E+00, -.33851100E+00, 0.16123900E-02, 0.98237600E-01, -.14180800E-01, 0.24571300E-01, -.47204600E+00, -.19995400E-01, -.41622700E+00, 0.91160300E-02, -.15439600E+00, 0.18991200E+00, -.28983600E-02, 0.30767900E-01, -.14234000E-02, -.27929400E+00, 0.81162200E+00, -.29916800E-01, -.19722400E+00, 0.18249500E+00, -.36244300E-01, 0.28738500E-01 },
            { 0.18232200E+01, 0.64814900E+00, -.35645900E+00, -.67822700E+00, -.25512800E+01, -.25474100E+00, -.81840800E+00, 0.24999800E+00, 0.13604500E+01, -.56503100E+00, -.39381600E+00, -.18960100E+01, -.19054700E+00, -.47248100E-01, 0.32659300E+00, 0.18122800E+00, -.48276500E+00, 0.38940200E-01, 0.85861200E+00, -.11916100E+00, -.10382100E+01, 0.50116600E+00, 0.15577400E+01, 0.23135300E+01, -.43133900E+00, 0.53956900E-01, -.12181300E+00, -.98884500E-01, -.13073800E+00, -.39888000E+00, -.68633700E+00, -.96063700E-01, -.72635900E+00, 0.22500800E+00, 0.76322000E-01, 0.27860700E+00, 0.32843000E-01, -.98310900E-02, -.39854700E-01, 0.14455900E+01, -.21862800E+01, 0.36332600E+00, 0.92345700E+00, 0.10551300E+01, -.76474000E+00, -.13233500E+01, -.24557000E+00, -.31618700E+01, 0.96531200E+00, -.18765300E+00, 0.94224000E+00, 0.89274100E+00, 0.35591500E+00, -.17691600E+00, -.16609600E+00, -.22504900E+00, 0.47470000E+00, 0.10832900E+00, -.20417800E+00, -.52681600E-01, 0.66360800E+00, -.81879300E+00, 0.41218500E+00, 0.13330700E+00, -.13213000E+00, -.88081800E+00, -.13094200E+01, -.89495100E+00, 0.27491800E+00, 0.10088600E+00, 0.68153600E+00, -.84426200E+00, -.27510000E+00, 0.94851500E-01, 0.29851100E-01, 0.39087000E+00, 0.20516900E+00, -.92698200E-01, -.17176800E+00, 0.18240500E+00, 0.36246500E+00, 0.58537300E+00, -.79108600E-01, -.31287300E-01, -.31141400E+00, -.14179200E+00, 0.37166500E-01, -.33705200E+00, -.14537300E+01, -.45235300E-01, -.18193500E+00, -.15539500E-01, 0.14532700E-01, 0.16679100E+01, 0.11115000E+01, 0.20465800E+00, 0.19719300E+00, -.73438000E+00, 0.74942500E+00, -.10346000E+00, -.20401000E+00, -.12275400E+00, -.13901700E+01, -.28076300E+01, 0.63769200E+00, 0.48966900E+00, 0.13006500E+01, -.77082200E+00, -.74442000E-01, 0.29407700E+00, 0.39608200E+00, -.21246900E+00, 0.17834500E+00, 0.82656300E+00, 0.56591300E+00, 0.94359200E-01, -.35930300E+01, -.23794600E+00, 0.24909900E+00, 0.82966700E-01, -.15637100E+00, -.61211300E+00, 0.32546800E+00, -.97800400E-01, -.69622000E-02, -.19325300E+00, -.33011300E+00, -.15991400E+00, 0.62850300E+00, -.21808500E+00, 0.12901300E-01, -.16051300E-01, -.17814900E+00, -.64251900E+00, -.51979700E+00, 0.12622400E+00, -.67810300E-01, 0.42501700E-01, 0.28546700E+00, -.11290400E+00, 0.72442500E+00, -.14961900E-01, -.31245200E-01, 0.60625300E+00, -.18383500E+00, 0.99951900E-01, 0.15941700E+00, -.98162500E+00, -.43946200E-01, -.12992800E+01, -.45558600E-01, -.56771500E-01, 0.73003300E+00, 0.85962000E+00, 0.24666900E+00, 0.80429400E+00, -.24011400E+00, 0.50555200E+00, 0.10100400E+01, -.43483600E+00, 0.28259100E+00, 0.11403100E+00, 0.54691100E-01, 0.24707300E+00, -.29744100E-01, 0.23435500E+00, -.45268300E+00, -.19190600E+00, 0.33277000E+00, -.94341400E-01, -.45622500E+00, 0.15489900E+00, -.26301000E-01, 0.72026000E-01, 0.52377400E-01, -.92277400E-01, 0.19225200E+00, -.27822300E+00, 0.40663200E-02, -.11369300E+00, 0.11086900E+00, -.16451800E+00, 0.10157600E+00, 0.17018100E-01, 0.15272300E+00, -.59849600E+00, 0.34664800E+00, 0.91324200E-01, 0.83188300E+00, 0.50754500E-01, -.22951200E+00, 0.44465800E+00, 0.10960000E+00, -.24791500E+00, 0.97281200E+00, 0.96781500E-01, 0.15956700E+00, 0.16036100E-01, 0.62027600E+00, 0.41990200E-03, 0.11830800E-01, -.17356500E+00, -.17218100E-01, 0.31567900E-02, 0.40695500E-02, 0.20907200E+00, -.59917100E-01, -.12321900E+00, -.54941700E-01, 0.57350300E+00, -.13904200E+00, 0.77093000E-01, -.22143000E+00, -.10815400E+00, 0.19669100E-01, 0.69201100E-03, 0.23050000E+00, -.59055600E-01, -.36799500E-01, -.34121000E-01, -.25487400E-01, 0.57955500E-01, 0.57055100E+00, -.43334200E-01, 0.11723600E+00, 0.20167500E+00, 0.17932300E-01, -.17306600E+00, 0.15358700E+00, -.18215400E+01, 0.19389800E+02, -.74165800E-02, 0.36053800E-01, -.84717700E-01, -.51063000E-02, -.46952900E-01, 0.41204400E+00, -.19723400E+00, 0.15143100E+00, -.70188600E-01, -.14449200E+00, 0.72731600E-01, 0.11036600E+00, -.20436500E-02, -.69942300E-01, 0.23088600E-01, -.19573700E+01, -.42508400E+00, 0.40122100E-01, 0.30675000E+00, 0.13219100E+00 },
            { -.48347900E+01, -.45119200E+00, 0.31096300E+01, -.10246700E+01, 0.48177100E+01, 0.10082000E+01, 0.24959100E+01, 0.56584200E-01, -.27505400E+01, 0.99450500E+00, 0.53743300E+00, 0.49324700E+01, 0.21373800E+00, -.77843200E+00, 0.94269000E+00, -.11660000E+01, 0.20618300E+01, -.17229100E+00, -.21303600E+01, -.98778200E+00, 0.38515600E+01, -.46901500E+00, -.60165900E-01, -.41548300E+01, 0.72918000E+00, 0.16888100E+01, 0.30298000E+00, -.52180000E+00, 0.20447400E+00, 0.27739800E+00, -.57293800E+00, -.58761300E+00, 0.12689600E+01, -.48167300E+00, 0.15585000E+00, -.48303100E+01, -.17903300E+01, 0.69823100E+00, 0.10586200E+01, -.24195500E+01, -.35497200E+01, 0.22933200E+01, 0.12216300E+01, 0.12013400E+01, 0.55845000E+00, 0.21132100E+01, -.12780200E+01, 0.52406100E+01, -.33706700E+01, 0.28013300E+01, -.29550200E+01, 0.47737400E+01, 0.13729900E+01, -.13187200E+01, 0.23794900E-01, 0.23275500E+01, -.16136300E+01, 0.45627100E+00, -.12248400E+01, 0.16670500E+01, 0.24857100E+00, 0.13089600E+00, -.15819500E+00, 0.68233700E+00, -.10166000E+01, 0.12490700E+01, 0.42866400E+01, -.37474400E+01, 0.94631200E+00, 0.30310300E+01, 0.12544700E+01, -.10555100E+01, -.95805300E+00, 0.20421400E+00, -.40458800E+00, -.22967300E+01, -.10807200E+01, -.12300600E+00, -.12268100E+01, -.39795200E+00, 0.89839700E+00, -.46384900E+00, -.58574000E+00, -.19254900E+00, 0.40299700E+00, 0.58920700E+00, -.38314900E+01, 0.74299400E-01, -.71458600E+01, -.27004800E+00, 0.93049500E-01, -.52350300E-02, -.12676600E+00, 0.18030700E+00, 0.52766000E+00, -.46486200E+00, -.56964800E+00, -.21513000E+01, -.96697900E-01, 0.49862000E+00, -.46868900E-01, -.24117400E+00, -.16117700E+00, 0.94378100E+00, -.11006200E+01, -.34322900E+00, -.17370400E+01, 0.18455700E+01, 0.54812600E+01, 0.33394900E+00, 0.75157200E+00, 0.10303900E+02, 0.23712900E+01, -.35818200E+01, -.60166500E+01, -.69414800E+00, 0.21374800E+01, -.22509600E+01, 0.31700700E+00, 0.38381700E-01, -.83553300E+00, -.23389100E+01, -.44584400E+00, -.17968100E+01, -.25720700E+01, -.15758200E+01, -.10951100E+01, 0.51998900E+00, -.87599300E+00, 0.82454700E+00, -.26335200E+00, -.37870700E+00, -.15569100E+01, 0.85237500E+00, -.21608100E+01, 0.30052100E+00, 0.40156100E-01, -.61618200E+00, -.12085600E+01, -.11826900E+01, 0.98748900E-01, 0.19638200E-01, 0.33468200E+00, -.80841000E+00, 0.27258000E+00, 0.21361400E+00, 0.52907900E-01, -.93070700E+00, 0.37079900E+00, 0.16523500E+01, 0.55197700E-01, 0.61956700E-01, -.11310700E+00, -.45478500E+00, -.49607200E+00, -.11060600E+01, 0.83932500E+00, 0.18646900E+00, 0.18252600E+01, -.39114700E+00, 0.67182200E+00, 0.11486300E+00, 0.83027900E+00, -.17942100E+00, -.61579100E-01, 0.58973700E+00, -.71029800E-01, -.10204000E+01, 0.20032600E+00, -.68591100E+00, -.63247300E+00, -.20496500E+01, 0.33249100E+00, 0.22571900E+00, -.53556900E-01, 0.10200100E+01, 0.97563500E+00, 0.43228900E+00, -.20859400E-01, 0.23874400E+00, -.83045200E-01, 0.87786500E-02, 0.10656400E+01, 0.17185200E+00, 0.12147000E+00, -.54269500E+00, 0.30543500E+00, 0.14135400E+00, 0.27715700E+00, 0.85597100E+00, -.48095100E+00, 0.12019500E+01, -.54638600E+01, -.40129200E+00, 0.14959300E+01, -.69258900E+00, -.10051100E+01, -.29089900E+00, -.57340600E+00, 0.27885800E+00, 0.65918200E-01, -.26534100E+00, -.17458800E+01, 0.22943900E+00, 0.16547700E+00, 0.11871900E+01, -.32432600E-01, 0.53143100E-01, -.90002400E-01, 0.17863300E+01, -.64183300E+00, 0.87247600E-01, -.47547600E+00, 0.11405900E+01, -.40060100E+00, 0.15838400E+00, 0.21197200E+00, 0.11532000E+00, -.11968600E-01, 0.59626100E-01, 0.38819100E+00, -.22672200E+00, -.20704200E+01, 0.36867200E-01, 0.15584400E+00, -.31654400E+00, 0.12796500E+00, 0.64848000E+00, 0.47236700E+00, 0.55890500E+01, -.32385500E+02, -.19427500E+00, -.15401600E+00, -.53891900E+00, -.22424200E+00, 0.10522000E+00, -.45329700E+00, 0.86082100E+00, -.79367400E+00, 0.38113400E-01, -.39392800E+00, -.22165300E+00, -.36001700E+00, -.39415100E+00, 0.11427600E+01, -.44039100E+00, 0.19037600E+01, 0.42190600E+01, -.94209300E+01, 0.55769600E+00, -.36789500E+00 },
            { 0.36548900E+01, 0.93142500E+00, -.89298800E+00, -.15166500E+01, -.49536900E+01, -.67150600E+00, -.12478400E+01, 0.20532700E+00, 0.11473300E+01, -.13462300E+01, -.20024500E+00, -.20138000E+01, -.97740900E+00, 0.54886600E+00, -.31588800E+00, 0.63104400E+00, -.16683900E+01, 0.24646000E+00, 0.14931900E+01, 0.30759000E+00, -.11269500E+01, -.72963000E-01, -.58304600E+00, 0.10992400E+01, -.48429300E+00, -.56734600E+00, 0.77461600E-01, -.11840900E-01, -.42383200E-01, 0.26353400E+00, -.58215100E+00, -.79781600E-01, -.16314400E+00, 0.43943900E+00, 0.51210200E+00, 0.39726300E+01, 0.11319800E+00, -.45393100E-01, -.77036100E-01, 0.85899800E+00, -.29201000E+00, 0.98481300E-01, 0.41777000E+00, 0.12267300E+00, -.37177700E+00, -.14052700E+00, 0.22816500E+00, -.18979200E+01, -.71882000E-02, -.75525400E+00, -.20561600E+00, -.24506000E+00, -.71610100E+00, 0.40049400E+00, 0.42629500E+00, -.57646100E+00, -.27559500E+01, 0.75063900E-01, 0.64785400E+00, -.44879400E+00, 0.36761900E+00, -.39616300E+00, 0.56026000E+00, 0.23082700E+00, 0.37028000E+00, -.72450500E+00, -.21337600E+01, 0.22743200E+00, -.87094200E+00, 0.43641800E+01, 0.64374100E+00, -.41155900E+00, -.44694600E+00, 0.91699500E-02, 0.19719200E+00, 0.42453000E+00, 0.31537100E+00, -.26485800E+00, -.27326100E-01, -.94660500E-01, -.31813500E+00, 0.76874400E-01, -.18368000E+00, 0.23736900E+00, -.29056200E-01, 0.13704000E-01, 0.20099500E+00, 0.66174500E+00, 0.14531800E+01, 0.12402000E+00, 0.20335900E+00, -.29177600E-01, 0.11831300E-01, -.67979900E+00, -.19219200E+00, -.80289900E+00, -.12044200E+01, -.48116200E+00, -.13603200E+00, 0.12161500E+00, 0.88199300E-01, 0.18573300E+00, 0.25942200E+00, 0.12207800E+01, -.48401300E+00, -.15356500E+01, -.78607300E+00, 0.66050300E+00, 0.21228600E+01, 0.55304300E-01, 0.71509200E+00, 0.30016400E+00, -.40438800E+00, 0.17409800E+01, 0.63363800E-01, 0.62209000E-01, -.38489100E+00, 0.30811300E+00, 0.50751200E-02, -.26206100E+00, 0.17281700E+00, 0.63117100E+00, 0.14357300E+00, 0.55413300E+00, 0.26711700E+00, 0.16466200E+00, -.35857100E-01, -.34971900E-01, 0.47519100E+00, 0.28491400E+00, -.64900200E-01, 0.12628100E+00, 0.11799100E+00, 0.55083600E+00, 0.61730500E+00, -.78688300E-01, -.62161400E-01, -.11294000E+00, 0.10119800E+00, -.15849600E+00, -.16739800E+00, -.13716900E-01, -.81466700E-02, 0.15474200E+00, 0.12317000E-02, -.67903700E-01, 0.32539600E-01, 0.36161400E+00, 0.28381400E-01, -.54973700E+00, -.41405700E-01, 0.26760600E+00, 0.18220400E+00, -.13141000E+00, -.10364400E+00, -.13357400E-01, -.69530300E-01, 0.93119300E-01, -.10753900E+00, -.28245400E-01, -.46135700E-01, 0.82093900E-02, -.26731900E-01, 0.33024200E-01, -.40673700E-01, -.16265500E+00, 0.98254400E-01, -.54632700E-01, -.15385200E+00, -.48927400E+00, 0.58113600E+00, 0.38715700E+00, -.11337900E-01, -.33321900E-01, -.47442000E-01, 0.15611000E+00, -.57565500E-01, 0.17151300E+00, -.10480700E+00, 0.95917800E-01, -.55104200E-01, 0.63633300E-01, -.47191400E-01, -.15116300E-01, -.28721400E-01, -.13334800E+00, -.92472000E-01, 0.46068700E-01, 0.94629200E-01, -.38486400E-01, 0.13701100E+00, -.73946000E-01, -.74824400E+00, 0.83028500E-01, -.23004100E+00, -.15465900E+00, -.14281600E-01, -.14509000E-01, -.10003400E+00, -.17482200E-01, 0.18114800E-01, 0.75629500E-01, -.10112500E+00, -.33444700E-01, 0.67737100E-02, -.10287800E+00, 0.16430000E-01, 0.74688500E-01, 0.44795400E-01, -.12015200E+00, 0.97791000E-01, -.18629200E-02, 0.22276600E+00, -.99164700E-01, 0.87537800E-01, -.33686600E-01, -.20529900E+00, -.36282400E-02, 0.23365300E-01, -.18173300E-01, 0.15517200E-01, 0.33033200E-01, -.24472800E+00, -.60246900E-01, -.11343200E+00, -.10127900E+00, -.18119700E+00, 0.56526200E+00, 0.10112000E+01, 0.40241700E+01, -.42497500E+02, -.98774100E-01, 0.33105000E+00, 0.44191700E+00, 0.12360300E-01, -.56936700E-01, -.82461400E+00, 0.31760700E+00, -.50913500E+00, -.14047200E+00, 0.22219100E+00, 0.46597000E-01, 0.51632900E-01, -.72181000E-01, 0.42320000E+00, 0.10982400E+00, -.67821800E+00, 0.55919900E+00, 0.83059200E+01, -.39356400E+00, 0.60370700E+00 },
            { -.18596400E+01, -.18433200E+01, -.13399800E+00, 0.23932500E+01, 0.59520400E+01, 0.66119500E+00, 0.10459200E+01, -.69654000E+00, -.22461800E+01, 0.86447600E+00, -.34849200E+00, 0.65152600E+00, -.45223300E+00, 0.13197600E+01, -.11889300E+01, -.15352800E+00, 0.65718700E+00, 0.13509900E+01, -.23459800E+01, 0.35784500E-01, 0.21452000E+01, 0.44562700E+00, -.23159000E+00, -.15414700E+01, 0.95324400E-01, -.59592100E-01, -.69275800E+00, -.13187400E+00, -.19661000E+00, -.53062300E-01, -.58007400E+00, 0.49317300E+00, 0.25138900E+00, 0.27842000E+00, 0.20302700E+00, -.47349700E+01, 0.22164000E+00, -.81118000E-01, -.11530900E+00, -.86181200E+00, 0.19474800E+01, -.41749000E+00, -.31959700E+00, -.12599000E+01, 0.29496300E+00, 0.16038200E+01, -.49083300E+00, 0.16019200E+01, -.21554500E-01, 0.35176200E+00, -.32681100E+00, -.83256300E+00, 0.63478800E+00, -.29301700E+00, 0.70320600E+00, 0.79111300E-01, -.31212600E+00, -.29253400E+00, -.11897300E+00, 0.45681200E+00, -.10011000E+01, 0.97332900E+00, -.76065000E-01, 0.34483800E+00, 0.53829200E-01, 0.10961900E+00, -.13993900E+00, 0.15752800E+01, -.56887500E+00, -.62398300E+01, -.14609100E+00, 0.12438300E+01, 0.12647200E-01, -.46871700E-01, 0.19514500E-01, -.28340800E+00, -.28284600E+00, 0.11787400E+00, -.35745900E+00, -.19502400E+00, -.14549100E+00, 0.41218900E-01, -.16346900E+00, 0.14132200E+00, 0.41815400E+00, -.10342200E+00, -.26234900E+00, 0.44142400E+00, 0.13283300E+01, 0.46071200E-01, 0.29378300E+00, 0.22118900E-01, -.97804700E-01, -.15986000E+01, -.12377500E+01, -.31248300E+00, -.47392300E+00, 0.81597000E+00, -.73147000E+00, 0.10464200E+00, 0.33269000E+00, 0.14710500E+00, 0.12334900E+01, 0.34750300E+00, -.44374100E+00, -.23838200E+00, -.18341900E+01, 0.12142000E+01, 0.37412900E+01, -.19033900E+00, -.63657300E+00, 0.86473100E+01, 0.65943300E+00, -.21193100E+01, -.23027800E+01, -.18760000E+00, 0.83009400E+01, -.24483100E+00, -.19224800E+00, -.20494800E+00, -.85909700E-02, 0.47689100E+00, -.18622600E+00, 0.41367900E+00, 0.39223500E+00, 0.37311200E+00, 0.65554400E+00, -.72348100E-01, -.11924900E+01, 0.16693100E+00, -.53009100E-01, -.57795900E+00, 0.35243200E+00, 0.42597900E+00, 0.47142200E+00, 0.24439800E+00, 0.69099000E-01, 0.89619700E-02, -.16103700E+00, -.85403500E-01, -.54522000E+00, -.21742800E-01, 0.71571000E-01, -.14996300E+00, 0.16241500E+00, -.79525800E-01, -.40000800E+00, 0.16764500E+01, -.97902800E-01, 0.11471200E+01, 0.96163600E-01, 0.16060200E+00, -.39108000E+00, -.57525000E+00, -.28425200E+00, -.78816200E+00, -.37432400E-01, -.26595300E+00, -.90180500E+00, 0.12670100E+01, -.21040800E+00, -.21611000E-01, -.68425800E+00, -.75281600E-01, 0.39349600E-03, -.51790500E+00, 0.25003900E+00, 0.66335800E+00, -.65678400E-01, -.36978800E-01, 0.19261800E+00, -.53257700E-01, 0.67337100E-03, -.22473500E+00, 0.67242100E-02, -.13215000E+00, -.44076400E+00, -.76152900E-01, 0.28261100E-01, -.80314000E-01, 0.20505900E-01, 0.13761900E+00, -.29075800E+00, -.20413000E-01, -.74932700E-01, 0.62564800E+00, -.13472700E+00, -.22044400E+00, -.67741000E+00, -.10214200E+00, 0.39057300E+00, -.46349000E+00, 0.13905100E+01, 0.13538900E+00, -.61417900E+00, 0.21996900E+00, 0.29527100E+00, 0.79045000E-01, -.17276200E-01, -.48023800E-01, 0.11043800E+00, -.33099000E-01, 0.71265300E-01, -.61110000E-02, -.34624100E-01, 0.14327900E-01, -.38126800E-01, 0.12605300E+00, -.20731900E-01, -.26016800E+00, 0.80125100E-01, 0.14893600E-01, 0.23067000E-01, -.18138100E+00, 0.35875200E-02, -.46783400E-03, -.32544500E-01, -.50661700E-01, 0.17968300E-02, -.24420200E-01, 0.34887200E-01, 0.97651700E-01, 0.53720200E+00, -.11479300E+00, -.17573800E+00, 0.86932100E-01, -.28661600E+00, 0.31237300E+00, -.28516200E+00, -.52070200E+00, 0.42996500E+01, -.12221800E+00, 0.71521100E-01, -.68790600E+00, 0.64398200E-01, -.28661100E-01, -.46141100E-01, 0.13617400E-01, -.22040600E-02, -.56942900E-01, 0.21117900E-01, -.18569800E-01, -.10258500E-01, 0.84505500E-02, -.95567900E-01, -.24097000E-01, -.42550400E-01, -.58071700E-02, 0.19399200E-01, 0.10648000E+01, -.58917500E-01 },
            { -.81102600E+00, -.17609600E+01, -.38670300E+00, 0.15625500E+01, 0.58864500E+01, 0.10618800E+01, 0.61340100E+00, -.31026100E+00, 0.27955500E+00, 0.66733700E+00, -.61574300E+00, 0.35804600E-01, -.22424500E+00, 0.91773600E+00, -.74622400E-01, -.20602900E+00, 0.30392900E+00, 0.57766700E+00, -.15845800E+01, -.52743200E-01, 0.19098200E+01, 0.31714500E+00, 0.62176800E+00, -.25628200E+01, -.53041700E-01, 0.29601900E+00, -.47218900E+00, -.56264200E+00, -.15164300E+00, -.13025900E+00, -.54909200E+00, 0.43194600E+00, -.13011700E+00, 0.23822500E+00, 0.38308000E+00, -.12327200E-02, 0.40449100E+00, -.16012300E+00, -.21554900E+00, -.14608900E+00, 0.16772600E+01, -.64063700E+00, -.38836300E+00, -.11695100E+01, 0.34806500E+00, 0.35882800E+00, -.11568900E+01, 0.14566800E+01, -.17457200E+01, 0.61207800E+00, -.42751100E+00, 0.99233800E+00, 0.17520400E+01, -.29158600E+00, -.39823500E+00, 0.69285200E+00, 0.20344200E+01, 0.28688900E+00, -.44973100E+00, 0.13217500E+01, 0.10856700E+01, -.72526500E+00, 0.23071300E+00, 0.22871900E+00, -.42012400E+00, 0.69408300E+00, 0.11094300E+01, 0.48853000E+00, -.32225300E+00, -.21580000E+01, 0.74371900E+00, 0.73667700E+00, -.25573400E+00, -.11287000E+00, -.27823300E-01, -.47156700E+00, -.25913100E+00, 0.84915400E-01, -.46060000E+00, -.27782500E-01, -.48147700E+00, -.26558100E+00, -.11243300E+00, -.33719900E+00, 0.36363400E+00, 0.75934200E-01, 0.30690600E+00, 0.37579900E+00, 0.13861800E+01, 0.92780100E-01, 0.13394600E+00, 0.63174500E-01, -.23034700E-01, 0.81499300E-01, 0.17643100E+00, -.44799000E+00, -.37399500E+00, -.31873600E+00, 0.20661500E+00, 0.13834100E+00, 0.23705700E+00, 0.12820300E-01, -.79371400E+00, -.76544000E+00, -.11223100E+00, -.26519200E+00, -.49414600E+00, -.73369700E+00, 0.36259200E+01, -.50649500E-01, 0.30757400E+00, 0.91760500E+01, 0.96873400E-01, -.15411400E+01, -.53040200E+00, 0.20124500E+00, 0.54069000E+01, -.45763400E+00, 0.24758100E+00, -.57235800E+00, 0.27224900E+00, 0.26241900E+00, 0.21704900E+00, 0.57799000E+00, 0.31724300E-01, 0.86384900E+00, 0.19527400E+01, 0.89407100E-01, -.11897500E+01, 0.58907600E+00, -.21293700E+00, -.14545200E+00, 0.55496800E+00, 0.55534900E+00, 0.24946700E+00, 0.57316000E+00, 0.21465900E+00, -.25534200E+00, -.90281800E-01, -.32999600E-01, -.85094100E+00, -.65304500E-01, 0.49257100E-02, -.16535900E+00, 0.44078700E-01, 0.21903500E-01, -.11729300E+00, 0.10281300E+01, -.86187300E-02, 0.98197300E+00, 0.84622400E-01, 0.10129800E-01, -.23478000E+00, 0.12393900E+00, 0.14022600E+00, -.24651600E+00, -.15067900E+00, -.31659800E+00, -.89427500E+00, 0.49053400E+00, 0.34597200E+00, -.82571500E-01, -.10847700E+00, 0.53316600E-01, -.22802100E+00, -.76422600E-01, 0.10837600E+00, 0.79513200E+00, 0.17762800E+00, -.14022700E+00, -.23906200E+00, -.11730800E+01, 0.36888900E-01, 0.51979700E-01, 0.71266200E-01, 0.30183000E-01, -.58284900E-01, -.71695600E-01, 0.81139200E-01, -.73191900E-01, 0.49673200E-01, -.51864700E-01, -.49898300E-01, -.15946900E-01, -.12403700E+00, 0.29521100E+00, -.35707700E+00, -.18025600E-01, -.52879500E+00, -.50716900E-02, -.75968900E-01, -.49053300E-01, 0.92875500E+00, 0.90848000E-01, -.19493300E+00, -.39406200E-01, -.97544600E-01, 0.27756600E-01, 0.61560800E+00, 0.50660500E-01, -.12007200E+00, -.83149700E-02, 0.19686000E+00, 0.50876500E-01, -.66998800E-01, -.28999800E+00, 0.45341800E-02, -.29545300E+00, 0.15777200E-02, 0.23659400E+00, 0.17231800E+00, 0.92322100E-01, -.15531300E+00, 0.15985500E+00, -.42145100E-01, -.14510300E-02, 0.11857500E+00, 0.24317800E-01, -.47636400E-01, -.29766700E-01, 0.75192200E-01, -.41920000E-01, 0.57507600E+00, 0.17169200E+00, -.22368400E+00, 0.16586400E-01, -.85503600E-01, 0.16687300E+00, 0.26329600E+00, -.54279300E+00, 0.20383400E+01, -.49647700E-01, 0.12178600E+00, 0.79911300E-01, -.23953900E-01, 0.96901300E-01, 0.97274700E-01, -.76749900E-01, 0.60096000E-02, -.10120100E-01, 0.20380300E-01, 0.32479600E-01, 0.94302500E-02, -.47526400E-01, -.64806600E-01, 0.49546700E-01, -.86703700E-01, 0.76374200E-02, 0.52906300E-01, -.55331900E-01, 0.14035000E+01 }
        },
        {
            { -.22764900E+06, 0.10835200E+06, 0.97059200E+05, 0.90260300E+04, 0.85081500E+04, 0.65412800E+05, -.15517700E+05, 0.69120100E+05, 0.24933800E+05, -.53501500E+06, 0.26154500E+06, 0.24119500E+06, 0.99642100E+04, 0.23559400E+05, 0.16288900E+06, -.85457700E+04, 0.20348100E+06, 0.54404500E+05, -.35287000E+06, 0.16225200E+06, 0.16308400E+06, -.82892200E+04, -.44039600E+04, 0.11325900E+06, 0.16399400E+04, 0.11925200E+06, 0.19147900E+05, -.17885700E+06, 0.85551300E+05, 0.76323400E+05, 0.99685500E+04, 0.57714600E+04, 0.53394800E+05, -.68865600E+04, 0.71247000E+05, 0.15529400E+05, 0.35303700E+06, -.16413300E+06, -.17286700E+06, 0.28528300E+04, -.35781300E+04, -.10736700E+06, 0.11526000E+05, -.13048100E+06, -.27973300E+05, -.41230700E+06, 0.19943800E+06, 0.18874700E+06, 0.12946300E+05, 0.14592700E+05, 0.12073100E+06, -.22078200E+05, 0.14616900E+06, 0.44208900E+05, -.19434800E+06, 0.95922500E+05, 0.76766700E+05, 0.11790600E+05, 0.13830000E+05, 0.58584400E+05, -.10971000E+04, 0.83721200E+05, 0.21073900E+05, -.90816000E+05, 0.43110400E+05, 0.45342900E+05, -.92612800E+04, -.88675100E+04, 0.32305400E+05, 0.57407400E+04, 0.33279500E+05, -.25403100E+04, 0.78105700E+05, -.38301300E+05, -.29311200E+05, -.48769600E+04, -.24517100E+04, -.23574800E+05, 0.18302800E+04, -.51622300E+05, -.90702700E+04, -.11617500E+06, 0.56439600E+05, 0.43855300E+05, -.11489000E+04, 0.22353400E+04, 0.40181600E+05, 0.12084100E+05, 0.46652600E+05, 0.60967800E+04, -.13442700E+06, 0.66740800E+05, 0.46842600E+05, 0.12230200E+05, 0.96888000E+04, 0.39116000E+05, -.31704900E+04, 0.72752400E+05, 0.18928300E+05, -.48764300E+06, 0.23450200E+06, 0.23356000E+06, 0.11596900E+04, 0.12199500E+05, 0.15059900E+06, -.69551300E+04, 0.18173300E+06, 0.41095200E+05, 0.10781200E+06, -.48469600E+05, -.43768500E+05, -.94510400E+03, 0.52332300E+03, -.34917100E+05, -.36911700E+04, -.41569500E+05, -.82378300E+04, 0.21680400E+06, -.10610500E+06, -.10590600E+06, -.48929000E+03, -.10960000E+05, -.66482600E+05, 0.76417200E+03, -.84438400E+05, -.20045000E+05, -.13638900E+06, 0.66590800E+05, 0.56745600E+05, 0.74313000E+04, 0.64790600E+04, 0.40108200E+05, -.51036800E+04, 0.60351200E+05, 0.16693000E+05, 0.35771300E+06, -.17048700E+06, -.17109200E+06, -.36097800E+04, -.58383500E+04, -.10872200E+06, 0.11779200E+05, -.12955100E+06, -.29787500E+05, -.24208800E+06, 0.11572900E+06, 0.11983100E+06, -.16893300E+05, -.16864300E+05, 0.81806000E+05, 0.65042300E+04, 0.84492100E+05, 0.37249100E+04, -.31714600E+06, 0.15599700E+06, 0.15041400E+06, 0.27529700E+04, 0.81491800E+04, 0.97150900E+05, -.88696200E+04, 0.11790600E+06, 0.26278800E+05, 0.11178500E+06, -.54228000E+05, -.38576200E+05, -.31184900E+04, -.43521300E+04, -.37305500E+05, -.82584000E+04, -.45145800E+05, -.75514400E+04, -.29550000E+06, 0.14016300E+06, 0.12775000E+06, 0.12921400E+05, 0.63049200E+04, 0.89537300E+05, -.98324400E+04, 0.11554800E+06, 0.22807500E+05, -.32517400E+06, 0.15938100E+06, 0.15532200E+06, 0.44066600E+04, 0.15389600E+05, 0.98246700E+05, -.76096800E+04, 0.12526300E+06, 0.31938400E+05, 0.40095500E+06, -.19717900E+06, -.18873800E+06, -.50990800E+04, -.12575700E+05, -.12246300E+06, 0.10846700E+05, -.15010800E+06, -.34398100E+05, -.53806600E+06, 0.24879400E+06, 0.23835300E+06, 0.18458300E+05, 0.14530300E+05, 0.15418500E+06, -.39175300E+05, 0.16523500E+06, 0.58022100E+05, 0.12079200E+06, 0.50084400E+04, 0.43689600E+05, 0.56796500E+05, 0.69407600E+05, 0.37334500E+05, -.27473900E+05, 0.88796600E+05, 0.85632700E+05, -.11233000E+06, -.95155400E+05, -.10713400E+06, -.22503200E+04, -.10420900E+06, -.71310700E+05, -.98222600E+05, -.31154800E+04, -.80406700E+05, 0.49041100E+04, -.88329100E+05, -.68334500E+05, -.45647700E+05, -.12412500E+04, -.12699600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23342700E+00, 0.71185200E+04, -.20819800E+05, 0.17871700E+05, 0.15300700E+05, -.22800700E+04, 0.54705200E+04, 0.13884200E+05, 0.13500100E+05, -.10996700E+06, 0.62235800E+05, 0.96534500E+03, 0.14325600E+05, 0.11610600E+05, 0.94300900E+05, 0.21186300E+06, 0.24499600E+06, 0.32168100E+05, -.10149800E+06, 0.72301100E+05, 0.36244900E+05, -.97767900E+04, 0.15837700E+05, 0.71739800E+05, 0.12665300E+06, 0.10148400E+06, 0.20732500E+05, -.25845100E+05, 0.19575400E+05, -.14430700E+05, 0.31380800E+05, 0.30033700E+05, 0.15901100E+04, 0.22449900E+05, 0.51633800E+05, 0.29402200E+05, -.13286800E+06, 0.47805600E+05, 0.78428100E+05, -.23132700E+05, -.20370000E+05, 0.32964400E+05, -.65562000E+05, -.69758000E+05, -.13741700E+05, 0.13209000E+06, -.56156800E+05, -.97393100E+05, 0.14530100E+05, -.63659400E+04, -.10425300E+05, 0.10784900E+06, 0.10590800E+06, -.47991000E+04, -.18390700E+06, 0.93170900E+05, 0.57950600E+05, 0.34748800E+05, 0.40423300E+05, 0.68160100E+05, 0.71180300E+05, 0.11878400E+06, 0.49061800E+05, 0.14295500E+05, -.31804800E+04, -.72318000E+04, -.39084100E+04, 0.46112100E+04, 0.29210600E+04, 0.24264300E+05, 0.70051000E+04, 0.34208800E+04, 0.53632600E+04, -.34333300E+04, 0.29408700E+05, -.34980000E+05, -.24351100E+05, 0.95518200E+04, -.12783600E+05, -.59876100E+05, -.27170100E+05, -.15983900E+06, 0.82147000E+05, 0.63857600E+05, -.81511300E+03, 0.19868500E+05, 0.68441400E+05, 0.62307000E+05, 0.72143600E+05, 0.28384300E+05, -.18600700E+06, 0.92911300E+05, 0.42330500E+05, 0.56653600E+05, 0.59545400E+05, 0.39427500E+05, 0.24990900E+05, 0.98529500E+05, 0.69158700E+05, -.19923300E+04, 0.15329900E+05, -.18974400E+05, 0.12250200E+05, 0.17710600E+05, 0.42133800E+05, 0.15213300E+06, 0.16082200E+06, 0.23780300E+05, 0.17051500E+06, -.93704000E+05, -.76069500E+05, 0.18131400E+04, -.15950000E+05, -.82985300E+05, -.90516300E+05, -.87916800E+05, -.25458600E+05, 0.86779100E+05, -.46026300E+05, -.39347600E+05, -.13583400E+05, -.15542500E+05, -.50067500E+05, -.92840100E+05, -.11395100E+06, -.24402300E+05, 0.58509300E+03, 0.18049900E+04, -.23875100E+05, 0.20353200E+05, 0.11507700E+05, 0.61256400E+04, 0.48811300E+05, 0.72446100E+05, 0.16534000E+05, -.89870400E+05, 0.31434700E+05, 0.64985200E+05, -.34978300E+04, 0.65663200E+04, -.10815700E+05, -.12322400E+06, -.10910800E+06, 0.58597500E+04, 0.18807100E+04, 0.76819800E+04, -.20226600E+04, -.12683900E+05, 0.59094900E+04, 0.24558300E+05, 0.77474200E+05, 0.39554200E+05, 0.72247600E+04, 0.18062800E+06, -.86514100E+05, -.10969800E+06, 0.32932300E+04, -.17673000E+05, -.31715400E+05, 0.64316900E+05, 0.61573000E+05, -.18276600E+05, 0.14202700E+06, -.73378700E+05, -.39159300E+05, -.99628800E+04, -.23264000E+05, -.48621700E+05, -.32929900E+05, -.52809200E+05, -.32465700E+05, -.99744600E+04, 0.17795900E+05, -.38981800E+05, 0.42057200E+05, 0.36906000E+05, 0.24627200E+04, 0.47653600E+05, 0.77899800E+05, 0.35189100E+05, 0.39338600E+04, 0.17799500E+04, -.22424200E+05, 0.17258900E+05, 0.35197700E+04, 0.31138900E+05, 0.10611800E+06, 0.12877800E+06, 0.11358100E+05, -.16849000E+06, 0.79606000E+05, 0.10883200E+06, -.11058800E+05, 0.13522000E+05, 0.22608800E+05, -.80982600E+05, -.87843700E+05, 0.12622400E+05, 0.67332600E+05, -.45868400E+04, -.83697400E+05, 0.43717900E+05, 0.38285000E+05, -.22940400E+05, 0.27601700E+05, 0.32543700E+05, 0.28367600E+05, 0.16185100E+05, -.87904900E+05, -.40660100E+05, 0.72751500E+04, -.72150000E+04, 0.96510600E+05, -.49471500E+04, -.29955100E+05, 0.38940000E+05, -.64483000E+04, 0.97911600E+05, 0.15760900E+05, 0.11199900E+06, 0.18587700E+05, 0.72640400E+05, -.11504300E+05, 0.18521700E+05, -.34491500E+05, 0.14347000E+06, 0.10796300E+06, -.16576500E+04, 0.75633300E+05, 0.14742200E+06, 0.86641900E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.46185100E+00, 0.28604200E+01, 0.61666400E+05, -.28759100E+05, 0.30859700E+04, -.74936800E+04, -.31889600E+05, -.76041700E+05, -.10016500E+05, -.30057600E+06, 0.15160000E+06, 0.30174700E+06, 0.12211300E+06, 0.28803800E+06, -.22688300E+06, -.86498000E+06, -.86691400E+06, 0.16489800E+06, 0.62616200E+06, -.30471300E+06, -.26952700E+06, 0.86297000E+05, 0.12988000E+06, -.36702900E+06, -.47095000E+06, -.48739400E+06, 0.12367900E+05, -.14777900E+06, 0.79223500E+05, 0.15086400E+06, -.27107500E+05, 0.60494200E+05, 0.34588100E+04, -.16198200E+06, -.22530500E+06, 0.33373200E+05, 0.75705200E+06, -.38052400E+06, -.41037300E+06, -.49656200E+05, -.16577700E+06, -.11879100E+06, 0.32731600E+06, 0.31075200E+06, -.13895800E+06, -.81666400E+06, 0.41233100E+06, 0.49761400E+06, 0.66391300E+05, 0.25504800E+06, 0.65783100E+05, -.47433200E+06, -.42424800E+06, 0.20692300E+06, 0.16449900E+06, -.80312900E+05, 0.11987700E+05, -.29166000E+05, 0.30342400E+05, -.15109000E+06, -.31114100E+06, -.39080600E+06, -.12364900E+05, 0.17126200E+06, -.81141900E+05, -.85386700E+05, 0.30667200E+05, 0.55003400E+05, -.96046900E+05, -.11304100E+06, -.11456200E+06, 0.12193600E+05, 0.42567200E+06, -.21300600E+06, -.30057600E+06, 0.28613500E+05, -.56695900E+05, -.10053200E+06, 0.13383300E+06, 0.19918500E+06, -.50532000E+05, 0.57746600E+06, -.28601500E+06, -.24300500E+06, 0.27325300E+05, 0.98561500E+04, -.25996900E+06, -.22937100E+06, -.28518400E+06, -.56533200E+05, 0.52312800E+05, -.25218000E+05, 0.11395900E+06, -.78008500E+05, -.22898100E+05, -.38606600E+05, -.18155800E+06, -.31707300E+06, -.51693100E+05, -.36739100E+06, 0.19144700E+06, 0.23679600E+06, 0.11327400E+06, 0.28324900E+06, -.14966000E+06, -.68632600E+06, -.66949300E+06, 0.17921600E+06, -.63893300E+06, 0.31459200E+06, 0.29421600E+06, -.39332400E+05, -.55388400E+05, 0.32710400E+06, 0.34503300E+06, 0.36246000E+06, 0.23406700E+05, 0.57203300E+05, -.28166800E+05, -.37781400E+05, -.35383300E+05, -.99306400E+05, 0.11835700E+06, 0.38266300E+06, 0.39160900E+06, -.48220400E+05, -.36174900E+06, 0.18176100E+06, 0.24674500E+06, 0.89976100E+04, 0.94546000E+05, 0.32534600E+05, -.23944000E+06, -.25326000E+06, 0.70351400E+05, 0.50145800E+06, -.25800400E+06, -.30610300E+06, -.85172100E+05, -.25833100E+06, 0.50613600E+05, 0.51608100E+06, 0.46352200E+06, -.19232600E+06, 0.44623600E+06, -.21559800E+06, -.21989900E+06, 0.84406500E+05, 0.13837600E+06, -.26446200E+06, -.33154700E+06, -.32900200E+06, 0.33213500E+05, -.84215300E+06, 0.42346600E+06, 0.47491100E+06, 0.78369400E+05, 0.24813300E+06, 0.10703400E+06, -.32777700E+06, -.28801900E+06, 0.20864600E+06, -.48195000E+06, 0.23661100E+06, 0.15047800E+06, 0.75322200E+04, 0.12771500E+05, 0.18368900E+06, 0.13375400E+06, 0.21180600E+06, 0.71084200E+05, -.24721000E+06, 0.13255100E+06, 0.24677900E+06, -.26531200E+05, 0.12518800E+06, -.13626600E+05, -.28647000E+06, -.35840300E+06, 0.76057800E+05, -.50679400E+06, 0.25280000E+06, 0.30732700E+06, 0.56755100E+05, 0.19576300E+06, -.32889900E+05, -.46747200E+06, -.45500600E+06, 0.14375600E+06, 0.89699100E+06, -.45075200E+06, -.51642700E+06, -.82339800E+05, -.30299700E+06, -.77728300E+05, 0.43293200E+06, 0.40143400E+06, -.24570500E+06, -.25838100E+06, 0.13295400E+06, 0.27304300E+06, -.46167600E+05, 0.59470600E+05, 0.32190700E+05, -.14847000E+06, -.20816000E+06, 0.31542300E+05, 0.19288800E+05, 0.51322500E+06, 0.39708400E+05, 0.15700500E+06, 0.64126100E+05, -.33162300E+06, 0.13678000E+06, 0.87020300E+05, 0.68979600E+05, 0.39052000E+05, -.41369000E+06, -.52000200E+05, -.30246000E+06, -.15955500E+06, -.23095800E+06, 0.92205900E+05, 0.19329900E+05, -.88901600E+05, -.37842600E+06, -.44251300E+06, -.51891000E+05, -.15998200E+06, -.39104100E+06, -.47605900E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.26381900E+00, -.24573200E+00, 0.24474800E+00, -.91234100E+04, -.11335200E+05, 0.10152900E+05, 0.23359500E+05, 0.37139600E+05, -.88419400E+04, 0.13557600E+05, -.70582500E+04, 0.11510500E+05, -.22033900E+06, -.19502200E+06, 0.21195800E+06, 0.51326800E+06, 0.48552000E+06, -.14211800E+06, -.50416900E+06, 0.24987400E+06, 0.25105700E+06, -.12718500E+06, -.51464100E+05, 0.26873800E+06, 0.30364100E+06, 0.31058700E+06, -.32038800E+04, 0.19438800E+06, -.98119300E+05, -.89053900E+05, -.37639900E+05, -.71077400E+05, -.15148100E+05, 0.90767100E+05, 0.90975700E+05, -.69556500E+05, -.24737700E+06, 0.12412500E+06, 0.11496100E+06, 0.11186800E+06, 0.12089200E+06, -.23712300E+05, -.21689200E+06, -.20141200E+06, 0.10710600E+06, 0.34118500E+06, -.17115200E+06, -.16427200E+06, -.88788100E+05, -.13861300E+06, -.45256000E+04, 0.22413100E+06, 0.19942500E+06, -.11986900E+06, 0.71403100E+05, -.35816900E+05, -.14564100E+05, -.73332600E+05, -.79807000E+05, 0.67089900E+05, 0.18743800E+06, 0.18148600E+06, -.72144800E+05, -.19218700E+06, 0.95042100E+05, 0.96105600E+05, -.53147500E+05, -.19703200E+05, 0.96382700E+05, 0.10043200E+06, 0.10191800E+06, -.26357600E+04, -.33815300E+06, 0.16871800E+06, 0.15509400E+06, 0.46207600E+05, 0.87883800E+05, 0.56245500E+05, -.87969200E+05, -.83876700E+05, 0.87332300E+05, -.36788100E+06, 0.18314800E+06, 0.19442300E+06, -.10453500E+06, -.25291600E+05, 0.19592700E+06, 0.20618800E+06, 0.20640500E+06, 0.43829800E+04, 0.21553200E+06, -.10752100E+06, -.86580700E+05, -.61278100E+05, -.85151500E+05, -.17221600E+04, 0.13508900E+06, 0.14047800E+06, -.75714300E+05, 0.40666100E+05, -.21909000E+05, -.37044500E+03, -.19488800E+06, -.18022600E+06, 0.17444600E+06, 0.42203600E+06, 0.39621700E+06, -.13662500E+06, 0.29014700E+06, -.14396500E+06, -.15767600E+06, 0.73737700E+05, 0.40903600E+05, -.17010200E+06, -.19494600E+06, -.18701500E+06, 0.39687200E+04, -.39994500E+05, 0.19873100E+05, 0.87071900E+04, 0.76205000E+05, 0.85269300E+05, -.81428100E+05, -.20500900E+06, -.19585400E+06, 0.69801300E+05, 0.23114000E+06, -.11550800E+06, -.10676900E+06, -.56477800E+05, -.84087100E+05, -.10302200E+05, 0.13015700E+06, 0.11425700E+06, -.73327900E+05, -.19787400E+06, 0.10032000E+06, 0.91348300E+05, 0.82279800E+05, 0.12609000E+06, -.41333500E+05, -.23209700E+06, -.21298600E+06, 0.10715800E+06, -.43692200E+06, 0.21655400E+06, 0.21875500E+06, -.11872400E+06, -.51540900E+05, 0.22517900E+06, 0.24287600E+06, 0.24623200E+06, -.21463300E+04, 0.28131400E+06, -.14096100E+06, -.13361100E+06, -.93638700E+05, -.12310900E+06, 0.25587800E+04, 0.18552200E+06, 0.16899800E+06, -.11387900E+06, 0.27882400E+06, -.13846800E+06, -.14811900E+06, 0.82417700E+05, 0.18843100E+05, -.14357300E+06, -.15473200E+06, -.16110500E+06, -.31684700E+04, 0.27642400E+06, -.13979600E+06, -.12427800E+06, -.60492300E+05, -.11155400E+06, -.11917100E+05, 0.15155800E+06, 0.14808600E+06, -.10881000E+06, 0.23643300E+06, -.11789100E+06, -.99512800E+05, -.10024000E+06, -.13254700E+06, 0.44822600E+05, 0.24646100E+06, 0.22881800E+06, -.12000700E+06, -.33471400E+06, 0.16757800E+06, 0.15499700E+06, 0.11697000E+06, 0.15950900E+06, -.15596800E+05, -.24150800E+06, -.22200300E+06, 0.14746100E+06, 0.12990700E+06, -.65628500E+05, -.56054300E+05, -.35295700E+05, -.57295100E+05, -.19447200E+04, 0.83107900E+05, 0.99394300E+05, -.46316700E+05, 0.92225000E+04, -.28501700E+06, -.91779200E+04, -.99875800E+05, 0.47601000E+05, 0.13364700E+06, -.14451400E+06, 0.22251500E+05, -.49348000E+05, -.82834000E+05, 0.22419900E+06, -.41776400E+05, 0.91719800E+05, 0.50954300E+05, 0.16051300E+06, -.10951400E+06, -.10802300E+06, 0.53624500E+05, 0.13564600E+06, 0.19893600E+06, -.42378800E+05, 0.10211900E+06, 0.14749400E+06, 0.26830900E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21044500E+00, 0.13010400E+01, 0.29620700E+00, -.11976800E+01, -.96573300E+04, 0.48071900E+04, 0.87874400E+04, 0.26106200E+05, -.38556700E+04, 0.35954200E+06, -.18031600E+06, -.15489000E+06, -.71236700E+05, -.17126500E+06, -.57017300E+04, 0.20806000E+06, 0.21220700E+06, -.13475900E+06, -.14619800E+06, 0.63990200E+05, 0.71233500E+05, -.39969300E+04, -.65284600E+05, 0.80321200E+05, 0.83242200E+05, 0.11530400E+06, -.19878300E+05, 0.11063600E+06, -.61383500E+05, -.43741300E+05, -.30053400E+05, -.76077500E+05, 0.55245900E+04, 0.68998600E+05, 0.88199500E+05, -.58698000E+05, -.31479800E+06, 0.16100000E+06, 0.14628500E+06, 0.44187300E+05, 0.10664200E+06, 0.39682000E+05, -.95825100E+05, -.97969400E+05, 0.92115700E+05, 0.28254700E+06, -.14599000E+06, -.13188100E+06, -.44706500E+05, -.12241700E+06, -.20149500E+05, 0.13365300E+06, 0.13898700E+06, -.10169100E+06, 0.15902700E+06, -.80599700E+05, -.55894900E+05, -.39495800E+05, -.84397900E+05, 0.89750700E+04, 0.97689300E+05, 0.10236400E+06, -.68673900E+05, -.61309200E+05, 0.26032400E+05, 0.30668400E+05, -.79426000E+03, -.28813500E+05, 0.29177700E+05, 0.23197500E+05, 0.34878100E+05, -.91119700E+04, -.28314200E+06, 0.14140700E+06, 0.12145700E+06, 0.44237100E+05, 0.80551500E+05, 0.42929300E+05, -.72204400E+05, -.70077400E+05, 0.79692300E+05, -.57368600E+05, 0.26697600E+05, 0.38167200E+05, -.96653200E+04, -.35067700E+05, 0.41187300E+05, 0.37750700E+05, 0.53150200E+05, -.12597000E+05, 0.24347500E+06, -.12156100E+06, -.92905600E+05, -.49166300E+05, -.85018400E+05, -.22685900E+05, 0.88349000E+05, 0.95518500E+05, -.79640300E+05, 0.26529100E+06, -.14102900E+06, -.11037000E+06, -.64099100E+05, -.17651200E+06, 0.18885000E+05, 0.18140900E+06, 0.19383900E+06, -.13217900E+06, 0.98782400E+05, -.44645500E+05, -.60655000E+05, 0.15527200E+05, 0.51454700E+05, -.70647400E+05, -.79998000E+05, -.86744300E+05, 0.26074700E+05, -.16727800E+06, 0.82966000E+05, 0.72093700E+05, 0.34741400E+05, 0.79604700E+05, -.46295000E+04, -.99655700E+05, -.94832400E+05, 0.62080900E+05, 0.21808400E+06, -.10982900E+06, -.97454200E+05, -.35866400E+05, -.74401300E+05, -.23307700E+05, 0.80238500E+05, 0.74774700E+05, -.67692500E+05, -.17496200E+06, 0.96030300E+05, 0.76622900E+05, 0.40437800E+05, 0.12337500E+06, -.13590900E+05, -.13776900E+06, -.14753300E+06, 0.91951800E+05, -.14905500E+06, 0.66788000E+05, 0.74688700E+05, -.49840400E+04, -.66533600E+05, 0.75404900E+05, 0.67775200E+05, 0.94465600E+05, -.23670100E+05, 0.25441800E+06, -.13002000E+06, -.11721100E+06, -.38928400E+05, -.11060400E+06, -.24053200E+05, 0.96581600E+05, 0.10611200E+06, -.88846600E+05, 0.35509400E+05, -.14321000E+05, -.29746100E+05, 0.86220500E+04, 0.27562300E+05, -.23854800E+05, -.23535000E+05, -.42583100E+05, 0.86548700E+04, 0.15624600E+06, -.88297100E+05, -.58104100E+05, -.44667200E+05, -.12029200E+06, 0.13708900E+05, 0.11158700E+06, 0.13940700E+06, -.90423200E+05, 0.29855800E+06, -.14851800E+06, -.12692900E+06, -.51161700E+05, -.11639500E+06, -.18104100E+05, 0.13244400E+06, 0.12781700E+06, -.97809100E+05, -.30190900E+06, 0.15357300E+06, 0.13537800E+06, 0.51714400E+05, 0.14951600E+06, 0.16033000E+05, -.13618400E+06, -.14658800E+06, 0.11872600E+06, 0.83181700E+05, -.46720300E+05, -.28725300E+05, -.14999000E+05, -.51695900E+05, 0.27242400E+03, 0.48085700E+05, 0.80854000E+05, -.38029500E+05, -.54628300E+05, -.16372600E+06, 0.30606000E+05, -.92572900E+05, -.51414200E+05, 0.67326700E+05, -.59602100E+05, -.24675100E+05, -.76147700E+05, -.12378700E+05, 0.11890200E+06, 0.15997600E+05, 0.46357400E+05, 0.83298600E+05, 0.41459400E+05, -.39393300E+05, -.15393600E+05, 0.83585300E+05, 0.40001400E+05, 0.12350300E+06, 0.53059800E+05, -.51381300E+04, 0.43356900E+05, 0.14907300E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19176500E-01, 0.93364600E+00, 0.31125000E+00, -.46514100E+00, -.75884800E+00, 0.53909500E+04, 0.13740900E+05, 0.29601000E+05, -.39513800E+03, 0.32744000E+06, -.16343300E+06, -.13445000E+06, -.12835400E+06, -.14597400E+06, 0.42826300E+05, 0.30954300E+06, 0.30242600E+06, -.13363000E+06, -.99007500E+05, 0.48837200E+05, 0.47414800E+05, -.39441800E+05, 0.18884300E+05, 0.74605800E+05, 0.12577100E+06, 0.10979100E+06, 0.15451300E+05, 0.22761100E+06, -.11429600E+06, -.10022700E+06, -.35588100E+05, -.52461100E+05, -.31838800E+05, 0.67572500E+05, 0.68535500E+05, -.57794600E+05, -.36318800E+06, 0.18181500E+06, 0.16852400E+06, 0.69202500E+05, 0.91942300E+05, 0.37658000E+05, -.14302100E+06, -.12645200E+06, 0.97139000E+05, 0.38561500E+06, -.19263700E+06, -.18185600E+06, -.60027000E+05, -.96951200E+05, -.44232800E+05, 0.15835100E+06, 0.14416800E+06, -.98352800E+05, 0.16677800E+06, -.83129100E+05, -.55189800E+05, -.60267300E+05, -.76780700E+05, 0.21704200E+05, 0.13192900E+06, 0.13530800E+06, -.73017900E+05, 0.13949600E+05, -.69321800E+04, -.69586300E+04, -.14178100E+05, 0.18427600E+05, 0.38330600E+04, 0.28044700E+05, 0.74230600E+04, 0.80322900E+04, -.33534600E+06, 0.16725200E+06, 0.14405700E+06, 0.53727300E+05, 0.94972700E+05, 0.50606100E+05, -.87376400E+05, -.88488100E+05, 0.94491700E+05, -.93453900E+05, 0.46614900E+05, 0.58421500E+05, -.44877400E+05, -.19399100E+04, 0.69055400E+05, 0.88760100E+05, 0.80695700E+05, -.52611300E+03, 0.26586000E+06, -.13254000E+06, -.98913000E+05, -.64074900E+05, -.96674800E+05, -.16649400E+05, 0.11679100E+06, 0.12890100E+06, -.90911800E+05, 0.36657500E+06, -.18318800E+06, -.15682300E+06, -.11378400E+06, -.11292300E+06, 0.68701400E+04, 0.23524600E+06, 0.21377700E+06, -.11535800E+06, 0.52379700E+05, -.25981200E+05, -.39954300E+05, 0.33787500E+05, 0.49289900E+04, -.58897900E+05, -.90567400E+05, -.75927500E+05, 0.21459300E+04, -.15430000E+06, 0.76895100E+05, 0.63315300E+05, 0.52167800E+05, 0.72761500E+05, -.23730300E+05, -.13480000E+06, -.13175600E+06, 0.67048500E+05, 0.25729500E+06, -.12839600E+06, -.11495300E+06, -.47518900E+05, -.76797900E+05, -.26595500E+05, 0.10052200E+06, 0.92530300E+05, -.73937200E+05, -.31885200E+06, 0.15976700E+06, 0.14670700E+06, 0.53508200E+05, 0.73164500E+05, 0.29265200E+05, -.14850500E+06, -.12811100E+06, 0.79043400E+05, 0.28450100E+04, -.15177300E+04, -.12179800E+04, -.33253600E+05, 0.32179100E+05, 0.24557400E+05, 0.79182100E+05, 0.40174700E+05, 0.17089900E+05, 0.36045700E+06, -.17986600E+06, -.16854000E+06, -.59568600E+05, -.80850800E+05, -.49912200E+05, 0.11574300E+06, 0.10422100E+06, -.89439400E+05, 0.68668600E+05, -.34379200E+05, -.48438300E+05, 0.37219200E+05, 0.34171000E+04, -.47292200E+05, -.65862700E+05, -.67851100E+05, 0.16861700E+04, 0.34761600E+06, -.17460100E+06, -.15039500E+06, -.53542500E+05, -.75481900E+05, -.48405200E+05, 0.10813500E+06, 0.10276900E+06, -.86184100E+05, 0.31815400E+06, -.15862400E+06, -.13263800E+06, -.73165600E+05, -.11168500E+06, -.60412900E+04, 0.17227900E+06, 0.16893000E+06, -.10896800E+06, -.45069900E+06, 0.22490200E+06, 0.20701100E+06, 0.78045900E+05, 0.10396800E+06, 0.57142400E+05, -.14596200E+06, -.13593400E+06, 0.11454500E+06, 0.13786200E+06, -.69182200E+05, -.53928900E+05, -.15067000E+05, -.24158100E+05, -.16464400E+05, 0.58288100E+05, 0.75994600E+05, -.27540700E+05, -.76707900E+05, -.16917900E+06, -.14094700E+05, -.86147700E+05, -.13185900E+05, 0.63666500E+05, -.64418500E+05, -.45588400E+05, -.58909300E+05, -.28967600E+04, 0.16920400E+06, 0.33815500E+05, 0.77302800E+05, 0.87622000E+05, 0.12837900E+06, -.35413500E+05, -.53687600E+05, 0.60278400E+05, 0.75156800E+05, 0.15884300E+06, 0.17122300E+05, 0.72097900E+05, 0.94359400E+05, 0.15975600E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.70630100E+00, -.91527900E+00, -.16303000E+00, -.33999400E+00, 0.35679100E+00, 0.59159600E+00, -.62320900E+04, -.19018300E+05, -.35364000E+04, -.62235200E+05, 0.30836200E+05, 0.10959700E+05, -.24295600E+05, -.54545600E+05, 0.62033800E+05, -.42497800E+02, -.12978200E+05, -.62097200E+05, -.10169700E+06, 0.50095000E+05, 0.53603500E+05, 0.21466100E+04, -.23013800E+05, 0.41490500E+05, 0.11066300E+05, 0.18070300E+05, -.23688600E+05, -.38317800E+05, 0.19077300E+05, 0.74877300E+04, -.20121700E+05, -.39078400E+05, 0.40460200E+05, 0.13356400E+05, 0.11521300E+05, -.36036400E+05, -.13729800E+05, 0.71645700E+04, 0.11547900E+05, 0.30989200E+05, 0.55978500E+05, -.34820300E+05, -.68274600E+03, 0.90852200E+04, 0.56930300E+05, -.10734700E+06, 0.53199700E+05, 0.43907800E+05, -.79822800E+04, -.22457200E+05, 0.46630200E+05, -.24506000E+05, -.93952700E+04, -.19700800E+05, 0.95596900E+05, -.47775400E+05, -.47927500E+05, -.46346800E+05, -.71485300E+05, 0.37895800E+05, 0.34717700E+05, 0.35017100E+03, -.80823800E+05, -.50259300E+05, 0.24700800E+05, 0.25136400E+05, 0.22210700E+04, -.14697400E+05, 0.19408200E+05, 0.67918000E+04, 0.16850000E+05, -.10851700E+05, -.96558000E+05, 0.48273500E+05, 0.68967800E+05, 0.34152500E+05, 0.57819200E+05, -.88632400E+04, -.18395800E+05, 0.19263700E+04, 0.56792200E+05, 0.23197300E+05, -.11731200E+05, -.34227800E+04, -.89840800E+04, -.31526700E+05, 0.20094700E+05, 0.12483100E+05, 0.48362300E+03, -.34548600E+05, 0.20662800E+06, -.10320100E+06, -.12796800E+06, -.53744800E+05, -.92571400E+05, -.42110800E+03, 0.29860800E+05, -.80199200E+04, -.94945200E+05, -.15843000E+05, 0.72059000E+04, 0.99282800E+04, -.42312200E+05, -.92192600E+05, 0.77423600E+05, 0.26493800E+05, 0.12090900E+05, -.94701700E+05, -.21210700E+05, 0.10922900E+05, -.12110900E+04, 0.19023900E+05, 0.45896500E+05, -.34018600E+05, -.22643500E+05, -.10825100E+05, 0.44000000E+05, -.87297500E+05, 0.43568000E+05, 0.38029100E+05, 0.47319200E+05, 0.67084100E+05, -.33508700E+05, -.38409000E+05, -.46059200E+04, 0.77038500E+05, 0.23326000E+05, -.11722400E+05, -.19714900E+05, -.20465900E+05, -.36622100E+05, 0.19720900E+05, -.14405800E+04, -.97929700E+04, -.35915500E+05, 0.13004300E+06, -.64438200E+05, -.54938000E+05, 0.12808200E+05, 0.32265500E+05, -.62093700E+05, -.41040700E+04, -.19449500E+05, 0.29453800E+05, -.10015800E+06, 0.49409900E+05, 0.50903300E+05, 0.60253300E+04, -.30758500E+05, 0.38639700E+05, 0.96546900E+04, 0.27698300E+05, -.20835900E+05, -.10124900E+06, 0.50198900E+05, 0.41613900E+05, -.56683900E+04, -.22753400E+05, 0.45190300E+05, -.22075000E+04, 0.78506900E+04, -.21464900E+05, 0.48684400E+04, -.20113600E+04, 0.88099700E+04, -.37557700E+04, 0.12419000E+05, -.80609300E+04, 0.10232500E+04, 0.54285000E+04, 0.15026300E+05, -.10998000E+06, 0.54671000E+05, 0.35177100E+05, -.21090600E+05, -.46235900E+05, 0.68797400E+05, 0.15292200E+05, 0.21435300E+05, -.41354400E+05, 0.13902500E+03, -.14279200E+03, -.49451800E+04, -.35080800E+05, -.50414900E+05, 0.49958000E+05, 0.22854700E+05, -.10302800E+04, -.58797300E+05, 0.90247100E+05, -.44725700E+05, -.38006800E+05, 0.19878200E+05, 0.48959800E+05, -.64608500E+05, -.17602100E+05, -.17144500E+05, 0.48940800E+05, -.64834700E+05, 0.31865800E+05, 0.19456500E+05, 0.51518500E+04, 0.15438000E+04, 0.18222600E+05, -.27641100E+05, -.40967500E+05, 0.74526400E+03, 0.50268600E+04, -.20985500E+05, 0.65233500E+05, -.20566700E+05, -.22122300E+05, 0.19063700E+05, -.58098100E+05, 0.30638600E+05, -.16838600E+05, -.62753800E+05, 0.62203400E+04, -.60671300E+05, -.27156100E+05, -.94195200E+04, -.39760800E+05, -.55503400E+05, -.36013200E+05, 0.17100000E+05, -.65032800E+05, 0.14069500E+05, 0.30537900E+05, -.73431300E+05, -.67725400E+05, 0.27219800E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.93146700E+00, -.40120100E+00, -.79748800E+00, 0.13980200E+01, -.75864600E+00, -.27568100E+01, 0.28701200E+01, 0.74807400E+05, 0.98319300E+04, 0.24470900E+07, -.12187400E+07, -.10941500E+07, 0.10378400E+06, -.73739400E+05, -.93789900E+06, -.49290100E+06, -.45476200E+06, -.19745500E+06, 0.16998600E+07, -.83830800E+06, -.86494200E+06, 0.25021700E+06, 0.26701200E+06, -.78394900E+06, -.65525700E+06, -.70554400E+06, 0.94360400E+05, 0.84821000E+06, -.41962800E+06, -.35524900E+06, -.78998800E+05, -.31890100E+05, -.25498700E+06, 0.73908000E+04, -.48661800E+05, -.68070300E+05, -.10498000E+07, 0.52065100E+06, 0.48098400E+06, -.26403300E+05, 0.30556500E+05, 0.36620400E+06, 0.75508500E+05, 0.93148700E+05, 0.81604200E+05, 0.11879000E+07, -.58697200E+06, -.53467300E+06, -.49871600E+05, -.41362000E+05, -.37930200E+06, -.16410700E+05, -.47779200E+05, -.11850500E+06, 0.86774600E+06, -.43101000E+06, -.38444700E+06, -.50264100E+04, -.51533000E+05, -.37571600E+06, -.15374000E+06, -.10557100E+06, -.44679700E+05, 0.78223200E+06, -.38412500E+06, -.39110400E+06, 0.10752200E+06, 0.16166400E+06, -.34614600E+06, -.25746200E+06, -.34242200E+06, 0.61687300E+05, -.48299400E+06, 0.24026000E+06, 0.12099900E+06, 0.10533200E+06, 0.12269100E+06, 0.99322000E+05, -.11326600E+06, -.10752700E+06, 0.12678600E+06, 0.10678300E+07, -.52990300E+06, -.54992300E+06, 0.16895700E+06, 0.11996900E+06, -.51960800E+06, -.41839600E+06, -.44090900E+06, 0.21098300E+05, 0.56919800E+06, -.28310100E+06, -.13271800E+06, -.83559000E+05, -.10931200E+06, -.17387800E+06, 0.44254800E+05, 0.71573600E+05, -.11880200E+06, 0.21979100E+07, -.10857800E+07, -.10566300E+07, 0.12854700E+06, 0.12251800E+06, -.92258400E+06, -.50487400E+06, -.52035500E+06, -.29635700E+05, -.99884200E+06, 0.49276100E+06, 0.52339300E+06, -.13971000E+06, -.18510600E+06, 0.52335400E+06, 0.41695800E+06, 0.42470700E+06, -.56407600E+05, -.79418600E+06, 0.39619300E+06, 0.39339900E+06, -.69228700E+05, -.12042800E+05, 0.38008400E+06, 0.25110100E+06, 0.18744300E+06, -.38426500E+04, 0.67395100E+06, -.33493100E+06, -.28173700E+06, -.53732800E+05, -.81396000E+05, -.20379700E+06, 0.26410200E+05, 0.11958600E+05, -.11343000E+06, -.13942000E+07, 0.68749400E+06, 0.63569700E+06, -.69080900E+03, -.70103900E+05, 0.51855000E+06, 0.20068400E+06, 0.26189600E+06, 0.26002900E+05, 0.16935400E+07, -.83535700E+06, -.84948100E+06, 0.23353800E+06, 0.34815400E+06, -.75891900E+06, -.58242600E+06, -.73266300E+06, 0.10827800E+06, 0.11001000E+07, -.54434500E+06, -.49354200E+06, -.10293500E+05, 0.17845000E+05, -.37861000E+06, -.95029000E+05, -.12786100E+06, -.49198000E+05, -.91312900E+06, 0.44982000E+06, 0.39213500E+06, -.87679600E+05, -.43392000E+05, 0.38098900E+06, 0.27449800E+06, 0.30197000E+06, 0.29583500E+05, 0.14243500E+07, -.70384000E+06, -.59395200E+06, -.11664300E+06, -.30480500E+05, -.44100800E+06, -.21355200E+05, -.12342400E+06, -.97603200E+05, 0.11338300E+07, -.56522200E+06, -.49940200E+06, -.31652400E+04, -.71091100E+05, -.43945100E+06, -.16370700E+06, -.10441300E+06, -.85598500E+05, -.14317300E+07, 0.70999100E+06, 0.65384400E+06, 0.10611200E+05, -.54055000E+05, 0.53305200E+06, 0.18791200E+06, 0.19714500E+06, 0.26573600E+05, 0.40614700E+06, -.19728800E+06, -.12820000E+06, -.51985800E+05, -.30241200E+05, -.10032700E+06, 0.59821300E+05, 0.15002000E+06, -.57315000E+05, -.54733100E+06, 0.24163100E+06, -.13002100E+06, -.14523400E+06, -.19823300E+06, -.35004000E+06, 0.32307100E+06, -.39556800E+06, -.25625900E+06, 0.50036200E+06, -.16021200E+05, 0.51455100E+06, -.30531700E+05, 0.35169500E+06, 0.10641600E+06, 0.37888700E+06, 0.15163400E+06, 0.23819500E+06, -.16683200E+06, -.10084900E+05, 0.20760700E+06, 0.62784400E+05, -.10003000E+06, -.25399000E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.48920400E-01, 0.19287400E+00, 0.77563600E-01, -.16294800E+00, 0.15361700E+00, -.10061100E+00, 0.18167700E-01, 0.35607100E-01, 0.34494700E+04, -.13902300E+06, 0.69549300E+05, 0.67159200E+05, -.47144800E+05, -.15680600E+05, 0.83504700E+05, 0.10536700E+06, 0.99952000E+05, 0.17031500E+05, -.11773800E+06, 0.61099900E+05, 0.59297500E+05, -.35857000E+05, 0.23456600E+04, 0.59674200E+05, 0.67239200E+05, 0.59760300E+05, 0.30326000E+05, 0.33845700E+05, -.15293000E+05, -.18382100E+05, 0.17547500E+04, 0.13465100E+04, -.10583800E+05, -.79679800E+03, -.39139400E+04, 0.48535300E+04, 0.12689500E+05, -.72306300E+04, -.58598600E+04, 0.18874700E+05, 0.92482500E+04, -.17960800E+05, -.33942600E+05, -.30056300E+05, -.48126700E+04, -.22877400E+04, 0.24896500E+04, -.21990800E+03, -.13424900E+05, -.64700000E+04, 0.13706100E+05, 0.31387000E+05, 0.26568800E+05, 0.59474400E+02, -.17031800E+05, 0.88691200E+04, 0.95043700E+04, -.91853300E+04, -.40073500E+04, 0.18285200E+05, 0.26534200E+05, 0.23648900E+05, 0.66319800E+04, -.27273400E+05, 0.14907800E+05, 0.13637800E+05, -.13693900E+05, 0.31250700E+04, 0.13965500E+05, 0.17331500E+05, 0.13341900E+05, 0.14921100E+05, -.22879400E+05, 0.11376000E+05, 0.14029600E+05, 0.22737400E+04, 0.62830700E+04, 0.30734900E+04, -.75079300E+04, -.82199500E+04, 0.57761400E+04, -.10358200E+06, 0.52206400E+05, 0.53809600E+05, -.29902300E+05, -.25310700E+04, 0.53013000E+05, 0.55552200E+05, 0.50975500E+05, 0.17580200E+05, -.78805500E+04, 0.39617700E+04, 0.11641300E+04, -.69913500E+04, -.56180600E+04, 0.11692900E+05, 0.21570300E+05, 0.21921700E+05, -.20723000E+04, -.70895200E+05, 0.37715800E+05, 0.36509500E+05, -.40972700E+05, -.76154900E+04, 0.52863200E+05, 0.74275300E+05, 0.65398700E+05, 0.18276100E+05, 0.80491300E+05, -.41433300E+05, -.42826500E+05, 0.23755200E+05, -.15832700E+04, -.44521100E+05, -.48139300E+05, -.42401600E+05, -.12730900E+05, 0.31483900E+05, -.15584500E+05, -.17098800E+05, 0.11867300E+05, 0.94424700E+04, -.24956700E+05, -.33750300E+05, -.32384800E+05, -.79307000E+04, -.73518300E+04, 0.39426200E+04, 0.28076300E+04, -.84610500E+04, -.56749800E+04, 0.11207100E+05, 0.20958700E+05, 0.19631800E+05, -.16808900E+04, -.50236000E+04, 0.21164900E+03, 0.37814500E+04, 0.10329200E+05, 0.20020600E+04, -.95849600E+04, -.26881000E+05, -.20865700E+05, -.75015600E+04, -.89691800E+05, 0.46862200E+05, 0.44984500E+05, -.34787400E+05, 0.52874400E+04, 0.45515200E+05, 0.52729400E+05, 0.44576300E+05, 0.28476500E+05, 0.21873600E+05, -.10063000E+05, -.12099300E+05, -.11754300E+05, -.72257700E+04, 0.17266700E+04, 0.17453700E+05, 0.13168000E+05, 0.49559500E+04, 0.78220800E+05, -.39996500E+05, -.37898700E+05, 0.20708400E+05, 0.12465500E+04, -.37218500E+05, -.38847400E+05, -.36258900E+05, -.17186800E+05, 0.51360900E+05, -.22971800E+05, -.28206700E+05, 0.29045500E+04, 0.28727500E+04, -.16046200E+05, -.12599000E+04, -.67552500E+04, 0.98831200E+04, -.14896000E+05, 0.73172500E+04, 0.74151400E+04, -.12166500E+05, -.12225400E+05, 0.20866300E+05, 0.33644900E+05, 0.31889400E+05, 0.45750900E+04, -.34238200E+05, 0.16279700E+05, 0.17782900E+05, 0.14005300E+05, 0.66691200E+04, 0.25607100E+03, -.17845800E+05, -.13147100E+05, -.80322100E+04, -.35191400E+04, 0.31142800E+04, 0.16745400E+03, -.32672500E+04, 0.84203400E+03, 0.40544300E+04, 0.80418500E+04, 0.59895100E+04, 0.36364000E+04, 0.21134200E+05, -.40773300E+05, -.16913600E+05, 0.24176400E+04, 0.36351800E+05, 0.27399800E+05, -.28881400E+05, 0.18085500E+05, 0.17570400E+05, -.27922600E+05, 0.31659000E+05, -.21980000E+05, 0.23164400E+05, -.82129100E+04, 0.40398700E+05, -.24848400E+05, -.32543600E+05, -.12465200E+05, 0.34259500E+05, 0.25370000E+05, -.36156400E+05, 0.40205900E+05, 0.40070000E+05, 0.39297400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.47359100E+00, 0.39963500E+00, 0.17056600E+00, -.11976900E+00, 0.35682500E+00, -.41702400E+00, 0.38425700E+00, 0.17874900E+00, -.10510600E+00, 0.47226300E+06, -.23478000E+06, -.24915900E+06, 0.69103300E+05, 0.62518100E+05, -.23368500E+06, -.22700200E+06, -.25094900E+06, 0.24060200E+04, 0.42183900E+06, -.20427300E+06, -.20882000E+06, 0.27158500E+05, 0.47582900E+05, -.19341700E+06, -.17893300E+06, -.18972000E+06, -.11347700E+05, 0.50250700E+05, -.21111500E+05, -.32630200E+05, 0.20646700E+05, 0.44563000E+05, -.41487100E+05, -.46105700E+05, -.58272700E+05, 0.30970900E+05, -.69704300E+05, 0.31592700E+05, 0.38793100E+05, -.24561900E+05, -.26053500E+05, 0.38843000E+05, 0.30655100E+05, 0.48261100E+05, -.11840200E+05, 0.20465700E+06, -.98806600E+05, -.10944600E+06, 0.23601500E+05, 0.27873700E+05, -.92495300E+05, -.69876000E+05, -.95214900E+05, 0.61175500E+04, 0.14241300E+06, -.70168800E+05, -.70808300E+05, 0.31288100E+05, 0.42065500E+05, -.78621700E+05, -.99037100E+05, -.11277900E+06, 0.18529400E+05, 0.10578900E+06, -.49925400E+05, -.52895200E+05, 0.64348300E+04, 0.24420100E+05, -.49083100E+05, -.45949400E+05, -.48244600E+05, 0.27821200E+04, 0.57484600E+05, -.28741200E+05, -.15735600E+05, -.28539700E+05, -.33439100E+05, -.45644100E+03, 0.16525700E+05, 0.23644100E+05, -.33567700E+05, 0.20073800E+06, -.98743300E+05, -.93081000E+05, 0.21571200E+05, 0.27034400E+05, -.90810900E+05, -.91039800E+05, -.10268800E+06, -.74877700E+04, -.30467700E+05, 0.15251200E+05, 0.44753900E+03, 0.44062900E+05, 0.50593800E+05, -.24296300E+05, -.61108500E+05, -.66736900E+05, 0.42834100E+05, 0.36700600E+06, -.17710200E+06, -.18328600E+06, 0.50789100E+05, 0.78347900E+05, -.17363600E+06, -.16516500E+06, -.19850300E+06, 0.19401200E+05, -.32636100E+06, 0.15945600E+06, 0.15441600E+06, -.24180000E+05, -.43353600E+05, 0.14522000E+06, 0.14983200E+06, 0.16161300E+06, 0.27839300E+04, -.21836700E+06, 0.10906500E+06, 0.10577700E+06, -.29255500E+05, -.31966000E+05, 0.10555700E+06, 0.11131800E+06, 0.12187400E+06, -.11283100E+04, 0.67824300E+05, -.33175000E+05, -.38950400E+05, 0.22748100E+05, 0.23534500E+05, -.40012700E+05, -.42123800E+05, -.52307000E+05, 0.12659300E+05, -.30915200E+06, 0.14842500E+06, 0.16137900E+06, -.24605900E+05, -.43509600E+05, 0.14199800E+06, 0.11979100E+06, 0.14377800E+06, -.71559900E+04, 0.30736000E+06, -.14854600E+06, -.15318800E+06, 0.20465800E+05, 0.54001300E+05, -.14132700E+06, -.13220500E+06, -.13870000E+06, 0.15637600E+04, 0.11695000E+06, -.56319200E+05, -.64894200E+05, 0.15634000E+05, 0.29585500E+05, -.51045000E+05, -.31711600E+05, -.55663200E+05, 0.10010400E+05, -.10572400E+06, 0.50523200E+05, 0.59174300E+05, -.22904400E+05, -.26250000E+05, 0.57313400E+05, 0.60957500E+05, 0.66145500E+05, -.20968200E+04, 0.11888100E+06, -.52569000E+05, -.72596700E+05, 0.29391200E+05, 0.67376800E+05, -.78247800E+05, -.80881700E+05, -.10052600E+06, 0.42580000E+05, 0.21374800E+06, -.10672100E+06, -.11067000E+06, 0.32465900E+05, 0.36735500E+05, -.10273800E+06, -.10416100E+06, -.12205000E+06, 0.77155900E+04, -.17086300E+06, 0.83223400E+05, 0.90931800E+05, -.23548200E+05, -.53911100E+05, 0.78287200E+05, 0.63933100E+05, 0.93602600E+05, -.22949400E+05, 0.34711300E+05, -.13424500E+05, -.25644900E+05, 0.73565100E+04, 0.63301200E+04, -.14615400E+05, -.64281600E+04, -.15052300E+05, 0.44101600E+04, -.10518900E+06, 0.10107000E+06, -.22427200E+05, -.24178200E+05, -.75200400E+05, -.78465100E+05, 0.91731900E+05, -.88277200E+05, -.74283000E+05, 0.11945700E+06, -.71164500E+05, 0.10971400E+06, -.27440600E+05, 0.29049200E+05, -.84513900E+04, 0.10737600E+06, 0.42497100E+05, 0.60295600E+05, -.64403100E+05, -.70280100E+05, 0.68674900E+05, -.13521500E+05, -.55446700E+05, -.10078300E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15508000E+01, 0.54771600E+00, -.17747100E+00, -.21459900E+00, 0.67203500E-01, -.76981400E+00, 0.99394800E+00, 0.47005500E-01, 0.76314200E+00, -.40900500E+00, 0.17175500E+04, 0.47761600E+05, 0.25672200E+06, 0.33304500E+06, -.27488500E+06, -.54031700E+06, -.69913100E+06, 0.25070100E+06, 0.67230400E+06, -.32735600E+06, -.34103400E+06, 0.92090500E+05, 0.94373400E+05, -.31409500E+06, -.27649300E+06, -.33336200E+06, 0.28527900E+04, -.20575400E+06, 0.10708000E+06, 0.12738000E+06, 0.75838800E+05, 0.16248600E+06, -.25724700E+05, -.14056400E+06, -.22083600E+06, 0.14146300E+06, 0.31504300E+06, -.16259700E+06, -.17393500E+06, -.15160700E+06, -.23118500E+06, 0.43695300E+05, 0.22698600E+06, 0.35434500E+06, -.19744900E+06, -.23378900E+06, 0.12087200E+06, 0.13667100E+06, 0.13334900E+06, 0.22973900E+06, -.71201800E+05, -.23599200E+06, -.35838600E+06, 0.19368700E+06, -.21817300E+06, 0.10996800E+06, 0.13397300E+06, 0.12025600E+06, 0.18748900E+06, -.80098700E+05, -.24768000E+06, -.32193200E+06, 0.16947900E+06, 0.23843600E+06, -.11574300E+06, -.11921400E+06, 0.34521600E+05, 0.52581400E+05, -.10859800E+06, -.88496300E+05, -.11103100E+06, 0.84015600E+04, 0.58841500E+06, -.29393500E+06, -.33807800E+06, -.11898500E+06, -.21803000E+06, -.62166800E+05, 0.17295800E+06, 0.26116200E+06, -.21625900E+06, 0.36260300E+06, -.17913100E+06, -.17912400E+06, 0.70731200E+05, 0.56293700E+05, -.18886700E+06, -.18057200E+06, -.19920500E+06, 0.23492600E+04, -.59275400E+06, 0.29613700E+06, 0.35394600E+06, 0.15036400E+06, 0.25464600E+06, 0.25425300E+05, -.23943300E+06, -.33806800E+06, 0.24634300E+06, -.81057900E+05, 0.48322000E+05, 0.60873300E+05, 0.24257000E+06, 0.36498700E+06, -.23565300E+06, -.47013500E+06, -.62539600E+06, 0.27993600E+06, -.35689100E+06, 0.17377600E+06, 0.17911400E+06, -.73921600E+05, -.94153500E+05, 0.21270600E+06, 0.22288800E+06, 0.24489500E+06, -.35439000E+05, 0.13827900E+06, -.68980100E+05, -.75001800E+05, -.12499300E+06, -.18239600E+06, 0.10278200E+06, 0.26518500E+06, 0.33734600E+06, -.15261500E+06, -.29336800E+06, 0.14730000E+06, 0.16771200E+06, 0.95796200E+05, 0.16014500E+06, -.10238500E+05, -.16487400E+06, -.23017400E+06, 0.14476200E+06, 0.53854500E+05, -.34171400E+05, -.49249700E+05, -.12678100E+06, -.23480000E+06, 0.13778100E+06, 0.27867500E+06, 0.39383300E+06, -.18333900E+06, 0.57107300E+06, -.27932500E+06, -.28630200E+06, 0.83916400E+05, 0.11627700E+06, -.26552500E+06, -.22676300E+06, -.27484100E+06, 0.16858900E+05, -.28562200E+06, 0.14517100E+06, 0.16243400E+06, 0.12958500E+06, 0.23303300E+06, -.43562100E+05, -.21020700E+06, -.30945900E+06, 0.19452300E+06, -.26938700E+06, 0.13164900E+06, 0.10946900E+06, -.43391000E+05, -.33313000E+05, 0.12782900E+06, 0.11741700E+06, 0.13417300E+06, 0.89174700E+04, -.22491700E+06, 0.12025100E+06, 0.15460900E+06, 0.10717700E+06, 0.23881800E+06, -.63693900E+05, -.21529800E+06, -.33217800E+06, 0.19977400E+06, -.28313200E+06, 0.14152800E+06, 0.17033800E+06, 0.15291700E+06, 0.24248000E+06, -.88285000E+05, -.30088300E+06, -.40561200E+06, 0.21054400E+06, 0.38070600E+06, -.19275200E+06, -.21326100E+06, -.17465200E+06, -.32076400E+06, 0.70382200E+05, 0.30051000E+06, 0.42155700E+06, -.27179300E+06, 0.57469000E+05, -.22900600E+05, -.97492900E+03, 0.97704800E+04, 0.27589600E+05, -.32735100E+05, -.20675200E+05, -.70655800E+05, 0.16125000E+05, -.17724600E+05, 0.30056600E+06, -.83969900E+05, 0.12825600E+06, -.41374800E+05, -.16221900E+06, 0.20413500E+06, -.55483100E+05, 0.69003000E+05, 0.17724900E+06, -.22267900E+06, 0.98179100E+05, -.82209600E+05, -.59847200E+05, -.92303700E+05, 0.22500800E+06, 0.12944700E+06, -.83246000E+05, -.67730600E+05, -.21837000E+06, 0.20904400E+05, 0.54699700E+04, -.85428100E+05, -.29778000E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.49104000E+00, -.14369400E+00, 0.98791700E-01, -.73688100E+00, 0.68685900E+00, -.10997000E+00, -.11983500E+00, 0.11649400E+00, 0.62088700E+00, 0.40224700E+00, 0.17866000E+00, -.36824600E+05, -.32595400E+05, -.89381800E+05, 0.93491400E+05, 0.19986300E+06, 0.22529200E+06, -.69223100E+05, -.18404500E+06, 0.94401200E+05, 0.95769400E+05, -.84200000E+04, -.35143800E+05, 0.97232500E+05, 0.10662200E+06, 0.10881100E+06, -.17109400E+05, 0.29099900E+05, -.12707300E+05, -.33698800E+05, -.10729100E+05, -.32090900E+05, 0.17983600E+05, 0.56189500E+05, 0.68069900E+05, -.30680800E+05, -.16688700E+06, 0.82517300E+05, 0.96434000E+05, 0.20921200E+05, 0.62427000E+05, 0.14167800E+05, -.56400800E+05, -.87166900E+05, 0.58958000E+05, 0.11299800E+06, -.54962500E+05, -.72784200E+05, -.28559400E+05, -.64829200E+05, 0.15694300E+05, 0.99091400E+05, 0.11395300E+06, -.57412500E+05, -.12386900E+05, 0.65293200E+04, -.11379800E+05, -.18647800E+05, -.40109500E+05, 0.60735300E+05, 0.10556900E+06, 0.11453300E+06, -.37747100E+05, -.40779700E+05, 0.21801900E+05, 0.20382400E+05, 0.25485700E+04, -.19898100E+05, 0.20012600E+05, 0.18282300E+05, 0.22562200E+05, -.11968600E+05, -.15185400E+06, 0.75865700E+05, 0.10952900E+06, 0.15679500E+05, 0.46529600E+05, 0.18238700E+05, -.45325100E+05, -.69780100E+05, 0.45012500E+05, -.36856800E+05, 0.19012800E+05, 0.19164000E+05, 0.43562500E+04, -.35310600E+04, 0.30057700E+05, 0.36110400E+05, 0.23772300E+05, -.36375700E+04, 0.10185300E+06, -.50957100E+05, -.94358500E+05, -.14062200E+05, -.44185200E+05, 0.70826500E+04, 0.66716000E+05, 0.93006400E+05, -.40570600E+05, 0.82863700E+05, -.38901100E+05, -.56697600E+05, -.34432500E+05, -.10409600E+06, 0.61141600E+05, 0.15966000E+06, 0.17773000E+06, -.91247000E+05, 0.14811900E+06, -.75293100E+05, -.76801900E+05, 0.12075000E+05, 0.32815300E+05, -.94298300E+05, -.10339300E+06, -.93819100E+05, 0.16457700E+05, 0.11507400E+05, -.55267700E+04, -.22159900E+04, 0.30067900E+05, 0.54034600E+05, -.66266800E+05, -.12365100E+06, -.13605400E+06, 0.45588000E+05, 0.91056000E+05, -.45191300E+05, -.61442200E+05, -.15180000E+05, -.39428000E+05, 0.33669900E+04, 0.58157400E+05, 0.68612800E+05, -.35193200E+05, 0.40542100E+04, -.45023700E+04, 0.15491100E+05, 0.34078800E+05, 0.73611100E+05, -.67126400E+05, -.14275100E+06, -.15547500E+06, 0.60054200E+05, -.11158900E+06, 0.58043600E+05, 0.56393400E+05, -.58614500E+03, -.44713300E+05, 0.58958700E+05, 0.61544400E+05, 0.66777000E+05, -.23833000E+05, 0.16798900E+06, -.82948100E+05, -.99949400E+05, -.24083600E+05, -.65323400E+05, -.11941500E+05, 0.66254600E+05, 0.76578600E+05, -.63322300E+05, 0.20912600E+05, -.11497500E+05, 0.80751300E+04, -.15310200E+05, -.95090600E+04, -.60702400E+04, -.52276900E+04, 0.21327000E+04, -.78565200E+04, 0.14241000E+05, -.41545300E+04, -.39969600E+05, -.15746600E+05, -.49223500E+05, 0.39249400E+05, 0.93913300E+05, 0.10845600E+06, -.45031600E+05, 0.50725300E+05, -.25604300E+05, -.46617200E+05, -.31629700E+05, -.68223300E+05, 0.54188900E+05, 0.13097300E+06, 0.14876600E+06, -.59297700E+05, -.17556400E+06, 0.86818900E+05, 0.10618400E+06, 0.33857400E+05, 0.94871100E+05, -.89531000E+04, -.10696400E+06, -.11844300E+06, 0.89272700E+05, 0.23097800E+04, 0.10273100E+03, -.22224900E+05, 0.33987600E+04, -.25741900E+04, 0.20405400E+04, 0.48872100E+04, 0.14051300E+05, -.72252000E+02, 0.38240000E+04, -.10480800E+06, 0.26628800E+05, -.37931600E+05, -.71557600E+04, 0.78944200E+05, -.60061200E+05, -.42342200E+04, -.17143200E+05, -.44970900E+05, 0.10373300E+06, -.19350200E+05, 0.58490400E+05, 0.33932800E+05, 0.26101200E+05, -.57740600E+05, -.20615700E+05, 0.20742600E+05, 0.52921900E+05, 0.11245300E+06, 0.11616300E+05, -.21944900E+04, 0.56742300E+05, 0.10411100E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.59050100E+00, 0.38758400E+00, -.38943900E-01, 0.12565800E+00, -.28885400E-01, -.10273000E-01, -.14480300E-01, 0.26348000E+00, -.88817100E+00, 0.18118200E+00, -.31407400E+00, -.34608300E+00, -.22921800E+06, -.27029500E+06, 0.21926000E+06, 0.41474300E+06, 0.53462000E+06, -.21257900E+06, -.48191100E+06, 0.24126700E+06, 0.24183100E+06, -.72295200E+05, -.55087800E+05, 0.22551900E+06, 0.20468400E+06, 0.22893600E+06, 0.58643800E+04, 0.22164200E+06, -.10939700E+06, -.11176200E+06, -.77673500E+05, -.14041300E+06, 0.89983600E+04, 0.11594700E+06, 0.17062600E+06, -.13082500E+06, -.25915800E+06, 0.12859800E+06, 0.12717700E+06, 0.13626100E+06, 0.18822600E+06, -.35702900E+05, -.17781800E+06, -.26555200E+06, 0.16808600E+06, 0.15663000E+06, -.77643400E+05, -.78181200E+05, -.11438200E+06, -.17194100E+06, 0.60774700E+05, 0.17061300E+06, 0.25659300E+06, -.14954200E+06, 0.23042600E+06, -.11485200E+06, -.10813400E+06, -.12014700E+06, -.17260800E+06, 0.55982500E+05, 0.20781100E+06, 0.27124800E+06, -.16206900E+06, -.17158100E+06, 0.85810900E+05, 0.85805700E+05, -.27286500E+05, -.33010000E+05, 0.78132300E+05, 0.65432900E+05, 0.76588700E+05, -.32581000E+04, -.50590800E+06, 0.25238100E+06, 0.25510200E+06, 0.12394400E+06, 0.20413000E+06, 0.45998700E+05, -.15224300E+06, -.22792500E+06, 0.20397200E+06, -.25472200E+06, 0.12714400E+06, 0.13262800E+06, -.58888000E+05, -.40552300E+05, 0.13850500E+06, 0.14217400E+06, 0.15375200E+06, -.38725000E+04, 0.57547600E+06, -.28710200E+06, -.28911500E+06, -.16306900E+06, -.25522000E+06, -.26026000E+05, 0.22498800E+06, 0.31305900E+06, -.25014400E+06, 0.12798700E+06, -.63179400E+05, -.55292200E+05, -.21761000E+06, -.29483300E+06, 0.17069800E+06, 0.36664700E+06, 0.46851800E+06, -.24037600E+06, 0.24490400E+06, -.12254900E+06, -.12975600E+06, 0.62650700E+05, 0.69337000E+05, -.15288500E+06, -.17074400E+06, -.18658800E+06, 0.27925600E+05, -.12544400E+06, 0.62714600E+05, 0.56940600E+05, 0.11327800E+06, 0.15235300E+06, -.78091700E+05, -.20636000E+06, -.26310900E+06, 0.13271400E+06, 0.20709200E+06, -.10320200E+06, -.10324100E+06, -.86787200E+05, -.13090000E+06, 0.17447300E+05, 0.12670200E+06, 0.18456200E+06, -.11992800E+06, -.54580400E+05, 0.26092100E+05, 0.27067700E+05, 0.11103500E+06, 0.17450700E+06, -.10073800E+06, -.20340500E+06, -.27784100E+06, 0.14413700E+06, -.40751100E+06, 0.20377900E+06, 0.20419700E+06, -.66268300E+05, -.72505200E+05, 0.18950100E+06, 0.16620900E+06, 0.18704900E+06, -.46096600E+04, 0.23667500E+06, -.11793200E+06, -.11768100E+06, -.11524900E+06, -.18272200E+06, 0.31938400E+05, 0.15919000E+06, 0.22103800E+06, -.16103300E+06, 0.17621900E+06, -.87919400E+05, -.86633100E+05, 0.42403900E+05, 0.30208000E+05, -.93262100E+05, -.99201500E+05, -.11172000E+06, 0.17672700E+04, 0.26380000E+06, -.12974900E+06, -.13322100E+06, -.11036900E+06, -.20167500E+06, 0.31722900E+05, 0.17321000E+06, 0.25067500E+06, -.18292200E+06, 0.23909200E+06, -.11940500E+06, -.11449100E+06, -.14343000E+06, -.20349300E+06, 0.68307600E+05, 0.23154000E+06, 0.30972600E+06, -.18371100E+06, -.34043400E+06, 0.16967900E+06, 0.16696800E+06, 0.15978500E+06, 0.26036700E+06, -.47857200E+05, -.23346500E+06, -.31104100E+06, 0.23236800E+06, -.28429400E+05, 0.14840300E+05, 0.12749800E+05, -.14179500E+05, -.20190100E+05, 0.20282400E+05, 0.14931800E+05, 0.44488100E+05, -.14447200E+05, 0.33300300E+04, -.22490900E+06, 0.67937700E+05, -.99265700E+05, 0.44202600E+05, 0.10433500E+06, -.16842300E+06, 0.49177200E+05, -.57395900E+05, -.15593300E+06, 0.17797000E+06, -.86390300E+05, 0.45915200E+05, 0.50887400E+05, 0.83222800E+05, -.18776100E+06, -.12123500E+06, 0.66270300E+05, 0.25676700E+05, 0.17072600E+06, -.25367100E+05, -.17298000E+04, 0.42964200E+05, 0.22325600E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.78567200E+00, 0.59336700E-01, 0.21116500E-01, -.26567800E+00, 0.50715200E+00, 0.47389400E+00, -.14311600E+00, -.32068300E-01, -.14631900E+01, 0.46081600E-01, -.18396100E+00, 0.10685900E+00, 0.48902600E+00, 0.27882000E+05, -.24925100E+05, -.35065200E+05, -.49681200E+05, 0.20252400E+05, 0.41006500E+05, -.20548300E+05, -.20987700E+05, -.53181300E+04, 0.20124000E+05, -.21808100E+05, -.23061100E+05, -.25021600E+05, 0.12634300E+05, -.19311100E+05, 0.79334900E+04, 0.10487500E+05, 0.33039300E+04, 0.94135400E+04, -.10851600E+04, -.33123300E+04, -.91998400E+03, 0.82081300E+04, 0.50489500E+05, -.24425000E+05, -.23732600E+05, -.47135900E+04, -.23303800E+05, 0.29189600E+03, 0.88333800E+04, 0.19234700E+05, -.24066800E+05, -.48235000E+04, 0.25071700E+04, 0.32171500E+04, 0.55362900E+03, 0.16478200E+05, -.11214900E+05, -.19955900E+05, -.27620800E+05, 0.10924900E+05, -.15830500E+05, 0.80163500E+04, 0.16210800E+04, 0.11823900E+05, 0.26233000E+05, -.23061400E+05, -.30031300E+05, -.32804300E+05, 0.22451000E+05, 0.17568400E+05, -.82012200E+04, -.87922600E+04, -.46823800E+04, 0.12669300E+05, -.82902600E+04, -.60791700E+04, -.92225700E+04, 0.10557600E+05, 0.43456200E+05, -.21690600E+05, -.23061200E+05, -.91885100E+04, -.21962400E+05, 0.26235300E+04, 0.14597000E+05, 0.28929500E+05, -.20368600E+05, -.21382300E+05, 0.10844000E+05, 0.53235600E+04, -.45491500E+04, 0.94542600E+04, -.24982800E+04, -.35513500E+04, 0.11861100E+04, 0.11978300E+05, -.52017700E+05, 0.25971500E+05, 0.26262700E+05, 0.13461900E+05, 0.29915500E+05, -.88359200E+04, -.26133200E+05, -.42046200E+05, 0.27114200E+05, -.36067200E+05, 0.18228700E+05, 0.11429300E+05, 0.59765800E+04, 0.48816600E+05, -.24493700E+05, -.39929200E+05, -.44247400E+05, 0.42826600E+05, -.28632000E+05, 0.14190900E+05, 0.21288600E+05, -.38110000E+04, -.23743600E+05, 0.30644100E+05, 0.31627100E+05, 0.27741400E+05, -.15878400E+05, 0.29791900E+05, -.14920600E+05, -.97944900E+04, -.17116000E+05, -.28859900E+05, 0.18525100E+05, 0.33483300E+05, 0.38133700E+05, -.24556400E+05, -.98710900E+04, 0.49380600E+04, 0.45025300E+04, 0.22936200E+04, 0.12718600E+05, -.91316200E+04, -.12677700E+05, -.19629800E+05, 0.10136600E+05, -.10094100E+05, 0.57025600E+04, 0.50550700E+04, -.77988300E+04, -.26086500E+05, 0.21570800E+05, 0.34180800E+05, 0.40397400E+05, -.16849000E+05, 0.37291600E+05, -.17920500E+05, -.18979000E+05, -.87804600E+04, 0.27149900E+05, -.19467100E+05, -.17504300E+05, -.21806800E+05, 0.20334200E+05, -.30632100E+05, 0.15625000E+05, 0.15544900E+05, 0.16844400E+04, 0.19833200E+05, -.24325800E+04, -.14648700E+05, -.18866600E+05, 0.19841000E+05, 0.11852800E+05, -.65616900E+04, -.62220900E+04, 0.80402500E+04, -.11415500E+04, -.36538500E+04, -.38471900E+04, -.44353000E+04, -.48149000E+04, -.12329900E+05, 0.38200800E+04, 0.71917100E+04, 0.39161700E+04, 0.14384100E+05, -.64288300E+04, -.83615200E+04, -.57005000E+04, 0.11426700E+05, -.23910300E+05, 0.11992200E+05, 0.73253200E+04, 0.12681100E+05, 0.25070700E+05, -.17537500E+05, -.28530600E+05, -.35667700E+05, 0.21350800E+05, 0.30698300E+05, -.15566700E+05, -.13640500E+05, -.62929700E+04, -.37369700E+05, 0.14934100E+05, 0.32498100E+05, 0.36245400E+05, -.34265900E+05, 0.11406300E+04, -.95730300E+03, -.69777600E+01, -.20393100E+04, 0.27690100E+03, -.55377900E+03, 0.13030000E+04, -.27921200E+03, -.17014400E+04, 0.21982400E+04, 0.29258100E+05, -.21698100E+05, 0.15831300E+05, 0.17325100E+05, -.25947200E+05, 0.21194200E+05, -.26529100E+04, 0.13062000E+05, 0.24843100E+05, -.27488600E+05, 0.15605000E+05, -.12798100E+05, -.13486400E+05, 0.50944700E+04, 0.23350300E+05, 0.45429200E+04, -.13419000E+05, -.22874700E+04, -.33425400E+05, -.17450700E+05, 0.18161200E+05, -.10550200E+04, -.28940700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23698200E-01, 0.33241200E-01, 0.52432100E-02, 0.61242900E+00, -.57498500E+00, 0.17203800E+00, -.26527100E-01, -.80416700E-01, -.57171600E+00, -.21927100E+00, 0.24366300E-01, -.83006600E-01, 0.63138700E-01, -.11583000E+00, -.17952100E+05, -.32527900E+05, -.44650300E+05, 0.69005500E+04, -.65996100E+04, 0.30752100E+04, 0.30631400E+04, -.90992900E+04, -.18335100E+05, 0.25444700E+04, 0.32595500E+04, 0.18653600E+04, -.82692900E+04, -.26969500E+05, 0.12949400E+05, 0.13779100E+05, 0.44148100E+04, 0.10312500E+04, 0.40921000E+04, -.57343800E+04, -.82156800E+04, 0.45083900E+04, 0.44602400E+05, -.21899800E+05, -.21740800E+05, 0.65664200E+03, -.97266800E+04, -.83979700E+04, 0.17295900E+04, 0.11664800E+05, -.12737600E+05, -.12540100E+05, 0.61696700E+04, 0.65497700E+04, 0.61721000E+04, 0.40533900E+04, -.53371100E+04, -.15953800E+05, -.22003000E+05, 0.58935900E+04, 0.61982400E+04, -.30919100E+04, -.56836600E+04, 0.84304800E+04, 0.34767000E+04, -.18113500E+05, -.29042400E+05, -.34114700E+05, 0.63034500E+04, -.38717200E+05, 0.19390200E+05, 0.19355400E+05, -.93652500E+04, -.89222800E+04, 0.19227300E+05, 0.21192700E+05, 0.19186600E+05, -.23437900E+04, 0.33944000E+05, -.16932200E+05, -.17588600E+05, -.74533100E+04, -.13744300E+05, -.22135500E+04, 0.11491500E+05, 0.21591700E+05, -.13391100E+05, -.16007600E+05, 0.80035900E+04, 0.57659100E+04, -.10901900E+05, -.82493300E+04, 0.36876400E+04, 0.22774300E+04, 0.34754100E+04, -.90770100E+03, -.26247000E+05, 0.13095300E+05, 0.13279900E+05, 0.88700600E+04, 0.14543400E+05, -.53367100E+04, -.23265000E+05, -.34306100E+05, 0.14418200E+05, -.77433800E+05, 0.38539600E+05, 0.36002300E+05, -.11500800E+04, -.27417000E+04, 0.14323100E+05, -.27770300E+04, -.95085500E+04, 0.10289100E+05, 0.42996200E+04, -.20797400E+04, 0.71974100E+03, 0.18217200E+04, 0.12093200E+05, 0.41919600E+04, 0.63094900E+04, 0.51255000E+04, 0.53199100E+04, -.62822900E+04, 0.30862200E+04, 0.51554500E+04, -.64583800E+04, -.44009300E+04, 0.16146900E+05, 0.25338400E+05, 0.31577300E+05, -.68026400E+04, -.11340300E+05, 0.56351300E+04, 0.55262900E+04, 0.32297900E+04, 0.51369500E+04, -.31089100E+04, -.10932200E+05, -.16968100E+05, 0.56903000E+04, 0.33929400E+04, -.13375800E+04, -.17762200E+04, -.93239700E+04, 0.19900900E+04, 0.10322300E+05, 0.21485900E+05, 0.25899500E+05, -.22059800E+04, -.68609700E+05, 0.34267000E+05, 0.34168300E+05, -.16811900E+05, -.19018400E+05, 0.33214000E+05, 0.35814900E+05, 0.33080700E+05, -.59465100E+04, -.59980900E+05, 0.29969500E+05, 0.30036700E+05, 0.21837200E+04, 0.54338900E+04, 0.14211900E+05, 0.18858300E+03, -.22627400E+04, 0.10691200E+05, 0.19795200E+05, -.99965400E+04, -.10040400E+05, 0.11292500E+05, 0.68301000E+04, -.89918500E+04, -.79782400E+04, -.76096700E+04, 0.89634900E+03, -.34140300E+05, 0.16264100E+05, 0.17541100E+05, 0.68873600E+04, -.68446500E+03, 0.39901600E+04, -.93063900E+04, -.12381200E+05, 0.50673300E+04, -.83159800E+04, 0.42003900E+04, 0.24291600E+04, 0.82118500E+04, 0.77520800E+04, -.12883500E+05, -.24628700E+05, -.32044400E+05, 0.10432500E+05, 0.86162000E+05, -.43014800E+05, -.42280900E+05, -.51401100E+04, -.35274900E+04, -.20184400E+05, -.16561200E+04, 0.16124600E+04, -.12357900E+05, 0.14740000E+04, -.98120400E+03, -.42850200E+03, 0.10513100E+03, 0.86681700E+02, -.79230000E+03, -.13164900E+03, -.25068400E+04, -.18197500E+03, 0.65462900E+04, 0.11246300E+05, -.24827600E+03, -.17467100E+04, -.70535200E+04, -.87703900E+04, 0.65248400E+04, 0.83955100E+04, -.67163600E+04, 0.66563000E+04, -.14007100E+05, -.85160200E+03, -.15554700E+05, -.24800500E+04, -.13676800E+05, 0.83841500E+04, 0.74112500E+04, 0.63296900E+04, -.20869800E+04, -.20370300E+05, 0.52117800E+04, -.75692300E+04, -.71902900E+04, -.11212000E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.25103200E+00, -.58609500E+00, -.47870400E-01, 0.73621900E+00, -.98759900E-01, -.44835200E-01, 0.56096700E+00, 0.10874200E+00, 0.42076100E+00, -.17155600E+00, 0.11151200E+00, 0.11966300E+00, 0.84727100E-01, 0.51804400E+00, -.28469600E+00, -.19991100E+05, -.19799100E+05, 0.55626300E+04, -.36088500E+03, 0.50704000E+03, 0.18029300E+04, -.61226300E+04, -.14145700E+05, 0.97884600E+03, -.78062400E+03, 0.23476000E+04, -.73094500E+04, 0.10418700E+05, -.40687400E+04, -.75564100E+04, 0.43173000E+03, 0.19464400E+03, -.36954500E+04, -.11163900E+05, -.16761600E+05, 0.66378500E+03, 0.58734200E+04, -.33724900E+04, -.72129500E+04, 0.39391100E+04, 0.62439400E+04, -.12569600E+05, -.13779500E+04, 0.17341300E+04, 0.46797800E+04, -.87002600E+04, 0.44398900E+04, 0.17515100E+04, 0.44831700E+04, 0.39316800E+04, -.18998200E+04, -.13364700E+05, -.88441700E+04, 0.67078300E+04, 0.51706900E+05, -.25719400E+05, -.56791000E+04, -.14471100E+05, -.16065900E+05, 0.12837700E+05, -.47017200E+04, -.20334200E+05, -.18588900E+05, -.22453700E+05, 0.11089900E+05, 0.11243500E+05, -.23143800E+04, -.88465000E+04, 0.10188800E+05, 0.79774300E+04, 0.11041300E+05, -.50857100E+04, 0.22723000E+05, -.11320900E+05, -.69992700E+04, -.40219700E+04, -.48387200E+04, -.80779900E+04, 0.55902200E+04, 0.44011300E+04, -.60164000E+04, 0.27929500E+05, -.13899400E+05, 0.40406800E+04, -.12555000E+05, -.17878200E+05, 0.13651900E+05, 0.81594100E+04, -.32954000E+04, -.17237800E+05, -.20458000E+04, 0.10187000E+04, 0.18271900E+03, -.11698500E+04, -.12982300E+04, 0.10122600E+05, -.10548600E+05, -.10005500E+05, -.69109700E+03, 0.14472500E+05, -.69830000E+04, 0.13362900E+05, -.14503900E+05, -.23703200E+05, 0.28222400E+05, 0.98191400E+04, -.45228200E+04, -.19918400E+05, -.46552600E+05, 0.23032200E+05, 0.84226900E+03, 0.19537000E+05, 0.25527400E+05, -.16638500E+05, -.78488400E+04, 0.61139400E+04, 0.24448200E+05, -.44556000E+05, 0.22214700E+05, 0.68375700E+04, 0.15761100E+05, 0.15199900E+05, -.93483800E+04, 0.18272800E+04, 0.12195100E+05, 0.16257300E+05, -.24869600E+04, 0.12788400E+04, 0.27959200E+04, -.36631800E+03, -.22917400E+03, 0.60087200E+04, -.54907500E+04, -.68805700E+04, 0.38334700E+03, -.23188500E+04, 0.51349400E+03, 0.26236800E+04, -.11428600E+04, 0.20351000E+04, 0.46878200E+04, 0.13958300E+05, 0.99121900E+04, -.18105200E+04, -.36427300E+05, 0.18111900E+05, 0.19189800E+05, -.59483800E+04, -.18706600E+05, 0.18089600E+05, 0.14317000E+05, 0.19419200E+05, -.10007600E+05, -.30418500E+05, 0.15091100E+05, 0.13916200E+05, 0.41400200E+04, 0.22754200E+04, 0.90470400E+04, -.16493600E+03, 0.11847800E+04, 0.41901500E+04, 0.10584000E+05, -.50533300E+04, -.38746200E+04, 0.62259900E+03, 0.35684400E+04, -.59927100E+04, -.15764600E+04, -.14153400E+04, 0.16400100E+04, 0.10779300E+05, -.37875100E+04, -.93640900E+04, 0.19875900E+04, 0.99378000E+03, -.62946600E+04, -.18098500E+05, -.23965700E+05, 0.21049400E+04, 0.23851400E+05, -.11905900E+05, 0.17354200E+04, -.83248300E+04, -.51651300E+04, 0.89961000E+04, -.73279900E+04, -.16554400E+05, -.63647600E+04, 0.29305400E+05, -.14602900E+05, -.19782800E+05, -.66393000E+02, 0.48717600E+04, -.20086500E+05, -.61622200E+04, -.17466600E+04, 0.26881300E+04, -.66567600E+04, 0.36036600E+04, 0.38980200E+03, 0.20661700E+04, 0.13407600E+04, 0.12686800E+04, -.23627900E+04, -.13699200E+04, 0.30543700E+04, -.92082800E+04, -.49590500E+04, 0.14157600E+05, -.15889900E+05, -.12679000E+05, 0.84123200E+04, -.91473400E+04, 0.41763000E+04, -.20682000E+05, -.11126400E+05, -.32836300E+04, -.14032600E+05, -.22703100E+04, -.25636700E+04, -.41104500E+04, -.83034900E+04, -.12029700E+05, 0.19921800E+05, -.15270100E+05, -.90918400E+02, 0.12872800E+05, -.13875000E+05, -.16518700E+05, 0.49453600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.26370800E+00, 0.72165000E-01, 0.54713000E-02, -.11970300E+01, 0.15331000E+00, 0.33583200E+00, -.24716400E+00, 0.44228400E-01, -.23137400E+00, 0.34592600E+00, -.29401600E+00, 0.15088700E-01, -.34423300E+00, 0.12546800E+01, -.83363100E-01, 0.10206000E+01, 0.59887300E+05, -.90047900E+04, -.26741600E+05, 0.12403100E+05, 0.11297700E+05, -.12570600E+05, -.10656200E+05, 0.12413300E+05, 0.74525200E+04, 0.16083200E+05, -.14657000E+05, -.23510800E+05, 0.12331400E+05, 0.14864100E+05, 0.88484000E+04, 0.74757000E+04, 0.12747000E+04, -.11363800E+05, 0.16293900E+05, 0.72695700E+04, 0.38000300E+05, -.19697700E+05, -.13096200E+05, 0.12863500E+04, 0.45121600E+04, -.11390500E+05, -.14074900E+05, -.59180200E+05, 0.30962800E+04, 0.40681600E+05, -.20984800E+05, -.17076200E+05, 0.62354700E+03, -.18198600E+05, -.16384700E+04, -.42034800E+04, 0.29023000E+05, -.16000000E+05, -.43608200E+05, 0.21270900E+05, -.55795800E+04, 0.21217800E+05, 0.16635600E+05, -.23519100E+05, -.21611900E+05, 0.50219100E+05, 0.17409800E+05, -.45793400E+05, 0.21539000E+05, 0.22877500E+05, -.98187400E+04, -.11610700E+05, 0.20518400E+05, 0.12581800E+05, 0.20938700E+05, -.97334900E+04, -.13526400E+05, 0.67432800E+04, 0.66139200E+03, -.96341500E+02, 0.11525400E+05, -.36211900E+04, -.13338200E+05, -.59495100E+05, 0.96860500E+04, -.72824200E+05, 0.35752000E+05, 0.12474500E+05, 0.35518200E+04, 0.15125600E+05, -.13039500E+04, -.11698600E+04, 0.23920700E+05, 0.13341800E+05, 0.38138300E+05, -.19074800E+05, -.17513500E+05, 0.39875700E+02, -.15172600E+05, -.98964800E+04, 0.13600900E+04, 0.78914300E+05, -.14064200E+05, -.39561400E+05, 0.18247600E+05, -.84184800E+04, 0.87910100E+04, -.29016700E+04, -.11370100E+05, -.13110000E+04, 0.70840800E+05, -.20907200E+04, 0.30321800E+05, -.14297300E+05, 0.15120500E+05, -.18408900E+05, -.11790300E+05, 0.31579500E+05, 0.34456600E+05, -.10628700E+05, -.15550200E+05, -.15388300E+05, 0.77645700E+04, 0.28606700E+05, -.13490300E+05, -.95582200E+04, 0.33203200E+05, 0.16651700E+05, -.35377100E+05, -.55600100E+04, -.12473000E+05, 0.60629900E+04, 0.39791600E+04, 0.10150200E+05, 0.22917400E+04, -.19209100E+04, -.10266800E+05, 0.31265600E+05, 0.39684600E+04, -.57414500E+05, 0.29095300E+05, 0.25956800E+05, 0.46127700E+04, 0.22969600E+05, 0.80655300E+04, 0.26629400E+04, -.26224800E+05, 0.23153200E+05, -.59601600E+05, 0.27886000E+05, 0.28496700E+05, -.16129800E+05, -.22524400E+05, 0.26530800E+05, 0.15182200E+05, 0.29113300E+05, -.18628000E+05, 0.19452400E+05, -.10456900E+05, -.77836800E+04, -.10488200E+05, -.22595600E+05, 0.10111200E+05, 0.25031000E+05, 0.39775500E+05, -.22933200E+05, 0.36810900E+05, -.17199900E+05, -.21148300E+05, 0.70041400E+04, -.29966300E+04, -.13215100E+05, -.93615900E+04, -.19259300E+05, 0.26357600E+04, -.27868100E+05, 0.14630400E+05, 0.19629200E+05, 0.96498400E+04, 0.52709300E+04, 0.28986500E+04, -.14937500E+05, 0.21500300E+05, 0.47999600E+04, 0.50983500E+04, -.25960800E+04, -.20930800E+05, 0.12888900E+05, 0.75546600E+04, -.24955400E+05, -.11914800E+05, 0.39787500E+05, 0.44360800E+04, -.12800700E+05, 0.70573400E+04, 0.13545800E+05, 0.53427500E+04, 0.24041300E+05, -.31358400E+04, -.26569500E+05, -.56990100E+05, 0.23217000E+05, -.56747800E+04, 0.29316400E+04, 0.76048400E+04, 0.39781300E+04, -.75802600E+03, 0.28488100E+03, -.57926700E+04, 0.19319400E+04, 0.36408000E+04, 0.13745000E+05, 0.73795400E+04, 0.25246800E+04, -.10245800E+04, -.10565600E+05, -.18906100E+04, 0.80181200E+04, 0.20070700E+04, -.91780600E+04, 0.95672100E+03, -.15926300E+05, 0.88343200E+04, -.14448700E+04, -.61939700E+04, -.12812800E+05, -.92410800E+04, 0.15376100E+05, 0.41605000E+04, 0.12210600E+05, -.22901600E+05, 0.45910200E+04, -.62919400E+04, 0.11139900E+05, -.80158000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.59912200E+00, 0.23528300E+00, 0.56656800E-01, 0.60492600E-01, 0.17681000E+00, 0.76952700E-01, -.11052600E+00, 0.11681900E+00, -.33242100E+00, 0.19857700E+00, -.30223600E+00, -.55412100E-01, 0.48261200E+00, -.99852800E-01, 0.24170100E+00, -.77094700E+00, -.26226700E+00, 0.73645400E+04, -.10766500E+05, 0.51406500E+04, 0.58523900E+04, -.67145100E+04, -.99070400E+04, 0.62386000E+04, 0.56319400E+04, 0.71635300E+04, -.32220600E+04, 0.10035200E+05, -.42437200E+04, -.55961500E+04, 0.39470500E+04, 0.49920100E+04, -.79338400E+04, -.11065300E+05, -.15320400E+05, 0.53068000E+04, 0.55683400E+04, -.33784800E+04, -.37648100E+04, -.18908900E+04, 0.32208500E+03, -.36876700E+04, -.28377600E+04, -.55497100E+03, -.12389100E+04, 0.15885700E+05, -.81810100E+04, -.87441000E+04, 0.11978400E+04, -.36542900E+04, -.47583600E+04, -.24502300E+04, 0.16015700E+04, 0.50390700E+03, 0.10421600E+05, -.53388400E+04, -.29590900E+03, -.12005000E+03, 0.90317300E+03, -.14241700E+02, -.98773100E+04, -.11060400E+05, 0.19571600E+04, -.16687000E+05, 0.77040100E+04, 0.83476400E+04, -.17357400E+04, -.58133800E+04, 0.74118700E+04, 0.47898600E+04, 0.80747700E+04, -.35034900E+04, 0.10757900E+05, -.53579600E+04, -.44733300E+04, -.67151500E+04, -.64511900E+04, -.77894700E+03, 0.25682400E+04, 0.41552000E+04, -.74794200E+04, -.10452400E+05, 0.50050400E+04, 0.99759700E+04, -.39223800E+04, -.68171400E+04, 0.10410000E+05, 0.58957900E+04, 0.57665400E+04, -.37736700E+04, -.19447000E+05, 0.96865200E+04, 0.97675200E+04, 0.80229700E+04, 0.97198700E+04, 0.28580900E+04, -.13727000E+05, -.95387000E+04, 0.11325000E+05, -.56187800E+04, 0.23276800E+04, 0.76023900E+04, -.89070600E+03, -.60813300E+04, 0.90145300E+04, 0.38572400E+04, 0.15078500E+04, -.15082200E+03, -.73538500E+04, 0.39023000E+04, -.18794500E+04, 0.72889300E+04, 0.93140200E+04, -.59921300E+04, 0.60299100E+03, -.15396700E+04, 0.47968700E+04, -.11286500E+05, 0.56399600E+04, 0.19202500E+04, 0.38027600E+04, 0.14240300E+04, -.54714700E+02, 0.35119500E+04, 0.44742800E+04, -.29862100E+03, 0.46537900E+04, -.23694200E+04, -.19155100E+04, 0.15432700E+04, -.51438500E+03, 0.16438700E+03, -.11716900E+04, 0.18599900E+04, 0.13088300E+04, -.19828700E+05, 0.97819900E+04, 0.10109200E+05, 0.13605400E+04, 0.49933800E+04, 0.69732200E+04, 0.43483100E+04, 0.15537300E+04, 0.31788900E+03, -.30559000E+05, 0.14426700E+05, 0.15512700E+05, -.47070700E+04, -.12510900E+05, 0.14434800E+05, 0.10306400E+05, 0.15871800E+05, -.55659300E+04, -.48688700E+04, 0.20608400E+04, 0.20287200E+04, 0.26335100E+04, -.14692500E+04, 0.19736800E+04, 0.55109400E+04, 0.27141400E+04, 0.28307300E+03, 0.21003700E+05, -.98468600E+04, -.10361600E+05, 0.18236200E+03, 0.20192600E+04, -.87528800E+04, -.43135300E+04, -.69232500E+04, 0.95709400E+02, 0.15915400E+05, -.68983100E+04, -.88727600E+04, 0.50247900E+04, 0.55449800E+04, -.11938500E+05, -.15929400E+05, -.20327300E+05, 0.63966800E+04, 0.11338600E+05, -.56638700E+04, -.22920500E+04, -.36326900E+03, 0.18107500E+04, -.24927500E+04, -.39030000E+04, -.74538400E+04, 0.34445100E+04, 0.11828300E+05, -.56206600E+04, -.68795500E+04, -.39801400E+04, 0.42108300E+03, -.49937500E+04, -.52075000E+04, -.70388100E+03, -.19425600E+04, -.10353400E+04, 0.70599200E+03, -.72457400E+02, 0.10459100E+04, -.86101900E+03, 0.27643200E+03, -.48065500E+03, 0.12169000E+04, 0.14159700E+04, -.10671500E+04, -.36684500E+04, 0.17661700E+04, -.70771900E+04, -.39114900E+04, 0.57269900E+04, -.14239400E+04, 0.19277100E+04, -.90634400E+04, 0.93144300E+03, -.34889600E+04, -.16233400E+04, 0.11003200E+04, -.23571200E+04, 0.52654600E+03, -.31207200E+03, -.38290300E+04, 0.87671900E+04, 0.24289700E+04, -.17394700E+04, 0.24658100E+04, -.11422300E+03, 0.33448200E+03, 0.32580300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.28120300E+00, 0.46037200E+00, 0.83795400E-01, -.62187800E+00, -.49104400E+00, 0.50108600E+00, -.85624000E+00, -.16606300E+00, -.34884000E+00, 0.75816400E-01, -.12467200E+00, -.80579700E-01, -.45226100E-01, 0.47691800E-01, -.55651100E+00, -.10885700E+01, -.23285000E+00, 0.86273400E-01, -.17594100E+05, 0.78670900E+04, 0.90059100E+04, -.14696500E+05, -.22640000E+05, 0.14990300E+05, 0.26183700E+05, 0.17075100E+05, -.18216200E+05, -.24534500E+05, 0.12276100E+05, 0.11796900E+05, 0.10856300E+05, 0.11804400E+05, -.13962000E+04, -.12827000E+05, -.10872000E+05, 0.10644200E+05, 0.29786500E+05, -.14835700E+05, -.15711900E+05, -.37070200E+04, -.74103200E+04, -.89862300E+04, -.67106400E+04, -.11415200E+05, -.63006300E+04, 0.31550100E+05, -.16362900E+05, -.16335600E+05, 0.52594300E+04, -.22422000E+04, -.97302200E+04, -.78750900E+04, -.82066700E+04, -.32284100E+04, 0.59651000E+03, -.46839100E+03, 0.39184200E+04, 0.48555100E+04, 0.18846700E+04, 0.11301800E+04, -.10702100E+05, -.31745800E+04, -.76420600E+03, -.49512700E+05, 0.23892900E+05, 0.24761000E+05, -.96156200E+04, -.15923300E+05, 0.25258200E+05, 0.27223400E+05, 0.25920600E+05, -.10643500E+05, 0.25537200E+05, -.12711000E+05, -.11755200E+05, -.10955700E+05, -.10101900E+05, -.29326800E+04, 0.33702200E+04, -.78552400E+04, -.99185500E+04, -.16696800E+04, 0.59841900E+03, 0.36492200E+04, -.10045800E+05, 0.54206900E+04, 0.39696900E+04, 0.95899800E+04, -.26139300E+03, -.40100300E+03, -.70138400E+04, 0.34809900E+04, 0.33229300E+04, 0.82524400E+04, 0.75243300E+04, -.91481500E+03, -.13337700E+05, 0.75684900E+04, 0.59136800E+04, -.40145100E+05, 0.19074000E+05, 0.24350900E+05, -.32813000E+04, -.14094000E+05, 0.26262500E+05, 0.28700700E+05, 0.23853100E+05, -.11563600E+05, 0.58854000E+03, 0.16078900E+03, -.51279800E+04, 0.83201100E+04, 0.19685200E+05, -.12341500E+05, -.10327600E+05, -.79492800E+04, 0.16420800E+05, -.28127200E+05, 0.13899600E+05, 0.10322400E+05, -.87658100E+03, 0.92807100E+03, 0.71799300E+04, 0.46708800E+04, 0.23581900E+04, 0.37985100E+04, -.79368100E+04, 0.38313900E+04, 0.43205900E+04, 0.69662300E+04, 0.57823100E+04, 0.30594500E+03, -.78951100E+04, -.90382000E+03, 0.51856300E+04, -.30805500E+05, 0.16069200E+05, 0.15689600E+05, -.25457400E+04, 0.13780800E+05, 0.75473200E+04, 0.13770200E+04, 0.34702500E+04, 0.12371800E+05, -.73238500E+05, 0.35288400E+05, 0.36853200E+05, -.18387200E+05, -.31889500E+05, 0.40931900E+05, 0.49315600E+05, 0.42513300E+05, -.21763600E+05, -.15836000E+03, -.37361800E+03, -.17447400E+03, -.10795500E+03, -.24890500E+04, 0.57618200E+04, 0.14431800E+05, 0.50767200E+04, -.50852300E+04, 0.13330300E+05, -.60351100E+04, -.62200100E+04, 0.79710900E+04, -.68412900E+04, -.50632300E+04, -.85849400E+04, -.29456400E+04, -.23911300E+04, -.27093600E+05, 0.13344400E+05, 0.12842300E+05, 0.13653800E+05, 0.11640900E+05, -.24263100E+04, -.16310800E+05, -.16003500E+05, 0.10202800E+05, 0.23729400E+05, -.11707100E+05, -.88992700E+04, 0.34824900E+04, 0.16178800E+04, -.57820500E+04, -.45379500E+04, -.67805600E+04, -.16655300E+04, 0.18827300E+05, -.90326300E+04, -.10804100E+05, 0.91240600E+02, 0.14216000E+05, -.19598700E+05, -.29969500E+05, -.17318500E+05, 0.14121700E+05, 0.58008100E+04, -.32728700E+04, -.34532200E+04, 0.36450200E+04, 0.21640800E+04, -.35688000E+04, -.39575600E+04, -.48620800E+04, 0.29824500E+04, 0.29384300E+04, -.16599600E+04, 0.62466400E+04, -.12299100E+05, -.21231800E+05, 0.10429100E+05, -.33618900E+04, 0.20221300E+04, -.19048000E+05, -.36055300E+04, 0.73821200E+04, -.35878700E+04, 0.22600400E+04, 0.91561800E+03, -.42562200E+04, -.46406000E+04, 0.27174300E+04, 0.15985900E+05, 0.83251000E+04, 0.15257600E+04, 0.16279500E+05, -.70058500E+04, 0.49721900E+04, 0.15840800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.76204600E-01, 0.52617100E-01, -.41049200E-02, -.56583900E+00, 0.30602500E+00, 0.24351300E+00, -.35804200E-01, 0.13364300E-02, 0.12362500E+00, -.13816300E-01, 0.12072200E+00, 0.26299900E+00, 0.60573800E-01, 0.72334600E-01, 0.57318900E-01, 0.20658000E+00, 0.13869700E+00, -.24097800E+00, 0.38756800E+00, 0.61517200E+03, 0.49656700E+02, 0.12026600E+05, 0.11590200E+05, -.50739200E+04, -.15311500E+05, -.60993800E+04, 0.10806200E+05, 0.19739500E+05, -.92875600E+04, -.97310900E+04, -.65771900E+04, -.81171600E+04, -.23826700E+04, 0.52651300E+04, 0.30256100E+04, -.67360400E+04, -.19128100E+05, 0.91682900E+04, 0.97204600E+04, -.22358700E+04, 0.26349800E+04, 0.80720100E+04, 0.73943100E+04, 0.10453300E+05, 0.24293600E+04, -.22254800E+05, 0.11460000E+05, 0.11303600E+05, -.53441700E+04, -.16359400E+04, 0.74823500E+04, 0.53670400E+04, 0.78899300E+04, -.22310300E+02, 0.92898100E+03, -.40092300E+03, -.13636500E+04, -.51298000E+04, -.14587100E+04, 0.46381800E+03, 0.69836800E+04, -.24460000E+03, -.20111100E+03, 0.30963700E+05, -.15168500E+05, -.15483000E+05, 0.10492700E+05, 0.76407100E+04, -.16250400E+05, -.18731200E+05, -.16362300E+05, 0.54348500E+04, -.16058700E+05, 0.79888400E+04, 0.78224900E+04, 0.58885300E+04, 0.47897300E+04, 0.36557600E+04, -.18095000E+04, 0.78986200E+04, 0.50703400E+04, -.32874500E+04, 0.17010400E+04, 0.12440900E+04, 0.10616300E+05, -.35500900E+04, -.38770500E+03, -.66739200E+04, 0.11931500E+04, 0.63091600E+03, 0.30854300E+04, -.15266000E+04, -.15382400E+04, -.45341900E+04, -.21853100E+04, -.68464900E+03, 0.61936100E+04, -.98753800E+04, -.18965600E+04, 0.13616700E+05, -.62844600E+04, -.77099800E+04, 0.53617400E+04, 0.61658000E+04, -.11285400E+05, -.16467500E+05, -.12175800E+05, 0.58325300E+04, 0.70233900E+03, -.58802800E+03, 0.70881200E+03, -.42393200E+04, -.93185000E+04, 0.42249200E+04, 0.55337400E+04, 0.37101300E+04, -.78361900E+04, 0.16576500E+05, -.81545900E+04, -.73710300E+04, 0.13808200E+04, -.22569400E+04, -.39309300E+04, -.56377800E+03, 0.15125100E+04, -.35678500E+04, 0.86898400E+04, -.42550600E+04, -.43994500E+04, -.53256900E+04, -.46150000E+04, -.10186500E+04, 0.54263900E+04, 0.35727800E+03, -.44561400E+04, 0.26154300E+05, -.13745500E+05, -.13067000E+05, 0.36452200E+04, -.55579600E+04, -.72837600E+04, -.14182900E+04, -.54427800E+04, -.63742400E+04, 0.40284900E+05, -.19583300E+05, -.20195700E+05, 0.19216400E+05, 0.15296600E+05, -.24078900E+05, -.32684200E+05, -.24541800E+05, 0.11482500E+05, -.42232300E+04, 0.22501700E+04, 0.21615700E+04, 0.23471300E+04, -.91531400E+03, -.26191700E+04, -.96825000E+04, -.21811800E+04, 0.23028500E+04, -.33542500E+04, 0.15636300E+04, 0.17233200E+04, -.85591700E+04, 0.44913900E+04, 0.17945700E+04, 0.57994200E+04, 0.37010900E+03, 0.76992400E+03, 0.22827600E+05, -.10444900E+05, -.11342100E+05, -.86262300E+04, -.94007700E+04, -.26269900E+04, 0.62851600E+04, 0.55547500E+04, -.70823200E+04, -.92759100E+04, 0.45129600E+04, 0.38975000E+04, -.38914600E+04, -.94645600E+03, 0.20471400E+04, 0.90964900E+03, 0.67019600E+03, 0.74375900E+03, -.35442600E+04, 0.16419900E+04, 0.21010200E+04, -.22062300E+04, -.49345500E+04, 0.88962700E+04, 0.17731600E+05, 0.90811500E+04, -.69539400E+04, -.69347600E+04, 0.38675300E+04, 0.33817700E+04, -.26238000E+04, -.19150800E+04, 0.33961100E+04, 0.27359700E+04, 0.45771000E+04, -.22672400E+04, -.36694000E+03, -.70994100E+03, -.22168300E+04, 0.75862900E+04, 0.13119200E+05, -.36353200E+04, 0.47305800E+03, 0.55521700E+03, 0.15406100E+05, 0.11727000E+04, -.55591700E+04, 0.56084500E+03, -.70290300E+03, -.22014400E+04, 0.17097300E+04, 0.12212900E+04, -.26931400E+04, -.11515000E+05, -.49224000E+04, 0.94091400E+03, -.10141900E+05, 0.30888700E+04, -.42259300E+04, 0.76273800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14284000E+01, 0.64766100E+00, 0.48918700E+00, 0.65681400E+00, 0.76383800E-01, 0.54118100E+00, -.50745000E+00, 0.35823600E-01, -.97160100E+00, 0.15101100E-01, -.41806500E+00, 0.68738900E+00, 0.32997700E+00, -.11900700E+01, 0.13685300E+01, -.68392400E+00, 0.27145100E+00, -.10845000E+01, -.10305700E+01, -.18012800E+01, 0.19941800E+04, 0.23646400E+05, 0.23437600E+05, -.10382800E+05, -.36540900E+05, -.12254000E+05, 0.21487500E+05, 0.56136000E+05, -.27118900E+05, -.29772500E+05, -.97506400E+04, -.48515600E+04, -.18444200E+05, 0.32590600E+04, -.93783200E+04, -.69268400E+04, -.42205200E+05, 0.19691900E+05, 0.17846200E+05, -.18230800E+05, -.22140600E+04, 0.24392700E+05, 0.21943700E+05, 0.34595300E+05, 0.15779300E+03, -.67400200E+03, 0.12350900E+03, -.16454300E+04, -.18858500E+05, -.10543300E+05, 0.40249300E+03, -.17732100E+04, 0.14446100E+05, -.69622300E+04, 0.40625500E+05, -.20392200E+05, -.34889500E+04, -.19678300E+05, -.63210600E+03, 0.56794700E+04, 0.23232400E+04, -.23740500E+05, -.97188800E+04, 0.69606000E+05, -.35518800E+05, -.34790900E+05, 0.26234600E+05, 0.17188200E+05, -.37750400E+05, -.46174900E+05, -.37770600E+05, 0.12218700E+05, -.12337600E+05, 0.61483100E+04, 0.98730800E+04, 0.75782100E+03, -.57780000E+04, 0.13542200E+05, 0.11659000E+04, 0.30070100E+05, -.42360200E+04, -.56944600E+04, 0.25727800E+04, 0.18633200E+05, 0.30100000E+05, -.10504800E+05, 0.95352700E+04, -.16524400E+05, -.22651700E+04, -.51139400E+04, 0.12588000E+03, -.59422000E+02, -.61875500E+03, 0.19532400E+04, 0.12748700E+05, -.10029600E+05, -.21887600E+05, -.53904700E+05, 0.89918100E+04, 0.50935800E+05, -.25787600E+05, -.87914600E+04, 0.12172500E+05, 0.18972100E+05, -.18178900E+05, -.39868600E+05, -.39496600E+05, 0.10453700E+05, -.55448600E+05, 0.27879000E+05, 0.88604800E+04, 0.83650500E+04, -.87238600E+04, 0.12197600E+04, 0.21667100E+05, 0.21367500E+05, -.13975100E+04, 0.63899200E+05, -.31799400E+05, -.44367000E+05, 0.12150300E+05, -.73377200E+04, -.32252200E+05, -.95273900E+04, 0.26698700E+03, -.60921800E+04, 0.46558600E+05, -.23245600E+05, -.21766100E+05, -.13104100E+05, -.12316700E+05, -.95329700E+04, 0.38505600E+04, -.48948800E+04, -.13031900E+05, 0.33650900E+05, -.17172100E+05, -.15076700E+05, 0.17028300E+05, -.11572200E+05, -.81802300E+04, 0.33193200E+04, -.12228300E+05, -.11701400E+05, 0.89564900E+05, -.45615800E+05, -.43979900E+05, 0.46118200E+05, 0.32900200E+05, -.54610300E+05, -.79707300E+05, -.55499500E+05, 0.27775400E+05, -.37575000E+04, 0.13907500E+04, 0.67552800E+03, 0.88405500E+04, 0.85442600E+03, -.99878500E+04, -.17980400E+05, -.56556600E+04, 0.61269900E+04, 0.17301200E+05, -.76897200E+04, -.66184100E+04, -.29220900E+05, 0.79163300E+04, -.16755900E+04, 0.16041200E+05, -.18132100E+04, -.77060000E+02, 0.73715200E+05, -.35333900E+05, -.40739900E+05, -.15435600E+05, -.44869200E+04, -.24202700E+05, 0.30234300E+04, -.71749100E+04, -.71228400E+04, -.39938500E+05, 0.19849600E+05, 0.30315100E+05, -.18983800E+05, -.18622100E+04, 0.26292000E+05, 0.18225300E+05, 0.75147800E+04, -.14482700E+04, -.10056600E+05, 0.53433600E+04, 0.85102800E+03, -.59807100E+04, -.20717800E+05, 0.17432700E+05, 0.35635500E+05, 0.26501400E+05, -.19458600E+05, -.18367200E+05, 0.96894400E+04, 0.53954800E+04, -.45948700E+04, -.53699400E+04, 0.73913400E+04, 0.37551100E+04, 0.12234500E+05, -.30651800E+04, -.13514800E+05, 0.15756900E+04, 0.10352900E+04, 0.51058300E+04, 0.28757500E+05, -.48272600E+04, 0.16143800E+04, -.40640500E+04, 0.23675300E+05, 0.11972600E+05, -.24401200E+05, 0.33719800E+04, 0.21648200E+03, -.14861600E+05, 0.67573400E+04, 0.49601900E+04, -.18021400E+05, -.13628700E+05, -.15147900E+05, -.22571100E+04, -.22696100E+05, 0.64416100E+04, -.14375800E+05, -.18603600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.68790600E+00, 0.96549900E+00, 0.51122500E+00, 0.18243300E+01, 0.56299900E+00, -.19351600E+01, 0.25794300E+00, 0.10254600E-01, -.12757300E-01, 0.20338600E+00, 0.44375400E+00, 0.35052800E+00, 0.43765200E+00, -.39693900E+00, 0.72069100E+00, -.80951100E+00, -.40823900E-01, 0.10791900E+01, -.98289700E+00, 0.34391800E+01, -.23634500E-01, -.42319800E+05, -.35253900E+05, 0.18652900E+05, 0.58827900E+05, 0.23609600E+05, -.34589100E+05, -.86493100E+05, 0.42039300E+05, 0.42138000E+05, 0.28869200E+05, 0.36554100E+05, 0.76990300E+04, -.25422400E+05, -.11329300E+05, 0.31816500E+05, 0.82986600E+05, -.38527100E+05, -.43485300E+05, 0.17359700E+04, -.19756100E+05, -.29556900E+05, -.25778000E+05, -.40321200E+05, -.15851900E+05, 0.87830900E+05, -.43510900E+05, -.45089000E+05, 0.19305100E+05, 0.58525300E+04, -.29798300E+05, -.22672600E+05, -.31456600E+05, -.19138100E+04, 0.88226800E+04, -.38934200E+04, 0.51247800E+04, 0.17031800E+05, 0.25935800E+04, -.49054300E+03, -.27378500E+05, -.33646900E+04, -.14539400E+04, -.10601100E+06, 0.54601800E+05, 0.53015700E+05, -.37915400E+05, -.20024900E+05, 0.57368800E+05, 0.71565100E+05, 0.57692900E+05, -.16249800E+05, 0.69906600E+05, -.34835800E+05, -.32433500E+05, -.26309200E+05, -.24481600E+05, -.11084200E+05, 0.89388300E+04, -.29304000E+05, -.24128900E+05, 0.15351300E+05, -.69301200E+04, -.21776700E+04, -.40072500E+05, 0.19466800E+05, 0.29942200E+04, 0.26110900E+05, -.63463600E+04, 0.25027000E+03, -.73331100E+04, 0.36949300E+04, 0.28132900E+04, 0.18090200E+05, 0.11337000E+05, -.16674100E+04, -.26649500E+05, 0.34890400E+05, 0.80029600E+04, -.55976500E+05, 0.29123600E+05, 0.38168200E+05, -.20166200E+05, -.14294400E+05, 0.48353800E+05, 0.64153500E+05, 0.47617000E+05, -.17277400E+05, -.19707200E+05, 0.92003400E+04, -.92802000E+03, 0.19207400E+05, 0.33083500E+05, -.20270300E+05, -.24209000E+05, -.98036900E+04, 0.33131200E+05, -.65326200E+05, 0.32233100E+05, 0.24014100E+05, -.66520500E+04, 0.81000600E+04, 0.12219900E+05, 0.74502300E+03, -.51418700E+04, 0.12518400E+05, -.31773300E+05, 0.15903600E+05, 0.16503500E+05, 0.20591600E+05, 0.19747500E+05, 0.23486900E+04, -.22220900E+05, -.49320200E+04, 0.17281100E+05, -.10475900E+06, 0.52887600E+05, 0.53182200E+05, -.16273100E+05, 0.17563800E+05, 0.31798000E+05, 0.11829000E+05, 0.25427400E+05, 0.20981800E+05, -.14201600E+06, 0.72873100E+05, 0.71537900E+05, -.67908400E+05, -.41377900E+05, 0.87651200E+05, 0.12645800E+06, 0.89262800E+05, -.36166300E+05, 0.15528900E+05, -.67383700E+04, -.82202400E+04, -.71518200E+04, 0.81326400E+04, 0.90957300E+04, 0.32190800E+05, 0.78310400E+04, -.60839600E+04, 0.15836200E+05, -.97284500E+04, -.70754600E+04, 0.34399100E+05, -.21913000E+05, -.70061600E+04, -.23791700E+05, -.19419000E+04, -.64505100E+04, -.96470200E+05, 0.46016300E+05, 0.46829100E+05, 0.37485200E+05, 0.42727400E+05, 0.70787100E+04, -.31789900E+05, -.22814000E+05, 0.34821100E+05, 0.39539100E+05, -.19417700E+05, -.12712700E+05, 0.13273200E+05, -.15311700E+03, -.29130300E+04, 0.72429500E+03, -.10887200E+04, -.56782300E+04, 0.51293400E+04, -.33912900E+04, -.61424300E+04, 0.85690200E+04, 0.14755900E+05, -.33972500E+05, -.63943600E+05, -.33327500E+05, 0.25190200E+05, 0.24842300E+05, -.13866700E+05, -.13195100E+05, 0.10063200E+05, 0.81169300E+04, -.12481800E+05, -.99662200E+04, -.16784500E+05, 0.78720100E+04, -.28524800E+04, 0.55754500E+04, 0.73619600E+04, -.26551800E+05, -.52139900E+05, 0.15136600E+05, -.16259600E+03, -.47035300E+04, -.47497300E+05, -.21377300E+04, 0.21010000E+05, -.18358300E+03, 0.77279500E+04, 0.67916100E+04, -.34512700E+04, -.34034600E+04, 0.10507600E+05, 0.35249500E+05, 0.18665000E+05, -.42483300E+04, 0.39888000E+05, -.10141400E+05, 0.17786300E+05, -.55229500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13234500E+00, 0.13918800E+01, 0.28047800E+00, -.20280100E+01, 0.16271300E+00, 0.52452800E+00, -.20536300E+01, -.24235800E+00, -.55559700E+00, -.53319200E+00, 0.19798000E+00, 0.68033000E+00, 0.10845000E+00, 0.21000700E+01, -.21390300E+00, 0.23774800E+01, 0.11967000E+01, 0.41851800E+00, -.57725000E-01, 0.66734300E+00, 0.77738800E-01, 0.43601800E+00, 0.12576000E+05, -.35290900E+04, -.90139500E+04, -.27080000E+04, 0.12680900E+05, -.26784300E+05, 0.13046600E+05, 0.13035300E+05, 0.36996600E+04, 0.17895700E+04, 0.96091700E+04, -.44977200E+04, 0.15336900E+04, 0.57229700E+04, -.82571900E+03, 0.39154400E+03, -.40363600E+03, 0.71593100E+04, 0.42470100E+04, -.64211600E+04, -.21831000E+04, -.25578800E+03, 0.12567700E+04, -.35672700E+05, 0.17838600E+05, 0.17704800E+05, 0.94819400E+04, 0.87888800E+04, 0.58708200E+04, 0.10362000E+05, 0.83612800E+04, 0.85606600E+04, -.91859500E+04, 0.46111800E+04, 0.73664000E+04, 0.14016700E+04, -.20384800E+04, 0.75171600E+04, 0.10532500E+05, -.12150400E+05, 0.14888200E+04, 0.16863900E+05, -.83965400E+04, -.84293100E+04, -.24963100E+04, 0.85100900E+04, -.70406100E+04, -.39983500E+04, -.71376600E+04, 0.85278300E+04, -.66148300E+04, 0.32988300E+04, 0.40792700E+04, 0.36293900E+03, 0.28957500E+04, -.85656500E+02, 0.74084500E+04, 0.11534400E+05, 0.24057200E+04, 0.66878100E+04, -.33318000E+04, -.14075500E+04, -.15490700E+05, -.11205000E+05, 0.87676000E+04, 0.11055200E+05, 0.43872100E+04, -.62649000E+04, -.38198900E+05, 0.19063700E+05, 0.18559600E+05, 0.52236500E+04, 0.69884600E+04, 0.10341800E+05, 0.13783200E+05, -.21372400E+05, 0.88454500E+04, -.14805000E+05, 0.73877300E+04, 0.10740500E+05, -.35852200E+04, 0.86257200E+04, 0.66203800E+04, -.22454400E+04, -.65835700E+04, 0.10401500E+05, 0.40305700E+04, -.20780500E+04, -.48780000E+04, -.16630100E+03, -.68641600E+04, -.30506200E+04, -.11809100E+05, 0.85780800E+04, -.45537100E+04, -.39747100E+05, 0.19802600E+05, 0.17612700E+05, 0.15340400E+04, 0.11373700E+05, 0.46677400E+04, -.42555300E+04, 0.14412200E+05, 0.91223300E+04, 0.63453600E+04, -.31575900E+04, -.30306300E+04, -.99773500E+03, -.41865700E+04, 0.10948700E+04, 0.11632800E+05, -.28962900E+04, -.40502100E+04, 0.64446000E+04, -.31214500E+04, -.29034100E+04, -.11818600E+05, -.11467500E+05, 0.53460800E+04, 0.40042400E+04, 0.42800900E+04, -.10516700E+05, 0.22225700E+05, -.11076600E+05, -.10967000E+05, -.46568500E+04, 0.17293600E+05, -.10142800E+05, -.72262400E+04, -.10279200E+05, 0.14700800E+05, -.15096900E+05, 0.75446500E+04, 0.75012500E+04, 0.43585200E+04, 0.71018600E+04, -.50730200E+03, -.97358300E+04, 0.46368400E+04, 0.10623300E+05, -.37413200E+03, 0.13679400E+03, 0.57513600E+03, 0.95870200E+04, 0.61027800E+04, -.45555100E+04, -.69838100E+04, -.26821000E+04, 0.86072100E+03, -.37567100E+05, 0.18339000E+05, 0.18274000E+05, 0.83408200E+04, 0.61490200E+04, 0.10939300E+05, -.77817900E+04, 0.24499600E+04, 0.11685300E+05, 0.16163700E+05, -.80372600E+04, -.59841400E+04, 0.40114500E+04, -.45805200E+04, -.23392500E+04, -.31586900E+04, -.45345600E+04, -.28974700E+04, 0.10774800E+05, -.53751100E+04, -.64399100E+04, -.64724000E+04, -.12858500E+05, 0.42966300E+04, 0.19421200E+05, 0.35723500E+04, -.15827900E+05, 0.20487100E+04, -.87963900E+03, -.13778600E+04, -.10360700E+04, -.90474200E+03, 0.96224000E+03, 0.47825700E+04, 0.43401400E+04, -.37602100E+04, 0.76140800E+03, -.76324600E+04, -.31575900E+04, 0.59054000E+04, -.42463400E+04, 0.15075800E+04, 0.14442800E+04, -.41921700E+03, 0.86078100E+04, -.37802600E+04, 0.85707900E+04, -.41095300E+04, 0.26290900E+04, 0.33945600E+04, 0.45733500E+04, 0.12915300E+04, 0.52329800E+04, -.76562700E+04, -.77279100E+03, 0.53682400E+04, 0.29626500E+04, 0.90390400E+03, 0.92219000E+03, 0.77905400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10634300E+01, 0.70853400E-01, 0.29337000E+00, 0.21177500E+01, 0.40346300E+00, -.16392100E+01, -.23799500E+00, -.17213400E+00, -.94136000E-01, -.28429800E+00, -.25442000E+00, -.28037300E+00, -.29361400E+00, -.65440300E+00, 0.34415000E+00, -.65645000E+00, -.26562200E+00, 0.75501100E+00, -.16101200E+01, -.21362900E+01, 0.65679300E-01, -.17613300E+00, 0.20039300E+00, 0.37307600E+04, 0.14641300E+05, 0.50702900E+04, -.20238900E+04, -.61720500E+04, 0.31334400E+04, 0.28396300E+04, 0.62853500E+04, 0.92832600E+04, -.68276600E+04, -.99261700E+04, -.58270000E+04, 0.67134600E+04, 0.99880000E+04, -.44277600E+04, -.56803900E+04, -.11853400E+05, -.15123600E+05, 0.42832600E+04, 0.25541600E+04, -.22081000E+04, -.80594800E+04, 0.25938400E+05, -.12891700E+05, -.13063600E+05, -.26653700E+04, -.29093300E+04, -.60816100E+04, -.92751100E+04, -.10032100E+05, -.68157400E+04, 0.15203100E+05, -.74723800E+04, -.48158500E+04, -.55984800E+03, -.37283000E+04, -.51310000E+04, -.85743900E+04, 0.30183100E+04, -.33335400E+04, -.48098300E+04, 0.27444600E+04, 0.24089700E+04, 0.22038800E+04, 0.24517700E+04, 0.41353100E+04, 0.10168500E+05, 0.48240000E+04, -.15187200E+04, 0.12541900E+05, -.62553100E+04, -.52894200E+04, -.46741000E+04, -.51197200E+04, 0.89536100E+03, -.18788800E+04, -.12043000E+05, -.31065200E+04, 0.78132900E+04, -.37824300E+04, -.29574900E+04, 0.57632400E+04, 0.17679900E+05, -.78102500E+04, -.31216000E+04, -.76919000E+04, 0.92936500E+04, 0.31025800E+05, -.15462100E+05, -.16093900E+05, -.28585600E+04, -.58450500E+04, -.93816900E+04, -.54721200E+04, 0.18291700E+05, -.89528600E+04, -.10575900E+05, 0.55769000E+04, 0.85579000E+04, 0.26325100E+04, 0.20522900E+04, 0.81883400E+04, 0.12680500E+05, 0.13948500E+05, -.27586900E+04, -.12163400E+05, 0.59681100E+04, 0.29837900E+04, 0.25291100E+04, 0.29885700E+04, -.34279500E+04, -.29818300E+04, -.31553600E+04, 0.64479100E+04, -.67236200E+03, 0.25649900E+03, -.23832800E+04, -.17913300E+04, -.18834200E+04, 0.15428200E+04, 0.83390700E+03, -.73248000E+04, -.21756000E+04, -.10268000E+05, 0.51382200E+04, 0.52938200E+04, 0.34996500E+04, 0.60390300E+04, -.23971000E+03, -.86076400E+04, -.11420600E+04, 0.36706500E+04, -.25278200E+05, 0.12640300E+05, 0.13009300E+05, 0.19006400E+04, 0.54361500E+04, 0.62453700E+04, 0.54129100E+04, 0.70146300E+04, 0.68226600E+04, -.17159300E+05, 0.89697200E+04, 0.87576200E+04, 0.34731200E+04, 0.38976400E+04, 0.12200400E+05, 0.23878600E+05, 0.13829700E+05, -.34455100E+04, 0.17458400E+05, -.85280100E+04, -.87061400E+04, 0.43114300E+03, 0.22023600E+04, -.23157400E+04, 0.19689400E+04, -.46182900E+04, -.45830400E+04, -.19751700E+04, 0.68826200E+03, 0.17040100E+04, -.81443500E+03, -.11970900E+05, 0.38376400E+04, -.39774900E+03, 0.28435200E+04, -.63078500E+04, 0.19747900E+04, -.10545000E+04, -.14199400E+04, 0.69966600E+04, 0.10175100E+05, -.10898300E+05, -.14278700E+05, -.12417700E+05, 0.63497300E+04, 0.82480000E+04, -.40450300E+04, -.21123000E+04, -.13306800E+04, -.24856000E+04, 0.26618500E+03, 0.18167600E+04, 0.16015500E+04, -.25523400E+04, -.18747300E+05, 0.91791000E+04, 0.78638700E+04, 0.19893900E+04, 0.62220400E+04, -.38117800E+04, -.12837500E+05, -.42130300E+04, 0.12126300E+05, 0.17421200E+04, -.11870500E+04, -.14144000E+04, 0.26298800E+04, 0.43996200E+04, -.21691300E+04, -.30874000E+04, -.55540400E+04, 0.18079000E+04, -.38914700E+04, 0.86740800E+04, 0.24474400E+03, -.94818100E+03, -.10797100E+05, 0.25548000E+04, 0.12142900E+04, -.23728300E+04, 0.76845300E+04, 0.19562100E+04, 0.27433500E+04, 0.38594000E+04, 0.56498800E+04, 0.11632700E+04, 0.10214500E+04, -.20582400E+03, 0.78074100E+03, -.49997600E+04, 0.41437300E+04, 0.13659400E+04, 0.79755500E+04, 0.11372600E+03, 0.47284200E+04, -.80380400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13868100E+01, 0.23643700E+00, 0.25829800E+00, -.83489900E+00, 0.12716000E+00, 0.91207300E+00, -.38540500E+00, -.27704300E+00, 0.79025600E+00, 0.27050200E+00, -.13992300E+00, -.23472100E+00, -.19558700E+00, -.11798000E+01, 0.21951200E+00, -.17342700E+01, -.27366200E+00, 0.10679500E+01, 0.12933000E+00, -.13817500E+01, 0.26731300E+00, -.28306200E+00, -.69346600E+00, 0.45620000E-01, 0.37611700E+04, 0.16561400E+04, 0.10131600E+04, -.44047400E+05, 0.20030900E+05, 0.21315000E+05, -.38335000E+04, -.10817000E+05, 0.24005000E+05, 0.14836600E+05, 0.29757000E+05, -.58428500E+04, 0.41603100E+04, -.57124300E+03, -.43241100E+04, 0.10784500E+05, 0.39845400E+04, -.10555800E+05, -.60437500E+04, -.10647500E+05, 0.95947900E+03, -.40424400E+05, 0.20449200E+05, 0.19961600E+05, 0.90682900E+04, 0.13295300E+05, 0.63267800E+04, 0.10978900E+05, 0.31780000E+04, 0.11267900E+05, -.30330800E+04, 0.18510500E+04, 0.91933900E+04, -.58875000E+04, -.99554200E+04, 0.15706100E+05, 0.19980500E+05, 0.40086100E+04, -.75563400E+04, -.28682200E+04, 0.25009800E+04, 0.14402000E+04, -.58624900E+04, 0.34613900E+03, 0.33154500E+04, 0.85668600E+04, 0.33078500E+04, 0.22414300E+04, 0.10385100E+05, -.51769300E+04, -.28228000E+04, 0.32351200E+04, -.39831400E+03, -.55768400E+04, 0.57359400E+04, -.25991700E+04, -.10702300E+04, 0.35959200E+05, -.17509300E+05, -.12758100E+05, -.21200700E+05, -.12083300E+05, 0.32080500E+04, 0.11769900E+05, -.34414200E+04, -.11122600E+05, -.32963200E+05, 0.16486400E+05, 0.14654000E+05, -.34514500E+04, 0.26107100E+04, 0.14344900E+05, 0.19103000E+05, 0.39825700E+04, 0.42514300E+04, -.15515400E+05, 0.83940200E+04, 0.17167100E+05, -.13389500E+05, -.80826900E+04, 0.20678900E+05, 0.19349900E+05, 0.11748000E+05, -.46746200E+04, 0.90143800E+04, -.48929900E+04, -.12427000E+05, 0.51861600E+04, 0.69180200E+04, -.16104500E+05, -.27936100E+05, -.22248800E+04, 0.85175500E+04, -.27644100E+05, 0.13615400E+05, 0.78201200E+04, 0.55913800E+03, 0.97737500E+04, -.33073500E+04, -.69853500E+04, 0.70416900E+04, 0.10032700E+05, -.15289300E+05, 0.76873000E+04, 0.79465200E+04, -.98031900E+03, 0.32979400E+04, 0.57843200E+04, 0.82126100E+04, -.18701600E+04, 0.28331300E+04, 0.38018800E+05, -.18243200E+05, -.17712700E+05, -.14071300E+05, -.78913900E+04, -.69701600E+04, -.57625100E+04, -.28012000E+04, -.75098900E+04, -.38085700E+04, 0.32112000E+04, 0.22925300E+04, -.10054600E+05, 0.10765600E+04, 0.57685700E+04, 0.15900500E+05, 0.56145200E+04, 0.12547200E+04, -.23151200E+05, 0.12181800E+05, 0.11461800E+05, 0.48241400E+03, 0.70131800E+04, 0.46415300E+04, -.51175500E+04, 0.79427200E+04, 0.88312000E+04, -.22859600E+05, 0.10220800E+05, 0.12771600E+05, 0.14030000E+05, 0.44460300E+04, 0.35781100E+04, -.50634800E+04, 0.47538000E+04, 0.23843400E+04, -.61151900E+05, 0.27711900E+05, 0.29215300E+05, -.28253900E+04, -.13472300E+05, 0.31985900E+05, 0.21660800E+05, 0.39724200E+05, -.66552900E+04, 0.16065600E+05, -.78524800E+04, -.24427600E+04, 0.25279900E+04, -.51804600E+04, 0.37224500E+04, 0.14357000E+04, 0.91328800E+03, -.59751700E+04, 0.18281500E+05, -.96124400E+04, -.12286900E+05, 0.20526700E+04, -.14559500E+04, -.85385100E+04, 0.16721300E+04, -.11036000E+05, -.42398100E+04, 0.57656000E+04, -.35079900E+04, -.42522500E+04, -.18841900E+03, 0.10614800E+04, -.11516100E+04, 0.33844500E+04, 0.99118900E+03, -.19329900E+04, 0.12753900E+04, -.10567300E+05, 0.92053900E+03, 0.35968100E+03, -.38254300E+04, 0.58881400E+04, -.43515200E+04, 0.26060600E+04, -.11167900E+04, -.11822600E+05, 0.17685000E+05, -.99930800E+04, 0.40292900E+04, 0.71561500E+04, 0.23972400E+04, -.59979300E+04, 0.48872000E+04, 0.22604800E+02, 0.29783000E+03, 0.10904500E+05, 0.53173200E+04, -.25448300E+04, 0.19346600E+04, 0.10795300E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17698000E+00, 0.21740400E+00, -.16237500E+00, -.10453800E+01, 0.22274800E+00, -.18149600E-01, -.30283400E+00, -.12831800E-01, -.29841000E+00, 0.44711100E-02, 0.10054900E+00, 0.21481300E+00, 0.11747600E+00, 0.10938300E-01, 0.10128300E+00, -.61144300E+00, 0.81702800E-01, 0.42967300E+00, -.65005100E-01, 0.11051600E+01, -.11823700E+00, 0.21437800E+00, -.30757100E-01, -.81864900E-01, -.25970700E+00, 0.14116100E+04, 0.10569300E+04, -.11008400E+05, 0.53598800E+04, 0.51529100E+04, 0.20958100E+04, 0.33644300E+04, 0.16156600E+04, -.75478800E+03, 0.21418400E+04, 0.24933600E+04, 0.33201500E+04, -.15161200E+04, -.23981800E+04, -.47489700E+04, -.37511300E+04, 0.10764700E+04, 0.19496400E+04, -.10821800E+03, -.34148800E+04, -.17503000E+04, 0.90736000E+03, 0.82708300E+03, 0.32302900E+03, 0.23247900E+04, -.75353700E+03, 0.85984300E+02, -.10038500E+04, 0.11499700E+04, 0.36500300E+04, -.17525800E+04, 0.11409800E+04, -.13402600E+04, 0.11939600E+04, 0.27424000E+04, 0.17888100E+04, -.37287300E+04, -.16070600E+04, 0.11181700E+03, 0.27149600E+02, -.51233900E+02, 0.15560100E+03, -.69379600E+02, 0.34162400E+03, 0.16598900E+04, 0.60673800E+03, 0.13443200E+04, 0.75970100E+04, -.37926600E+04, -.27635000E+04, -.23560100E+04, -.38489000E+04, 0.45180000E+03, 0.19690500E+04, 0.46587500E+02, -.30264800E+04, 0.23692600E+04, -.11285400E+04, -.30336500E+03, 0.20002600E+04, -.12101700E+03, 0.57489500E+03, 0.10899100E+03, -.19671400E+04, 0.42007600E+03, -.57484100E+04, 0.28871300E+04, 0.22782500E+04, 0.13579400E+04, 0.36624900E+04, 0.37152000E+03, 0.15147900E+04, -.23558600E+04, 0.20752000E+04, -.94900600E+04, 0.48014000E+04, 0.82277800E+04, 0.25164500E+03, 0.20101200E+04, 0.69617300E+04, 0.50927000E+04, 0.32659100E+04, 0.15892800E+04, -.44284700E+04, 0.21292100E+04, -.10508000E+04, 0.42159500E+04, 0.18724600E+04, -.54288000E+04, -.57804500E+04, 0.20259000E+04, 0.29167400E+04, -.45258700E+03, 0.19100100E+03, -.27797100E+04, 0.14087700E+04, -.66514900E+01, -.41080100E+04, -.35535100E+04, 0.18937900E+03, 0.15215800E+04, -.18361000E+04, 0.93348600E+03, 0.11237500E+04, 0.37177000E+03, 0.19453200E+04, 0.10827200E+03, 0.61519800E+03, -.26144700E+04, 0.10748300E+04, 0.14780000E+04, -.68861200E+03, -.40292800E+03, -.66645500E+03, -.21694300E+04, 0.59545900E+03, 0.69437300E+03, 0.77581000E+03, -.63854400E+03, -.62259300E+03, 0.41523300E+03, 0.50910200E+03, -.75655400E+02, -.26358400E+03, 0.13084200E+04, 0.34037100E+04, 0.19520400E+04, 0.20951700E+04, -.54460200E+03, 0.31932500E+03, 0.33485700E+03, 0.19156100E+04, 0.93175700E+03, 0.13659500E+03, -.16180000E+04, 0.16190800E+04, 0.11019900E+04, 0.41586300E+04, -.21816500E+04, -.12760800E+04, -.28257700E+03, 0.17552200E+03, -.10374900E+04, -.19064600E+04, -.66097800E+03, -.17102500E+04, -.11849400E+05, 0.57135000E+04, 0.54002400E+04, 0.24435200E+04, 0.41670100E+04, 0.14880200E+04, -.12076900E+04, 0.21689200E+04, 0.28430800E+04, 0.26628800E+04, -.13059500E+04, 0.79798900E+03, -.18492200E+04, -.98992100E+03, 0.35965500E+04, 0.25904600E+04, 0.13591700E+04, -.23428000E+04, -.14633000E+04, 0.69010600E+03, -.93717500E+03, -.11357300E+02, 0.21638800E+03, -.28929100E+04, -.51037700E+03, -.26257200E+04, 0.61815100E+03, 0.89567400E+03, -.49134900E+03, -.10180500E+04, 0.18705200E+03, 0.81237700E+03, -.36163700E+03, 0.69629400E+03, 0.11331800E+03, -.82999100E+02, -.12046400E+04, -.67068400E+03, 0.32425100E+03, -.69058100E+03, -.14870100E+04, 0.34203100E+04, -.12493700E+03, -.15006800E+04, 0.83397800E+03, -.12441400E+04, 0.25512000E+04, -.49365800E+03, 0.29311800E+04, -.15702400E+02, 0.23455300E+04, -.75101800E+02, -.89458800E+03, 0.27262300E+03, -.91361700E+01, 0.32426600E+04, 0.78779400E+03, 0.46809800E+03, 0.58117400E+03, 0.79455100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.61030500E+00, -.31108600E+00, -.16844400E+00, 0.10167900E+01, -.14339600E+00, -.66750500E+00, 0.34466000E+00, 0.13997300E+00, -.68261000E+00, 0.23458600E+00, 0.13054200E-01, -.14118100E+00, 0.15722200E-01, -.43827000E+00, 0.17271700E+00, 0.59407300E-01, -.11290600E-01, -.64866700E+00, -.10395000E+01, 0.19849700E+00, 0.65900200E-01, 0.18687500E+00, -.20373700E+00, 0.20210200E+00, -.12850400E+00, -.53471800E+00, 0.25128300E+04, -.30637000E+04, 0.20250600E+04, 0.11966500E+04, 0.30776600E+04, 0.47544700E+04, -.24308200E+04, -.54472600E+04, -.62016400E+04, 0.36719000E+04, -.42258400E+03, -.28663100E+03, -.34058100E+03, -.32184600E+04, -.17432100E+04, 0.22232400E+04, 0.41132900E+04, 0.36758900E+04, -.24413600E+04, -.17028100E+04, 0.78643600E+03, 0.71726800E+03, 0.34181800E+03, 0.16450600E+04, -.66004600E+03, -.11988000E+03, 0.11526200E+04, 0.16432400E+03, -.89644200E+03, 0.39454700E+03, 0.23465700E+04, -.83217600E+02, 0.17374000E+04, 0.31179000E+04, 0.24750500E+04, -.45579700E+04, -.84213400E+03, 0.35104500E+04, -.21352400E+04, -.17518300E+04, 0.11873200E+04, -.22074500E+04, -.12053300E+04, 0.37350000E+03, -.10787200E+04, 0.11546500E+04, 0.59759800E+03, -.30596500E+03, 0.20293600E+03, -.17308800E+04, -.10866400E+04, 0.17184100E+04, 0.32284600E+04, 0.39195000E+04, -.72108600E+02, 0.69820600E+04, -.35961600E+04, -.29149000E+04, 0.10966100E+04, 0.11681800E+04, -.10863200E+04, 0.65313800E+03, -.35420300E+04, 0.20161500E+04, -.67043300E+04, 0.33539700E+04, 0.31624800E+04, 0.21996100E+04, 0.33052400E+04, 0.51717400E+03, 0.12158200E+04, -.77813300E+04, 0.17602700E+04, -.78566800E+04, 0.36987700E+04, 0.60519200E+04, 0.16603700E+04, 0.22693600E+03, 0.43096000E+04, 0.18892200E+04, -.10873400E+04, 0.86852800E+03, 0.56694500E+03, -.22675600E+03, -.24029200E+04, 0.32710300E+04, 0.30007700E+04, -.54457100E+04, -.69234100E+04, -.56963500E+01, 0.22860600E+04, -.11266900E+05, 0.56603500E+04, 0.35353800E+04, 0.16378000E+04, 0.17234100E+04, 0.64845800E+03, -.12075800E+04, 0.40760600E+04, 0.24034100E+04, 0.44523800E+04, -.22229000E+04, -.19911300E+04, -.75392700E+03, -.13598100E+04, -.54011700E+03, 0.23915700E+04, -.38855200E+03, -.21486700E+04, -.13736900E+04, 0.47004500E+03, 0.69658400E+03, 0.33947300E+02, -.72838700E+03, 0.10768400E+04, -.15432300E+03, -.30246700E+03, 0.74503500E+03, 0.63251400E+04, -.36252000E+04, -.30330300E+04, 0.10292900E+04, -.35514500E+04, -.19620000E+04, 0.10017000E+04, -.18845500E+04, 0.22202200E+04, 0.48062700E+04, -.26043600E+04, -.24553000E+04, 0.26647900E+04, 0.50314500E+03, -.31093800E+04, -.25535800E+04, -.20634100E+04, 0.14131200E+04, -.47899300E+04, 0.27412100E+04, 0.29000500E+04, -.13508400E+04, -.10158200E+04, 0.21810900E+04, 0.34527500E+02, 0.29800600E+04, -.30462800E+04, -.22425300E+04, 0.18773200E+04, 0.81599100E+03, 0.42618200E+04, 0.65007000E+04, -.40787400E+04, -.79019500E+04, -.84750200E+04, 0.50818200E+04, 0.10292800E+05, -.51771300E+04, -.35306400E+04, -.70673200E+03, -.98291100E+03, -.17480300E+04, -.18965000E+04, -.38917600E+04, -.21147100E+04, 0.11083100E+03, 0.10732300E+03, -.90602100E+03, -.26038400E+04, 0.11475900E+04, -.34487500E+03, 0.95051200E+03, 0.15917200E+04, 0.33694500E+02, 0.48957100E+03, -.16078900E+02, -.51707200E+03, -.58110600E+03, 0.26786400E+03, -.15371200E+03, 0.60212500E+03, 0.69966800E+03, -.73070700E+03, 0.39985800E+03, -.96851300E+03, 0.51221700E+03, -.14259100E+03, -.32223900E+04, 0.18376500E+04, -.49027500E+03, -.67419000E+03, -.24326100E+03, -.11997700E+04, 0.43641700E+04, -.16092500E+04, 0.15116900E+04, 0.10564500E+04, 0.13364700E+04, -.10864200E+04, -.54274300E+03, 0.12706500E+04, 0.17209400E+03, 0.51200900E+04, 0.19851000E+04, -.66432300E+03, -.32221100E+03, 0.11417600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.53440300E+00, 0.13482100E+01, 0.46557600E+00, -.82571900E+00, 0.88556400E-01, 0.74449600E+00, -.55063000E+00, -.21255100E+00, 0.11927100E+00, 0.59068300E-02, -.49669400E+00, -.63158400E+00, -.35924000E+00, -.10378700E+01, 0.29146000E+00, -.72229600E+00, -.58308800E+00, -.74222200E-01, 0.66137300E+00, -.66931100E-01, -.19989800E+00, -.40868400E-01, -.23793000E+00, -.43997600E+00, -.61131800E+00, 0.24286000E+00, -.17348700E+00, -.30217300E+05, 0.13245600E+05, 0.14997800E+05, -.54320300E+04, -.10918800E+05, 0.18877800E+05, 0.15891800E+05, 0.27824800E+05, -.77956300E+04, -.38381500E+04, 0.28099000E+04, 0.96988300E+03, 0.62271300E+04, 0.54574700E+04, -.41728900E+04, -.29987600E+04, -.44103600E+04, 0.26454400E+04, -.14133400E+05, 0.72597500E+04, 0.72542000E+04, 0.13044900E+04, 0.52364300E+04, 0.17836200E+04, 0.32379400E+04, 0.36677400E+03, 0.40543600E+04, 0.31596000E+04, -.13530800E+04, 0.13929900E+04, -.53306500E+04, -.51647300E+04, 0.60285900E+04, 0.77859400E+04, 0.42989400E+04, -.51437100E+04, 0.21350300E+04, -.31919900E+03, -.10661600E+04, -.10289300E+04, 0.15610600E+04, -.13599900E+04, -.20804500E+04, -.11131600E+04, 0.22908100E+04, 0.49241600E+04, -.24617300E+04, -.12926900E+04, 0.32899400E+04, 0.19482600E+03, -.34634200E+04, 0.16725000E+04, -.16448000E+04, -.63850600E+03, 0.19259600E+05, -.93309500E+04, -.74982100E+04, -.94017400E+04, -.75254200E+04, 0.38556200E+03, 0.28802400E+04, -.19831400E+04, -.63325600E+04, -.10459400E+05, 0.52479500E+04, 0.40373000E+04, -.39524700E+04, -.39810000E+03, 0.58790500E+04, 0.48600700E+04, 0.30711100E+04, 0.81978800E+03, 0.55679200E+04, -.23578900E+04, 0.12611500E+04, -.81171400E+04, -.35942100E+04, 0.48258800E+04, 0.49221700E+04, 0.33904800E+04, -.27236900E+04, -.11698600E+04, 0.36281000E+03, -.22639500E+04, 0.34829900E+04, 0.20670300E+04, -.41117000E+04, -.75589500E+04, -.35031500E+03, 0.33885100E+04, 0.26600200E+04, -.14125400E+04, -.32602600E+04, -.35085800E+02, 0.36323100E+04, -.66067300E+04, -.48143000E+04, 0.24037500E+03, 0.40182800E+04, -.70628300E+04, 0.35688800E+04, 0.35093700E+04, -.17466300E+04, 0.19996200E+04, 0.23021700E+04, 0.13136000E+04, -.62643600E+03, 0.19959500E+04, 0.25440800E+05, -.12052900E+05, -.11825700E+05, -.42624000E+04, -.30297000E+04, -.68838600E+04, -.42112800E+04, -.40818400E+04, -.22770500E+04, 0.75405000E+03, 0.57195800E+03, -.23948500E+03, -.32662400E+04, 0.26710200E+04, -.58131400E+03, -.12827500E+04, -.27117100E+03, 0.30113900E+04, -.77469700E+04, 0.43067600E+04, 0.39773300E+04, -.11613400E+04, 0.22476700E+04, 0.92940000E+03, -.20851100E+04, 0.29352800E+04, 0.35517400E+04, -.14760600E+05, 0.65450200E+04, 0.81124200E+04, 0.52149300E+04, 0.32859800E+04, 0.32354500E+04, 0.65666100E+03, 0.31581100E+04, 0.19665700E+04, -.41910900E+05, 0.18411200E+05, 0.20343300E+05, -.67744400E+04, -.14030700E+05, 0.25530200E+05, 0.22700500E+05, 0.37749700E+05, -.10146700E+05, -.61465700E+04, 0.31541600E+04, 0.49552800E+04, 0.14773600E+04, -.11057400E+04, 0.60616600E+04, 0.43868100E+04, 0.46135300E+04, -.15818200E+04, 0.33432800E+03, -.51055500E+03, -.16896500E+04, 0.26730300E+04, -.34601600E+04, 0.81544700E+03, 0.33711900E+04, -.18688300E+04, -.38016600E+04, 0.12209900E+04, -.99194500E+03, -.14753400E+04, -.66327900E+03, -.44295500E+03, 0.12914900E+03, 0.17166100E+04, 0.13049100E+04, -.13063400E+04, -.70798500E+03, -.41086400E+04, 0.58743400E+03, -.63421600E+03, 0.37325400E+04, 0.45949100E+03, -.23879000E+04, 0.19276800E+04, -.83417400E+03, -.39687400E+04, 0.33817400E+04, -.43158500E+04, -.23358200E+03, 0.11062600E+04, -.59129200E+02, -.28037600E+04, -.31694900E+03, 0.82805500E+03, -.20542900E+04, 0.10783600E+04, -.15576600E+04, -.99253400E+03, -.79361700E+03, 0.41282200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.34273300E+00, -.49980200E+00, -.35440600E-01, 0.61137500E+00, 0.55423600E+00, -.47692400E+00, 0.53949800E+00, 0.14416400E+00, 0.10202900E+00, -.95587300E-01, 0.32363500E-01, -.33745600E-01, 0.24265500E-01, 0.16717900E+00, 0.11605900E+00, 0.28341500E+00, 0.11366400E+00, 0.82613700E-01, -.69970000E+00, 0.44778400E+00, 0.34633300E-01, 0.21792200E+00, -.17101700E+00, -.14979600E+00, -.26887900E-01, 0.43188300E+00, 0.48322200E-01, -.35195300E+00, 0.48039600E+03, 0.63853000E+02, -.65679800E+03, -.18440100E+04, 0.12266200E+04, 0.10072500E+04, 0.12009400E+04, -.17453400E+04, -.51382400E+04, 0.18159600E+04, 0.27279300E+04, 0.15687000E+04, 0.18412100E+04, 0.38538700E+03, -.26780200E+03, -.17392200E+03, 0.16593400E+04, -.45928100E+04, 0.22190200E+04, 0.25517600E+04, 0.66572500E+03, 0.79624300E+03, 0.13595300E+04, 0.20720300E+04, -.45945200E+02, 0.52820700E+03, -.35995100E+04, 0.16776700E+04, 0.51421100E+03, 0.55681000E+03, -.34447400E+03, -.15320700E+03, 0.21509500E+04, 0.23380200E+04, 0.31968300E+03, 0.89757500E+03, -.89538700E+03, -.44921100E+03, 0.10112500E+04, -.43109800E+03, -.64322200E+03, -.13700500E+04, -.44782600E+03, -.48241200E+02, -.25768600E+04, 0.12769100E+04, 0.99712300E+03, 0.13748700E+04, 0.24466600E+04, -.10388700E+04, -.46050700E+03, -.22901600E+04, 0.22224600E+04, 0.26185800E+04, -.15136700E+04, -.22087500E+04, -.60104300E+03, -.12487100E+04, -.12722000E+04, -.70470900E+02, -.34161000E+03, -.39541800E+03, -.64459300E+03, 0.31362500E+03, 0.34974200E+03, -.99658400E+03, -.23034200E+04, 0.16778800E+04, 0.51413700E+04, 0.47202300E+04, -.16109100E+04, 0.21302800E+03, -.40334600E+03, -.13283000E+04, 0.41296100E+02, -.18009400E+04, -.68403200E+03, 0.84892200E+03, 0.14446100E+04, -.12022100E+04, 0.64209900E+04, -.30419300E+04, -.16804500E+04, -.14734300E+04, -.13378900E+04, 0.64587700E+03, -.15556700E+04, -.11086600E+04, -.18903800E+04, -.34595200E+04, 0.18001900E+04, 0.28381500E+04, 0.72470200E+03, 0.15694800E+04, 0.15194600E+04, -.91438400E+03, -.10012800E+04, 0.13641200E+04, -.42597300E+04, 0.21168400E+04, 0.20258000E+04, 0.49572200E+03, 0.38957600E+03, 0.11701600E+04, 0.10408500E+04, 0.59213100E+03, 0.54682600E+03, 0.15826600E+04, -.10227100E+04, -.10143200E+04, 0.21953900E+03, 0.46059300E+03, -.10532300E+04, -.22903900E+04, -.72804500E+03, 0.97097800E+03, -.10253900E+04, -.20155000E+02, 0.44992100E+03, 0.47824700E+03, -.69360400E+03, 0.88728100E+02, -.99093600E+03, 0.47373500E+03, -.12232600E+03, 0.10342500E+04, -.80026900E+03, -.34287300E+03, -.52857400E+03, -.16989500E+04, 0.21481700E+03, -.17600100E+03, 0.64199600E+03, -.11913800E+04, -.45116500E+04, 0.27663500E+04, 0.21920800E+04, -.93973900E+03, 0.11874700E+04, 0.14246600E+04, 0.11918600E+04, 0.13940400E+04, 0.60412100E+03, -.31315900E+03, 0.94315400E+03, 0.34132300E+03, -.54278400E+03, -.20995500E+04, 0.14636800E+04, 0.10526500E+04, 0.11894900E+04, -.20127100E+04, 0.30834800E+04, -.16018000E+04, -.24070300E+04, 0.22824400E+03, -.41763700E+03, -.21659900E+04, -.15343800E+04, -.23682900E+03, -.34642600E+03, -.22389800E+04, 0.13426500E+04, 0.14662700E+04, 0.28190000E+03, 0.19640700E+04, 0.88855400E+03, 0.62334200E+03, -.10544500E+04, 0.14638400E+04, 0.16608700E+04, -.40030300E+03, -.69402500E+03, -.18785900E+02, 0.47192600E+03, -.41326800E+03, 0.46408100E+03, -.88519200E+03, -.34878500E+03, 0.11467900E+04, -.89668800E+03, -.41161700E+03, 0.95052100E+03, -.58559000E+03, 0.17964600E+02, -.32138300E+03, 0.46668000E+03, 0.12039100E+04, -.17376000E+04, 0.18544600E+04, -.57212700E+03, -.22643100E+03, 0.12653000E+04, 0.29234700E+03, -.45420700E+03, 0.68307400E+03, -.89756400E+03, -.18060200E+03, 0.19780200E+04, 0.53195500E+03, -.17233000E+02, -.13717300E+03, 0.10285100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14366900E+01, -.13106100E+00, -.43127200E+00, -.22200900E+01, -.40554200E+00, 0.19574600E+01, 0.22603200E+00, 0.22603900E+00, 0.84594900E-01, -.60539700E-01, 0.77257200E+00, 0.12964200E+01, 0.71431400E+00, 0.20046900E+01, 0.66551700E+00, 0.25344400E+01, 0.82206200E+00, -.72550900E+00, 0.93592200E-01, 0.33497600E+01, -.53272400E+00, 0.31284500E+00, -.80186100E-02, -.65704800E+00, -.65420100E+00, 0.34281600E+01, 0.40832100E+00, -.90574000E+00, -.15076600E+01, 0.14082300E+04, -.78498100E+04, -.17290600E+05, 0.98772100E+04, 0.45851500E+04, 0.58171600E+04, -.94759400E+04, -.79773300E+04, 0.35387200E+04, 0.57328500E+04, 0.20150000E+05, 0.17685600E+05, -.89810400E+04, -.77812200E+04, -.40082600E+04, 0.13269600E+05, -.19898600E+05, 0.99321400E+04, 0.11156000E+05, 0.42954000E+04, -.24682200E+03, 0.68058800E+04, 0.53838100E+04, 0.48959200E+04, 0.92173400E+03, -.15366900E+05, 0.75039200E+04, -.17738100E+04, 0.47313000E+03, -.89421000E+04, -.53047000E+04, 0.73572500E+03, 0.90180600E+04, 0.39761600E+04, 0.16503600E+05, -.83704900E+04, -.82646500E+04, 0.20451000E+04, 0.81803000E+03, -.82834900E+04, -.10925000E+05, -.68183300E+04, -.20978800E+04, -.28672900E+05, 0.14288400E+05, 0.11866900E+05, 0.11727200E+05, 0.16894000E+05, -.37651100E+04, -.45772600E+04, 0.13056200E+04, 0.14541000E+05, 0.69875100E+04, -.36995000E+04, -.73170900E+04, -.17853800E+05, -.50344000E+04, -.18745100E+04, 0.39240900E+04, 0.50877100E+04, -.39284700E+04, 0.87045400E+04, -.43753400E+04, -.39962700E+04, -.10348900E+05, -.15494000E+05, 0.53471800E+04, 0.73940500E+04, 0.53273800E+04, -.10032500E+05, 0.13706400E+05, -.70235000E+04, -.16460400E+05, -.18615000E+04, -.69178500E+04, -.16238300E+05, -.14598500E+05, -.69847000E+04, -.15820600E+04, 0.22171000E+05, -.10826800E+05, -.29684200E+02, -.12065400E+05, -.63987400E+04, 0.14735400E+05, 0.87570900E+04, -.52400500E+04, -.87227300E+04, -.22621900E+05, 0.11388700E+05, 0.21124500E+05, -.48322700E+04, 0.81346200E+04, 0.17594800E+05, 0.99038300E+04, 0.65120900E+04, -.41358900E+02, -.56441800E+03, 0.26430700E+03, -.60193100E+03, -.18966400E+04, -.52104500E+04, 0.19027000E+04, 0.17569200E+04, 0.37474500E+04, -.37485800E+04, 0.20243100E+05, -.10180100E+05, -.10444600E+05, -.57479500E+04, 0.35473100E+04, -.65612100E+04, -.41189800E+04, -.53045700E+04, -.26077500E+04, 0.15021700E+05, -.76613200E+04, -.81100000E+04, 0.82856700E+02, 0.20373300E+04, -.87913300E+04, -.12378100E+05, -.57284400E+04, -.55287900E+04, -.18981000E+05, 0.93388600E+04, 0.98721700E+04, -.30143000E+04, 0.66227200E+03, 0.23601600E+04, -.22062000E+04, -.46248200E+03, 0.41409000E+04, -.35408700E+05, 0.17960000E+05, 0.16557000E+05, 0.61723300E+04, 0.23499500E+04, 0.90729900E+04, 0.79350100E+04, 0.84296800E+04, 0.60370100E+04, -.89005200E+04, 0.45504700E+04, 0.59308100E+04, -.80141000E+04, -.21510800E+05, 0.14457300E+05, 0.67360000E+04, 0.10205400E+05, -.99617800E+04, 0.35977700E+04, -.18500600E+04, -.88475500E+04, 0.99781000E+04, 0.16294700E+03, -.15100500E+05, -.11438000E+05, -.62241000E+04, 0.63268200E+04, 0.19373200E+05, -.95418300E+04, -.56909400E+04, -.33784500E+04, -.39629400E+04, 0.93085100E+04, 0.11763400E+05, 0.52890300E+04, -.10287400E+05, -.48880100E+04, 0.27970500E+04, 0.30985600E+04, -.97619200E+03, -.22180200E+04, 0.27981300E+04, 0.11867100E+04, 0.23456100E+04, -.30174600E+04, 0.59601600E+04, -.35332500E+04, -.15518500E+04, 0.30909000E+04, 0.54917700E+04, -.90874700E+04, -.13337400E+04, 0.87572300E+04, -.71219700E+03, -.29369100E+04, -.28663300E+04, -.41742000E+04, -.93479300E+04, 0.29921500E+04, -.74599600E+04, -.21751700E+04, 0.62994700E+04, -.19688200E+04, -.36218200E+03, -.83955500E+04, -.26660400E+04, -.31000700E+04, -.19451400E+04, 0.36176800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.57857700E+00, -.95027200E-01, -.11931000E+00, 0.23340600E+01, -.10140800E+01, -.37799800E+00, 0.41689100E+00, -.96467000E-01, -.10105500E+01, -.62135600E+00, 0.32627700E+00, 0.63523900E-01, 0.17482000E+00, -.16424500E+00, 0.56963600E+00, -.74910900E+00, -.50672300E+00, -.10063700E+01, -.48101900E+00, 0.57781000E+00, 0.48499600E-01, 0.32814000E+00, -.27178100E+00, 0.30377300E+00, -.60915700E+00, 0.74561100E+00, 0.17428300E+00, -.94429400E+00, -.95312900E+00, 0.22723100E+00, -.80862100E+04, -.14653900E+05, 0.11655800E+05, 0.80938300E+04, 0.10492000E+05, -.11700200E+05, -.25966600E+05, 0.12196400E+05, 0.12319200E+05, 0.13462100E+05, 0.18044600E+05, -.55271000E+04, -.60714400E+04, -.12809800E+04, 0.13055000E+05, -.18097200E+05, 0.90063300E+04, 0.95121400E+04, 0.54585400E+04, 0.43600200E+04, 0.16220800E+04, 0.87980100E+04, 0.31546100E+04, 0.51051100E+04, 0.33602600E+04, -.17831900E+04, -.17009500E+04, -.87014200E+04, -.11737800E+05, 0.75588100E+04, 0.10088200E+05, 0.34544500E+04, -.96900900E+04, 0.80765300E+04, -.44549500E+04, -.40383400E+04, 0.18471300E+04, 0.11216400E+03, -.44394500E+04, -.69570100E+04, -.42488900E+04, 0.16882600E+04, -.10463200E+05, 0.52037100E+04, 0.53547700E+04, 0.79217700E+04, 0.10341400E+05, -.62350200E+04, 0.26505500E+03, 0.36736700E+03, 0.77659600E+04, 0.21791900E+05, -.11049600E+05, -.10063600E+05, -.14933400E+05, -.21168000E+05, 0.60166000E+04, 0.77091200E+04, 0.39955300E+04, -.15374600E+05, -.15618400E+05, 0.77874500E+04, 0.70288200E+04, -.68821000E+04, -.76683400E+04, 0.13469600E+05, 0.83231200E+04, 0.86637000E+03, -.29564700E+04, 0.16705000E+05, -.86567400E+04, -.73487600E+04, -.93144200E+04, -.13172500E+05, 0.29228000E+04, 0.42549700E+04, 0.36052900E+03, -.10209100E+05, 0.35078900E+04, -.16082300E+04, -.10677300E+04, 0.24388900E+04, 0.39557100E+04, -.46141500E+03, -.47540200E+04, -.34911700E+03, 0.13430500E+04, -.30377200E+05, 0.15250000E+05, 0.15946300E+05, 0.81251400E+04, 0.14581100E+05, 0.61163800E+03, -.34686700E+04, 0.39440500E+04, 0.14102200E+05, -.26486500E+04, 0.13212200E+04, 0.11187200E+04, -.30883100E+04, -.43608900E+04, 0.41886500E+04, 0.48855600E+04, 0.15540300E+04, -.23320700E+04, 0.14163500E+05, -.71643600E+04, -.70259600E+04, -.49431300E+04, -.35067000E+04, -.15377400E+04, -.55717300E+04, -.23998300E+04, -.22212700E+04, 0.10243800E+05, -.55996300E+04, -.51487900E+04, 0.89663300E+03, -.28097400E+03, -.59461000E+04, -.95588300E+04, -.56173600E+04, 0.29210100E+04, -.20837700E+05, 0.10159400E+05, 0.10708500E+05, 0.40519400E+04, 0.23713900E+04, 0.13839300E+04, -.41629200E+04, 0.37290900E+04, 0.60029800E+04, -.16106400E+05, 0.84506800E+04, 0.82133500E+04, 0.54009500E+04, 0.11360800E+05, -.99227300E+03, -.13738000E+04, 0.26160500E+03, 0.77383200E+04, -.52034400E+04, 0.28011600E+04, 0.26099800E+04, -.79084400E+04, -.16442700E+05, 0.14351500E+05, 0.10809900E+05, 0.14580100E+05, -.12743400E+05, 0.70236400E+04, -.35729100E+04, -.32394500E+04, 0.17382900E+04, -.15724000E+04, -.31675100E+04, -.40880400E+04, -.20807900E+04, -.16931600E+04, 0.18341600E+05, -.89474400E+04, -.92093900E+04, -.52611400E+04, -.56439700E+04, 0.28538900E+04, 0.99420100E+04, -.45600300E+03, -.81832700E+04, 0.84318400E+04, -.37346700E+04, -.43931400E+04, -.10221100E+04, -.19398800E+04, -.15820000E+04, 0.27879600E+04, 0.25154600E+03, -.24992900E+04, -.14487300E+04, -.11225400E+05, 0.21688000E+04, -.21961800E+04, -.30848300E+03, 0.12429100E+04, -.41378500E+04, 0.47406000E+04, -.31335700E+04, -.78249300E+04, 0.64966300E+04, -.88358700E+04, -.34380200E+04, 0.44619100E+04, -.18433300E+03, -.44197300E+04, -.28161300E+03, 0.33877400E+04, -.18914800E+04, 0.66652700E+04, 0.27330000E+04, -.37470300E+04, -.37211100E+04, 0.11034600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.50311500E+00, -.74354400E+00, -.22529200E+00, 0.86766400E+00, 0.14939300E+00, -.44420600E+00, 0.13696200E+01, 0.30480300E+00, -.27387000E+00, 0.45385600E-01, 0.73965200E-01, -.33426900E-03, 0.21631900E-01, 0.78400500E-01, -.12658300E+00, 0.79204100E+00, 0.20643800E-01, -.15990900E+01, 0.17198600E+01, 0.26035800E+01, 0.36609300E+00, 0.51358300E+00, 0.94082700E-01, -.65745700E+00, -.21831700E+00, -.11209300E+01, 0.31961900E-01, 0.41635900E-01, -.94242800E+00, -.38386500E+00, 0.72727600E+00, -.35145000E+04, 0.15926900E+04, 0.82692700E+04, 0.83634700E+04, -.19764500E+04, 0.11644800E+03, -.67714900E+03, 0.36455300E+03, 0.34390800E+04, -.38728200E+04, 0.15322100E+04, -.23925000E+04, -.25075200E+04, -.11530800E+04, -.14493800E+04, 0.70518000E+03, 0.86128600E+03, -.20017700E+04, -.18346500E+04, 0.35745300E+04, 0.93449000E+02, 0.32064700E+03, -.26983800E+04, -.33420000E+04, 0.15858000E+04, -.17011600E+03, 0.59329300E+04, 0.59166700E+03, -.44925900E+04, -.19334400E+04, 0.70034000E+04, 0.48725600E+04, 0.72826700E+03, -.61036800E+03, -.36410700E+03, -.68510300E+03, 0.23739500E+04, -.53358800E+03, -.75708900E+03, 0.41523800E+03, -.86061900E+02, -.22987700E+04, 0.11410300E+04, 0.58929000E+03, 0.63463200E+03, 0.10044200E+03, 0.65747100E+03, -.30417100E+04, -.52369600E+04, 0.98957200E+03, -.16971600E+05, 0.82712200E+04, 0.74178100E+04, 0.26490700E+04, 0.52661200E+04, 0.24755500E+03, -.16942700E+04, 0.42282500E+04, 0.58111400E+04, 0.13034900E+05, -.65158300E+04, -.61143700E+04, -.58542900E+01, -.32932900E+04, -.37046700E+04, 0.32828800E+04, 0.12504500E+05, -.39081700E+04, 0.45083300E+04, -.24515100E+04, -.43475400E+04, 0.92602400E+02, 0.19903800E+03, -.51666900E+04, -.26144600E+04, 0.30587800E+04, 0.84869100E+03, 0.85034700E+04, -.40955600E+04, -.22318300E+04, -.67211600E+04, -.41314100E+04, 0.21622900E+04, 0.23750200E+04, -.54797900E+04, -.23886700E+04, 0.15859300E+05, -.78685600E+04, -.63912300E+04, -.55495400E+04, -.44416800E+04, 0.15002100E+04, 0.31911200E+04, -.40618700E+04, -.67184100E+04, -.78474100E+04, 0.39176700E+04, 0.37590500E+04, 0.27521800E+04, 0.38399400E+04, 0.39458000E+03, -.20180300E+04, 0.26705200E+04, 0.25724600E+04, -.10262900E+04, 0.44145900E+03, -.70171200E+02, 0.20554700E+04, 0.45399900E+04, -.31227400E+04, -.23650000E+04, -.17115400E+04, 0.28642600E+04, -.97810500E+04, 0.46150200E+04, 0.47985000E+04, -.26672100E+04, 0.40446300E+04, 0.38752400E+04, 0.23309000E+04, 0.58922800E+04, -.19744300E+04, 0.75384700E+04, -.39755500E+04, -.35454800E+04, -.68002800E+04, -.49773500E+04, 0.19525300E+04, 0.48504500E+04, 0.53614300E+03, -.48946100E+04, 0.33219600E+04, -.12590100E+04, -.22419600E+04, -.38024200E+04, -.26247300E+04, 0.19008500E+04, 0.45649200E+04, 0.23963100E+03, -.23955400E+04, -.94847200E+03, 0.59671900E+03, 0.78570400E+03, -.31447500E+03, -.57530700E+04, 0.34355700E+04, 0.11382200E+05, 0.11109900E+05, -.30824900E+04, -.47045100E+04, 0.23117200E+04, 0.10932400E+04, 0.14684300E+04, -.38287200E+03, -.59242400E+03, 0.27200100E+03, 0.15925500E+04, 0.18911600E+04, -.90121900E+04, 0.46678800E+04, 0.51865700E+04, 0.60664300E+04, 0.65120400E+04, -.59077400E+03, -.46739600E+04, -.21048700E+04, 0.47084600E+04, -.33363500E+04, 0.21284500E+04, 0.22969300E+04, 0.24463200E+03, 0.27504200E+04, 0.10264100E+04, 0.35201900E+03, -.10119700E+04, 0.18845800E+03, 0.20661500E+04, 0.38362300E+04, -.13460300E+04, 0.22302400E+04, -.11753500E+04, -.35552000E+04, 0.55017000E+03, -.81416400E+03, 0.31792100E+04, 0.30601700E+03, -.35367400E+04, 0.27828600E+04, 0.30332600E+03, -.75078000E+03, -.22735700E+04, -.21476800E+03, 0.18831600E+04, -.35624700E+04, 0.14342600E+03, -.35364800E+04, 0.76852500E+03, 0.75316700E+03, 0.15282400E+04, -.32447400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.64816300E+00, 0.25710500E+00, 0.76200500E-01, 0.61343500E+00, -.82976300E+00, 0.52229800E+00, -.29695600E+00, -.32916100E+00, 0.10376100E+00, -.36239500E+00, -.21365900E+00, -.91814500E+00, -.22421500E+00, -.10785300E+01, -.46730000E-01, 0.23062900E-01, -.17348300E+00, -.69633400E+00, 0.76166400E+00, -.12429900E+01, 0.99350100E-01, -.63458200E+00, 0.29898900E+00, 0.25924800E+00, -.11330300E+00, -.55757200E+00, 0.29879700E+00, 0.12878800E+01, -.13327300E+01, -.76152900E+00, 0.47750700E+00, 0.10029200E+01, -.24720900E+04, -.10369600E+05, -.12295300E+05, 0.31436600E+04, 0.17328300E+05, -.74973300E+04, -.97488300E+04, 0.68173600E+04, 0.45866500E+04, -.81469800E+04, -.48623600E+04, -.25414400E+04, 0.21745200E+04, 0.27256500E+04, -.12887900E+04, -.14331000E+04, 0.31249400E+04, -.46530700E+04, 0.88268700E+01, -.24919100E+04, 0.33927300E+04, -.21248100E+04, -.27771600E+04, 0.14871800E+04, 0.23557100E+04, -.93292100E+03, -.31343800E+04, -.17521400E+04, -.51461800E+04, -.22150100E+04, 0.11046600E+04, 0.25630500E+04, -.60634600E+03, -.12837800E+04, -.25827500E+04, -.82145800E+03, -.47520500E+03, 0.35666300E+03, -.76568900E+03, -.25781600E+04, -.10495200E+05, 0.52467700E+04, 0.51770800E+04, 0.19185700E+04, 0.44182100E+04, 0.14433900E+04, -.15755600E+04, 0.62751600E+04, 0.35494200E+04, -.10936700E+05, 0.56978900E+04, 0.81428900E+04, -.12208900E+05, -.77914800E+03, 0.70405600E+04, 0.58001100E+04, 0.55306900E+04, -.18441400E+04, 0.77146300E+04, -.38554200E+04, -.44483900E+04, -.30129800E+04, -.39243000E+04, -.23205500E+04, -.88757200E+04, -.83772900E+04, -.26701800E+04, -.19355100E+04, 0.14391200E+04, 0.28206000E+04, 0.93050500E+03, 0.73537500E+02, -.60199900E+04, -.12264400E+05, -.83535500E+04, 0.18568800E+04, -.38477800E+04, 0.17969800E+04, 0.15121800E+04, -.30682900E+04, -.90820300E+03, 0.73580600E+04, 0.11477100E+05, 0.23027500E+04, -.13220600E+04, -.18108800E+05, 0.89594500E+04, 0.94021700E+04, -.42956100E+04, 0.43979600E+03, 0.11654000E+05, 0.87508600E+04, 0.74125100E+04, -.21965100E+04, 0.11225400E+05, -.56083000E+04, -.55838300E+04, -.18249000E+04, -.58124800E+04, -.19907000E+04, -.18756400E+04, -.59399600E+03, -.48556800E+04, 0.46294900E+04, -.22049200E+04, -.20516100E+04, -.61780600E+04, 0.53852200E+03, -.12946200E+02, 0.46295300E+04, -.18402000E+04, -.42871800E+04, 0.85821800E+04, -.35189600E+04, -.43266000E+04, -.24374600E+04, -.98702200E+03, -.33707900E+04, -.19326600E+04, -.39572000E+04, -.44354600E+04, -.27511200E+05, 0.14122800E+05, 0.13417300E+05, 0.49255900E+03, 0.31736500E+04, 0.54169700E+04, -.17127400E+03, 0.22197400E+04, 0.53853500E+04, -.78014200E+04, 0.32466700E+04, 0.40596300E+04, 0.74974300E+04, 0.73136900E+03, 0.78287200E+03, 0.14658500E+04, 0.23560200E+04, 0.37578400E+04, -.14804700E+04, 0.47508000E+03, 0.74860400E+03, 0.21552900E+03, -.84759900E+03, -.23575500E+04, -.12803500E+05, -.14482000E+05, 0.42674800E+04, 0.84744100E+04, -.41401900E+04, -.26981700E+04, 0.48478800E+04, 0.31689700E+03, -.78386900E+04, -.52529100E+04, -.63887500E+04, 0.26883500E+04, 0.29914100E+05, -.15253700E+05, -.14221900E+05, -.41190700E+04, -.52638500E+04, -.80097000E+03, 0.43705800E+04, 0.17283800E+04, -.86247600E+04, -.46076300E+04, 0.15943100E+04, 0.19541200E+04, 0.32547600E+03, -.34349400E+04, 0.18285200E+04, -.10625900E+04, 0.21225500E+04, -.84792400E+03, 0.11736600E+04, -.10236900E+04, 0.41165600E+03, -.36648100E+03, 0.62877200E+03, -.39289500E+04, 0.58302200E+03, 0.39870500E+04, -.48884400E+04, 0.22862300E+04, -.71169800E+04, -.13418700E+04, -.54989300E+04, -.28623600E+04, -.40272200E+04, 0.17532600E+02, 0.46118700E+04, 0.18233400E+04, 0.93049700E+03, -.11450900E+05, 0.29236300E+03, -.22386400E+04, -.13259700E+04, 0.51064600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.19102900E+01, -.12235800E+01, -.69490700E+00, 0.48443700E+01, -.90205500E-01, -.34902900E+01, 0.33283500E+01, 0.10080100E+01, -.20622100E+01, 0.16314500E+01, -.60541900E-01, -.58119700E+00, 0.68299500E+00, -.32903100E+01, 0.17497400E+01, -.43657100E+01, -.21274500E+01, -.23538600E+01, -.20639000E+00, 0.47907100E+01, 0.27438400E+00, 0.11844500E+01, -.16619900E+01, -.10302000E+01, -.78993100E+00, 0.84144300E+00, -.50786600E+00, -.17368100E+01, 0.12339300E+01, 0.32929100E+00, 0.18245800E+01, -.12374300E+01, -.65755200E+00, 0.26031700E+05, 0.14915100E+05, -.21513700E+04, 0.22111700E+05, -.11000600E+05, -.11090000E+05, -.16796800E+04, -.19573300E+05, 0.71222000E+04, -.77330700E+03, 0.46004700E+03, -.13476700E+05, 0.26568200E+05, -.13255300E+05, -.14462500E+05, -.12804100E+05, -.94305600E+04, 0.69234000E+03, -.12880500E+05, 0.56345300E+03, -.10950600E+05, 0.39513900E+04, -.19525400E+04, 0.35312700E+03, 0.10913800E+05, 0.84506900E+04, -.84057800E+04, -.11631500E+05, 0.96694200E+04, 0.78084600E+04, -.38276100E+04, 0.19951100E+04, 0.19157500E+04, -.42660900E+04, 0.29489700E+04, 0.15033300E+04, 0.27504300E+04, 0.25998200E+04, -.92712300E+03, 0.72230500E+04, -.35889100E+04, -.35914300E+04, -.42776800E+04, -.10738200E+05, 0.79110800E+04, -.65032800E+04, -.15981000E+04, -.75806200E+04, -.52562000E+05, 0.26186900E+05, 0.29059400E+05, 0.14967400E+05, 0.25603600E+05, 0.20308700E+04, -.71904000E+04, 0.63238600E+04, 0.22386800E+05, 0.44515200E+05, -.22228800E+05, -.21470400E+05, 0.26023000E+04, 0.87969500E+03, -.20305700E+05, -.17835400E+05, 0.94763000E+04, -.47389700E+04, 0.13588800E+05, -.67324200E+04, -.52621100E+04, 0.16394800E+04, 0.86242900E+04, -.13879500E+05, -.12669400E+05, -.22326800E+04, 0.70670300E+04, -.77197200E+04, 0.38345600E+04, 0.74591400E+03, -.72788900E+04, -.32577700E+04, 0.19054600E+04, 0.14462300E+05, -.10201300E+05, 0.19154600E+04, 0.73921200E+05, -.36943500E+05, -.38824100E+05, -.17535200E+05, -.23735300E+05, -.74048800E+04, 0.95754600E+04, -.11112700E+05, -.22997800E+05, 0.36266900E+04, -.18097900E+04, -.17213500E+04, 0.21769500E+04, 0.59579600E+04, -.54100200E+04, -.10887100E+05, 0.36605200E+04, 0.28341700E+04, 0.51256000E+03, -.21776800E+03, -.61440200E+03, 0.90681300E+04, 0.98823000E+04, -.97915400E+04, -.16640800E+04, -.93862200E+04, 0.77483100E+04, -.15610200E+05, 0.79040500E+04, 0.78958300E+04, -.70626700E+04, 0.54930600E+04, 0.60174900E+04, 0.54381500E+04, 0.83292700E+04, -.28731200E+04, 0.21232800E+05, -.10617400E+05, -.11118500E+05, -.15585900E+05, -.71482400E+04, 0.15549200E+04, 0.13476800E+05, -.46317700E+04, -.96242700E+04, 0.21936800E+05, -.10917200E+05, -.12250100E+05, -.97442000E+04, -.14107200E+05, 0.29911900E+04, 0.99319700E+04, -.45114500E+03, -.11551800E+05, -.15012100E+04, 0.66146400E+03, 0.10558600E+04, -.39965400E+04, -.47467000E+04, 0.58840000E+04, 0.38784300E+05, 0.23345900E+05, -.74298200E+04, -.31626100E+05, 0.15821900E+05, 0.17745700E+05, 0.48326200E+03, 0.21596300E+04, 0.10976000E+05, 0.10298500E+05, 0.68468900E+04, 0.27769400E+04, -.16727800E+05, 0.83697600E+04, 0.86092300E+04, 0.15720300E+05, 0.10561700E+05, -.44731400E+04, -.17862600E+05, 0.14668100E+04, 0.10079300E+05, -.15228300E+05, 0.76893000E+04, 0.85199000E+04, 0.16851100E+03, 0.43887200E+04, 0.34476700E+04, -.32007900E+04, -.44373700E+02, 0.40617100E+04, 0.89409100E+03, 0.15988900E+05, -.16465000E+04, 0.88486900E+03, 0.34763900E+04, -.10431200E+05, 0.20436700E+04, -.50872100E+04, -.95860400E+01, 0.97811100E+04, -.17481300E+05, 0.98546400E+04, 0.52173100E+03, -.98565400E+04, -.63503700E+04, 0.12149800E+04, -.14460200E+04, -.18815600E+04, 0.10808400E+04, -.16757500E+05, -.29709800E+04, 0.22844400E+04, 0.36004700E+04, -.15356800E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.34309800E+00, -.15818400E+00, 0.11290300E-01, -.15033400E+00, -.11896000E+00, 0.12804400E+00, -.84917700E-01, -.28832500E+00, 0.73350700E+00, -.37438800E+00, 0.36049700E+00, 0.10766800E+00, -.73185700E+00, 0.48808500E-01, -.28604100E+00, 0.25628800E+00, -.18310200E+00, -.43932700E+00, -.13980000E+00, -.68766100E+00, -.30128500E+00, -.27440100E+00, -.36646200E-01, 0.10551900E-01, -.13314100E+00, -.21452700E-01, 0.10779100E+00, -.10293300E-01, 0.12424700E+00, 0.26875700E-01, -.14450300E+00, -.22975300E+00, 0.30573800E+00, 0.59561900E-01, 0.28237400E+04, -.24719700E+03, -.41032600E+04, 0.19592500E+04, 0.20511500E+04, -.25721400E+04, -.24609900E+03, 0.12067400E+04, 0.22961400E+03, -.51629600E+03, 0.55302200E+03, 0.13176500E+04, -.63719900E+03, -.39144300E+03, -.76382800E+03, -.76559500E+02, -.61727700E+03, 0.15100900E+03, -.77162700E+03, -.29569700E+03, 0.76788400E+04, -.38152600E+04, -.37336500E+04, -.17697000E+04, -.13770500E+04, -.16130900E+03, -.41745300E+03, 0.10859700E+04, -.19535400E+04, -.85602200E+03, 0.40032800E+03, 0.43061500E+03, 0.15268100E+04, 0.11404400E+04, -.63367100E+02, -.10577100E+04, 0.25380800E+03, 0.98021800E+03, 0.29788400E+04, -.14927000E+04, -.11498300E+04, -.60038800E+03, -.11844500E+04, -.62206400E+03, -.28285600E+03, -.13545700E+04, -.90691400E+03, 0.14334400E+04, -.74121800E+03, -.17750900E+04, 0.29103200E+04, -.84774600E+03, -.31705800E+03, -.15642700E+04, 0.30088500E+03, -.71542900E+03, 0.16911000E+04, -.83117100E+03, -.11144500E+04, -.51862900E+03, -.86389700E+03, 0.88902500E+03, 0.11990400E+04, 0.56414100E+04, -.10992900E+04, 0.51095800E+04, -.25703200E+04, -.22303100E+04, -.13209100E+04, -.12634300E+04, 0.21186300E+04, 0.30256900E+04, 0.35116000E+04, -.21686400E+04, -.63656000E+04, 0.31802300E+04, 0.30277200E+04, 0.19864100E+04, 0.56178100E+03, -.83717800E+03, -.15929000E+03, -.31565100E+02, 0.13237300E+04, 0.92063500E+03, -.45957300E+03, -.10425200E+04, 0.25070600E+04, 0.13648900E+04, -.33371000E+04, -.22439600E+04, -.28038000E+04, 0.16121200E+04, -.38480600E+04, 0.19335200E+04, 0.18988000E+04, 0.76223600E+03, 0.16973300E+04, 0.80072300E+03, -.69461600E+03, 0.78980200E+03, 0.14952800E+04, -.56432700E+04, 0.27919000E+04, 0.28238000E+04, 0.17503000E+04, 0.25978300E+03, 0.21711600E+04, 0.16054500E+04, 0.23749300E+04, 0.87651000E+03, -.46067500E+04, 0.22854400E+04, 0.23585900E+04, 0.20302000E+04, 0.16150300E+04, 0.15259600E+04, -.42891100E+03, 0.21634300E+04, 0.14531700E+04, 0.48544700E+04, -.24520400E+04, -.21477400E+04, 0.62629300E+03, -.95601800E+03, -.77390600E+03, -.22925200E+03, -.10476600E+04, -.14253600E+04, 0.55163000E+04, -.26944200E+04, -.23257700E+04, -.14429400E+04, 0.38638600E+03, -.19799900E+04, -.11525800E+04, -.29425600E+04, -.26296300E+03, 0.24526500E+04, -.11998300E+04, -.12668500E+04, -.29072300E+03, -.22852600E+02, -.10746000E+04, -.85316100E+03, 0.24369100E+04, -.49716500E+03, -.11507600E+04, 0.56996900E+03, 0.49400600E+03, -.19749800E+04, -.71088300E+03, 0.25206200E+04, 0.18413300E+04, 0.17461300E+04, -.95747000E+03, -.10176000E+05, 0.50987300E+04, 0.43100000E+04, 0.10144500E+04, 0.11203100E+04, 0.55334400E+03, -.45186100E+03, 0.62043300E+03, 0.23659900E+04, -.90078000E+03, 0.53792900E+03, 0.25256500E+03, 0.14721300E+03, 0.45012300E+03, 0.26433500E+03, 0.53281800E+03, 0.72410200E+03, -.72720600E+02, -.21701600E+04, -.53615800E+03, 0.63198800E+03, -.98156500E+03, -.10233100E+03, 0.19402500E+04, -.33769900E+03, -.97125300E+03, 0.16289300E+04, -.89933000E+03, -.32160000E+03, 0.77617500E+02, 0.14743500E+04, 0.38712200E+02, 0.11883500E+04, -.52796400E+03, -.21031200E+04, -.19277000E+03, -.14060300E+04, 0.13058000E+04, -.19331000E+02, 0.10719000E+03, -.86786400E+03, 0.61679000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15713400E+01, -.32316400E-01, -.31220200E+00, -.23807800E+00, -.65132900E+00, -.51963000E+00, 0.63518700E+00, 0.12133000E+00, 0.85018900E+00, 0.15348800E+00, 0.62297800E+00, -.37580000E+00, 0.11223700E+00, 0.70076000E+00, -.50844700E-01, 0.73557300E+00, 0.48416000E-01, 0.87695500E+00, -.29635000E+00, 0.75328200E+00, -.52009200E+00, 0.20837300E+00, -.27417300E+00, 0.21689700E-01, -.18142800E+00, 0.53967600E+00, 0.54317100E+00, 0.19617300E+00, 0.13317000E+01, 0.24933800E+00, -.36666600E+00, -.27936400E+00, -.69116800E+00, -.23958400E+00, 0.19271900E+00, 0.32084700E+04, 0.20393400E+05, -.92659100E+04, -.11160800E+05, 0.80271200E+04, -.12427400E+04, -.79524700E+04, -.66952900E+04, -.51702100E+04, -.15766100E+04, -.24403900E+03, 0.13462100E+03, -.70265700E+03, 0.37689000E+04, -.33151400E+04, 0.11583500E+04, -.27548800E+04, 0.18568700E+03, 0.12412500E+03, -.28073300E+04, 0.14737300E+04, 0.44170500E+04, 0.23818600E+04, -.22409000E+04, -.18515800E+03, -.42218800E+04, 0.94644300E+03, 0.31650600E+04, -.34519200E+03, 0.63454400E+03, 0.17090700E+03, -.53800700E+04, 0.18625900E+04, 0.10905500E+04, 0.26190600E+04, 0.51001300E+03, -.17000600E+04, -.30284600E+03, 0.17065600E+03, 0.34922700E+03, -.98650500E+02, -.20737200E+04, 0.17839700E+04, -.20868600E+03, 0.53270400E+04, -.27604000E+04, -.21402200E+05, 0.10902200E+05, 0.15037300E+05, -.10937400E+05, -.60062200E+03, 0.11213000E+05, 0.74682500E+04, 0.10758900E+05, -.17235300E+04, 0.78535500E+03, -.40783400E+03, -.56654300E+03, 0.78529100E+03, 0.22271700E+04, -.32083900E+04, -.10365700E+05, -.73405000E+04, 0.29035700E+04, 0.38870200E+04, -.15721900E+04, 0.13272000E+04, -.22216000E+04, 0.18004200E+04, -.40833800E+04, -.88682400E+04, -.75079200E+04, 0.38720200E+04, -.44724200E+04, 0.20816300E+04, -.89063300E+03, -.46454900E+04, -.55631200E+02, 0.32081200E+04, 0.84535200E+04, 0.11235300E+03, 0.84310000E+03, -.12161200E+04, 0.52975300E+03, -.91085800E+03, -.77348900E+04, -.46246900E+04, 0.67788800E+04, 0.97821500E+04, 0.73071200E+04, -.72279800E+04, 0.75021200E+04, -.37659000E+04, -.35714100E+04, -.48135400E+02, -.23656600E+04, -.20675400E+04, -.20138200E+04, 0.84890800E+03, -.16734700E+04, 0.15516600E+03, 0.19971200E+02, 0.35120000E+03, -.79320800E+04, -.18220800E+04, 0.26228000E+04, 0.81177600E+04, 0.67283700E+04, -.74268800E+04, 0.25796600E+04, -.80087400E+03, -.12236100E+04, -.60372300E+04, 0.30017600E+04, -.17624100E+02, 0.20089800E+04, -.12523800E+04, -.39628000E+04, -.22055700E+05, 0.11321000E+05, 0.10298900E+05, -.26853200E+04, 0.43205100E+04, 0.55489800E+04, 0.14163600E+04, -.11565400E+04, 0.56768200E+04, 0.85917700E+04, -.48218400E+04, -.46559900E+04, 0.78469400E+04, -.66221100E+03, -.42247700E+04, -.19441800E+04, -.45845000E+04, 0.24330400E+04, -.10627300E+04, 0.33369700E+03, 0.46097100E+03, -.21221100E+03, -.17240000E+04, 0.18115500E+04, 0.23026700E+04, 0.15843900E+04, 0.32625000E+04, -.12987000E+04, 0.72812400E+03, 0.34290200E+04, 0.37280800E+04, 0.54541300E+00, -.79369000E+03, 0.13679100E+03, -.23832900E+04, 0.23987700E+04, 0.22008100E+05, -.11245500E+05, -.10570700E+05, 0.51322000E+03, -.49116500E+04, -.29484100E+04, 0.14524500E+04, 0.42371600E+04, -.84915300E+04, -.29560500E+04, 0.85866600E+03, 0.13400800E+04, 0.93197900E+03, -.20775600E+04, 0.11129000E+04, -.11121600E+04, 0.17254900E+04, 0.38905900E+03, 0.12854400E+04, 0.50017500E+03, -.17156900E+03, 0.34459300E+03, 0.48875500E+03, -.43808100E+04, 0.12515300E+04, 0.18228000E+04, -.39578100E+04, 0.39037000E+04, -.74551900E+04, 0.32762000E+03, -.23769600E+04, -.34519900E+04, -.38536500E+04, 0.80956500E+03, 0.47781700E+04, 0.24137000E+03, 0.10605900E+04, -.11551600E+05, 0.48190700E+03, -.77920800E+03, 0.80976600E+03, -.99911600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37562200E+00, 0.80785200E+00, 0.99062700E-01, -.79674800E+00, 0.18963400E+00, 0.39384400E+00, -.96503900E-01, -.12664200E+00, -.13089200E-01, -.80270700E-01, -.17257300E+00, -.45849200E+00, -.17446800E-01, 0.46248900E+00, -.20696600E+00, -.40367600E-01, -.39733500E+00, 0.24498000E+00, -.13086300E+00, -.74377800E+00, -.39052800E+00, -.61245100E-01, -.13595400E+00, -.72231100E-01, -.27172900E+00, 0.96555200E+00, -.66902900E+00, -.57721700E+00, -.30902700E+00, 0.22673900E+00, 0.30509400E+00, -.41658200E+00, 0.32750200E-01, 0.77081800E-01, -.25088400E-01, 0.14251600E-01, -.48692400E+04, 0.23313800E+04, 0.24028200E+04, -.16258700E+04, -.42469400E+03, 0.23406400E+04, 0.36216000E+04, 0.28190900E+04, -.29421900E+03, 0.53538000E+03, -.25044500E+03, 0.20689200E+02, -.10438600E+04, 0.19638500E+04, -.10127500E+04, -.20473800E+03, -.50048000E+03, 0.63626500E+03, 0.71987000E+03, -.35389800E+03, -.60410700E+03, -.11151200E+03, 0.61066300E+03, -.95482100E+01, 0.63680500E+03, -.29482100E+04, 0.64865800E+03, 0.30560600E+04, -.15729800E+04, -.15265500E+04, 0.22710300E+04, -.11134800E+03, -.16211300E+04, -.16382200E+04, -.12677900E+04, 0.94533400E+02, 0.27658400E+04, -.13881400E+04, -.12274800E+04, -.82915100E+03, -.13749100E+04, -.26840100E+03, 0.25975400E+04, 0.14570500E+04, -.12781100E+04, 0.15690900E+05, -.78593200E+04, -.87751800E+04, 0.18557800E+04, 0.16104700E+04, -.60078500E+04, -.29888000E+04, -.66036900E+04, -.70050200E+02, -.63708500E+04, 0.31898200E+04, 0.29469200E+04, 0.18662100E+04, 0.28149600E+04, 0.83784300E+03, 0.26802000E+03, -.35662700E+04, 0.26388800E+04, -.11116900E+03, 0.21328900E+02, 0.50693200E+02, 0.89071100E+03, 0.99778900E+03, 0.26621800E+03, 0.31679700E+03, -.11795000E+04, 0.46678100E+03, 0.90779000E+03, -.44040500E+03, -.11704000E+03, 0.10086800E+04, 0.69023600E+03, -.18423500E+04, -.44417900E+04, -.68786400E+02, 0.11421600E+04, 0.40056700E+04, -.19929800E+04, -.20924900E+04, 0.15604400E+04, 0.13143800E+04, -.30402900E+04, -.27033100E+04, -.53647800E+03, 0.32985600E+03, 0.15066700E+04, -.74151800E+03, -.77910200E+03, -.17104000E+01, 0.59785700E+03, -.42764700E+03, 0.61871000E+03, -.85382300E+03, 0.80620700E+02, 0.20578400E+04, -.10591500E+04, -.10454700E+04, 0.19615300E+04, 0.37343300E+03, -.86514300E+03, -.17836900E+04, -.13657800E+04, 0.57437100E+03, 0.16743600E+04, -.88315100E+03, -.81797200E+03, 0.22411100E+04, 0.14151500E+03, -.91007000E+03, -.62943200E+03, -.26057900E+03, -.76034500E+02, 0.97319900E+04, -.48901900E+04, -.46428700E+04, 0.67276800E+02, 0.29698800E+03, -.36281700E+04, -.14316400E+04, -.18075600E+04, -.22893400E+03, -.12142500E+05, 0.61180400E+04, 0.64303000E+04, -.22643000E+04, -.17764800E+04, 0.49693800E+04, 0.26238000E+04, 0.53432000E+04, -.64577600E+03, 0.10980800E+04, -.50795100E+03, -.55409400E+03, -.31979900E+03, 0.19235500E+03, -.54997900E+03, -.20718800E+03, -.10775200E+03, 0.94098100E+02, -.26270800E+04, 0.13052700E+04, 0.10871200E+04, -.11492800E+04, -.18429400E+03, 0.16003700E+04, 0.97377700E+03, 0.10467700E+04, 0.29645900E+03, -.74190200E+04, 0.37292300E+04, 0.32819900E+04, 0.10537000E+03, -.33653300E+03, 0.24347100E+04, 0.91563100E+03, 0.16599500E+04, 0.73718900E+02, 0.87604800E+03, -.35491600E+03, -.62778300E+03, -.74088100E+03, 0.30282300E+03, -.14405600E+03, 0.48601400E+03, 0.32936700E+03, -.77978300E+03, -.13772600E+03, 0.79406800E+03, -.52626800E+02, -.87721300E+02, 0.17986600E+04, -.32673800E+03, 0.10332500E+03, -.23567700E+03, 0.11440400E+04, 0.71506600E+03, 0.28930100E+04, 0.14438800E+03, 0.41693000E+03, 0.14810900E+04, 0.66388100E+03, 0.39203400E+03, -.13928000E+04, -.29255100E+03, -.73307600E+03, 0.33934200E+04, -.17235900E+04, 0.54918400E+03, -.23896200E+03, -.59593700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.59397800E-01, 0.35440900E+00, 0.10289500E+00, -.83739600E-01, -.38206300E+00, 0.38473600E+00, 0.99228000E-01, 0.23053100E-01, -.69544400E-01, 0.38051100E-01, 0.12319600E+00, 0.13301900E+00, 0.10948400E+00, 0.35111000E-01, 0.19781500E+00, 0.25352300E-01, 0.69386900E-01, 0.17535800E+00, -.31313400E+00, 0.25454000E+00, 0.57660000E-02, 0.73863500E-01, 0.68912400E-02, 0.79038900E-01, 0.97655400E-02, 0.15340100E+00, 0.13909900E+00, -.59219200E-01, -.23232800E+00, 0.73136100E-01, -.39562400E-01, -.28810300E-02, -.79983300E-01, -.22787000E-01, -.62005700E-01, 0.59331100E-02, -.27942200E+00, 0.15946500E+03, -.83430100E+02, 0.33726100E+03, 0.15460200E+03, 0.33188200E+02, 0.29512100E+03, 0.14689200E+02, 0.80943800E+01, 0.31633700E+03, -.13350000E+03, -.61133800E+02, -.73540700E+02, -.22212300E+02, -.10346900E+03, -.14900700E+03, -.18077600E+03, -.77448100E+02, -.21876600E+03, 0.13075100E+03, 0.85372500E+02, 0.10666500E+03, 0.50732000E+02, 0.46985500E+01, 0.20138100E+03, 0.32221900E+03, 0.59683000E+02, 0.13867900E+04, -.60241500E+03, -.69295600E+03, 0.42731800E+03, 0.38383500E+03, -.70441500E+03, -.74794800E+03, -.70175400E+03, 0.16870300E+03, 0.65293700E+03, -.32635500E+03, -.27514200E+03, -.63660300E+02, -.13061700E+03, -.14471800E+03, 0.30832300E+03, -.11762800E+03, -.15420200E+03, 0.19884200E+04, -.96414000E+03, -.11450000E+04, -.18919300E+03, 0.34103700E+03, -.80127800E+03, -.32298800E+03, -.82566700E+03, 0.14180000E+02, -.19122800E+03, 0.98670600E+02, -.26251700E+02, 0.82477800E+02, 0.12995400E+02, 0.28178700E+02, 0.10132500E+03, 0.63773900E+03, 0.42128500E+02, 0.12877000E+04, -.58654800E+03, -.52045100E+03, 0.52094100E+02, 0.12733900E+03, -.60329700E+03, -.46086300E+03, -.30947900E+03, -.10626600E+03, 0.14354900E+03, -.10021000E+03, 0.22145300E+02, -.20191500E+03, -.25065000E+02, 0.32323900E+02, -.23023000E+03, -.17513500E+03, -.14365300E+02, 0.60766400E+03, -.32022300E+03, -.31206300E+03, -.10849600E+03, 0.15903100E+03, -.21474300E+03, -.41200900E+03, -.47410100E+03, -.14297400E+03, -.41594300E+03, 0.21228800E+03, 0.19311700E+03, 0.14624300E+03, 0.14893800E+03, 0.25436300E+02, -.17023600E+03, -.10569000E+03, 0.16476800E+03, 0.20542400E+03, -.10111700E+03, -.11033100E+03, 0.12471700E+03, 0.15164000E+03, -.22519300E+03, -.29952000E+03, -.22254000E+03, 0.85557000E+02, 0.76040300E+03, -.27769300E+03, -.37510000E+03, 0.36020600E+03, 0.30224200E+03, -.47290400E+03, -.64721400E+03, -.45677100E+03, 0.27146400E+03, 0.15850600E+04, -.74472900E+03, -.72449900E+03, -.37781300E+03, -.20157900E+03, -.44937600E+03, -.11109700E+03, -.34923600E+03, -.17137100E+03, -.32601700E+04, 0.15426500E+04, 0.17468900E+04, -.34710600E+03, -.35940200E+03, 0.13579700E+04, 0.96325200E+03, 0.13856500E+04, 0.16849100E+02, 0.27898400E+03, -.17305000E+03, -.12821400E+03, -.99216500E+02, -.82713600E+02, -.17575500E+02, 0.28659900E+02, -.84090900E+02, -.50349600E+02, -.20891600E+03, 0.11915500E+03, 0.12947200E+03, 0.52988500E+00, -.12244500E+03, 0.11631300E+03, 0.24638700E+03, 0.28471600E+03, 0.54078300E+02, -.20777700E+04, 0.10027100E+04, 0.93002900E+03, 0.35757400E+03, 0.16344600E+03, 0.64555700E+03, 0.13434000E+03, 0.35157400E+03, 0.22007200E+03, 0.17418000E+03, -.14491500E+03, -.15427200E+03, -.10133300E+03, -.13502100E+03, -.46216500E+02, -.46193200E+02, -.54468300E+02, -.15666600E+03, 0.33519000E+02, 0.19160200E+03, -.29173800E+02, 0.40613500E+02, 0.13671600E+03, -.38614800E+03, 0.47985200E+02, -.42943700E+02, 0.17144100E+03, 0.11645400E+03, 0.15737600E+03, 0.51953500E+02, -.81409000E+02, 0.14655300E+03, -.34947500E+02, 0.31541600E+02, 0.39095600E+02, -.64672300E+02, -.30012300E+03, 0.45563900E+02, -.11665800E+03, 0.33637000E+02, -.13877700E+03, -.18860300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.17612900E+01, -.89064800E+00, -.58917200E+00, -.10710600E+01, -.59174200E+00, 0.39958300E-02, 0.37901000E-01, -.66492500E-01, 0.13559900E+01, -.67350500E+00, 0.78421700E+00, -.23790700E-01, -.21845900E+00, 0.16972800E+01, -.25485200E+01, 0.13217100E+01, -.11725900E+00, 0.50281900E+00, 0.81834500E+00, -.17511000E+00, -.82811300E+00, -.14738900E+00, 0.54137400E+00, -.11277100E+00, -.57901000E+00, 0.25844800E+00, -.35992700E+00, 0.31291800E+00, 0.46703700E+00, -.25189600E+00, 0.26770600E+00, -.76407000E+00, 0.15039500E+00, 0.11526700E+00, 0.10499400E+01, 0.64557400E+00, 0.56443800E-01, -.23360500E+01, 0.80484100E+03, -.91968800E+03, -.27944200E+04, 0.25268600E+04, 0.43568900E+04, 0.46701500E+03, -.17836600E+04, 0.11383800E+04, -.51744000E+03, 0.90583900E+02, -.19256600E+04, 0.52520700E+03, 0.47062400E+03, -.23661600E+04, -.42099400E+04, -.12164800E+04, -.40774800E+04, 0.20312800E+04, -.16159100E+04, 0.37763900E+04, 0.26350500E+04, -.50150800E+04, -.21960900E+04, 0.11048300E+04, 0.43157600E+04, -.24754000E+04, 0.13165200E+04, 0.12359400E+04, 0.86809400E+03, 0.60838900E+03, 0.90802800E+03, 0.55947900E+03, 0.17799500E+04, 0.44738700E+03, 0.12919300E+04, -.65623300E+03, -.14198200E+04, -.19990200E+03, -.15693800E+03, -.35108200E+03, 0.10188500E+04, -.54533800E+04, -.15319200E+03, 0.13041300E+05, -.65720500E+04, -.97078000E+04, 0.37233700E+04, 0.64434500E+04, -.10494900E+05, -.58930300E+04, -.72872800E+04, 0.39525100E+04, 0.39755900E+04, -.19752400E+04, -.15937000E+04, 0.87922000E+03, -.17875400E+03, -.28466900E+04, 0.20385000E+04, 0.51640500E+04, -.18283900E+03, -.62041300E+03, 0.32731100E+03, -.36512100E+04, 0.20027700E+04, 0.31258100E+04, -.43874300E+04, -.27280900E+04, -.14855900E+04, 0.32254600E+04, 0.62495600E+04, -.30610800E+04, 0.93565900E+03, -.37996600E+04, -.40163600E+04, 0.33731900E+04, -.60933400E+03, -.67351800E+03, -.34517100E+04, 0.15032900E+05, -.74949300E+04, -.47399700E+04, -.19856900E+04, -.15770100E+04, -.16251800E+04, -.32937100E+04, -.72976200E+04, -.48700100E+04, -.35022400E+04, 0.17647700E+04, 0.16133300E+04, 0.13872200E+04, 0.20817100E+04, -.44850700E+03, -.12061500E+04, 0.64539600E+03, 0.15716500E+04, 0.37778400E+04, -.19387400E+04, -.23588500E+04, 0.19961900E+04, 0.94599100E+03, -.29040800E+04, -.97848100E+03, -.40393200E+03, 0.86558300E+03, -.11842600E+05, 0.60177400E+04, 0.57525700E+04, -.21528200E+03, 0.41428000E+03, 0.50618000E+04, 0.44109200E+04, 0.66565100E+04, -.35752000E+02, 0.19213700E+05, -.96080200E+04, -.92168600E+04, -.21379900E+04, -.30041000E+03, -.49998400E+04, -.19356600E+04, -.72134000E+04, -.18581000E+04, -.15233400E+05, 0.76623200E+04, 0.76448500E+04, -.34429200E+04, -.34915900E+04, 0.76744500E+04, 0.53009400E+04, 0.69621500E+04, -.18526100E+04, -.59046300E+03, 0.29611700E+03, 0.44702700E+03, -.32816200E+03, 0.96359400E+02, 0.48806900E+03, -.50329800E+03, -.83333400E+03, 0.13430100E+03, -.62290300E+04, 0.31051700E+04, 0.29515700E+03, 0.22400500E+03, 0.47267100E+03, 0.47708700E+03, 0.25886000E+04, 0.35871000E+04, 0.25764000E+04, -.23354800E+05, 0.11671900E+05, 0.12490000E+05, 0.17963200E+04, 0.27405600E+03, 0.72146900E+04, 0.21064700E+04, 0.82891400E+04, 0.14060900E+04, -.12558200E+04, 0.74970100E+03, 0.90181000E+03, -.50596600E+03, 0.97167200E+03, 0.44150500E+03, -.48829000E+03, -.14050000E+04, -.89284800E+03, 0.16429300E+04, 0.54019600E+04, -.17228100E+04, 0.25246600E+04, 0.22126100E+04, -.37812500E+04, 0.17659700E+04, -.51765200E+03, 0.49376100E+04, 0.26762300E+04, 0.11147800E+03, 0.31084500E+04, -.30340400E+03, 0.12740100E+04, -.66583600E+02, 0.16896300E+04, 0.10224600E+04, -.36798900E+04, -.13341000E+04, -.44939600E+03, -.21284300E+04, 0.21748400E+04, 0.46171100E+03, -.49518400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.34561600E+00, 0.61645000E+00, 0.28873900E+00, -.43482500E+00, 0.16405200E+00, 0.11210700E+00, -.15840100E+00, -.16460800E-01, 0.17751400E+01, -.68160400E-01, -.13567400E+00, -.14726400E+00, -.15788200E+00, -.36147500E+00, 0.70877000E-01, -.30869100E+00, -.12223400E-01, 0.59645000E+00, -.55685800E+00, -.13408500E+01, 0.12475000E+00, -.19252800E+00, -.15578200E+00, 0.29463900E+00, 0.31243200E+00, -.53021800E+00, 0.27415600E+00, 0.25560400E+00, 0.37074400E+00, -.56579700E-01, -.14811200E+00, -.38868100E+00, -.62610200E-01, 0.94185700E-01, 0.13327700E+00, -.14023700E+00, -.77909100E+00, 0.40193300E-01, 0.58042700E-01, 0.10815500E+04, 0.15022000E+03, 0.19871500E+02, 0.10004900E+04, 0.13433900E+03, -.79664300E+02, -.48591100E+04, 0.24306200E+04, 0.26022200E+04, 0.77494100E+03, 0.15056300E+04, 0.98473000E+03, 0.12714100E+04, -.14244900E+03, 0.15900700E+04, -.48067700E+04, 0.23977000E+04, 0.19506800E+04, 0.10093200E+04, 0.68660600E+03, 0.71191300E+03, 0.27028600E+04, -.89517700E+02, 0.10507300E+04, 0.28162800E+04, -.13981100E+04, -.14077000E+04, 0.68230300E+03, -.37282500E+03, -.11490600E+04, -.83115000E+03, -.11882000E+04, -.65112000E+03, 0.52582400E+03, -.26380000E+03, -.32393800E+03, 0.29503200E+03, 0.29668100E+03, -.34379400E+03, 0.12694900E+04, 0.31499700E+03, 0.21762600E+03, 0.63739500E+04, -.31872600E+04, -.37411000E+04, -.87088700E+03, 0.10903900E+04, -.25946500E+04, -.20665800E+03, -.26928600E+04, 0.15710200E+03, -.48559200E+04, 0.24238900E+04, 0.23533800E+04, 0.67643500E+03, 0.85308900E+03, 0.10817200E+04, 0.34852400E+04, -.97032800E+03, 0.10566200E+04, -.25745300E+04, 0.12857400E+04, 0.94991100E+03, 0.72505400E+03, 0.71941800E+03, -.27779300E+03, 0.27428600E+03, -.80037700E+03, 0.57265200E+03, 0.57820500E+04, -.28795800E+04, -.23072700E+04, -.14646800E+04, -.35887400E+03, -.94904400E+03, -.34479300E+04, -.25435000E+03, -.77585300E+03, -.13197500E+04, 0.65742300E+03, 0.94510200E+03, -.43758800E+03, 0.24403700E+03, 0.89212500E+03, -.53966800E+03, 0.13020200E+04, -.11265300E+03, -.15204500E+04, 0.75997100E+03, 0.74059700E+03, 0.31809200E+03, 0.16646300E+03, 0.41592200E+03, 0.14992600E+04, -.48997200E+03, 0.25188000E+03, 0.35170200E+04, -.17671800E+04, -.18361500E+04, -.23894000E+03, 0.42810000E+01, -.10545900E+04, -.15580300E+04, -.13135100E+03, -.53040300E+03, 0.44100500E+04, -.21931700E+04, -.22172700E+04, 0.52923400E+03, -.55070900E+03, -.17157000E+04, -.85475900E+03, -.18686800E+04, -.59859700E+03, 0.20551200E+04, -.10255800E+04, -.92135500E+03, -.86343700E+03, 0.50551900E+02, -.66577800E+03, -.75449800E+03, -.14847300E+03, 0.70443900E+02, -.87452500E+04, 0.43678100E+04, 0.44950400E+04, -.39480000E+03, -.11838400E+04, 0.33870500E+04, 0.15247100E+04, 0.37014300E+04, 0.59641600E+02, 0.25057000E+03, -.10946500E+03, -.73253100E+02, -.49193100E+01, -.47328600E+02, -.71284400E+02, 0.13157100E+03, -.47892100E+02, 0.70272800E+02, 0.17010100E+04, -.84624100E+03, -.11293400E+04, 0.24246400E+03, -.26578300E+03, -.96292800E+03, -.78235500E+03, -.24905800E+03, -.40401400E+02, -.49211800E+03, 0.24414300E+03, 0.24479300E+03, 0.60352900E+03, 0.70574700E+03, 0.20604300E+03, 0.30519500E+03, -.53458600E+03, 0.42537000E+03, 0.15842000E+04, -.77655500E+03, -.84335700E+03, -.23050100E+03, -.11117000E+03, -.48062800E+03, 0.70483300E+02, -.32465900E+03, -.16944600E+03, 0.15957600E+04, -.37493700E+03, -.48474600E+03, 0.94210700E+03, 0.65980400E+03, -.39997900E+03, -.32983900E+02, 0.22085100E+03, 0.28801700E+03, -.69480100E+03, 0.29116600E+04, -.41037600E+03, 0.98358000E+02, 0.14802700E+04, 0.20729500E+03, 0.15616300E+03, 0.66195700E+03, -.59834900E+03, -.22855200E+02, 0.22034600E+04, -.65439200E+03, 0.23431400E+03, 0.31721900E+03, 0.36534500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10191300E+01, 0.90755500E+00, 0.25103300E+00, -.27005400E+01, -.20007000E+00, 0.19445800E+01, -.22839000E+01, -.66119600E+00, 0.38501200E+00, -.78912000E+00, 0.16119500E+00, 0.28226600E+00, -.19062700E+00, 0.80352900E+00, -.59109000E+00, 0.91276800E+00, 0.86109900E+00, 0.97757300E+00, 0.12671700E+01, 0.15158600E+01, 0.27080700E+00, 0.63323200E+00, 0.10101400E+01, -.55605100E+00, 0.35823900E+00, -.29813800E+00, 0.49997900E+00, 0.11990700E+01, 0.13848300E+01, -.91312300E+00, -.21720700E+00, 0.17304600E+01, 0.56048000E+00, -.45442100E+00, -.76713500E+00, 0.27223100E-01, -.10794700E+00, 0.20996100E+01, 0.13107400E+01, -.36107500E+00, 0.86924300E+04, -.44134900E+04, -.90744400E+04, -.13424300E+04, 0.60780900E+04, 0.12938000E+05, -.65985300E+04, -.72707700E+04, -.21729400E+04, -.71609100E+04, -.21575500E+04, -.22882800E+03, 0.58389900E+04, -.40208000E+04, 0.13336500E+05, -.67110500E+04, -.51813600E+04, -.74457400E+04, -.44348400E+04, -.32366500E+03, -.66504700E+04, 0.25415000E+03, -.63701000E+04, 0.56573700E+04, -.30195200E+04, -.28333800E+04, 0.84762000E+03, -.90846400E+03, -.32346900E+04, -.48773600E+04, -.38571600E+04, -.12218200E+04, -.18707200E+05, 0.93584300E+04, 0.92708500E+04, 0.30727400E+04, 0.54863600E+04, 0.24727300E+04, -.93485700E+04, 0.95760600E+04, 0.56139200E+04, -.28069400E+05, 0.14128000E+05, 0.17189600E+05, -.30603300E+04, -.59459300E+04, 0.14246300E+05, 0.49061600E+04, 0.14367400E+05, -.23618400E+04, 0.20909300E+05, -.10466600E+05, -.10127700E+05, -.64529700E+04, -.74099600E+04, -.16980400E+04, -.12460700E+05, -.75392700E+04, -.74149500E+04, 0.14068500E+05, -.70726100E+04, -.60293300E+04, -.17322600E+04, -.53809800E+04, -.25907100E+04, -.29875800E+04, -.30613400E+03, -.50435700E+04, -.19376300E+05, 0.96194900E+04, 0.79311100E+04, 0.49560600E+04, 0.32680100E+04, 0.66906700E+04, 0.18012800E+05, 0.16765600E+04, 0.19194900E+04, -.15903800E+05, 0.79668200E+04, 0.77816600E+04, 0.92812600E+03, 0.41970400E+03, 0.63394800E+04, 0.11883100E+05, 0.88943200E+04, 0.46378700E+04, 0.14483500E+05, -.72846700E+04, -.72231000E+04, -.44689500E+04, -.61644100E+04, -.17246400E+04, -.20715900E+04, 0.12175500E+04, -.50510300E+04, -.15269100E+05, 0.77455400E+04, 0.81041000E+04, 0.68023100E+03, 0.29282300E+04, 0.54843600E+04, 0.42918500E+04, 0.95594800E+03, 0.24749400E+04, 0.21125500E+05, -.10802700E+05, -.10583800E+05, 0.43711600E+04, -.56715200E+02, -.11261100E+05, -.13768500E+05, -.12097900E+05, -.78040200E+01, -.30939200E+05, 0.15505000E+05, 0.14834500E+05, 0.44330400E+04, 0.71576200E+03, 0.72852000E+04, 0.29784300E+04, 0.64687800E+04, 0.27062600E+04, 0.29321600E+05, -.14771300E+05, -.15563000E+05, 0.56467000E+04, 0.30354100E+04, -.13934000E+05, -.75166500E+04, -.14498800E+05, 0.16142800E+04, -.38010100E+03, 0.20884200E+03, 0.30484300E+01, 0.82082200E+01, -.22693900E+02, -.38489400E+03, 0.45955800E+03, 0.15118400E+04, -.38941400E+03, -.38873800E+04, 0.19158100E+04, 0.28872700E+04, 0.25453400E+04, 0.24115800E+04, -.22695800E+04, -.57335500E+04, -.53988600E+04, -.12508800E+03, 0.36214700E+05, -.18126200E+05, -.17352400E+05, -.52517200E+04, -.37455200E+04, -.60921100E+04, -.46535700E+03, -.54882500E+04, -.50204100E+04, -.10673800E+05, 0.49406600E+04, 0.55607600E+04, 0.62036800E+03, -.28375200E+04, 0.32414700E+04, -.83879400E+03, 0.51984500E+04, 0.22037100E+04, -.43527200E+04, -.51236200E+04, 0.22947100E+04, -.52035800E+04, -.53185600E+03, 0.31698400E+04, -.26900200E+04, 0.22416600E+04, -.80521900E+04, -.64535400E+03, -.11287700E+05, -.18714100E+04, -.33207900E+04, -.53935400E+04, -.34221500E+04, -.16611700E+04, -.37781300E+04, 0.67065700E+04, 0.20080300E+04, -.10038400E+05, 0.49272300E+03, -.36813200E+04, -.18616600E+04, 0.42605900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.85371800E+00, 0.48051700E+00, 0.63400800E-01, 0.29368700E+00, -.24308200E+00, 0.46331300E+00, -.72715300E-01, 0.42811900E-01, -.14204900E+01, -.33628400E+00, -.65487100E-01, 0.11119900E+00, 0.66193000E+00, 0.54017500E+00, -.28743100E+00, -.37555700E-01, 0.14301500E+00, -.10257600E+01, 0.97576000E+00, 0.72459300E+00, 0.27090900E+00, 0.24009700E-01, 0.13549900E+00, -.19286400E+00, 0.11192800E+00, -.25844400E+00, -.49521300E+00, -.78593500E+00, -.81491600E+00, 0.52393100E-01, 0.40264900E+00, -.42535800E+00, -.52811700E+00, 0.18160200E-01, 0.92243600E-01, 0.14418700E+00, -.11013900E+01, 0.17484700E+01, -.24070900E+00, 0.14451800E+01, -.12699300E+00, 0.11878400E+04, 0.49494100E+03, 0.99617100E+03, -.42434100E+03, 0.89484100E+04, -.44222500E+04, -.41797600E+04, -.31794700E+04, -.23435000E+04, -.79821400E+03, -.32948900E+04, 0.75335200E+03, -.46256800E+04, 0.31446100E+04, -.15572800E+04, -.28912700E+04, 0.13463300E+04, 0.33325500E+02, -.34187000E+04, -.52141700E+04, 0.14288200E+04, 0.65440900E+03, -.42234100E+04, 0.21913500E+04, 0.21112100E+04, -.85442900E+03, -.45530700E+02, 0.15107100E+04, 0.10566500E+04, 0.25225200E+04, 0.11017400E+04, -.45295700E+04, 0.22476400E+04, 0.19450500E+04, 0.23334500E+03, 0.58472800E+03, 0.12868300E+04, -.15174800E+04, 0.16244100E+03, 0.10140700E+04, -.10159600E+04, 0.46438100E+03, -.33187000E+03, 0.14670400E+04, 0.26332900E+04, -.26485700E+04, -.35234300E+04, -.10409000E+04, 0.33247300E+04, 0.12758700E+05, -.63551400E+04, -.64134900E+04, -.94775600E+03, -.22307200E+04, -.40034000E+04, -.63156700E+04, 0.84440100E+03, -.28642400E+04, 0.44914600E+04, -.22065100E+04, -.33887500E+04, -.99807200E+02, -.33313300E+01, -.43720000E+04, -.57208200E+04, -.10391600E+04, 0.69017300E+03, -.49363800E+04, 0.25296700E+04, 0.41098100E+04, -.17360000E+03, -.21457800E+04, 0.40439600E+04, 0.61004200E+04, -.14653900E+04, -.25236500E+03, 0.11583200E+05, -.57639200E+04, -.45876600E+04, -.15524000E+04, -.20109000E+04, -.10931700E+04, 0.12302300E+04, -.41106100E+04, -.28590100E+04, 0.45263700E+04, -.22414100E+04, -.23314500E+04, -.50024300E+03, 0.86602100E+02, -.18080900E+04, -.33367400E+04, 0.13141300E+04, -.94712400E+03, -.37872700E+03, 0.17336300E+03, -.38677900E+02, 0.17197600E+04, 0.81741000E+03, -.19535100E+04, 0.22484300E+03, -.37411200E+04, 0.27143800E+04, -.11669600E+05, 0.59685400E+04, 0.57609100E+04, -.24980300E+04, 0.73177600E+03, 0.43937600E+04, 0.31555900E+04, 0.65189600E+04, 0.12619200E+03, 0.35298000E+04, -.17591000E+04, -.16191200E+04, -.13651600E+04, -.84519300E+03, -.10854500E+04, 0.10506000E+04, -.17668400E+04, -.68130400E+03, -.39565900E+04, 0.20079500E+04, 0.20759900E+04, -.10489900E+04, -.39371000E+03, 0.28024600E+04, 0.40051800E+04, 0.24387900E+04, -.17960000E+04, -.30138500E+03, 0.13468800E+03, 0.29961300E+03, -.36135100E+03, -.69443500E+02, 0.56655200E+03, 0.11845900E+03, 0.74612300E+03, -.25045100E+03, -.62813600E+04, 0.31265100E+04, 0.24202100E+04, 0.10507800E+04, 0.13153600E+04, 0.36415300E+02, 0.44652000E+03, 0.40553400E+03, 0.21847700E+04, -.29157300E+04, 0.14508800E+04, 0.19044200E+04, 0.23868000E+03, -.98535600E+03, 0.28650500E+04, 0.51724900E+03, 0.32870600E+04, -.12384500E+04, -.57491900E+04, 0.28972500E+04, 0.29149400E+04, -.73369200E+03, 0.79115500E+03, 0.20814200E+04, 0.33977000E+03, 0.12427500E+04, -.85660400E+03, -.10367300E+04, 0.36139900E+04, -.18694500E+02, -.20253300E+03, -.38406000E+03, -.32481000E+04, 0.52423800E+03, -.24774900E+03, 0.10184000E+04, 0.30110000E+04, -.57259500E+04, 0.18634300E+04, -.18001000E+04, -.23593600E+04, -.19063600E+04, -.31556100E+02, 0.69183300E+02, -.33628800E+03, -.38987200E+03, -.57308600E+04, 0.43746400E+03, 0.73469500E+01, -.45981200E+03, -.31825200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.95236200E+00, -.40952000E+00, -.35670300E+00, -.56635900E+00, 0.19780300E+00, -.55526200E+00, 0.64627600E+00, 0.60800700E-01, 0.83487000E+00, 0.17279000E+00, 0.25543900E+00, -.66439000E+00, -.19966800E+00, 0.11416400E+01, -.98944600E+00, 0.57332500E+00, -.16194500E+00, 0.85994300E+00, 0.13299800E+01, 0.27859500E+01, -.75274200E+00, 0.26704200E+00, -.14258500E+00, -.38274200E+00, 0.20106100E+00, 0.49124200E+00, -.10342000E+00, -.54598500E+00, -.86141800E+00, 0.34391900E+00, 0.11487000E+00, 0.26582100E+00, -.32807700E+00, -.20840700E-01, 0.82389300E-01, 0.31050000E+00, 0.14464500E+01, -.10448700E+01, 0.12422100E-01, 0.54683800E+00, 0.10027000E+00, -.17022300E+00, -.21296500E+04, 0.67738400E+03, -.80277100E+02, 0.42386100E+04, -.21148600E+04, -.19984700E+04, 0.48614900E+03, -.12923100E+04, -.80416000E+03, -.94564000E+03, 0.10959400E+04, -.81193800E+03, 0.28594300E+03, -.14942100E+03, -.80510700E+03, 0.13202800E+03, 0.29244500E+03, -.13585700E+04, -.27866000E+04, -.63523200E+03, -.52698700E+03, -.78554100E+04, 0.39409100E+04, 0.39270800E+04, -.25305500E+04, -.27864500E+02, 0.36475700E+04, 0.33589200E+04, 0.31830900E+04, 0.96712700E+03, -.92303000E+03, 0.46137800E+03, 0.27432100E+03, 0.61040000E+03, 0.12296700E+04, -.41492000E+03, -.21635300E+04, -.94007200E+03, 0.92357000E+03, -.13147800E+05, 0.65537000E+04, 0.62932800E+04, 0.87996900E+03, -.45083200E+03, 0.30192600E+04, 0.41111400E+03, 0.18575500E+04, 0.11621000E+04, 0.54292000E+04, -.27119200E+04, -.26913500E+04, -.15091400E+04, -.25025800E+04, -.88032800E+03, -.26866300E+04, 0.79917800E+03, -.22655600E+04, -.52855800E+04, 0.26357900E+04, 0.20487200E+04, 0.86608900E+03, 0.13669400E+04, -.75268500E+03, -.71668700E+03, 0.10796000E+04, 0.19731300E+04, -.16146100E+04, 0.82841300E+03, 0.16356200E+04, -.34365800E+03, -.13912800E+04, 0.29889900E+04, 0.53914600E+04, 0.23191300E+04, -.17328000E+04, -.70467100E+03, 0.36171900E+03, 0.10255000E+04, -.73147700E+03, -.10665900E+04, 0.19398800E+04, 0.20045600E+04, 0.28390600E+04, -.45196800E+03, 0.58396800E+03, -.29134000E+03, -.34942600E+03, -.67191900E+03, -.11249800E+04, 0.15638100E+03, -.14196200E+04, -.15615400E+04, -.51007200E+03, -.31250100E+04, 0.15761600E+04, 0.13778100E+04, -.11649600E+04, -.10724100E+04, 0.84229100E+03, 0.89842900E+03, -.10088800E+04, -.20501100E+03, -.97429900E+04, 0.48992000E+04, 0.48289300E+04, -.27297900E+04, -.66010300E+03, 0.42318800E+04, 0.33348600E+04, 0.34860200E+04, 0.18170200E+04, -.60481300E+04, 0.30124600E+04, 0.31200700E+04, 0.90049000E+03, 0.27082300E+03, 0.20960100E+04, 0.13780000E+04, 0.42711200E+04, 0.79908200E+03, 0.10123100E+05, -.50430700E+04, -.51398300E+04, 0.93241200E+03, 0.24169800E+04, -.38353800E+04, -.14709800E+04, -.25926900E+04, 0.27771800E+03, -.51853000E+03, 0.22780300E+03, 0.38662600E+03, 0.33105800E+03, 0.29878300E+03, 0.22102000E+03, 0.16620200E+03, 0.91440800E+03, 0.22727800E+03, -.23077400E+04, 0.11424200E+04, 0.80284600E+03, 0.10566200E+04, 0.13470700E+04, -.63456200E+03, -.44162200E+03, 0.28107900E+03, 0.97626200E+03, 0.72732800E+04, -.36209900E+04, -.33673600E+04, -.16487600E+04, -.22370700E+04, -.10947200E+04, -.46386700E+03, -.43399300E+04, -.22390600E+04, 0.60740700E+03, -.29335900E+03, -.18226000E+03, 0.87726000E+03, 0.85198400E+02, -.36572000E+03, -.54625700E+03, -.11684900E+04, 0.69636800E+03, -.93343500E+03, 0.78989000E+03, -.35212200E+03, 0.37223300E+02, -.12048000E+04, -.31354300E+03, 0.96035800E+03, -.27557900E+03, 0.17570200E+03, 0.74684100E+03, -.29514200E+04, 0.73976500E+03, -.71369500E+03, -.11625400E+04, -.29947900E+03, 0.11023900E+04, 0.12349400E+04, 0.23978100E+01, 0.18894900E+04, -.29849500E+04, 0.11296300E+04, 0.26297600E+03, 0.14554300E+04, -.90227500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.70910000E+00, 0.57728600E+00, 0.64606100E-01, -.68131500E+00, 0.18810800E+00, 0.10611500E+01, -.36761500E+00, -.43833200E+00, 0.26587400E+00, 0.17997600E+00, -.36380900E+00, -.83418600E+00, -.34014300E+00, -.15667800E+01, -.28578300E+00, -.17569500E+01, -.10214200E+01, 0.14652500E+00, -.13127600E+00, -.24596200E+01, -.31129200E+00, -.53922800E+00, -.32247500E+00, 0.14097900E+00, 0.18532100E-01, 0.57039700E+00, -.56516000E+00, 0.25681700E+00, -.11464800E-01, -.43522900E-01, 0.96316200E-01, -.34569800E+00, 0.56587800E+00, 0.76167300E-01, 0.10984900E+00, -.39000200E+00, 0.60238900E+00, -.79591000E+00, -.13075700E+00, -.16544400E+01, -.43656200E-02, -.15341800E+00, -.51093800E+00, 0.20838600E+04, -.63316300E+03, 0.39131700E+04, -.19444400E+04, -.18985200E+04, 0.98975100E+02, -.85088900E+03, -.12110200E+04, -.15806200E+04, -.29467500E+03, -.36050200E+03, 0.13961000E+04, -.69584500E+03, -.11134400E+04, -.82341200E+02, 0.21547700E+03, -.10943300E+04, -.29073100E+04, -.29435900E+04, -.27706800E+03, 0.26126400E+04, -.12631900E+04, -.13069000E+04, 0.93504400E+03, 0.41117900E+03, -.11429400E+04, -.75798300E+03, -.97104500E+03, 0.71246100E+02, -.20380700E+04, 0.10131800E+04, 0.85385900E+03, -.52463900E+02, 0.29863200E+03, 0.35616700E+03, -.76267800E+03, 0.23731900E+04, -.74083500E+02, 0.94481900E+02, -.63292600E+02, -.25018800E+03, -.56591400E+03, -.10020500E+02, -.24011700E+03, -.64429700E+03, -.88635200E+03, -.13737800E+03, 0.41405700E+03, -.20346900E+03, -.17409300E+03, 0.64050500E+03, 0.62623800E+03, -.91297900E+03, -.51030900E+04, -.64877500E+04, 0.80489600E+03, -.34592400E+04, 0.17439800E+04, 0.13127300E+04, 0.99406000E+03, 0.54334600E+03, -.29505900E+03, -.22684800E+04, -.22952300E+04, 0.11581100E+04, -.33993300E+04, 0.17302600E+04, 0.22220400E+04, -.13952600E+02, 0.79766400E+03, 0.21015200E+04, 0.37468600E+04, 0.16742600E+04, 0.59153100E+03, 0.96882200E+03, -.47412200E+03, -.10261800E+03, -.22578800E+03, -.35869800E+03, 0.56163500E+03, 0.21358900E+04, 0.36546100E+04, -.79307100E+03, 0.52984700E+04, -.26396500E+04, -.26214300E+04, -.63720800E+03, -.17712700E+04, -.96013000E+03, -.70032000E+03, -.25334400E+03, -.13636900E+04, -.17148900E+04, 0.83325300E+03, 0.82627000E+03, 0.59161100E+02, 0.19152600E+03, 0.59787300E+03, 0.51436000E+03, 0.74476300E+03, -.50851900E+02, 0.13575200E+04, -.62016200E+03, -.70688900E+03, 0.99155400E+03, -.10174900E+01, -.89964800E+03, -.90266000E+03, -.57601800E+03, 0.10924200E+04, -.73371800E+04, 0.36622900E+04, 0.36384400E+04, 0.79395600E+03, 0.12482400E+04, 0.12359300E+04, 0.23622300E+03, 0.50169700E+03, 0.25079900E+04, -.33168400E+04, 0.16750100E+04, 0.17177900E+04, -.93897100E+03, 0.70870800E+02, 0.14132200E+04, 0.20600000E+04, 0.20186500E+04, 0.25966800E+03, 0.11639500E+04, -.56582500E+03, -.53799400E+03, 0.54523800E+02, 0.15929100E+03, -.50036400E+03, 0.15561400E+03, 0.36273300E+03, 0.85462300E+02, -.42037100E+04, 0.20927800E+04, 0.18967600E+04, 0.75570200E+03, 0.12216100E+04, 0.11120000E+03, -.46715400E+03, -.56227800E+03, 0.15760700E+04, 0.12966000E+05, -.64782200E+04, -.62331900E+04, -.17027800E+04, -.26906100E+04, -.17674200E+04, 0.69992900E+03, 0.19494400E+03, -.41127900E+04, -.18237300E+04, 0.90991800E+03, 0.85235900E+03, 0.32858700E+03, -.25070400E+03, 0.42396600E+03, -.66734600E+03, 0.16026300E+03, 0.45058400E+03, -.62154100E+03, 0.87644600E+03, 0.67142900E+02, -.51485100E+03, -.26496000E+03, -.68135000E+03, 0.50775500E+03, 0.13768500E+03, -.91640800E+02, 0.16106500E+04, -.21239700E+04, 0.35722800E+03, -.10086900E+04, -.57959700E+03, -.96585600E+03, 0.91425300E+03, 0.52013800E+02, 0.53059000E+03, 0.11104000E+04, -.19902500E+04, 0.24546000E+03, -.90232800E+02, 0.39376100E+03, -.94874900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.82470600E+00, 0.97818900E+00, 0.36069600E+00, -.10890700E+01, 0.17036500E+00, 0.79853100E+00, -.61275300E+00, -.23412300E+00, 0.97383800E+00, 0.10531500E+00, -.44833800E+00, -.62067100E+00, -.37068900E+00, -.14021000E+01, 0.29061700E+00, -.10239600E+01, -.45039800E+00, -.37681300E+00, 0.12069900E+01, -.20732500E-01, 0.23448200E-01, -.11558700E+00, -.31288200E+00, -.44060200E+00, -.18951600E+00, -.29543800E+00, -.98003000E+00, 0.10373100E+01, 0.67136300E+00, -.32436300E+00, 0.10693200E+00, -.15742200E+00, 0.20700000E+00, 0.43706100E-01, -.36517900E+00, -.12582700E+00, 0.26424200E+00, -.13748700E+01, 0.35699200E-01, 0.78939800E+00, -.59115900E-01, -.11211400E+00, 0.17047400E+00, 0.65842700E+00, 0.10620800E+04, -.11337800E+03, 0.58497600E+02, -.11474900E+03, -.70067900E+03, -.17056400E+03, 0.10809300E+03, -.11950900E+04, 0.24143600E+04, -.71584800E+03, 0.50170100E+04, -.24927500E+04, -.17510000E+04, -.13217300E+04, -.18454200E+04, 0.11584000E+04, -.69182000E+03, 0.52784500E+03, -.10830700E+04, 0.18452300E+04, -.97917100E+03, -.92145100E+03, -.38341100E+03, 0.54159400E+03, -.83054600E+03, -.54259900E+03, -.32672500E+03, -.24815500E+03, -.21611800E+03, 0.10688400E+03, 0.33378000E+03, -.36374700E+03, -.11006900E+04, 0.10491700E+04, 0.11168700E+04, 0.34011300E+04, -.45241100E+03, -.36626900E+04, 0.18391500E+04, 0.20941200E+04, 0.64412300E+03, -.36544200E+03, 0.25990000E+04, 0.10349200E+04, 0.32711200E+04, -.26068500E+03, 0.19836400E+04, -.98510500E+03, -.95959800E+03, -.31863600E+03, 0.19242600E+03, -.10423900E+03, -.21886700E+04, -.11963200E+04, -.35959600E+03, 0.73886200E+04, -.37185200E+04, -.30414300E+04, -.13251000E+04, -.11416500E+04, 0.45783600E+02, -.16069200E+04, -.65124500E+03, -.17763100E+04, -.52388800E+04, 0.25629500E+04, 0.16076700E+04, 0.18485800E+04, 0.17052400E+04, -.22452600E+04, -.78662100E+03, -.26909300E+04, 0.23996200E+04, 0.40953400E+02, -.32489200E+02, -.85679000E+03, 0.82355600E+03, 0.75387300E+03, -.19285600E+04, -.19079100E+03, -.10934700E+04, 0.85242300E+03, 0.29842300E+04, -.14869400E+04, -.14498200E+04, -.55293500E+03, -.14596800E+03, -.48199700E+03, -.17280700E+03, 0.22553400E+04, -.80225100E+03, -.69216700E+03, 0.35363300E+03, 0.41270300E+03, 0.27131800E+03, -.13005200E+03, 0.67291800E+03, 0.19820300E+04, -.49655800E+03, -.62798600E+02, 0.11858300E+04, -.67279600E+03, -.53981400E+03, -.50078800E+03, 0.12113000E+04, -.32878500E+03, 0.24748100E+02, 0.66770100E+03, -.18273000E+04, 0.21236900E+04, -.10681100E+04, -.11160900E+04, 0.31399500E+03, 0.59900300E+03, -.11925200E+04, 0.38286000E+03, -.25437900E+04, -.80542000E+03, 0.65133800E+04, -.32663300E+04, -.32372700E+04, 0.38001600E+03, -.42471000E+03, -.25011100E+04, -.17670600E+04, -.36985300E+04, -.33516100E+03, -.52087100E+03, 0.24590700E+03, 0.19358100E+03, -.12596800E+03, -.17982200E+03, 0.11347800E+03, -.17546400E+03, 0.34355100E+03, -.24739400E+03, 0.16015700E+04, -.79524600E+03, -.34190900E+03, -.65644800E+03, -.83248500E+03, 0.70466300E+03, 0.36319200E+03, -.18440600E+04, -.93970900E+03, -.32005600E+04, 0.16167000E+04, 0.12496100E+04, 0.17347700E+03, -.82496300E+02, 0.48692900E+03, -.16289400E+03, 0.35000900E+04, 0.10115200E+04, -.24928900E+04, 0.12506500E+04, 0.12516700E+04, -.40402300E+03, 0.21291200E+03, 0.97744200E+03, 0.74722200E+03, 0.24580500E+04, -.44302500E+03, -.94326700E+03, -.64155100E+03, 0.12066500E+04, -.12691000E+04, -.45793400E+03, -.28268100E+02, -.77560300E+03, 0.28211300E+03, -.15545700E+04, -.76292200E+02, -.93569800E+03, -.10214700E+04, 0.16311400E+03, -.11423900E+04, -.51398300E+03, -.17559300E+04, -.14372300E+04, 0.10049300E+04, -.14271500E+04, -.25511200E+03, 0.46821600E+03, -.11584500E+04, -.17483200E+04, 0.74920000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12416700E+01, 0.86506700E+00, 0.57100100E+00, -.34380900E+01, 0.33361700E-01, 0.20290700E+01, -.28735400E+01, -.55535900E+00, 0.14750800E+01, -.97426900E+00, -.26823200E+00, 0.23145800E+00, -.74994900E+00, 0.13002100E+01, -.24255700E+00, 0.33162300E+01, 0.22072200E+01, 0.12434100E+00, 0.30254500E+01, 0.20348900E+01, 0.31731000E+00, -.32974200E+00, 0.48294200E+00, -.44115500E+00, 0.14951800E+01, -.35326400E+01, -.12625800E-01, 0.18992400E+01, -.10554500E+01, -.83906000E+00, -.66057700E+00, 0.95388900E+00, -.26542800E+00, -.69453500E-01, -.12358000E+01, 0.27373100E+00, -.49007200E+00, -.83909900E+00, -.19306500E+00, -.22209600E+01, -.95068900E-01, 0.76711900E+00, -.18905500E+01, 0.65991400E+00, -.77423700E+00, -.22161300E+05, 0.11110100E+05, 0.12691300E+05, 0.48845000E+04, 0.76010900E+04, 0.38628800E+04, 0.91666500E+04, 0.48707000E+04, 0.77573800E+04, -.12070300E+05, 0.60529400E+04, 0.28378100E+04, 0.72753100E+03, 0.10414400E+04, 0.36586600E+04, 0.95032700E+04, -.46431400E+04, 0.42500200E+03, -.89179000E+03, 0.40807100E+03, 0.45232900E+03, -.68809900E+03, 0.11402400E+03, 0.89641000E+03, 0.10906100E+04, 0.21162600E+03, 0.93633200E+03, 0.52905600E+03, -.27929000E+03, -.16090200E+03, 0.25704000E+04, 0.29466500E+04, -.22740200E+04, -.38637700E+03, -.16485400E+03, 0.28361200E+04, 0.33921800E+04, -.17131800E+04, -.75912400E+04, 0.33078500E+04, 0.21874100E+04, -.48061400E+04, -.14350400E+04, -.80889700E+04, 0.16590000E+04, -.17867800E+05, 0.89433200E+04, 0.81304300E+04, -.12578100E+04, -.59294300E+03, 0.76839100E+04, 0.17242300E+05, 0.87891100E+03, 0.34574100E+03, -.25221100E+05, 0.12528900E+05, 0.10457600E+05, 0.43694500E+04, 0.84484200E+04, 0.50659100E+04, 0.95078800E+04, 0.46381600E+04, 0.62230600E+04, 0.13646400E+05, -.68723000E+04, -.29129900E+04, -.23735600E+04, -.32175800E+04, -.31782500E+04, -.10526600E+05, 0.64401400E+04, -.42077900E+04, -.13231700E+05, 0.65874500E+04, 0.77196000E+04, 0.15297200E+04, 0.30798500E+04, 0.25182500E+04, -.17261600E+04, 0.99105700E+04, 0.35227400E+04, -.10015400E+05, 0.50216000E+04, 0.48688100E+04, -.27104500E+03, 0.12829600E+03, 0.44469900E+04, 0.74199700E+04, -.43654300E+04, 0.11230000E+04, 0.64210100E+04, -.32163000E+04, -.39006400E+04, -.28066500E+04, -.49026100E+04, 0.77033400E+03, -.34601800E+04, -.94935700E+03, -.38099800E+04, 0.90131200E+03, -.50363800E+03, -.46094300E+03, -.83083800E+03, -.99741300E+03, 0.98078300E+03, 0.23343100E+04, -.33916300E+03, 0.17036400E+04, 0.68954000E+03, -.37508100E+03, 0.85260000E+03, 0.24247000E+04, 0.31905700E+04, 0.38174100E+02, -.33510200E+04, 0.83908500E+04, 0.20365100E+04, -.25833600E+04, 0.12826200E+04, 0.29879500E+04, -.33880300E+02, 0.62661700E+03, 0.41109100E+03, -.25000400E+04, 0.34823700E+04, 0.98267600E+02, 0.28821500E+04, -.14568400E+04, -.10790100E+04, 0.40479600E+03, 0.22398300E+03, -.15156500E+04, -.45581500E+03, 0.64814100E+03, 0.49354500E+03, 0.61693400E+04, -.30775300E+04, -.51790500E+04, 0.10639600E+03, -.91738200E+03, -.16350800E+04, -.30100700E+04, 0.89547300E+03, -.11002100E+04, -.21527400E+02, 0.61795400E+02, -.11928700E+04, -.20839200E+04, -.31269700E+04, -.20255300E+04, 0.12245500E+04, -.12211000E+05, -.65421000E+03, 0.15900100E+04, -.64484700E+03, -.13828200E+04, 0.44316400E+03, 0.10173800E+04, -.53905200E+03, 0.11310100E+04, 0.51111400E+03, 0.35782800E+03, 0.27643100E+04, -.42877100E+04, -.17882000E+04, 0.27933400E+04, 0.11834600E+04, 0.37850200E+04, 0.32289500E+02, -.49962300E+03, 0.28679300E+04, -.67902100E+04, 0.96494300E+04, -.24580500E+04, 0.32329600E+04, 0.50530500E+04, 0.31164400E+04, 0.97687700E+03, 0.20037000E+04, -.26322500E+04, 0.28999200E+04, 0.90586900E+04, -.12933700E+04, 0.12996800E+04, 0.43947900E+04, 0.43402900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21572700E+01, 0.45450400E+00, 0.79502000E+00, -.15930000E+01, -.14691100E+01, 0.21315600E+01, -.33432800E+01, -.73150400E+00, 0.20446300E+01, -.12163800E+01, -.64221900E+00, -.19734100E+00, -.95589200E+00, -.26702300E+01, 0.41620600E-01, 0.10180700E+01, 0.98990200E+00, -.13139300E+01, 0.14154500E+01, -.36227100E+01, 0.49240100E+00, -.18619200E+01, -.61990400E+00, 0.71234900E-01, 0.14985100E+01, -.37729900E+01, -.90894700E+00, 0.35726100E+01, 0.13226200E+01, -.14787100E+01, -.12095000E+01, -.12261100E+01, 0.10232500E+01, 0.31573900E+00, 0.16581000E+00, 0.16105200E+01, 0.35626500E+01, -.62252000E+01, 0.25416000E+01, -.20893300E+01, 0.11544100E+00, -.36332400E+01, 0.15191700E+01, 0.66188000E+00, -.24923600E+01, 0.86665600E+00, 0.24267300E+03, -.12339900E+04, -.70806400E+04, -.53072300E+03, 0.20288300E+04, -.20463100E+04, 0.19728900E+05, -.96043300E+04, 0.28571600E+05, -.14091100E+05, -.91162500E+04, -.49846900E+04, -.10194600E+05, 0.95667100E+04, -.16104800E+04, 0.34383200E+04, -.99859300E+04, 0.15794300E+05, -.77418100E+04, -.78914700E+04, 0.54386300E+02, 0.14328400E+04, -.72484900E+04, -.36853300E+04, -.16568300E+04, 0.34763700E+04, -.11879300E+05, 0.58875600E+04, 0.73605900E+04, -.23156400E+04, -.40738600E+04, 0.70952400E+04, 0.17629000E+04, 0.15957600E+05, -.11498100E+01, -.16548000E+04, 0.72265500E+03, 0.33333700E+04, -.12034200E+04, -.75444300E+04, 0.95812800E+04, 0.56733300E+03, 0.12141100E+05, -.59424100E+03, 0.14230400E+05, -.70339600E+04, -.70371800E+04, 0.67561800E+03, 0.16518400E+04, -.95358500E+03, -.12807500E+05, -.95838600E+04, -.27080100E+04, 0.18907400E+05, -.94509100E+04, -.50019400E+04, -.97204600E+04, -.11493000E+05, 0.10599000E+05, -.56367100E+04, 0.73156100E+04, -.12959700E+05, -.36222300E+05, 0.17983100E+05, 0.11379600E+05, 0.13912100E+05, 0.10695000E+05, -.13199900E+05, -.49202500E+04, -.15207500E+05, 0.19499100E+05, 0.87075400E+04, -.44478500E+04, -.94824800E+04, 0.52805800E+04, 0.42542300E+04, -.16967900E+05, -.30490400E+04, -.11693500E+05, 0.74110100E+04, 0.16563000E+05, -.81613600E+04, -.79755000E+04, -.17342700E+04, 0.22405400E+04, -.34730000E+04, -.19687700E+04, 0.15099400E+05, -.41514000E+04, 0.92428600E+04, -.46432500E+04, -.36780400E+04, 0.48185400E+04, 0.61593800E+03, -.53573300E+04, -.55236200E+03, -.18809600E+05, 0.88585800E+04, 0.23901000E+03, 0.18380000E+03, 0.19702900E+03, -.56997800E+04, 0.67591200E+04, 0.13788400E+03, 0.33428800E+04, 0.11416300E+05, -.40041600E+04, -.10451300E+05, 0.51481600E+04, 0.45945600E+04, -.94054800E+03, -.30989100E+04, 0.17986200E+04, 0.73887300E+04, 0.14085400E+04, -.23366500E+04, 0.65180600E+04, -.31602400E+04, -.31037400E+04, -.19342500E+04, 0.22215700E+04, -.61909000E+03, 0.43729600E+04, -.64769400E+04, -.56404500E+04, 0.11314100E+04, -.74293000E+03, -.11606500E+04, -.70501100E+03, -.13098100E+04, -.44018200E+03, -.65599100E+03, 0.32259500E+04, -.11909400E+04, 0.81929500E+04, -.40241200E+04, -.10648900E+04, -.19787500E+04, -.35837100E+04, 0.41117300E+04, -.12248000E+04, -.11489500E+05, -.34530000E+04, 0.21405200E+05, -.10573700E+05, -.12679300E+05, 0.16343300E+04, 0.48179300E+04, -.10923500E+05, -.65216300E+04, 0.11010800E+04, 0.32945800E+04, -.25381100E+05, 0.13131000E+05, 0.12323500E+05, -.46066000E+04, 0.59326400E+04, 0.93323800E+04, 0.72899700E+04, 0.14754200E+05, -.37067600E+04, -.68380100E+04, -.35246000E+04, 0.79422200E+04, -.82018000E+04, -.73542300E+04, 0.23340600E+04, -.66922800E+04, -.89710100E+03, -.62190100E+04, -.33456400E+04, -.76947100E+04, -.65142200E+04, 0.17803600E+04, -.72709300E+04, -.47028900E+04, -.12926300E+05, -.69161000E+04, 0.67102100E+04, -.47691500E+04, -.35702000E+04, 0.74451700E+04, -.82095900E+04, -.78275300E+04, 0.56162200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23635800E+01, -.10260900E+01, -.20136400E+00, -.10600600E+01, 0.13193800E+00, 0.10862900E+01, -.86174400E+00, -.15800300E+00, 0.28852000E+00, -.16341600E+00, -.40863300E+00, -.12752100E+00, -.17393000E+00, 0.44814500E+00, -.77637100E+00, 0.62602800E+00, 0.24361800E-02, -.39155000E+00, 0.11956600E+01, 0.25438800E+01, -.23608600E+00, 0.42491200E+00, 0.11170600E+00, -.74666300E+00, 0.52605500E-02, -.43157200E-01, -.96034900E+00, -.21607300E+00, 0.44461100E+00, 0.10417300E+00, -.13847900E+00, -.69585500E+00, -.27388800E+00, 0.14422000E+00, -.16132800E+00, -.88241500E-01, 0.80570300E+00, -.43964000E+01, -.10188200E+01, 0.16377900E+01, -.28847700E+00, 0.92340900E+00, 0.33982700E+00, -.12913000E+00, 0.59397900E+00, -.39438300E+00, 0.16689700E-01, 0.13870600E+04, 0.68342700E+03, -.23548400E+03, 0.90743000E+02, 0.71456200E+03, -.19561700E+04, 0.63842000E+03, -.79793000E+03, 0.38057000E+03, -.27714400E+04, 0.80064700E+03, 0.95187200E+03, -.45872100E+04, -.29242000E+04, -.24897800E+04, 0.10074600E+04, 0.38997600E+04, -.20223500E+04, -.19469500E+04, 0.26831000E+04, 0.25529200E+04, -.22028400E+04, -.34391000E+04, -.21205300E+04, 0.12623000E+04, -.43793800E+04, 0.21746100E+04, 0.20559900E+04, 0.16724000E+04, 0.28752000E+04, -.10030500E+04, -.35155500E+04, -.24932000E+04, 0.24324400E+04, 0.35993100E+04, -.18141000E+04, -.57647400E+04, 0.27058900E+04, 0.38400400E+04, -.58030800E+04, -.42726800E+04, -.53876200E+04, 0.20862200E+04, 0.35939300E+04, -.17823900E+04, -.25153900E+04, -.14556400E+04, -.32679200E+04, -.44678200E+03, 0.19444100E+04, 0.31012400E+04, -.23683900E+04, -.52591800E+04, 0.25984600E+04, 0.47148500E+03, 0.33794900E+04, 0.54578200E+04, -.25555900E+04, 0.75801800E+03, -.94550300E+02, 0.37678200E+04, -.30260100E+03, 0.14127600E+03, 0.42146000E+04, -.39120800E+04, -.33541000E+04, 0.68233600E+04, 0.54284900E+04, 0.57548700E+04, -.43099900E+04, 0.43782700E+04, -.21584700E+04, -.52626700E+02, -.95108400E+03, 0.75769700E+03, 0.10717400E+04, -.61252500E+01, 0.18975400E+03, -.21589400E+04, -.19233000E+04, 0.95762300E+03, 0.66359600E+03, 0.28534200E+03, -.10162300E+04, 0.86574300E+03, 0.22975200E+03, -.17196800E+04, 0.20752100E+03, -.36718800E+04, 0.17711800E+04, 0.12997000E+04, 0.23323200E+03, 0.55770700E+02, 0.12803800E+04, 0.13198100E+03, 0.24393400E+04, -.69403700E+03, -.27396600E+04, 0.12162300E+04, 0.12851100E+04, 0.32402200E+04, 0.95478100E+03, 0.41728000E+03, -.20881400E+04, 0.62057300E+03, 0.33717900E+04, 0.41744900E+04, -.20943400E+04, -.10779100E+04, 0.10477500E+04, 0.23400400E+04, -.10514000E+04, -.22277600E+04, -.13634500E+04, 0.21043400E+04, -.90134600E+04, 0.44950100E+04, 0.54090100E+04, -.29878000E+04, -.16911700E+04, 0.40075400E+04, 0.36515500E+04, 0.50102100E+04, -.16622900E+03, 0.32524700E+04, -.15660100E+04, -.13879900E+04, -.15269100E+02, 0.19731000E+03, -.13058300E+04, -.85613200E+03, -.12478000E+04, 0.46278800E+03, -.89569700E+04, 0.44517900E+04, 0.23196100E+04, 0.13225900E+04, 0.10655000E+04, 0.95336000E+03, 0.10677100E+04, 0.41223000E+04, 0.31801300E+04, -.70655900E+04, 0.35373900E+04, 0.31103400E+04, -.15521100E+04, -.45119900E+04, 0.34059600E+04, 0.27074700E+04, 0.11258900E+04, -.33169700E+04, -.63946200E+04, 0.31661300E+04, 0.29825200E+04, 0.48245700E+03, -.43089900E+03, 0.19211800E+04, -.11191300E+04, 0.11961400E+04, 0.42627700E+03, -.16871200E+03, 0.18355600E+04, -.16043300E+04, 0.12472700E+04, 0.15623900E+04, -.12564700E+04, 0.15493400E+04, -.29619200E+03, 0.39689600E+04, 0.37291100E+03, -.17140600E+04, 0.19656100E+04, -.23747700E+03, 0.15495700E+04, -.85391000E+02, 0.27426900E+04, 0.10977400E+04, -.21601900E+04, 0.95922200E+03, -.14279000E+04, -.15511600E+04, 0.17167900E+04, 0.21468900E+04, -.18601600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18111600E+01, 0.44892200E+00, 0.36169000E+00, 0.11206400E+00, 0.77988300E+00, 0.20499700E+00, -.45207800E+00, 0.40964100E-01, -.37986500E+00, 0.16398800E+00, -.64059200E+00, 0.28426400E+00, 0.22953400E+00, -.14959400E-01, 0.27831000E+00, -.39745000E+00, -.22342100E+00, 0.20318300E+00, 0.32317100E+00, -.22756900E+00, -.95214200E-02, -.32099000E+00, 0.47815800E+00, -.37550400E-01, 0.12260500E-01, 0.72021900E+00, -.94855600E+00, -.73483200E+00, -.11597400E+01, 0.27260700E+00, -.68480300E-01, -.44747600E-01, 0.18486500E+00, 0.13964400E+00, 0.26112200E+00, -.67489900E+00, 0.44820700E-01, -.47847900E+00, -.73427300E+00, 0.13826300E+01, -.12979300E+00, 0.62725300E+00, 0.37897000E+00, 0.26291000E+00, 0.88886100E+00, -.27697000E+00, -.97535300E-01, 0.21756000E+00, 0.63148900E+03, -.68809400E+02, -.21264300E+03, 0.42825600E+03, 0.10784400E+04, 0.17265400E+03, 0.61441900E+03, -.30041200E+03, -.16992400E+03, 0.39478800E+02, -.55163300E+03, 0.16487600E+03, 0.30303600E+03, -.58403700E+03, -.58501500E+03, -.21990400E+04, 0.11279600E+04, 0.10988200E+04, -.29214200E+03, 0.29719900E+03, 0.76747800E+03, 0.30012600E+02, 0.39538600E+03, 0.43543400E+03, 0.94332100E+03, -.47310500E+03, -.41416500E+03, 0.37557000E+03, 0.33686000E+03, -.54146800E+03, -.36920700E+03, -.17147200E+04, 0.19463500E+03, 0.24921600E+04, -.12445800E+04, -.12357200E+04, -.44102500E+02, 0.29628900E+03, -.98688300E+03, -.45979500E+03, -.20166400E+04, -.30509700E+03, -.42401800E+03, 0.21569100E+03, 0.16508500E+03, -.17974900E+03, -.47185800E+03, 0.39535600E+03, 0.46647900E+03, 0.13012200E+04, -.33570100E+03, 0.23586600E+03, -.89452600E+02, 0.50573900E+01, 0.28533500E+03, 0.18668700E+04, -.51659200E+03, 0.25277400E+03, -.17542800E+03, 0.12264000E+04, -.87276200E+03, 0.45423900E+03, 0.27962500E+03, -.86202100E+02, -.31122900E+03, -.24401900E+02, -.21409900E+03, 0.13767000E+04, -.78588400E+02, -.77834000E+03, 0.39059600E+03, 0.28184700E+03, 0.24949900E+03, 0.21133000E+03, -.24547300E+03, -.48112800E+03, 0.30223400E+03, 0.30212100E+03, -.23327600E+04, 0.11667600E+04, 0.12064100E+04, 0.25269700E+03, 0.32685300E+03, 0.62174000E+03, -.31694700E+03, -.14369700E+04, 0.47720200E+03, -.30706400E+04, 0.15264800E+04, 0.16974400E+04, -.51333700E+03, -.49928400E+03, 0.16114900E+04, 0.10931600E+04, 0.14262500E+03, -.30436500E+03, -.16055600E+04, 0.84817600E+03, 0.80650600E+03, -.14816300E+03, 0.45584600E+03, 0.52450900E+03, -.25478200E+03, -.15099000E+03, 0.83467500E+03, 0.26460900E+04, -.13118700E+04, -.13850000E+04, 0.33284800E+03, 0.79410200E+03, -.10684400E+04, -.86460900E+03, 0.13118300E+04, 0.28383000E+03, -.27553800E+03, 0.14428800E+03, 0.27724500E+03, 0.53617900E+03, 0.52650400E+02, -.10817700E+03, -.42506800E+03, 0.50240300E+03, 0.26389000E+03, 0.89678000E+03, -.43703700E+03, -.53473700E+03, 0.28778200E+02, 0.15407400E+02, -.29799600E+03, -.10049800E+03, 0.98075700E+01, -.62383100E+02, -.49514100E+03, 0.24748800E+03, 0.27833500E+03, -.37085400E+02, 0.24163900E+03, 0.64651800E+03, 0.66300400E+03, 0.11477900E+04, 0.23521600E+01, -.50473500E+04, 0.25003600E+04, 0.24648000E+04, -.45056300E+03, -.19008300E+04, 0.19458000E+04, 0.12346100E+04, -.83864100E+03, -.78351200E+03, 0.12471800E+04, -.63971200E+03, -.79753800E+03, 0.16360400E+03, -.24523700E+03, -.51142700E+03, -.39625300E+03, -.95054900E+03, 0.68850900E+02, -.51688200E+03, 0.18032900E+03, -.24682100E+02, 0.28507500E+02, -.58834600E+03, -.11681800E+03, 0.35243900E+03, -.38776800E+03, 0.29776900E+03, -.30558000E+03, 0.41289600E+03, 0.72373900E+01, 0.29749500E+03, 0.43683900E+03, 0.41617900E+03, 0.33748900E+03, 0.40627800E+03, -.15477900E+03, -.21968000E+02, 0.10987000E+03, 0.57803900E+03, 0.20703300E+03, 0.49850700E+03, -.24773900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13931400E+01, 0.70909800E+00, 0.48585500E+00, 0.93403200E+00, 0.56593800E+00, -.17143000E+00, 0.11681500E-01, 0.60757700E-01, -.97021900E+00, 0.60867700E+00, -.68681800E+00, -.78767100E-01, 0.82526400E-01, -.10542600E+01, 0.15921800E+01, -.10343800E+01, 0.58859800E-01, 0.31752200E+00, -.11125900E+01, -.54068900E+00, 0.52522600E+00, 0.16044700E-01, -.36154300E+00, 0.12119000E+00, 0.50834400E+00, 0.43690100E+00, 0.39168700E+00, -.37588700E+00, -.24253300E+00, 0.23362900E+00, -.26626500E+00, 0.70080900E+00, 0.25232500E+00, -.35422000E-01, -.19214900E+00, -.62236600E+00, -.43190200E+00, 0.12595400E+01, -.48444900E+00, -.20185800E+00, 0.85767100E-01, 0.15402500E+00, -.74058700E+00, 0.35435200E+00, 0.68001400E-01, 0.10898400E-01, -.98031200E-01, -.13973800E+00, 0.73980400E+00, 0.92414200E+03, -.44521600E+03, 0.38809700E+03, 0.67425400E+03, 0.27538100E+03, -.53912900E+03, 0.26863400E+03, 0.50766300E+03, -.15818800E+03, 0.17061200E+03, 0.10034800E+04, 0.10168000E+04, -.84245500E+03, -.13408700E+03, -.18182900E+04, 0.85647300E+03, 0.91002000E+03, -.91146600E+03, -.94903300E+02, 0.95690800E+03, 0.13485800E+04, 0.82406100E+03, 0.43585700E+03, 0.15767400E+04, -.78315500E+03, -.65726700E+03, -.38138600E+03, -.40881400E+03, -.27890400E+03, 0.54414100E+03, 0.78403200E+02, -.30083800E+03, 0.33180700E+04, -.16427400E+04, -.15838400E+04, -.87393900E+02, -.34622100E+03, -.10244600E+04, -.38941000E+03, -.23386100E+04, -.27195700E+03, -.24484400E+04, 0.12194600E+04, 0.11838300E+04, 0.35127700E+03, 0.62266200E+03, 0.88354500E+03, 0.80185800E+03, -.72577300E+03, 0.51480700E+03, -.22762200E+04, 0.11021900E+04, 0.14228900E+04, -.14288800E+03, 0.78128500E+02, 0.93515300E+03, 0.69379300E+03, 0.87099100E+03, -.64291600E+02, 0.90081200E+03, -.47907000E+03, -.73847200E+03, 0.73106500E+03, 0.23422300E+03, -.13899900E+04, -.20119100E+04, 0.31233700E+03, 0.25801100E+03, -.11039400E+04, 0.54545300E+03, 0.32683200E+03, 0.43527600E+03, 0.86564000E+03, -.84776900E+03, -.12214200E+04, 0.96871500E+03, 0.10186500E+04, 0.41584100E+03, -.20927500E+03, -.27824300E+03, -.42142500E+03, -.53779600E+02, 0.16628300E+03, 0.65665300E+03, -.68770500E+03, -.22269900E+03, 0.24214200E+04, -.11958600E+04, -.13005100E+04, -.10088000E+03, -.39236000E+03, -.10770300E+04, -.17654900E+04, -.24380700E+04, 0.91570400E+02, -.24123700E+04, 0.11348500E+04, 0.12274000E+04, -.12621400E+04, -.23345000E+03, 0.13330800E+04, 0.18954100E+04, 0.10959900E+04, 0.20312200E+03, -.18035000E+04, 0.88729000E+03, 0.10298900E+04, -.18007400E+03, -.41418200E+03, 0.65260400E+03, 0.13510600E+03, 0.32971600E+04, -.28761100E+03, -.26547100E+04, 0.13113100E+04, 0.11840300E+04, 0.37366500E+03, 0.49629700E+03, 0.10333900E+04, 0.43296100E+03, 0.18571000E+04, 0.12889200E+03, -.13214500E+04, 0.63511400E+03, 0.70082800E+03, 0.27477300E+03, 0.37000900E+03, 0.24729500E+03, 0.10196000E+03, 0.53882100E+03, 0.45793500E+03, 0.62485000E+03, -.31084800E+03, -.21624200E+03, 0.45750500E+02, -.18342800E+03, 0.17966500E+03, -.22907200E+03, -.28238400E+03, -.17758000E+03, 0.21975100E+04, -.10750600E+04, -.13572000E+04, 0.12393300E+03, 0.18975600E+03, -.95601500E+03, -.96588600E+02, -.32582600E+04, 0.30289500E+03, 0.10330400E+04, -.50364400E+03, -.36771700E+03, -.71231300E+02, 0.31415200E+03, -.34102000E+03, 0.24688800E+03, -.18103600E+03, -.18688300E+03, -.15412600E+03, -.21900700E+03, 0.24994100E+02, -.13657000E+03, -.36510600E+02, 0.42102500E+03, -.68624500E+02, -.17697600E+03, -.27952700E+03, -.55564500E+03, 0.11823500E+04, -.34186100E+03, 0.21683900E+03, 0.34447400E+03, 0.32883100E+03, -.13338200E+03, 0.37433300E+02, 0.23102600E+03, 0.29187800E+02, 0.82955500E+03, 0.80776100E+01, -.63530800E+02, 0.61558100E+02, 0.29430600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12771200E+01, 0.15411500E+00, -.52646900E+00, 0.23546400E+01, -.34305000E+00, -.30162700E+01, 0.37808100E+01, 0.11366100E+01, -.65361400E+00, 0.85329100E+00, -.44312600E-01, -.10583400E+00, 0.54920300E-01, 0.13724300E+01, 0.65856900E+00, 0.10160400E+01, 0.39349600E+00, -.29115800E+00, -.14911700E+01, -.62409900E+00, -.10124000E+01, -.53682800E+00, -.93554200E-01, 0.67054200E+00, -.12279200E+01, 0.19527900E+01, -.17822900E+00, -.74018700E+00, -.50015800E+00, 0.60667500E+00, 0.38042300E-01, -.72044100E+00, -.51074200E+00, 0.94269200E-02, -.49537700E+00, 0.36922000E+00, 0.15008800E+01, 0.16313800E+01, 0.13253400E+01, -.67994000E+00, 0.85015500E-01, -.20333600E+01, 0.28837400E+01, 0.30452300E+00, 0.70917600E+00, -.56061900E+00, 0.20503000E+00, 0.21449800E+00, 0.17735500E+00, 0.19564600E+01, -.16641300E+04, 0.25059600E+04, 0.84932200E+03, 0.16111000E+03, 0.12269600E+05, -.60274500E+04, -.53661100E+04, -.48224700E+04, -.53756300E+04, 0.83763200E+04, 0.53454600E+04, -.11683100E+04, -.63635000E+04, 0.10386300E+05, -.49657400E+04, -.51903600E+04, 0.29003100E+04, -.96233700E+03, -.50001100E+04, -.55209600E+04, -.51893400E+04, -.24365600E+04, 0.71548600E+04, -.35834600E+04, -.30959900E+04, -.21967000E+04, -.55307800E+04, 0.18639000E+04, 0.38619900E+04, 0.70102800E+04, -.44519500E+04, 0.63539800E+03, -.32684600E+03, -.22135400E+04, -.46758300E+04, -.34382400E+04, 0.67511100E+04, 0.42501800E+04, 0.57857200E+04, -.36851100E+04, -.96267400E+04, 0.48460800E+04, 0.47179900E+04, 0.12801200E+04, 0.52247900E+04, 0.37281500E+04, -.27057100E+04, -.64930700E+04, 0.31880500E+04, 0.15264700E+05, -.73973200E+04, -.70673600E+04, -.42067300E+04, -.43601000E+04, 0.46717700E+04, 0.30068600E+04, -.28990300E+04, -.64746100E+04, -.17317500E+05, 0.86890700E+04, 0.74089200E+04, 0.69004900E+04, 0.79157900E+04, -.10668200E+05, -.75954200E+04, -.84404600E+03, 0.10945800E+05, -.96595400E+04, 0.47912900E+04, 0.29727500E+04, 0.44105900E+04, 0.26237600E+04, -.68141200E+04, -.11513100E+04, -.60067000E+02, 0.56480700E+04, 0.29922100E+04, -.14693700E+04, -.11173900E+04, 0.29025400E+03, 0.11202000E+04, -.28129000E+03, 0.61405000E+03, -.19053300E+03, -.47922500E+03, -.15393700E+04, 0.76308400E+03, 0.12225300E+04, 0.46712600E+02, 0.79792000E+03, 0.31858400E+04, 0.16340600E+04, 0.33977200E+04, -.46476400E+03, 0.21751200E+05, -.10519700E+05, -.10769300E+05, 0.34517800E+04, 0.18630400E+04, -.94144100E+04, -.89056700E+04, -.10283800E+05, -.29683000E+04, -.48808700E+04, 0.25219800E+04, 0.22100200E+04, -.44482500E+03, 0.15733600E+04, -.48293800E+03, 0.69890700E+02, -.33463800E+04, 0.10946600E+04, 0.37235200E+04, -.18479500E+04, -.53313800E+03, 0.10899900E+04, -.73148600E+03, -.22234400E+04, -.15481100E+04, -.40040500E+04, 0.61393500E+03, 0.47475700E+04, -.22795400E+04, -.25837700E+04, -.99423200E+03, -.14764900E+04, -.16425200E+04, 0.62955400E+03, -.70605200E+03, -.14667400E+04, 0.58453700E+04, -.28882500E+04, -.23800500E+04, -.31809700E+04, -.24463300E+04, 0.43727800E+04, 0.17509500E+04, -.58886700E+03, -.43944900E+04, 0.17527700E+04, -.10308100E+04, -.18239800E+04, 0.34743900E+04, 0.21060100E+04, -.50375700E+04, -.36480400E+04, 0.25613200E+04, 0.30333900E+04, 0.25027000E+04, -.14032100E+04, -.22425600E+04, -.11242200E+04, -.16505000E+04, -.40850800E+03, 0.19276200E+04, 0.33257700E+04, -.10159300E+04, -.31204500E+04, -.66117100E+04, 0.35398900E+04, -.44080100E+04, -.25736900E+04, 0.35794400E+04, -.36342000E+04, -.93089000E+03, -.64471400E+04, -.30186300E+04, 0.32219900E+04, -.45894700E+04, 0.24852800E+04, -.16401200E+03, 0.77182300E+03, -.39180000E+04, -.39209600E+04, 0.48959000E+04, -.29957600E+04, 0.38690100E+04, 0.26993500E+04, -.31202800E+04, -.33433500E+04, 0.62769600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11216800E+01, 0.67225200E+00, 0.16858000E+00, 0.14090200E+01, -.54389000E+00, -.83201100E+00, -.68366600E+00, 0.11847600E+00, 0.44704400E-01, 0.43748600E-01, -.48984000E-02, -.81417500E-01, 0.33930900E-01, -.41532600E+00, -.19655500E+00, -.34318700E+00, -.18600100E+00, -.50761000E+00, 0.50833300E+00, 0.25742500E+00, 0.24131900E+00, -.51691800E-01, -.44804800E+00, -.35405800E+00, 0.24705400E+00, -.15071800E+00, -.21671500E+00, -.28132600E+00, -.49887000E+00, -.18802200E+00, 0.89333900E-01, 0.54326000E+00, -.48472300E-01, -.15228900E+00, -.98847600E-01, 0.16484300E+00, 0.31444400E+00, -.12832400E+00, -.37680600E+00, -.32677900E+00, -.16361900E+00, 0.64072400E+00, -.55605600E+00, -.10567600E+00, -.31168600E-01, 0.13133400E+00, -.84400100E-01, 0.26686900E-01, 0.15973700E+00, -.42536500E+00, -.10286700E-01, -.14594900E+04, 0.65437500E+03, 0.19037500E+03, -.76665900E+03, 0.36999800E+03, 0.11167100E+03, 0.43388300E+03, 0.62288600E+03, -.10983000E+04, -.97371800E+03, 0.80214800E+02, 0.22664800E+03, -.36816100E+03, 0.14630600E+03, 0.18394500E+03, -.11473800E+03, 0.11450000E+02, 0.18921900E+03, 0.31895500E+03, 0.35720000E+03, 0.30202800E+03, -.17364100E+03, 0.90339600E+02, -.29957400E+02, 0.16156200E+03, 0.63799600E+03, -.48288700E+03, -.31924600E+03, 0.71610500E+02, 0.49575000E+03, 0.88989100E+03, -.43767900E+03, -.23026400E+03, 0.49370900E+03, 0.13348000E+04, -.15194000E+04, -.91362400E+03, -.13337500E+04, 0.79776600E+03, 0.31660800E+04, -.15873800E+04, -.15353700E+04, -.32576400E+03, -.13606300E+04, -.64395800E+03, -.30811400E+03, -.13830100E+03, -.10782600E+04, -.21899800E+04, 0.10540100E+04, 0.85704400E+03, 0.45669600E+03, 0.36886200E+03, -.50241000E+03, -.10056600E+04, 0.10627800E+04, 0.25903500E+03, 0.84589900E+03, -.43557100E+03, -.69637300E+02, -.82329200E+03, -.39788300E+03, 0.17845900E+04, 0.16399100E+04, -.12985600E+03, -.13478800E+04, 0.16290700E+04, -.81173900E+03, -.39313400E+03, -.79867100E+03, -.58064100E+03, 0.76380300E+03, 0.99763700E+02, 0.16745300E+03, -.91987200E+03, 0.54708100E+02, -.31775900E+02, -.11210000E+03, -.10786000E+03, -.41462800E+03, -.31560100E+02, -.31887900E+03, 0.55602700E+03, 0.75747800E+01, 0.99786900E+03, -.48513400E+03, -.66464200E+03, 0.19492300E+03, 0.37793900E+03, -.83302300E+03, -.15768400E+03, -.17572700E+04, 0.37173200E+03, -.12714400E+04, 0.58221900E+03, 0.61083500E+03, -.48486200E+02, -.47036600E+03, 0.37615400E+03, 0.35936700E+03, 0.80356700E+03, 0.92499700E+03, -.11437100E+03, 0.46870300E+02, 0.12259700E+03, -.26298800E+03, -.27669300E+03, 0.31726600E+03, 0.58716700E+03, 0.12578800E+04, -.29227900E+03, -.21594700E+04, 0.10648300E+04, 0.80940700E+03, -.30898000E+03, -.71046200E+03, 0.11639900E+04, 0.95484900E+03, 0.13863400E+04, -.33308300E+03, -.70571100E+03, 0.32793300E+03, 0.44116200E+03, 0.18642400E+03, 0.31061100E+03, 0.13949500E+03, -.21472600E+03, 0.29248300E+03, 0.33612600E+03, -.81424700E+03, 0.40393500E+03, 0.27946000E+03, 0.53894100E+03, 0.59088400E+03, -.61117200E+03, -.18725100E+03, -.48254000E+03, 0.69903600E+03, 0.20914600E+04, -.10204900E+04, -.83512300E+03, -.20005600E+03, -.20749200E+03, -.13610800E+03, -.33346900E+03, -.14216900E+04, -.98288900E+02, -.66125500E+03, 0.35260400E+03, 0.57592500E+03, 0.35923000E+03, 0.25856700E+03, -.79048500E+02, -.58778800E+03, -.20138000E+03, 0.44975100E+03, 0.16976100E+03, 0.13013000E+04, -.22773500E+03, 0.25203800E+03, 0.89200600E+02, -.66139700E+03, 0.61155300E+03, 0.54748300E+02, 0.54345100E+03, 0.48848200E+03, -.67038400E+03, 0.50978900E+03, -.50972700E+03, 0.18117800E+03, -.35341000E+03, 0.41947800E+03, 0.50726300E+03, -.21640000E+03, 0.35766400E+03, -.94040200E+03, -.11558000E+03, 0.19935400E+03, 0.24936500E+03, -.12959500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10674600E+00, 0.14196700E+01, 0.18576200E+00, -.24565100E+00, -.45316900E+00, 0.42630900E+00, -.15878100E+01, -.28487700E+00, -.27847600E+00, -.24923300E+00, 0.66668000E-01, 0.17131700E+00, 0.10553400E+00, -.19619000E+00, 0.42959100E+00, -.15044500E+00, 0.76912100E-01, -.45889900E+00, 0.39634800E+00, 0.25827100E+00, -.30744800E-01, -.19447100E-01, 0.18114100E+00, -.11669200E+00, -.12244800E+00, 0.80524800E+00, -.74928200E+00, -.25328400E+00, -.93551600E+00, -.15652500E-01, 0.54839600E+00, -.13451100E+00, 0.92292800E-01, 0.87657300E-01, -.37226600E+00, -.67181100E-02, 0.74302500E+00, -.11474800E+01, -.32842300E-01, -.43720100E+00, -.63791900E-01, 0.13736200E+00, 0.28105200E+00, 0.57284100E+00, 0.31704200E-01, -.41207700E-01, -.20732400E-01, 0.12460400E+00, -.75913600E+00, 0.40897400E+00, 0.34538600E-02, 0.14317000E+00, 0.26137800E+04, -.40877700E+03, 0.33152000E+04, -.16406700E+04, -.15059700E+04, -.51967000E+03, -.14122100E+04, 0.45527300E+03, -.69003000E+03, -.96241600E+03, -.14666200E+04, 0.31526100E+04, -.15324800E+04, -.15767900E+04, 0.99667900E+03, 0.42096200E+03, -.17959100E+04, -.24288900E+04, -.16836700E+04, 0.17616800E+03, -.81201800E+03, 0.39892600E+03, 0.48337200E+03, 0.30621300E+03, -.26164800E+03, 0.25180700E+03, -.13417500E+03, 0.16610100E+04, 0.26055300E+03, 0.15554500E+04, -.78536500E+03, -.10596400E+04, -.40246700E+03, 0.54823700E+03, -.81415600E+02, -.33471300E+03, -.13723400E+03, 0.11403200E+03, 0.15018000E+04, -.73954900E+03, -.79182100E+03, -.36386500E+03, -.17171800E+03, 0.23676600E+02, -.16982300E+04, -.15996300E+04, -.87031600E+03, 0.21184100E+04, -.10051500E+04, -.96251500E+03, -.39551100E+02, 0.18042900E+04, -.42327000E+02, -.34763300E+03, -.19853000E+02, 0.44343200E+03, -.50910500E+04, 0.25569100E+04, 0.23103400E+04, 0.10768700E+04, 0.11378500E+04, -.50624500E+03, 0.10231400E+03, 0.25852500E+03, 0.20427700E+04, 0.10486600E+04, -.52670800E+03, -.83682400E+03, 0.39456400E+03, 0.26662300E+03, -.14529600E+04, 0.35446900E+03, -.55729800E+03, 0.49798100E+03, 0.50985200E+03, -.24985900E+03, -.12982800E+03, 0.11119000E+03, 0.45161900E+03, -.12005900E+03, -.64281800E+03, -.39103500E+03, -.10487400E+03, -.33165300E+04, 0.16424100E+04, 0.19137400E+04, 0.11307800E+03, 0.82039100E+01, 0.17496000E+04, 0.17396800E+04, -.32659700E+03, 0.43463000E+03, 0.49823100E+04, -.24282900E+04, -.24775600E+04, 0.11120700E+04, 0.12689400E+04, -.25663900E+04, -.30065300E+04, -.22703600E+04, 0.16053300E+03, 0.34802800E+04, -.17191200E+04, -.18877100E+04, 0.42651700E+03, 0.15429900E+04, -.16600700E+04, 0.17604600E+03, -.15754300E+03, 0.72486800E+03, 0.23952600E+03, -.11056600E+03, 0.29344800E+03, 0.16832700E+03, -.86806400E+03, -.19197200E+03, -.16889000E+02, -.42545500E+03, -.53054100E+03, 0.21579600E+04, -.10491400E+04, -.12363600E+04, -.23221500E+03, -.36317000E+03, -.64849500E+03, -.21516100E+03, -.26367400E+02, -.38364200E+03, -.15896900E+04, 0.80071000E+03, 0.87009700E+03, 0.63781400E+02, 0.17296200E+03, 0.12703500E+04, 0.64391700E+03, 0.46318300E+03, 0.41552100E+02, -.25989600E+04, 0.12645700E+04, 0.12072700E+04, -.55528500E+03, -.24763300E+04, 0.10594900E+04, -.18801700E+03, 0.10700900E+03, -.12438800E+04, -.28151200E+04, 0.13671100E+04, 0.10507400E+04, -.32505400E+03, 0.45917800E+01, 0.87886600E+03, 0.17264800E+03, 0.14994200E+04, -.51960300E+02, -.10683100E+04, -.20019000E+03, 0.70617900E+03, -.94408600E+03, -.90910700E+03, -.20397900E+03, -.33007800E+03, -.28375100E+03, -.80983300E+03, -.39377700E+03, -.64252200E+03, -.59020400E+03, 0.32862800E+03, -.68754200E+02, -.43190300E+03, -.65610900E+03, -.52000300E+03, 0.83545700E+03, 0.10197000E+03, -.54348600E+03, 0.93591800E+03, -.60975700E+03, 0.27996000E+03, 0.24052800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24464200E+01, 0.70077300E+00, 0.11659800E+01, -.27044800E+01, 0.13752600E+01, 0.31096100E+01, -.26519700E+01, -.94973400E+00, 0.16582900E+01, 0.65894800E+00, -.10358700E+00, 0.61722000E+00, -.14368800E+00, -.13873800E+01, 0.27044600E+00, -.22476000E+01, -.65775800E+00, 0.13570300E+01, 0.79134000E+00, -.22785900E+01, 0.73432900E-01, -.73244100E+00, -.61841800E+00, 0.19739800E+00, 0.83728700E+00, 0.78641600E+00, -.83566800E+00, 0.76185200E-01, -.85510400E-01, 0.44182100E+00, -.18001500E+00, -.63198900E+00, -.39334300E+00, 0.23749200E-01, -.21154400E+00, 0.17948400E+00, 0.38829200E+00, 0.88926700E+00, -.81931000E+00, -.12800500E+01, -.38252700E+00, 0.34095400E+00, 0.22167800E+00, -.15656100E-02, -.14685900E-01, -.50248300E-01, 0.49241500E-01, 0.53570800E+00, 0.49374300E-01, -.11651400E+01, 0.25060800E+00, 0.46270300E-01, -.15981500E+00, 0.63965900E+03, -.39256900E+04, 0.19440300E+04, 0.16869700E+04, 0.62719500E+03, 0.15729500E+04, 0.33447500E+03, 0.11896900E+04, 0.72886100E+03, 0.12641600E+04, -.57599500E+04, 0.28285700E+04, 0.28806300E+04, -.28068700E+04, -.13480200E+04, 0.31031400E+04, 0.39141500E+04, 0.26140500E+04, -.50929500E+03, 0.18941500E+04, -.93971900E+03, -.11033400E+04, -.54122600E+03, -.56307900E+03, -.21561100E+03, 0.18500900E+04, 0.62128200E+03, -.74970500E+03, -.38525300E+04, 0.19412100E+04, 0.17855900E+04, -.24349500E+03, -.26820800E+04, 0.17860100E+04, 0.17511500E+04, 0.23201800E+04, -.13923900E+04, -.18902600E+04, 0.93334300E+03, 0.10411200E+04, 0.80969900E+03, 0.10391800E+04, 0.79657600E+02, 0.59131200E+03, -.17366100E+04, 0.11797700E+04, -.36043100E+04, 0.17330200E+04, 0.15203100E+04, -.33674000E+03, -.14718600E+04, 0.48715200E+02, -.91822300E+03, 0.65033200E+03, -.70967100E+02, 0.71805400E+04, -.35969500E+04, -.32984300E+04, -.36113600E+03, 0.24266400E+03, -.12383000E+04, -.15217100E+04, -.21155000E+04, -.13015400E+04, -.29938800E+04, 0.14954800E+04, 0.15793700E+04, -.33525400E+03, -.44494900E+03, 0.15644500E+04, -.11064700E+03, 0.15447100E+04, 0.56947300E+03, 0.78315100E+03, -.39385600E+03, -.38452300E+03, -.45801000E+03, -.42897900E+03, -.29999400E+03, 0.45450800E+03, -.35065600E+03, -.11325000E+03, 0.35382400E+04, -.17293100E+04, -.20028200E+04, -.28768800E+03, 0.18730100E+03, -.18579100E+04, -.18764000E+04, -.21097300E+04, -.25645700E+03, -.11800900E+04, 0.54957300E+03, 0.58804300E+03, -.24044800E+04, -.16530700E+04, 0.10735400E+04, 0.24643800E+04, 0.18342500E+03, -.50699500E+03, -.61314100E+04, 0.30438900E+04, 0.31095200E+04, -.22811700E+03, -.18721800E+04, 0.23014200E+04, 0.86488300E+03, 0.38510300E+04, -.11243900E+04, 0.40655800E+04, -.20387600E+04, -.20830600E+04, 0.20067400E+04, 0.23691700E+04, -.23136700E+04, -.26693000E+04, -.22408600E+04, 0.16569500E+04, -.31582300E+04, 0.15334400E+04, 0.16889600E+04, 0.33813000E+03, 0.24436800E+03, 0.99258800E+03, 0.59223400E+03, 0.84052900E+03, 0.40354100E+03, 0.27605000E+04, -.13844300E+04, -.14344400E+04, 0.44261400E+03, 0.46214400E+03, -.21552800E+04, -.17356100E+04, -.21243500E+04, -.12257900E+03, 0.78556100E+04, -.38842800E+04, -.37823800E+04, -.57257800E+02, 0.20110300E+04, -.19738400E+04, 0.80016400E+02, -.33596000E+04, 0.97340200E+03, 0.72166300E+04, -.35725600E+04, -.34609100E+04, 0.40042700E+02, -.38354800E+03, -.22497700E+04, 0.22942700E+02, -.20948200E+04, -.69452500E+02, 0.12010200E+04, -.52627400E+03, -.33014100E+03, 0.51544100E+03, 0.66863300E+03, 0.17045200E+03, 0.15612800E+03, 0.25429900E+03, -.11633000E+04, 0.81497600E+03, 0.16627100E+04, 0.18873800E+03, -.53805800E+03, 0.19164100E+03, 0.13850800E+03, 0.34608000E+03, 0.45473100E+03, 0.23099100E+03, 0.29022900E+03, 0.12039400E+04, -.71319800E+03, 0.54835100E+02, -.38171600E+03, 0.36400400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.95987800E-01, -.37549600E-01, 0.73244200E-01, 0.14862100E+01, -.71179400E+00, 0.10845700E-01, 0.34207900E+00, -.75132600E-01, -.47780100E-01, -.36263400E+00, 0.57026400E-01, -.31220100E+00, 0.27377900E-01, 0.60301400E-01, -.24354900E+00, 0.22110700E+00, -.18912800E+00, -.49470600E+00, 0.51653600E+00, -.10067700E+01, 0.66936100E-01, -.41985600E+00, 0.22942600E+00, 0.28570500E+00, 0.72448300E-01, -.41165400E+00, -.82256000E-01, -.89386000E-01, -.10551100E+01, -.22443400E+00, 0.35331700E+00, 0.52972300E+00, 0.37333000E+00, -.46550700E-01, -.43339700E-01, -.11567800E+00, 0.16600200E+00, 0.15768600E+01, 0.37851500E-01, 0.23747200E+00, 0.39330800E-02, -.15177100E+00, 0.47756000E+00, -.28753600E+00, 0.15856800E+00, -.25059000E-01, -.83262600E-01, -.20532800E+00, -.42633600E+00, -.77268900E+00, 0.10835300E-01, -.65391900E-01, 0.35477000E+00, -.33293800E+00, -.20473400E+04, 0.10128300E+04, 0.96679500E+03, 0.60542200E+03, 0.87011600E+03, 0.92259800E+01, 0.50303400E+03, 0.39119400E+03, 0.78863300E+03, -.39873600E+04, 0.19388600E+04, 0.19947000E+04, -.18100100E+04, -.46137300E+03, 0.20548500E+04, 0.26049300E+04, 0.20508200E+04, 0.31489000E+03, 0.26079400E+03, -.12617400E+03, -.15781000E+03, -.35128300E+03, 0.72733900E+02, -.35560800E+02, 0.46312200E+03, -.25912000E+03, -.16895000E+03, -.45650900E+03, 0.24310000E+03, 0.34211100E+03, 0.40636900E+03, -.12736800E+04, 0.27771000E+02, 0.31640100E+03, 0.42399800E+02, -.47111300E+03, -.75058900E+03, 0.36877600E+03, 0.39483700E+03, 0.61936300E+03, 0.25420800E+03, 0.59184400E+01, 0.60836500E+03, -.41479900E+03, 0.62498300E+03, -.23310000E+04, 0.11167500E+04, 0.11651400E+04, -.27329900E+03, -.11497300E+04, 0.19342700E+03, -.36947900E+03, 0.75365000E+03, -.81036300E+02, 0.37531600E+04, -.18831300E+04, -.17968900E+04, -.37215500E+03, -.46874000E+03, -.22078600E+03, -.57729600E+03, -.77132300E+03, -.11499500E+04, -.11332800E+04, 0.57186300E+03, 0.63520600E+03, 0.85905900E+01, 0.65561400E+02, 0.53835700E+03, -.64741100E+03, 0.50862900E+03, 0.45898200E+03, 0.68834600E+03, -.34631900E+03, -.43664000E+03, -.31203000E+03, -.44785100E+03, -.11046600E+03, 0.46527900E+03, 0.37234000E+03, -.21455700E+03, 0.21020700E+04, -.10317000E+04, -.12828100E+04, -.85988500E+02, -.21827000E+03, -.12456900E+04, -.13691700E+04, -.15647300E+04, 0.16046800E+03, -.50636000E+04, 0.24712100E+04, 0.25358200E+04, -.21840400E+04, -.84675800E+03, 0.25092800E+04, 0.30673300E+04, 0.25487700E+04, 0.73979400E+02, -.43755800E+04, 0.21719200E+04, 0.23283400E+04, -.17240300E+03, -.12770300E+04, 0.16504300E+04, 0.11097900E+03, 0.27552200E+04, -.65833000E+03, 0.45525100E+03, -.23758200E+03, -.49526300E+03, 0.54670200E+03, 0.14697800E+04, -.32659500E+03, -.63794300E+03, -.10061000E+03, 0.66845200E+03, -.20497100E+04, 0.99203600E+03, 0.11478600E+04, 0.30913000E+03, 0.34041500E+03, 0.56704400E+03, 0.24852600E+03, 0.58239200E+03, 0.34952100E+03, 0.13623500E+04, -.68841200E+03, -.68779300E+03, 0.27023100E+03, 0.25150200E+03, -.11446300E+04, -.10434000E+04, -.12506200E+04, 0.11240100E+03, 0.43918800E+04, -.21681400E+04, -.22233700E+04, -.60244600E+02, 0.12327800E+04, -.10732300E+04, 0.67357600E+03, -.21313900E+04, 0.44244500E+03, 0.22833900E+04, -.11455300E+04, -.86401200E+03, 0.33636800E+02, 0.13031200E+03, -.70023300E+03, 0.37600800E+02, -.74411100E+03, -.16337900E+03, 0.55102500E+03, 0.13414600E+03, -.29419500E+03, 0.45108300E+03, 0.73552900E+02, 0.11852200E+03, 0.25837200E+03, -.39069900E+01, 0.74573000E+02, 0.41170300E+03, 0.74435300E+03, 0.30811300E+03, -.25704800E+03, 0.57983900E+02, 0.19379300E+03, 0.23649200E+03, 0.50405100E+03, -.25655500E+03, 0.14578600E+02, 0.58286900E+03, -.12287500E+03, 0.16274500E+03, -.25908300E+03, -.10132900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.51032500E+00, 0.16084500E+00, -.37746000E-01, 0.10648700E+01, -.78897100E+00, -.25056800E-01, -.51680100E-01, -.17267700E+00, -.37643400E+00, -.44658800E+00, -.11658600E+00, -.76552400E+00, -.13575800E-01, -.37663200E+00, 0.20543400E+00, 0.29225300E-01, 0.81891100E-01, -.44119300E+00, -.35698900E-01, -.39571100E+00, -.31048400E+00, -.48323300E+00, 0.30023800E+00, 0.35167600E+00, -.45306700E+00, 0.76266100E+00, 0.55980900E-01, 0.49749200E+00, -.13277500E+01, -.38194500E+00, 0.35879300E+00, 0.49471000E+00, 0.69877900E+00, 0.40650300E-01, 0.77324700E-01, 0.47299200E-01, 0.41018000E+00, -.62106800E+00, 0.48202100E+00, 0.59690900E+00, 0.12452800E+00, -.40826300E-01, 0.42396700E+00, 0.30795200E+00, -.36364900E+00, -.12668000E+00, -.36198600E-01, -.21979900E+00, -.56676100E+00, 0.16978200E+00, 0.34489900E+00, -.25890600E+00, 0.86791600E+00, -.78737700E-01, 0.13253000E+01, -.11158300E+02, 0.40870900E+03, -.55113300E+03, 0.44436100E+03, -.16180700E+03, -.56438200E+03, 0.42495100E+03, 0.15112700E+03, 0.41264600E+04, -.21496200E+04, -.20631700E+04, 0.11696900E+04, 0.17437900E+04, -.21387700E+04, -.25889200E+04, -.21506400E+04, 0.11847900E+04, 0.98905600E+03, -.49086300E+03, -.28107300E+03, -.59422700E+02, -.10918800E+03, -.35576200E+03, -.32588000E+03, -.79303700E+03, -.19164600E+03, -.34744200E+04, 0.17358800E+04, 0.20159700E+04, 0.75663500E+03, -.14824800E+02, 0.96771500E+03, -.30252900E+02, 0.12721900E+04, -.34971000E+02, -.25893300E+03, 0.12458600E+03, 0.48653000E+02, -.48767600E+03, -.34489800E+03, 0.16166500E+03, 0.49639700E+03, 0.31601700E+04, -.90356400E+02, 0.17894900E+04, -.95909600E+03, -.43707000E+03, 0.10404200E+04, 0.18156300E+04, -.49550900E+03, 0.36626300E+03, 0.23656400E+03, 0.34670200E+03, -.15517300E+04, 0.69939400E+03, 0.29067800E+03, -.27945000E+02, -.56202500E+03, 0.82812100E+03, 0.10178600E+04, 0.65012300E+03, -.78118900E+03, 0.14341700E+04, -.73058600E+03, -.10029000E+04, -.14797200E+03, 0.70552700E+03, -.60348700E+03, -.10408700E+04, -.13618100E+04, -.54473600E+03, -.21768400E+04, 0.10817400E+04, 0.10298400E+04, 0.20519800E+03, 0.40912300E+03, 0.50271100E+03, -.39911900E+03, -.81852700E+02, 0.69721600E+03, 0.54456800E+03, -.28175500E+03, -.21292900E+03, 0.36854300E+02, -.58404000E+03, -.23421700E+03, -.37878100E+03, -.38135400E+03, -.51832300E+03, 0.16015800E+04, -.96496800E+03, -.77775400E+03, 0.14372800E+04, 0.95750400E+03, -.10908700E+04, -.21863300E+04, -.10238800E+04, 0.15428400E+04, 0.49510700E+04, -.25025800E+04, -.23870800E+04, 0.52608300E+03, 0.13308700E+03, -.12132700E+04, -.31288100E+03, -.15540100E+04, -.22487900E+03, -.18125600E+02, -.52330300E+01, -.66888700E+02, -.16593400E+04, -.14359200E+03, 0.47349100E+03, 0.11761600E+04, -.66215400E+02, -.15993500E+03, 0.42386600E+03, -.22937400E+03, -.30217300E+03, -.21923200E+02, 0.23929300E+01, -.12931300E+03, -.44760900E+03, -.38643900E+03, 0.16758900E+03, -.24203600E+03, 0.12707800E+03, 0.23494500E+03, -.22217000E+03, -.84014000E+03, 0.78410900E+03, 0.12481300E+04, 0.10566100E+04, -.71162600E+02, -.80035500E+04, 0.40468300E+04, 0.36868800E+04, -.30420300E+03, -.66705100E+03, 0.19302400E+04, 0.32826100E+03, 0.14424200E+04, 0.33626600E+03, -.87853500E+03, 0.52760400E+03, 0.51686200E+03, 0.62559000E+02, -.24500500E+02, 0.35388100E+03, 0.50967600E+02, 0.34853500E+03, -.23657600E+03, -.29311000E+03, 0.92942500E+02, -.18675900E+03, 0.12728800E+03, 0.80226500E+03, -.26663200E+02, 0.23424000E+03, 0.28502600E+02, 0.10322100E+04, -.15429500E+03, -.11336000E+04, 0.21417100E+03, 0.40023900E+03, -.44423600E+03, 0.22318000E+03, 0.18673500E+03, -.19103900E+03, -.37586200E+03, -.29856800E+03, -.47307900E+03, -.77736300E+03, 0.30914600E+03, 0.12567800E+03, -.52996000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.39655200E+01, 0.21597100E+01, 0.21345500E+01, -.90424600E+01, 0.21135900E+01, 0.87697400E+01, -.86023200E+01, -.27802500E+01, 0.45040400E+00, -.21581000E+01, 0.85567900E+00, 0.18009100E+01, -.90336600E-01, 0.28794600E+01, -.25791900E+01, 0.28067800E+01, 0.21265300E+01, 0.25658600E+01, 0.29628700E+01, 0.98287300E+00, 0.53173100E+00, 0.71337800E+00, 0.25745000E+01, -.10084600E+01, 0.18078200E+01, -.24777900E-01, -.37298600E+00, 0.20597000E+01, -.84064700E+00, 0.10861600E+01, -.23840500E+01, -.16381800E+01, -.85047400E+00, 0.12074400E+00, -.74422400E+00, -.13146200E+01, -.30337400E+01, -.34401800E+00, -.51875200E+01, -.20138200E+01, -.14466800E+01, 0.35532300E+01, -.15776600E+01, -.21613000E+01, 0.13693900E+00, -.11821500E+01, 0.18703800E+00, 0.45660600E+01, 0.10759800E+01, -.75846500E+00, -.31451600E+00, -.13815500E+01, -.28169800E+01, 0.22358100E+01, -.28075700E+01, -.80388300E+00, -.33101700E+04, 0.16007500E+04, -.51100900E+03, -.24634500E+04, -.33489600E+04, -.50366500E+04, 0.17974300E+04, 0.89300500E+04, -.42268600E+04, -.44680800E+04, 0.35046700E+04, -.97558100E+03, -.42050400E+04, -.40661200E+04, -.31692100E+04, -.26033600E+04, -.79105300E+04, 0.39344500E+04, 0.22442200E+04, 0.49780200E+03, 0.10355100E+04, 0.87580400E+03, -.23971500E+04, 0.21254100E+04, 0.14679200E+04, -.36593100E+03, 0.14138300E+03, -.25794900E+04, -.10094600E+04, -.20367700E+04, -.35170700E+03, -.12570600E+04, 0.19041700E+04, -.10807800E+04, 0.15652500E+03, -.69519200E+02, 0.10058900E+04, 0.22449100E+04, 0.20773700E+04, -.69570700E+03, -.41713100E+04, -.13712600E+05, 0.12365800E+04, -.68311600E+04, 0.35687100E+04, -.63611900E+03, 0.20578300E+04, 0.54069100E+03, -.82471700E+03, -.44537500E+04, -.25970100E+04, 0.23511000E+04, 0.14065200E+04, -.54476000E+03, 0.28898400E+04, -.73357400E+03, 0.68667000E+03, 0.11560100E+04, 0.23543900E+04, -.19116700E+02, 0.94020100E+03, 0.46257800E+03, -.22621600E+03, 0.14930600E+04, 0.69015900E+03, -.16571100E+04, 0.23707700E+04, 0.58240000E+04, 0.49748900E+04, -.99249200E+03, 0.45624700E+04, -.22676200E+04, -.15446700E+04, 0.56125500E+03, 0.44951100E+02, -.12540400E+04, 0.36766200E+03, 0.22629700E+04, -.10530300E+04, -.50654600E+04, 0.25095600E+04, 0.17579500E+04, 0.25736400E+04, 0.23053100E+04, 0.20975000E+04, 0.65055300E+03, 0.25357000E+04, 0.11668500E+04, 0.13918200E+05, -.65747600E+04, -.71372400E+04, 0.40734200E+04, 0.24358100E+04, -.68121800E+04, -.62007000E+04, -.47898800E+04, -.26884100E+04, -.16052400E+05, 0.80726000E+04, 0.73139500E+04, -.56485900E+03, 0.82970500E+03, 0.34988600E+04, 0.90672400E+03, 0.38210400E+04, 0.21173200E+04, -.41566000E+04, 0.21286900E+04, 0.30895500E+04, -.26837900E+04, -.40514100E+03, 0.17237300E+04, 0.31536700E+04, 0.21892100E+04, 0.12347400E+04, 0.66879400E+04, -.32565400E+04, -.27050800E+04, -.13201900E+04, -.16800800E+04, -.18416600E+04, 0.99088800E+03, 0.56776200E+03, -.18164100E+04, -.16453700E+04, 0.83802500E+03, -.62879100E+02, -.18516300E+03, 0.14389800E+04, -.26064200E+04, -.35088300E+04, -.25833800E+04, 0.10804600E+04, 0.28269700E+05, -.14213100E+05, -.11715700E+05, -.16025000E+04, -.26279500E+04, -.50503400E+04, 0.16438600E+04, -.24645000E+04, -.52810900E+04, 0.28356200E+04, -.14957400E+04, -.19016000E+04, 0.75297200E+03, 0.18247100E+04, -.14799100E+04, -.57911600E+03, -.32911100E+04, 0.66852900E+03, 0.56154300E+03, 0.11988400E+04, -.49160100E+02, -.18140600E+03, 0.78179200E+03, -.32793900E+03, 0.29132500E+02, 0.48443400E+03, -.84499400E+02, 0.40914700E+03, -.18719800E+04, 0.38440300E+03, -.78328000E+03, 0.12363000E+03, -.11916400E+04, 0.28790300E+03, -.84802900E+03, -.35493100E+03, 0.19644900E+04, -.10592700E+04, -.69569700E+03, -.21480500E+03, 0.65247400E+03, -.91168400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.35942500E+00, -.12195200E+01, -.38942600E+00, 0.52647100E+00, 0.90837600E-01, -.14828700E+00, 0.11121000E+01, 0.21791400E+00, 0.18298400E+00, -.23365200E+00, -.73176100E-01, -.11561200E+00, -.13810700E+00, -.30407900E+00, 0.45010900E+00, 0.68906000E+00, 0.66663400E-01, -.51636700E+00, 0.45883100E+00, 0.73733200E+00, 0.24843300E+00, 0.15502700E+00, -.16738000E+00, -.25735700E+00, -.37774100E-02, -.10258700E+01, 0.47184400E+00, 0.39215200E+00, -.61957600E+00, -.13232700E+00, 0.23347300E+00, 0.59726800E+00, -.67629500E-01, 0.39553600E-01, 0.11972800E+00, -.44655300E-01, 0.82818900E-02, 0.12583000E+00, 0.28244800E+00, 0.20468600E+00, 0.64702700E-01, -.52588900E+00, 0.44181700E+00, -.16992200E+00, -.96195600E-01, -.25153100E-01, -.10846000E-01, -.66866600E-01, 0.45672100E-01, 0.24779700E-01, 0.12548500E+00, 0.18237600E+00, 0.88211300E-02, -.20213000E+00, 0.50166300E+00, -.25134500E+00, -.53478300E-01, -.32363900E+03, 0.10504500E+03, 0.29395400E+03, -.15306200E+03, -.82566500E+02, -.31394200E+03, 0.21169900E+04, -.10627200E+04, -.10586300E+04, 0.46961000E+03, 0.15368300E+03, -.10442100E+04, -.10777900E+04, -.10720100E+04, 0.23122800E+03, -.55842200E+03, 0.27633000E+03, 0.25976900E+03, 0.10581400E+03, 0.36341400E+02, 0.16916000E+03, -.15642200E+03, 0.48843200E+03, 0.84582600E+02, -.16291400E+04, 0.81018600E+03, 0.60426100E+03, 0.11621000E+03, -.33327400E+03, 0.80268800E+03, 0.28648900E+03, 0.10286000E+04, -.10334100E+03, -.22150300E+03, 0.11311800E+03, 0.14520800E+03, -.12795300E+03, 0.14660700E+03, 0.30881800E+02, -.51927600E+03, -.89563500E+03, 0.75275800E+02, 0.40940400E+03, -.20655100E+03, -.25893600E+03, 0.21724600E+03, 0.26969400E+03, 0.11956000E+03, 0.28399300E+03, -.21051300E+03, -.14799900E+03, -.11262600E+04, 0.55663700E+03, 0.52718900E+03, 0.31391200E+03, 0.67689800E+03, 0.58710100E+02, 0.36728900E+03, 0.35977500E+03, 0.18983400E+03, 0.27861900E+03, -.13949300E+03, -.30125800E+03, 0.18856000E+03, 0.23560700E+03, -.27365600E+03, 0.13030900E+03, -.65424400E+02, 0.17887800E+03, 0.40626800E+03, -.20156300E+03, -.12055300E+03, -.14424700E+03, -.25316200E+03, 0.72771500E+01, 0.14639200E+03, 0.20218900E+03, -.11257400E+03, -.10936700E+03, 0.44774600E+02, 0.93849000E+02, 0.12239200E+03, -.11330000E+03, 0.10162500E+03, -.93692300E+02, 0.31456600E+03, 0.89835500E+02, 0.26618900E+04, -.13417500E+04, -.13245000E+04, 0.58238300E+03, -.66510100E+02, -.12780200E+04, -.12404100E+04, -.13115600E+04, 0.20485300E+03, 0.52160800E+03, -.26289800E+03, -.32419800E+03, 0.51580100E+03, 0.36908100E+03, -.35100000E+03, 0.10096000E+03, -.74449500E+03, 0.20522900E+03, 0.99488300E+03, -.49302400E+03, -.30697600E+03, -.36139500E+03, 0.98021900E+02, -.41057100E+03, -.60430700E+02, -.59253200E+03, -.55498100E+02, 0.74846100E+03, -.36388100E+03, -.39570000E+03, -.16377400E+03, -.21451700E+03, -.16827200E+03, 0.13932700E+01, -.13843400E+03, -.20487800E+03, 0.13791800E+02, -.69907100E+01, 0.22306100E+02, -.35316600E+02, -.18426800E+03, 0.24134500E+02, -.27581100E+02, -.14478900E+03, -.43013600E+02, 0.18263500E+03, -.87922200E+02, -.91669400E+02, -.52759000E+03, -.45131400E+03, 0.26142000E+02, -.15741900E+03, 0.62316100E+03, -.18292800E+03, -.41523200E+03, 0.21125800E+03, 0.74177700E+02, -.43938700E+02, 0.13345800E+03, 0.12954900E+03, -.13974600E+02, 0.20333300E+03, -.50757300E+02, 0.67839100E+01, -.13033600E+03, 0.15247900E+03, -.16466100E+03, 0.12736200E+03, 0.88500900E+02, -.21599100E+03, 0.11353600E+03, -.31964100E+03, -.16767500E+03, -.29576400E+03, -.27424000E+03, 0.28373800E+02, -.10625300E+03, -.16876100E+03, -.14703900E+03, -.32706200E+03, 0.34035800E+03, 0.17671100E+03, 0.43693200E+02, -.10424900E+03, -.19156100E+03, -.73361400E+00, 0.18996300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.67842600E-01, 0.26285000E+00, 0.51433100E-01, -.12565100E+01, 0.58968000E+00, 0.66495100E+00, -.15708800E+00, -.44667000E-01, -.67235400E-01, 0.15712700E-01, 0.20404700E+00, 0.45253000E+00, 0.92761700E-01, 0.62124600E-02, 0.15454900E+00, 0.27570700E+00, 0.27082700E+00, -.56935000E+00, 0.84154800E+00, 0.20297900E+01, 0.42602100E-01, 0.34100100E-01, -.38192100E-01, -.83964000E-01, 0.54737300E-01, -.10019300E+00, 0.10304800E+00, 0.37233400E-01, -.32016600E+00, 0.12387000E-01, 0.24716400E-01, 0.12870400E+00, 0.17590100E-01, -.27849700E-01, 0.13217000E-01, 0.17969000E-01, 0.11448000E+00, -.47389400E+00, -.20624800E-01, -.34754400E+00, -.49899400E-01, -.98156200E-01, 0.10319200E+00, -.89938500E-01, -.63680800E-01, -.16080700E-01, 0.47340900E-02, 0.69362600E-01, 0.10053800E-01, -.26187900E+00, 0.10363800E+00, 0.42910300E+00, -.47839100E-01, 0.17610600E+00, 0.39922300E-01, -.14564700E-01, -.25978900E-01, 0.44097500E-01, -.10259000E+03, -.16266200E+03, -.99704200E+02, -.34804800E+02, 0.11405500E+03, -.12723200E+04, 0.62986400E+03, 0.63578300E+03, -.19956800E+03, 0.21575000E+03, 0.50894800E+03, 0.27524300E+03, 0.58525200E+03, 0.15434700E+03, -.52492400E+03, 0.26077600E+03, 0.24966600E+03, 0.23266800E+03, 0.33506800E+03, -.50629700E+02, -.37747300E+03, -.42095300E+03, 0.29902600E+03, 0.16479000E+04, -.82112600E+03, -.82379100E+03, 0.18771700E+03, 0.29533100E+03, -.73873200E+03, -.47231400E+03, -.84791700E+03, 0.45904900E+02, 0.11421200E+02, -.42156800E+01, -.52083400E+01, -.15511200E+03, -.16891000E+03, 0.37782200E+02, 0.13126900E+03, 0.47952900E+03, -.11918700E+03, -.19260600E+03, 0.93537600E+02, 0.80106500E+02, 0.67318500E+02, 0.42013700E+03, -.18189600E+03, -.97795500E+02, -.63815100E+02, 0.36214800E+03, 0.13227200E+02, -.24753000E+01, 0.86194700E+01, -.12689600E+03, -.28462200E+03, 0.18588200E+03, 0.96498600E+02, 0.12526300E+03, -.15861400E+03, 0.38172500E+03, -.18670400E+03, -.17070800E+03, 0.52691000E+02, 0.18259900E+03, -.16987700E+02, -.26612900E+02, -.44802100E+02, -.13344800E+03, -.41251300E+03, 0.20679700E+03, 0.22488700E+03, 0.23719200E+02, 0.56357400E+02, 0.12772200E+03, -.26205100E+02, 0.87204500E+02, 0.61396000E+02, -.66963300E+03, 0.32706800E+03, 0.37684900E+03, -.30962500E+02, -.11690600E+03, 0.26293000E+03, 0.11170800E+03, 0.24157600E+03, -.14501000E+03, -.16537600E+04, 0.82138100E+03, 0.82339700E+03, 0.23076100E+02, 0.23570400E+03, 0.60794700E+03, 0.16288400E+03, 0.77554300E+03, 0.20871200E+03, 0.73938000E+03, -.37110300E+03, -.39966200E+03, 0.18142900E+03, 0.24501200E+03, -.32748300E+03, -.36057900E+03, -.22192700E+03, 0.18756300E+03, -.10281400E+04, 0.51607100E+03, 0.54033400E+03, 0.15918700E+02, -.96882700E+02, 0.37066800E+03, 0.23534100E+03, 0.50814300E+03, -.23153900E+01, 0.60717700E+03, -.29295600E+03, -.30874000E+03, -.73498600E+02, -.10847200E+03, -.11643500E+03, 0.18374700E+01, -.53642100E+02, -.73346500E+02, -.53504000E+03, 0.26373300E+03, 0.26116000E+03, -.10757600E+03, -.13508500E+03, 0.17742700E+03, 0.16826600E+03, 0.32375700E+03, 0.78840300E+02, -.94985200E+03, 0.47563000E+03, 0.50547700E+03, -.25077500E+03, -.57264400E+03, 0.55723400E+03, 0.53526500E+03, 0.34128600E+03, -.43586600E+03, -.59558400E+03, 0.28758300E+03, 0.24287600E+03, 0.93002000E+02, 0.60648600E+02, 0.13619900E+03, -.15805100E+03, -.81566200E+02, 0.51442200E+02, -.11531600E+03, 0.28064400E+03, -.11432900E+03, 0.11131500E+03, 0.11398700E+03, -.13562500E+03, 0.12038600E+03, -.93529900E+01, 0.47902600E+03, -.20735400E+02, -.15834800E+03, 0.11283400E+03, 0.14250000E+02, 0.16961600E+02, 0.71213800E+02, 0.89802100E+02, 0.35908700E+02, -.29886900E+03, 0.18851200E+02, -.17385500E+03, -.10231400E+03, 0.14862900E+03, 0.13295800E+03, -.26158300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.42118200E+00, -.39857600E+00, 0.52920700E-01, 0.95820400E+00, 0.21234000E+00, -.32541200E+00, 0.58980800E+00, 0.14487600E+00, -.10654500E+01, 0.52568900E-01, 0.16643100E+00, 0.16177100E+00, 0.12262400E+00, 0.66223200E-01, -.81897900E-01, -.12664300E+00, 0.90518900E-01, -.43766700E-01, -.49504000E+00, 0.10495000E+01, 0.23435800E+00, 0.48217100E+00, -.21492700E+00, -.29049300E+00, 0.18019800E+00, 0.25522000E+00, 0.12969800E+00, -.74682800E+00, 0.64171700E-01, -.66156400E-01, 0.36005000E+00, 0.25664600E+00, 0.60648400E-01, 0.12047900E-01, 0.55156400E+00, -.64535600E-01, -.54488400E-01, -.15671200E+00, 0.70492000E-02, 0.51350600E+00, -.45109100E-01, 0.77773800E-01, -.45131000E-01, 0.15944600E+00, 0.21441100E+00, -.46323300E-01, -.85087000E-01, -.14036100E+00, -.43518700E+00, -.30700900E-01, -.13622500E+00, -.33735900E+00, 0.43223500E+00, 0.25232400E+00, 0.47697500E+00, -.79240900E-01, 0.57342400E-01, 0.78987700E+00, -.42729800E+00, -.78309500E+03, -.31351600E+03, 0.38887200E+03, 0.34456100E+02, 0.39370000E+03, -.19378600E+03, -.19834100E+03, 0.10569000E+04, 0.80034600E+03, -.54899100E+03, -.15112000E+04, -.54732800E+03, 0.59100600E+03, -.53011000E+03, 0.26435900E+03, 0.30474900E+03, 0.63252600E+03, 0.96576100E+03, -.51927700E+03, -.14016800E+04, -.20003000E+04, 0.78671700E+03, 0.51380200E+04, -.25705400E+04, -.20662000E+04, -.13739400E+02, 0.24742700E+04, -.27946200E+04, -.17375300E+04, -.31456700E+04, 0.55177400E+03, 0.17836700E+04, -.88998500E+03, -.98236200E+03, -.76862700E+03, -.13598400E+04, -.11392500E+03, 0.11502700E+04, 0.36280000E+04, -.10717100E+04, 0.12645900E+04, -.62471400E+03, -.56899500E+03, 0.75204900E+03, 0.18137900E+04, -.11922000E+04, -.14809000E+02, 0.14727700E+03, 0.68943100E+03, -.19232400E+04, 0.95716800E+03, 0.10633700E+04, -.72033900E+03, -.15380700E+04, 0.19434600E+04, 0.12959800E+04, 0.14617000E+04, -.10885800E+04, 0.25152500E+04, -.12553700E+04, -.77896800E+03, -.36848700E+03, -.55290100E+02, -.16328200E+03, -.58421900E+03, -.14652700E+04, -.10330700E+04, -.29698500E+04, 0.14808100E+04, 0.13722600E+04, 0.42215100E+03, 0.60254500E+03, 0.59178900E+03, -.51409600E+03, -.40763500E+03, 0.78755700E+03, -.11038000E+04, 0.54518700E+03, 0.70434200E+03, 0.75998900E+02, -.46378800E+02, 0.33373200E+03, 0.10924700E+03, -.22212600E+03, -.20344400E+03, -.25264700E+04, 0.12497800E+04, 0.12311500E+04, 0.10160300E+04, 0.62708200E+03, 0.58230600E+03, -.96193300E+03, 0.67956300E+03, 0.12367800E+04, 0.43858200E+04, -.21906600E+04, -.21953100E+04, -.39862100E+03, 0.62688900E+03, -.11192600E+04, -.81845500E+03, -.63162700E+03, -.85549400E+02, -.57259900E+04, 0.28532700E+04, 0.26219300E+04, -.87901800E+03, -.16754600E+04, 0.26631700E+04, 0.22947900E+04, 0.27981700E+04, -.23194900E+03, 0.10376500E+04, -.51444300E+03, -.57814400E+03, -.14304600E+03, 0.14412000E+03, -.26852500E+03, -.26798600E+03, -.32610300E+03, -.17401200E+02, -.20796400E+04, 0.10398600E+04, 0.93017300E+03, -.28074600E+03, -.17635300E+03, 0.10872100E+04, 0.12851400E+04, 0.19994600E+04, 0.13492000E+03, -.70066200E+04, 0.34979700E+04, 0.36213500E+04, 0.41577800E+03, -.12410200E+04, 0.20927500E+04, 0.59544600E+03, 0.34383900E+03, 0.27519400E+02, -.24527300E+04, 0.12308600E+04, 0.12812400E+04, 0.34654500E+03, -.51942700E+02, 0.57565700E+03, -.60919500E+03, 0.76688500E+02, 0.36874800E+03, -.45433700E+03, 0.96990300E+03, -.46079400E+03, 0.34088600E+03, 0.37270600E+03, -.49682300E+03, 0.53732700E+03, -.28240600E+03, 0.15316400E+04, -.17086200E+03, -.73525800E+03, 0.64686200E+03, 0.19005700E+03, 0.27926200E+03, 0.37024900E+03, 0.55237600E+03, 0.36139800E+03, -.79805800E+03, -.23515600E+03, -.10791300E+04, -.33970400E+03, 0.66761700E+03, 0.53515200E+03, -.10084500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21460100E+01, 0.28791700E+01, 0.12356200E+01, -.51292000E+01, -.65271000E+00, 0.43347300E+01, -.50998400E+01, -.14144300E+01, 0.72742300E+00, -.17322300E+01, 0.69214800E+00, 0.13218700E+01, -.27863600E+00, 0.14699700E+01, -.92469600E+00, 0.30981300E+01, 0.22379600E+01, 0.16473200E+01, 0.17396300E+01, 0.34107900E+01, 0.47059200E+00, 0.11515300E+01, 0.17717300E+01, -.98357800E+00, 0.98869600E+00, -.11465300E+01, 0.11352900E+01, 0.23291600E+01, 0.48879300E+01, -.81012000E+00, -.12934500E+01, -.13904200E+01, -.12133500E+01, -.11648700E+00, 0.35320100E-01, 0.13426600E+01, -.28629600E+01, 0.35538100E+01, 0.65809200E+00, 0.47797200E+01, 0.73382000E+00, -.26803600E+00, 0.30464400E+01, -.93963200E+00, 0.13360700E+01, -.12262300E+01, 0.88921400E+00, 0.29334700E+01, -.12750500E+01, 0.25794400E+01, -.94010800E+00, -.44709500E+01, -.71578400E+00, 0.18607800E+01, -.18914600E+01, -.29666700E+01, 0.42534400E+00, -.23934100E+01, -.31194400E+01, 0.65802500E+01, -.23217300E+04, -.71842700E+04, 0.94060100E+03, 0.13517600E+05, -.65380100E+04, -.67581000E+04, 0.11690900E+04, -.21273700E+03, -.57517900E+04, -.40080100E+04, -.59377600E+04, -.17301500E+04, 0.33344500E+04, -.16704400E+04, -.19069100E+04, -.20907300E+04, -.38876700E+04, 0.68108600E+03, 0.40756300E+04, 0.59706300E+04, -.30506500E+04, -.26964000E+05, 0.13439100E+05, 0.11520700E+05, -.55079500E+02, -.64038100E+04, 0.11152000E+05, 0.59169200E+04, 0.13601700E+05, -.31198200E+03, -.60884900E+04, 0.30383400E+04, 0.35067900E+04, 0.23578500E+04, 0.50989300E+04, -.61654700E+03, -.59420500E+04, -.16762500E+05, 0.36981300E+04, -.69699600E+04, 0.35968200E+04, 0.29592000E+04, 0.19647600E+04, 0.14182000E+04, 0.18695300E+04, 0.62446200E+03, -.30998300E+04, 0.18747800E+04, 0.54849300E+04, -.26621700E+04, -.32198500E+04, 0.12565600E+04, 0.55764200E+04, -.37082000E+04, -.17778700E+04, -.27241000E+03, 0.28643700E+04, -.34795000E+04, 0.17223400E+04, -.16014300E+03, -.24895300E+03, 0.27107400E+03, 0.95462400E+03, 0.33472700E+04, 0.53510500E+04, 0.33723300E+03, 0.65118000E+04, -.32422800E+04, -.24275300E+04, -.40059400E+03, -.69465500E+03, -.17335900E+04, -.58212200E+02, -.29808900E+04, -.12687800E+04, 0.27649100E+04, -.13771000E+04, -.12934100E+04, 0.50665700E+03, 0.16387800E+04, -.22612500E+03, 0.91857300E+02, 0.80392300E+03, 0.39291600E+03, 0.31529200E+05, -.15424600E+05, -.15676000E+05, 0.40463200E+04, 0.18395200E+04, -.13402300E+05, -.90594400E+04, -.13899300E+05, -.30431200E+04, 0.40161900E+03, -.14392400E+03, -.70009900E+03, 0.23802700E+04, 0.10508500E+03, -.12734500E+04, 0.31432500E+04, -.39547600E+03, 0.11073300E+04, 0.20402600E+05, -.10147200E+05, -.83665900E+04, 0.65181400E+03, 0.29007300E+04, -.84667700E+04, -.58469700E+04, -.92149400E+04, -.80644700E+03, -.26479300E+04, 0.13578600E+04, 0.99433800E+03, 0.82713600E+03, -.40955100E+03, 0.42743700E+02, -.64545200E+03, 0.24532600E+03, 0.99695300E+03, 0.19798700E+04, -.97274600E+03, -.69209200E+03, 0.21186300E+04, 0.81936200E+03, -.24290000E+04, -.19842000E+04, -.27379000E+04, 0.18862500E+04, 0.10273600E+05, -.52095300E+04, -.52229200E+04, -.37005700E+04, -.28693100E+03, -.14473500E+04, -.22828400E+04, 0.67001000E+03, -.25302300E+04, 0.11459100E+05, -.56386300E+04, -.67507000E+04, -.10881700E+04, 0.49484100E+03, -.29773300E+04, 0.17652100E+04, -.27314800E+04, -.22292700E+04, 0.17611200E+04, -.19103400E+04, 0.12013800E+04, -.10439300E+04, 0.36463800E+03, 0.70997100E+03, -.14544700E+04, 0.18672300E+04, -.43422900E+04, 0.62795500E+03, 0.25604500E+03, -.17391800E+04, -.78414600E+03, -.18682800E+03, -.23056700E+04, -.21377500E+03, -.14317100E+04, 0.22551600E+04, 0.24329600E+04, 0.17654500E+04, -.45150800E+03, -.16366700E+04, 0.40822600E+03, 0.22979900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19108100E+01, 0.85638000E+00, 0.59146600E+00, -.32087100E+01, 0.43490800E+00, 0.32252300E+01, -.20264000E+01, -.95962600E+00, 0.19758200E+00, -.70653000E+00, -.30824400E-01, 0.50761900E-01, -.37087800E+00, 0.99010400E-01, -.49048100E+00, 0.66562700E+00, 0.45168400E+00, 0.40648800E+00, 0.62442900E+00, -.30596100E+01, -.39926800E+00, -.10199800E+01, 0.82184900E+00, 0.25787400E+00, 0.45112700E+00, 0.10418800E+00, -.99670100E+00, 0.16108700E+01, -.21434800E+00, -.40023700E+00, -.41109600E+00, -.90779800E+00, 0.58522100E+00, 0.19936900E+00, -.15547300E+01, -.47769100E+00, 0.47441200E+00, -.21827000E+01, 0.93582500E+00, -.26343600E+01, 0.36454900E-01, -.21551500E+00, 0.78503400E+00, 0.43752700E+00, 0.33458200E+00, 0.44731400E-01, 0.61892900E-01, 0.72123500E+00, -.34267500E+00, -.47611500E+00, 0.25508200E+00, 0.77579900E-01, 0.35681900E+00, 0.40961100E+00, -.57557700E+00, 0.19290000E+00, 0.14493200E+00, -.85065800E+00, -.56136500E+00, -.10596900E+01, 0.10124000E+00, 0.25528800E+04, 0.67200700E+03, 0.75184300E+04, -.37961200E+04, -.37590000E+04, 0.31209200E+04, 0.18433100E+04, -.40670100E+04, -.50375300E+04, -.36858800E+04, 0.53897600E+03, -.12442300E+04, 0.61965000E+03, 0.65072900E+03, 0.15809000E+03, -.49609600E+02, 0.13917600E+03, -.12652800E+04, 0.79213200E+03, 0.11574600E+03, 0.92052000E+04, -.45935600E+04, -.43809700E+04, 0.26069300E+02, 0.18898300E+04, -.38051700E+04, -.26865300E+04, -.33091400E+04, -.25406500E+03, 0.27971200E+03, -.13588200E+03, -.28131100E+03, -.20592700E+00, -.21055700E+03, 0.58681600E+03, 0.85616300E+03, 0.41722500E+04, -.10080800E+03, 0.55651400E+04, -.27840200E+04, -.26508700E+04, 0.35069600E+03, -.28645800E+03, -.16428100E+04, -.22998800E+04, 0.73356100E+03, -.14483600E+04, -.19709400E+04, 0.97999000E+03, 0.11219800E+04, -.58909200E+03, -.48068300E+03, 0.67724400E+03, 0.77563700E+03, -.18235000E+04, 0.21530000E+03, 0.36990000E+04, -.18382900E+04, -.15376500E+04, 0.36708200E+03, 0.12673900E+03, -.83903200E+03, -.24427600E+03, -.21281200E+04, -.58388800E+03, -.21467500E+04, 0.10693600E+04, 0.90967600E+03, 0.98419700E+03, 0.10961700E+04, 0.36566200E+03, -.22596600E+03, 0.21714900E+04, 0.87145900E+03, -.27863600E+04, 0.13453600E+04, 0.13911900E+04, 0.10689200E+04, 0.74093400E+03, 0.71142100E+03, -.18625500E+03, 0.11287400E+04, 0.25447000E+03, 0.34407000E+04, -.17902300E+04, -.17289000E+04, 0.30304900E+04, 0.23269400E+04, -.26714500E+04, -.49512600E+04, -.16691300E+04, 0.63307000E+03, -.38133400E+04, 0.18982200E+04, 0.19878400E+04, -.15292800E+04, -.15329700E+04, 0.17510100E+04, -.27154000E+03, 0.91346100E+03, -.96992100E+03, -.11754800E+05, 0.58672400E+04, 0.55261100E+04, -.23627200E+04, -.20415200E+04, 0.51601800E+04, 0.46260000E+04, 0.46364800E+04, 0.60651000E+03, 0.47574100E+04, -.23243800E+04, -.22452200E+04, -.75413300E+03, -.70967400E+03, -.11640900E+04, 0.19501400E+03, -.73882600E+03, -.91045000E+03, -.55181000E+03, 0.27298700E+03, 0.26380400E+03, -.14453600E+04, -.13802000E+04, 0.66938500E+03, 0.24919700E+03, 0.53865500E+03, -.88463100E+03, 0.13032500E+04, -.65061500E+03, -.64599700E+03, 0.20824800E+04, 0.17643200E+04, -.11582200E+04, 0.38243300E+03, -.14541200E+04, 0.15044000E+04, -.45055800E+04, 0.21892300E+04, 0.23802200E+04, 0.28365400E+03, 0.20381000E+03, 0.12011500E+04, -.20620100E+03, 0.16682900E+04, 0.39805100E+03, -.33430800E+03, 0.33754100E+03, -.13217800E+03, -.59020400E+02, 0.84294200E+03, 0.22430200E+02, 0.14290900E+03, -.29790500E+03, 0.13903000E+04, -.31522900E+03, -.11467900E+04, 0.41632500E+03, 0.38822100E+03, -.18654700E+03, 0.17712900E+03, -.37058900E+03, -.50084400E+03, -.60437700E+03, -.12022800E+04, -.96796200E+03, -.75532600E+03, 0.17184200E+03, -.88675600E+03, -.31738400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.33044700E+01, -.23118200E+01, -.20535300E+01, 0.86826100E+01, -.32766700E+00, -.78866500E+01, 0.10040100E+02, 0.24800000E+01, -.15147500E+01, 0.39825100E+01, -.98588300E+00, -.20888700E+01, 0.74031500E+00, -.32333600E+01, 0.29272000E+01, -.87872500E+01, -.53683000E+01, 0.38636000E+00, -.55563100E+01, -.45637400E+01, -.20115000E+01, -.74706700E+00, -.27456100E+01, 0.13258400E+01, -.36000700E+01, 0.85201400E+01, 0.17203200E+01, -.38444100E+01, 0.10764200E+01, 0.31190500E+01, 0.13987600E+00, -.35902400E+00, 0.58730600E+00, -.15988400E+00, 0.21101900E+01, -.85017200E+00, 0.34042400E+01, 0.46675900E+01, -.11575400E+01, 0.40332500E+00, 0.13315900E+00, -.43652600E+01, 0.55816200E+01, -.28438600E+01, 0.23760200E+01, -.24901200E+01, 0.17491200E+00, -.23828600E+00, 0.21769400E+01, -.99338700E+00, -.17105100E+00, -.35659200E+01, -.38209600E+01, -.62928700E+00, -.20875900E+00, -.95305000E+00, 0.19875000E-01, -.36191500E+01, -.79195200E+01, 0.36461500E+01, 0.12942500E+01, 0.18307400E+01, -.35435600E+04, -.35572500E+05, 0.17543000E+05, 0.17784300E+05, -.91360800E+04, -.24230700E+04, 0.16095800E+05, 0.13765100E+05, 0.16263900E+05, 0.19126600E+04, -.18275000E+05, 0.91110500E+04, 0.91651400E+04, 0.57290200E+04, 0.88233900E+04, 0.13517700E+04, -.64796500E+04, -.37303200E+04, 0.84395200E+04, 0.27401200E+05, -.13646800E+05, -.13494300E+05, 0.25531500E+03, 0.12406400E+04, -.86134500E+04, -.39555500E+04, -.11488000E+05, -.11763800E+04, 0.73969500E+04, -.36784300E+04, -.37619300E+04, -.31834000E+04, -.47213700E+04, -.13923100E+04, -.38322600E+03, -.11813700E+04, -.42577400E+04, -.31345100E+04, 0.14299600E+04, 0.15477200E+04, -.37106900E+04, 0.29862500E+04, 0.53226000E+03, 0.40861700E+04, -.12636500E+04, 0.22464300E+04, -.68507900E+04, 0.34006400E+04, 0.35191600E+04, 0.87491300E+03, -.19014200E+04, 0.33811600E+04, 0.20265100E+04, 0.51928100E+04, -.25242700E+04, -.30665000E+04, 0.15691500E+04, 0.19012900E+04, -.92100300E+02, -.10360700E+03, 0.12731200E+04, 0.17099100E+04, 0.20753200E+04, 0.36787100E+03, 0.55413200E+04, -.27560700E+04, -.27931000E+04, -.36005700E+04, -.48415700E+04, 0.53995200E+03, 0.29525400E+04, 0.23093300E+04, -.33299900E+04, -.45582700E+04, 0.22937500E+04, 0.24931200E+04, -.24279100E+04, -.39501700E+04, 0.21969400E+04, 0.16146200E+04, 0.17252500E+04, -.32382300E+03, -.41028500E+05, 0.20255600E+05, 0.20483200E+05, -.96687100E+04, -.58951900E+04, 0.18283200E+05, 0.15022600E+05, 0.18262200E+05, 0.51290800E+04, 0.63169900E+04, -.32200000E+04, -.32317600E+04, 0.51159300E+04, 0.88048600E+04, -.47325000E+04, -.47458900E+04, -.58078200E+04, 0.54519700E+04, -.25488300E+04, 0.12808100E+04, 0.12720600E+04, 0.59080300E+04, 0.19960400E+04, -.17062400E+04, -.38284600E+04, 0.42460600E+03, -.16515800E+03, 0.35048800E+04, -.17782900E+04, -.16798800E+04, -.98933100E+03, -.95646900E+03, 0.48186500E+03, 0.10026700E+04, 0.26838500E+03, -.13915300E+04, -.51227900E+04, 0.25140700E+04, 0.24979100E+04, 0.15369900E+04, 0.30111500E+04, 0.10051700E+04, -.94191000E+03, -.83801600E+03, 0.19615300E+04, -.50023100E+04, 0.25949400E+04, 0.26203900E+04, -.59965800E+04, -.13517600E+05, 0.58541100E+04, 0.56589100E+04, 0.86282800E+04, -.79497100E+04, -.14035100E+05, 0.68736800E+04, 0.68600500E+04, 0.88131000E+03, 0.32288700E+02, 0.34476200E+04, -.34575000E+04, 0.21986800E+04, 0.26801500E+04, -.21772500E+04, 0.31260300E+04, -.81172900E+03, 0.69370600E+03, -.22885200E+04, -.22229600E+04, 0.10464600E+04, -.14938100E+04, 0.22047200E+04, 0.15290700E+03, -.56100400E+03, 0.74826700E+03, -.67701400E+03, 0.80816500E+03, 0.79121800E+03, 0.10460500E+04, 0.15511700E+04, -.72345200E+03, 0.18267000E+04, -.15918000E+04, 0.24253900E+04, 0.10861100E+04, 0.25246200E+04, -.32558900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19041700E+01, 0.12098300E+01, 0.81491200E+00, -.42124300E+01, -.11682700E+00, 0.29450800E+01, -.26664100E+01, -.70925800E+00, 0.19651000E+01, -.14902100E+01, -.29483200E+00, 0.19306600E+00, -.93025900E+00, 0.23225500E+01, -.93499000E+00, 0.49898300E+01, 0.24168400E+01, 0.73874900E+00, 0.15261600E+01, -.42829700E+01, -.42616800E-01, -.17199800E+01, 0.11459500E+01, 0.79260200E+00, 0.10245700E+01, -.34008900E+01, -.42927000E+00, 0.29865200E+01, 0.30164000E+00, -.99559000E+00, -.16465100E+01, -.15032400E+00, -.23622800E+00, -.32861100E+00, -.15236000E+01, 0.97113900E+00, -.28652800E+00, 0.66305100E+00, 0.40525300E+00, -.26195200E+01, -.30127600E+00, -.20715500E+00, -.10781400E+01, 0.60338600E+00, -.55646300E+00, 0.10729500E+01, 0.20611800E+00, -.90701600E-01, 0.75150700E+00, -.47597600E+00, 0.14413100E+00, 0.21088600E+01, -.33086100E+00, -.32325500E+00, -.15952300E+01, -.68306100E+00, -.23298000E+00, -.64804200E+00, -.17164700E+01, -.60620300E+00, 0.75762700E-01, 0.70883800E-01, -.31385400E+00, -.13582700E+05, 0.66928100E+04, 0.67921500E+04, -.39438800E+04, -.30242700E+03, 0.61723100E+04, 0.54841200E+04, 0.65849000E+04, 0.91997000E+03, -.52043500E+04, 0.25950500E+04, 0.25574600E+04, 0.14260800E+04, 0.22101400E+04, 0.50773300E+03, -.12444200E+04, -.11216900E+04, 0.19122200E+04, 0.76050200E+04, -.37713800E+04, -.40644300E+04, 0.35729600E+03, -.28877300E+04, -.17774700E+04, -.10880600E+04, -.21286100E+04, -.23406100E+04, 0.49557100E+03, -.24289000E+03, -.17769900E+03, -.38251600E+03, -.44150000E+03, -.14932000E+03, -.21749200E+03, -.64957400E+03, -.16970400E+03, -.21893300E+04, 0.10450700E+04, 0.10410600E+04, -.10733500E+04, 0.75013500E+03, -.98557200E+01, -.14297100E+04, -.58357800E+03, 0.18003600E+04, 0.48930300E+03, -.23639200E+03, -.24914300E+03, 0.31185600E+03, -.14301900E+04, -.79535600E+02, 0.11059800E+03, 0.50639600E+02, -.97161100E+03, 0.12760400E+03, -.42729400E+02, -.26249700E+03, 0.89227800E+03, 0.72002200E+03, -.55692100E+03, -.70696400E+03, 0.21932300E+03, 0.96048000E+03, 0.21262700E+04, -.10578100E+04, -.10253200E+04, -.10846500E+04, -.11353700E+04, 0.22767600E+02, 0.75529500E+03, 0.16207000E+04, -.10211400E+04, -.63498500E+03, 0.31797600E+03, 0.14494700E+03, -.65579600E+03, -.20649400E+04, 0.39889500E+03, 0.55582200E+03, 0.41416600E+03, -.10595900E+04, -.17256800E+05, 0.85412500E+04, 0.86417200E+04, -.41411000E+04, -.78877800E+03, 0.76502000E+04, 0.60747400E+04, 0.84297600E+04, 0.10644500E+04, -.63253600E+04, 0.31399900E+04, 0.32164100E+04, 0.15033800E+04, 0.16444000E+04, 0.97377900E+03, -.22508000E+04, 0.83380500E+03, 0.18440600E+04, -.16382700E+04, 0.81941700E+03, 0.81230500E+03, 0.15665900E+04, 0.32000300E+04, -.44771000E+03, -.83122100E+03, 0.23644700E+02, 0.20075900E+04, 0.11416600E+04, -.56285700E+03, -.36257200E+03, -.49110900E+03, -.64146200E+03, 0.34319500E+03, 0.88609000E+03, 0.76596200E+03, -.73238900E+03, -.19649400E+04, 0.96034200E+03, 0.10525100E+04, -.26762600E+03, 0.22091300E+03, 0.36224200E+03, -.18681600E+03, -.33099500E+03, 0.11116000E+03, 0.41934700E+04, -.20703200E+04, -.21629300E+04, -.18728600E+04, -.41992100E+04, 0.87900400E+03, 0.47486900E+04, 0.18911800E+04, -.37632800E+04, -.10887500E+04, 0.45125900E+03, 0.58117900E+03, 0.28172400E+03, 0.13792400E+03, 0.23855000E+03, -.55666100E+03, -.16534400E+03, 0.25326300E+03, -.72048900E+03, 0.66691100E+03, -.54487000E+03, 0.53064800E+03, 0.10293000E+03, -.54217500E+03, 0.56919200E+03, -.42770900E+03, 0.14779600E+04, 0.79749600E+03, -.51132400E+03, 0.56744900E+03, -.14639900E+03, -.58924900E+03, 0.72472200E+03, 0.30675500E+03, 0.20777700E+03, -.10315900E+04, -.17045400E+03, -.44794100E+03, -.58059400E+02, 0.62724700E+03, -.83343500E+01, -.64100800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12286700E+01, -.11724500E+01, -.14494800E+00, 0.26956400E+00, 0.91097400E+00, -.63205600E+00, 0.77625500E+00, 0.47633500E+00, 0.71501100E-01, 0.82867000E-01, -.85281000E-01, 0.41860100E+00, -.16691600E+00, 0.46079400E+00, -.14071200E+01, -.76441500E-01, -.11584600E+00, -.37978700E+00, 0.77807200E+00, 0.21380700E+01, 0.43874800E+00, 0.99549000E+00, -.35277800E+00, -.80976000E+00, 0.23043400E+00, -.81371100E+00, 0.43311300E-02, -.10433600E+01, 0.16520300E+01, -.75807900E-01, 0.54004000E+00, -.18764700E+00, -.72826400E+00, 0.13388700E+00, 0.55057700E+00, 0.19625700E+00, -.47642500E-01, -.29267300E+01, -.29667800E+00, 0.29203400E+01, 0.37332300E-01, 0.84336900E+00, -.12552900E+00, -.38870100E+00, -.14264600E+00, -.16559800E+00, 0.69190300E-01, 0.30967600E+00, 0.25154600E+00, -.30187200E+00, -.30615900E+00, -.50171500E+00, -.49640100E+00, 0.55765200E+00, 0.19597500E+00, 0.46845500E+00, 0.14553100E+00, 0.10157600E+01, -.24157100E-01, 0.79877800E+00, -.55612400E-01, -.14168000E+00, -.42737000E-01, 0.52843600E-02, 0.96286400E+02, 0.95580400E-01, -.21052000E+01, -.47743800E+03, 0.84674700E+02, 0.24470400E+03, -.15182200E+03, -.53422600E+03, 0.55702200E+03, -.27524600E+03, -.22261300E+03, -.22798000E+03, -.40041900E+03, 0.10649300E+03, 0.24834000E+03, 0.11926600E+04, -.22754800E+03, -.16545500E+04, 0.79696300E+03, 0.11012300E+04, -.30235700E+02, 0.14769200E+04, 0.55513000E+03, 0.74036900E+03, 0.64403800E+03, 0.11445100E+04, 0.19725600E+03, -.10231400E+03, -.16502400E+03, -.78359000E+02, 0.12979100E+03, -.18019800E+02, -.95279900E+02, -.43026300E+03, -.14379200E+03, 0.68535600E+03, -.28705200E+03, -.25615800E+03, -.27108000E+03, -.29911600E+03, 0.13640200E+03, 0.13908200E+04, 0.26641600E+03, -.52001000E+03, -.23184100E+03, 0.16211600E+03, 0.16256700E+03, 0.44751100E+01, 0.40071400E+03, 0.43900000E+02, -.15973300E+03, 0.17776400E+03, 0.39263500E+03, -.88909400E+03, 0.44343500E+03, 0.69520500E+03, -.43203700E+03, -.26081000E+03, 0.66174100E+03, 0.83437500E+03, 0.26844500E+03, -.26607900E+03, 0.51396000E+03, -.25548800E+03, -.37771800E+03, 0.79353800E+02, 0.53631900E+02, -.26946900E+03, -.11847200E+03, -.95306600E+03, -.41549100E+02, -.60605200E+03, 0.29442700E+03, 0.30130800E+03, -.13257700E+03, 0.36104000E+03, 0.39675400E+03, 0.43803200E+03, 0.56444100E+03, 0.16489600E+03, 0.27510400E+04, -.12498900E+04, -.13858400E+04, 0.38539700E+03, -.51927800E+03, -.10751400E+04, -.43237800E+03, -.15748000E+04, -.41872100E+03, 0.39998500E+04, -.19933800E+04, -.19399100E+04, -.82722300E+02, 0.47456600E+03, -.11730100E+04, 0.48283800E+03, -.10072600E+04, -.32831200E+02, 0.18720500E+04, -.87732500E+03, -.11671700E+04, 0.33842400E+03, -.12322400E+04, -.73536600E+03, -.97738400E+03, -.89991000E+03, -.10158500E+04, -.25691800E+03, 0.12841000E+03, 0.11933400E+03, 0.24892600E+03, 0.16454500E+03, -.14001100E+03, -.28088600E+03, -.31469800E+03, 0.27721000E+03, -.31254700E+01, 0.43175300E+01, -.34396400E+02, 0.32596000E+03, 0.10887600E+03, -.10731800E+02, -.70337300E+02, 0.16419700E+03, 0.11195200E+03, -.24820600E+04, 0.12207100E+04, 0.12511000E+04, 0.24760900E+03, 0.45027700E+03, 0.26605900E+03, -.18209200E+04, -.30656700E+03, 0.63749800E+03, -.10623200E+04, 0.55115100E+03, 0.70165300E+03, -.17589200E+03, -.36185900E+03, 0.35078600E+03, -.11662700E+02, 0.90879200E+03, 0.36767600E+02, 0.15935500E+03, -.17695600E+03, 0.79299400E+02, -.15641400E+03, -.31856700E+03, 0.16291700E+02, -.15853000E+03, 0.86745900E+02, -.71725100E+03, -.12265900E+03, 0.45757500E+03, -.12348800E+03, 0.26904500E+02, 0.26240500E+03, -.23944600E+03, 0.45839900E+02, 0.47199300E+02, 0.42827600E+03, 0.50951400E+03, 0.38752200E+03, 0.28250600E+03, -.14864700E+03, 0.53702200E+03, 0.94084600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.71737800E+00, 0.64934900E-01, 0.21798600E+00, 0.11083000E+01, 0.20768200E+00, -.97455200E+00, -.11815400E+00, -.11430300E+00, -.41552000E-01, 0.31425300E-01, -.38483900E+00, -.64454100E+00, -.35603700E+00, -.10009400E+01, -.33366400E+00, -.12667400E+01, -.41060700E+00, 0.36331800E+00, -.46427900E-01, -.16677700E+01, 0.26915200E+00, -.15324100E+00, 0.33979700E-02, 0.32710500E+00, 0.33001700E+00, -.17160900E+01, -.20250200E+00, 0.44883500E+00, 0.75199100E+00, -.49889200E+00, 0.10565200E-02, 0.11675400E-02, -.11964600E-02, 0.16968200E-03, 0.29803400E-02, -.90491100E-03, -.55811000E-02, 0.15923800E-02, -.60522300E-02, 0.14405700E-03, -.15064900E-02, 0.12783100E-01, -.93306200E-02, -.37697300E-02, -.47028500E-03, 0.26290300E-02, -.17818400E-02, 0.38911200E-02, -.37435200E-02, -.85818600E-02, -.15068200E-03, 0.51400300E-02, 0.35608700E-02, 0.35635400E-02, 0.83065200E-02, -.37568300E-03, 0.86677300E-03, 0.11907600E-01, 0.36975600E-01, -.16387500E-01, -.32958500E-02, -.12162800E-02, -.79026300E-03, -.50240800E-02, 0.70066400E-02, 0.27835500E+01, 0.16291100E+01, 0.27974900E+01, -.10186500E+01, -.57803000E+01, -.32286900E+01, 0.18267900E+01, -.77770900E+01, 0.39153900E+01, 0.42087300E+01, 0.42058600E+01, 0.69978100E+01, -.18355300E+01, -.36120700E+01, -.25330900E+02, 0.50436200E+01, -.17475500E+01, 0.10196700E+01, -.28581700E+00, -.80428200E+01, -.11596500E+02, 0.45265300E+01, 0.15877600E+01, 0.57462900E+01, -.11833100E+02, 0.37820800E+01, -.19351900E+01, -.15785400E+01, 0.39018500E+00, -.10929500E+01, -.22976800E+01, 0.24714600E+01, 0.12530400E+02, 0.52986900E+00, 0.10270400E+02, -.53706700E+01, -.46793300E+01, 0.24488200E+01, 0.92613600E+01, -.52825800E+01, -.70853900E+01, -.81240500E+01, 0.65274900E+01, 0.20425700E+00, -.50200100E+00, -.62793400E+00, 0.25431000E+01, -.60344300E+01, -.30491900E+01, -.21529300E+01, 0.55736200E+00, -.19918100E+01, -.31195000E+01, 0.14018600E+01, 0.63339000E-01, -.17938500E+01, -.29639800E+01, -.10657800E+01, -.46861000E+01, -.37463200E+01, -.17388500E+01, -.15328900E+02, 0.76144500E+01, 0.68959900E+01, 0.33598800E+00, 0.39914000E+01, 0.32525300E+01, -.31154100E+01, -.12005200E+01, 0.29453600E+01, 0.60592500E+01, -.27058500E+01, -.57602700E+01, -.19950900E+01, -.37051700E+01, -.77319100E+00, 0.36239100E+01, -.61769000E+01, -.44027900E+01, -.64736200E+01, 0.27679300E+01, 0.34244300E+01, -.79944500E+00, 0.42915300E+01, 0.20767700E+01, -.40848800E+01, -.20737600E+01, 0.35526900E+01, 0.15571900E+01, -.73558000E+00, 0.86027800E+00, -.15164700E+01, 0.17822700E+01, -.67989300E+00, -.25031500E+01, 0.17624000E+00, -.10932700E+01, -.13686600E+01, 0.19401300E+00, -.12877600E+01, 0.21407600E+01, 0.69870300E+01, -.30939000E-01, 0.22202200E+01, -.20325500E+01, 0.88360100E+01, -.92700600E+01, 0.42974400E+01, 0.57946700E+01, -.11426200E+01, 0.78660500E+00, 0.40563100E+01, 0.10190600E+01, 0.19931900E+01, -.11348900E+01, 0.39989700E+01, -.18948400E+01, -.14735300E+01, -.86587400E-01, 0.19490400E+01, 0.18957500E+01, 0.54440200E+01, 0.40319100E+01, -.30086500E+01, -.28794800E+02, 0.14448100E+02, 0.12779600E+02, 0.12729000E+01, -.97456900E+01, 0.10282900E+02, 0.98535900E+01, 0.11806700E+02, -.21635700E+01, 0.23980700E+02, -.11584200E+02, -.91801300E+01, 0.30655900E+01, 0.30316300E+00, -.82049000E+01, -.21074700E+01, -.15765100E+02, 0.22369800E+01, -.22236100E+01, 0.11414900E+01, -.13721500E+01, 0.16465400E+01, 0.16697200E+01, -.10124400E+01, 0.21870200E+01, -.17227600E+01, 0.30609800E+01, 0.13585000E+01, -.30142800E+01, 0.27139700E+01, 0.13711800E+01, -.28290300E+01, 0.36442000E+01, 0.67762400E+00, 0.14669100E+01, -.28291400E+01, -.36073300E+01, -.52999600E+01, -.15824200E+01, 0.23716200E+01, -.10905600E+01, -.19347300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21420900E+01, 0.33765900E+00, 0.52996700E+00, 0.98296700E+00, 0.17451900E+00, 0.81655000E+00, -.90228000E+00, -.17525000E+00, -.97001100E+00, -.71956200E-01, -.11470300E+01, -.52721200E-01, -.51742100E-01, -.57848000E+00, 0.13274100E+01, -.65514600E+00, -.23566700E-01, -.14011400E+01, 0.27700200E+00, -.12656700E+01, 0.58920300E+00, -.39625400E+00, -.21557800E+00, 0.44933400E+00, 0.15698400E+00, -.73634900E+00, -.36340300E+00, -.48668400E+00, -.40461200E+00, -.33307200E-01, 0.22717400E+00, 0.47241200E+00, 0.66938900E-01, -.16437900E+00, -.68198800E+00, -.48993800E+00, 0.44740300E+00, 0.13131100E+01, -.78011800E+00, -.40314100E+00, -.21584600E+00, -.26915300E+00, 0.19748000E+00, -.29771300E+00, 0.26267500E+00, 0.51103100E-01, 0.50523400E-01, -.22628900E-01, 0.59289300E-01, -.85766200E+00, 0.43307400E-01, 0.10575300E+01, -.91101200E+00, -.16644600E+00, -.11041300E+01, -.59048600E+00, -.78300100E-01, 0.70601100E+00, 0.13592700E+01, -.43178300E+00, -.96851900E-01, 0.17559300E-01, -.77355500E-01, 0.22105100E+00, 0.13317900E+00, 0.12390000E+00, -.81331200E+03, 0.14052900E+03, 0.61337100E+02, 0.93641600E+02, -.25253400E+03, 0.13699300E+03, 0.89641100E+03, -.44615700E+03, -.44314000E+03, -.15657700E+03, -.42283100E+03, -.24513600E+02, 0.42482900E+03, -.45694200E+03, -.38467900E+03, -.20931900E+04, 0.10530200E+04, 0.93355400E+03, -.38846700E+02, -.35710300E+03, 0.79722200E+03, 0.63866300E+03, 0.10155100E+04, -.12543400E+03, -.23345100E+03, 0.11425200E+03, 0.13919100E+03, 0.19286800E+03, 0.33991800E+03, -.20327500E+03, -.21651400E+03, -.19077700E+03, 0.34305400E+03, 0.10498500E+04, -.53261500E+03, -.53881800E+03, -.18533300E+03, 0.27543500E+03, -.10199000E+03, 0.53887000E+03, 0.29063300E+03, 0.12926100E+03, 0.94183000E+03, -.48774100E+03, -.53370400E+03, 0.22992400E+03, 0.10571600E+03, -.52051000E+03, -.61429300E+03, -.38277400E+03, 0.65657100E+02, -.87706500E+03, 0.43110700E+03, 0.29700000E+03, -.42838900E+03, -.20751700E+03, 0.11031700E+03, -.49554100E+02, 0.32154800E+03, -.99047100E+02, 0.74038000E+03, -.37084100E+03, -.33746500E+03, -.37009500E+03, -.16676400E+03, -.15774200E+03, 0.15650200E+03, -.21132600E+03, -.24141900E+03, 0.91468600E+03, -.42437300E+03, -.48748100E+03, -.17530100E+03, -.48040800E+01, -.25507800E+03, 0.65972100E+01, -.43901300E+03, 0.11214800E+01, 0.18262400E+04, -.91489500E+03, -.90439400E+03, -.91177400E+03, 0.30927900E+03, -.54457200E+03, -.10323400E+03, -.11616000E+04, 0.18723700E+03, 0.23460300E+04, -.11643400E+04, -.11680000E+04, 0.12183300E+03, 0.32536400E+02, -.61160800E+03, 0.14245200E+03, -.66551300E+02, -.31765100E+03, 0.22257600E+04, -.11350000E+04, -.99778700E+03, 0.37874400E+03, 0.12660800E+03, -.83761400E+03, -.79887200E+03, -.10285800E+04, -.62889100E+02, -.18197200E+04, 0.86912300E+03, 0.87133300E+03, 0.20388800E+03, 0.15226200E+03, 0.47648500E+03, 0.54206900E+01, 0.25076500E+03, 0.22100500E+03, 0.38906400E+03, -.18985600E+03, -.17924200E+03, 0.57858600E+03, 0.48724700E+03, -.12893600E+03, -.80921400E+02, -.55406000E+03, 0.32679900E+03, -.39499200E+04, 0.19717700E+04, 0.19249500E+04, -.13889200E+03, -.20426700E+03, 0.10746000E+04, 0.34838800E+02, 0.70665600E+03, 0.26081400E+03, 0.13291200E+04, -.63817000E+03, -.68624800E+03, -.16415400E+02, -.19818700E+03, -.36569000E+03, 0.16437000E+02, -.46995200E+03, -.45611900E+02, 0.11209800E+03, -.14981700E+03, 0.82449200E+02, -.83817000E+02, -.75376700E+01, -.14239700E+02, -.32334100E+02, 0.95206800E+02, -.78355200E+03, 0.12622000E+03, 0.25797100E+03, -.84908600E+01, 0.30757600E+02, -.50079500E+02, -.14951600E+03, -.97462800E+02, 0.53005300E+02, 0.31210200E+03, -.11214500E+03, 0.12035000E+03, -.16548600E+02, -.93327400E+02, 0.18769500E+01, 0.87414700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.86955700E+00, 0.16322600E+01, 0.65212300E+00, -.91118500E+00, 0.47621600E+00, 0.15476400E+00, -.53479600E+00, -.98563200E-01, 0.23381400E+01, -.34688000E+00, -.19935400E+00, -.11591300E+00, -.25205300E+00, -.32171100E+00, 0.11758700E+00, 0.26328400E+00, 0.21980000E+00, 0.77545600E+00, -.37095300E+00, -.19914000E+01, 0.31521000E-01, -.53302800E+00, -.12036400E+00, 0.29634500E+00, 0.35350300E+00, -.39804600E+00, 0.25313000E+00, 0.87955600E+00, 0.43890800E+00, -.97650300E-01, -.55358200E+00, 0.13688700E+00, 0.42916700E+00, 0.30461800E-02, 0.10925000E+00, -.89967400E-01, 0.69463800E-01, -.38406000E+00, 0.51311000E+00, -.84212500E-01, 0.93717700E-01, -.10200100E+01, 0.20672200E+00, 0.77132700E-01, 0.60267600E+00, 0.62546900E-01, 0.50483900E-01, -.11372600E-01, 0.73203700E+00, 0.87872200E+00, -.39705200E-01, -.40153800E+00, -.76683900E+00, -.19189300E+00, -.33000300E+00, -.46646000E+00, 0.97139800E-01, -.41157200E-01, 0.14550300E+01, -.88627700E-01, 0.79133500E-01, 0.13319700E+00, 0.45272800E-01, -.81681200E-01, -.69029500E-01, 0.13156000E+00, 0.74382600E-01, -.85994200E+03, 0.18289500E+03, 0.62794400E+03, 0.49010400E+01, -.67825100E+03, 0.26411600E+03, -.13073500E+03, -.98528400E+02, -.28259400E+03, -.21689700E+03, 0.26787900E+03, 0.69306700E+03, 0.14595900E+04, -.29005300E+03, -.13337600E+04, 0.66335700E+03, 0.76710300E+03, -.52088000E+03, 0.35998900E+03, 0.74380200E+03, 0.71696500E+03, 0.12937500E+04, -.16898300E+02, 0.42877100E+03, -.21597800E+03, -.24192000E+03, 0.75373700E+02, 0.28105000E+02, -.30345600E+03, -.24239600E+03, -.13836200E+04, -.53625000E+02, 0.35304800E+03, -.17653300E+03, -.13012000E+03, -.43818000E+01, -.10354200E+04, 0.16901100E+03, 0.52394700E+03, 0.11987600E+03, -.56965300E+03, -.70988600E+03, 0.33985900E+03, 0.34359600E+03, -.75955800E+01, 0.91720700E+02, 0.30390500E+03, 0.15250700E+03, 0.33308900E+03, 0.32137200E+03, -.12068800E+04, 0.59563100E+03, 0.65552100E+03, -.63106300E+02, -.24626500E+03, 0.50523800E+03, 0.34917700E+03, -.16649300E+03, 0.30652400E+01, 0.14105100E+04, -.70612100E+03, -.75528500E+03, -.27808500E+02, -.21019900E+03, -.56200600E+03, -.99954900E+02, -.50057300E+03, -.25500600E+03, 0.77814400E+03, -.37142100E+03, -.41121300E+03, -.17468500E+03, 0.20028500E+03, -.27600200E+03, -.14329900E+03, -.18726900E+03, -.32144000E+02, 0.28379100E+03, -.15020000E+03, -.14104900E+03, -.35630800E+03, -.10705300E+04, 0.21234100E+03, 0.11740300E+04, -.14876500E+03, -.10652600E+04, -.73225900E+02, 0.41343100E+02, 0.76011600E+02, -.45597000E+02, 0.19082000E+03, 0.23170200E+02, 0.51995100E+03, -.51483200E+03, 0.33515800E+02, 0.90821500E+03, -.46522300E+03, -.50994000E+03, 0.33785400E+03, -.37580300E+03, -.43071000E+03, -.44676200E+03, -.94476800E+03, 0.74051000E+02, -.99802600E+03, 0.47912200E+03, 0.48190200E+03, 0.11503800E+03, 0.25265500E+03, 0.21921100E+03, -.38573600E+02, 0.14041000E+02, 0.13602100E+03, 0.88881000E+03, -.43802000E+03, -.45260700E+03, 0.14411100E+03, 0.18539000E+03, -.47073900E+03, -.44986900E+03, -.54197100E+03, 0.36190200E+02, 0.14707900E+04, -.73374400E+03, -.76047600E+03, 0.61367800E+02, 0.92444500E+03, -.74067800E+03, -.12223800E+04, -.31451100E+03, 0.45518000E+03, -.70600900E+03, 0.36834500E+03, 0.43993100E+03, -.17297000E+03, -.26726200E+03, 0.35014200E+03, 0.25722500E+03, 0.11512700E+04, 0.72579700E+01, 0.18193600E+03, -.46655700E+03, 0.93789400E+02, -.11218400E+03, -.13823000E+03, 0.89697700E+02, -.10095800E+03, 0.10677300E+03, -.81222300E+03, 0.31268400E+03, 0.32476100E+03, -.86593800E+02, -.59163100E+02, 0.87599500E+02, -.92538300E+02, 0.78433800E+02, 0.14981800E+03, 0.42079800E+03, 0.31919200E+03, 0.17491700E+03, 0.12498400E+03, -.15098500E+03, 0.77828700E+02, 0.39062900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.34643000E+01, 0.54315200E+01, 0.24750800E+01, 0.27505700E+01, 0.19297800E+01, -.30961700E+01, -.15119500E+00, -.37647700E+00, 0.13420300E+01, -.55623200E+00, 0.45084900E+00, 0.52549500E+00, 0.91172000E-01, -.18272900E+01, 0.12738400E+01, -.24594000E+01, -.47400700E-01, 0.20818700E+01, -.26486200E+01, 0.21481900E+01, 0.70371400E+00, 0.11253100E+01, -.32651900E+00, 0.81276400E+00, 0.47318100E+00, -.10747800E+01, 0.58783300E+00, 0.63761900E+00, 0.47966300E-01, -.40869400E+00, -.12091400E+00, 0.64260700E+00, 0.30962400E+00, -.18523700E+00, -.62037500E+00, 0.57077200E-01, -.11359700E+01, 0.90517500E-01, -.10702400E-01, -.99756600E+00, 0.26032700E+00, 0.49042600E+00, -.30375400E+01, 0.58901400E-02, -.12805100E+01, 0.66440700E+00, 0.73059300E-01, -.17259600E+00, 0.20954000E+01, 0.14015500E+01, -.99223900E-01, 0.99736100E+00, -.16269800E+01, -.27089100E+00, -.21450200E+01, -.88528800E+00, -.18661300E+00, 0.31887600E+01, 0.64426100E-01, -.63347300E+00, -.42852600E-01, 0.52676200E+00, -.52202400E+00, 0.13710100E+01, 0.37896700E-01, -.50040800E-01, 0.23674800E+01, 0.39645300E+00, 0.11568300E+04, 0.40573200E+04, 0.15386900E+04, -.84209600E+03, 0.30375300E+04, -.15115000E+04, -.14003100E+04, -.85180200E+03, -.16673300E+03, -.81157300E+03, 0.51804100E+03, -.67289800E+03, -.21011600E+03, -.54494800E+04, 0.26709700E+04, 0.34649700E+04, 0.11452400E+04, 0.25872800E+04, 0.14898000E+04, 0.10257200E+04, -.15259700E+03, 0.27974000E+04, -.73694600E+03, 0.36447700E+03, 0.28426100E+03, -.37380900E+03, -.78588400E+03, 0.75292100E+03, 0.13192700E+04, 0.35329500E+04, -.76758600E+03, -.49941200E+04, 0.24893900E+04, 0.26092700E+04, -.14354100E+03, -.17190400E+04, 0.23657800E+04, 0.30207700E+04, 0.41043700E+03, -.71008700E+03, -.58311600E+03, 0.32770600E+03, 0.37383700E+03, 0.13357600E+03, -.19910000E+03, 0.30628100E+03, 0.46075200E+02, 0.85187700E+03, 0.17007700E+03, -.63413100E+04, 0.31539000E+04, 0.38225300E+04, -.14200700E+03, 0.24000200E+03, 0.26481500E+04, 0.17115000E+04, 0.20890800E+04, -.19090600E+03, -.33406900E+04, 0.16705100E+04, 0.14487200E+04, 0.99620200E+03, 0.92437200E+03, 0.48909300E+03, -.74445900E+03, -.12678400E+04, 0.10987300E+04, -.48613600E+03, 0.23351400E+03, 0.30105900E+03, -.54947800E+03, 0.11507900E+03, 0.37460500E+01, -.25042700E+03, -.54887800E+02, 0.29738500E+02, -.19374500E+04, 0.10114000E+04, 0.92825800E+03, 0.47721600E+03, -.73176000E+03, 0.20012100E+04, 0.50946200E+04, 0.24289800E+04, -.44891300E+03, 0.71288400E+04, -.35989600E+04, -.34676500E+04, 0.32168500E+03, 0.23931600E+03, -.18321500E+04, 0.12305800E+04, -.35284600E+04, 0.69814000E+02, 0.71216400E+04, -.34725500E+04, -.40264900E+04, -.21376300E+03, -.12188500E+04, -.24719600E+04, -.19877800E+04, -.15797700E+04, -.26099900E+04, -.34107500E+03, 0.15456900E+03, 0.82986900E+02, 0.47040900E+03, 0.47329100E+03, -.18498100E+03, -.82581100E+03, -.58078000E+03, 0.71609300E+03, 0.46409300E+04, -.23089600E+04, -.24640700E+04, -.46021400E+02, -.68966500E+03, -.12839800E+04, -.72436600E+03, -.67142900E+03, -.48404800E+03, -.74414700E+03, 0.40700800E+03, 0.45168000E+03, -.18251900E+03, 0.21685500E+04, -.12748300E+04, -.40938800E+04, 0.34891800E+03, 0.11357200E+04, -.29894300E+04, 0.15373000E+04, 0.18238100E+04, -.22907400E+03, -.30013300E+03, 0.10565400E+04, 0.51523100E+03, 0.10020600E+04, 0.96898600E+02, 0.35958900E+02, -.40046100E+03, 0.18163500E+03, -.12860500E+02, -.78362900E+03, 0.45502300E+03, -.30553200E+02, 0.16907800E+03, 0.79425000E+03, -.92686200E+03, 0.76584500E+03, -.40469100E+03, 0.14605000E+03, 0.19224000E+03, 0.17737100E+03, 0.17993600E+02, 0.47905200E+03, -.32083700E+03, 0.13591800E+04, 0.12443300E+04, 0.73966600E+03, -.24967400E+03, 0.10828500E+04, 0.32275500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.16114700E+00, 0.83346400E-01, -.97165000E-01, -.13773100E+01, 0.51856300E+00, 0.97847900E-01, -.18230600E+00, 0.44230300E-01, 0.41561500E+00, 0.15682100E+00, -.61060400E-01, 0.26390500E+00, -.13465100E+00, -.13098700E+00, -.68316900E-01, 0.18278500E+00, 0.16820300E+00, -.71289600E-01, 0.11340200E+00, 0.48905200E+00, 0.13572500E+00, 0.23143200E+00, -.80312900E-01, -.30128900E+00, 0.79422600E-01, -.40346200E+00, 0.22643700E+00, 0.38839900E+00, 0.64786800E+00, 0.62196100E-01, -.29648500E+00, -.42522200E-01, -.17814900E+00, 0.10151800E-02, 0.12954700E-01, 0.85361300E-01, -.44728000E+00, -.81187800E+00, -.85742000E-01, 0.93086100E-01, 0.18805100E-01, 0.13638700E+00, -.28916500E+00, 0.12037900E+00, -.24328000E+00, -.44675600E-01, 0.83982700E-01, 0.16883700E+00, 0.31311800E+00, 0.63567800E+00, 0.62177200E-01, 0.45543200E-01, -.44065500E+00, 0.83676400E-01, -.54441400E+00, 0.32897500E+00, 0.12241700E-01, -.64703400E+00, 0.94120200E-03, 0.39494000E-01, 0.16803400E-01, -.17616400E+00, 0.33435100E-01, -.62523300E-01, -.71378400E-01, 0.37493500E-01, -.18084700E+00, 0.10106800E+00, -.97078400E-01, 0.65399700E+02, 0.29720300E+02, 0.33197300E+02, -.12729700E+03, 0.62220900E+02, 0.45774900E+02, 0.35318200E+02, -.16449300E+02, 0.12372900E+02, -.47224600E+02, 0.23170600E+03, 0.12669800E+02, 0.59256500E+03, -.29866500E+03, -.36896000E+03, 0.16937400E+03, 0.57770700E+02, -.26566300E+03, -.14308700E+03, -.15309500E+03, 0.49792400E+01, -.10565800E+03, 0.54179300E+02, 0.47675800E+02, 0.85017700E+01, 0.42769600E+02, 0.66589100E+02, -.76888700E+02, -.23769500E+03, 0.10261900E+02, -.22973500E+02, 0.15727200E+02, 0.66776700E+01, -.43277100E+02, -.12843200E+02, -.27584600E+02, -.14087900E+02, -.19633500E+02, -.54829300E+02, -.60229100E+02, 0.41265400E+02, 0.36572100E+02, -.52653600E+02, 0.13678300E+03, 0.61918400E+02, 0.54757600E+02, -.22497600E+02, 0.19749200E+02, 0.16724800E+03, -.81287100E+02, -.13944600E+03, 0.10438700E+03, 0.51942000E+02, -.39465800E+02, 0.94212400E+02, 0.51201500E+02, 0.87326700E+02, 0.94645500E+02, -.46156400E+02, -.22111400E+02, 0.19606500E+02, -.10429400E+02, -.10392700E+02, 0.31963700E+02, 0.81282300E+02, -.75786800E+01, -.47221900E+03, 0.22881500E+03, 0.25834700E+03, 0.76933700E+02, 0.12901000E+02, 0.15559800E+03, 0.51432300E+01, 0.24985800E+03, 0.68815600E+02, 0.28597700E+03, -.13268000E+03, -.13899600E+03, 0.11157800E+03, 0.51830400E+02, -.15808300E+03, -.76299500E+02, -.74926200E+02, 0.22218000E+02, -.58303600E+02, 0.28487900E+02, 0.11311000E+01, 0.82646600E+02, 0.51273800E+02, -.34943300E+02, -.39306900E+01, -.14024600E+02, 0.34217200E+02, -.47007100E+03, 0.24524000E+03, 0.29428400E+03, 0.48948600E+02, -.37252900E+02, 0.12656900E+03, -.65631000E+01, 0.77032600E+02, 0.56517700E+02, 0.49418300E+03, -.23447500E+03, -.24607800E+03, -.48536000E+02, -.91485500E+02, -.13247400E+03, 0.29283600E+02, -.53538600E+02, -.77194300E+02, -.68185400E+02, 0.33163100E+02, 0.50901100E+02, -.39950900E+02, -.29381900E+02, -.83592900E+02, -.16080200E+03, -.12555300E+03, 0.14211900E+02, 0.57354200E+03, -.28847200E+03, -.27643500E+03, -.11174900E+03, -.86945700E+02, -.61367700E+02, 0.35702500E+02, -.68212600E+02, -.88336700E+02, -.19153900E+03, 0.80644400E+02, 0.34181900E+02, -.54359200E+02, 0.38174300E+02, 0.32518000E+02, -.44474100E+02, 0.49416800E+02, -.20372800E+02, -.61652200E-01, 0.74024800E+02, 0.13275300E+02, -.21631700E+02, 0.29806300E+02, -.34600400E+02, -.29133100E+02, -.20839700E+01, 0.15230000E+02, -.17562900E+02, 0.32172600E+02, -.22177800E+02, -.38244700E+02, 0.82654200E+02, -.42348200E+02, -.75296700E+01, -.76446900E+02, 0.17200900E+02, 0.55001600E+02, 0.54218700E+02, -.24680600E+02, -.32207200E+02, 0.37552600E+01, -.49259700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18312900E+01, -.12968700E+01, -.82862500E+00, 0.43210400E+01, -.20036100E+00, -.30186000E+01, 0.29633000E+01, 0.84436100E+00, -.19851200E+01, 0.17948600E+01, -.10382300E+00, -.67471000E+00, 0.71196400E+00, -.17758200E+01, 0.15051200E+01, -.38999200E+01, -.18606000E+01, -.51897300E-01, -.15698700E+01, 0.25186000E+01, -.86403400E-01, 0.10496600E+01, -.96047600E+00, -.10897500E+00, -.16361000E+01, 0.16446500E+01, 0.94967800E+00, -.76470700E+00, 0.10364900E+01, 0.43670300E+00, 0.55448400E+00, 0.65563900E+00, 0.15715200E-04, -.18689100E+00, -.21100600E+00, -.16102700E+00, 0.66999600E+00, 0.30559900E+01, -.30496600E+00, 0.97008900E+00, 0.18351300E+00, -.50304900E+00, 0.12933400E+01, -.12181200E+01, -.22034900E-01, -.63500900E+00, -.64947000E-01, -.13231300E+00, -.98228300E+00, -.78905600E+00, -.76791700E-02, 0.49248500E-01, 0.60391000E+00, -.92689400E-02, 0.43062000E+00, -.35798400E+00, -.20872800E+00, 0.30130700E+00, 0.13672500E+01, -.17819100E+01, -.21842600E+00, 0.60039100E-01, -.82297900E-01, -.28697700E+00, -.36594600E+00, -.42295400E+00, -.35321800E+00, -.12497200E+01, 0.33546100E-01, 0.30383000E+00, -.58274100E+03, -.13525400E+03, 0.34655300E+04, -.17249400E+04, -.16171300E+04, -.37963600E+03, -.41693800E+03, -.72768300E+03, 0.83750400E+03, -.11107000E+04, -.76432200E+03, -.16319100E+04, 0.80192100E+03, 0.11379300E+04, -.83168200E+03, 0.13724600E+04, 0.80759000E+03, 0.77120300E+03, 0.10992500E+04, -.10200100E+03, -.12612800E+04, 0.62311700E+03, 0.61457900E+03, 0.30927100E+03, 0.26448400E+03, -.95883400E+02, 0.42036400E+03, 0.20448700E+04, 0.37861400E+03, 0.28367600E+04, -.14346700E+04, -.13882200E+04, 0.30334600E+03, 0.71996100E+03, -.47384800E+03, 0.22623800E+04, -.10261200E+03, 0.11454600E+03, -.26248100E+04, 0.12582900E+04, 0.12661600E+04, 0.31308900E+03, -.45106900E+03, 0.65980400E+03, -.14376300E+02, 0.18982400E+04, 0.59927800E+02, -.33845300E+04, 0.16638900E+04, 0.19839700E+04, -.70494400E+03, -.43865000E+03, 0.15934500E+04, 0.12980100E+04, 0.28925600E+03, -.10345300E+04, -.22364200E+04, 0.11130100E+04, 0.10142000E+04, 0.30923400E+03, 0.63526700E+03, 0.17232200E+03, -.84206600E+03, -.21466600E+04, 0.82804200E+03, -.42856000E+03, 0.25621700E+03, 0.22793200E+03, -.10411500E+03, -.14847200E+02, 0.45533600E+03, 0.78616200E+03, -.26058900E+03, -.28356400E+03, 0.18468600E+03, -.12613100E+03, -.11429000E+03, -.27696800E+03, -.38309800E+03, 0.14574900E+03, 0.76638800E+03, -.96560400E+03, 0.21642900E+03, 0.14567000E+05, -.72823700E+04, -.72106900E+04, -.91519100E+03, -.14600900E+03, -.36298500E+04, 0.20531900E+04, -.23101000E+04, -.16935100E+04, 0.11798600E+04, -.60254800E+03, -.72589400E+03, -.88489600E+02, -.14930300E+04, -.19278800E+03, -.11235700E+03, -.86326900E+03, -.42841900E+03, -.16738200E+04, 0.76729700E+03, 0.75505200E+03, 0.10827600E+03, 0.45796100E+03, 0.35761100E+03, -.53259500E+03, -.17674500E+03, 0.27180700E+03, 0.19646400E+04, -.96417900E+03, -.10661900E+04, 0.43383700E+03, 0.37178600E+03, -.24776700E+03, 0.35224400E+03, 0.39460700E+03, 0.10593600E+03, -.14990900E+05, 0.75108100E+04, 0.74693000E+04, 0.81144300E+03, 0.71798500E+03, 0.31690700E+04, -.34382800E+04, 0.11124800E+04, 0.20018700E+04, -.16986400E+03, 0.19048000E+03, 0.26881000E+03, 0.15577400E+03, -.29025700E+03, 0.30674800E+02, -.14533600E+03, 0.10861300E+03, 0.25244700E+03, -.96704900E+02, 0.74553100E+02, 0.47924500E+02, 0.80018000E+02, 0.10939500E+02, -.11083400E+03, 0.11856900E+03, -.44878200E+02, -.32361300E+03, -.24071900E+02, 0.14480900E+03, 0.74859500E+02, 0.38575600E+03, 0.25736100E+03, 0.79247500E+02, 0.44523200E+03, 0.13688300E+03, 0.10658400E+03, 0.59628200E+03, -.14561300E+03, -.11395000E+02, 0.91396100E+02, 0.11101000E+04, -.22283800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.65050800E+00, 0.14378900E+01, 0.37765100E+00, -.28789800E+01, 0.75915800E+00, 0.14742400E+01, -.25795900E+01, -.60045300E+00, -.90050900E+00, -.41879700E+00, 0.21140900E+00, 0.58176200E+00, 0.17025400E+00, 0.16394800E+01, -.33275300E+00, 0.11209500E+01, 0.61846200E+00, 0.52701400E+00, 0.22950900E+00, 0.65825900E+00, -.97615500E-01, 0.48999500E+00, 0.11171100E+01, -.89146100E-01, -.52906000E-02, 0.98196500E+00, -.20673500E+00, -.56230500E+00, -.28535200E+00, 0.28139900E+00, 0.27952200E+00, -.31012300E+00, -.37530400E-01, 0.80242800E-01, 0.83949700E-01, -.25695300E+00, -.34763800E+00, -.77360100E+00, -.40570700E+00, 0.22116300E+00, -.47328200E-01, 0.77555000E+00, 0.20051300E+00, -.58545400E-01, 0.15639200E+00, -.32450500E+00, -.53893000E-01, 0.52682600E+00, 0.11727500E+00, -.88389000E-02, 0.63054600E-01, -.19124700E+00, -.13903500E-01, 0.26378000E-01, 0.34045300E+00, -.52434700E-01, 0.41676300E-01, 0.61571100E+00, 0.29082500E+00, -.42457800E-01, 0.52464000E-01, 0.25590000E+00, 0.39947800E-02, -.69624200E-01, 0.44480600E-01, -.15173000E+00, 0.10669000E+00, -.39038700E-02, 0.45815700E-01, -.14501400E+01, 0.63035200E-01, -.19745200E+03, -.36376900E+03, 0.18039100E+03, 0.14907000E+03, 0.15077700E+03, -.56221500E+02, 0.14670000E+02, 0.52215200E+02, 0.11666200E+03, 0.95682400E+02, 0.47761700E+03, -.23756500E+03, -.33788600E+03, -.16120200E+03, -.71692700E+03, 0.88690800E+02, 0.14840800E+03, 0.31550600E+03, -.43312200E+03, 0.10414500E+03, -.51089600E+02, -.51993000E+02, -.59354200E+02, 0.17842200E+03, 0.32351600E+02, -.17154700E+03, -.32937400E+03, -.21550800E+02, -.22638000E+03, 0.11483400E+03, 0.87441400E+02, -.14409000E+03, -.23510200E+02, -.56235100E+02, -.44763400E+03, -.31509100E+02, -.61224400E+02, 0.73991400E+03, -.36171500E+03, -.36411800E+03, 0.14563700E+03, 0.22588800E+03, -.46593900E+03, -.39229400E+03, -.76581900E+03, 0.22299500E+03, 0.30285800E+03, -.15229800E+03, -.22965300E+03, -.81349500E+02, -.29693100E+03, -.15605200E+03, 0.18537400E+02, -.10522400E+03, 0.13011200E+03, -.39853600E+02, 0.20854400E+02, 0.83945900E+02, 0.31680400E+02, 0.24671600E+03, -.57412600E+02, -.10594900E+03, 0.10040100E+03, 0.40566500E+02, -.26244100E+03, 0.13365600E+03, 0.21736500E+03, -.17644000E+03, 0.76114000E+02, 0.10933500E+03, 0.36555300E+02, 0.10631000E+03, 0.56546500E+02, 0.13834800E+04, -.67611700E+03, -.68898100E+03, 0.27682800E+03, 0.32958300E+03, -.68359300E+03, -.71172200E+03, -.64145400E+03, -.59243700E+02, -.14239800E+04, 0.71165100E+03, 0.63235300E+03, 0.55749600E+02, -.73541700E+02, 0.38059200E+03, 0.11602000E+03, 0.47609200E+03, -.46399800E+02, 0.16841500E+03, -.79104100E+02, 0.64967000E+02, 0.55064100E+03, 0.34066000E+03, -.35787500E+03, -.49916300E+03, -.44244700E+03, 0.39596900E+03, 0.30153700E+03, -.14291000E+03, -.19757300E+03, -.72127700E+02, -.21441500E+03, 0.47580100E+02, 0.23143200E+03, 0.76295700E+02, -.20173300E+03, -.11488500E+03, 0.59431900E+02, 0.70202500E+02, -.10423300E+02, 0.16976800E+03, -.82932500E+01, -.91643800E+02, -.23645800E+02, -.16988300E+03, 0.20302100E+04, -.10156600E+04, -.96953400E+03, -.29686400E+02, -.51238000E+02, -.43434200E+03, 0.86606500E+02, -.43164200E+03, -.22471700E+01, 0.97025100E+03, -.49167100E+03, -.63558600E+03, -.27150900E+02, -.29895600E+02, -.36552100E+03, -.78396200E+02, -.47908000E+03, 0.65340200E+02, -.75580400E+01, -.44122100E+02, 0.33841100E+02, -.80053600E+02, -.81752100E+02, -.59928500E+02, -.58173800E+02, 0.36941500E+01, -.13570000E+03, 0.31686200E+02, 0.15902500E+03, -.19758000E+02, -.10370100E+03, 0.69341800E+01, -.89447800E+01, -.12304000E+03, 0.38648200E+02, 0.55580900E+02, 0.16785500E+02, 0.87125500E+02, 0.88982600E+02, -.53463600E+02, -.13462300E+03, 0.19523200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23128600E+00, -.50582800E-01, -.72920600E-01, 0.13491300E+01, -.96826400E+00, 0.88828700E-01, 0.49803800E-02, -.12986700E+00, -.62104700E+00, -.64805600E+00, 0.20063400E+00, 0.55261800E-01, 0.23699000E+00, 0.81314500E-01, 0.19354800E+01, 0.21704400E+00, -.69650700E-01, 0.31845800E+00, -.72729400E+00, -.57897300E+00, -.13631600E+00, -.71419800E-01, 0.20819600E-01, 0.35347500E+00, -.24959200E+00, 0.79872800E+00, 0.12623700E+00, -.21456900E+00, -.24016600E+00, 0.26230600E+00, 0.36233400E-02, -.67560500E-01, -.68025000E-01, -.40155200E-01, -.34921700E-01, 0.92730600E-01, 0.97233300E-01, -.24732400E+00, 0.41228600E-01, 0.44307100E+00, 0.30292300E-01, -.19535400E+00, 0.30465200E+00, -.20811400E+00, 0.28133700E+00, -.14220600E+00, 0.37363600E-01, 0.20862900E+00, 0.27690600E+00, 0.63729900E+00, -.81524000E-01, -.55347200E+00, -.28933900E+00, 0.39438700E-01, -.36405200E+00, -.33186500E+00, 0.51809900E-01, 0.24281100E+00, -.14850600E+01, 0.62523900E+00, 0.10425700E+00, 0.25924300E+00, 0.43766000E-01, 0.57783400E-01, -.33653600E-02, 0.80175500E-01, 0.35057500E+00, 0.26542400E+00, -.75707300E-02, -.57940200E-01, -.12013900E+00, 0.15545300E+00, 0.10311800E+04, -.51354500E+03, -.51628300E+03, -.28668500E+03, -.14907500E+03, -.18895500E+03, 0.25941600E+03, -.10047200E+03, -.30210800E+03, -.22797800E+04, 0.11360300E+04, 0.11100200E+04, 0.19235500E+03, -.10057100E+03, 0.75178200E+03, 0.41179100E+03, 0.76487800E+03, 0.19913900E+03, -.55920700E+03, 0.27794900E+03, 0.31004400E+03, 0.51220600E+02, 0.10460300E+01, 0.10560600E+03, 0.17692200E+03, 0.45450400E+03, 0.98780100E+02, -.13528400E+03, 0.63001700E+02, 0.44547000E+02, 0.31210600E+03, -.21436500E+02, 0.95082300E+02, 0.29118000E+03, -.15343900E+03, 0.30686600E+03, 0.37221400E+02, -.25695700E+02, -.31801200E+02, 0.26806700E+02, -.11357800E+03, 0.49207100E+02, 0.45984800E+02, 0.23544000E+03, -.11709100E+02, -.59123600E+03, 0.29089700E+03, 0.26687600E+03, 0.10621000E+03, 0.28815800E+03, 0.10455200E+03, -.14560400E+03, -.14206900E+03, 0.10934700E+03, -.52404800E+03, 0.26134700E+03, 0.27541800E+03, 0.14107300E+03, 0.93670800E+02, 0.46288600E+02, -.18152700E+03, -.31040200E+03, 0.21825200E+03, -.49702200E+02, 0.25799300E+02, -.16468700E+01, -.42229500E+01, -.62828900E+02, -.17078000E+02, -.67713000E+01, -.57781800E+02, -.35770400E+02, -.12442200E+04, 0.61663600E+03, 0.62225100E+03, -.15378400E+03, -.21773200E+03, 0.63377300E+03, 0.70059000E+03, 0.61152200E+03, -.23124300E+03, 0.21679200E+04, -.10856800E+04, -.10808000E+04, 0.14300400E+02, -.13477800E+03, -.52980300E+03, 0.30346900E+03, -.62673000E+03, -.11141000E+03, 0.13597900E+04, -.67760800E+03, -.67305200E+03, -.26487800E+03, 0.18575200E+03, -.41615300E+03, -.18368500E+03, -.43324400E+03, -.20426200E+03, -.39855900E+03, 0.19572100E+03, 0.21005600E+03, 0.13199100E+02, 0.62378300E+02, 0.11281600E+03, -.89004600E+02, 0.33332200E+02, 0.14264100E+02, 0.34327800E+03, -.16939700E+03, -.16654600E+03, -.14156600E+02, -.17939500E+03, -.11266500E+01, 0.20720800E+03, 0.25298700E+03, -.84265400E+02, -.19414100E+04, 0.97450300E+03, 0.96562000E+03, -.11408100E+03, 0.20873100E+03, 0.38028500E+03, -.40540800E+03, 0.44191700E+03, 0.15099800E+02, 0.19520800E+03, -.75893100E+02, -.77179400E+02, 0.80075900E+01, 0.81056800E+02, -.23778100E+02, 0.98904400E+02, -.61123500E+02, -.88961400E+02, 0.15882400E+02, -.39064500E+02, -.19721900E+01, 0.71186500E+02, -.68914700E+02, 0.12850100E+03, 0.15103900E+02, 0.21912100E+02, 0.92848300E+02, -.60638400E+02, 0.61095500E+02, -.51868800E+02, 0.14227700E+03, -.90739500E+02, 0.79909300E+02, 0.78263600E+02, 0.14071000E+02, -.98086200E+02, 0.17944400E+03, 0.21099300E+03, 0.65613700E+02, 0.96642500E+01, 0.22548900E+03, 0.65840500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12980500E+01, -.67881400E-01, 0.56518200E-02, -.28288600E+00, 0.71701800E+00, 0.73102000E+00, -.18042800E+00, -.81323100E-01, -.22818400E+01, -.34075800E-01, -.30699500E+00, 0.67309100E-01, 0.57368100E+00, 0.11633900E+01, -.15986400E+00, -.30464900E+00, -.33814100E-01, -.72719400E-01, 0.13389300E+00, 0.77647100E+00, 0.25910000E+00, 0.34281400E+00, -.15260100E+00, -.31181400E+00, 0.29003600E+00, -.43421300E+00, 0.24037300E+00, -.29189500E+00, -.16418400E+00, 0.22315800E+00, 0.31639900E-01, -.29623100E+00, -.32046300E+00, 0.11415300E+00, 0.17435000E+00, -.24308500E-01, -.41710900E+00, 0.12218100E+01, 0.22598100E+00, 0.10222500E+00, 0.34814200E-01, -.13557300E+00, 0.45303300E+00, -.35461900E+00, -.32372700E+00, 0.72662600E-01, 0.71484000E-01, 0.84271200E-01, -.54573500E+00, -.24945800E-01, -.11152400E+00, -.90067400E-01, 0.23763000E+00, 0.32480100E-01, -.16548600E+00, -.12013100E+00, 0.82290500E-01, -.24236300E+00, 0.15476100E+01, -.48459400E-01, -.58995200E-01, -.20138700E+00, -.68373100E-01, -.91010700E-01, -.16779600E+00, 0.20455600E+00, 0.41319600E-01, 0.43977100E+00, -.61092000E-01, 0.10792200E+01, -.34808700E-01, 0.22908300E+00, 0.21259900E+00, 0.26621800E+01, 0.31596200E+02, 0.97593300E+02, 0.81139800E+02, -.62269400E+02, -.51157000E+02, -.64396900E+03, 0.13379900E+01, -.25541000E+02, 0.18103600E+02, 0.16293200E+03, -.18174600E+03, -.52171900E+03, 0.14793300E+03, 0.49055400E+02, -.28259000E+03, -.16235000E+03, 0.94276600E+02, -.49983200E+02, -.67102000E+02, -.53393200E+02, -.37249900E+02, -.79176100E+02, -.26217100E+01, 0.43697000E+03, 0.10136900E+03, -.53746400E+03, 0.26315700E+03, 0.31491300E+03, -.17623200E+03, -.40352400E+01, 0.83094300E+02, -.19460900E+03, -.31529000E+02, 0.30276800E+03, 0.48976300E+03, -.25148400E+03, -.21035500E+03, 0.10092700E+03, -.91592900E+02, -.22524300E+03, -.16109600E+03, 0.17062400E+02, -.93138300E+02, 0.78723900E+03, -.39276500E+03, -.23953800E+03, -.61024700E+02, -.34257900E+03, -.22206800E+03, -.12106000E+03, -.51676700E+02, -.11281500E+03, -.56530000E+03, 0.28036300E+03, 0.18343800E+03, -.15227400E+02, 0.11089000E+03, 0.14037300E+03, -.99486000E+02, -.25729500E+03, 0.16779200E+03, 0.70519500E+03, -.32555100E+03, -.45696600E+03, -.75136200E+02, -.10938500E+03, -.18024700E+03, 0.73238700E+02, -.21560700E+03, -.50178400E+02, -.65663500E+03, 0.32172700E+03, 0.32292800E+03, -.27987100E+03, 0.44935100E+02, 0.28491200E+03, 0.19556700E+03, 0.23506000E+03, 0.46356400E+02, -.13464900E+04, 0.67376100E+03, 0.77732300E+03, -.30894600E+03, -.25824900E+03, 0.48682500E+03, -.39754000E+02, 0.74712400E+03, -.51188400E+02, 0.25503700E+03, -.13925800E+03, -.36847100E+03, 0.11296300E+03, 0.39773000E+03, -.13866800E+03, -.13134400E+03, 0.11410900E+03, 0.94216800E+02, -.10084500E+04, 0.45069300E+03, 0.61351500E+03, -.86157300E+02, -.10441400E+03, 0.45622300E+03, 0.40974500E+03, 0.69984800E+03, -.17710700E+03, -.50271900E+03, 0.25136200E+03, 0.23891500E+03, -.36112900E+02, 0.23661800E+03, 0.31459800E+03, 0.36497900E+03, 0.49522200E+03, -.79613700E+02, 0.38795400E+03, -.19324000E+03, -.23337600E+03, 0.45416300E+03, 0.18072800E+03, -.16612800E+03, 0.15546000E+03, -.53962800E+03, 0.75628700E+01, 0.56177500E+03, -.27414300E+03, -.92994300E+02, 0.73895700E+01, -.94561100E+01, -.13125600E+03, 0.87554200E+02, -.19435200E+03, -.11219000E+02, 0.33736800E+02, -.18879800E+02, -.48383200E+02, 0.69004100E+02, -.48994500E+02, -.15657400E+01, 0.46690700E+02, 0.31977700E+02, 0.50465700E+02, 0.78382800E+02, -.25318900E+02, 0.41621200E+02, -.50887900E+02, -.10660100E+03, 0.10608200E+03, 0.61299200E+02, 0.86769800E+02, -.74241900E+02, -.12934100E+03, -.83042400E+02, 0.46899100E+02, 0.12007900E+03, -.44447900E+02, 0.37576400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25967600E+01, 0.29972500E+01, 0.13042000E+01, -.76211900E+00, 0.13581900E+01, -.18397800E-01, -.52439500E+00, -.40314800E+00, 0.13842900E+01, 0.72965200E+00, -.99184700E+00, -.14671800E+01, -.82344900E+00, -.30630000E+01, -.32650900E+00, -.46114600E+01, -.18246800E+01, 0.18950000E+01, -.47013100E+00, 0.11929900E+00, 0.25176700E+00, 0.10069500E+01, -.18774500E+01, -.50374100E+00, 0.47994500E+00, -.17631100E+00, 0.34555100E+00, 0.32958900E+00, 0.14595700E+01, 0.19973600E+00, 0.43715000E+00, -.11513400E+00, -.54684800E+00, -.93179300E-01, -.87568900E+00, 0.50697000E-01, 0.12511900E+01, -.12368500E+01, -.44738000E+00, 0.41937900E+00, 0.11622000E-01, -.71911300E+00, 0.13682000E+01, -.80364500E+00, 0.24401500E+00, -.28402300E+00, 0.18521000E+00, 0.56598400E+00, -.47221000E+00, -.18061700E+01, -.13980600E+00, -.57295300E+00, -.42171800E+00, 0.48066000E+00, -.17022700E+00, -.51720600E+00, -.18276300E-01, -.34065200E+00, -.27902700E+01, 0.12857000E+01, 0.99531700E-01, 0.14636200E+00, -.24795900E+00, 0.62735500E+00, -.42657700E-01, -.22463700E+00, -.14849200E+00, -.23448500E+00, 0.40417300E+00, 0.98887300E+00, 0.35884800E+00, -.29624100E+00, -.16531400E+01, 0.11439700E+00, -.93350200E+02, -.19744400E+03, -.34319900E+02, 0.15856500E+03, 0.24051300E+03, 0.73333300E+03, -.17786100E+03, -.15429500E+04, 0.78434500E+03, 0.30373600E+03, 0.20064600E+03, -.67921900E+03, 0.66710500E+03, 0.38245900E+03, 0.83244500E+03, 0.12112900E+03, -.10751300E+04, 0.53755000E+03, 0.67688300E+03, 0.21047600E+03, 0.28728900E+03, 0.46769800E+02, -.30878100E+03, -.15088500E+04, 0.41827300E+03, -.59748200E+03, 0.31158800E+03, 0.14733600E+03, 0.18539200E+03, -.39448900E+03, 0.30985900E+03, 0.16993400E+03, 0.45058100E+02, 0.39867800E+03, 0.56351600E+03, -.29301200E+03, -.34585100E+03, 0.90270000E+02, 0.79280300E+03, -.13586400E+03, -.13010300E+03, -.22562500E+03, 0.23728300E+03, -.53378900E+03, 0.26839100E+03, -.15232800E+03, 0.25271100E+03, 0.84116300E+03, -.10563400E+03, -.15966900E+03, 0.47212800E+02, 0.37242600E+03, 0.14245200E+04, -.71079300E+03, -.51728200E+03, -.33121100E+03, -.76872800E+03, -.19217900E+03, 0.63524100E+03, 0.63300900E+03, -.40275300E+03, -.62714000E+03, 0.29354200E+03, 0.27793100E+03, 0.65651300E+02, 0.17165900E+03, 0.10913800E+03, -.20716000E+03, 0.26657000E+03, 0.31388000E+03, -.10214000E+04, 0.50782100E+03, 0.52841000E+03, 0.11466200E+03, -.55027800E+03, 0.60222900E+03, 0.78304800E+03, 0.58328300E+03, -.67927200E+03, 0.89523500E+03, -.43940200E+03, -.54523100E+03, 0.76196200E+03, -.18366800E+03, -.45273400E+03, 0.81796300E+02, -.41331600E+03, 0.23040800E+03, 0.21528500E+04, -.10895000E+04, -.75257200E+03, 0.33350200E+03, 0.55990700E+03, -.10426800E+04, -.84076900E+03, -.82942200E+03, -.31163800E+03, 0.81850800E+02, -.26357800E+02, -.82515200E+01, -.13463200E+03, -.17416600E+03, 0.12591900E+03, 0.40625900E+02, -.11341600E+03, -.16049100E+03, -.10265100E+03, 0.48189100E+02, 0.12730400E+03, 0.23017200E+03, -.27525700E+03, -.19141700E+03, -.23500100E+03, -.45370300E+03, 0.37748200E+03, 0.28559800E+03, -.15070800E+03, -.14524500E+03, -.11676600E+04, -.31204200E+02, 0.39858700E+03, 0.51441400E+03, 0.11414000E+04, -.83687300E+03, 0.84700200E+03, -.44666000E+03, -.63505200E+03, -.48961100E+02, 0.46660600E+03, -.26555400E+03, 0.63271500E+02, -.53751600E+03, -.28785000E+03, 0.30624700E+03, 0.85291800E+02, 0.13969700E+03, -.14937900E+02, -.31666600E+01, 0.10866400E+03, -.23492800E+03, 0.28211700E+03, -.11495600E+03, -.79081300E+02, 0.12199800E+03, -.34122400E+03, -.31366900E+02, -.95618900E+01, -.32063800E+03, -.20484500E+03, -.16829300E+03, 0.77260600E+02, 0.25052300E+03, 0.30825600E+03, 0.24287600E+02, -.24616700E+03, -.24706000E+02, 0.86082800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25481600E+01, 0.23759400E+01, 0.10779800E+01, -.62119600E+01, -.10559900E+00, 0.47861200E+01, -.54432300E+01, -.15515400E+01, 0.23257800E+01, -.18071500E+01, 0.26685200E+00, 0.81780400E+00, -.72586200E+00, 0.93127500E+00, -.10814100E+01, 0.31604200E+01, 0.22406200E+01, 0.11473300E+01, 0.23851400E+01, 0.10690300E+01, 0.42388600E+00, 0.29931200E+00, 0.16367400E+01, -.89145100E+00, 0.11268500E+01, -.17933800E+01, 0.35108800E+00, 0.33105800E+01, 0.29928500E+01, -.10857200E+01, -.17914500E+01, 0.11552500E+01, 0.87429500E-01, -.68971700E+00, -.14363900E+01, 0.12389400E+01, 0.19710100E+01, 0.12041300E+01, 0.11342700E+01, -.25105200E+01, 0.99313000E+00, -.88193800E+00, 0.12803500E+01, -.82408400E+00, -.98425800E+00, -.12353100E+00, 0.62540100E+00, 0.14140300E+01, 0.47072700E+00, -.15984400E+00, 0.21007100E+00, 0.60848600E+00, -.13310200E+01, 0.84304200E+00, -.13532600E+01, -.35956300E+00, 0.61697200E-01, -.13515700E+01, -.99083500E+00, 0.78418900E+00, 0.15393600E+00, -.86019000E+00, -.27410500E-02, -.33767200E+00, -.21375300E+00, 0.71085300E-02, -.66452400E+00, -.81487000E+00, -.31396100E-01, 0.17781500E+01, -.15695000E+00, 0.18733300E+01, -.30226000E+01, 0.15066300E+01, -.37675600E+00, -.10011700E+04, 0.64489500E+03, 0.42710100E+03, 0.13049900E+02, 0.18338000E+04, -.55860800E+01, -.27248200E+04, 0.13422000E+04, 0.11232500E+04, 0.78927500E+03, 0.23202300E+04, 0.43168500E+03, 0.34957400E+03, 0.94429200E+03, 0.10384000E+04, -.12617600E+04, 0.63116200E+03, 0.77182800E+03, 0.55239000E+03, -.27690800E+03, -.11146000E+03, 0.58763000E+03, -.14175400E+04, -.94348200E+01, 0.14499100E+04, -.71952300E+03, -.83632000E+03, 0.17492100E+04, -.64816400E+03, 0.21057600E+03, 0.17542300E+04, -.42890600E+03, 0.40174700E+03, -.26875500E+04, 0.13163000E+04, 0.12277100E+04, -.39058500E+03, -.84177200E+03, 0.16715100E+04, 0.12484300E+04, 0.24248600E+04, 0.52325300E+02, -.55160100E+04, 0.27465000E+04, 0.25008500E+04, 0.87697800E+03, 0.28198500E+04, 0.14366000E+04, -.83534500E+01, 0.10871600E+03, 0.97204500E+03, 0.29018300E+04, -.14481600E+04, -.13551600E+04, -.15435300E+03, -.14423700E+04, -.64111300E+03, 0.67018500E+03, 0.29937300E+03, -.84837000E+03, -.11139500E+04, 0.49436400E+03, 0.44710800E+03, 0.60943000E+03, -.65135500E+02, 0.39445800E+02, -.64076000E+03, 0.28138200E+03, -.82602800E+02, -.76546100E+04, 0.37711400E+04, 0.38356100E+04, -.10462900E+04, -.18702300E+04, 0.38782700E+04, 0.42501700E+04, 0.38275200E+04, -.11565400E+04, 0.72311200E+04, -.36255800E+04, -.36161500E+04, 0.75829200E+03, 0.84114900E+03, -.21781500E+04, 0.33309800E+03, -.35091600E+04, 0.70385300E+03, -.14891300E+04, 0.75773300E+03, 0.89638300E+03, -.28484200E+04, -.12475500E+04, 0.15994600E+04, 0.21759100E+04, 0.12664900E+04, -.97144800E+03, -.30801900E+03, 0.21184800E+03, 0.12828900E+03, 0.52848100E+03, 0.10870000E+04, -.60246900E+03, -.13145200E+04, -.12882300E+04, 0.87969600E+03, 0.11269800E+04, -.56250300E+03, -.53139800E+03, 0.41050200E+03, -.11461100E+04, -.71980900E+03, -.82868700E+03, -.99001700E+03, 0.61847600E+03, -.50067400E+04, 0.25168600E+04, 0.24444000E+04, -.17256500E+04, -.37818700E+03, 0.12628500E+04, -.61842200E+03, 0.31594000E+04, -.13415900E+04, -.54600100E+04, 0.27589500E+04, 0.27688800E+04, 0.34956100E+03, 0.42563700E+03, 0.17667500E+04, -.60761100E+02, 0.23966700E+04, 0.17270600E+03, -.12428700E+02, -.38761800E+02, -.89127700E+02, 0.20640200E+03, -.11002800E+03, 0.62409500E+03, 0.50301300E+02, -.54456100E+02, 0.22766400E+03, -.20883500E+03, 0.12302200E+02, -.97010400E+02, 0.78124500E+03, -.23195600E+03, -.60877500E+02, 0.32080500E+03, -.22874400E+03, -.20564900E+03, 0.89288800E+03, 0.72495300E+03, 0.48964400E+02, -.18913400E+03, 0.10026900E+04, 0.15606600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23501800E+01, 0.96914000E+00, 0.53944200E+00, 0.14309200E+01, -.34070400E+00, 0.46718200E+00, -.47709700E+00, 0.19371300E-01, -.64620900E+00, -.78855700E+00, -.47831400E+00, 0.56247000E+00, 0.61593100E+00, 0.45990100E+00, 0.31346800E+00, -.29963600E-01, 0.23781200E+00, -.74542100E+00, 0.29184900E+00, -.18002000E+01, 0.54436300E+00, -.49288300E+00, 0.44896000E+00, 0.50406500E-01, -.75196500E-02, 0.20033800E+01, -.14480400E+01, -.13222300E+01, -.25134000E+01, 0.21428900E+00, 0.43829400E+00, 0.87810500E+00, 0.42196100E+00, -.19835700E+00, -.47928500E+00, -.27709800E+00, 0.17603600E+01, 0.65077900E+00, -.33612100E+00, -.11435000E+00, -.57868300E-01, 0.16324800E+00, 0.39346200E+00, 0.42731500E+00, 0.71632000E+00, -.19705400E+00, -.15034800E+00, -.26219600E+00, 0.15739400E+01, 0.10175500E+00, 0.84889600E-01, 0.14657200E+00, -.10461400E+01, -.89843100E+00, 0.16660100E+00, 0.89809300E-01, 0.35466000E-01, -.97603300E+00, -.38145500E+01, -.45187700E+00, 0.11119500E+00, 0.32110100E+00, 0.15005300E+00, 0.34536400E+00, -.15133700E+00, -.21338600E+00, 0.14377400E+00, 0.55079900E-01, -.44188600E-01, 0.76045600E+00, -.75947900E-01, -.33284800E+00, 0.19798800E+01, -.98117600E+00, -.60601700E+00, -.88538400E-01, -.43651200E+03, 0.28647200E+03, 0.46366300E+03, 0.26186000E+04, -.14386100E+03, 0.36456000E+04, -.18099300E+04, -.18812400E+04, -.35305900E+03, 0.16058200E+04, -.13148800E+04, -.64431000E+03, -.85073300E+03, 0.46305300E+03, 0.33484000E+03, -.16597600E+03, -.17326600E+03, -.10876300E+03, 0.12687300E+02, -.72518800E+02, -.44100900E+03, -.16555600E+04, -.24952500E+03, 0.19123700E+03, -.91973200E+02, -.11201300E+03, -.52152700E+03, 0.50298300E+02, 0.19831100E+02, 0.53610100E+03, 0.87852400E+03, -.95460100E+03, -.13867000E+04, 0.68663900E+03, 0.68708000E+03, -.25769800E+03, 0.11118900E+04, 0.49419600E+03, 0.14901800E+03, -.24238500E+02, 0.33389500E+03, -.10648600E+04, 0.54076100E+03, 0.51317200E+03, -.56930100E+03, 0.26059200E+03, 0.84640900E+03, 0.11978500E+04, 0.81520000E+03, -.60967100E+03, 0.17456800E+04, -.87148600E+03, -.83901300E+03, -.16487500E+03, -.50350300E+03, -.38672700E+03, 0.40072500E+03, 0.15301200E+03, -.39093400E+03, -.71381700E+03, 0.35349000E+03, 0.43603900E+03, -.16356400E+02, 0.70333600E+03, 0.30584300E+03, -.85030300E+01, 0.57622400E+03, 0.27842200E+03, 0.39702600E+04, -.19859000E+04, -.19863400E+04, 0.11227100E+04, -.11469100E+03, -.19172900E+04, -.17364700E+04, -.18360400E+04, 0.31012700E+03, 0.15530200E+04, -.76914500E+03, -.83152200E+03, 0.40975000E+03, 0.24215500E+03, -.66577000E+03, -.72629700E+02, -.55230000E+03, 0.85042700E+02, -.12960600E+04, 0.63433800E+03, 0.74822900E+03, 0.10163900E+04, -.13742700E+04, 0.21211100E+03, -.27746200E+03, 0.36457100E+01, -.62111400E+03, 0.12658300E+04, -.64958500E+03, -.68529400E+03, 0.14380500E+03, -.18415500E+03, -.47369700E+03, -.36488400E+03, -.48978200E+03, 0.26676000E+03, 0.11276700E+04, -.57096100E+03, -.56436700E+03, 0.57643100E+03, -.22208900E+03, -.90164600E+03, -.12136600E+04, -.15491700E+04, 0.88546400E+03, 0.24470900E+01, -.42616300E+01, 0.22588600E+02, -.33532100E+03, 0.32453000E+03, 0.11498400E+03, -.53649400E+03, -.15081100E+03, 0.35067800E+03, -.12557500E+04, 0.58809200E+03, 0.53064300E+03, -.27137200E+03, -.23932200E+03, 0.42853600E+03, 0.75631600E+02, 0.12187400E+04, -.38879700E+03, 0.13244100E+03, -.25873500E+02, 0.21645900E+03, -.29012700E+03, -.48819300E+02, -.28072700E+03, -.23067300E+03, 0.13090100E+03, -.40022600E+03, 0.88091400E+02, -.25639000E+02, -.22102900E+03, -.28400900E+03, 0.64922400E+03, -.76553800E+03, -.72738400E+02, -.66301400E+02, 0.49837400E+03, 0.48722200E+02, -.34056000E+03, 0.43267000E+02, -.39102500E+03, -.14004600E+03, 0.68024600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.15500700E+01, -.80074100E+00, -.65438200E-01, 0.10798100E+01, -.73535300E+00, 0.39337500E+00, -.61293900E+00, -.34695000E+00, -.35809100E+00, -.12447400E+01, -.28550200E+00, -.31422200E-01, -.60232400E+00, 0.15091000E+00, -.50424900E+00, 0.77333300E+00, 0.56476900E+00, -.12343500E+01, 0.34120400E+00, -.11409100E+01, 0.37291300E+00, -.42337500E+00, 0.56479500E+00, 0.57024500E+00, 0.21438100E+00, -.11607400E+00, -.97570500E+00, -.35116000E+00, -.19963300E+01, -.49620500E+00, 0.81177200E+00, 0.20738300E+00, 0.47885300E+00, 0.16959500E+00, 0.81642300E-01, -.49294900E+00, -.88461000E+00, -.11345900E+01, 0.21891900E+00, 0.25307900E+01, 0.14338200E-01, 0.90824300E+00, -.85768300E+00, 0.72540800E+00, 0.31980500E+00, 0.23635200E+00, -.14098400E+00, -.60994100E+00, 0.79456000E+00, 0.54308800E+00, -.12282700E+00, 0.14065200E+00, -.67995100E+00, -.91873300E+00, 0.14248400E-01, 0.78049200E-01, 0.15141400E-01, 0.15805300E+01, 0.70429600E+00, -.96528500E+00, -.25490200E+00, 0.26690700E+00, 0.39327100E-01, -.49561300E-02, 0.35164500E+00, -.13561400E+00, 0.87455600E+00, 0.32336800E+00, -.12315200E+00, -.44070700E+00, 0.11209700E+00, -.67419500E+00, 0.68800900E+00, -.98771500E+00, 0.45601100E-01, -.26981600E+00, -.15681500E+00, -.19732800E+03, 0.17651800E+03, 0.35346300E+03, 0.23106300E+03, -.91197100E+03, 0.45733900E+03, 0.40909500E+03, 0.17682500E+03, -.68754500E+02, 0.19251300E+03, 0.45395800E+02, 0.13811700E+03, 0.30911700E+03, 0.45603800E+03, -.22682300E+03, -.19954400E+03, -.21577900E+03, -.31182900E+03, 0.23776400E+03, 0.39710800E+03, 0.75336000E+03, -.51214400E+03, -.15959100E+03, 0.79947100E+02, 0.34704700E+02, -.12903500E+03, 0.25702300E+03, 0.47901500E+02, 0.16813500E+03, -.44930300E+02, -.45622800E+03, 0.64083600E+03, -.31442100E+03, -.36178400E+03, -.43982300E+02, 0.37811400E+03, -.24329200E+03, -.22906600E+03, -.40372200E+03, -.52652000E+02, 0.18438800E+02, -.58149000E+01, -.67428100E+02, -.86670900E+02, 0.27882900E+03, -.90708900E+02, -.26069900E+03, -.89755500E+02, 0.13649800E+03, -.54219400E+02, 0.27939000E+02, 0.94235900E+02, -.31454200E+01, -.54254400E+02, 0.15998000E+03, 0.82945900E+02, 0.43540000E+02, -.12499800E+03, -.43020500E+03, 0.21243300E+03, 0.30611900E+03, 0.44539500E+02, 0.32354000E+03, 0.27367300E+02, -.51315300E+02, 0.10204200E+03, 0.19284400E+03, 0.29757600E+04, -.14765800E+04, -.14898300E+04, 0.83181500E+03, 0.62624600E+02, -.14378300E+04, -.13987500E+04, -.14307100E+04, 0.23929700E+03, 0.51757600E+03, -.25845800E+03, -.33392200E+03, 0.97714400E+02, -.17666700E+03, 0.23562800E+02, 0.20121500E+03, -.22212300E+03, -.10290500E+03, 0.15037700E+04, -.74764500E+03, -.57131800E+03, 0.15171200E+03, 0.11531400E+03, -.65570400E+03, -.47487300E+03, -.56893300E+03, -.30432500E+03, -.20040500E+02, 0.31100400E+01, -.10079000E+03, 0.28329500E+03, 0.23801100E+02, -.16564900E+03, -.36917100E+03, -.22924500E+03, 0.40065500E+03, 0.26241900E+03, -.13360100E+03, -.14207200E+03, 0.13609600E+03, -.17921500E+03, -.73375500E+02, 0.52827200E+02, -.12698800E+02, 0.46228900E+02, -.17773000E+03, 0.87380100E+02, 0.12313300E+03, 0.42668500E+02, 0.14631800E+03, -.21886400E+03, -.48668700E+03, -.15439100E+03, 0.40502100E+03, 0.51550000E+03, -.26706400E+03, -.37094500E+03, -.13713500E+03, -.28651300E+02, -.18276400E+03, 0.11290300E+03, -.39961100E+02, -.25729400E+03, -.13452300E+02, -.84971100E+02, 0.60357900E+02, -.89367100E+02, -.11735700E+03, 0.27146600E+02, -.61580500E+02, -.14738000E+02, -.93601200E+02, -.25349400E+03, 0.48406700E+02, -.97392900E+02, -.58540500E+02, 0.19480400E+03, -.10031700E+03, -.13048900E+03, -.64024500E+02, 0.16438800E+03, -.25454500E+02, 0.12942000E+03, 0.92697200E+02, -.10410700E+03, -.49510900E+02, 0.12407200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12655400E+01, 0.90836700E+00, 0.47350100E+00, -.31642100E+01, -.69544500E+00, 0.24877400E+01, -.32200400E+01, -.82152800E+00, 0.68460100E+00, -.20744900E+01, 0.26766200E+00, 0.91355500E+00, -.83435200E+00, 0.20545100E+01, -.85249800E+00, 0.52475800E+01, 0.30097200E+01, -.70619500E+00, 0.10817600E+01, -.15740500E+01, 0.82654300E+00, -.65495400E+00, 0.14646600E+01, 0.69575100E+00, 0.14303700E+01, -.57403100E+01, 0.26590900E+00, 0.27851000E+01, 0.10585400E+01, -.16302400E+01, -.10108300E+01, -.76729200E-02, -.37792800E-01, -.24411300E+00, -.19616600E+01, 0.67111000E+00, -.38844600E+00, 0.19891700E+01, 0.93382500E+00, -.18392400E+01, -.10106000E+00, -.15407500E+00, -.93190400E+00, 0.84233300E+00, -.67959400E+00, 0.11205500E+01, 0.13534100E+00, -.49152500E+00, -.10987000E+01, -.71775000E+00, 0.27894300E+00, 0.11538500E+01, 0.10812700E+01, -.29628100E-01, -.61413900E+00, 0.34580600E+00, -.25024700E+00, -.15073700E+01, 0.89804500E+00, -.13492900E+01, -.32422300E+00, -.91536600E+00, -.35599600E+00, 0.16123900E+00, -.36861600E+00, 0.62305300E+00, 0.20157100E+00, -.79569200E+00, 0.38868000E-01, 0.57059700E+01, -.43343300E+00, -.78252400E+00, 0.19726500E+01, 0.22312400E+01, -.71876600E+00, 0.14084600E+00, 0.51832900E+00, -.11837300E+01, 0.93988000E+03, 0.11574300E+04, 0.12667800E+03, 0.22304000E+04, -.11017300E+04, -.13828400E+04, -.45930900E+03, 0.13238300E+02, -.59227500E+03, -.50652400E+03, -.14183400E+03, -.80226000E+03, 0.17619800E+03, -.87155000E+02, 0.12387500E+02, 0.12827600E+03, -.13276800E+03, 0.75035900E+01, 0.18028100E+03, -.37601100E+03, -.32421300E+03, 0.11331400E+03, -.39562100E+02, -.16421800E+03, 0.10858200E+03, 0.16336000E+03, -.75786200E+01, -.29905200E+03, 0.47844800E+03, -.79405500E+03, -.12385300E+04, 0.60377800E+03, 0.47316400E+03, -.61952600E+02, 0.31216000E+03, 0.39314300E+03, 0.16020700E+03, 0.38010600E+02, 0.62069700E+02, -.57723900E+03, 0.28732000E+03, -.13295400E+02, 0.27112500E+02, 0.54244500E+03, -.79988600E+01, -.35969400E+03, -.20524100E+03, 0.86589700E+02, 0.16812700E+04, -.84034600E+03, -.68989300E+03, -.40112400E+03, -.67077500E+03, -.15400200E+03, 0.55626500E+03, 0.10552100E+04, -.69084400E+03, -.56222200E+03, 0.24787900E+03, 0.33466100E+03, 0.37397400E+02, 0.38313900E+03, 0.52312300E+01, -.19491700E+03, -.25954000E+03, 0.13642100E+03, 0.22806800E+04, -.11440800E+04, -.11313300E+04, 0.62688600E+03, -.10575200E+03, -.10406700E+04, -.87155500E+03, -.90354900E+03, 0.40199000E+02, 0.91372700E+02, -.32958300E+02, -.14076600E+03, 0.21541200E+03, -.37919100E+03, 0.22270800E+03, 0.78537900E+03, 0.38176300E+03, -.57319700E+03, -.50150200E+03, 0.23054300E+03, 0.63294000E+03, 0.30946800E+03, -.18535100E+03, -.88467700E+02, 0.16712600E+03, -.31920500E+03, 0.57333600E+03, 0.17647900E+04, -.81689600E+03, -.10568300E+04, 0.12361000E+03, 0.12195200E+03, -.65072500E+03, -.69044900E+03, -.12301800E+04, 0.35123400E+03, 0.55222700E+03, -.27613200E+03, -.26251700E+03, -.99134400E+01, -.32013900E+03, -.26225500E+03, -.26088300E+03, -.82419300E+03, 0.28755700E+03, 0.82541400E+03, -.42431600E+03, -.43608600E+03, -.44352600E+03, 0.24180900E+03, -.34313500E+03, -.51013800E+03, -.24263300E+03, 0.64237700E+03, 0.36841000E+03, -.20284500E+03, -.35048400E+03, -.42281400E+02, 0.26948600E+02, -.11394000E+03, 0.30679500E+03, 0.26242200E+03, -.24155400E+03, 0.36390600E+02, -.35647000E+03, 0.17259300E+03, -.13422900E+03, 0.11816200E+03, -.48579800E+02, -.10038800E+03, 0.48256700E+02, -.17449000E+03, 0.10744800E+03, -.11451700E+03, -.16619000E+03, -.90083000E+02, 0.25793200E+03, -.19751800E+03, -.32400700E+03, -.74640700E+02, 0.21934600E+03, -.26968600E+02, -.15621100E+03, -.10494900E+03, -.19438000E+03, -.32860500E+03, 0.38323800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36109200E+00, 0.35998400E+00, 0.15713800E-01, -.88127800E+00, -.11958300E+00, 0.26906400E+00, -.95105800E+00, -.17197500E+00, 0.80251700E+00, -.10195600E+00, -.14944800E+00, -.88726500E-01, -.37784400E-01, 0.18661000E+00, 0.15199300E-01, -.56257400E+00, -.10881300E+00, 0.74384500E+00, 0.83878700E-01, -.78985200E+00, -.43671400E+00, -.38040400E+00, 0.13023300E+00, 0.39272900E+00, -.43591500E+00, 0.88387700E+00, -.13285400E-01, 0.51112900E+00, 0.39183200E+00, 0.19421400E+00, -.37643900E+00, -.53877300E+00, 0.10205300E-01, 0.89507800E-01, -.29686500E+00, 0.37831100E-01, -.22984300E+00, -.25465200E+00, 0.29565700E+00, 0.57928200E+00, 0.89986500E-01, -.27465500E+00, 0.41440000E+00, -.15415500E+00, -.23508000E+00, -.76363200E-01, 0.10166700E+00, 0.19872300E+00, 0.33183000E+00, 0.76677000E+00, 0.17477700E+00, -.17435000E+00, -.19146100E+00, -.25343600E+00, -.21293900E+00, -.19843600E-01, -.19360000E-01, 0.98616400E-01, 0.14224900E+01, -.94784200E+00, -.21240900E-01, 0.14777700E+00, -.69831200E-01, 0.93126900E-01, -.31033400E-01, -.68567600E-01, 0.23088400E+00, 0.41301100E+00, 0.35244300E-01, -.95139100E+00, 0.85009700E-01, -.72323300E-01, 0.16092300E+00, -.47891000E+00, -.29440900E-01, -.89324100E-01, 0.15695300E+00, 0.23126400E+00, -.22974700E-01, -.51188100E+03, -.36628100E+02, -.16738500E+04, 0.83587200E+03, 0.83676000E+03, 0.14543800E+03, -.69650100E+03, 0.62552900E+03, 0.36403500E+03, 0.48325500E+03, -.70056100E+01, -.10182500E+03, 0.50633500E+02, 0.47294100E+02, 0.25116700E+02, 0.98906000E+02, -.43232900E+02, -.42506500E+02, 0.16241800E+03, 0.14982800E+03, -.69100200E+02, 0.34723600E+02, 0.40586200E+02, -.45796600E+02, -.85412500E+02, 0.39774900E+02, -.13961000E+03, -.30712100E+03, 0.34468300E+03, 0.66794200E+03, -.33377400E+03, -.32239100E+03, 0.10025600E+03, -.19409000E+03, -.27135900E+03, -.16239600E+03, -.14625800E+03, -.66626500E+02, 0.71409200E+03, -.35707400E+03, -.34556300E+03, 0.15768700E+03, -.23353700E+03, -.36788400E+03, -.34282300E+03, -.29367600E+03, 0.15428800E+03, -.26059500E+03, 0.12998800E+03, 0.11885500E+03, -.44866100E+01, 0.94433900E+02, 0.46103500E+02, -.88049100E+02, -.12110600E+03, 0.70042100E+02, 0.23723400E+03, -.11387500E+03, -.13653400E+03, -.47383100E+02, -.26249500E+03, -.37704300E+02, 0.92592200E+02, -.29285800E+02, -.83525400E+02, -.10656300E+04, 0.53141800E+03, 0.53320300E+03, -.34081900E+03, 0.30938600E+02, 0.52558300E+03, 0.47736900E+03, 0.47532700E+03, -.12384900E+03, -.48047800E+03, 0.24029800E+03, 0.25251800E+03, -.69309500E+02, -.34017900E+02, 0.11918800E+03, -.74015200E+02, 0.34896900E+02, 0.41665200E+02, 0.12937400E+04, -.64458800E+03, -.67805100E+03, -.50319500E+02, 0.51321700E+03, -.48718400E+03, -.39543000E+03, -.42678400E+03, 0.11236200E+03, -.73390500E+03, 0.35975600E+03, 0.40079500E+03, -.82476000E+02, 0.33201500E+01, 0.30920500E+03, 0.25404700E+03, 0.33537800E+03, -.14707900E+03, -.59745700E+03, 0.29921800E+03, 0.30502800E+03, -.15936600E+03, 0.17840900E+03, 0.37194500E+03, 0.43486600E+03, 0.49832000E+03, -.22040300E+03, -.13663900E+03, 0.66913600E+02, 0.64325700E+02, 0.88758500E+02, -.97224600E+02, 0.10485100E+03, 0.31410000E+03, 0.32262600E+03, -.20684100E+03, 0.69367400E+03, -.34066900E+03, -.32663500E+03, -.67258600E+01, 0.73818400E+02, -.18599100E+03, 0.58925900E+02, -.36268700E+03, 0.60231200E+02, 0.93520500E+01, -.39108600E+01, -.51437000E+02, 0.66915700E+02, 0.10851500E+02, 0.25891900E+02, 0.53587200E+02, -.11392900E+01, 0.67232100E+02, 0.77697700E+02, 0.90001500E+02, 0.52834700E+02, 0.15795500E+02, -.17669400E+03, 0.21498300E+03, 0.29760100E+02, 0.26396400E+02, -.11238900E+03, -.57101700E+02, 0.16492800E+03, -.49941000E+01, 0.12607300E+03, -.14386700E+02, -.13232600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17651900E+01, 0.14554900E+01, 0.66854200E+00, -.46980800E+01, -.93171200E+00, 0.39320000E+01, -.55343400E+01, -.13419500E+01, 0.46747800E-01, -.15879800E+01, 0.29117000E-01, 0.67051000E+00, -.70089200E+00, 0.11767600E+01, -.12441800E+01, 0.24567000E+01, 0.21842500E+01, 0.43395600E+00, 0.27068600E+01, 0.99360500E+00, 0.70921000E+00, 0.74565600E-01, 0.10815400E+01, -.92514700E+00, 0.19499300E+01, -.32415800E+01, 0.28260900E+00, 0.18604600E+01, 0.90014300E-01, -.98732800E+00, -.10174500E+01, -.14039500E+00, -.11947600E+00, -.89074500E-03, -.51523500E-01, -.11981900E-02, -.24360600E+01, -.86145600E+00, -.75228700E+00, -.12386000E+01, -.37143800E+00, 0.14392800E+01, -.20297600E+01, 0.74890400E+00, -.42179500E+00, 0.25182500E+00, 0.87286200E-01, 0.81671400E+00, -.10827100E+01, 0.86413400E+00, -.40242800E+00, -.17975700E+01, 0.60368000E+00, 0.77004900E+00, 0.21085000E+00, -.65848900E+00, 0.16053400E+00, -.38281700E+00, -.83091900E+01, 0.49817400E+01, 0.59858800E+00, 0.16402800E+00, -.12325200E-01, 0.89591900E+00, -.34650500E+00, -.39519200E-01, -.58541600E+00, -.80878600E+00, 0.23917300E+00, 0.55081000E+00, -.60526700E-01, 0.20280800E+01, 0.21648900E+01, -.37825900E+00, -.39764200E+00, -.18440000E+00, 0.19498300E-01, -.14276900E+01, -.71515800E-01, -.15039000E+01, 0.34532900E+03, 0.44543100E+02, 0.85023000E+01, -.30245800E+03, 0.61657100E+03, 0.83783300E+03, -.54155300E+03, -.37970000E+03, -.19199000E+04, 0.19532800E+04, -.17523900E+04, 0.87616300E+03, 0.92947600E+03, 0.22190500E+03, 0.33905700E+03, 0.37729700E+03, 0.31897200E+03, 0.96658800E+03, 0.23835600E+03, -.52169200E+03, 0.26649200E+03, 0.22169500E+03, -.61151000E+03, -.41900800E+03, 0.72206700E+03, 0.16460200E+04, 0.11567500E+04, -.53195300E+03, 0.96491300E+03, -.50135900E+03, -.57110500E+03, 0.83305100E+02, 0.12662200E+04, -.66199800E+03, -.66079600E+03, -.87420200E+02, 0.50133200E+03, 0.14686500E+04, -.71687400E+03, -.99964800E+03, 0.10426500E+03, 0.54432400E+03, -.72277700E+03, -.62225900E+03, 0.87127700E+03, 0.37195000E+03, 0.14700900E+04, -.73514400E+03, -.68011900E+03, -.68709100E+03, -.11602400E+04, 0.35267400E+03, 0.11651500E+04, 0.67529600E+03, -.10003900E+04, -.12089800E+04, 0.59008000E+03, 0.50797300E+03, 0.57763200E+03, 0.96522900E+03, 0.28163300E+03, -.35605300E+02, 0.80199400E+03, 0.11076000E+04, 0.21136100E+04, -.10895600E+04, -.10400500E+04, 0.64333800E+03, -.40627200E+03, -.84136300E+03, -.74283000E+03, -.10259100E+04, -.25863600E+03, 0.46232100E+04, -.22876200E+04, -.22849300E+04, -.49676100E+02, -.13221200E+04, -.96025900E+03, 0.71789500E+03, -.11226400E+03, -.68769600E+03, 0.15599300E+04, -.81207500E+03, -.64414900E+03, 0.10027900E+03, -.38971800E+03, -.56199100E+03, -.69848400E+03, 0.50448800E+03, -.18183000E+04, -.66131400E+03, 0.30712000E+03, 0.35895200E+03, 0.23994400E+03, -.12830600E+03, 0.22096600E+02, -.54549800E+03, -.22285000E+03, 0.47685400E+03, -.78301900E+03, 0.37711600E+03, 0.43825400E+03, 0.33789900E+03, -.31350300E+03, 0.37459600E+03, 0.45928300E+03, -.14817200E+03, 0.47139700E+03, -.45174400E+04, 0.22335400E+04, 0.21517000E+04, 0.15173800E+03, 0.16249100E+04, 0.69661500E+03, -.13914100E+04, -.18673000E+03, 0.10141300E+04, -.20410600E+04, 0.97911500E+03, 0.10028100E+04, -.25568000E+03, 0.39449300E+03, 0.73301200E+03, 0.37976000E+03, 0.62923700E+03, -.19411100E+03, 0.46228400E+03, 0.16793700E+02, 0.27339100E+03, -.91519000E+02, -.34083400E+02, 0.17274600E+03, -.34985700E+03, 0.45401300E+03, -.26255400E+03, -.89799600E+03, 0.22601800E+03, -.63094500E+03, -.12890500E+03, 0.16691700E+03, -.44125300E+03, -.67221500E+03, -.37115600E+03, 0.27432300E+03, 0.36526400E+02, 0.34702000E+03, 0.20557400E+02, -.34824300E+03, 0.16173700E+02, 0.15119800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10019800E+01, -.78010500E+00, -.16686400E+00, 0.28073200E+01, 0.74421100E+00, -.20033300E+01, 0.29338900E+01, 0.72091100E+00, -.93056100E-01, 0.13427500E+01, -.81174300E-01, -.50958100E+00, 0.60410200E+00, -.13706000E+01, 0.85841300E+00, -.26271900E+01, -.18351300E+01, -.54267700E+00, -.12716500E+01, -.33133600E+00, -.70825200E+00, -.24695900E+00, -.11636300E+01, 0.10874500E+00, -.11318700E+01, 0.34467900E+01, -.52656800E+00, -.18118100E+01, -.69484800E+00, 0.12335100E+01, 0.43602900E+00, -.85497300E+00, -.38329200E+00, 0.16705100E+00, 0.54911500E+00, -.96930700E-01, 0.10463000E+01, -.21868000E+00, -.51323500E+00, 0.15258700E+01, -.28014700E+00, -.38905100E+00, 0.18768400E+01, -.52303300E+00, 0.11436500E+01, -.49842200E+00, -.36395200E-01, 0.85002700E-01, -.35335200E-01, -.20143200E+00, -.11129200E-01, 0.18380400E+00, -.35336400E+00, 0.10747900E+00, -.35409000E+00, -.64074900E+00, 0.25351500E-01, 0.65761800E+00, -.14170100E+01, 0.15796100E+01, 0.45089200E+00, 0.77240100E+00, 0.10217700E+00, 0.70719200E+00, 0.84245300E-01, -.51030100E+00, 0.33475500E+00, 0.11460300E+01, 0.84016700E-01, -.33056200E+01, 0.17606100E+00, 0.46046000E+00, -.25634600E+01, -.19023300E+01, 0.55235100E+00, -.24259700E+00, -.94298900E+00, -.41285100E+00, -.10215300E+00, -.22886200E+01, 0.14864700E+00, -.54430900E+04, 0.27161600E+04, 0.29364000E+04, 0.83630000E+03, -.51088300E+03, 0.16224800E+04, 0.82631400E+03, 0.77872600E+03, 0.12563500E+04, 0.51590800E+03, -.25618100E+03, -.27988200E+03, -.48175100E+03, -.28758800E+03, 0.17675500E+00, 0.12798000E+03, 0.54377800E+03, -.23494300E+03, -.43177300E+03, 0.19876700E+03, 0.21486300E+03, -.16853600E+03, -.16965200E+03, 0.21956100E+03, 0.19839600E+03, -.13792000E+04, 0.47731700E+03, 0.18031600E+04, -.90108300E+03, -.80451500E+03, -.19473300E+03, 0.30870000E+02, -.44607300E+03, -.15906900E+03, -.13145900E+03, -.87786200E+02, 0.16119400E+04, -.79460900E+03, -.53262300E+03, 0.85939600E+01, -.97437600E+02, -.48652100E+03, -.29860100E+03, -.49296800E+03, -.18933400E+02, -.64561200E+03, 0.32367500E+03, 0.28402900E+03, 0.13985900E+03, 0.69232900E+02, 0.14521100E+03, -.27857700E+03, -.97224900E+03, 0.21173100E+03, 0.75595200E+03, -.36222700E+03, -.28720000E+03, -.88005600E+02, -.25711600E+03, -.18497700E+03, -.21196700E+02, 0.30517300E+03, -.12363300E+03, -.13370800E+04, 0.65201900E+03, 0.64809400E+03, -.23656000E+03, -.29178900E+03, 0.64513400E+03, 0.63261900E+03, 0.47393800E+03, -.24343600E+03, 0.31648900E+02, -.25885600E+02, -.47053000E+02, 0.24898500E+02, 0.12181700E+03, -.17739000E+03, -.47883900E+03, -.12493400E+04, 0.55257700E+03, 0.41971000E+04, -.20809700E+04, -.22393400E+04, -.32163700E+03, 0.50198000E+03, -.13511200E+04, -.10924800E+04, -.80809600E+03, -.10009500E+04, -.25783000E+04, 0.12119800E+04, 0.13226200E+04, 0.24934900E+03, 0.15365000E+03, 0.67357900E+03, 0.34713200E+03, 0.10170300E+04, 0.19102100E+03, -.10202200E+04, 0.50064600E+03, 0.46862200E+03, 0.82502500E+01, -.31437700E+02, 0.55006700E+03, 0.74825200E+03, 0.11321700E+04, -.29099500E+02, -.55457200E+03, 0.28738700E+03, 0.38299600E+03, 0.21302000E+03, 0.81296400E+02, 0.15515300E+03, 0.27899200E+03, 0.13732100E+04, -.53527700E+03, 0.74105700E+03, -.35319400E+03, -.36570000E+03, -.21227900E+03, 0.46052000E+02, -.39695000E+02, 0.37805100E+03, 0.10557600E+02, -.30030600E+03, 0.14585700E+03, -.64984800E+02, -.84685700E+02, 0.13981400E+03, -.21610800E+03, 0.10518300E+03, 0.56589800E+02, 0.48581800E+02, 0.79276200E+02, 0.42472900E+02, 0.17150200E+03, -.41260100E+01, -.51353100E+02, -.20982800E+03, 0.55575300E+02, 0.22684400E+03, 0.66253900E+02, -.10690600E+03, -.48553000E+02, 0.48868800E+03, 0.17145600E+03, 0.13606700E+03, 0.71386600E+02, 0.11862200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.35794000E+01, -.27431000E+01, -.13653900E+01, 0.78978600E+01, 0.14650700E+01, -.62774700E+01, 0.82792600E+01, 0.20729500E+01, -.16704400E+01, 0.38681200E+01, -.28092600E-02, -.97253400E+00, 0.16708700E+01, -.17965200E+01, 0.19175100E+01, -.83588800E+01, -.49380500E+01, 0.12924700E+01, -.44250200E+01, 0.20238200E+01, -.15253900E+01, 0.11983800E+01, -.25610700E+01, -.13841200E+00, -.29038500E+01, 0.98132800E+01, 0.95179800E+00, -.61121000E+01, -.91342400E+00, 0.35589200E+01, 0.10694700E+01, -.35873300E+00, -.32856400E+00, 0.13061300E+00, 0.31902000E+01, -.11065900E+01, 0.18081300E+01, 0.15093200E+01, -.16653600E+01, 0.45358700E+01, 0.13245600E+00, -.33377800E+00, 0.35180300E+01, -.34420400E+01, 0.14280300E+01, -.22186800E+01, -.31329700E+00, 0.36591600E+00, 0.16757300E+01, -.10836400E+01, -.46499100E+00, -.29205600E+01, -.17540900E+01, 0.14613200E+00, 0.16013800E+01, -.42744800E+00, 0.37095500E+00, 0.22694900E+01, -.28680400E+01, 0.14161800E+01, 0.57979800E+00, 0.18131100E+01, 0.48051000E+00, 0.24078500E+00, 0.11294300E+00, -.10257600E+01, 0.42809600E+00, 0.12222300E+01, 0.25768000E+00, -.10446100E+02, 0.51209600E+00, 0.12546700E+01, -.35925600E+01, 0.30118700E+01, 0.26407200E+01, 0.10481100E+00, 0.77656300E+00, 0.26783500E+01, -.18226700E+01, 0.34520600E+00, 0.67820300E+00, -.36955400E+00, -.85601700E+02, 0.47896100E+03, 0.78464800E+03, 0.31523000E+04, -.87100800E+03, -.41803200E+03, 0.11577000E+04, -.66793500E+03, 0.19346000E+04, -.95385500E+03, -.11896900E+04, -.15763800E+03, -.48310800E+03, 0.56939600E+02, 0.58077600E+03, 0.15094900E+04, -.89028800E+03, 0.41235900E+04, -.20705200E+04, -.19539500E+04, 0.15538700E+04, 0.10130200E+04, -.13882200E+04, -.68770200E+03, -.20098300E+04, -.11656900E+04, -.44114600E+04, 0.22655600E+04, 0.23015300E+04, -.83008000E+03, -.29975400E+04, 0.20364600E+04, 0.17238900E+04, 0.12582200E+04, -.63233900E+03, -.25233100E+04, 0.12307300E+04, 0.16364500E+04, 0.82688800E+02, -.71704100E+03, 0.12478100E+04, 0.75784400E+03, -.94666000E+03, -.50378000E+03, -.22692800E+04, 0.11426800E+04, 0.11693100E+04, 0.12853400E+04, 0.18967900E+04, -.19570600E+03, -.17467600E+04, -.57353300E+03, 0.99130300E+03, -.10294600E+04, 0.40659800E+03, 0.11602500E+04, -.17134100E+03, -.11852200E+04, 0.42016900E+03, 0.30628700E+03, -.15775300E+03, -.14970900E+04, -.17342500E+04, 0.91378800E+03, 0.83919700E+03, -.64809400E+03, 0.93601900E+03, 0.72543900E+03, 0.80209900E+03, 0.11058300E+04, 0.73359700E+03, 0.34831400E+04, -.17842800E+04, -.20769800E+04, -.37503400E+03, 0.26628200E+04, -.12872900E+04, 0.21686500E+03, -.35954300E+04, 0.45692100E+02, -.63561800E+04, 0.33050600E+04, 0.34664500E+04, -.22013800E+04, -.26378700E+04, 0.34617100E+04, 0.32788900E+04, 0.13417500E+04, 0.15745800E+04, 0.52126700E+04, -.22743600E+04, -.31795100E+04, 0.33275400E+03, 0.12910900E+04, -.25348800E+04, -.16924100E+04, -.33377500E+04, 0.59809100E+03, 0.21284500E+04, -.10417900E+04, -.11972700E+04, -.12576600E+04, -.44510600E+03, -.50982800E+03, -.46906700E+03, 0.16520400E+03, -.13809700E+04, -.84467900E+03, 0.46040200E+03, 0.75348600E+03, 0.23042300E+03, -.21572800E+04, -.25157300E+03, -.14244600E+04, 0.15068400E+04, 0.84084700E+03, -.30707800E+04, 0.16474000E+04, 0.10802700E+04, 0.46431900E+03, -.83905800E+03, 0.73375300E+03, -.60403600E+03, 0.10372100E+04, 0.10445300E+04, -.10666400E+04, -.15596500E+03, -.38863100E+03, 0.11850800E+03, 0.42030800E+03, -.13852800E+03, 0.71447900E+03, -.10781000E+04, 0.62810800E+03, 0.74912500E+03, -.83819200E+02, 0.10705700E+04, 0.69674700E+03, 0.48825100E+02, 0.98762500E+03, 0.76411700E+03, 0.26335200E+03, -.54389000E+03, 0.40058200E+03, -.49051300E+02, -.42740100E+03, 0.51927900E+03, 0.60955500E+03, -.23045200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.97260500E+00, 0.42679700E+00, 0.73049300E+00, -.79357500E+00, 0.32919100E+00, 0.21438400E+01, -.29238100E+01, -.96161100E+00, 0.11701400E-01, -.11579300E+00, 0.11579400E-01, -.80749600E-01, 0.57871000E-01, -.71830500E+00, 0.21498900E-01, -.46919600E+00, -.16018300E+00, -.46983400E+00, 0.86730700E+00, 0.11108400E+01, 0.78217400E+00, 0.42781100E+00, 0.18266100E+00, -.24947500E+00, 0.16481200E+00, -.85798300E+00, 0.11311200E+01, 0.89011600E+00, -.45197900E+00, -.11326100E+00, -.22697400E+00, 0.11471000E+01, 0.55745700E+00, -.97423700E-01, 0.60072600E+00, -.32638100E+00, -.21788200E+01, 0.10179500E+01, -.12677700E+01, 0.75937700E+00, -.14317000E+00, 0.13621400E+01, -.14768600E+01, -.74097900E+00, -.49512200E+00, 0.14629200E+00, -.13928000E+00, -.58699800E-01, 0.34780600E+00, -.16142800E+01, -.61476200E+00, -.60004100E+00, -.35175300E+00, 0.21905700E+00, -.75489400E-01, 0.40611000E+00, 0.10959000E+00, -.18469900E+00, 0.24439700E+00, -.60096100E+00, -.18557800E+00, -.23633600E+00, -.64258500E-01, -.16747600E+00, -.68231500E+00, -.42065300E+00, -.34399500E-01, 0.12929900E+00, -.11478700E+00, -.21002700E+00, -.19413600E+00, 0.10599700E+01, 0.20019200E+01, 0.53868500E+00, -.54921200E+00, -.66155700E-03, 0.89703900E+00, -.27216300E+00, -.10784700E-01, 0.10184500E+01, 0.46916900E+00, 0.41941400E-01, 0.24998600E+00, 0.54320900E+03, -.36970800E+03, -.40091800E+03, 0.27025500E+03, 0.19406700E+03, 0.38508800E+03, -.27786500E+03, 0.10733800E+03, -.56537300E+02, -.82977200E+02, 0.60335300E+02, -.79537600E+02, -.11769000E+02, -.98745400E+02, -.60200500E+03, -.18015800E+02, -.82726800E+02, 0.51408700E+02, 0.99025500E+02, -.31528300E+03, 0.13781300E+03, 0.11225300E+03, 0.25133900E+03, 0.74630200E+02, -.86584400E+02, -.24327600E+02, 0.14344400E+02, 0.10772500E+03, 0.13765800E+03, 0.39642700E+03, -.47573000E+01, -.97659900E+02, 0.25582600E+02, -.12616700E+03, -.10168900E+04, 0.50387100E+03, 0.88816700E+03, -.22754100E+03, 0.14578800E+03, 0.52311000E+03, 0.60489000E+03, 0.32901600E+03, -.19454900E+03, 0.43920100E+03, -.22026400E+03, -.33677400E+03, -.17103800E+03, -.28894100E+03, -.18326600E+01, 0.37868200E+03, 0.37183500E+03, -.12046100E+03, 0.10365100E+03, -.42181700E+02, -.72601900E+02, 0.17072800E+03, 0.20041100E+03, -.29190100E+02, 0.10452800E+03, -.29813000E+03, 0.16337800E+03, 0.11757000E+04, -.57001600E+03, -.60974100E+03, 0.27417800E+03, -.13696800E+03, -.56197700E+03, -.45953900E+03, -.57977800E+03, 0.24410400E+03, 0.42039800E+03, -.21054000E+03, -.13595500E+03, 0.36841300E+02, 0.10044400E+03, -.13990600E+03, 0.24117400E+03, 0.18744000E+03, 0.14616800E+03, -.45093300E+02, 0.26608400E+02, -.31264000E+03, 0.26570300E+03, 0.17427600E+03, -.11144400E+03, -.15103400E+03, -.18331200E+03, -.74492900E+02, -.97403800E+02, 0.31085900E+02, 0.84162700E+02, -.32525500E+02, -.13967400E+03, 0.51543800E+01, -.10411400E+03, 0.19254800E+02, 0.10235900E+03, 0.21341900E+03, -.10315300E+03, -.19421900E+03, 0.36988100E+03, 0.17000700E+03, -.21327500E+03, -.42581000E+03, -.47991400E+03, 0.36863600E+03, 0.15171200E+03, -.76253600E+02, 0.11729300E+02, -.67444200E+02, -.34629000E+03, 0.22551600E+02, -.16472700E+03, 0.79535900E+02, -.29269700E+03, 0.67240200E+03, -.35360000E+03, -.13072900E+03, -.98304100E+02, 0.93456000E+02, -.28305700E+03, -.30966800E+02, -.10171000E+03, -.18656100E+03, 0.67802100E+01, 0.13230100E+03, 0.42807100E+02, -.75660100E+02, 0.15730400E+03, -.10413800E+03, -.70173800E+02, 0.51279700E+02, -.11944100E+03, -.27696400E+02, -.85076900E+02, -.59560200E+02, -.78483300E+02, 0.19625200E+03, -.22001800E+03, -.38655800E+02, -.11626200E+03, 0.16747100E+03, 0.11553900E+03, -.14805200E+03, -.14248900E+03, -.92818500E+02, 0.10585600E+03, -.81011900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.41742200E+01, 0.38169500E+01, 0.19356800E+01, -.73066000E+01, 0.11217400E+01, 0.59521900E+01, -.64649200E+01, -.22168500E+01, 0.48363700E+00, -.19876800E+01, 0.12644700E+01, 0.19566400E+01, 0.34995300E+00, 0.24434900E+01, -.65427000E+00, 0.27960200E+01, 0.22462200E+01, 0.31823300E+01, 0.12208900E+01, 0.61096700E+01, -.19337100E+00, 0.17502800E+01, 0.22475800E+01, -.99904800E+00, 0.81409300E+00, 0.18534400E+01, 0.42948300E+00, 0.29363900E+01, 0.97673900E+01, -.92643500E+00, -.14032800E+01, -.12223100E+01, 0.13645700E+01, 0.22210900E+00, -.32101000E+00, 0.12346400E+01, 0.12399600E+01, 0.57883700E+01, 0.43959200E+01, -.46304400E+01, 0.17764600E+01, -.35238300E+01, 0.26465800E+01, 0.89350000E+00, -.24205300E+00, -.76521000E-01, 0.64620500E+00, 0.10282200E+01, -.49042100E+01, 0.61898700E+00, -.37887600E+00, -.35542900E+01, 0.41196800E+01, 0.14002700E+01, 0.14228000E+01, -.22194400E+01, 0.11592100E+00, -.14922500E+01, 0.19649400E+01, 0.27205000E+01, 0.45090300E+00, 0.17303000E+00, 0.13817500E+00, -.22719700E+00, -.63400400E+00, 0.57930700E+00, 0.11105400E+01, -.29581700E+00, 0.24163700E+00, -.21375800E+01, 0.92553300E+00, -.25281500E+01, -.41755000E+01, 0.29360500E+00, 0.25994400E+01, -.41592000E+00, -.24268200E+00, 0.19465800E+01, -.21057200E+01, 0.12937800E+00, -.14223900E+00, 0.38931500E+00, -.13568400E+00, -.13340700E+00, 0.16455500E+04, 0.59642500E+03, -.79353200E+03, -.22033900E+04, 0.33492500E+03, -.17617800E+04, 0.23215100E+04, -.11599900E+04, -.11664400E+04, 0.12061900E+03, -.70175300E+03, -.12261000E+02, 0.98626400E+03, 0.77696500E+03, -.89547300E+03, 0.25145100E+01, 0.70481300E+01, 0.10480500E+03, 0.15820600E+04, 0.18917700E+03, -.32762800E+03, -.18205900E+04, 0.12767000E+04, -.27995000E+04, -.32577700E+04, 0.16325300E+04, 0.15761200E+04, -.19021200E+04, -.21148200E+04, 0.18946100E+04, 0.28021100E+04, 0.13772500E+04, -.83029100E+03, 0.13720500E+04, -.69961500E+03, -.88821700E+03, -.38262500E+02, -.96224200E+03, -.10373600E+03, -.27839400E+03, -.59608600E+03, -.84260800E+03, -.12790600E+04, 0.63500400E+03, 0.55291000E+03, 0.80829600E+03, 0.10022700E+04, 0.12028000E+03, -.72354600E+03, 0.10177600E+04, 0.23177400E+03, 0.13449800E+04, -.72319500E+03, -.94284500E+03, -.50200800E+02, -.51101300E+03, -.84907800E+03, -.11342500E+04, -.13386000E+04, -.10023000E+04, 0.13758500E+04, -.66370600E+03, -.66111300E+03, 0.86580600E+02, 0.90509800E+03, -.81827900E+03, -.85238600E+03, -.10141800E+03, 0.10243400E+04, -.96076900E+04, 0.48206800E+04, 0.49584000E+04, -.10557000E+04, -.54522700E+03, 0.35263900E+04, 0.10563400E+04, 0.40416000E+04, -.11154400E+04, -.80789000E+04, 0.40346600E+04, 0.38031400E+04, -.33295100E+04, -.15485700E+04, 0.40940900E+04, 0.48201900E+04, 0.31854100E+04, 0.21147900E+04, 0.85307700E+04, -.40490900E+04, -.43008600E+04, 0.73617900E+03, 0.85126900E+03, -.36768900E+04, -.16329900E+04, -.33481700E+04, 0.90895400E+03, 0.31092400E+04, -.15427900E+04, -.15125600E+04, -.16064500E+04, -.10850900E+04, -.14375100E+04, -.99252500E+03, -.25242300E+03, -.67516800E+03, 0.12418100E+05, -.62233400E+04, -.63432100E+04, 0.11013400E+04, 0.15709800E+04, -.48296000E+04, -.18037900E+04, -.70065500E+04, 0.27973300E+04, 0.36086800E+03, -.13878200E+03, 0.13402500E+03, 0.39403300E+03, 0.70706000E+02, -.18700200E+03, 0.40192200E+03, 0.26904900E+03, 0.39018700E+03, -.52501100E+03, -.59622400E+03, -.12273100E+03, 0.21729400E+03, 0.95057600E+01, 0.35823800E+03, 0.44704500E+03, -.69500700E+03, 0.61687000E+03, 0.29059600E+03, -.12032500E+04, 0.67576900E+03, 0.33884200E+03, -.15552000E+03, 0.36759000E+03, 0.17523000E+03, 0.35020000E+03, -.43949600E+03, -.11161800E+03, -.20992900E+03, -.14384100E+03, 0.28739000E+03, -.63287900E+03, 0.46322500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18425200E+01, -.86813200E+00, -.53437900E+00, 0.31179900E+01, 0.21771400E+00, -.25671200E+01, 0.14954500E+01, 0.56871600E+00, -.12403800E+01, 0.89867700E+00, 0.14086100E+00, -.36443100E+00, 0.30736200E+00, -.84091400E+00, 0.39584900E+00, -.55453100E+00, -.48111000E+00, -.14517500E+01, -.25548200E+01, 0.32740800E+01, 0.16737700E-02, 0.12870100E+01, -.75565600E+00, 0.62962200E-01, -.77090900E+00, 0.23950300E-01, 0.17477300E+01, -.92549100E+00, 0.75516600E+00, 0.12238900E+00, 0.60563900E+00, -.60289600E-01, 0.73781200E-01, 0.54556300E-01, 0.31419300E-01, -.43767300E-01, 0.10693500E+01, -.31053300E+01, -.11556500E+00, 0.25153800E+01, 0.84984100E-01, 0.29889700E+00, 0.65706000E+00, -.50943000E+00, 0.48095700E+00, -.32155200E+00, 0.19339600E-01, 0.18405100E+00, 0.64402300E+00, -.17805900E+00, -.74457700E-01, -.53757400E-02, -.65181500E+00, 0.13972500E+00, -.70751200E+00, 0.24277700E+00, 0.52764900E-02, 0.65193500E+00, 0.79330300E-01, -.96279100E+00, -.15294000E+00, 0.15120700E+00, -.15235000E+00, 0.20772300E+00, -.17839500E-01, -.36614200E+00, 0.46079900E+00, -.16900000E+00, 0.12681500E+00, 0.25170000E+00, 0.14682200E+00, 0.54350800E+00, 0.21799500E+00, 0.28324500E+00, -.41179100E+00, 0.17426800E+00, 0.51832900E+00, -.20574000E+00, 0.10050700E+00, 0.77000700E+00, -.17967300E-01, 0.10172900E+00, -.20811100E-01, 0.17011100E+00, 0.67862200E-01, 0.11618400E+04, -.23901100E+03, 0.11185300E+03, -.34095200E+03, 0.79199900E+03, 0.33576700E+02, -.15926000E+02, -.27598600E+01, -.14321300E+03, -.73498200E+02, 0.58909300E+02, -.39220100E+02, 0.50273700E+02, -.20914600E+02, 0.38631500E+03, -.20191800E+03, -.23368600E+03, -.10196800E+03, 0.57598300E+02, -.32663700E+02, 0.49750600E+03, -.29855400E+03, 0.68362400E+01, -.32322700E+03, 0.15245600E+03, 0.13482800E+03, 0.44728200E+02, 0.22862900E+03, 0.22139100E+03, -.68928400E+02, 0.15083800E+03, 0.13387600E+01, -.26312100E+03, 0.13223600E+03, 0.12945100E+03, -.14824700E+03, 0.25840100E+03, 0.16161000E+03, 0.14265700E+03, -.19293300E+01, -.19057400E+03, 0.83335000E+02, -.40828400E+02, 0.16301600E+02, -.88042600E+02, -.17682300E+03, 0.47142600E+02, 0.15660500E+03, 0.65211400E+02, -.10566900E+02, -.42752400E+03, 0.20739400E+03, 0.33124000E+03, -.98498500E+02, 0.72078200E+02, 0.22704100E+03, 0.25000200E+03, 0.26134800E+03, 0.35090300E+02, 0.32035700E+03, -.16813000E+03, -.16647900E+03, 0.21710700E+03, -.21205200E+03, -.15599100E+03, -.92102200E+02, -.21173000E+03, -.90166200E+02, 0.22610400E+04, -.11322100E+04, -.12098800E+04, 0.32088100E+03, 0.55126900E+03, -.86500300E+03, -.23219700E+03, -.12412700E+04, 0.27631700E+03, 0.12836600E+04, -.64886300E+03, -.48397000E+03, 0.34502600E+03, -.64747600E+03, -.47666600E+03, -.52752800E+03, -.35936500E+03, -.74065300E+03, -.18529000E+03, 0.10202900E+03, -.18125900E+02, 0.26648200E+02, 0.84916500E+02, 0.41206900E+02, -.17727300E+03, -.21551500E+03, 0.82057100E+02, -.39603800E+03, 0.19401600E+03, 0.17203800E+03, 0.11892000E+03, -.11818800E+03, 0.23339100E+03, 0.23998700E+03, 0.21819900E+03, 0.97968100E+02, -.20239000E+04, 0.10182100E+04, 0.10605400E+04, -.25936300E+03, -.38527600E+03, 0.66556000E+03, -.18962400E+03, 0.11698000E+04, -.15907100E+03, -.50878400E+03, 0.27724600E+03, 0.12454400E+03, -.11234000E+02, -.99964900E+02, 0.16274900E+03, -.45783700E+01, 0.12750500E+03, -.12525100E+03, 0.80494800E+02, 0.31417600E+02, 0.97522700E+01, -.26464800E+02, -.35032500E+02, -.44872100E+02, -.61666400E+02, 0.64166700E+02, -.85199900E+02, -.38429400E+02, 0.18647000E+03, -.74255000E+02, 0.54493000E+01, 0.19227400E+03, -.11747500E+03, -.21335900E+02, 0.26470700E+01, 0.93682100E+02, 0.15426600E+03, 0.21910600E+02, 0.45851500E+02, -.31837700E+02, 0.20642800E+03, -.21780900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11583000E+01, 0.98444000E+00, 0.41509300E+00, -.36319900E+01, 0.18258500E+00, 0.27761200E+01, -.25060400E+01, -.79036900E+00, 0.77897700E+00, -.11877600E+01, 0.36262900E+00, 0.78459500E+00, -.23365400E+00, 0.18460000E+01, -.77282600E+00, 0.30763900E+01, 0.13421400E+01, 0.14378600E+00, 0.98763200E+00, -.79287800E+00, -.43003500E+00, -.62197800E+00, 0.10653000E+01, 0.20336100E+00, 0.53840000E+00, 0.72500300E+00, -.11419300E+01, 0.12707800E+00, -.11916500E+01, 0.14283800E-02, 0.18347800E+00, -.90854500E+00, 0.10610600E+00, 0.23220900E+00, -.17497500E+00, 0.47239700E-03, 0.54737000E+00, -.25107400E+01, 0.27387600E+00, -.11569800E+01, -.23183100E+00, -.24877900E+00, 0.83741200E+00, 0.11111500E+01, 0.58966100E+00, 0.65028000E-01, 0.12552400E-01, 0.28187200E+00, -.13718400E+01, 0.44821100E+00, 0.10144600E+00, -.21487100E+00, 0.12065300E+01, 0.45278700E-01, 0.38754000E+00, -.78169200E-01, 0.97169400E-01, 0.13805800E-01, 0.18051800E+01, 0.16077400E+01, 0.17826900E+00, -.71877300E-01, 0.75320400E-01, -.10540000E+00, 0.30443400E+00, 0.34213600E+00, 0.47698100E+00, 0.10077300E+01, -.16924000E-01, 0.14444900E-01, -.54442400E+00, 0.62453300E-01, -.12913200E+01, 0.27097900E+00, 0.50479200E+00, -.52888700E-01, -.23048900E+00, 0.23721300E+00, 0.16098200E+00, 0.26354100E+00, -.27967200E+00, -.17766700E+00, -.18930500E-01, 0.15946600E+00, 0.84987600E-01, -.28891300E+00, -.17658300E+03, -.18420000E+03, -.80376000E+03, 0.49534100E+03, -.38812300E+02, 0.20995700E+02, 0.21923300E+02, -.22139100E+03, -.81668400E+02, 0.36427200E+02, 0.29826100E+02, 0.30076600E+03, -.41799600E+02, -.23977100E+03, 0.10793200E+03, 0.10306200E+03, 0.55842900E+02, -.25853800E+03, 0.10537200E+02, -.24929200E+03, -.70678700E+03, 0.23104300E+03, 0.57049200E+03, -.28091800E+03, -.27891100E+03, -.12805800E+03, 0.48220100E+02, -.11610000E+03, 0.31756100E+02, 0.31846200E+02, 0.17717800E+03, 0.12166800E+04, -.59755600E+03, -.58014200E+03, 0.11412500E+03, 0.74768100E+02, -.42616600E+03, -.39600000E+03, -.15790400E+03, 0.57686500E+02, -.14159300E+03, 0.71676300E+02, 0.83153300E+02, 0.19063200E+02, -.79844100E+02, 0.65200700E+02, -.11419000E+03, -.50848600E+03, -.11138000E+02, 0.84686400E+03, -.42491100E+03, -.38725200E+03, 0.93147800E+02, 0.81472500E+02, -.35466000E+03, -.25827100E+03, -.73827100E+02, 0.75964300E+02, -.17762600E+04, 0.86974000E+03, 0.88422000E+03, -.47944100E+03, -.16344500E+03, 0.85703700E+03, 0.81759500E+03, 0.75228400E+03, -.22948200E+03, -.12795100E+04, 0.63276800E+03, 0.61999400E+03, 0.43014000E+02, -.21862100E+03, 0.29641200E+03, -.20637900E+03, -.15959900E+03, 0.27533700E+03, -.43771400E+03, 0.22368100E+03, 0.24510000E+03, -.22675000E+03, 0.32318100E+03, 0.30724900E+03, 0.35686600E+03, 0.75108800E+03, -.32270100E+03, -.10661500E+04, 0.50922000E+03, 0.54299400E+03, 0.11926200E+02, -.85594000E+01, 0.33610700E+03, 0.15339100E+03, 0.44220900E+03, 0.17024200E+02, -.57803000E+03, 0.28072100E+03, 0.28153600E+03, -.40954300E+02, -.12977600E+03, 0.24838400E+03, 0.39297500E+03, 0.45182100E+03, 0.25600400E+02, 0.59327700E+03, -.29175900E+03, -.28092500E+03, 0.56043300E+01, 0.19906400E+03, -.37008500E+02, 0.37336200E+03, 0.57309800E+03, -.33533200E+03, -.66122100E+03, 0.33114900E+03, 0.28840800E+03, -.12619300E+03, -.27977700E+02, 0.34582000E+03, 0.23801100E+03, 0.25001000E+03, -.13062600E+03, 0.14024100E+03, -.85288700E+02, 0.12840300E+02, 0.67212600E+02, 0.32182500E+02, 0.61198600E+02, -.31776600E+02, 0.12091400E+03, 0.10668700E+02, -.67884000E+02, -.11437500E+03, -.11395100E+03, -.12148500E+03, -.18942300E+03, -.58510600E+02, 0.14399100E+02, -.79939600E+01, -.53260100E+02, -.11692700E+03, -.12507500E+03, -.32530200E+02, -.92896100E+01, -.15622300E+03, 0.11479900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.45853400E+00, 0.11091600E-01, 0.12757700E+00, 0.95391600E+00, -.28048200E-01, -.61980000E+00, -.51228000E-01, -.95775000E-01, -.21518000E+00, -.42192700E-01, -.26862000E+00, -.48209000E+00, -.24954400E+00, -.69225000E+00, 0.29767100E-01, -.87150000E+00, -.25339200E+00, 0.22740400E+00, -.19977100E-02, -.10713100E+01, 0.21470500E+00, -.72595900E-01, -.38360800E-01, 0.19590700E+00, 0.19962800E+00, -.11918100E+01, -.78804000E-01, 0.35624700E+00, 0.58429400E+00, -.35766000E+00, 0.37982900E-01, 0.49677500E-01, 0.14939000E-01, -.14238300E-01, -.12700900E-01, 0.22176400E-01, -.94623700E-01, 0.65199800E-01, 0.42653600E-01, -.59764300E-01, -.11533700E-01, -.12499800E+00, -.59115800E-01, -.23083200E-01, 0.55015200E-01, 0.36118200E-01, 0.71458300E-02, -.14791800E-01, -.20756800E+00, 0.81885500E-01, -.53467100E-01, -.83081700E-01, 0.12137200E+00, 0.45234200E-01, -.14060500E+00, -.17563600E+00, 0.36705700E-02, -.41251800E-01, 0.40276900E-01, 0.14522500E+00, -.41995000E-01, -.59455600E-01, -.17576700E-01, 0.43101900E-01, 0.49071900E-01, 0.11073800E+00, 0.11111900E-01, -.87103500E-01, 0.26846400E-01, -.62274800E+00, 0.70669400E-01, -.30894600E+00, -.35489000E+00, -.51978800E+00, 0.23422100E+00, -.65254900E-01, -.47469500E-01, 0.16134500E+00, -.91644100E-01, 0.40037100E-01, -.13200200E+00, 0.23928600E-01, -.47271900E-01, -.13376700E+00, 0.75160400E-01, -.68120500E-01, 0.21109900E+00, 0.93499600E+02, 0.66688300E+02, 0.63311700E+02, -.29613300E+03, 0.14763400E+03, 0.13965500E+03, 0.75186700E+02, 0.76999900E+02, 0.38967500E+02, -.46759200E+02, -.77975800E+02, 0.10819000E+03, -.13488300E+03, 0.69417300E+02, 0.78786300E+02, -.14180800E+03, -.87804300E+02, 0.10057400E+03, 0.26561600E+03, 0.19576900E+03, -.29140600E+02, 0.18453700E+03, -.90107900E+02, -.88944600E+02, 0.12111200E+03, 0.22958300E+03, -.13701700E+03, -.22029700E+03, -.72765700E+02, 0.14352600E+02, -.18964700E+03, 0.94013500E+02, 0.90061300E+02, 0.24844400E+02, 0.40304900E+02, 0.61334600E+02, 0.89093500E+02, 0.15776100E+03, 0.50085700E+02, 0.10033800E+03, -.50029400E+02, -.59680700E+02, -.81380600E+02, -.10513500E+03, 0.34812100E+02, 0.13756900E+03, 0.98991300E+02, -.38528500E+02, -.18518500E+03, 0.97064300E+02, 0.76347600E+02, 0.92038700E+02, 0.12395700E+03, 0.57253300E+02, 0.19481000E+02, 0.82680000E+02, 0.16575900E+03, 0.30083300E+03, -.14624600E+03, -.14841300E+03, 0.88634100E+02, -.37709200E+01, -.13983600E+03, -.13710000E+03, -.15563600E+03, 0.54423100E+01, 0.85463800E+03, -.42591200E+03, -.41438100E+03, -.43374600E+02, -.10375500E+03, -.20804200E+03, 0.17876900E+03, -.22059100E+02, -.11567300E+03, 0.23136600E+02, -.11276100E+02, -.22813000E+02, 0.12740200E+03, 0.20529000E+02, -.50103600E+02, -.16980300E+03, -.10326100E+03, -.76252600E+02, -.18561800E+03, 0.85954900E+02, 0.11230800E+03, -.56160900E+02, -.10972000E+03, 0.10844300E+03, 0.46207100E+02, 0.12856200E+03, -.63743800E+02, -.29762800E+02, 0.15851700E+02, 0.21120100E+02, 0.76024000E+02, 0.95915300E+02, -.17385800E+02, -.79247000E+02, -.12603500E+03, 0.47944900E+02, -.55586400E+03, 0.27643000E+03, 0.26812100E+03, 0.56587100E+02, 0.11755700E+03, 0.10043100E+03, -.26348800E+03, -.71161900E+02, 0.10832500E+03, -.25755900E+02, 0.76476900E+01, 0.26275200E+02, -.74036100E+01, 0.67746600E+02, -.21050400E+02, -.39812500E+02, 0.62472900E+01, -.17819000E+02, 0.41196900E+02, 0.48089700E+02, 0.29288600E+02, -.31585600E+02, 0.14096500E+02, 0.59204300E+01, -.49569900E+02, 0.53989800E+02, -.44923700E+02, -.59250700E+02, 0.11775600E+03, -.64654700E+02, -.25470400E+02, 0.95421200E+02, -.35376800E+02, -.43902900E+02, -.62370200E+02, 0.46602700E+02, 0.58299300E+02, 0.76940300E+02, -.58291500E+01, -.38609300E+02, 0.56594600E+02, -.24953200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.25893700E+01, -.17032400E+01, -.11211600E+01, 0.70513100E+01, -.62424700E+00, -.44185200E+01, 0.47092300E+01, 0.11387200E+01, -.20521400E+01, 0.22380900E+01, -.10769100E+00, -.14332500E+01, 0.11265700E+01, -.34194200E+01, 0.17373900E+01, -.61849900E+01, -.39969200E+01, -.17257700E+01, -.10563800E+01, 0.25243300E+01, -.57983100E+00, 0.86357000E+00, -.14919400E+01, -.19957300E+00, -.21958100E+01, 0.40388800E+01, -.50561000E+00, -.30171100E+01, -.10448500E+01, 0.82929400E+00, 0.21858700E+01, 0.50013200E+00, 0.31081600E+00, 0.82245000E-01, 0.94667500E+00, -.51622600E+00, 0.24349400E+01, -.12954200E+01, -.82888500E+00, 0.25472500E+01, 0.23870000E+00, 0.59233900E-01, 0.18510400E+01, -.14524600E+01, 0.21976800E+00, -.10531100E+01, -.12408100E+00, -.18061300E+00, 0.49588800E+00, -.12568300E+01, 0.13975900E+00, 0.10022600E+01, -.13433600E+01, -.66458000E+00, 0.50235300E+00, 0.81156000E+00, -.10624400E-01, 0.38160000E+00, -.82400300E+00, -.94060700E+00, 0.10970500E+00, 0.70437500E+00, 0.23869300E+00, -.15325500E+00, 0.45242400E+00, -.72420500E+00, 0.75893900E+00, -.21234400E+00, -.29076400E-02, 0.72651200E-01, 0.41878400E+00, 0.41968900E+00, -.12857700E+01, -.12465400E+01, -.16869700E+00, 0.14521100E+00, -.28840500E+00, 0.14187800E+00, -.35737600E+00, 0.99655100E+00, -.98949700E-01, -.56179600E+00, -.79009600E-01, 0.55054900E+00, 0.29021600E+00, 0.91203300E+00, -.13122300E+00, 0.44552200E+01, -.16644700E+04, 0.92231900E+03, 0.11637500E+04, -.57528000E+03, -.53168100E+03, -.87461600E+03, -.40737000E+03, -.16581200E+03, 0.44509200E+02, 0.84094000E+03, -.52956200E+03, 0.10246500E+04, -.53378000E+03, -.65788000E+03, 0.78054700E+02, 0.15958600E+03, -.46385000E+03, -.63499700E+03, -.26129100E+04, 0.11660300E+04, 0.12460600E+04, -.62768900E+03, -.58577900E+03, -.18677700E+03, -.44541100E+03, -.18229300E+03, 0.98160000E+02, -.14379200E+03, 0.42969000E+03, 0.20737800E+04, -.10104000E+04, -.82817800E+03, -.44917400E+02, 0.27949700E+03, -.76985100E+03, -.78960100E+03, -.10605500E+04, 0.13953300E+03, -.22301000E+03, 0.11468200E+03, 0.22888800E+03, 0.23044200E+03, 0.19925700E+03, -.19318200E+03, -.65171000E+03, -.14906600E+04, 0.10713800E+03, 0.56861400E+03, -.30373600E+03, 0.39222600E+02, -.63385700E+03, -.59326400E+03, 0.92402100E+02, 0.37289100E+03, 0.63326600E+03, -.68157500E+03, -.24984500E+04, 0.11976600E+04, 0.12143900E+04, -.42854600E+03, -.50066700E+03, 0.12230500E+04, 0.11963300E+04, 0.96237500E+03, -.74011100E+03, -.28618900E+04, 0.14073500E+04, 0.12188500E+04, 0.92660900E+03, 0.89833500E+03, 0.13921300E+03, -.20279900E+04, -.21826800E+04, 0.15694600E+04, 0.38711800E+04, -.19203000E+04, -.17337400E+04, 0.28250900E+03, 0.53917900E+03, -.15619800E+04, -.11372000E+04, -.31350900E+03, -.79766700E+03, -.26491200E+04, 0.12534500E+04, 0.11966000E+04, 0.19706300E+03, 0.35397900E+03, 0.85848000E+03, 0.52030700E+03, 0.84520000E+03, 0.28635200E+02, -.17429400E+04, 0.84927300E+03, 0.79973300E+03, 0.60231000E+02, -.40954600E+03, 0.95862500E+03, 0.12063000E+04, 0.15536300E+04, -.66933200E+02, -.65122600E+03, 0.34448600E+03, 0.50739900E+03, -.76835100E+03, -.98560300E+03, 0.10588700E+04, 0.25761700E+04, 0.38091200E+04, -.18926600E+04, -.93607100E+03, 0.46410400E+03, 0.15671700E+03, -.24673000E+03, -.54242400E+03, 0.62191300E+03, 0.20853900E+03, 0.31450000E+03, -.14174200E+03, 0.11470400E+03, -.16406500E+03, -.14188600E+03, 0.18024100E+03, -.27790200E+03, -.65397200E+02, 0.10045600E+03, 0.11724800E+02, 0.39146600E+02, 0.17839300E+03, -.11647900E+03, 0.34302700E+02, -.55100800E+02, -.64092700E+03, 0.13737300E+02, 0.21509400E+03, 0.23813600E+03, -.13794600E+03, -.34658200E+03, -.73152500E+02, 0.24490600E+03, 0.12352600E+03, -.18383300E+03, 0.93469200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11750100E+01, 0.11421300E+01, 0.29441400E+00, 0.20021400E+00, -.79053200E+00, 0.32967600E+00, -.13552700E+01, -.54243900E+00, -.19907400E+00, -.23874800E+00, 0.50893000E-01, -.44516200E+00, 0.17864300E+00, -.89262400E+00, 0.12299600E+01, -.83090500E+00, 0.21646700E-01, 0.14506200E+00, -.45111600E+00, -.16812800E+01, -.59366500E+00, -.10605400E+01, 0.59149200E+00, 0.84308300E+00, -.92742500E+00, 0.21690000E+01, 0.58527500E-01, 0.13556600E+01, -.18668600E+01, -.18473000E+00, -.18902600E+00, 0.43103700E+00, 0.11518700E+01, -.46619000E-02, -.21684700E+00, -.22446400E-01, -.12932700E+00, 0.14789300E+01, 0.67758200E+00, -.10823100E+01, 0.12231300E+00, -.42384700E+00, 0.24021700E+00, 0.69095100E+00, -.53185600E+00, -.26784800E-01, -.31673700E-01, -.24881500E+00, -.41054000E-02, 0.13217200E+01, 0.59001300E+00, 0.21892000E+00, 0.91511300E+00, -.27933600E+00, 0.27065000E+00, 0.45229700E+00, -.13578800E+00, 0.48685400E-01, 0.33679600E+00, -.91911300E+00, 0.38974300E-01, 0.30059900E+00, -.84027700E-01, 0.33824600E+00, -.75424700E+00, -.68032900E-01, 0.54985800E+00, 0.46610600E+00, 0.13602000E+00, -.10417300E+01, -.17383200E+00, -.93905100E-01, 0.11763500E+01, -.68917100E+00, -.34074100E+00, -.16706400E+00, 0.45661000E-01, -.18884300E+00, 0.73663100E-01, 0.46002200E+00, 0.13125200E+00, 0.22573900E+00, -.16579500E+00, 0.12802600E+00, 0.10947300E+00, 0.36592000E+00, -.82895000E-01, 0.66549700E+00, -.17780700E+00, -.25833400E+03, 0.33722200E+03, -.16457500E+03, -.19006900E+03, -.10918400E+03, -.63830600E+02, -.70379100E+02, 0.62737000E+01, 0.19521900E+03, -.14548600E+03, 0.99308000E+03, -.49399500E+03, -.52503600E+03, 0.14860800E+03, 0.13268100E+03, -.28893700E+03, -.20971700E+03, -.75424800E+03, 0.53630000E+02, -.11133400E+03, 0.66767100E+02, 0.86506400E+02, -.52366300E+02, -.51872500E+03, 0.76260800E+02, 0.96728100E+02, -.27931200E+02, -.30095100E+02, -.54396500E+03, 0.27406600E+03, 0.36607200E+03, -.46120100E+02, -.99523000E+02, 0.22799900E+03, 0.17179800E+03, -.18337700E+03, -.12273700E+02, -.14582300E+03, 0.75478700E+02, 0.11351300E+03, 0.17492600E+03, 0.28358000E+03, -.12153900E+03, -.31272000E+03, -.28582900E+03, 0.10668800E+03, -.83460500E+01, -.18075600E+02, 0.18492600E+03, -.99119100E+02, -.30191600E+03, 0.71866600E+02, 0.52719000E+02, 0.47240100E+02, -.33533800E+03, -.69802200E+03, 0.34556500E+03, 0.33660500E+03, -.23496500E+03, 0.59661400E+02, 0.33369300E+03, 0.32908000E+03, 0.32920300E+03, 0.31802500E+02, 0.94918300E+02, -.60590900E+02, -.15806100E+03, 0.69651000E+02, 0.43425500E+03, -.17119500E+03, -.24701100E+03, -.88254300E+03, 0.20086700E+03, -.50797400E+03, 0.29107500E+03, 0.35933100E+03, -.28865900E+03, -.10043100E+03, 0.31704100E+03, 0.33129500E+03, 0.22117300E+03, 0.26867400E+03, -.10250300E+03, 0.75929700E+02, -.39626500E+02, 0.69974700E+02, 0.22613300E+03, -.63897800E+02, -.53314200E+02, -.16098400E+03, 0.54072600E+02, 0.38501100E+03, -.19318200E+03, -.21694400E+03, -.14362900E+02, 0.12071000E+02, -.11806600E+03, -.15283200E+03, -.85893200E+02, -.15631600E+03, -.40810300E+03, 0.21326300E+03, 0.29486000E+03, -.11908900E+03, -.49883200E+03, 0.25987700E+03, 0.38515700E+03, 0.11287500E+04, -.27617900E+03, -.20458000E+03, 0.93854000E+02, -.66892400E+02, 0.46041500E+02, -.16405000E+03, 0.52355100E+02, -.14814400E+03, -.10683300E+02, 0.19679400E+03, -.14653900E+03, 0.15553700E+02, -.72210400E+02, 0.33193900E+02, 0.50368000E+02, -.73270000E+02, 0.12873300E+03, -.15319800E+03, 0.81841600E+02, 0.16870900E+03, -.39387300E+02, 0.17258100E+03, 0.69867200E+02, -.14185100E+03, 0.11295300E+03, 0.14139400E+03, 0.51814100E+02, -.88926000E+02, -.40298800E+02, -.34460600E+02, -.57287100E+02, 0.56920800E+02, 0.13640500E+02, -.86132200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21672300E+01, 0.15899100E+01, 0.63304800E+00, -.58294000E+01, -.13490600E+01, 0.45774300E+01, -.69905400E+01, -.16245900E+01, 0.59862900E+00, -.23082600E+01, -.69805400E-01, 0.70308500E+00, -.12393800E+01, 0.86951800E+00, -.14938100E+01, 0.41143000E+01, 0.31335900E+01, 0.93963600E+00, 0.37440600E+01, 0.12555300E+01, 0.12901600E+01, -.48490300E-01, 0.16805300E+01, -.63830000E+00, 0.29939000E+01, -.71663300E+01, -.91231800E+00, 0.36671900E+01, 0.10722100E+01, -.23872000E+01, -.97108800E+00, 0.12497400E+00, -.88950100E-01, -.24808200E-01, -.21668400E+01, 0.66428200E+00, -.10179200E+01, -.40227200E+01, -.23803500E+00, -.30890600E+01, -.17377600E+00, 0.23759900E+01, -.44524200E+01, 0.21038600E+01, -.22954100E+01, 0.13094400E+01, 0.12226500E+00, 0.32057000E+00, -.40405800E+00, -.72857000E+00, 0.24574500E+00, 0.31188400E+00, 0.13779600E+01, 0.46550800E+00, 0.14332000E+01, 0.12931800E+01, -.28248700E+00, 0.43147400E-01, -.22409600E+00, -.89203700E+00, -.57858200E+00, -.95494800E+00, -.24466600E+00, -.38160600E+00, 0.28929600E+00, 0.62375100E+00, -.76630600E+00, -.20534400E+01, 0.80895700E-01, 0.22733700E+01, 0.24102200E+00, -.15732400E+01, 0.23090700E+01, 0.31540500E+00, 0.72341200E+00, -.51313300E+00, -.14591200E+00, -.13718300E+00, -.20546600E+00, -.12579400E+01, -.73865600E-01, -.31321500E+00, -.98599400E-01, -.90719500E+00, 0.27140000E+00, 0.17424900E+00, 0.86530200E+00, 0.36287900E+01, 0.36416900E-01, 0.16754400E+01, -.17040000E+04, 0.84077200E+03, 0.92843300E+03, 0.82976700E+03, 0.63244700E+03, 0.22066800E+03, -.72134400E+02, 0.85958700E+02, 0.69425200E+03, -.18138800E+04, 0.92677600E+03, 0.93061900E+03, -.76624900E+02, 0.42450400E+03, 0.47078100E+03, 0.45412900E+03, 0.25228500E+04, 0.16698500E+03, -.83707700E+03, 0.39449200E+03, 0.32835400E+03, 0.12838800E+03, 0.48340900E+03, 0.20640700E+03, 0.34563400E+02, 0.26323000E+03, -.10144200E+01, -.93129000E+03, 0.44686000E+03, 0.24131300E+03, -.10208800E+02, 0.28687100E+03, 0.88886600E+02, -.69403300E+02, 0.12608600E+04, 0.26585100E+03, 0.12862200E+04, -.64892700E+03, -.68753400E+03, -.58592300E+03, -.73280000E+03, 0.83053700E+02, 0.78034900E+03, 0.92399000E+03, -.62668000E+03, -.11619500E+04, 0.62090600E+03, 0.23637500E+03, 0.22076800E+03, 0.60940200E+03, 0.28551200E+03, 0.35749900E+03, -.13717000E+03, 0.57810200E+03, 0.24804000E+04, -.12151700E+04, -.12162000E+04, 0.56532100E+03, 0.37485300E+02, -.11216400E+04, -.10442700E+04, -.10203600E+04, 0.38775200E+03, 0.20236900E+04, -.97942300E+03, -.81794800E+03, -.44294300E+03, -.11642400E+04, 0.15445700E+03, 0.10175600E+04, 0.26477200E+04, -.10273500E+04, 0.16338400E+04, -.88556900E+03, -.94119600E+03, 0.33686900E+03, 0.84624400E+01, -.93845200E+03, -.72113400E+03, -.69929600E+03, 0.82605400E+02, 0.61324200E+03, -.32867400E+03, -.16155200E+03, -.94562000E+02, -.33665600E+03, -.17186000E+02, -.40942600E+02, 0.14555000E+02, -.15110300E+02, 0.81089100E+02, -.24907500E+02, 0.55690800E+01, 0.32898300E+03, 0.13943400E+03, -.84390700E+02, -.13701900E+03, -.67034500E+03, 0.41062500E+03, -.19248700E+04, 0.93360800E+03, 0.79921600E+03, 0.18661700E+03, 0.77347100E+03, 0.42546900E+02, -.85177300E+03, -.28478900E+04, 0.67687100E+03, 0.67319700E+03, -.33674000E+03, -.17926700E+02, 0.14897800E+03, 0.45682800E+03, -.37457900E+03, -.25873600E+02, -.43533700E+03, -.18439400E+01, 0.77953500E+01, 0.14207200E+03, 0.12851900E+03, -.11033300E+03, -.66561500E+02, 0.37041400E+02, -.14220100E+03, 0.12358600E+03, -.88593100E+02, -.30132500E+03, 0.10958900E+03, -.18288200E+03, 0.70219200E+02, 0.26915200E+03, -.15539000E+03, -.37824300E+03, -.13479100E+03, 0.15785100E+03, 0.53525700E+02, 0.15093300E+03, 0.78473900E+02, -.14546000E+03, 0.19433000E+03, -.55502500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.70488500E+01, 0.92798300E+01, 0.41126200E+01, -.30719600E+01, 0.38601500E+01, 0.27089100E+00, -.28982900E+01, -.13950100E+01, 0.42589300E+01, 0.13333400E+01, -.18652100E+01, -.24858600E+01, -.15268100E+01, -.70256100E+01, -.77305600E-01, -.89124600E+01, -.36438000E+01, 0.46033400E+01, -.11761400E+01, -.25181000E+01, -.39955400E-01, 0.80441600E+00, -.29509800E+01, -.45854400E+00, 0.89244300E+00, 0.18570300E+00, -.14543700E+00, 0.22790500E+01, 0.33202300E+01, 0.54180100E+00, -.53329400E+00, -.10006300E+01, -.84871800E+00, -.11177400E+00, -.17463200E+01, 0.60269700E+00, 0.22351000E+01, -.55146400E+01, -.13994600E+01, -.41529500E+01, -.10950800E+00, -.86849700E+00, -.15689600E+00, 0.42610400E-01, -.69954800E+00, -.24104300E+00, 0.93804700E+00, 0.23585600E+01, 0.44099400E+01, -.33437800E+00, -.30882700E+00, 0.88356600E-01, -.54383800E+01, 0.31889000E+01, -.70677200E+01, -.22990500E+01, -.54537200E-01, 0.19956600E+01, -.79612700E+01, 0.36171100E+01, 0.93890100E+00, 0.14897000E+01, -.48521200E+00, 0.23134500E+01, 0.10411200E+00, 0.77001800E-01, 0.15133900E+01, 0.10736100E+01, 0.11444300E+01, 0.20207400E+01, -.40729700E+00, 0.17422200E+01, 0.15089300E+01, 0.26716400E+01, 0.11369800E+00, 0.70223600E+00, 0.25209600E+01, 0.34047900E+00, -.97116900E+00, 0.65258800E+01, 0.10926000E+01, -.20618800E+01, 0.44819800E+00, 0.12330300E+01, 0.14525000E+00, 0.48938900E+00, -.60487000E+00, 0.49165000E+01, 0.10267500E+01, 0.19317700E+01, 0.55385700E-01, -.12964700E+02, 0.14375500E+03, 0.52691900E+02, -.22863700E+01, 0.38226200E+02, 0.35200600E+03, 0.68466000E+03, 0.13985000E+03, -.24456100E+04, 0.11883600E+04, 0.12433000E+04, 0.38370800E+03, 0.17693300E+03, 0.33472500E+03, -.10003300E+04, 0.10641500E+04, 0.16016600E+02, -.37836700E+03, 0.14530200E+03, 0.11322900E+03, -.58024600E+02, -.66716600E+03, 0.14612100E+03, 0.21550700E+03, 0.86951200E+02, -.49761900E+03, 0.30337800E+04, -.15272700E+04, -.17044000E+04, 0.12460400E+03, -.52016700E+03, -.15616100E+04, -.15746500E+04, -.15165500E+04, 0.52298300E+02, -.97790000E+03, 0.47977500E+03, 0.36140500E+03, 0.21979700E+02, 0.35012200E+03, 0.24525700E+03, -.22415800E+03, 0.62286100E+02, 0.29036100E+03, 0.19115600E+04, -.89650100E+03, -.15428500E+04, -.29712700E+03, -.25188800E+03, -.91865300E+03, -.77395700E+03, -.13170200E+04, -.99939900E+02, -.10963200E+04, 0.54010100E+03, 0.56922300E+03, -.53447600E+03, 0.21577400E+03, 0.43389900E+03, 0.15630600E+03, 0.57563300E+03, 0.26316800E+03, -.29451700E+04, 0.14933300E+04, 0.18149300E+04, -.98970500E+03, -.88620000E+03, 0.15093800E+04, 0.50291000E+03, 0.30047600E+04, -.86418300E+03, -.28193700E+03, 0.39001800E+02, -.35310300E+03, -.24349700E+03, 0.94818800E+01, 0.29144700E+03, 0.42626800E+03, 0.52506900E+03, 0.66865700E+01, -.94857800E+02, 0.46448000E+01, 0.29599000E+03, 0.11239600E+03, 0.15932200E+03, 0.78929400E+02, 0.23843600E+03, 0.27042600E+03, 0.18161000E+03, -.18871100E+04, 0.94441300E+03, 0.98281300E+03, -.54757800E+03, 0.17491800E+03, 0.11363200E+04, 0.14776900E+04, 0.17843700E+04, -.44237800E+03, 0.30404200E+04, -.15229100E+04, -.17670300E+04, 0.12010000E+04, 0.79338200E+03, -.15957400E+04, -.76713200E+03, -.37691500E+04, 0.12195000E+04, -.10833000E+04, 0.66561200E+03, 0.11388600E+04, 0.18600300E+03, -.16871700E+03, 0.47351100E+03, 0.32702000E+03, 0.77854600E+03, 0.46964700E-01, -.11879400E+03, -.29424500E+03, -.14051300E+03, 0.10867600E+03, -.31533200E+03, 0.20226100E+03, 0.15305000E+03, -.98431400E+02, 0.17708300E+03, 0.83138400E+02, -.23437800E+02, 0.19800200E+03, 0.69133000E+02, -.10414900E+03, 0.48289300E+03, 0.95228900E+02, 0.40782400E+03, -.18537600E+03, -.28741900E+03, -.45603600E+02, 0.28323500E+03, 0.38992900E+03, -.18510600E+03, 0.22386600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.43880600E+01, 0.32369800E+01, 0.13860700E+01, -.97406400E+01, -.19803300E+01, 0.79418800E+01, -.10931800E+02, -.27488600E+01, 0.13505000E+01, -.36088300E+01, -.24907000E+00, 0.42400300E+00, -.16723200E+01, 0.14389000E+00, -.23957400E+01, 0.62840600E+01, 0.38745000E+01, -.20752400E+00, 0.58325400E+01, -.15831000E+01, 0.95776700E+00, -.14111600E+01, 0.28294400E+01, -.70496900E+00, 0.35178200E+01, -.78776000E+01, -.22170000E+01, 0.54801400E+01, -.13292200E+01, -.33615800E+01, -.32490800E+00, -.51605200E+00, 0.67650800E+00, 0.33682800E+00, -.21363800E+01, 0.61990200E+00, -.10065600E+01, -.78874200E+01, 0.64292700E+00, -.33401200E+01, -.41662800E+00, 0.14150500E+01, -.34819800E+01, 0.45535300E+01, -.61731300E+00, 0.12408200E+01, 0.34711400E+00, 0.91224300E+00, -.14969200E+01, 0.29890800E+01, 0.20622700E-01, -.67069900E+00, 0.20149200E+01, 0.63102900E+00, -.74264600E+00, -.62056800E+00, -.12025100E+00, -.10975400E+00, -.25997600E+01, 0.26368300E+01, -.26938900E+00, -.10400900E+01, -.18857300E+00, -.96736500E-01, 0.41850600E+00, 0.10946400E+01, -.63930200E+00, -.20652900E+01, -.63819500E-01, 0.60184500E+01, -.75685700E-01, -.69107600E+00, 0.49621900E+01, 0.19687000E+00, -.59748500E-01, -.23531500E+00, 0.11435200E+01, 0.18426400E+00, -.36815800E+00, 0.31824700E+01, 0.17351600E+00, -.10177000E+01, -.17847500E+00, -.89522600E+00, -.75728400E-01, -.15449500E+00, 0.25000400E+01, -.45100500E+01, -.16060300E+01, 0.20217200E+01, 0.25607800E+00, -.89364800E+00, 0.25576400E+03, 0.10497100E+02, -.22525800E+02, 0.67841400E+02, 0.39801300E+03, 0.72790300E+03, 0.10984200E+03, -.30532600E+04, 0.14985100E+04, 0.14522700E+04, 0.12466500E+03, 0.25649200E+03, 0.42369400E+03, -.90809100E+03, 0.17432900E+04, -.18949700E+02, 0.76007700E+03, -.44520000E+03, -.55648100E+03, 0.14345500E+03, -.17443900E+03, -.17660500E+03, -.18841200E+03, -.53332000E+03, -.49458000E+03, 0.41364700E+04, -.20712800E+04, -.23663900E+04, 0.43651400E+02, 0.61274400E+02, -.22838300E+04, -.25893600E+04, -.22192400E+04, 0.19269600E+03, -.23766000E+03, 0.10821900E+03, 0.74359800E+02, -.36637600E+03, -.65267500E+02, 0.19845000E+03, 0.13555600E+03, 0.59827300E+03, -.88778100E+02, 0.19249200E+04, -.88540000E+03, -.15735500E+04, -.76208200E+03, -.10368200E+03, -.86806300E+03, -.52243100E+03, -.12320800E+04, -.17783000E+03, 0.25873100E+04, -.13109300E+04, -.12747300E+04, 0.67402100E+03, 0.45515600E+02, -.13728500E+04, -.17224400E+04, -.12323600E+04, 0.80932200E+02, -.56908400E+04, 0.28772800E+04, 0.31725800E+04, -.48026700E+03, -.11841600E+04, 0.24251000E+04, -.38486400E+03, 0.39637200E+04, -.74693200E+03, 0.44775000E+04, -.23954900E+04, -.25621600E+04, 0.49774300E+03, 0.41889800E+03, -.19270300E+04, -.12239000E+04, -.13857400E+04, -.19795200E+03, -.45554100E+03, 0.11034600E+03, 0.39885100E+03, 0.23398900E+03, 0.75653900E+02, 0.36751300E+03, 0.44569100E+03, 0.58387000E+03, 0.25079800E+03, -.29228200E+04, 0.14564500E+04, 0.14755500E+04, -.39340200E+03, 0.57224600E+02, 0.16274300E+04, 0.20589800E+04, 0.21896700E+04, -.11288400E+03, 0.37625000E+04, -.18934500E+04, -.21363300E+04, 0.93170100E+03, 0.11700200E+04, -.18297200E+04, 0.19193800E+03, -.43538600E+04, 0.13399000E+04, -.86204200E+02, 0.13857900E+03, 0.63163000E+03, 0.31768500E+03, -.32427400E+03, 0.16782400E+03, 0.28954900E+03, 0.66156900E+03, -.27767600E+03, 0.83629000E+02, -.55340200E+03, -.74043800E+02, 0.47230900E+02, -.60153200E+03, 0.33477500E+03, -.52145900E+01, 0.51663900E+02, -.39283500E+02, -.86952000E+02, 0.31252600E+02, -.51046700E+01, 0.19075400E+01, -.10309900E+03, 0.30443100E+03, -.21072700E+03, 0.45523900E+03, 0.47561800E+02, -.67636200E+03, 0.57957400E+02, 0.55231800E+03, 0.33756500E+03, -.54672200E+03, 0.48312200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11107700E+01, 0.26503800E+01, 0.56612100E+00, -.20111200E+01, 0.48023100E+00, 0.10281800E+01, -.67358200E+00, -.44324700E+00, -.53202200E-01, -.11078800E+00, -.55490400E+00, -.10216200E+01, -.30984900E+00, 0.43318300E+00, -.23638600E+00, -.29151200E+00, -.88431200E+00, 0.59822300E+00, -.82308700E+00, -.59021500E+01, -.65984900E+00, -.11017500E+01, -.11144900E+00, 0.58145700E+00, -.39121700E+00, 0.15064800E+01, -.91365500E+00, -.53640600E+00, -.95573300E+00, 0.61740400E+00, 0.12103300E+00, -.72381800E+00, 0.19028300E+00, 0.32173400E-01, 0.10834400E+00, -.78651500E-01, 0.15063700E+01, 0.34811000E+01, 0.67513600E-01, -.25587600E+01, -.71548600E-01, -.81677700E+00, 0.16544000E+00, 0.11307000E+00, -.22404700E-01, 0.14737900E+00, 0.87899900E-01, -.89802300E-01, 0.65463400E+00, 0.86979600E-01, 0.36486600E-01, 0.47695200E+00, -.11576900E+01, 0.20372300E+00, -.11947100E+01, -.11187900E+01, -.41259200E-01, 0.49883700E+00, -.56985100E+00, 0.54054300E+00, 0.34651100E+00, 0.52830200E+00, 0.42359300E-01, 0.36752600E+00, -.60258400E-01, 0.17966800E+00, 0.21313900E+00, 0.64325500E+00, 0.51741600E-01, -.15409300E+01, -.11714900E+00, 0.42224700E+00, 0.42064300E+00, 0.71289800E-01, -.95485100E-01, -.21599000E-01, 0.27536800E+00, -.29237100E+00, -.19031400E+00, 0.86963500E+00, 0.33636500E+00, -.20962800E+00, 0.95645400E-01, 0.13542100E+00, 0.13233500E-02, -.90769000E-01, -.31142100E+00, 0.23595500E+00, -.49785200E-01, 0.30758900E+00, -.64539500E-01, 0.11238800E+00, 0.70531700E-01, -.95828100E+02, 0.20452300E+02, -.41305100E+02, -.28366800E+02, 0.84338600E+02, -.65879200E+02, 0.58721100E+03, -.29636300E+03, -.30452100E+03, 0.74611500E+02, 0.30183100E+03, -.23709300E+03, -.20134300E+03, -.99352400E+03, 0.32352800E+03, 0.69267300E+02, -.37431500E+02, -.12688600E+02, -.39589400E+02, -.19565600E+03, 0.19686600E+02, 0.64475100E+02, 0.96170900E+01, 0.65211000E+02, 0.77004100E+02, -.36103800E+02, 0.85996500E+01, 0.78841500E+02, 0.22039000E+03, -.69950300E+02, -.83287800E+02, -.32200200E+03, 0.10513200E+03, -.16590700E+02, 0.86511700E+01, 0.12499400E+02, 0.78264400E+02, 0.85348100E+02, -.67878000E+02, -.16093200E+03, -.21845800E+03, 0.22427300E+02, -.42300700E+03, 0.20559500E+03, 0.25249600E+03, -.43711600E+02, -.22961500E+03, 0.24487600E+03, 0.20890500E+03, 0.39711300E+03, -.22035100E+03, -.25990200E+03, 0.12050700E+03, 0.12501800E+03, -.24422300E+02, -.90804500E+02, 0.13793900E+03, 0.17430100E+03, 0.96350300E+02, -.96780700E+02, 0.99777600E+02, -.52795700E+02, -.76401400E+02, 0.29464600E+03, 0.49513700E+03, -.27287300E+03, -.50759000E+03, -.10453500E+04, 0.48594200E+03, 0.19411800E+03, -.93907100E+02, -.10576900E+03, -.45127200E+02, 0.81865700E+02, -.60219100E+02, -.43394900E+02, -.85849800E+02, -.99424900E+01, -.39058000E+03, 0.18148900E+03, 0.18953700E+03, 0.41687400E+02, 0.75263600E+02, 0.94286200E+02, 0.32039200E+02, 0.91059300E+02, 0.26604700E+02, -.22640200E+03, 0.11080800E+03, 0.10805300E+03, 0.35765500E+02, -.12247500E+03, 0.11148200E+03, 0.11764600E+03, 0.82720300E+02, -.49026700E+01, -.59952500E+03, 0.30237300E+03, 0.32900400E+03, -.33223800E+03, -.74281500E+03, 0.49961500E+03, 0.75388800E+03, 0.15570100E+04, -.71694200E+03, -.22713000E+01, 0.17292800E+01, -.26852600E+02, -.26092600E+02, -.14607800E+03, 0.39100500E+02, 0.10696600E+02, 0.12161300E+03, -.48176000E+02, -.52851400E+02, -.30531900E+02, -.49388300E+02, 0.43383300E+02, 0.19259400E+02, -.57461600E+02, 0.55678300E+02, -.64244800E+02, 0.33307900E+02, 0.70623700E+02, -.94369800E+02, 0.52199600E+02, 0.19313000E+02, -.13654900E+03, 0.25140400E+02, 0.68214400E+02, -.44787300E+02, -.38111700E+02, -.60065700E+02, -.76321000E+02, -.26821300E+02, 0.27550800E+02, 0.14747800E+02, 0.39270500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14525100E+01, -.96675900E+00, -.49590100E+00, 0.27518900E+01, 0.52482900E+00, -.24213600E+01, 0.21795700E+01, 0.66514100E+00, -.11877400E+01, 0.11216200E+01, 0.20084400E+00, 0.44459300E-01, 0.70502600E+00, 0.37975700E+00, 0.33740000E+00, -.30232400E+01, -.14181000E+01, 0.10171800E+01, -.13888900E+01, 0.30109500E+01, 0.25525800E+00, 0.15887400E+01, -.89952100E+00, -.50282100E+00, -.47586600E+00, 0.27473000E+01, 0.16905000E+01, -.27979700E+01, -.13952000E+00, 0.12945000E+01, 0.54528200E+00, 0.86875100E+00, 0.20402600E-01, -.58888100E-01, 0.21038200E+01, -.67199600E+00, -.11703000E+01, 0.17331300E+01, -.11866900E+01, 0.22116400E+01, 0.10091400E+00, 0.58938600E+00, -.46717700E+00, -.20654700E+01, 0.28295900E-01, -.75693500E+00, -.20165500E+00, 0.87832700E-01, 0.14326200E+01, -.72788100E+00, -.44480500E+00, -.21161000E+01, -.13801400E+01, -.24725800E-02, 0.10045300E+01, -.56609100E-01, 0.20595600E+00, 0.96834100E+00, 0.35433600E+00, -.24137700E+00, -.10984000E+00, 0.86048000E-01, 0.17688200E+00, -.46364200E+00, -.38683800E+00, -.31310500E+00, -.54547100E+00, -.25194400E+00, 0.39689600E-01, -.32045600E+01, 0.53637300E+00, 0.62476400E+00, -.98491800E+00, 0.24082300E+00, 0.21137500E+00, 0.23785600E+00, 0.66454800E+00, 0.73353200E+00, -.74063200E+00, 0.20204100E+01, 0.30073800E+00, -.58692000E+00, 0.14382200E+00, 0.19469500E+00, 0.14085500E+00, 0.39401900E+00, 0.42117100E-01, 0.11252700E+01, 0.20431100E+00, 0.24560200E-01, 0.82106400E-01, 0.16965800E+00, -.18587900E+00, 0.27902700E-01, -.16480700E+03, 0.98451900E+02, 0.21581300E+03, 0.40837300E+03, -.36378700E+02, -.12552400E+04, 0.62335400E+03, 0.64290900E+03, 0.12392400E+03, 0.12178800E+03, 0.34140400E+03, 0.60005400E+02, 0.72773300E+03, -.27901700E+03, 0.65954700E+03, -.32663700E+03, -.32895500E+03, -.51274000E+02, 0.31428800E+03, -.23673900E+03, -.29398100E+03, -.50461000E+03, -.13252100E+03, -.55125600E+03, 0.26960000E+03, 0.26369400E+03, -.37503400E+03, 0.34469900E+01, 0.21398800E+03, 0.89622300E+02, 0.48065000E+03, -.22149000E+03, -.44717600E+03, 0.22250600E+03, 0.20334100E+03, 0.45451900E+02, 0.63794200E+02, 0.13346900E+03, 0.94814800E+02, 0.11422800E+03, 0.15199700E+03, 0.79612500E+03, -.37649300E+03, -.44831300E+03, -.94135900E+02, 0.33164700E+03, -.44761100E+03, -.40353600E+03, -.59586000E+03, 0.14606400E+03, 0.12654000E+04, -.61510000E+03, -.62982400E+03, 0.40431100E+03, -.10578400E+02, -.61984200E+03, -.57179200E+03, -.56164100E+03, 0.16680200E+03, -.82035000E+03, 0.40942900E+03, 0.44282800E+03, -.87583900E+02, -.22867900E+03, 0.50629700E+03, 0.32839700E+03, 0.99622200E+03, -.11972200E+03, -.33501900E+03, 0.16281800E+03, 0.11499600E+03, 0.92825500E+02, -.12188900E+03, 0.12340300E+03, 0.11507900E+03, 0.19585300E+03, -.19370900E+03, -.20007100E+03, 0.74044100E+02, 0.11976400E+03, 0.18493600E+03, -.84140400E+01, -.18292300E+02, -.79220000E+02, 0.11112000E+03, 0.20694300E+03, 0.83806400E+03, -.41356900E+03, -.41258000E+03, 0.26162900E+03, 0.27240200E+02, -.38771700E+03, -.37789800E+03, -.40451600E+03, 0.13777400E+03, 0.18626500E+04, -.92835200E+03, -.95420900E+03, 0.11324800E+03, 0.32047000E+03, -.90934100E+03, -.65505400E+03, -.15374600E+04, 0.36525200E+03, 0.22193800E+03, -.10269100E+03, -.58252400E+02, 0.11923800E+03, 0.70359000E+02, -.14509900E+03, -.12416000E+03, -.34243600E+03, -.83519700E+02, 0.44173100E+02, 0.30107200E+02, 0.34332100E+02, -.25906100E+02, -.16364000E+03, 0.97260900E+02, -.27274600E+02, 0.28529200E+02, -.16494000E+01, -.83203600E+02, 0.86237700E+02, -.32750300E+02, 0.28746300E+02, 0.18393100E+03, -.17706100E+03, -.37612700E+02, 0.12796000E+03, 0.54997500E+02, 0.89222800E+02, 0.66263200E+02, 0.13510700E+03, -.94073000E+02, 0.47363100E+02, 0.49693800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.72575400E+00, 0.24916500E+00, 0.27237900E-01, 0.55750200E+00, 0.43821000E+00, -.11505200E+01, 0.86369000E+00, 0.43038500E+00, -.69624800E+00, 0.91025000E+00, 0.49390400E-01, 0.36274600E+00, 0.19549100E+00, 0.12396300E+01, 0.53110100E+00, 0.11439000E+00, 0.42787500E+00, 0.26090000E+00, -.13153500E+01, 0.94716100E+00, -.30168000E+00, 0.35256200E+00, -.28757100E+00, 0.10221700E+00, -.26826300E+00, 0.14505100E+01, -.54915800E-02, -.14113000E+01, 0.22923400E+00, 0.68741700E+00, -.39533400E-01, -.51266900E+00, -.39859100E+00, -.12420600E-01, 0.18852100E+00, -.76782100E-01, 0.70126600E+00, 0.35742400E+00, -.14648100E+00, 0.90415200E+00, -.16268800E-02, -.78626700E-01, 0.90449200E+00, -.55176600E+00, 0.28748900E+00, -.28159100E+00, -.62583700E-01, -.41382600E-01, -.73856200E+00, -.46447700E+00, -.14484900E+00, -.46493200E+00, 0.43900700E+00, -.15098100E-01, 0.48220400E+00, -.16138100E+00, 0.55519800E-01, 0.79462300E+00, -.34274400E+00, 0.48023200E+00, 0.35687300E-02, 0.22769700E+00, -.30347800E-01, 0.14943800E+00, 0.12201900E+00, -.17504600E+00, 0.54594600E+00, 0.54380200E-01, 0.70481300E-01, -.13795500E+01, -.14596700E-01, 0.60498000E+00, 0.68416700E+00, -.62615800E+00, -.17622300E+00, -.83165700E-01, 0.17679800E+00, -.22697100E+00, -.13759600E+00, 0.18319200E+00, 0.97781600E-01, 0.17043300E+00, 0.23992400E-01, -.55429600E-01, -.13758100E-01, 0.34523100E+00, 0.47153200E+00, -.22843500E+01, -.29418700E+00, 0.16924800E+00, 0.10401000E+00, -.17569900E-01, 0.55023800E-01, -.15535400E+00, 0.28251000E+00, -.71944600E+02, -.14816800E+03, -.40092300E+03, -.58888300E+01, 0.64965400E+03, -.31291500E+03, -.33771900E+03, -.37600500E+03, -.28484100E+02, -.80494400E+02, 0.31529400E+03, -.66599200E+03, 0.92903300E+01, -.34081800E+02, 0.21147800E+02, 0.39854000E+02, 0.11498200E+03, 0.30299400E+03, 0.33863200E+02, -.77078500E+02, 0.24831000E+03, -.42407300E+02, -.50857900E+03, 0.25837300E+03, 0.30623800E+03, 0.48672600E+02, 0.21959600E+03, 0.33363300E+03, 0.43326900E+03, 0.17560400E+03, -.56411600E+02, 0.33525800E+03, -.16633100E+03, -.16861800E+03, -.12969300E+03, -.26442900E+03, 0.10182000E+02, 0.23795200E+03, 0.10563400E+03, -.11104700E+03, -.58118600E+03, 0.28380800E+03, 0.30957700E+03, 0.16241900E+03, 0.18244800E+02, 0.34285500E+03, 0.38461500E+03, 0.53343600E+03, 0.51683900E+02, 0.92939800E+03, -.46391400E+03, -.46960200E+03, 0.30696700E+03, -.13310200E+03, -.45048600E+03, -.40725900E+03, -.52398300E+03, 0.23946300E+02, 0.46977000E+03, -.23730600E+03, -.24390200E+03, 0.21198600E+03, 0.28332000E+03, -.34544400E+03, -.28013100E+03, -.84179400E+03, 0.26588800E+03, 0.77322800E+03, -.37628600E+03, -.40224100E+03, 0.19606900E+03, 0.99517100E+02, -.38097600E+03, -.40234700E+03, -.39673200E+03, -.76525600E+02, -.16186300E+03, 0.65561200E+02, 0.11662100E+03, -.96148200E+02, -.12998300E+03, 0.11146400E+03, 0.58911700E+02, 0.13791400E+03, -.86773600E+02, -.14844900E+03, 0.71811800E+02, 0.72281600E+02, 0.14113700E+03, 0.59468100E+02, -.58663800E+02, -.18397700E+03, -.19928500E+03, 0.23720200E+03, -.81696000E+03, 0.40792200E+03, 0.42633300E+03, -.15992000E+03, -.37994000E+03, 0.51297300E+03, 0.42219100E+03, 0.13190200E+04, -.40458100E+03, 0.35361500E+03, -.20877200E+03, -.19489100E+03, -.89912500E+02, 0.26139200E+02, -.12253600E+03, -.36210900E+02, 0.44296100E+02, -.13449100E+03, 0.72235100E+02, 0.74823700E+02, 0.17401100E+02, -.16864100E+02, 0.11649400E+03, -.72997200E+02, -.52303800E+02, 0.53136000E+02, -.85145800E+02, -.10468100E+02, -.16673800E+02, -.66390800E+02, -.99524000E+02, 0.11898500E+03, -.11274800E+03, 0.73796700E+01, -.18112600E+03, 0.10059000E+03, -.24194700E+02, -.29108200E+02, -.10294900E+03, -.34799700E+02, -.15717900E+02, -.40662400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.73089500E+01, 0.46266800E+00, -.12240100E+01, 0.27847900E+01, 0.15211000E+01, -.52198800E+01, 0.48077800E+01, 0.20805300E+01, -.26810200E+01, 0.32281800E+01, 0.14285800E+01, 0.10633300E+01, 0.22443300E+01, 0.34607500E+01, 0.14513100E+01, 0.13512700E+01, -.10932400E+01, 0.29664500E+00, -.43671100E+01, 0.12730300E+02, -.16321600E+01, 0.43685000E+01, -.15334400E+01, -.20383400E+01, -.33787000E+01, 0.77705000E+01, 0.27668900E+01, -.40979700E+01, 0.34525100E+01, 0.32447100E+01, 0.66104500E+00, -.51789300E+00, -.14071200E+01, -.47938100E-01, 0.11281300E+01, 0.59123500E+00, 0.33763100E+01, -.65431300E+01, -.10617400E+01, 0.25548400E+01, 0.54836500E-01, -.89638900E+00, 0.40512600E+01, -.26460000E+01, 0.13467100E+01, -.15848500E+01, -.13946400E+00, 0.11197200E+01, -.20706100E+01, -.28909200E+01, 0.15854400E+00, -.35737800E+00, 0.16988500E+01, 0.12186400E+01, 0.22711700E+01, 0.77796200E-02, -.94981300E-01, -.11127700E+01, 0.10889000E+00, 0.40693000E+00, -.18433700E+00, -.44676400E+00, -.46729100E-01, -.34785900E+00, -.32248500E+00, -.11947500E+01, -.23842600E+01, -.29688000E+01, -.12638500E-01, -.28034900E+01, 0.20263400E+01, 0.85684600E+00, -.69092100E+01, -.23253400E+01, 0.17983600E+01, 0.60409000E+00, 0.34623400E+00, 0.11482800E+00, -.46545200E+00, 0.36147100E+01, -.51582800E+00, 0.87962700E+00, -.34577800E-01, -.36721900E+00, -.12126300E+00, 0.44550900E+00, 0.12435900E+01, -.41923200E+01, -.11140800E+01, 0.33747800E+00, -.62990700E+00, 0.66517000E+00, -.24912200E+00, 0.36441900E-03, 0.11278700E+01, -.22338400E+01, -.71147200E+03, -.19344500E+04, -.11996100E+03, 0.95905700E+03, -.43452600E+03, -.47488100E+03, -.18773400E+04, -.10832600E+04, -.14256500E+02, 0.16074400E+04, 0.48123800E+03, -.75301700E+03, 0.12408600E+04, -.58947400E+03, -.59675000E+03, 0.39296400E+03, 0.21832900E+04, -.37638600E+03, -.56413300E+03, 0.94711700E+02, 0.67668700E+03, -.10702900E+04, 0.55209000E+03, 0.53518200E+03, 0.98482700E+02, 0.12797700E+04, 0.65747400E+03, 0.54393100E+03, 0.11128900E+04, 0.36103900E+03, 0.29883400E+04, -.14906100E+04, -.15111400E+04, -.97531100E+03, -.15305300E+04, -.21786000E+03, 0.12580900E+04, 0.14411300E+04, -.12474900E+04, -.18932900E+04, 0.97407400E+03, 0.87598800E+03, 0.11727800E+03, 0.11601200E+04, 0.10471800E+04, 0.11643200E+04, 0.17089500E+04, 0.66231300E+03, 0.72983600E+04, -.36164700E+04, -.36436100E+04, 0.22031300E+04, -.13616000E+03, -.35730300E+04, -.35414300E+04, -.37084000E+04, -.18011800E+03, -.39515400E+04, 0.19873600E+04, 0.20235600E+04, 0.13946200E+04, -.10595500E+03, 0.55288400E+03, -.14602100E+04, -.28838000E+03, 0.88484100E+03, 0.64450200E+04, -.32273200E+04, -.32383600E+04, 0.21734100E+04, 0.10134900E+04, -.36149300E+04, -.35004600E+04, -.33981600E+04, 0.43026400E+02, 0.30673700E+03, -.27472100E+03, 0.36757100E+02, -.51357400E+03, -.12543600E+04, 0.55853800E+03, 0.72887600E+03, 0.10668600E+04, -.75596700E+03, -.15947900E+03, 0.76110800E+02, 0.11765100E+03, 0.70066100E+03, -.17791800E+03, -.60178100E+03, -.93121700E+03, -.14864300E+04, 0.10470700E+04, 0.12983800E+04, -.67559700E+03, -.67850900E+03, -.79382900E+03, 0.81615600E+03, 0.43314600E+03, 0.16521500E+04, 0.11092200E+04, -.55355600E+03, 0.28232300E+04, -.15693300E+04, -.13599800E+04, -.41061500E+03, 0.12796900E+03, -.93818100E+03, -.96484400E+01, -.11461500E+03, -.68520700E+03, 0.57522400E+03, -.11465000E+03, 0.33613200E+03, -.30814600E+03, 0.32828500E+02, -.66479900E+02, -.59052500E+03, 0.55539300E+03, -.72405300E+03, -.45170900E+03, 0.29023200E+03, -.76349000E+03, -.66006700E+03, 0.48810600E+03, -.86130400E+03, -.73010500E+03, -.53298200E+03, 0.74933000E+03, -.20161300E+03, 0.20062500E+03, 0.19342900E+02, -.58213000E+03, -.57755500E+03, 0.26888300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.85235900E+00, -.85600400E+00, -.40774500E+00, 0.30176300E+01, -.14635700E+00, -.21221100E+01, 0.32057000E+01, 0.73302600E+00, -.26395800E+00, 0.72519800E+00, -.36342700E-01, -.45055800E+00, 0.27436700E+00, -.82397800E+00, 0.58958700E+00, -.10341400E+01, -.10970800E+01, -.39649200E+00, -.19356600E+01, -.19516100E+01, -.36803400E+00, -.38607200E+00, -.64063800E+00, 0.61481300E+00, -.70593800E+00, 0.14866800E+01, -.21785500E-01, -.11854300E+01, -.73119700E+00, 0.40791600E+00, 0.48479700E+00, 0.21256700E-01, 0.97092000E-01, -.70012400E-01, 0.12474800E+00, -.28438500E+00, 0.91475000E+00, -.48480800E+00, 0.21632400E+00, 0.10525200E+01, 0.43742000E-01, -.63005800E+00, 0.12615200E+01, 0.42147900E-01, 0.98983200E+00, -.36269100E+00, -.12340100E+00, -.37063000E+00, 0.58874300E+00, 0.22818000E+00, 0.20775400E+00, 0.30191300E+00, -.30947700E+00, -.15861500E+00, -.20019800E+00, 0.43969400E-01, -.77753900E-01, -.61180000E+00, 0.26372100E+00, -.36690000E+00, 0.14578300E+00, 0.49499300E+00, 0.93890700E-01, -.47357000E-01, 0.26074200E-01, 0.12723100E+00, -.51228800E-01, 0.23074700E+00, 0.11805400E-01, 0.16726600E+01, -.11584200E+00, -.12326900E+01, 0.25268100E+00, 0.29847100E+00, 0.59882600E-01, 0.65804700E-01, 0.16039500E+00, 0.38488800E-01, 0.15241900E+00, 0.10549700E+01, -.11712700E+00, -.33097900E+00, 0.37040200E-01, 0.19573800E+00, -.11015500E+00, 0.37119700E+00, -.14731300E+00, -.24942800E+00, -.11700600E+00, 0.19087600E+00, -.30218400E+00, 0.24787800E+00, 0.34520000E-01, -.71059600E+00, -.49652100E+00, 0.20655500E+00, -.81899500E-01, 0.22818100E+03, -.91493900E+02, 0.87381600E+02, -.49952700E+02, -.49726700E+02, 0.53563000E+02, 0.25395500E+03, -.94377300E+02, -.58344800E+02, -.12999300E+03, 0.18680900E+03, 0.27118300E+03, -.14088600E+03, -.13333800E+03, -.94062800E+02, 0.99537500E+02, -.85445400E+02, -.48479600E+02, -.36973500E+03, 0.28835300E+03, -.85851800E+02, 0.45021000E+02, 0.39631900E+02, 0.47338500E+02, 0.30801700E+03, -.72934400E+02, -.21945200E+03, 0.13621700E+03, 0.15825000E+03, 0.54545900E+03, -.27260200E+03, -.25235700E+03, -.43544600E+02, -.63784900E+02, -.16761800E+03, -.30474500E+02, 0.68266800E+02, -.21146700E+03, -.73562300E+03, 0.39469200E+03, 0.42078300E+03, -.10422400E+03, 0.14467400E+03, 0.25246600E+03, 0.11974500E+03, 0.25821000E+03, -.10543800E+02, 0.99207500E+03, -.50462600E+03, -.49616900E+03, 0.32833700E+03, -.67092700E+02, -.44983900E+03, -.38767800E+03, -.45021200E+03, -.48210700E+02, -.71897800E+03, 0.35866000E+03, 0.31999500E+03, 0.42454100E+03, 0.28779000E+03, 0.10603000E+03, -.52568400E+03, -.48985100E+03, 0.45170700E+03, 0.79640500E+03, -.40218700E+03, -.33165400E+03, 0.23395400E+03, 0.59983800E+02, -.47878800E+03, -.43913400E+03, -.46252200E+03, 0.72957900E+02, -.83271600E+03, 0.33721600E+03, 0.38396000E+03, 0.68783100E+02, -.28614400E+02, 0.31983100E+03, 0.17656300E+03, 0.42162000E+03, -.23672200E+02, 0.15839200E+03, -.78724600E+02, -.76599800E+02, 0.13386500E+03, -.14386100E+03, -.81656300E+02, -.10479900E+03, -.47613300E+03, 0.10736700E+03, 0.12620500E+03, -.61838500E+02, -.34758600E+02, -.45857600E+03, -.28507300E+03, 0.11987200E+03, 0.70679400E+03, 0.84018800E+03, -.55094900E+03, 0.56681200E+03, -.29413300E+03, -.32928600E+03, -.67360500E+01, -.79585500E+02, -.19468000E+03, -.74246400E+02, -.24105000E+03, -.33129700E+02, -.29027700E+02, -.26769500E+02, 0.29536200E+02, -.59253100E+02, -.11900800E+03, -.31863700E+02, -.15293000E+02, -.13956900E+02, -.77335100E+02, -.21611000E+02, 0.80424600E+01, -.28252300E+02, 0.96089000E+01, -.52698400E+02, -.94378300E+02, -.12448900E+03, 0.54549900E+00, 0.92432700E+02, -.94397500E+02, 0.21381800E+02, 0.10504800E+03, -.96852300E+02, -.59263800E+02, 0.10391200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.67156400E+01, -.32744500E+01, -.31626800E+01, 0.10057900E+02, -.93651300E+00, -.10172200E+02, 0.10304300E+02, 0.32889800E+01, -.34170100E+01, 0.33591700E+01, 0.57217800E+00, -.11432800E+00, 0.19094500E+01, 0.31841000E+01, 0.23234900E+01, -.31119700E+01, -.21811600E+01, 0.13677200E+01, -.59972700E+01, 0.71067200E+01, -.97325200E+00, 0.32997700E+01, -.13924700E+01, 0.29080100E+00, -.38004200E+01, 0.70389500E+01, 0.37165500E+01, -.58098800E+01, 0.19982200E+01, 0.33192700E+01, 0.90902100E+00, 0.13765000E+01, -.11093100E+01, -.61358500E+00, 0.15668400E+01, -.72447700E+00, 0.11994300E+01, 0.92210800E+01, -.22331500E+01, 0.54414000E+01, 0.40360500E+00, -.31539100E+01, 0.49585100E+01, -.47594000E+01, 0.30297800E+01, -.30106400E+01, -.10136300E+00, -.21040200E+00, 0.35659800E+01, 0.22947600E+00, -.58639100E+00, -.35502600E+01, -.48928500E+01, -.14419000E+01, -.15733700E+01, -.18221200E+01, -.98492300E-02, -.25229400E+01, -.32371200E+01, 0.41007200E+00, 0.29087500E+00, 0.14386700E+00, 0.55686600E+00, -.55482900E+00, -.57451400E+00, -.10087400E+01, -.27687700E-01, -.13075200E+01, -.68438100E-01, 0.44310200E+01, -.28514000E+00, -.15361400E+00, 0.69452100E+01, -.12860600E+01, -.25760500E+01, -.13397400E-01, 0.17050500E+01, -.19409600E+01, 0.66084400E+00, -.39727300E+00, -.36529700E+00, 0.54618600E+00, -.18606500E+00, -.28078800E+00, -.53005700E+00, -.84988300E-01, 0.91714500E+00, -.66366200E+01, -.15205500E+01, 0.73988900E+00, -.25843100E+00, -.17335100E+00, 0.56976200E+00, -.19860000E+01, -.60564100E+00, 0.24330500E+01, -.49417700E+00, -.24601500E+01, -.38321500E+03, 0.15446400E+04, -.76681000E+03, -.93952700E+03, -.21118700E+03, 0.71433800E+03, -.37274300E+03, 0.85371200E+03, -.43622100E+03, 0.32658200E+03, 0.13727300E+04, -.70416900E+03, -.76388700E+03, -.18322600E+03, 0.88395200E+03, -.34586500E+03, -.40311200E+03, -.11392500E+04, 0.10746200E+04, -.50986000E+02, 0.38807000E+02, 0.48544100E+02, 0.31028100E+03, 0.18264800E+04, -.42171900E+03, -.95181800E+03, 0.27642400E+03, 0.57985100E+03, 0.41402600E+04, -.20657800E+04, -.17706300E+04, -.89760800E+03, -.12698800E+04, -.72524300E+03, 0.92210100E+03, 0.14908000E+04, -.16115700E+04, -.46643600E+04, 0.24072900E+04, 0.30441900E+04, -.21972600E+03, 0.76931200E+03, 0.16166000E+04, 0.82574100E+03, 0.15120100E+04, 0.22388000E+03, 0.47215900E+04, -.23942800E+04, -.23869000E+04, 0.16022800E+04, -.80320900E+03, -.21207600E+04, -.17036600E+04, -.21762600E+04, -.36739800E+03, -.15359500E+04, 0.76780400E+03, 0.30856000E+03, 0.23084700E+04, 0.14587900E+04, -.85343500E+02, -.19482800E+04, -.23378600E+04, 0.20455300E+04, 0.50104000E+04, -.25159300E+04, -.15676100E+04, 0.76826900E+03, 0.17503300E+03, -.26989000E+04, -.21637000E+04, -.26148300E+04, 0.46479300E+02, -.28531400E+04, 0.11359800E+04, 0.95950100E+03, 0.26439000E+03, -.57571500E+02, 0.10857300E+04, 0.45082600E+03, 0.11913400E+04, -.53331600E+02, -.10700100E+04, 0.53544000E+03, 0.44512300E+03, 0.52708000E+03, -.56245100E+03, 0.34464300E+03, 0.13503100E+02, -.15578300E+04, 0.64998400E+03, -.43079800E+03, 0.21105100E+03, 0.50307900E+03, -.24885000E+04, -.16113500E+04, 0.96527400E+03, 0.26306600E+04, 0.40194900E+04, -.25142200E+04, 0.24382500E+04, -.13005300E+04, -.19997800E+04, 0.13110100E+02, 0.94546800E+01, -.98675400E+03, -.43966100E+03, -.10520300E+04, -.21505000E+03, 0.14470600E+03, 0.10726200E+02, 0.17310000E+03, -.27482200E+03, -.23225900E+03, -.13717400E+03, -.26291500E+03, 0.15196400E+03, -.51327100E+03, -.32464900E+03, -.19279200E+01, -.35696500E+03, -.84539100E+01, -.11905100E+03, -.55178300E+03, -.81487700E+03, -.31974000E+03, 0.57906400E+03, -.22459900E+02, 0.21979500E+03, 0.20972500E+03, -.43950800E+03, -.86534300E+00, 0.30987200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.16428100E+01, 0.48034100E+01, 0.17219800E+01, -.20560900E+01, 0.46305000E+00, 0.13777800E+01, -.17815900E+01, -.60372200E+00, 0.80301400E+00, -.91270300E-01, -.84474400E+00, -.92319800E+00, -.68581700E+00, -.26248000E+01, 0.12729000E+01, -.12158700E+01, -.99043500E+00, -.72000800E-01, 0.13554400E+01, -.20635300E+01, -.38373900E+00, -.74973800E+00, -.11024300E+00, -.49838600E+00, -.12563400E+01, 0.49550900E+00, -.40688900E+00, 0.29535600E+01, -.86152800E-01, 0.21522600E-01, -.46148900E+00, 0.13612600E-01, -.17435400E-01, -.37880900E-01, -.48905600E-01, 0.21396100E+00, -.64663800E+00, 0.11144800E+01, -.76618600E-02, -.21099900E+01, -.11363300E+00, -.64469700E+00, -.17717000E+00, 0.51437400E+00, 0.23836700E-01, 0.10458200E+00, 0.32202400E+00, 0.40241400E+00, 0.13199200E+01, 0.15520900E+01, -.20778900E+00, -.18360100E-01, -.19506300E+01, 0.97918500E+00, -.30935600E+01, -.13366500E+01, 0.62308300E-01, 0.96896900E+00, -.12956000E+01, 0.14941700E+01, 0.43412700E+00, 0.56204100E+00, 0.24341300E-01, 0.45254800E+00, 0.74338300E-01, 0.19328900E+00, 0.52755000E+00, 0.10020100E+01, -.23516600E-01, -.14198800E+01, -.32840900E+00, 0.12095700E+01, 0.18200600E+01, 0.48415800E+00, -.65244900E+00, 0.15110200E+00, 0.92312400E+00, 0.13113400E+00, -.47499300E+00, 0.21084100E+01, 0.44397500E+00, -.50468000E+00, 0.12040600E+00, 0.29499500E+00, 0.73180000E-01, 0.14580000E+00, -.15089500E+00, 0.19175600E+01, 0.11210900E+00, 0.61725400E+00, -.58963700E-01, 0.24895200E+00, 0.10081300E+00, 0.35754000E+00, -.26193900E+00, -.82630400E-01, 0.11957500E+00, 0.55900800E+00, -.16070100E+00, 0.65777200E+03, -.31989700E+03, -.36325100E+03, 0.68909100E+02, 0.35854100E+03, -.21488700E+03, -.17415200E+03, -.66864000E+03, 0.18136300E+03, -.43672400E+03, 0.21389600E+03, 0.20482600E+03, -.43053900E+02, -.23188000E+03, 0.25301700E+03, 0.23724700E+03, 0.16648900E+03, -.17358700E+03, -.10571400E+03, 0.51564700E+02, 0.77195500E+02, 0.21085300E+02, 0.60465600E+02, 0.38295000E+02, 0.72125200E+02, -.13307400E+03, -.79259000E+01, 0.60508400E+02, -.29689600E+02, 0.19661100E+02, 0.24693100E+02, -.16579600E+02, -.84294800E+01, 0.42045400E+02, 0.63158400E+02, 0.51830000E+01, -.63544900E+03, 0.29367200E+03, 0.44885100E+03, 0.29547300E+02, -.23809200E+03, 0.28693700E+03, 0.24798100E+03, 0.19254800E+03, -.13342500E+03, -.95879800E+02, 0.48936300E+02, 0.39937900E+02, -.49969600E+02, -.67486300E+02, 0.71414400E+02, 0.16472700E+03, 0.74375200E+02, 0.11230700E+03, 0.84030400E+03, -.42073100E+03, -.50178700E+03, 0.18308500E+03, 0.46499500E+03, -.39294200E+03, -.15219400E+03, -.63421800E+03, 0.21272400E+03, 0.28452500E+03, -.13414900E+03, -.46847500E+01, -.13656700E+03, -.84574800E+02, -.65555500E+02, 0.44495200E+02, -.66668300E+02, -.37645100E+02, 0.54859300E+03, -.23211800E+03, -.37660900E+03, -.88125000E+01, 0.10619400E+03, -.22534600E+03, -.19665700E+03, -.43123200E+03, 0.61840800E+02, -.41519500E+03, 0.20703700E+03, 0.17914400E+03, -.53529600E+02, -.39154600E+02, 0.24376200E+03, 0.20101200E+03, 0.20937200E+03, -.59973000E+02, -.84182100E+03, 0.42047700E+03, 0.47406800E+03, -.30837600E+03, -.89235800E+03, 0.52214700E+03, 0.40696700E+03, 0.11128000E+04, -.49648700E+03, 0.22259700E+03, -.11610000E+03, -.25355200E+03, 0.17464000E+02, 0.10735300E+03, -.12485000E+03, -.85510500E+02, -.26845100E+03, 0.62964600E+02, -.72372400E+02, 0.17056700E+03, -.56790200E+02, 0.40708200E+02, 0.12198400E+03, -.10906800E+03, 0.69274800E+02, -.75157200E+02, 0.66490500E+02, 0.77128400E+02, -.98316100E+02, 0.85739100E+02, 0.48113200E+02, -.21330900E+02, 0.80145900E+02, 0.70688600E+02, -.51754400E+02, -.45060100E+02, 0.37886700E+02, -.57340600E+02, -.10720700E+03, 0.75505000E+02, 0.10046200E+03, -.15389500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21184500E+01, 0.26165000E+01, 0.14304800E+01, 0.33126700E+01, 0.16773900E+01, -.38363100E+01, 0.10446100E+00, -.12734400E+00, 0.11260800E+01, 0.18470700E+00, 0.62849000E+00, 0.55704600E+00, 0.53019800E+00, -.16429800E+01, 0.15794500E+01, -.22781100E+01, -.25381500E+00, 0.26035200E+01, -.28608600E+01, 0.47047000E+01, 0.21265100E+00, 0.16826200E+01, -.25993300E+00, 0.61279800E+00, 0.30032500E+00, -.71144000E+00, 0.45587800E+00, 0.41375200E+00, 0.67012500E+00, -.82078400E-01, -.35369500E+00, 0.13965400E+00, -.12175500E+00, -.14244100E+00, -.76015500E+00, 0.55825200E-01, -.54791900E-01, -.59327000E+00, -.29383900E+00, -.84432900E-01, 0.36793400E-01, -.13294900E+00, -.96248100E-01, -.37347800E+00, 0.54981000E-01, -.78095000E-01, 0.19032500E+00, 0.58376500E+00, 0.17746100E+01, 0.43260700E+00, 0.25166100E-01, 0.36021800E+00, -.19912000E+01, 0.19477400E+00, -.18049100E+01, -.74979700E+00, -.43367300E-01, 0.87089800E+00, -.34021900E+01, 0.56246300E+00, 0.25499900E+00, 0.60026000E+00, -.21225900E+00, 0.86832800E+00, -.52075000E+00, -.19412800E+00, 0.80170800E+00, 0.54300200E+00, 0.37611600E+00, 0.12424000E+01, -.30770600E-01, 0.12228800E+01, 0.90888000E+00, 0.89052700E+00, -.36938600E+00, 0.29378200E+00, 0.46530700E+00, -.14034900E+00, -.18668700E+00, 0.13233100E+00, 0.24965200E+00, -.95805200E-01, 0.85519800E-01, 0.11964200E+00, -.69067500E-01, 0.40058400E+00, -.99505300E+00, 0.83047600E+00, 0.34723000E+00, -.21048700E+00, 0.51252300E-01, 0.29286600E-01, 0.11973600E-01, 0.71312200E+00, -.22410800E+00, -.83666800E+00, 0.15246500E+00, -.26438900E+00, -.13103400E-01, -.35724500E+00, 0.19627700E+02, -.21145400E+02, 0.16433500E+03, -.49904300E+02, 0.24917900E+02, -.14348600E+03, -.39681900E+03, 0.94183500E+02, -.27282200E+03, 0.14603700E+03, 0.13081800E+03, -.45622100E+01, -.14704600E+03, 0.13152600E+03, 0.77446400E+02, 0.25863600E+02, -.38167000E+02, 0.12333700E+02, -.55846700E+01, 0.14328500E+02, 0.11065200E+03, -.10109200E+03, 0.57267800E+02, 0.16141700E+03, -.30311500E+02, -.96671800E+02, -.20616600E+03, 0.10389100E+03, 0.13266000E+03, 0.75320700E+02, 0.66609200E+02, 0.39152000E+02, -.18580500E+02, -.21131600E+02, 0.92000600E+02, -.17835700E+03, 0.67710400E+02, 0.17181800E+03, 0.14802100E+03, -.10084800E+03, 0.20062800E+02, -.98861800E+02, -.96353500E+02, 0.61455100E+02, -.14266000E+04, 0.74957700E+03, 0.70778600E+03, -.33818900E+03, -.86622400E+02, 0.63936900E+03, 0.51985600E+03, 0.64153600E+03, 0.20004700E+02, 0.56603700E+03, -.28552400E+03, -.33588700E+03, 0.21709700E+01, 0.12029300E+03, -.20651200E+03, 0.23335500E+03, -.23387000E+03, -.14517100E+02, -.80600000E+03, 0.43320000E+03, 0.47936600E+03, -.33886400E+03, -.16378400E+03, 0.43998300E+03, 0.43670200E+03, 0.43392000E+03, -.57557200E+02, 0.56721800E+03, -.23801400E+03, -.34971400E+03, -.92720600E+02, 0.81087800E+02, -.19574200E+03, -.96485400E+02, -.37239400E+03, -.50602600E+02, -.34309200E+03, 0.17104900E+03, 0.15353300E+03, -.22000300E+03, 0.23948900E+02, 0.20939100E+03, 0.18737700E+03, 0.27884500E+03, -.11862900E+03, 0.19812600E+03, -.10151800E+03, -.61948400E+02, -.15588500E+03, -.24687300E+03, 0.48186100E+02, -.10007200E+03, 0.44638400E+03, -.15764300E+03, 0.26471000E+02, -.18501500E+02, -.98811300E+02, 0.68105600E+02, 0.15211400E+03, -.68460200E+02, -.79135900E+02, -.32188600E+03, 0.14923600E+03, 0.49080400E+01, 0.10665700E+03, -.51349800E+01, 0.16970100E+02, 0.97220100E+02, -.15203600E+02, 0.12573800E+02, -.22258000E+01, 0.60773300E+02, 0.20721000E+01, -.24537100E+02, 0.16917900E+02, 0.27174500E+02, -.17838300E+02, 0.86794900E+02, 0.22130700E+02, -.51269000E+02, -.60699800E+02, 0.13386900E+03, 0.28782100E+02, -.74694600E+02, 0.63058700E+02, 0.73269400E+02, -.99134600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.39893100E+00, -.16079800E-01, 0.10197200E+00, 0.10568500E+01, 0.36319200E-01, -.73586500E+00, -.60315200E-01, -.78615100E-01, -.43346000E+00, -.35591900E-01, -.23119600E+00, -.37797100E+00, -.20214800E+00, -.40953300E+00, -.31490000E-01, -.53895700E+00, -.24138200E+00, 0.22579500E+00, -.33183500E+00, -.76465700E+00, 0.48531400E-01, 0.12022300E-01, 0.25747300E-01, 0.22212500E+00, 0.15043800E-01, -.33865900E+00, -.52534400E-01, 0.61482500E-01, 0.39915100E+00, -.11306700E+00, 0.94107800E-01, -.34119500E-01, -.26836300E-02, 0.26813700E-01, 0.15970600E+00, 0.54889400E-01, 0.11603500E+00, -.76556800E+00, 0.12802100E-01, -.10170000E+00, -.12250400E-01, 0.83346800E-01, -.91282200E-01, 0.42271500E-01, -.14550100E+00, 0.26408200E-01, -.74079500E-02, -.57807000E-01, -.15915500E+00, -.18798800E+00, 0.27752800E-01, 0.22775200E+00, 0.20005300E+00, 0.12544500E+00, 0.45104700E-01, 0.16408800E+00, -.16406000E-01, -.19286200E+00, 0.47297500E+00, -.19804200E-01, -.35385700E-01, -.14709900E+00, 0.84015000E-02, -.46810000E-01, 0.32888700E-01, 0.46524400E-01, -.19349800E+00, -.24306700E+00, -.27469600E-01, 0.63813500E-01, 0.11519900E-01, -.55414400E-01, -.16033400E+00, -.40252900E-02, 0.36873400E-02, 0.22422300E-01, 0.11867700E+00, 0.11399700E-01, -.44707000E-01, 0.39558800E+00, 0.29423200E-01, -.13486400E-01, 0.22247000E-01, -.14224500E-01, -.17290800E-01, 0.91265000E-03, 0.86497900E-01, -.53509300E+00, -.75416700E-01, 0.13399200E+00, -.15999200E-01, 0.76280000E-01, -.96220300E-02, -.16536500E+00, 0.81545300E-01, 0.39672200E-01, 0.25572900E-01, -.22367100E+00, 0.52270200E-01, 0.40091400E-01, 0.57290300E-01, 0.12316000E+02, -.32605300E+02, -.11093800E+02, 0.11635500E+02, 0.88698100E+02, 0.65515000E+02, -.53070300E+02, 0.15330400E+03, -.76286000E+02, -.74521500E+02, -.19447900E+02, 0.75518400E+02, -.59629800E+02, -.42227000E+02, -.39235400E+02, 0.43939100E+02, -.83971100E+02, 0.42166300E+02, 0.29113800E+02, -.42204700E+02, 0.33797200E+02, 0.22928400E+02, 0.78255800E+01, 0.84601900E+02, 0.16617300E+02, 0.12041600E+03, -.60420700E+02, -.75530700E+02, -.34275500E+02, -.40785700E+02, -.21847700E+02, 0.18479000E+02, -.63602400E+02, -.50416700E+02, 0.74823500E+02, -.31717700E+02, -.79069400E+02, -.20764500E+02, 0.46631300E+02, -.21096100E+02, -.90532700E+01, 0.27988500E+02, 0.64129000E+01, 0.34817200E+03, -.17520800E+03, -.17106900E+03, 0.56282200E+02, -.14402400E+02, -.14252200E+03, -.85071000E+02, -.17351500E+03, -.51944100E+01, -.11044100E+03, 0.56660700E+02, 0.80716700E+02, 0.34836900E+01, -.44529600E+02, 0.50181400E+02, -.11027100E+02, 0.62576400E+02, -.41290700E+01, -.32804600E+01, -.18364500E+01, -.38801100E+02, 0.41959000E+02, 0.75948700E+01, -.20873400E+02, -.51622400E+02, -.26720900E+02, -.33918900E+01, -.20619900E+03, 0.89235300E+02, 0.12917800E+03, 0.45856300E+02, -.15161100E+00, 0.47164500E+02, 0.19988600E+02, 0.93772200E+02, 0.34955500E+02, 0.12251200E+03, -.60873500E+02, -.52196000E+02, 0.90393800E+02, 0.59787500E+01, -.10013800E+03, -.10040000E+03, -.13738200E+03, 0.64121600E+02, 0.10614600E+01, -.21386400E+01, -.18263200E+02, 0.21157700E+02, 0.10196600E+03, -.38484800E+02, -.34549200E+02, -.99721600E+02, 0.56181900E+02, 0.19181100E+01, -.75209700E+01, 0.44503100E+02, -.28711500E+02, -.55665700E+02, 0.13979800E+02, 0.15874200E+02, 0.73375600E+02, -.36304200E+02, 0.19371500E+02, -.41986000E+02, 0.13983800E+02, -.14093200E+02, -.29703200E+02, 0.10573400E+02, -.19017000E+02, 0.15812800E+02, -.45572000E+02, -.17048000E+02, 0.13647600E+02, -.20447900E+02, -.15284500E+02, 0.89400000E+01, -.59238900E+02, -.14396300E+02, 0.21167900E+01, 0.41628500E+02, -.12902300E+02, 0.72609900E+01, 0.19496900E+02, -.39313800E+02, -.15268900E+02, 0.35603000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.65575600E+00, -.25994000E+00, -.19217800E-02, -.23359200E+00, 0.80755500E+00, -.66175800E+00, 0.19992300E+00, 0.30033900E+00, 0.97943300E-01, 0.20880400E+00, 0.40368100E+00, 0.96432100E+00, 0.37707400E+00, 0.63082900E+00, -.34674100E+00, 0.16851400E+00, 0.11294500E+00, 0.24345200E+00, 0.31585600E+00, 0.29100300E+01, 0.14085700E+00, 0.89623100E+00, 0.12143900E+00, -.56479400E+00, -.31317100E-01, 0.40185500E+00, -.58611300E-01, -.62094700E+00, -.11850700E+00, 0.26449900E+00, 0.43947700E-01, -.38473300E-01, -.41488400E+00, 0.70223900E-01, 0.50276100E+00, -.51126200E-01, -.74092000E+00, -.12528200E+01, -.39063500E+00, 0.17672800E+01, 0.36499100E-03, 0.10310800E+01, -.73642300E+00, -.39328800E-01, -.50250700E+00, -.10102200E+00, -.75929800E-01, 0.80887300E-01, -.53230200E-01, -.66260000E-01, -.95949800E-01, -.34423700E+00, 0.41610600E+00, 0.16599900E+00, 0.77475700E+00, 0.84501400E+00, 0.55422900E-01, 0.32163500E+00, 0.68871800E+00, -.36112700E+00, -.16645500E+00, -.26263000E+00, -.20775100E-01, -.20450900E+00, 0.57473400E-01, -.59801700E-01, -.19780200E+00, -.34924200E-02, -.72349500E-01, -.72152600E+00, -.97543900E-02, -.20053900E+00, 0.12062100E+00, 0.27300700E+00, -.95921500E-01, 0.69478500E-02, 0.20530800E+00, 0.37795400E+00, -.15721000E+00, 0.22204400E+00, -.82012500E-01, -.21126300E-01, 0.60496300E-02, -.25078500E-01, 0.82483700E-01, -.11727100E+00, -.22624800E+00, 0.12461800E+01, 0.14512000E+00, -.27315700E+00, 0.98964000E-01, -.12897000E+00, -.35334000E-01, 0.40584700E+00, 0.18855000E+00, -.28260100E+00, 0.54542000E-01, -.43735200E+00, 0.23476100E-01, 0.42924000E+00, -.40421300E+00, 0.27813900E+00, 0.20865500E+03, -.94764000E+02, 0.23420800E+01, -.25416500E+03, -.15272300E+03, 0.14522600E+03, -.26123200E+03, 0.13255100E+03, 0.14121700E+03, 0.34773900E+02, -.25089000E+03, 0.75145100E+02, 0.83302200E+02, -.23157500E+02, -.31902100E+02, 0.31551500E+03, -.15791600E+03, -.14128000E+03, 0.19015500E+03, -.16217300E+03, -.13217900E+03, -.72722700E+02, -.15768100E+03, 0.77403900E+01, -.21261400E+03, 0.10655100E+03, 0.10391800E+03, 0.78105600E+02, 0.11356900E+03, 0.99604500E+01, -.95072700E+02, 0.15268000E+02, 0.82378200E+02, 0.29439400E+02, -.19354900E+02, -.55530400E+01, 0.10329000E+03, -.13212700E+03, -.72190500E+02, -.17123700E+03, -.17432400E+03, 0.26333000E+02, -.13704800E+04, 0.69739500E+03, 0.68380000E+03, -.37056100E+03, 0.46819500E+02, 0.64822100E+03, 0.54862300E+03, 0.65738100E+03, -.87849500E+02, 0.35912900E+03, -.18311000E+03, -.18897100E+03, -.59833700E+02, 0.90467400E+01, -.12883900E+03, 0.12509700E+03, -.16013800E+03, -.92584400E+02, -.81321300E+03, 0.41602500E+03, 0.38727900E+03, -.26485400E+03, -.15126200E+02, 0.44329200E+03, 0.41014100E+03, 0.40541700E+03, 0.47110000E+02, 0.13324100E+03, -.47415800E+02, -.73899400E+02, -.85865100E+02, 0.87539500E+02, -.45387100E+02, -.16316900E+02, -.16258100E+03, -.63408500E+02, -.22661300E+03, 0.11252100E+03, 0.11362100E+03, -.25319300E+03, 0.35098400E+02, 0.18449600E+03, 0.17972500E+03, 0.15294700E+03, -.17302900E+03, -.24259300E+01, 0.45220700E+01, 0.14776900E+02, -.65853900E+02, -.80646400E+02, 0.54259000E+02, 0.22020700E+02, 0.32213000E+03, -.42024500E+02, -.15161600E+03, 0.95062100E+02, 0.79564000E+02, 0.45514100E+02, 0.29803000E+02, 0.50988300E+02, -.21969900E+01, -.13253200E+03, 0.11101700E+03, -.20302300E+02, 0.17673700E+02, -.94603500E+01, 0.19212900E+02, 0.70428100E+02, 0.80777500E+01, 0.29819600E+02, -.16319100E+02, 0.64163300E+02, 0.22395500E+02, -.36536800E+02, 0.29657300E+02, 0.40822100E+02, -.94106000E+02, 0.14588100E+03, 0.11486500E+02, -.93902300E+01, -.92057700E+02, 0.12532300E+02, -.20561600E+02, -.54531700E+02, 0.72008600E+02, -.18175700E+02, -.33100900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20787500E+01, 0.20187100E+01, 0.57261500E+00, -.65157300E+01, 0.11536100E+00, 0.43973700E+01, -.47950000E+01, -.13445700E+01, 0.33397200E+00, -.15998800E+01, 0.22308400E+00, 0.76126200E+00, -.55645900E+00, 0.15079700E+01, -.10375700E+01, 0.39276300E+01, 0.21240400E+01, 0.39573600E+00, 0.15000700E+01, -.77938200E+00, -.80615700E-01, -.36417400E+00, 0.18696700E+01, -.54443700E-01, 0.82814600E+00, -.17571200E+01, -.57564800E+00, 0.20992300E+01, -.71523400E+00, -.83289200E+00, 0.23749700E-01, -.98045700E+00, 0.50495100E+00, 0.47052100E+00, 0.45067700E+00, -.87871300E-01, -.10176500E+01, -.23202200E+01, 0.11256700E+01, -.22189400E+00, 0.95735500E-01, -.12441000E+00, -.30272800E-01, 0.17005900E+01, -.85951600E-01, 0.28908600E+00, 0.10445400E+00, 0.32434800E+00, -.19987300E+01, 0.17042300E+01, -.17546100E+00, -.15676100E+01, 0.20058000E+01, 0.50797600E-01, 0.73424600E+00, -.15761600E+00, 0.17036100E+00, 0.89910800E-01, 0.95130400E+00, 0.77675100E+00, -.13133200E+00, -.69653600E+00, -.41643200E-01, -.41023300E+00, 0.39800600E-02, 0.24534000E+00, -.36228600E+00, -.15008200E+00, -.19254700E+00, 0.39229000E-01, 0.47663100E-01, 0.32158200E+00, -.17055900E+01, 0.41174500E+00, 0.59911500E-01, 0.17796700E+00, 0.21839800E+00, 0.19542300E+00, 0.13255800E+00, 0.86165200E+00, -.30877700E+00, 0.16426700E+00, -.56823000E-01, -.28499400E+00, -.13612400E-01, -.19442300E+00, 0.51269100E+00, 0.46047500E-01, -.29948600E+00, -.37855300E+00, 0.16925200E+00, -.26396300E+00, 0.73806200E-01, 0.16221500E+01, 0.29531000E+00, -.14697700E+01, 0.16494700E+00, -.25138700E+00, -.17268900E+00, 0.11510900E+01, -.14204000E+00, 0.48684000E-01, -.15588300E+01, -.76180600E+03, 0.17892300E+03, 0.40421400E+02, 0.20614500E+03, -.11570100E+03, -.14920000E+02, 0.24821300E+02, 0.50144100E+02, 0.30138300E+03, 0.23609300E+02, -.24088900E+03, -.27512900E+03, -.22384600E+03, 0.21023000E+03, 0.16885000E+04, -.83683100E+03, -.78367800E+03, 0.58438300E+03, -.43699300E+03, -.58098700E+03, -.45523000E+03, -.64602600E+03, -.89288100E+02, -.29293900E+03, 0.14889500E+03, 0.12999800E+03, 0.68046200E+02, 0.12918200E+03, 0.24854300E+02, -.93373900E+02, 0.17664900E+03, 0.88039200E+02, -.36935000E+03, 0.18504400E+03, 0.18734500E+03, 0.16578200E+03, -.41763900E+02, 0.53097700E+02, -.69946400E+02, 0.92456100E+02, 0.23205900E+03, -.14300700E+04, 0.73843000E+03, 0.71133900E+03, -.21459500E+03, 0.11036400E+03, 0.65182600E+03, 0.41080200E+03, 0.65487600E+03, -.45063100E+03, -.15921100E+03, 0.65424400E+02, 0.71347100E+02, -.11223300E+03, -.34177200E+03, 0.73399200E+02, 0.23384300E+03, -.32995900E+03, -.37066700E+03, -.46387300E+03, 0.27006200E+03, 0.14849300E+03, 0.10959800E+03, 0.26666700E+03, 0.17328700E+03, 0.47197900E+02, 0.54617800E+02, 0.18111000E+03, 0.19763600E+03, -.10111100E+03, -.57211800E+02, -.31474200E+03, 0.13665400E+02, 0.93090300E+02, 0.10948300E+03, -.77114800E+02, -.36946800E+03, -.57266400E+03, 0.28184900E+03, 0.29564600E+03, -.80456600E+03, 0.84202300E+02, 0.51725700E+03, 0.58251100E+03, 0.59427100E+03, -.45748900E+03, 0.38988000E+03, -.18479300E+03, -.16722600E+03, 0.24315800E+03, 0.92380600E+03, -.35435700E+03, -.44090000E+03, -.25633800E+02, 0.69840700E+03, -.51687200E+03, 0.27182600E+03, 0.28879700E+03, -.24626100E+02, -.80662400E+02, 0.20330100E+03, -.12558800E+02, 0.14484000E+03, 0.15695000E+03, 0.10588900E+03, -.12801200E+03, 0.58027600E+02, -.32892800E+02, 0.63091600E+02, 0.11320400E+03, -.70722800E+02, 0.93124300E+02, -.72373500E+01, -.85218200E+02, 0.73826800E+02, -.95614100E+02, -.20011600E+02, -.96495500E+02, 0.33727100E+03, -.10685100E+03, -.55359300E+02, -.70173600E+02, -.46729700E+02, 0.15720500E+02, -.21084900E+02, 0.14266600E+03, -.21874600E+03, 0.85965000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23944200E+01, -.11306000E+01, -.20351300E+00, 0.47398300E+00, 0.21065600E+01, -.18492500E+01, 0.31743000E+01, 0.12306500E+01, 0.41543600E+00, 0.70040900E+00, 0.87435900E+00, 0.20635000E+01, 0.58174000E+00, 0.26031600E+01, -.12665400E+01, 0.21940400E+01, 0.36513700E+00, 0.59371900E+00, -.17638400E+00, 0.40794300E+01, 0.95808400E+00, 0.20234600E+01, -.61637800E+00, -.12017000E+01, 0.16194300E+01, -.24257000E+01, -.35026000E+00, -.32516500E+01, 0.12433000E+01, 0.81937600E+00, 0.30214000E+00, -.56249100E+00, -.19549200E+01, 0.16564900E-02, 0.89844500E+00, -.14279200E+00, -.36759000E+00, -.18995400E-02, -.10999600E+01, 0.11549800E+01, -.15795500E+00, 0.12441700E+01, -.16942600E+01, -.11409300E+01, 0.33280600E+00, 0.33419100E+00, -.24820100E+00, -.22803000E+00, -.89479200E+00, -.21864700E+01, -.10500300E+01, -.35565500E+00, 0.15560400E+00, -.63165100E-01, 0.11812000E+01, -.73914200E+00, 0.16797500E+00, 0.89403000E+00, 0.77438400E+00, 0.96455200E+00, -.19207200E+00, -.53866900E+00, 0.97679900E-01, -.43433900E+00, 0.10416200E+01, 0.63631900E-01, -.74520700E+00, -.53667900E+00, -.12293600E-01, -.16849400E+01, 0.45161500E+00, -.58494100E+00, -.32868700E+01, 0.56377700E+00, 0.11152800E+01, 0.13627100E+00, -.95894900E-01, 0.10818400E+01, -.72324200E+00, -.64047600E+00, -.41571200E+00, -.56916500E+00, -.77204000E-01, 0.19200500E-01, 0.33852200E+00, 0.27709000E-01, 0.47199000E+00, 0.32214900E+01, 0.32521400E+00, -.58514600E+00, -.14687200E+00, 0.19744200E-01, -.18910700E+00, -.61172200E-01, -.10340100E+00, -.78618700E+00, -.11341800E+00, 0.62942400E+00, 0.53952900E-01, -.27918800E+00, 0.46114300E+00, 0.22012400E+01, 0.22880000E+00, -.35297700E+00, -.14983500E+03, -.62170500E+03, -.48751400E+03, 0.46845100E+03, -.60620500E+03, 0.30381400E+03, 0.31782800E+03, 0.26227500E+03, -.30198300E+03, 0.22589000E+03, 0.20595100E+03, 0.37442000E+03, -.25678100E+03, 0.12936100E+04, -.64881400E+03, -.62218900E+03, 0.43789300E+03, -.14238000E+03, -.47908300E+03, -.47411400E+03, -.57490700E+03, 0.74394000E+02, -.88338200E+03, 0.44164500E+03, 0.42854300E+03, 0.14937200E+03, 0.17122400E+03, 0.17624700E+03, -.19926800E+03, -.33376300E+02, 0.27944800E+03, -.10188600E+03, 0.21634000E+02, 0.28955700E+02, 0.57988500E+02, -.30370500E+03, 0.11811200E+03, 0.47383900E+03, 0.28058200E+03, -.13361000E+03, -.44000200E+03, 0.22635300E+03, 0.21851400E+03, 0.91474300E+01, 0.20928300E+03, 0.16778800E+03, 0.13188500E+02, 0.18834400E+03, -.18294700E+03, -.10774200E+04, 0.53377600E+03, 0.55334500E+03, -.42868100E+02, 0.28205300E+02, 0.21716000E+03, -.45182800E+03, -.75186900E+02, -.42434100E+02, 0.18869800E+04, -.95206700E+03, -.99632800E+03, 0.28083500E+03, 0.67102300E+03, -.82916500E+03, -.50779000E+03, -.85557200E+03, 0.31452800E+03, 0.82712100E+03, -.33164700E+03, -.37190100E+03, -.34185700E+03, -.77820500E+02, -.78000900E+02, 0.71614600E+02, -.23766600E+03, -.27046700E+03, -.14290200E+04, 0.71233900E+03, 0.71777800E+03, -.60237500E+03, 0.48797400E+02, 0.82641800E+03, 0.89960000E+03, 0.11050600E+04, -.30889700E+03, -.27213700E+03, 0.14064500E+03, 0.13371900E+03, 0.10452100E+03, -.42010900E+03, 0.33348200E+03, 0.87710800E+03, 0.60593800E+03, -.17862600E+03, -.22792100E+03, 0.14963000E+03, 0.14080500E+03, 0.69933300E+01, -.69813100E+02, 0.13956200E+03, 0.37219100E+02, 0.12747500E+03, -.10036200E+02, -.20129700E+02, -.47141000E+02, -.79175900E+02, 0.11036900E+03, 0.18703200E+03, 0.32792100E+02, 0.63883100E+02, -.35440200E+02, 0.16926300E+03, 0.54910700E+02, -.12762300E+03, 0.42308400E+02, -.40270400E+01, -.12935600E+03, 0.40038700E+03, 0.11358500E+03, -.63741300E+02, -.20507700E+03, -.29441900E+03, -.14074000E+03, -.13121100E+03, 0.27991600E+03, -.21823400E+03, 0.36996100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.29997300E+01, 0.11250300E+01, 0.85062200E+00, -.46129900E+01, 0.51186800E+00, 0.47787400E+01, -.29027700E+01, -.14362400E+01, 0.25473800E+00, -.10861500E+01, -.17714900E+00, -.82174200E-01, -.73379300E+00, -.40508000E+00, -.68659900E+00, 0.43456700E+00, 0.61865100E+00, 0.43656600E+00, 0.10023500E+01, -.46146400E+01, -.23524200E+00, -.14140000E+01, 0.88311800E+00, 0.22351400E+00, 0.10479400E+01, -.93330100E+00, -.89250600E+00, 0.24051900E+01, -.19799100E+00, -.42231500E+00, -.91724500E+00, -.13729100E+01, 0.51077300E+00, 0.29672700E+00, -.18395400E+01, -.67913800E+00, -.43070400E+00, 0.10272000E+00, 0.88806400E+00, -.50874200E+01, -.11825500E+00, -.25059200E+00, 0.22875600E+00, 0.65532000E+00, 0.13376100E+00, 0.31724300E+00, 0.83637900E-01, 0.76964300E+00, -.94531700E+00, -.50846800E+00, 0.22544400E+00, -.42454900E-01, 0.38232200E+00, 0.64749100E+00, -.98088000E+00, 0.61058300E-01, 0.17377900E+00, -.19059300E+01, -.10951600E+01, 0.12890100E+00, 0.42891500E+00, 0.10367200E+01, 0.25952400E-01, 0.16392900E+00, -.29045500E+00, 0.31859600E+00, -.24745900E+00, 0.86386500E+00, -.60969700E-02, 0.82554300E+00, -.36821700E+00, 0.25138800E+00, 0.20385000E+00, 0.66298800E+00, -.30661200E+00, -.64106100E-01, -.49906100E+00, -.78238300E+00, 0.25832000E-01, -.17232000E+01, 0.38322100E+00, -.36512100E-01, 0.46085200E-01, -.15016600E+00, -.32574000E-01, -.49941800E+00, -.25421200E+00, 0.11203400E+01, 0.36864400E+00, -.20808200E+00, 0.25556700E+00, -.14892100E+00, -.75448700E-02, -.46594700E+00, -.80282200E-01, 0.95105900E+00, -.21159500E+00, -.55735500E+00, 0.11629500E+00, -.57286800E+00, -.19625900E+00, -.84403300E+00, 0.48480000E+00, -.43109500E+00, -.22255500E+00, -.32702600E+03, -.43848400E+03, -.65494700E+00, -.33435900E+03, 0.17262600E+03, 0.18360400E+03, 0.45234700E+02, -.10380700E+03, 0.98788400E+02, 0.92367400E+02, -.10857200E+03, 0.18037400E+02, 0.10302200E+04, -.51446400E+03, -.48764300E+03, 0.20261300E+03, -.17941900E+03, -.39110500E+03, -.34559700E+03, -.68963800E+03, -.17814000E+02, -.10865400E+03, 0.55276500E+02, 0.52610000E+02, 0.61734900E+02, 0.83817500E+02, -.52794000E+01, -.43112000E+02, 0.26985300E+03, 0.54270400E+02, -.31052600E+03, 0.15696200E+03, 0.18645300E+03, -.33727800E+02, -.11717800E+03, 0.94396300E+02, 0.79677600E+02, 0.46184100E+02, -.20013300E+02, -.19748500E+03, 0.11443300E+03, 0.95526200E+02, -.56114200E+02, 0.53448700E+02, 0.10285400E+03, 0.14312900E+03, 0.14385400E+03, -.29436500E+02, -.49008200E+03, 0.23706900E+03, 0.22127800E+03, 0.29039100E+02, 0.16017700E+03, 0.98277800E+02, -.40399700E+02, -.32486100E+03, 0.27097300E+02, 0.26726000E+03, -.11591900E+03, -.17459300E+03, 0.21536200E+03, 0.10939900E+03, -.18112500E+03, -.17521600E+03, -.14362100E+03, 0.90394500E+02, -.54973100E+02, 0.19418900E+02, -.27507800E+02, -.12009400E+03, 0.51544800E+02, 0.14728300E+03, -.35833600E+01, -.22124200E+03, -.95204000E+02, -.57161300E+03, 0.28517100E+03, 0.27791500E+03, -.34269200E+03, -.37792900E+01, 0.42079000E+03, 0.43423900E+03, 0.44111600E+03, -.26855200E+03, 0.82836600E+03, -.40707700E+03, -.39025500E+03, -.71301400E+01, -.24245400E+03, -.18124300E+03, 0.12314000E+03, 0.47668600E+03, -.50705000E+02, 0.19643800E+03, -.85898200E+02, -.10118900E+03, -.55862200E+02, -.16771700E+02, -.59180000E+02, 0.21083900E+02, -.11900400E+03, 0.20907400E+02, -.36702400E+02, 0.20839900E+02, -.11750900E+02, 0.31484000E+01, 0.28968900E+02, -.31499300E+02, 0.22606100E+02, -.19215900E+02, 0.33922400E+02, 0.39832500E+02, -.19854400E+02, 0.32964100E+02, -.31882800E+02, -.30711900E+02, 0.18445200E+03, -.27691500E+02, 0.38003200E+02, -.39643500E+02, -.69055900E+02, -.64882900E+02, -.41693100E+00, 0.98076900E+02, -.11410900E+03, -.30632700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20074700E+01, 0.13244100E+01, 0.66306700E+00, -.27260300E+01, -.60737800E+00, 0.33406000E+01, -.22761100E+01, -.97868000E+00, 0.58814200E+00, -.11187600E+01, -.71538400E-01, -.33900700E+00, -.55023600E+00, -.13888600E+01, -.13510200E+01, 0.12363300E+01, 0.32644000E+00, -.15098200E+01, 0.31386800E+01, -.18519700E+01, 0.85237000E-01, -.12595000E+01, 0.81731800E+00, -.31627500E+00, 0.88762600E+00, -.23747100E+01, -.14443900E+01, 0.20642200E+01, -.15625300E+01, -.11924500E+01, 0.18401600E+00, -.69527500E+00, 0.14237100E-01, 0.24182900E+00, -.79335200E+00, 0.33412500E+00, -.10034500E+01, -.19570000E+01, 0.44943400E-01, -.75942300E+00, -.34254500E+00, 0.10481100E+01, -.44168100E+00, 0.18934400E+01, 0.19060700E+00, 0.35457600E+00, 0.18795200E+00, 0.57424100E+00, -.37401100E+00, 0.11524000E+01, 0.14764000E+00, 0.56858300E+00, 0.31163200E+00, 0.38427400E+00, -.99215600E+00, -.11922800E+00, -.47410600E-01, -.15683200E+01, -.24509500E+01, 0.18247300E+01, 0.40274000E+00, 0.93674000E-02, 0.60535300E-01, 0.12657800E+00, 0.12675100E+00, 0.16734100E+00, -.73786200E+00, -.20848300E+00, -.15347000E+00, 0.26648400E+01, -.30133100E+00, -.30213000E-01, 0.54511900E+00, 0.41599200E+00, -.21451300E+00, 0.39434700E-01, 0.10954400E+00, 0.25780800E-02, 0.99988000E-01, 0.11910000E+01, -.11025100E+00, -.62891400E+00, -.84240700E-01, 0.13578600E+00, 0.10210400E+00, 0.15961500E+00, 0.24162500E+00, 0.17832800E+01, 0.20940300E+00, -.13033000E-01, -.81279600E-01, -.31815000E-01, 0.87537600E-01, -.33189100E-01, -.45434900E+00, -.16197500E+00, -.10201900E+00, 0.45358500E+00, -.59494700E-01, 0.52938700E+00, 0.23858000E-01, 0.13557400E-01, -.88157300E-01, 0.53482500E-01, 0.16196700E+00, -.32624800E+00, 0.47245900E+03, -.25624200E+02, 0.11521800E+03, -.52118900E+02, -.60914700E+02, -.37806400E+02, 0.37846800E+02, -.23089500E+02, 0.18169500E+02, -.17492600E+03, 0.10169500E+03, 0.51343700E+03, -.25491300E+03, -.26376700E+03, 0.37697100E+01, 0.12274600E+03, -.29047700E+03, -.30725200E+03, -.25227000E+03, 0.13196900E+03, 0.39327100E+03, -.19600000E+03, -.19088300E+03, -.88645800E+02, -.88868400E+02, -.83942300E+02, 0.55344600E+02, 0.21948700E+03, -.16872800E+03, 0.82942100E+02, -.27327900E+02, -.26311200E+02, -.53998400E+01, 0.11132300E+03, -.91084700E+02, -.21061900E+03, -.14270100E+03, 0.65573200E+02, 0.31529200E+03, -.15370300E+03, -.15745400E+03, 0.50096000E+02, 0.20748700E+02, -.11627300E+03, -.64440600E+02, -.99513000E+02, -.64427200E+02, -.12017000E+03, 0.59319200E+02, 0.48898300E+02, -.44661800E+02, -.19673000E+03, 0.12792700E+03, -.89157500E+01, 0.30300800E+03, -.11912500E+03, 0.12691600E+03, -.58017400E+02, -.47480500E+02, 0.67662600E+02, -.15073200E+02, -.85767900E+02, -.10598300E+03, -.28134800E+02, -.18061500E+02, -.70297000E+03, 0.31029500E+03, 0.32211100E+03, 0.70042900E+02, 0.28239400E+02, 0.24206100E+03, 0.62827800E+02, 0.21522100E+03, 0.85885700E+02, -.35440400E+02, 0.18846500E+02, 0.15646900E+02, 0.10179000E+03, -.72043100E+02, 0.52820900E+01, 0.14253400E+02, -.19632900E+03, 0.10158100E+03, -.16917500E+03, 0.83570000E+02, 0.90332200E+02, 0.40925200E+02, 0.28251200E+03, -.44394300E+02, 0.22704500E+02, -.34230800E+03, 0.14905700E+03, -.28041100E+02, 0.13213400E+01, 0.35217600E+01, -.37938100E+02, -.74338800E+02, 0.29609500E+02, 0.40941300E+02, 0.80683500E+02, -.45999600E+02, 0.15445100E+02, -.50218900E+02, 0.34064500E+02, -.33755600E+02, -.15765700E+02, -.15106100E+01, -.25812700E+02, 0.28620800E+02, -.49969400E+02, -.23674900E+02, 0.10599800E+01, -.33866700E+02, -.31106600E+01, -.47583800E+02, -.89935700E+02, -.11530300E+03, 0.44273700E+01, 0.38426800E+02, -.10242300E+03, -.56445900E+01, 0.10874700E+02, -.66696900E+02, -.79192500E+02, 0.41236700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.30628300E+01, 0.19269300E+01, 0.13330100E+01, -.28097200E+01, 0.12536300E+00, 0.32366300E+01, -.24977000E+01, -.10984500E+01, 0.13825900E+01, -.73767300E+00, -.63020900E+00, -.64961900E+00, -.10843600E+01, -.25555400E+01, 0.85444600E+00, -.41859800E+00, 0.68146200E+00, 0.29176600E+00, 0.67008000E+00, -.37927600E+01, 0.60863200E+00, -.12045400E+01, -.65243600E+00, -.10185200E+00, 0.20182400E+01, -.24246900E+01, -.30943500E-01, 0.23728700E+01, 0.11885600E+01, -.90547300E+00, -.13000300E+01, 0.22074700E+00, 0.70143000E+00, 0.90384600E-02, -.22693200E+00, -.72854700E-01, -.17710800E+01, -.10208200E+01, 0.43031800E-01, -.45387900E+01, -.11604400E+00, 0.43465400E+00, -.36071800E+01, 0.24224300E+01, -.94919800E+00, 0.11603800E+01, 0.48984500E-01, -.20538000E+00, -.65886300E-01, 0.12202500E+01, 0.65346400E-01, 0.68475500E+00, 0.39677900E+00, 0.44737200E+00, -.70676200E+00, 0.43277900E+00, 0.71295600E-02, -.53167800E+00, -.52153800E+00, 0.15728600E+01, 0.26211300E+00, -.61336400E-01, 0.42067000E-01, 0.17982100E+00, -.27945800E+00, 0.49802200E+00, 0.44330800E-01, 0.10618400E+01, -.49004600E-01, 0.14146300E+01, -.57284700E+00, -.21217500E-01, -.11698800E+01, 0.13749500E+01, 0.38871300E+00, 0.12090500E+00, -.79375500E+00, 0.27855300E+00, -.73074700E-01, 0.39991200E+00, 0.57037200E+00, -.45750100E+00, 0.19461700E+00, 0.48368300E+00, -.42472900E-02, 0.39246400E-01, -.11501100E+01, -.29575500E+00, 0.65253700E+00, -.33752500E+00, -.15155000E+00, 0.20384600E+00, -.19489200E+00, -.86140800E+00, 0.25405000E+00, 0.60930500E+00, -.53226600E-02, 0.94539500E+00, -.22617300E+00, -.10032600E+01, 0.25706200E+00, -.17204100E+01, -.20061800E+00, -.12780400E+00, 0.35759300E-02, 0.35379700E+00, -.54487500E+00, -.29213200E+03, 0.28742300E+03, -.14564200E+03, -.16491700E+03, -.21993400E+03, 0.11333300E+03, -.16305300E+02, 0.74291700E+02, -.19845500E+03, 0.10105400E+03, -.66645800E+03, 0.33165900E+03, 0.29784500E+03, -.23171700E+03, 0.23467500E+03, 0.15741000E+03, 0.96368000E+02, 0.44721000E+03, 0.13806100E+03, 0.48029500E+03, -.24063600E+03, -.22755900E+03, -.56677500E+02, -.92108400E+02, -.11691500E+03, 0.40949300E+02, -.54576100E+02, -.18565800E+03, 0.30470000E+03, -.14699900E+03, -.14437800E+03, -.22635800E+02, 0.19472500E+03, -.17169600E+03, -.37567500E+03, -.17248300E+03, 0.58846100E+02, 0.70680100E+03, -.36176300E+03, -.35095800E+03, 0.19879600E+02, 0.40977400E+01, -.27817600E+03, -.10701900E+03, -.32501700E+03, 0.16179700E+03, -.11690400E+04, 0.58936800E+03, 0.57993200E+03, 0.98454800E+02, 0.47447900E+02, 0.32017700E+03, -.12630700E+03, -.41310600E+01, 0.14449100E+03, -.76518600E+03, 0.37583000E+03, 0.43981800E+03, -.23876200E+03, -.23733600E+03, 0.35836900E+03, 0.25421900E+03, 0.38461600E+03, -.11808400E+03, -.52409000E+03, 0.23877000E+03, 0.23685500E+03, 0.27924100E+03, 0.55468200E+02, 0.79533100E+01, -.40774000E+02, 0.23104800E+03, 0.29313100E+03, 0.73217600E+03, -.36329700E+03, -.36744800E+03, 0.43336300E+03, -.13011000E+03, -.48666500E+03, -.53812000E+03, -.86929600E+03, 0.29400900E+03, 0.12040500E+04, -.60685600E+03, -.60933600E+03, -.14081600E+03, 0.40487600E+02, -.31913200E+03, 0.16737600E+03, 0.19425800E+03, -.65341400E+02, 0.44495900E+03, -.24398100E+03, -.24127100E+03, -.13852100E+02, -.26084500E+02, -.12967800E+03, 0.41550900E+02, -.15659100E+03, -.94121400E+02, 0.30106300E+01, -.26292200E+02, 0.39260000E+02, -.55864100E+02, -.10752000E+03, -.13564800E+01, -.12697100E+02, 0.99554700E+01, -.98646600E+02, 0.16058900E+01, 0.37282600E+02, -.11258100E+02, -.65883300E+02, 0.40444300E+02, -.27218600E+03, -.57022400E+02, 0.48380600E+02, 0.11334700E+03, -.49580500E+02, 0.79425200E+02, 0.67797100E+02, -.18531300E+03, -.12181000E+03, 0.31552700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11478500E+01, 0.88355400E+00, 0.97656700E-01, -.33568700E+01, -.40832500E+00, 0.20957400E+01, -.30237400E+01, -.75660600E+00, 0.98629200E-01, -.92022700E+00, 0.54024200E-01, 0.37653300E+00, -.30438800E+00, 0.12228600E+01, -.30211000E+00, 0.12062700E+01, 0.12366200E+01, 0.10668800E+01, 0.65001200E+00, 0.66802400E+00, 0.87355500E-01, 0.35398300E+00, 0.83391600E+00, -.40803100E+00, 0.73668300E+00, -.92199700E+00, 0.91822900E-01, 0.58735600E+00, 0.47533200E+00, -.32387200E+00, -.50615600E+00, -.43725800E-01, -.81826900E-01, -.25431800E-01, -.16134000E+00, -.60929700E-01, -.94928200E+00, -.10835800E+01, -.42612700E+00, -.12209100E+00, 0.31227700E-02, 0.79142900E+00, -.11697300E+01, 0.33735200E+00, -.25351900E+00, -.86013600E-01, 0.29081700E-01, 0.48037100E+00, 0.42494700E+00, 0.11391400E+01, -.15405700E+00, -.10768500E+01, -.14025200E+00, -.18275400E+00, 0.10386900E+00, -.32843000E-01, 0.82467700E-01, -.71874300E+00, -.39485300E+01, 0.10858300E+01, 0.20258700E+00, 0.47940200E-01, 0.50768400E-01, 0.17918700E+00, -.17853200E+00, -.15286900E+00, -.60096200E+00, -.74033700E+00, 0.49416600E-01, -.41271200E+00, 0.13942000E+00, 0.71379200E+00, 0.11997300E+01, -.86531500E+00, -.32095500E+00, -.14463200E+00, -.22492200E+00, -.10665100E+01, 0.45538100E+00, -.20747800E+01, 0.21328700E+00, 0.48616000E+00, -.21296800E-01, -.22561700E+00, -.11040900E+00, -.77878700E-01, -.39071100E+00, 0.20129600E+01, 0.51820000E-01, 0.31351600E+00, -.12195800E+00, 0.21082400E+00, -.10184300E+00, -.85474300E+00, -.23570500E+00, -.43859900E+00, 0.36074500E-01, 0.17447700E+00, 0.99733300E-01, 0.69518200E-01, 0.26992900E+00, 0.29506600E+01, 0.49312100E-01, -.32858500E+00, 0.48428400E+00, 0.34473600E-01, 0.17356800E+00, -.20056100E+00, -.30326300E+03, 0.14792800E+03, 0.15615000E+03, -.24805800E+02, -.27861300E+02, 0.10431900E+03, 0.44434500E+02, 0.18055700E+03, -.55557300E+02, 0.29281700E+03, -.14488300E+03, -.14054600E+03, 0.11372100E+03, 0.29902000E+02, -.12929700E+03, -.11598700E+03, -.18097300E+03, -.40240500E+02, -.12513300E+03, 0.62297300E+02, 0.58520100E+02, 0.59174200E+02, 0.41920800E+02, 0.38261100E+02, -.16720500E+01, 0.42970100E+01, 0.63947100E+02, -.27812900E+03, 0.14585600E+03, 0.12912500E+03, 0.10355900E+03, -.34898600E+02, 0.70169200E+02, -.53849400E+02, 0.33816100E+02, 0.35219100E+02, -.45943100E+03, 0.22686300E+03, 0.22984300E+03, 0.98113900E+01, -.59926600E+02, 0.16549600E+03, 0.37243100E+02, 0.21792800E+03, 0.30729700E+01, -.57999400E+02, 0.28621900E+02, 0.36661100E+02, 0.49147200E+02, 0.16111800E+03, -.53921800E+02, -.70695800E+02, -.11974100E+03, 0.11844100E+03, -.70678700E+03, 0.35847200E+03, 0.34172300E+03, -.15210200E+02, -.12388400E+03, 0.28682100E+03, 0.15914100E+03, 0.27286200E+03, -.29691200E+01, 0.18138700E+03, -.11134100E+03, -.58555000E+02, -.56642300E+02, -.21467200E+02, -.50607000E+02, 0.38691100E+01, 0.43454500E+02, -.50266600E+02, -.84156500E+02, 0.41167200E+02, 0.45154300E+02, -.16246400E+03, -.88838900E+02, 0.99575100E+02, 0.16982400E+03, 0.24807800E+03, -.85400200E+02, 0.21578400E+03, -.10671300E+03, -.11234500E+03, -.45681300E+01, -.27904200E+02, -.45773000E+02, -.50062500E+01, -.57729600E+02, -.42582400E+02, 0.23285700E+03, -.11515900E+03, -.10897300E+03, -.40478900E+01, 0.74032200E+02, -.84358000E+02, 0.93552800E-01, -.52866200E+02, -.21514400E+02, -.24508400E+02, 0.71982800E+02, -.20758600E+02, 0.65903700E+01, 0.31639300E+02, -.33921700E+02, 0.10764500E+02, -.20791200E+02, 0.49007800E+02, 0.17228500E+02, 0.30810600E+02, 0.17019600E+02, 0.14992400E+02, 0.65855400E+02, 0.81209200E+02, 0.38122600E+02, -.36984100E+02, -.28911100E+02, 0.33940100E+02, 0.11170000E+02, -.25521600E+02, 0.56383300E+02, 0.29857900E+02, -.55925700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13783000E+01, -.20988800E+01, -.76545000E+00, 0.37644800E+00, -.29458600E+00, 0.68201400E-01, 0.19850700E+01, 0.63064100E+00, -.50242900E+00, 0.59421800E+00, -.60561200E+00, -.62626600E+00, -.55025900E+00, 0.10167400E+01, -.14792800E+01, 0.14464400E+01, 0.17542500E+00, -.13697800E+01, 0.16473700E+01, 0.80046500E+00, 0.40926700E+00, 0.34092200E+00, -.29673900E+00, -.69583200E+00, 0.15801200E+00, -.19685100E+01, 0.49826100E+00, -.30869600E+00, 0.20310400E+00, -.29940800E+00, 0.47983100E+00, 0.54052700E+00, -.46759600E+00, 0.21770800E-01, 0.50077400E+00, -.46751800E-01, -.33185300E+00, -.69917500E+00, -.20812900E+00, 0.27200500E+01, -.77270500E-01, -.94858500E-01, 0.14473300E+01, -.86435000E+00, 0.74790900E+00, -.42472500E+00, 0.40641900E-01, 0.35654900E+00, -.37285200E+00, -.86436900E+00, -.17819400E+00, -.83092400E+00, -.22720600E+00, -.92866000E-01, 0.80941000E+00, -.22847700E+00, 0.98469900E-01, -.48943900E+00, -.14466100E+01, 0.83143900E+00, -.45687700E-01, -.20215200E+00, 0.10335700E+00, -.34846100E+00, 0.29427200E+00, -.77705700E-01, -.10306100E+01, -.59538800E+00, -.30599200E+00, -.63777700E-01, 0.28954100E+00, -.28848200E+00, -.44037300E+00, -.69491300E+00, 0.51487800E+00, -.12685800E+00, -.20441700E+00, 0.36106300E+00, 0.56720600E-02, 0.13900500E+00, -.87414300E-01, -.90035300E-01, 0.27591500E-01, -.23169000E+00, -.77235300E-01, 0.90067700E-01, 0.12902300E+00, -.12437600E+01, -.19439500E+00, -.43926500E+00, -.12153900E+00, 0.52828400E-01, -.12241900E-01, -.45533500E+00, 0.10158200E+00, 0.69774700E+00, -.47436400E-01, 0.45022100E+00, -.37285600E-01, -.35261000E-01, -.66599200E+00, -.15490100E+01, 0.46390900E+00, -.23715500E+00, -.38199600E+00, 0.27637900E-02, -.13890100E+00, -.40903500E+00, 0.15758700E+00, 0.28633200E+02, 0.23233400E+01, -.51815500E+02, -.83279100E+01, 0.42662700E+02, 0.43442700E+02, -.33701400E+02, 0.19041000E+02, -.20290700E+03, 0.10073500E+03, 0.10150300E+03, -.50267800E+02, 0.72506300E+02, 0.54685200E+02, 0.22739200E+02, 0.19363100E+03, 0.18614800E+02, 0.14470500E+02, -.61590500E+01, -.86038300E+01, 0.18248200E+02, 0.15376800E+01, -.38578400E+02, -.42914500E+02, -.20096900E+03, -.26406500E+02, 0.82829000E+02, -.40784000E+02, -.47307600E+02, -.96142500E+01, 0.14147900E+02, -.20873100E+02, -.29082000E+02, 0.48018700E+02, -.11511300E+02, 0.26417800E+03, -.11064800E+03, -.13163200E+03, 0.37563900E+02, -.76727100E+02, -.96527700E+02, -.52750600E+02, -.16007900E+03, 0.28091300E+02, -.44095600E+03, 0.21405900E+03, 0.22413500E+03, 0.59764300E+02, -.59951800E+01, 0.12433100E+03, -.10146100E+03, 0.23415300E+02, 0.34437100E+02, 0.22327900E+03, -.95517200E+02, -.11431700E+03, -.61217200E+02, 0.51321700E+02, -.82196600E+02, -.60962800E+02, -.72697400E+02, -.19886900E+02, -.33527100E+03, 0.16245500E+03, 0.18617800E+03, 0.72212500E+02, 0.43141200E+02, 0.62822600E+02, 0.18879600E+02, 0.14200200E+03, 0.10054400E+03, 0.15945300E+03, -.78222200E+02, -.76044000E+02, 0.11709100E+03, -.26236000E+02, -.90693000E+02, -.47753100E+02, -.16673900E+03, 0.12265800E+03, 0.31915800E+02, -.13144500E+02, -.18021900E+02, -.48960100E+02, 0.51053100E+02, -.74325400E+00, 0.16973500E+03, 0.14561900E+03, -.19077200E+02, -.13302000E+03, 0.67791500E+02, 0.72506500E+02, -.37394500E+02, -.99411000E+02, 0.68102200E+02, -.15567800E+02, 0.36147000E+02, -.27890100E+02, 0.32973300E+02, -.28534800E+02, 0.16604500E+02, -.14026400E+01, -.25033200E+02, 0.14997800E+00, -.78737000E+01, 0.18883300E+02, -.32858700E+02, -.13776900E+02, -.17653800E+02, -.22073800E+02, -.21580700E+02, -.18483700E+02, -.71071200E+02, -.25784100E+01, -.14327200E+01, 0.33493100E+02, -.72926000E+02, 0.99973000E+01, 0.14842900E+02, -.37688400E+02, -.78727000E+02, 0.14924100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23903800E+01, -.16047100E+01, -.10281700E+01, 0.49433400E+01, 0.26704300E+00, -.38765500E+01, 0.31425100E+01, 0.95165800E+00, -.16713000E+01, 0.23027400E+01, -.12152900E-01, -.77574600E+00, 0.95602900E+00, -.27598100E+01, 0.98720900E+00, -.58438800E+01, -.30245200E+01, 0.68384000E-01, -.24914100E+01, 0.31907300E+01, -.29874300E+00, 0.14198900E+01, -.16185700E+01, -.48579600E+00, -.80336400E+00, 0.41844600E+01, 0.80162500E+00, -.36812900E+01, -.87890000E+00, 0.14427500E+01, 0.14347600E+01, -.26599800E-01, 0.21242500E+00, 0.28456100E+00, 0.21370400E+01, -.99097900E+00, 0.53384100E+00, -.31737400E+01, -.95530400E+00, 0.38067500E+01, 0.18112500E+00, 0.58675100E+00, 0.10591500E+01, -.89122300E+00, 0.76528800E+00, -.12960100E+01, -.22158300E+00, 0.27791300E+00, 0.13281000E+01, -.18288100E-01, -.30030400E+00, -.23396700E+01, -.71723900E+00, -.80582200E-01, 0.84983800E+00, 0.54952900E+00, 0.21438400E+00, 0.66409900E+00, -.13107800E+01, -.87113300E+00, -.30346400E+00, 0.18013600E+00, 0.20434300E+00, -.61855700E+00, -.22362300E+00, -.67322200E+00, -.28495600E+00, -.10086900E+01, -.52895200E-01, -.91652400E+00, 0.43465500E+00, 0.63841800E+00, 0.10139700E+01, -.25039400E+00, -.35365000E+00, 0.20665100E+00, 0.10026400E+01, 0.53675300E+00, -.47425600E+00, 0.18773700E+01, 0.23214800E-01, -.32754600E+00, 0.47763700E-01, 0.14771900E-01, -.61548400E-01, 0.96965000E+00, 0.40338400E+00, -.20822200E+01, -.45864900E+00, -.76073000E-01, -.21344800E+00, 0.17467400E+00, 0.39264900E-02, -.82209600E+00, 0.38784400E+00, 0.70250700E-01, 0.10112600E+00, 0.18932400E+00, 0.96171600E-01, 0.52717700E+00, -.72801400E-02, -.56635600E+00, -.38481900E-02, 0.13124200E+00, -.36648500E+00, 0.21853100E+00, 0.11099600E+00, -.39794300E+00, -.11675100E+01, -.98150000E-01, 0.31271900E+02, 0.13349900E+02, -.12344100E+02, 0.42654100E+01, -.42483100E+02, 0.14628700E+03, -.12479500E+03, -.16511400E+03, 0.81219900E+02, 0.13199400E+03, -.81666600E+00, 0.10529500E+03, 0.61712900E+02, -.13621800E+01, 0.41017700E+02, -.39035800E+02, -.33351000E+03, 0.16637400E+03, 0.14035900E+03, 0.96632100E+02, 0.89299100E+02, 0.54049800E+02, -.82390600E+02, -.28837700E+03, 0.13703500E+03, 0.19054300E+03, -.10066400E+03, -.14290300E+03, 0.14412300E+03, -.26806700E+02, -.79770200E+02, -.10313500E+03, -.59234800E+02, -.17668200E+02, -.46359100E+02, 0.15889500E+02, 0.21267500E+02, 0.15076300E+03, -.26021500E+02, -.11059700E+02, -.10551300E+03, 0.24383900E+01, -.50216900E+02, -.39881200E+03, 0.19730200E+03, 0.23386600E+03, 0.32732400E+02, 0.10574700E+03, 0.31219500E+02, -.16756600E+03, -.26638100E+02, 0.10397000E+03, -.85071200E+03, 0.42971800E+03, 0.33515800E+03, -.11418300E+03, -.61797500E+02, 0.39205800E+03, 0.26526400E+03, 0.37840600E+03, 0.81602500E+01, 0.10605900E+03, -.53510200E+02, 0.60033400E+02, 0.25590700E+02, 0.24822400E+02, -.13348400E+03, -.66303600E+02, 0.10396000E+03, 0.86791100E+02, 0.46351500E+03, -.23050200E+03, -.22080300E+03, 0.21845600E+02, -.10644400E+03, -.20442800E+03, -.11957000E+03, -.98030300E+02, 0.80308000E+02, 0.15613800E+03, -.75654200E+02, -.88189800E+02, -.17377200E+02, 0.23413900E+02, -.39120400E+01, 0.16940700E+03, 0.92983000E+00, -.28279700E+02, 0.44105300E+02, -.28604600E+02, 0.27767900E+02, 0.32122900E+02, -.50436900E+01, 0.36133100E+01, -.19665200E+02, 0.22784200E+02, -.69322200E+02, -.81668400E+01, 0.38516200E+02, -.21175600E+02, 0.26214100E+02, 0.68825100E+02, -.31446400E+01, 0.22722200E+02, -.29972600E+02, 0.60928400E+02, 0.24960800E+02, 0.20008800E+02, 0.23619500E+02, 0.14480200E+02, 0.48818100E+02, 0.65518200E+00, 0.10347000E+03, -.56032600E+02, -.46568100E+02, -.26684800E+02, 0.14188200E+02, -.79855200E+02, 0.20613300E+02, -.25895700E+02, -.27655700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17209900E+01, 0.18987700E+01, 0.78050000E+00, -.58214500E+01, 0.68142100E+00, 0.40015900E+01, -.48653600E+01, -.13016400E+01, 0.26338100E+00, -.13816000E+01, 0.49586100E+00, 0.13642600E+01, -.25348300E+00, 0.21017200E+01, -.80131200E+00, 0.26634800E+01, 0.20312900E+01, 0.13176500E+01, 0.11457300E+01, 0.60284300E+00, 0.67926300E-01, 0.51248500E-01, 0.13325600E+01, -.11588900E+00, 0.94436200E+00, -.15433100E+00, -.16457500E+00, 0.10114600E+01, 0.13105100E+00, -.10327400E+00, -.74286100E+00, -.54573800E+00, -.24329100E+00, -.21352000E-01, -.76246500E+00, 0.12948500E+00, -.98232700E+00, -.73337200E+00, -.39089400E-01, -.17610100E+01, -.11505800E+00, 0.36321200E+00, -.56498600E+00, 0.90542400E+00, -.15002600E+00, 0.17097400E+00, 0.10495800E+00, 0.64747000E+00, -.84413500E+00, 0.64283300E+00, 0.16541600E-01, -.10114200E+01, 0.96272500E+00, 0.94938000E+00, -.19495000E+00, -.29842200E+00, 0.38320100E-01, -.30958100E+00, 0.21422600E+00, 0.21827100E+01, 0.24585900E+00, -.12502000E+00, -.64384800E-02, 0.15719800E-01, -.16193200E+00, 0.44426400E+00, -.11433600E+00, 0.24012400E+00, 0.13247300E+00, 0.12765300E+01, -.44105700E+00, -.42861300E-01, 0.95041700E+00, 0.94338700E+00, 0.39741800E+00, -.11062200E+00, -.22064300E+00, -.31185900E+00, 0.31785400E+00, -.11658100E+01, 0.18032100E+00, 0.68735700E-01, 0.10363200E+00, 0.56745500E-01, -.26879200E+00, -.98794800E+00, 0.52970500E+00, -.35091000E+01, -.43811800E+00, 0.44996800E+00, 0.67211800E-01, 0.80973900E-01, 0.34173100E-01, -.90154900E+00, -.32968600E+00, 0.47592900E+00, -.26303100E+00, -.31635000E-02, 0.13284100E+00, -.91759800E+00, 0.55443300E+00, 0.95297600E+00, -.42781000E+00, -.56001800E-01, 0.25289900E+00, -.23489900E+00, 0.43022600E-01, 0.49512500E+00, 0.20157900E+00, 0.20540700E-01, 0.19669000E+00, 0.12026500E+03, 0.16169900E+02, -.66817400E+02, -.90636100E+02, -.11567400E+03, -.41708300E+02, 0.45674400E+03, -.22677700E+03, -.23091500E+03, 0.39348000E+02, -.13108400E+03, -.19125300E+03, -.18169800E+03, -.40301600E+03, 0.12667200E+02, 0.11774800E+03, -.58198300E+02, -.49150800E+02, -.89936000E+02, -.61800200E+02, 0.28375100E+02, 0.11988700E+03, 0.40908000E+03, -.39069200E+02, -.21085900E+03, 0.10558300E+03, 0.13870400E+03, -.11196400E+03, -.70043900E+02, 0.10121200E+03, 0.18987400E+03, 0.89828000E+02, -.36835400E+02, 0.32325800E+03, -.16048900E+03, -.16221300E+03, 0.74259100E+02, 0.77681600E+02, -.18662500E+03, -.24723100E+03, -.13654400E+03, -.13938300E+02, 0.54117400E+03, -.27144900E+03, -.29725800E+03, -.60627400E+02, -.70768100E+02, -.79909800E+02, 0.84827000E+02, 0.32679200E+02, -.11123700E+03, 0.55934400E+03, -.28166700E+03, -.25524500E+03, 0.20320700E+03, 0.67114500E+02, -.28280700E+03, -.22265200E+03, -.27435100E+03, 0.20905500E+02, 0.19442300E+03, -.96383200E+02, -.15254500E+03, -.77205300E+02, -.27187200E+02, 0.35795700E+02, -.52878400E+01, -.20719800E+03, -.11971900E+03, -.50935400E+03, 0.25291400E+03, 0.25164200E+03, -.12881800E+03, 0.12527700E+03, 0.28048800E+03, 0.20135100E+03, 0.33266100E+03, -.16407400E+03, -.25400400E+03, 0.12825700E+03, 0.14741700E+03, 0.83398800E+02, 0.20478300E+02, -.16419700E+02, -.19987500E+03, -.18649000E+03, 0.12618100E+03, 0.24058000E+03, -.11815600E+03, -.14182900E+03, 0.23796100E+02, 0.73088200E+02, -.10091600E+03, 0.31437800E+02, -.21517300E+02, 0.13845400E+02, -.52508200E+01, -.28908000E+02, 0.14178400E+01, -.25104000E+02, -.29744500E+02, 0.11913100E+02, -.26322100E+02, 0.90584300E+01, -.28753900E+02, -.16934300E+02, 0.19340000E+02, -.11255600E+02, 0.15684200E+02, 0.67594000E+01, 0.86229600E+02, -.76336900E+02, 0.21889100E+02, 0.22825400E+02, 0.25825000E+01, -.12659400E+02, 0.43463000E+02, 0.38062600E+02, 0.35180300E+02, 0.36818800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24052200E+01, 0.31784500E+01, 0.12559900E+01, -.31542700E+01, 0.12244400E+00, 0.24962500E+01, -.23453100E+01, -.82068100E+00, 0.20781900E+01, 0.22492200E-01, -.10238700E+01, -.12084700E+01, -.98424100E+00, -.37103000E+01, 0.99987700E+00, -.18243900E+01, -.67917200E+00, -.37855700E+00, 0.23459900E+01, -.27609600E+01, 0.55922900E-01, -.11111200E+01, -.38854300E+00, -.40902300E+00, -.79215500E-01, -.15002800E+01, -.17922200E+01, 0.35252500E+01, 0.13533400E+01, -.69004400E+00, -.56731100E+00, -.81151200E+00, 0.13278400E+00, 0.11445700E+00, -.11001600E+01, 0.99215800E-02, -.35166300E+00, -.15775500E+01, -.46111600E-01, -.65923300E+00, -.27261600E+00, -.55304300E+00, 0.82173700E-01, 0.17954500E+01, 0.14031700E+01, 0.23418800E+00, 0.25357500E+00, 0.38770600E+00, 0.55764900E+00, 0.75444200E+00, 0.51696000E-01, 0.67586100E+00, -.96913600E+00, 0.78879300E+00, -.23258200E+01, -.71934900E+00, -.64138000E-01, -.13894700E+00, -.94198100E+00, 0.81734300E+00, 0.30521400E+00, 0.24328800E+00, 0.40181700E-01, 0.23415100E+00, -.48647900E-01, 0.28377700E+00, 0.14578300E+00, 0.38908700E+00, -.66411300E-01, 0.12107900E+01, -.28807900E+00, 0.22763400E+00, 0.45236600E+00, 0.88853300E+00, -.27553200E+00, 0.23307500E+00, 0.25725900E+00, -.33677200E-01, -.81460600E-01, 0.13982500E+01, 0.40351100E+00, -.34871000E+00, 0.14090700E+00, 0.28679400E+00, -.17013100E+00, -.48591100E+00, -.53068000E+00, -.74390900E+00, -.38623000E-01, 0.42173400E+00, -.18605100E+00, 0.24004000E+00, 0.86842400E-01, 0.62546700E+00, -.46572400E+00, -.70674900E+00, 0.13930300E+00, 0.36112500E+00, -.12000700E+00, -.23820100E+00, 0.40789600E+00, -.25148300E+01, -.84394900E+00, 0.20589500E+00, -.21604000E+00, 0.57201700E-01, -.42652200E+00, 0.19021500E-01, -.10033400E+01, -.21785200E+00, -.32543100E-01, -.12780900E+00, 0.12738300E+03, 0.20108100E+02, -.54955300E+01, -.30820200E+02, -.20334300E+01, 0.28410900E+03, -.14248000E+03, -.14706500E+03, 0.65018300E+02, 0.99417000E+02, -.15427700E+03, -.19448900E+03, -.88235400E+02, 0.35553900E+02, 0.58056700E+02, -.29010200E+02, -.25098200E+02, -.31875100E+01, -.45461200E+02, -.40358600E+01, 0.37611600E+02, -.86084100E+01, -.28810800E+02, -.23130100E+03, 0.12903900E+03, 0.12159900E+03, 0.64164100E+02, 0.67473000E+02, 0.41320700E+02, -.77741500E+02, 0.61715200E+02, 0.70154200E+02, 0.66102000E+03, -.33285400E+03, -.32972000E+03, 0.26038100E+03, 0.17908600E+02, -.30132200E+03, -.26982900E+03, -.30886400E+03, -.88799400E+02, -.35720200E+03, 0.17752800E+03, 0.17294300E+03, 0.16456900E+03, 0.81724600E+02, 0.42124100E+02, -.19537700E+03, -.53280600E+02, 0.96249300E+02, -.11104100E+03, 0.53927700E+02, 0.75281400E+02, 0.10438100E+03, -.16880700E+02, 0.50393300E+01, -.59104100E+02, 0.18511600E+02, -.14466100E+02, -.25553300E+03, 0.88283500E+02, 0.13367800E+03, 0.12359400E+02, -.10163100E+02, 0.76347600E+02, 0.26851400E+02, 0.16215000E+03, 0.11853600E+02, 0.86266200E+02, -.41695000E+02, -.39333800E+02, -.22326900E+02, -.97558500E+02, -.27567700E+02, 0.26342400E+02, -.82931500E+02, 0.33927300E+02, 0.21619500E+03, -.10644900E+03, -.10412600E+03, -.16853200E+03, 0.16516200E+02, 0.21812500E+01, 0.22927400E+03, 0.12131700E+03, -.63259300E+02, 0.63978900E+03, -.33060400E+03, -.32645300E+03, -.22930500E+01, 0.43427200E+02, -.21260000E+03, -.13471800E+02, -.25099100E+03, -.60147600E+02, 0.36097600E+02, 0.26033600E+02, 0.24182600E+02, -.21957000E+02, 0.78571600E+01, -.17183300E+01, -.35799300E+02, 0.25648200E+02, -.36031700E+02, -.28169900E+02, 0.38535300E+02, -.38831000E+02, -.14559000E+02, 0.59177200E+02, -.33186800E+02, -.34237600E+02, -.44681400E+02, 0.34896500E+02, -.45529100E+02, 0.16770300E+02, -.10186200E+02, -.29547700E+02, -.70709500E+02, -.10473000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.26359700E+01, -.24325500E+01, -.13362600E+01, 0.64551500E+01, 0.12158500E+01, -.60199300E+01, 0.61365300E+01, 0.16737000E+01, -.11050200E+01, 0.28346200E+01, -.19589100E+00, -.10124600E+01, 0.11059000E+01, -.22590100E+01, 0.18919200E+01, -.62046600E+01, -.31474900E+01, 0.29586600E+00, -.28118200E+01, 0.47136000E+01, -.20447700E+00, 0.19108600E+01, -.18196800E+01, 0.52374100E-02, -.23603800E+01, 0.22779100E+01, 0.18829800E+01, -.15790700E+01, 0.36484100E+01, 0.10893700E+01, -.53041000E-01, 0.12303700E+01, 0.18876600E+00, -.42008000E+00, -.26684200E-01, -.40102100E+00, 0.17854300E+01, 0.37246800E+01, -.55748500E+00, 0.10733600E+01, 0.57435600E+00, -.88849700E+00, 0.97098700E+00, -.28979600E+01, -.71854100E+00, -.67412400E+00, -.70666500E-01, -.86263600E+00, 0.26876700E+01, -.39419700E+01, 0.49325400E+00, 0.90103100E+00, -.31062100E+01, -.53698500E+00, 0.14794900E+01, 0.19700100E+01, -.20434300E+00, -.10665900E+01, 0.21223000E+01, -.49435300E+01, -.26707800E+00, 0.47271500E+00, -.42399700E-01, -.24001700E+00, -.68969500E+00, -.11073000E+01, -.24139200E+00, -.28069500E+00, 0.15565300E+00, 0.19972700E+01, 0.11382200E+01, 0.28825300E+00, -.84353800E+00, 0.21239600E+00, -.48237000E+00, 0.73773000E-01, -.78151900E+00, -.15129200E+01, 0.28907400E+00, -.51776500E+01, 0.17036600E+00, 0.10246900E+01, -.28373700E-01, 0.23922300E+00, 0.81302900E-02, 0.46805900E+00, -.18837200E+01, 0.50183700E+01, 0.12973500E+01, 0.68396100E-01, 0.47132400E+00, -.16916100E+00, -.12188300E+00, -.63427300E+00, -.56005400E+00, -.12044400E+01, 0.32633500E-01, -.11052200E+00, -.11468200E+00, -.22062000E+00, 0.21887500E+00, -.53200900E+00, -.10699200E+01, 0.76003800E+00, 0.21683200E-01, -.56137400E-01, -.13209900E+01, 0.88861000E+00, 0.18103700E+01, 0.84852300E-01, -.46195900E+00, -.27689900E+00, -.30683200E+00, 0.11643300E+03, 0.10556700E+03, -.20093700E+03, 0.26430500E+02, 0.38669600E+02, -.26877800E+02, -.13210100E+02, -.17731200E+03, -.11936000E+02, -.21119900E+02, -.58653600E+02, -.31625700E+03, 0.67594600E+01, 0.77898000E+03, -.38932900E+03, -.37833300E+03, -.27996100E+03, -.29910000E+03, -.81167200E+02, 0.24098900E+03, 0.59401600E+03, -.29484600E+03, 0.32899500E+03, -.16435600E+03, -.11147300E+03, -.11928500E+03, 0.10061500E+03, -.14983500E+03, -.62311700E+01, -.37367600E+03, -.62442500E+02, 0.69364000E+03, -.34469400E+03, -.34940700E+03, -.39086300E+02, 0.38016300E+02, -.27117200E+03, -.68087800E+02, -.27254000E+03, 0.92917500E+02, 0.81825500E+03, -.40655300E+03, -.44805400E+03, -.53994300E+02, -.36687600E+03, -.21771200E+02, 0.32272400E+03, 0.47092700E+03, -.25430500E+03, 0.13632200E+04, -.69683200E+03, -.66340100E+03, 0.16726900E+03, 0.46128300E+02, -.61948700E+03, -.36676600E+03, -.51858500E+03, 0.31976900E+02, -.52860800E+03, 0.28338400E+03, 0.15086700E+03, 0.62030900E+02, 0.16330200E+03, 0.18915200E+03, -.69093500E+02, -.31650300E+03, 0.14985100E+03, -.42628400E+03, 0.21896600E+03, 0.19942500E+03, 0.20154100E+03, 0.18020800E+03, 0.12344600E+03, 0.21916200E+02, -.14764600E+03, 0.14410900E+03, -.66920200E+03, 0.33274400E+03, 0.36456900E+03, -.14297900E+03, 0.10474200E+03, 0.17606600E+03, -.11961400E+03, -.40821900E+02, -.71463000E+01, -.10568500E+03, 0.64253800E+02, 0.17898800E+02, 0.10994200E+02, 0.56880300E+02, -.63705400E+01, 0.22854400E+02, 0.21373500E+02, 0.75140100E+02, 0.29579100E+02, -.39500200E+02, 0.47642600E+02, -.42092200E+02, 0.83586600E+02, -.22140500E+01, -.39662000E+02, 0.48907100E+02, -.10200300E+03, -.36262300E+02, -.50574200E+02, -.29011600E+02, -.33192400E+02, -.52500200E+02, -.13203100E+03, -.18361800E+03, 0.38821400E+02, 0.88714000E+02, 0.17703500E+02, -.33887400E+02, -.74666800E+02, -.64588100E+02, 0.27786800E+02, 0.38400200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24414000E+01, 0.23023200E+01, 0.12361200E+01, -.60582100E+01, -.10476000E+01, 0.54303800E+01, -.64922900E+01, -.16468700E+01, 0.73487500E+00, -.24730900E+01, -.20550000E+00, 0.62502000E+00, -.12765500E+01, 0.11747800E+01, -.14840100E+01, 0.52104100E+01, 0.29761400E+01, -.14074400E+01, 0.44966400E+01, -.24586900E+01, 0.48146000E+00, -.17016900E+01, 0.16634900E+01, -.48454400E+00, 0.20246600E+01, -.48642400E+01, -.10124300E+01, 0.31756100E+01, -.25628200E+01, -.15189000E+01, -.76243600E+00, -.35513000E+00, -.34918700E+00, 0.11011900E+00, -.83938400E+00, 0.26662000E+00, -.19749900E+01, 0.25697400E+01, 0.12315100E+00, -.20901200E+01, -.44036100E+00, 0.56531400E-01, -.15473400E+00, 0.16007100E+01, 0.26205900E+00, 0.41764000E+00, 0.39221000E+00, 0.12824700E+01, -.15019400E+01, 0.24161400E+01, -.20953400E+00, -.11500600E+01, 0.43398100E+00, 0.11364300E+00, -.15777500E+01, -.15804400E+01, 0.24561800E+00, -.33306600E+01, -.32812900E+01, 0.34028200E+01, 0.47121300E+00, -.71658600E+00, 0.27675900E+00, -.57229800E+00, -.22763500E+00, 0.83463000E+00, -.88551900E-01, -.64905800E+00, -.43293400E+00, 0.59408100E+01, -.68586600E+00, -.56645500E-01, 0.14695200E+01, 0.16763300E+01, -.70666900E+00, 0.38307300E+00, 0.53788000E+00, 0.71596900E-01, 0.66029000E+00, 0.22877900E+01, -.24914900E+00, -.40257700E+00, -.66467400E-01, -.22213400E-01, -.30647200E+00, -.78021000E+00, 0.88369700E+00, -.38110900E+01, -.90278400E+00, 0.12883800E-01, -.19252100E+00, -.19131500E+00, 0.21257500E+00, 0.99525600E+00, -.17087300E+00, -.11916700E+01, -.11811600E+00, -.68223500E+00, -.18291000E-01, 0.97034600E+00, 0.23168200E+00, 0.30051700E+00, -.32863600E+01, 0.12785100E+01, 0.29814400E+00, -.26060200E+00, 0.41420500E+00, 0.97256500E-01, -.22559200E+01, -.56136900E+00, 0.66836700E+00, 0.60778900E+00, 0.14386100E+00, -.43791100E-01, -.13984700E+03, -.74008600E+02, -.16736600E+03, 0.69445500E+03, -.34099200E+03, -.36009900E+03, 0.25272300E+03, 0.18144300E+03, -.49039500E+03, -.58286400E+03, -.38919000E+03, 0.16308200E+03, 0.10994400E+03, -.55493200E+02, -.47470600E+02, -.34783400E+02, -.48937700E+02, 0.22058600E+02, 0.10970900E+03, 0.71908400E+02, -.45162100E+02, -.62656900E+03, 0.35126600E+03, 0.32289500E+03, 0.85546500E+02, -.37897000E+02, 0.18173100E+03, -.18054600E+03, 0.23039800E+03, 0.88918200E+02, 0.30841800E+03, -.13967500E+03, -.15194000E+03, 0.27599700E+03, -.92647500E+02, -.24502600E+03, -.52077000E+03, -.20072100E+03, 0.31128400E+02, -.77226400E+03, 0.38645200E+03, 0.37741300E+03, 0.33814900E+03, 0.38876100E+03, 0.54812200E+02, -.46974300E+03, -.21553200E+03, 0.30089000E+03, -.86513200E+03, 0.43566100E+03, 0.46457500E+03, -.83754500E+02, -.21486200E+03, 0.33662000E+03, 0.13815000E+03, 0.36272700E+03, -.48757500E+01, -.25412500E+03, 0.27988300E+02, 0.15954100E+03, -.50091200E+02, -.75447900E+02, 0.14175900E+03, 0.22980200E+03, 0.42433100E+03, -.15151000E+03, -.47280800E+03, 0.23263400E+03, 0.24557500E+03, -.14388300E+03, 0.29967600E+02, 0.21416100E+03, 0.20914600E+03, 0.14445800E+03, -.45823600E+02, 0.61907500E+03, -.30818500E+03, -.30665500E+03, -.27244500E+03, -.15328700E+03, -.66593700E+02, 0.45981800E+03, 0.22356600E+03, -.19311800E+03, 0.13728200E+04, -.68629600E+03, -.69647300E+03, 0.73275300E+02, 0.97043000E+02, -.46400500E+03, -.37733100E+02, -.48247500E+03, -.10200300E+03, 0.85179500E+01, 0.51040800E+02, 0.67424500E+01, -.40864300E+02, -.68436300E+02, -.17769000E+02, -.39896900E+02, 0.62252700E+01, -.24275800E+02, -.23537600E+02, 0.13526900E+03, -.34643100E+02, 0.12829900E+02, 0.12995900E+03, 0.77431100E+02, -.44190200E+02, -.69216700E+02, 0.54784800E+02, -.65618800E+02, 0.14437400E+03, 0.64373600E+02, 0.28580000E+02, -.80567400E+02, -.33752200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14296000E+01, -.10351800E+01, -.45410300E+00, 0.38530300E+01, 0.72627000E+00, -.27818400E+01, 0.33481500E+01, 0.79466600E+00, -.52633700E+00, 0.25592800E+01, -.33557800E+00, -.15594600E+01, 0.10235200E+01, -.39508200E+01, 0.64683000E+00, -.61889400E+01, -.39516800E+01, -.19535400E+00, -.17303900E+01, -.33446200E+00, -.13419200E+01, -.20681500E+00, -.14323200E+01, -.41853900E-01, -.18263100E+01, 0.50424400E+01, -.42077100E+00, -.17607400E+01, 0.40553100E+00, 0.13403800E+01, 0.26144600E+00, -.10462700E+01, 0.12138500E+00, 0.16271200E+00, 0.11807300E+01, -.46883600E+00, 0.10687800E+01, -.20619300E+01, -.47744500E+00, 0.22830200E+01, -.77109600E-01, -.18703700E+00, 0.20356600E+01, -.42511500E+00, 0.13235300E+01, -.86013000E+00, -.13072900E+00, 0.39491300E-01, -.26454400E+00, -.56638300E+00, 0.74839600E-02, 0.51665000E+00, -.74899300E-01, 0.23253300E+00, -.14524100E+00, -.23647700E+00, 0.38450500E-01, 0.51015300E+00, -.20421800E+01, 0.13351300E+01, 0.33991000E+00, 0.89887000E+00, -.16299800E-01, 0.89083400E+00, 0.16792100E+00, -.95851500E+00, 0.21449800E+00, 0.49281700E+00, 0.12413300E+00, -.20164700E+01, 0.51201000E+00, 0.93106800E+00, -.18805200E+01, -.16443100E+01, 0.44624000E+00, 0.86077500E-02, -.50016600E+00, 0.37971000E+00, -.54659200E+00, 0.14781500E+00, 0.26962300E+00, -.65921900E-01, 0.49482600E-02, 0.61531800E+00, -.15765000E-01, 0.75130800E-01, -.34904100E-01, -.21259000E+01, 0.19577300E+00, -.90574100E+00, -.63073000E+00, 0.10292700E+00, -.67238200E-01, -.15405700E+01, -.23760300E+00, 0.69616900E+00, -.10832700E+00, 0.34392400E+00, 0.90456600E-01, -.88619400E+00, 0.29949000E-01, -.16520900E+01, 0.34015400E+00, -.55170100E+00, 0.19492300E+00, 0.12208400E+00, -.88243100E-01, 0.29766100E+00, -.89196100E+00, 0.97670500E-01, 0.79232100E+00, 0.53489000E+00, 0.78950700E+00, -.18602800E+00, -.24102000E+00, -.20036800E+03, 0.14912100E+03, 0.41394200E+03, -.20314100E+03, -.20509300E+03, 0.12506700E+03, 0.13087600E+02, -.21829800E+03, -.14860400E+03, -.37939500E+03, 0.21870900E+02, 0.39580800E+03, -.19767300E+03, -.19161500E+03, -.85232900E+02, -.79798900E+02, -.79049300E+02, 0.93933000E+02, 0.29753300E+03, -.14240500E+03, -.25155900E+03, 0.12883200E+03, 0.15510600E+03, 0.12474600E+02, 0.41916900E+02, 0.17010600E+02, -.21581600E+03, -.15787500E+03, 0.74240800E+02, -.52134200E+03, 0.27809600E+03, 0.25955500E+03, -.18707500E+03, -.93477700E+02, 0.23450000E+03, 0.20385100E+03, 0.24815800E+03, 0.47095300E+01, 0.53442800E+03, -.26589300E+03, -.28866300E+03, 0.81989200E+02, -.44162300E+02, -.12932700E+03, 0.11292800E+03, -.11264900E+03, -.43094500E+02, 0.30247800E+03, -.14355400E+03, -.14574100E+03, 0.10784000E+03, -.57020900E+02, -.16119700E+03, -.15430000E+03, -.10304800E+03, -.39062300E+02, -.94868900E+02, 0.44483300E+02, -.87045400E+01, -.68464900E+02, 0.24651300E+02, 0.10294100E+03, 0.51730600E+02, -.11061300E+03, -.55438300E+02, -.45987700E+03, 0.22667500E+03, 0.22306000E+03, -.13249100E+03, 0.44615800E+02, 0.24234000E+03, 0.18868400E+03, 0.12788600E+03, -.65507800E+02, -.10393300E+03, 0.50002800E+02, 0.67147700E+02, -.99862100E+02, 0.93054800E+01, 0.30865900E+02, -.11004300E+03, 0.12299500E+03, -.12753400E+02, 0.62814000E+02, -.21865300E+02, -.48684300E+02, -.27511200E+02, 0.69216500E+01, -.50323200E+02, 0.18544400E+02, -.23257000E+02, 0.53105900E+02, -.77755900E+00, -.10218700E+02, 0.32765700E+02, -.43616200E+02, 0.52459100E+02, -.37166800E+02, -.29471000E+02, 0.31387700E+02, -.62793800E+02, -.30387000E+02, 0.15197200E+02, -.29764700E+02, -.26955000E+02, -.37293600E+02, 0.24916600E+02, -.11748400E+03, -.16520100E+02, 0.56665600E+02, 0.45214700E+02, 0.68410700E+01, -.33663200E+02, 0.92387500E+00, 0.13173300E+02, -.39401600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.41421200E+01, 0.28680000E+01, 0.25992800E+01, -.93326500E+01, 0.11061000E+01, 0.97690500E+01, -.11166800E+02, -.31482900E+01, 0.79003800E+00, -.28235800E+01, 0.86951800E+00, 0.17793200E+01, -.29880000E+00, 0.92391900E+00, -.32459500E+01, 0.35167700E+01, 0.26862600E+01, 0.25283000E+00, 0.65875500E+01, 0.56272700E+01, 0.21184900E+01, 0.14430000E+01, 0.19027400E+01, -.26092200E+01, 0.39334400E+01, -.50276400E+01, -.10977200E+01, 0.16613400E+01, -.23963000E+01, -.18163000E+01, 0.39809900E+00, 0.27120200E+00, -.34394100E+00, 0.37263000E+00, 0.84102200E+00, -.16809300E+00, -.52952900E+01, -.59279600E+01, -.22215700E+01, 0.25542600E+01, -.63005800E+00, 0.68300900E+01, -.59978800E+01, 0.94841400E+00, -.12068300E+01, 0.12096500E+01, -.30237000E+00, 0.18122700E+01, -.20562000E+01, -.38412000E+00, -.15201800E+01, -.90351600E+00, 0.23664600E+01, 0.16052900E+01, 0.12930200E+01, -.12172900E+01, 0.32960300E+00, 0.46637500E+01, 0.10845300E+01, 0.26686200E+01, 0.53717500E-01, 0.17764300E+00, -.33939300E+00, 0.25259700E+00, 0.45717300E+00, -.58201200E+00, -.82827500E+00, 0.53130500E+00, 0.17692700E+00, -.10368500E+02, 0.43421600E+00, 0.18010800E+01, -.16832500E+01, -.22135300E+01, 0.10389100E+01, -.50689600E+00, -.63232600E+00, 0.52704400E+00, -.90616900E+00, -.39981600E+00, 0.42949500E+00, -.26912700E+00, 0.14080200E+00, 0.56614000E-01, 0.24861000E+00, 0.51909900E+00, 0.36217200E+00, 0.26235300E+01, 0.18820100E+00, -.30318800E+00, 0.25989800E+00, -.41427900E-01, -.12530700E+00, 0.40907500E+00, 0.99366000E-01, 0.93621300E+00, -.23984900E+00, 0.10968900E+01, -.20322400E+00, 0.23292600E+00, -.11403200E+00, 0.68627600E+00, -.61889100E-01, -.26503300E+00, 0.32970900E+00, 0.10543100E+00, 0.13999200E+01, -.42541700E+00, 0.41556100E+00, 0.77343600E-01, 0.11123500E+01, -.55026800E+00, -.82472700E+00, -.71029700E+00, -.51170300E+00, 0.19670800E+01, -.25692600E+03, -.30719500E+02, 0.58560500E+01, -.49858800E+01, -.19421100E+03, -.23712100E+03, -.10093100E+02, -.10432700E+03, 0.45104300E+03, 0.12738500E+03, 0.12773400E+03, -.64424700E+02, -.54958000E+02, -.11386700E+03, -.10538700E+03, 0.56212600E+02, 0.12204200E+03, 0.16564600E+03, -.70058800E+02, -.30995400E+03, 0.19804400E+03, 0.15651000E+03, -.17691400E+03, 0.18866200E+02, 0.22111500E+03, 0.45693000E+03, 0.47945900E+03, -.49620100E+02, 0.20702200E+04, -.10455600E+04, -.10321700E+04, 0.33199700E+03, 0.35990700E+03, -.92186200E+03, -.75310700E+03, -.95186400E+03, 0.18397900E+03, -.42490100E+03, 0.21439300E+03, 0.20622200E+03, -.54566100E+02, 0.23114300E+01, 0.17539600E+03, -.14310100E+03, 0.41441400E+03, -.29927100E+02, 0.25890300E+03, -.16448100E+03, -.62872000E+02, -.57989600E+02, 0.35269300E+01, -.93784800E+02, -.31465400E+02, -.18856000E+03, 0.10108300E+03, -.56932900E+03, 0.20438500E+03, 0.30517300E+03, 0.10002800E+03, -.93025200E+02, 0.19974200E+03, 0.19355200E+03, 0.44984000E+03, -.89626000E+02, -.10808600E+03, 0.63648800E+02, 0.66951300E+02, 0.24471000E+03, 0.23641900E+03, -.31368300E+02, -.12343000E+03, -.28139400E+03, -.20231100E+02, -.22206400E+02, 0.12409700E+02, 0.17907000E+02, -.18241800E+02, -.92839100E+02, 0.20282300E+02, 0.22099800E+03, -.16155900E+03, -.30879900E+02, 0.10581800E+04, -.53501700E+03, -.53869100E+03, 0.10188300E+03, 0.20704300E+03, -.37253000E+03, -.56959000E+02, -.55319000E+03, 0.38629900E+02, 0.46990500E+02, 0.42336300E+02, 0.20861800E+01, -.13615000E+02, -.22781100E+03, 0.66985400E+02, -.20388600E+02, 0.11057800E+02, -.40261600E+02, -.11358500E+02, 0.26335200E+02, -.12842300E+02, 0.27249500E+02, 0.77179100E+02, -.48779200E+02, -.47210200E+02, 0.76781100E+02, 0.35828900E+02, -.95900900E+02, 0.36082800E+02, 0.19392500E+03, -.60906700E+02, -.31351600E+02, -.80849200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.98425700E+00, 0.82561400E+00, 0.24644200E+00, -.27572700E+01, -.30699300E+00, 0.20762000E+01, -.25670300E+01, -.71094000E+00, 0.34199500E-01, -.79016800E+00, 0.83431400E-01, 0.17134700E+00, -.27411100E+00, 0.55826400E+00, -.65159100E+00, 0.13811000E+01, 0.98899400E+00, 0.33212700E+00, 0.85411700E+00, 0.15469200E+00, 0.20653700E+00, 0.15544700E+00, 0.67084900E+00, -.28175200E+00, 0.68599200E+00, -.11446900E+01, 0.84905400E-02, 0.91748400E+00, -.60421600E-01, -.47731800E+00, -.12255200E+00, 0.95901400E-01, 0.15160900E+00, 0.70334600E-02, 0.61308200E-03, 0.87194800E-01, -.35823200E+00, -.15870100E+01, -.21521700E+00, -.96011800E+00, -.11110200E+00, 0.40159900E+00, -.91058900E+00, 0.39944500E+00, -.50042900E+00, 0.99602700E-01, 0.28771900E-01, 0.36554800E+00, -.47337700E+00, 0.48749400E+00, -.51271500E-01, 0.10762000E+00, 0.78820000E+00, 0.62487000E-01, 0.26290600E+00, -.12250600E+00, 0.64306300E-02, 0.36418400E+00, -.20382700E+00, 0.49939100E+00, -.22002000E-02, -.31518700E+00, -.13647000E+00, 0.20080700E+00, -.60509900E-01, -.72518100E-01, -.56041900E+00, -.21360100E+00, 0.10531400E+00, -.13735000E+00, 0.86422900E-01, 0.47661400E+00, -.48388100E+00, 0.42244600E+00, -.19374000E-01, 0.13397800E+00, 0.15110100E+00, -.86617100E-01, -.28128100E+00, 0.33557400E+00, 0.10109700E+00, -.37499100E+00, -.34887100E-01, 0.32321400E-01, 0.13406700E-01, 0.13421600E+00, 0.72535900E-01, -.28914400E+00, -.50110500E-01, 0.18994800E-01, -.11403600E+00, 0.59341500E-01, -.67193100E-01, -.13810300E+00, 0.23330600E+00, 0.13562300E+00, 0.23505200E-01, 0.46086800E-01, 0.98262500E-02, -.16417500E+00, -.27330200E+00, -.18673400E+01, 0.19095500E+00, -.86860800E-01, 0.54012200E-01, 0.23768100E+00, -.34443100E-01, 0.24093000E+00, 0.27453600E+00, -.25094600E+00, -.48138800E+00, -.29798600E+00, 0.13745200E+00, 0.16426500E+00, 0.12428200E+00, -.10895600E+00, -.21004500E+00, -.38082500E+03, 0.18773600E+03, 0.18245400E+03, -.72503800E+02, -.50904500E+02, 0.17085100E+03, 0.16272900E+03, 0.34295700E+03, -.40202700E+02, -.29969700E+03, 0.14942500E+03, 0.15049600E+03, 0.10599500E+03, 0.95958900E+02, 0.20592700E+02, -.87483100E+02, -.17846400E+03, 0.98015100E+02, 0.12331600E+03, -.61000400E+02, -.73695000E+02, -.30145500E+02, -.33141300E+02, -.23428100E+01, 0.10479600E+03, 0.13940800E+03, -.64415600E+02, 0.30342300E+03, -.15335600E+03, -.15018800E+03, 0.81121100E+02, -.84158100E+01, -.11944500E+03, -.64501500E+02, -.16690800E+03, -.19148200E+02, -.13397400E+03, 0.66871300E+02, 0.72985400E+02, -.34536000E+02, -.57475500E+02, 0.48145800E+02, -.11914500E+03, 0.57157500E+02, -.43309700E+02, 0.42760200E+03, -.22303700E+03, -.19537600E+03, -.69305800E+01, 0.37348400E+02, -.15304700E+03, -.95120900E+02, -.19102700E+03, 0.71585100E+01, -.31616300E+02, 0.16620000E+02, 0.44702300E+02, 0.32096300E+02, 0.34720700E+02, -.33803900E+02, -.56379200E+01, 0.73193300E+02, 0.29847300E+02, 0.14048100E+03, -.68582500E+02, -.62167100E+02, 0.55039000E+02, 0.35302700E+02, -.79883100E+02, -.77152300E+02, -.51901300E+02, 0.60033400E+02, -.22962900E+03, 0.11546300E+03, 0.11207700E+03, 0.22596500E+02, 0.43817400E+02, 0.65981300E+02, 0.15732800E+03, 0.44161400E+02, 0.49164400E+02, 0.14588800E+03, -.70749600E+02, -.68145500E+02, 0.20261500E+02, -.23399300E+02, -.32551400E+02, -.30376200E+02, -.10977200E+03, 0.78481900E+01, 0.23897400E+02, -.83644500E+01, -.15722600E+00, 0.17423300E+02, -.39020900E+02, 0.22071800E+02, 0.31884300E+01, -.46484600E+01, 0.75053400E+00, 0.62018500E+01, 0.54651800E+01, -.62546500E+00, 0.58511000E+01, -.53038700E+01, -.19385900E+02, 0.37583300E+02, 0.31305900E+01, -.56421700E+01, -.88744200E+02, 0.12542000E+02, 0.29649400E+02, -.28992000E+01, -.59247800E+02, 0.11954100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.44950700E+01, -.37243600E+01, -.23124400E+01, 0.63373600E+01, 0.93192100E+00, -.62173800E+01, 0.85398800E+01, 0.22353600E+01, -.15925600E+01, 0.29012500E+01, 0.63110100E+00, -.19618200E+00, 0.17125500E+01, 0.33161400E+01, 0.48638300E+00, -.14911500E+01, -.22761700E+01, 0.11224600E+01, -.40093800E+01, 0.54181600E+01, -.21371100E+01, 0.17060300E+01, -.55987100E+00, 0.74695500E+00, -.31230900E+01, 0.74417900E+01, 0.13184200E+01, -.53385800E+01, 0.18604700E+00, 0.28993500E+01, 0.11070600E+01, 0.20603700E+00, -.56913800E-01, -.18998700E+00, 0.78639900E+00, -.81071800E+00, 0.43562300E+01, -.23282200E+00, 0.17471800E-01, 0.38734100E+01, 0.53700100E+00, -.22564600E+01, 0.58944000E+01, -.33665700E+01, 0.19809100E+01, -.20112200E+01, -.31354400E+00, -.33181700E+00, 0.19331500E+01, -.23046900E+01, 0.50547800E+00, -.60622500E+00, -.20371800E+01, -.74649900E+00, 0.10304700E+01, 0.56607900E+00, -.89506000E-01, -.10215800E+01, 0.17782900E+01, -.39388600E+01, -.15901100E+00, 0.11239600E+01, 0.27582000E+00, -.66426500E+00, -.33897800E+00, -.71565600E+00, 0.54329300E+00, -.91507600E+00, 0.24510100E-01, 0.15640300E+01, 0.44420500E+00, 0.76587200E-01, 0.26077900E+00, 0.38253200E+00, -.42385800E+00, 0.60854800E+00, 0.10810600E+01, 0.40472100E+00, 0.12115500E+00, 0.18284800E+01, -.68143300E+00, 0.22841400E-01, -.47896800E-01, 0.25578700E+00, -.34350200E+00, 0.68143800E+00, 0.29250600E+00, -.47889100E+01, -.80136100E+00, 0.72788200E+00, -.44002800E+00, 0.31494300E+00, 0.84619300E-01, -.16072600E+00, -.37638700E+00, -.87102400E+00, 0.15773700E+00, -.45875700E+00, 0.15129600E+00, -.64940400E+00, 0.16338400E+00, -.16995100E+01, -.20561200E+01, 0.44562800E+00, -.57668500E+00, 0.24491400E+00, -.97314300E+00, -.45315600E+00, 0.94388000E+00, -.44085800E+00, -.47229300E+00, 0.31699300E-01, -.44431200E+00, 0.14291400E+01, 0.36254000E+00, -.14457400E+01, -.38218400E+00, 0.22203200E+01, 0.26215800E+02, -.37444700E+01, 0.38242700E+03, 0.29693500E+03, -.21573700E+03, -.20548000E+03, -.30222600E+03, 0.25043600E+03, 0.10765900E+03, -.53357300E+02, -.50440200E+02, 0.12409500E+02, 0.99071600E+01, -.55807500E+02, 0.15842300E+02, -.16142300E+03, -.31490700E+02, -.38749700E+03, 0.19929300E+03, 0.20625300E+03, 0.24447100E+03, 0.14197600E+01, 0.39637000E+02, -.48093200E+03, -.37129700E+02, 0.21053100E+03, -.92944500E+03, 0.48144800E+03, 0.46502300E+03, -.25055300E+03, 0.22522300E+02, 0.40242800E+03, 0.25084900E+03, 0.39734100E+03, 0.29843000E+02, -.62914700E+03, 0.31273300E+03, 0.30442400E+03, 0.19074300E+03, 0.45790700E+03, -.19578700E+02, -.23547900E+03, -.71348200E+03, 0.32960700E+03, -.16816500E+04, 0.86644100E+03, 0.83699900E+03, -.41566700E+03, -.90880100E+02, 0.79430100E+03, 0.54651000E+03, 0.81573600E+03, -.11507500E+03, -.11413200E+03, 0.25913700E+02, 0.53135900E+02, -.47475900E+02, -.15613600E+03, 0.58774900E+02, 0.95272700E+02, 0.25074500E+03, -.71025700E+02, 0.22076400E+03, -.11980700E+03, -.10982400E+03, -.13637600E+03, -.17487700E+03, -.43486700E+02, -.53893600E+02, -.16816200E+03, -.61484400E+02, 0.80431800E+03, -.40201200E+03, -.39730400E+03, -.76906200E+02, -.33986500E+03, -.15233400E+03, 0.13664000E+03, 0.50966000E+03, -.24299300E+03, 0.50755000E+03, -.26199600E+03, -.25359800E+03, 0.20969200E+02, 0.82778800E+02, -.17047500E+03, 0.35291600E+02, -.21736500E+03, -.93297900E+02, -.54425500E+02, 0.44716800E+02, 0.19224900E+01, -.45640100E+02, 0.84877100E+01, -.25425800E+02, -.16790200E+00, 0.47792800E+01, -.19840300E+02, -.87556600E+01, 0.62297400E+02, -.97813100E+01, -.23818300E+02, 0.51257500E+02, 0.84295600E+02, 0.16948800E+02, -.93624400E+02, 0.20080500E+02, 0.34932300E+02, 0.10908300E+03, 0.42020700E+00, -.70579300E+01, -.54921700E+01, -.19300900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14776500E+01, 0.14607200E+01, 0.36474400E+00, -.38373500E+01, -.26312700E+00, 0.26779900E+01, -.29526500E+01, -.90629700E+00, 0.81394700E+00, -.10592400E+01, 0.15708000E+00, 0.30709400E+00, -.34724600E+00, 0.10187200E+01, -.63463600E+00, 0.15145100E+01, 0.11077900E+01, 0.97605400E+00, 0.16293600E+01, 0.86222100E+00, 0.12772900E+00, 0.40256900E+00, 0.14893700E+01, -.48647500E+00, 0.30283500E+00, -.28476900E+00, 0.28911100E+00, 0.16597400E+01, 0.14579700E+01, -.74728100E+00, -.65800900E+00, 0.18403900E+01, 0.24197100E+00, -.66489700E+00, -.17098100E+01, -.12871500E+00, -.64400500E+00, 0.33830400E+01, 0.58299300E+00, -.26296300E+01, 0.81523800E+00, 0.47666000E+00, -.65866400E+00, 0.78672100E+00, 0.83077700E+00, -.29193700E-01, -.12317200E+00, 0.21137600E+00, 0.37822400E-01, 0.42343600E+00, 0.24028600E+00, 0.54944300E+00, -.12331200E+00, 0.37396200E+00, -.98632100E+00, -.13547300E+00, -.13281000E+00, -.17770900E+01, -.19163500E+01, 0.11183400E+01, 0.22505600E+00, -.40666700E+00, -.12689900E-02, 0.18451000E+00, -.31569200E+00, 0.13007800E+00, -.59380200E+00, -.18312900E+00, -.34090200E-01, 0.23878300E+01, -.22540100E+00, 0.32596400E+00, -.95688500E+00, 0.61802900E+00, -.19210100E+00, 0.37143700E+00, -.59713800E-01, -.19152600E+00, -.66146300E-01, -.48479500E+00, 0.64839400E-01, 0.13529000E-01, -.36647800E-01, -.42482000E-01, 0.22584900E-01, 0.58801200E-01, 0.65617200E-01, -.37290800E+00, 0.72215600E-01, -.27348600E-01, 0.19780800E+00, -.14835400E+00, -.36826200E-01, -.23375800E+00, 0.39637600E-01, 0.13795300E+00, -.11575100E+00, -.60183100E+00, 0.63842500E-01, 0.38380400E-01, -.23557900E+00, 0.11246800E+01, 0.11899700E+00, 0.14475900E+00, 0.96067000E-01, 0.86433400E-01, 0.23673000E+00, 0.42934100E+00, 0.53134600E+00, -.10071500E+00, -.25613500E+00, 0.27947000E+00, -.30894300E+00, 0.10023600E+00, 0.26798600E+00, -.23049600E-01, -.66966100E-01, 0.99560700E+00, -.15715200E-01, 0.13937200E+02, -.60547300E+02, 0.28036400E+02, -.11240900E+02, 0.19368600E+01, -.87386900E+02, -.67031900E+00, 0.27756500E+03, -.13847200E+03, -.14400400E+03, -.11013600E+03, -.86568500E+02, -.20447100E+02, 0.80372400E+02, 0.17825400E+03, -.87033400E+02, 0.34991900E+02, -.28386300E+02, -.12456000E+02, -.18477000E+02, 0.92811100E+02, -.64874800E+02, -.15263000E+03, -.25087300E+03, 0.75233500E+02, -.17045800E+03, 0.84795800E+02, 0.82913300E+02, -.51760600E+02, 0.53527200E+02, 0.57652500E+02, 0.50417400E+01, 0.10756500E+03, 0.42855900E+02, 0.25578300E+03, -.12764800E+03, -.12581500E+03, -.12889600E+02, -.51057400E+02, -.53162200E+02, 0.18452600E+03, 0.61336200E+02, -.28693200E+02, -.18265000E+03, 0.98211600E+02, 0.57439500E+02, 0.33030600E+02, -.30140300E+02, 0.79180400E+02, 0.60309400E+02, 0.13948600E+03, -.54598800E+02, -.16285000E+03, 0.10549100E+03, 0.42608700E+02, 0.76253600E+02, 0.30249300E+02, 0.18888500E+02, -.97566100E+01, -.32134600E+01, 0.96173600E+02, 0.18691900E+02, -.96789300E+01, -.22113300E+02, 0.79860100E+02, -.48836300E+01, -.16682300E+02, -.40852500E+02, -.11492100E+03, 0.38800700E+02, 0.86310900E+02, -.43578200E+02, -.46231100E+02, 0.88630600E+00, 0.21358000E+02, -.35874800E+02, -.17846500E+03, -.72807200E+02, -.99224800E+01, -.32481000E+03, 0.16217500E+03, 0.16217200E+03, 0.14570300E+02, 0.66910700E+02, 0.77679300E+02, -.88073900E+01, 0.10414400E+03, 0.48282600E+02, -.32236200E+02, 0.42263500E+02, -.60874200E+00, -.15490800E+02, 0.13169200E+02, -.14949700E+02, 0.12815600E+02, -.57236100E+01, 0.12610400E+02, 0.41408000E+01, -.17028600E+02, 0.16741800E+02, 0.14398100E+01, 0.70662800E+01, -.32888500E+02, -.26465000E+02, 0.42796700E+02, -.48428800E+01, 0.88470100E+02, -.35498900E+02, -.18143200E+02, -.15767500E+02, 0.59204600E+02, -.31115300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.32610700E+01, 0.19759300E+01, 0.13734500E+01, -.34795600E+01, -.64795300E+00, 0.43282300E+01, -.33223800E+01, -.12741300E+01, 0.18670600E+01, -.14875900E+01, -.43786500E+00, -.25883600E+00, -.11994300E+01, -.37737600E+01, 0.16562600E+00, 0.45083400E+00, 0.87384400E+00, -.16247700E+01, 0.20803400E+01, -.47996200E+01, 0.12631700E+01, -.14290700E+01, 0.59365100E-01, -.53745400E+00, 0.16922100E+01, -.46008900E+01, -.62312200E+00, 0.41578400E+01, 0.70213300E+00, -.17970100E+01, -.10835600E+01, -.46744100E-01, 0.28340200E+00, 0.43011100E-01, -.48455500E+00, 0.75299300E+00, -.10033700E+01, -.22889800E+01, 0.20283800E+00, -.30644600E+01, -.13473500E+00, 0.24458600E+00, -.20422100E+01, 0.17131300E+01, -.10160000E+01, 0.80275500E+00, 0.41266000E+00, 0.72676100E+00, -.51777500E-01, 0.14404700E+01, 0.34190000E-01, 0.11565900E+01, 0.88392300E-01, 0.85141100E+00, -.14923100E+01, 0.69065500E-01, 0.10145200E+00, -.11801600E+01, -.17849800E+01, 0.27870500E+01, 0.39002100E+00, -.65381100E+00, -.28911900E-01, 0.22810500E+00, -.15318800E-01, 0.64525800E+00, -.72478000E+00, 0.72992600E+00, -.70069400E-01, 0.21593400E+01, -.79319800E+00, 0.46826100E+00, -.16115700E+01, 0.16162300E+01, -.33780200E+00, 0.40193100E+00, -.83430200E+00, -.10319600E+01, 0.52854400E+00, -.11731100E+01, 0.43014600E+00, 0.12917000E+00, 0.69428500E-01, -.66069200E-01, -.53763100E-02, -.72568300E-01, -.13937000E+01, 0.43611300E+01, 0.66911600E+00, -.93840200E+00, 0.64733500E-01, -.20160100E+00, 0.27460900E-01, 0.83121200E+00, 0.16816100E+00, 0.74778200E-01, -.12421500E-03, 0.55299600E+00, -.26067100E+00, 0.15742000E+01, -.11127600E+01, -.52560400E+00, 0.13854500E+01, 0.53133300E+00, -.25804100E+00, -.12966500E+00, 0.29641100E+00, 0.86269300E+00, 0.52891900E+00, 0.45639400E+00, -.57035600E+00, -.32205600E-01, -.14539900E+00, -.77896700E+00, 0.13059100E-01, 0.85985300E+00, 0.77763300E-01, 0.16804800E+01, -.15499500E+00, 0.14615300E+01, -.23102300E+03, -.14201900E+03, 0.14057500E+03, 0.59534600E+02, -.37672300E+02, -.13937200E+03, 0.22123900E+03, -.11002500E+03, -.10849300E+03, -.13261000E+03, -.11977700E+03, 0.17138300E+02, 0.48471600E+02, 0.17574300E+03, -.67023800E+02, 0.16986900E+03, -.87487600E+02, -.80114700E+02, -.19478500E+03, 0.69405400E+02, 0.36012500E+02, 0.47356800E+03, -.31948700E+02, -.11478000E+03, 0.12668600E+03, -.69344500E+02, -.63478600E+02, -.57103900E+02, 0.10674300E+02, -.63712500E+02, -.15565100E+02, -.19779200E+02, 0.91064300E+02, 0.54592600E+03, -.27402600E+03, -.27892400E+03, 0.15474300E+02, -.10335400E+03, -.70824300E+02, 0.33426800E+03, 0.15621100E+03, -.91985100E+02, 0.90074200E+03, -.44889100E+03, -.44674400E+03, 0.19587000E+03, 0.15088200E+03, -.49782300E+03, -.29295300E+03, -.50748200E+03, 0.18718500E+03, 0.57585900E+03, -.26919600E+03, -.28220200E+03, -.16501400E+03, -.11431900E+03, -.16811600E+02, -.22310800E+02, -.36286800E+03, -.21094200E+03, -.55519100E+03, 0.27896600E+03, 0.27922300E+03, 0.35347000E+02, 0.15780900E+03, 0.21938400E+03, 0.11945500E+03, 0.20032000E+03, -.81887800E+02, -.24792400E+03, 0.12408100E+03, 0.12905100E+03, -.83226300E+02, -.60035800E+02, 0.54296800E+02, -.27654900E+03, -.12043700E+03, -.22802600E+01, -.52460300E+03, 0.27325700E+03, 0.25828600E+03, -.50503700E+02, -.55691900E+02, 0.16981000E+03, 0.42853500E+02, 0.22963200E+03, 0.37212400E+02, -.18289900E+02, -.70834000E+02, 0.30667700E-01, 0.48823700E+01, 0.70881700E+01, 0.12903600E+01, -.29868900E+01, 0.69323900E+01, 0.70272200E+00, -.81250200E+01, -.61352700E+02, 0.45400200E+01, -.58436600E+00, -.27376400E+02, -.15793500E+02, -.24037800E+02, 0.88193000E+02, 0.32272600E+01, 0.13500400E+03, -.45130100E+02, 0.13663500E+02, 0.74506500E+01, 0.99102200E+02, 0.58687400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15895600E+01, -.15410000E+01, -.87302200E+00, 0.41234000E+01, 0.71083000E+00, -.36374300E+01, 0.52069900E+01, 0.11886700E+01, -.62467700E-01, 0.15810500E+01, 0.16391100E+00, -.33183500E+00, 0.76198900E+00, -.70906100E+00, 0.13902900E+01, -.22589300E+01, -.19612600E+01, 0.29057700E+00, -.43365800E+01, -.14613800E+01, -.10220800E+01, 0.23111100E+00, -.62648300E+00, 0.11295600E+01, -.21701300E+01, 0.43483100E+01, 0.22757200E+00, -.20929100E+01, 0.80172100E+00, 0.14600800E+01, 0.59013200E+00, -.32813900E+00, 0.30921400E+00, -.31649100E-01, 0.20629200E+00, -.38337600E+00, 0.33146800E+01, -.29430300E+00, 0.78249200E+00, 0.11491300E+01, 0.55091600E+00, -.23337800E+01, 0.31820200E+01, -.83648500E+00, 0.10534500E+01, -.98821200E+00, -.52068900E-01, -.44559600E+00, 0.11094600E+01, 0.10725900E-01, 0.45264700E+00, 0.10005200E+00, -.76671900E+00, -.47275800E+00, 0.31916100E+00, 0.15876200E+00, -.11463500E+00, 0.10430500E+01, 0.33344100E+01, -.26662300E+01, -.26706000E+00, 0.21502900E+00, -.21461100E-01, -.90465200E-01, 0.33084900E+00, -.15972800E+00, 0.17842400E+00, 0.30491800E+00, 0.82450700E-01, -.21890100E+01, 0.52658400E-01, -.85717900E+00, -.10109500E+01, -.12774000E+01, 0.89092600E-01, 0.14026700E+00, 0.40708300E-02, 0.69515600E-01, 0.11769800E+00, -.22708500E+00, -.58569500E+00, 0.47179700E+00, -.47228700E-01, -.30677300E+00, 0.65385700E-02, 0.74012900E+00, 0.59946100E-01, 0.49295600E+00, -.24234800E+00, 0.45523400E+00, -.27855500E-01, 0.18278000E+00, -.27898300E-01, -.21803100E+00, 0.13556200E+00, 0.87888100E+00, 0.10521000E+00, 0.82626600E+00, -.10413700E+00, 0.40314500E+00, -.32911200E+00, 0.85964000E+00, 0.80086900E+00, -.19552700E+00, -.35372400E-01, -.36701400E+00, 0.59243400E+00, -.18981400E+00, 0.11483900E+01, -.51608600E-01, -.78117900E+00, -.83964000E+00, -.75220000E+00, -.10893900E+00, 0.17737700E+00, 0.23660200E+00, 0.83197100E-01, 0.45650800E+00, -.84729600E-01, 0.16462000E-01, 0.43552500E+00, 0.10015100E+03, -.36017400E+02, 0.13490300E+02, -.24733100E+02, -.38978900E+02, -.74132800E+01, 0.37923700E+01, 0.53526600E+01, -.13418800E+01, 0.95148600E+01, -.66133000E+01, 0.10080400E+02, -.11909100E+02, 0.17318200E+02, 0.65938500E+02, -.38590100E+02, -.25161600E+02, -.18824000E+02, -.14211900E+02, -.44188000E+02, -.85571100E+02, -.42023400E+02, 0.73806400E+01, -.15584400E+03, 0.72182300E+02, 0.77740000E+02, -.49370100E+02, 0.24234600E+01, 0.69881000E+02, 0.52549500E+02, 0.56819500E+02, 0.15611400E+02, -.20973500E+03, 0.10321400E+03, 0.10026000E+03, -.43033400E+02, 0.17435700E+02, 0.58933500E+02, -.38438000E+02, -.54173600E+02, 0.41305900E+02, -.11365800E+03, 0.54320000E+02, 0.59257900E+02, -.42990400E+02, -.12116700E+02, 0.79502500E+02, 0.60274900E+02, 0.81174300E+02, -.59185200E+02, -.13654400E+03, 0.74478600E+02, 0.52922300E+02, 0.57736000E+02, 0.47926300E+02, 0.49114000E+01, 0.35451400E+01, 0.52572600E+02, 0.67808900E+02, -.24956600E+03, 0.12428800E+03, 0.12277200E+03, -.14356600E+02, -.37707400E+02, 0.11058400E+03, 0.10176300E+03, 0.12346000E+03, 0.68640300E+02, 0.36584900E+02, -.16528700E+02, -.15535700E+02, 0.87528900E+02, -.11492300E+02, -.42271300E+02, -.95598500E+01, 0.38679600E+02, -.68237600E+01, -.27307700E+02, 0.12322500E+02, 0.80396600E+01, 0.28677300E+02, 0.34098500E+02, 0.46701800E+01, -.39023100E+01, -.18278100E+01, 0.21875100E+02, -.14392700E+02, -.16528600E+01, -.59929500E+01, -.10709200E+02, -.32752700E+02, 0.18895100E+01, 0.10193600E+02, -.84138500E+01, -.73140000E+01, 0.13143500E+02, -.95082200E+01, 0.14224900E+02, 0.36789300E+00, 0.65398100E+01, -.10117900E+02, 0.21027500E+02, 0.17556800E+02, 0.71525200E+01, -.26519700E+02, -.10281600E+02, 0.26088600E+02, 0.24329500E+02, -.69926200E+01, 0.46103600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20180000E+01, 0.12003200E+01, 0.87321100E+00, -.50715800E+01, 0.19456300E+00, 0.35647200E+01, -.39030000E+01, -.99848100E+00, 0.15388100E+01, -.22407600E+01, 0.39611300E+00, 0.13706700E+01, -.61617700E+00, 0.21685500E+01, -.12245100E+01, 0.44489700E+01, 0.28591500E+01, 0.42656600E+00, 0.25779800E+01, -.69514000E+00, 0.83606000E+00, -.59435300E+00, 0.15902900E+01, -.77353100E-02, 0.17591500E+01, -.41286800E+01, -.43228700E+00, 0.24859200E+01, 0.21114500E+00, -.10975200E+01, -.13384300E+01, -.90617100E-01, -.20643800E+00, -.76253600E-01, -.84993600E+00, 0.31171600E+00, -.20096400E+01, 0.21986700E+01, 0.32423000E+00, -.26408400E+01, -.24881400E+00, 0.31342100E+00, -.23883100E+01, 0.12739100E+01, -.98188400E+00, 0.10933800E+01, 0.10149900E+00, -.77545100E-01, -.12005200E+01, -.31964400E+00, -.20919900E+00, -.10020400E+01, 0.16913700E+01, 0.35241500E+00, 0.10844300E+01, -.38489300E-01, 0.74365100E-01, 0.23783400E+00, 0.13357900E+01, 0.68616300E+00, -.22431900E+00, -.71646400E+00, -.10169400E+00, -.44582400E-01, 0.11237900E+00, 0.67025900E+00, -.18175500E+00, 0.65704500E+00, 0.37579400E-01, -.21147900E+01, -.46575800E+00, -.11956200E+01, 0.81704800E+00, 0.13868400E+00, 0.72849900E+00, -.54290600E+00, -.67779100E+00, 0.31559600E+00, -.80884200E-01, -.33813200E+01, 0.20425900E-01, 0.56577000E+00, 0.19905700E-01, -.52972200E+00, -.75114300E-01, -.88841500E+00, 0.50313800E+00, -.23423000E+01, -.45574400E+00, 0.28722400E+00, 0.45590200E+00, -.16310000E+00, -.11527100E+00, -.10642000E+01, -.74260600E-01, 0.39453500E+00, -.10398500E+00, -.20149300E+00, 0.19884300E-02, 0.24724700E+00, -.26615300E+00, 0.20381000E+01, -.19296300E+00, 0.90871700E-01, 0.13996800E-01, 0.50641100E+00, -.46248700E+00, -.25288600E+00, -.77196700E+00, -.21625300E+00, 0.70866500E+00, -.61206300E+00, -.10356700E+01, 0.42768100E+00, 0.32371000E+00, 0.26983600E+00, 0.32473600E+00, -.71029900E+00, 0.13618900E+00, 0.60248100E-01, -.96508000E-01, 0.20237400E+00, 0.58763500E+02, 0.17695200E+03, 0.27292100E+03, -.30361300E+02, -.35118300E+03, 0.17542600E+03, 0.17220900E+03, 0.12163100E+03, 0.11503700E+03, 0.58472200E+02, -.63132400E+02, -.10755900E+02, 0.11804700E+03, -.36050300E+03, 0.17972500E+03, 0.15970100E+03, 0.29185300E+02, -.81674800E+02, 0.13938600E+03, 0.63211700E+02, 0.25966500E+03, 0.36369000E+01, -.18970200E+03, 0.95329200E+02, 0.95576100E+02, 0.12198600E+03, -.52914600E+02, 0.52720600E+02, -.32098400E+02, 0.75487000E+02, -.13137400E+03, 0.87138300E+02, -.42079200E+02, -.30809500E+02, -.51893200E+02, 0.17595100E+02, -.47625700E+02, -.43276400E+02, 0.10196300E+02, -.10582600E+02, -.46614000E+02, 0.18524000E+02, 0.32208600E+02, 0.53239000E+02, -.99654400E+02, 0.41277200E+02, -.62835800E+01, 0.32157100E+01, -.68749300E+02, 0.15623200E+03, -.87119800E+02, -.35272100E+02, 0.25497200E+01, 0.34704000E+02, -.92931200E+02, 0.16634600E+02, 0.10148800E+03, -.31588800E+02, -.17268300E+03, 0.84337800E+02, 0.94502300E+02, -.73740500E+02, -.87204000E+02, 0.64782800E+02, 0.46321700E+02, 0.12262400E+03, -.47575100E+02, 0.98241900E+02, -.49832600E+02, -.54444200E+02, 0.40775700E+02, -.16614000E+01, -.79481700E+01, 0.20631500E+02, -.62322000E+02, 0.10618200E+02, 0.39496200E+03, -.19741100E+03, -.18610800E+03, 0.41968600E+02, -.15770300E+01, -.11878700E+03, 0.85249100E+01, -.10742600E+03, -.27477500E+01, 0.19519700E+02, -.68788200E+01, -.21338600E+02, 0.22312300E+02, -.54741500E+02, 0.24630100E+01, 0.20609800E+01, -.19255000E+02, 0.41908400E+02, 0.14948400E+02, 0.16099100E+02, 0.94130600E+01, 0.22557300E+02, 0.12421400E+01, 0.48966200E+01, 0.25926100E+02, -.37687100E+02, -.40875200E+02, 0.40140900E+00, -.10357300E+02, 0.45636600E+02, 0.18799200E+02, 0.12947100E+02, -.32868600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13017700E+01, -.91863100E+00, -.53091100E+00, 0.31015200E+01, 0.34313900E+00, -.24094400E+01, 0.24584200E+01, 0.68426100E+00, -.66656300E+00, 0.15397300E+01, -.12975600E+00, -.60526400E+00, 0.63730900E+00, -.17146500E+01, 0.62111200E+00, -.37906600E+01, -.23149200E+01, 0.66775700E+00, -.14680700E+01, 0.83384400E+00, -.66497400E+00, 0.32475200E+00, -.81762000E+00, -.10452900E+00, -.97281100E+00, 0.35124300E+01, -.16719300E+00, -.20097700E+01, -.41654100E+00, 0.98618300E+00, 0.56749600E+00, -.35668900E+00, 0.12228400E+00, 0.19577300E+00, 0.12559900E+01, -.52523700E+00, 0.66944700E+00, -.19990600E+01, -.37114600E+00, 0.30061500E+01, 0.11400400E+00, 0.22123600E+00, 0.12156700E+01, -.66611400E+00, 0.68385100E+00, -.84851100E+00, -.14688700E+00, 0.57282700E-01, 0.10606500E+01, 0.16177800E+00, -.13770500E+00, -.69245900E+00, -.89538500E+00, -.24158000E+00, -.80466200E-01, -.53565700E-01, 0.67042700E-01, 0.13695800E+01, -.15208700E+01, -.54577800E+00, -.77937400E-01, 0.64688700E+00, 0.11260600E+00, 0.39691500E-01, 0.14981900E+00, -.56324800E+00, 0.56035000E+00, -.22676700E+00, -.21655000E-01, -.22709400E+01, 0.24478700E+00, 0.13734800E+00, 0.64074400E+00, -.14095500E+01, -.12258700E+00, -.82149800E-01, 0.34529000E+00, 0.68159300E+00, -.28124000E+00, 0.10875200E+01, -.12033800E+00, -.10524300E+00, -.14292400E-01, 0.10331900E+00, 0.75290500E-01, 0.40610400E+00, 0.13814700E+00, 0.81633000E+00, 0.76275200E-01, -.69746800E-01, -.66844500E-02, -.21149300E-01, 0.19921400E-01, -.30944500E-01, 0.91122900E-01, -.30285200E-01, -.87070600E-02, -.28729700E+00, 0.55303500E-01, 0.78917400E-01, 0.47752700E-01, 0.18893600E+00, -.86060100E-01, 0.32143600E-01, -.24362700E-01, -.87710700E-01, -.13622400E-01, -.10601800E+00, 0.95813100E-01, 0.82695400E-01, 0.46025200E+00, 0.15663200E+00, 0.20221400E+00, 0.28091200E-01, -.15291600E+00, 0.22679200E+00, -.28296500E-01, -.73784200E+00, -.12068800E-02, -.45862200E+00, 0.14744300E+00, -.14033200E+00, -.67558000E+00, 0.11516400E+03, 0.26132900E+03, 0.29783500E+02, -.14448600E+03, 0.71994200E+02, 0.69992400E+02, 0.66451200E+02, 0.56926700E+02, 0.13363600E+02, -.11741600E+02, -.78085100E+02, 0.38836600E+02, -.11041200E+03, 0.61132900E+02, 0.43718300E+02, 0.13486800E+02, -.20498800E+02, 0.18104600E+02, -.10697900E+03, 0.14399600E+03, 0.44359800E+02, 0.11968100E+03, -.61115200E+02, -.59465100E+02, 0.10097400E+03, 0.12117100E+02, -.60483500E+02, -.89931900E+02, -.78306300E+02, -.82981500E+02, -.11695900E+03, 0.59920800E+02, 0.66556500E+02, -.87011800E+02, -.40555500E+02, 0.36237700E+02, -.10910200E+03, 0.41204800E+02, -.48158500E+02, 0.62060000E+02, -.40098900E+02, -.23947800E+02, 0.34180400E+02, -.60010100E+02, 0.22501300E+02, -.21557200E+02, 0.13640400E+02, -.96443400E+02, -.45708700E+03, 0.20545000E+03, 0.24196400E+03, 0.95028000E+02, 0.69752100E+02, 0.71084100E+02, 0.93891600E+02, 0.32300500E+03, 0.70663000E+02, -.13930300E+03, 0.68432400E+02, 0.73194300E+02, 0.18119900E+02, -.16427300E+02, 0.25270200E+02, 0.32687300E+01, -.88398300E+01, 0.40974500E+02, -.97205900E+01, 0.44011400E+01, 0.14191400E+01, 0.10228200E+03, 0.65586700E+02, -.13200500E+02, 0.95068400E+02, -.13326800E+02, 0.69718200E+02, 0.40518200E+03, -.20774400E+03, -.19595000E+03, 0.47404500E+02, 0.34414000E+02, -.13124100E+03, -.25696900E+02, -.17116300E+03, 0.13368000E+02, 0.27534000E+02, 0.20108500E+02, -.39915600E+01, 0.47756200E+01, -.77572300E+02, 0.13944000E+02, -.70206500E+00, -.57059400E+01, 0.30267500E+01, 0.71331500E+01, 0.26120500E+02, 0.88169100E-01, 0.10752300E+02, 0.99191700E+01, -.27741000E+02, 0.13897200E+02, -.10189200E+02, -.96347200E+01, -.82300300E+02, -.45984300E+01, 0.59353100E+02, -.53072300E+01, -.49476000E+02, -.21688600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.29949000E+01, -.20700600E+01, -.12150800E+01, 0.78123900E+01, -.35168500E+00, -.47429600E+01, 0.51446400E+01, 0.12308500E+01, -.20317000E+01, 0.19539800E+01, 0.26400800E+00, -.73305100E+00, 0.13517100E+01, -.15926400E+01, 0.34515100E+00, -.69945000E+01, -.41287800E+01, -.44986400E+00, -.29611900E+01, 0.41916400E+00, -.64150600E+00, 0.90429800E+00, -.20289600E+01, -.19754800E+00, -.21424000E+01, 0.75617700E+01, 0.16699900E+00, -.52771600E+01, -.13257200E+01, 0.20689500E+01, 0.17890500E+01, 0.73871400E+00, 0.43381300E+00, -.25680200E+00, 0.19489800E+01, -.38645200E+00, 0.28107300E+01, 0.16502300E+01, -.91906400E+00, 0.35904300E-02, -.13643300E-01, -.45775000E+00, 0.18508200E+01, -.17256600E+01, 0.63543300E+00, -.14177900E+01, -.30930500E+00, -.18236600E+00, 0.15859700E+01, -.86207000E+00, -.70391200E-01, 0.62692700E+00, -.81651500E+00, -.43254600E+00, 0.13725600E+00, -.18324100E+00, -.16239100E-01, 0.33800200E-01, -.25781300E+01, -.11119100E+01, 0.63767100E-01, 0.53006800E+00, 0.77138200E-01, 0.42141000E+00, -.44255800E+00, -.86737100E+00, -.67635200E+00, -.70477900E-01, 0.12537200E+00, -.23500000E+01, 0.57393100E+00, 0.11259200E+01, 0.23020300E+00, -.79841700E+00, -.38464200E+00, 0.53639400E-01, 0.50837500E+00, -.18326300E+00, -.96109800E+00, -.12565700E+01, 0.21052900E+00, -.12978300E+00, -.64099700E-01, 0.70727000E-01, 0.15399000E+00, 0.83474900E+00, 0.63122300E-01, 0.24839600E+00, 0.74167800E-01, 0.12389600E+00, -.89764900E-01, 0.74419900E-01, -.30278700E-01, -.17249100E+01, 0.29392900E+00, 0.10470500E+01, -.65647900E-01, -.52396400E-01, 0.15651500E+00, 0.69498400E+00, -.32310900E+00, 0.72044500E+00, 0.79522700E+00, -.58857200E-01, -.11735800E+00, 0.30155900E+00, -.23217800E+00, 0.32412600E+00, 0.95734100E+00, 0.50294000E-01, 0.41836100E+00, -.17824200E+00, -.78131700E+00, 0.59771600E+00, -.80738700E-01, -.32448600E+00, -.37943800E+00, 0.11099500E+01, 0.29427700E-01, -.28703900E+00, -.50890900E-01, -.27710300E+00, -.22526000E-01, 0.67739300E+00, -.22529100E+03, 0.90024200E+02, 0.41721100E+03, -.20841300E+03, -.20176200E+03, -.17812800E+03, -.17441500E+03, -.10474300E+02, 0.15616500E+03, 0.41698500E+03, -.16224400E+03, 0.37849300E+02, -.13513200E+02, 0.11891100E+02, -.21145500E+02, 0.74480900E+02, -.47327600E+02, -.14500500E+03, -.15082300E+03, 0.56567200E+02, -.27475700E+03, 0.14051100E+03, 0.13642000E+03, -.11154200E+03, 0.10043100E+03, 0.11499800E+03, 0.95089800E+02, 0.18233500E+03, 0.25961700E+02, 0.32100800E+03, -.15791800E+03, -.18309700E+03, 0.21859700E+02, 0.52985100E+02, -.91550700E+02, 0.12611500E+03, -.98321400E+02, 0.21830800E+02, -.25382900E+03, 0.12561300E+03, 0.13149300E+03, 0.53561600E+02, -.25643400E+02, 0.77688300E+02, 0.47421400E+02, 0.11316800E+03, 0.21923700E+02, -.42773500E+02, 0.19698600E+02, -.34546200E+02, -.79484700E+02, -.12221100E+03, 0.12649600E+03, 0.87215100E+02, -.51869600E+02, -.12742400E+03, 0.61309700E+02, -.29230200E+02, -.37492400E+02, 0.31669600E+02, 0.35114800E+02, -.67259200E+02, -.12807600E+03, -.16338500E+03, -.67304000E+02, 0.13429300E+03, -.69693000E+02, -.52231500E+02, -.25378300E+02, -.73018700E+02, -.35983200E+02, -.16991700E+03, -.44536500E+02, -.67876200E+02, 0.78837300E+02, -.36419200E+02, -.55872000E+02, -.13492600E+02, 0.68841800E+02, -.50550100E+02, 0.39570700E+02, 0.45504000E+01, 0.11591800E+02, -.36407900E+02, 0.17401900E+02, 0.10410200E+02, -.15742800E+02, 0.28315300E+02, -.20419600E+02, -.53643400E+01, 0.32747300E+01, 0.11996100E+02, -.10361800E+02, 0.13176000E+02, -.29299600E+01, -.56420300E+01, 0.13753700E+02, -.16247900E+02, -.81612200E+02, 0.26470200E+02, -.12184900E+02, 0.90024600E+02, -.65875200E+01, -.12019900E+02, -.41367000E+02, 0.74610200E+02, -.58754200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.45034600E+01, 0.20167200E+01, 0.17013600E+01, -.44258400E+01, -.46780200E+00, 0.58741400E+01, -.44230100E+01, -.18810700E+01, 0.26617600E+01, -.17958200E+01, -.10214800E+01, -.12092500E+01, -.17516500E+01, -.37957000E+01, -.32102700E+00, 0.97437200E-01, 0.61745000E+00, -.97552000E+00, 0.41076000E+01, -.49930200E+01, 0.92035600E+00, -.20857100E+01, -.20196900E-01, -.11211000E+00, 0.25134300E+01, -.59336300E+01, -.13607700E+01, 0.44861200E+01, 0.23270000E+00, -.23060700E+01, -.85253100E+00, 0.17409600E+00, 0.61471000E+00, -.43666600E-01, -.18579600E+01, 0.30872100E+00, -.11162200E+01, -.29405900E+01, -.25132700E+00, -.57401900E+01, -.54743100E+00, 0.73097400E+00, -.39148200E+01, 0.31468700E+01, -.10474100E+01, 0.15282900E+01, 0.25700300E+00, 0.41639000E+00, -.17680500E+01, 0.40398300E+00, -.14849000E+00, 0.14225900E+01, 0.15997700E+01, 0.12953700E+01, -.18415000E+01, -.44131000E+00, -.65938500E-01, 0.53663200E+00, 0.19386200E+01, 0.22450500E+01, -.61563900E-01, -.80251700E+00, -.25303000E+00, 0.15372900E+00, 0.16178600E+00, 0.12563000E+01, 0.47154700E+00, 0.59110800E+00, 0.24161100E-01, 0.10430800E+01, -.96619400E+00, -.20188300E+00, 0.36073000E+00, 0.25401700E+01, 0.40790100E+00, 0.19645000E-01, -.31999000E+00, 0.36250200E+00, -.81163000E-01, -.35356700E+00, 0.43632000E+00, -.28647600E+00, 0.16346600E+00, -.31450600E+00, -.63170700E-03, -.10570600E+01, -.33707400E+00, -.17603200E-01, 0.81206200E-01, -.12929600E+00, 0.15815800E+00, 0.61444500E-01, 0.53834700E-01, -.24939200E+00, -.45699900E-02, 0.11592100E+01, -.53032300E-01, 0.10824700E-01, -.56719400E-03, -.17922100E+00, -.50553400E+00, -.13314900E+01, 0.23011400E+01, -.54252900E+00, -.75771300E+00, 0.72872000E+00, -.10226700E+01, -.57424600E+00, -.10049000E+01, 0.35061100E+00, -.91742600E+00, -.35748800E+00, 0.63418800E+00, 0.38861500E-01, -.19053100E+00, -.11332200E+01, -.18560100E+00, 0.58359900E+00, 0.14299700E+00, -.15636000E+00, -.89393200E-01, 0.15551000E+01, -.69530600E+00, -.79112900E+00, -.10423400E+01, 0.25406500E+03, 0.32722500E+03, -.16347600E+03, -.16621700E+03, -.11025000E+03, -.13721200E+03, 0.34832700E+02, 0.13530300E+03, 0.48205300E+03, -.16744300E+03, -.39137900E+03, 0.20201800E+03, 0.17983000E+03, 0.11615800E+03, 0.10222800E+03, 0.64091900E+02, -.25727800E+03, 0.91113300E+01, 0.11905200E+03, -.35432100E+03, 0.18895300E+03, 0.17773700E+03, 0.16027300E+03, 0.72646900E+02, 0.68322100E+02, -.16580000E+03, 0.23585800E+03, -.18278800E+03, 0.66503500E+03, -.32331700E+03, -.32416600E+03, 0.15379400E+03, 0.40317300E+02, -.26318300E+03, -.45883400E+02, -.16742500E+03, -.17591800E+01, -.37079500E+03, 0.19660400E+03, 0.19167500E+03, 0.29422500E+03, -.21779300E+03, 0.76633500E+02, -.66700000E+02, 0.12761300E+03, -.27847400E+02, 0.33584100E+03, -.18449600E+03, -.12899000E+03, -.15587500E+03, -.20139500E+03, -.19561000E+01, 0.13079000E+03, 0.13946700E+03, -.22513300E+03, 0.61118600E+03, -.30613300E+03, -.29811900E+03, 0.63690000E+02, -.10463900E+03, -.34678500E+03, -.40646400E+03, -.48457100E+03, -.17664400E+03, 0.24645800E+03, -.13292300E+03, -.12603600E+03, -.22832000E+03, 0.93319100E+02, 0.31102800E+02, 0.55836000E+02, -.32324400E+02, -.38367500E+02, 0.86008200E+03, -.44360200E+03, -.41708500E+03, -.13477200E+02, 0.10360400E+02, -.28205800E+03, 0.11004900E+03, -.69726500E+02, -.96761500E+02, -.54905700E+01, -.73947100E+01, 0.23290300E+02, -.85184600E+01, 0.10736100E+03, -.41053400E+02, -.41915100E+02, 0.59129600E+01, 0.56601900E+02, -.37493800E+02, 0.98699000E+02, -.42582000E+02, 0.35398600E+01, 0.26273400E+02, -.57711400E+02, -.13851100E+03, -.83022500E+02, -.49270100E+02, 0.76929100E+02, 0.15341200E+02, -.90961100E+02, -.12958900E+03, 0.25713800E+02, 0.53312000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12898900E+01, 0.94133500E+00, 0.48624300E-01, -.35861500E+01, -.10470500E+01, 0.23829700E+01, -.37142200E+01, -.89500900E+00, -.16466800E+00, -.13091900E+01, -.18268200E-01, 0.33142500E+00, -.65179200E+00, 0.10504800E+01, -.86048200E+00, 0.19444100E+01, 0.17299800E+01, 0.10355900E+01, 0.16649500E+01, 0.98058000E+00, 0.77824000E+00, 0.51143000E+00, 0.12153400E+01, -.55018700E+00, 0.14938600E+01, -.35500400E+01, 0.33181300E+00, 0.16225900E+01, 0.45795600E+00, -.14117000E+01, -.23189100E+00, 0.98030700E+00, 0.50669700E+00, -.10443600E+00, -.27862600E+00, -.17630100E-01, -.70406500E+00, -.15064000E+01, -.12147900E+00, -.59145500E+00, 0.24168100E+00, 0.84214400E+00, -.22893500E+01, 0.46605600E+00, -.10511000E+01, 0.15207300E+00, 0.88650400E-01, 0.38243900E+00, 0.66421900E+00, 0.52778900E+00, -.22932700E+00, -.13317000E+01, -.14155500E+00, -.10364500E+00, 0.79465700E+00, 0.18456700E+00, 0.61762200E-01, -.65475700E-01, -.22806100E+01, -.23063800E+00, -.36272800E+00, -.65565200E+00, -.27895000E-01, -.49785800E+00, 0.37384000E-02, 0.33387800E+00, -.79137700E+00, -.21306700E+01, -.27487900E-01, 0.14243000E+01, 0.33750600E+00, -.45137800E-01, 0.23876900E+01, 0.54077300E+00, -.41336600E+00, 0.12169100E+00, 0.92229200E+00, -.10977300E+00, 0.65205900E-01, 0.12097600E+01, 0.56249400E-01, -.36745000E+00, 0.29140100E-02, -.67515700E+00, -.10496600E+00, 0.15593700E+00, 0.26957800E+00, 0.21702300E+00, -.45632900E+00, 0.61188500E+00, 0.30718200E+00, 0.70763000E-01, 0.43977000E-01, 0.24775100E+00, 0.13480100E+00, -.23571800E+00, 0.26160800E-02, 0.23894500E+00, 0.40472500E-01, 0.42669700E+00, 0.18384200E+00, 0.18046400E+01, -.48759400E+00, 0.24549600E+00, 0.11087000E+00, -.10324800E+00, -.17364400E+00, -.15784900E+00, 0.87982100E-01, 0.22466700E+00, 0.13404200E+00, 0.40665900E+00, 0.31242500E+00, -.16833500E+00, -.61237800E-01, -.20229000E+00, -.16053700E+00, 0.10070500E+00, -.24319700E-01, 0.26136200E+00, 0.35839500E+00, 0.55011300E-01, -.49105900E+00, 0.35138200E+00, -.11710100E+00, -.49163400E-03, -.23880100E+03, 0.11928500E+03, 0.11805100E+03, 0.82182800E+02, 0.78245900E+02, 0.29623000E+02, -.43938700E+02, 0.42184300E+02, 0.76893000E+02, -.59118900E+02, 0.34624700E+02, 0.23810300E+02, -.53868900E+02, -.48228000E+02, 0.61780700E+01, -.62687600E+02, 0.58881400E+02, 0.25685600E+01, -.15583500E+03, 0.85293500E+02, 0.78045900E+02, 0.39519300E+02, 0.58503700E+01, 0.49726600E+02, 0.56704200E+01, 0.71962900E+02, -.65509900E+02, -.23829400E+03, 0.11949500E+03, 0.12296800E+03, 0.10256000E+03, 0.11605300E+03, 0.13074600E+01, -.16408200E+03, -.10019600E+03, 0.11819600E+03, 0.70215700E+02, -.34559900E+02, -.34080000E+02, 0.11641400E+03, -.13327700E+02, -.39494500E+02, -.75960700E+02, -.53142500E+02, -.82617100E+02, 0.18433000E+03, -.99774500E+02, -.83694200E+02, -.35201000E+02, -.65788300E+02, -.20209900E+02, 0.48122400E+02, 0.28979700E+02, -.65538000E+02, 0.24501900E+03, -.12277000E+03, -.12132500E+03, -.52926100E+02, -.11346100E+03, -.47638000E+02, 0.15693400E+02, 0.95529000E+02, -.89794400E+02, 0.21465800E+03, -.10772800E+03, -.10934400E+03, -.32747700E+02, -.42472300E+02, -.25336700E+02, 0.89891200E+02, -.40266800E+02, -.46817000E+02, 0.24757000E+03, -.12020200E+03, -.11970600E+03, -.33065500E+01, -.52609100E+01, -.71321600E+02, 0.19147600E+02, -.49666900E+02, -.41151300E+02, 0.47054300E+01, 0.13236700E+01, -.73657900E+01, 0.15354800E+02, -.60151900E+02, -.67545200E+01, 0.13980700E+00, -.36622600E+01, 0.28226400E+02, 0.18593300E+01, 0.18942500E+02, -.31462500E+01, 0.71057100E+01, 0.58598700E+01, 0.21446500E+02, 0.41088300E+01, 0.21259800E+02, -.27780900E+02, 0.14449200E+01, -.97853000E+01, 0.63173200E+02, -.17016800E+01, -.18858100E+01, 0.75751500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.40787200E+01, 0.32788100E+01, 0.17764900E+01, -.74753600E+01, -.51890000E+00, 0.62835700E+01, -.75829000E+01, -.22030200E+01, 0.22638100E+01, -.23565400E+01, -.21971300E+00, -.21404100E+00, -.10396500E+01, -.16380500E+01, -.12012500E+01, 0.29328600E+01, 0.20144600E+01, 0.72777200E-01, 0.29274000E+01, -.34468000E+01, 0.47875200E+00, -.14063000E+01, 0.97465100E+00, -.11547000E+00, 0.23262200E+01, -.50207300E+01, -.79777200E+00, 0.48257400E+01, 0.42628600E+00, -.19428400E+01, -.10312800E+01, -.84378100E+00, 0.24472800E+00, 0.10877700E+00, -.14705200E+01, 0.82835500E+00, -.14080400E+01, -.42885700E+01, 0.52142300E+00, -.46606100E+01, -.43707900E+00, 0.17561500E+00, -.24228700E+01, 0.32171700E+01, -.59922900E+00, 0.12723100E+01, 0.39960300E+00, 0.81535800E+00, -.18545900E+01, 0.17281100E+01, 0.19956000E+00, 0.12519700E+01, 0.20954900E+01, 0.13024700E+01, -.10715100E+01, -.43297100E+00, -.42339000E-01, -.11212100E+01, -.40322500E+00, 0.37829400E+01, 0.39831800E+00, -.89045400E+00, -.24674100E+00, 0.54088400E+00, -.11327900E+00, 0.66947800E+00, -.12617700E+01, 0.58173700E+00, 0.12592000E+00, 0.40291800E+01, -.21875400E+00, 0.57057900E+00, -.22506900E+01, 0.17403300E+01, 0.81441500E+00, 0.24181900E+00, -.67681800E+00, -.40609800E+00, -.36836300E+00, 0.16155800E+00, 0.56732700E+00, -.65212700E+00, 0.18454300E-01, 0.19898700E+00, -.41692000E-01, -.26060500E+00, 0.19475700E+00, -.21732200E+01, -.20047500E-01, 0.11510300E+00, -.21410500E+00, 0.20212300E+00, -.31096000E-01, -.65920600E+00, 0.18729600E-01, 0.18664700E+00, 0.24639800E-01, 0.37180000E+00, -.23751400E-01, -.84744600E+00, -.34744700E+00, -.32707000E+01, 0.65117000E+00, -.31872900E+00, -.10614200E+00, 0.37055600E+00, -.14240100E+00, 0.28828500E+00, -.10874500E+01, -.21099300E+00, -.35679500E+00, -.26541900E+00, 0.63837000E+00, 0.15535300E-02, 0.25267100E+00, -.39011300E-01, -.16740400E+00, 0.16464200E+01, 0.14528800E+00, 0.32631800E+00, 0.76398800E-01, 0.63991500E+00, 0.74427000E+00, -.10127900E+01, 0.97574200E-01, 0.20518500E+00, 0.35106000E+00, 0.14901600E+02, 0.15800900E+01, -.16039700E+02, -.99925300E+01, -.76240500E+00, 0.91632400E+01, -.58512000E+02, 0.18832500E+01, 0.48384700E+02, -.36141500E+02, -.16836300E+02, 0.11036000E+02, -.60147600E+01, 0.47047100E+01, 0.85839300E+02, 0.40381700E+01, -.27006200E+02, 0.16789000E+03, -.91875000E+02, -.84145900E+02, -.21598800E+02, -.38030800E+02, -.55999200E+02, 0.26571100E+00, -.86989800E+02, 0.63126700E+02, 0.10819700E+03, -.57456800E+02, -.58634600E+02, -.13304100E+03, -.13841600E+03, 0.45462700E+02, 0.10390600E+03, 0.14844300E+03, -.11447800E+03, 0.16950800E+02, -.95603300E-01, -.63714900E+01, -.11503800E+03, 0.39827200E+02, 0.54507000E+01, 0.43128500E+02, 0.10880600E+02, 0.43385800E+02, -.10144000E+03, 0.67497900E+02, 0.34042400E+02, 0.67430700E+02, 0.86078700E+02, -.23052900E+02, -.68216900E+02, -.58553100E+02, 0.99048100E+02, -.10040300E+03, 0.48089000E+02, 0.48139000E+02, 0.43300600E+02, 0.53559300E+02, 0.21152700E+02, 0.88397000E+01, 0.37862400E+02, 0.63526500E+02, -.22824600E+03, 0.11707000E+03, 0.11684900E+03, 0.11068800E+03, 0.93128900E+02, 0.34176600E+01, -.77323200E+02, -.80105000E+02, 0.88475000E+02, -.32319600E+03, 0.15071000E+03, 0.15607000E+03, -.10850600E+02, -.13084000E+02, 0.10436500E+03, -.18241900E+02, 0.12664900E+03, 0.14033900E+02, 0.99115100E+01, -.84892400E+01, -.31456700E+01, 0.57145800E+00, 0.11852300E+02, 0.16401100E+02, 0.72910500E+00, 0.27018700E+01, -.16395500E+02, -.12729700E+01, -.17371900E+02, 0.12661700E+01, 0.39435600E+01, -.12203000E+02, -.80098600E+01, 0.10797700E+02, -.83885200E+01, 0.19407600E+02, -.30982500E+02, 0.16474300E+02, -.19115100E+02, 0.94262900E+01, -.53158100E+01, 0.92359100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.29019800E+01, -.93793700E-01, 0.11540600E+00, -.39403000E+01, -.14027700E+01, 0.42274400E+01, -.56921700E+01, -.17795700E+01, 0.98188600E+00, -.19979000E+01, -.68916100E+00, -.86024500E+00, -.77245600E+00, -.31103300E+01, 0.35269100E+00, -.27766600E+01, -.63438500E+00, 0.45735400E+00, 0.45024500E+00, -.58525400E+01, -.45963300E+00, -.18832900E+01, 0.22491100E+00, 0.67362000E+00, 0.59636600E+00, -.10399100E+00, -.15105400E+01, 0.20056800E+01, 0.11926200E+01, -.51421700E+00, -.91472800E+00, -.15146800E+01, 0.60810000E+00, 0.18174200E-01, -.18198600E+01, -.82567200E-01, 0.11120400E+01, -.17224600E+01, -.37261600E-01, -.38385100E+01, -.23081700E+00, -.19962000E+00, -.69079100E+00, 0.18343300E+01, -.19780500E-01, 0.46970100E+00, 0.87126100E-01, 0.22535900E-01, -.70758100E+00, 0.33115100E+00, 0.26479900E+00, 0.78915600E+00, 0.44211400E+00, 0.70758600E-02, -.71744800E+00, 0.30225100E-02, -.74817800E-01, -.13083200E+01, -.64727700E+00, 0.11921900E+01, 0.32331200E+00, 0.17662200E+00, -.21796100E-01, 0.43459200E+00, 0.22017000E-02, 0.40405400E+00, 0.67600700E+00, 0.39483400E+00, 0.16614600E+00, 0.39014600E+01, -.53559200E+00, 0.35834400E+00, 0.13212100E+01, 0.85758500E+00, -.54055200E+00, 0.40445700E-01, -.53787300E+00, -.14973900E+01, 0.97959900E+00, -.19081000E+01, 0.26697200E+00, 0.55152700E+00, -.10097900E+00, 0.16262600E+00, -.20371800E+00, -.76321400E+00, -.12253500E+00, -.79472900E+00, -.81953100E-01, 0.51565500E+00, -.11433300E+00, -.98711100E-02, 0.58165900E-01, -.24285300E+00, -.55477200E+00, -.52961600E+00, -.28963300E-01, 0.40340000E+00, -.60033300E-01, 0.99629800E-01, 0.74188500E+00, 0.86823900E+00, -.13675200E+01, 0.41039500E+00, 0.15548900E+00, -.46364500E+00, 0.88769400E-01, 0.37245600E+00, -.62299600E+00, -.20789700E+00, -.53590100E+00, 0.69124100E+00, 0.56086800E+00, 0.10097100E+00, 0.20536300E+00, -.12309000E+01, -.68022700E+00, -.29029900E+00, -.18802800E+00, -.26193300E+00, 0.32807800E-01, -.53239200E+00, -.12690100E+01, 0.16882600E+01, 0.30556400E+00, -.51680400E+00, -.57041600E+00, -.87618900E-01, -.59256500E+01, -.17956900E+02, -.28180000E+02, 0.85687900E+02, 0.75852000E+02, 0.50335800E+03, -.74241300E+01, -.78052500E+03, 0.40035700E+03, 0.36377200E+03, 0.69147600E+02, -.19980400E+02, 0.24100500E+03, 0.16097000E+02, 0.12078900E+03, 0.82259100E+02, -.10857700E+04, 0.56222100E+03, 0.54344200E+03, -.51149000E+02, -.62096800E+02, 0.37867900E+03, 0.10007500E+03, 0.53714300E+03, -.84068300E+02, 0.47949800E+03, -.22707100E+03, -.22167700E+03, 0.25991700E+03, 0.19034900E+03, -.26977800E+03, -.11182300E+02, -.17194800E+03, 0.16424600E+03, -.33687400E+03, 0.15643000E+03, 0.16644400E+03, 0.18819900E+03, -.25844200E+03, 0.92019900E+02, 0.38513300E+01, 0.60336700E+02, -.10802000E+03, 0.11724700E+04, -.58496800E+03, -.53455000E+03, -.20792600E+03, -.16666300E+03, -.27645300E+03, -.26491300E+02, -.27515100E+03, -.26221600E+03, 0.21133300E+03, -.10479400E+03, -.10099600E+03, -.14259700E+03, -.17255600E+03, -.41070600E+01, 0.54746600E+01, 0.36966200E+02, -.27802800E+03, 0.44792900E+03, -.23562500E+03, -.23505000E+03, -.29488800E+03, -.15402000E+03, 0.33294300E+02, -.20853700E+02, -.54489100E+02, -.17908600E+03, 0.73504500E+03, -.34352500E+03, -.35243500E+03, 0.48681400E+02, 0.11744000E+03, -.26909800E+03, 0.97980800E+02, -.17726400E+03, -.12108800E+02, -.13532900E+02, 0.12551500E+02, -.10140800E+02, 0.78811800E+01, 0.46210800E+02, -.45573600E+02, -.22450100E+02, -.11612500E+01, 0.74155100E+02, -.22798800E+02, 0.35885300E+02, -.17874100E+02, 0.18121300E+02, 0.98526500E+01, 0.51081000E+02, -.90047600E+02, -.65599500E+02, -.54699500E+02, 0.20056100E+03, -.94368100E+01, -.23602700E+02, -.19598700E+02, 0.11938800E+03, -.50698900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.68133400E+01, 0.88854500E+00, 0.27605200E+01, -.98158300E+01, 0.26627900E+01, 0.10571100E+02, -.89575300E+01, -.29841800E+01, 0.45846800E+01, 0.27462400E+00, -.65280700E+00, 0.70725900E+00, -.71621000E+00, -.34721800E+01, -.11670500E+01, -.34422000E+01, -.95385100E+00, 0.27370300E+01, 0.52367500E+01, -.36714400E+01, -.40701200E+00, -.21447900E+01, -.33482200E+00, -.81650600E+00, 0.23275800E+01, 0.11671000E+01, -.38450800E+01, 0.18657300E+01, -.17700900E+01, -.61794100E+00, -.81039900E-01, -.12739000E+01, 0.64208000E-02, 0.42483300E+00, -.34590500E+00, 0.46012100E+00, 0.11040300E+01, -.67143600E+01, -.16391900E+00, -.17238000E+01, -.36131600E+00, 0.19011800E+01, -.87433500E+00, 0.24332800E+01, -.80413900E+00, 0.17797700E+00, 0.15139000E-01, 0.13355500E+01, -.21193900E+01, -.38827800E-01, 0.29679500E+00, -.69578100E+00, 0.36474600E+01, 0.16705400E+01, 0.26648300E+01, 0.96843500E+00, 0.14301800E+00, 0.12205000E+01, 0.93991100E+00, 0.14974000E+01, 0.50928400E-01, 0.21704900E+00, 0.99580200E-01, -.27957700E+00, 0.58229200E+00, 0.44149400E+00, -.52410200E+00, 0.78680800E+00, -.15735900E-01, -.42509500E+01, 0.27915000E-02, -.83304400E+00, -.15122100E+01, -.39301300E+00, 0.10825700E+01, -.15178600E+00, -.87397900E-01, 0.19390900E+01, -.73486200E+00, 0.28655600E+01, -.12821200E+00, -.13394200E+01, 0.63251000E-01, 0.19928200E+00, 0.40792900E+00, -.63689400E+00, 0.89903400E+00, 0.59874400E+01, 0.90474400E+00, -.33702000E-01, 0.16160200E+00, 0.16009600E+00, -.11980000E+00, -.21434800E-01, 0.57756000E+00, 0.53083700E-01, -.73757800E-01, 0.63052800E+00, -.17738500E+00, 0.32586500E+00, -.31468300E+00, -.30659400E-01, 0.10547800E+01, -.22872300E+00, -.11402900E+00, 0.17100500E-01, 0.10359600E+01, -.43108000E+00, -.17026000E-01, -.75172300E-01, -.10165300E+01, 0.58841500E+00, 0.90581300E+00, -.62840300E+00, 0.10443600E+00, -.12165800E+01, -.19917100E+00, 0.23017200E+01, -.65939900E-01, 0.89892500E-01, 0.12325400E+00, 0.15781900E+01, -.81862100E+00, 0.53713800E-02, 0.90683700E+00, -.27204000E+00, -.31774800E+00, 0.32009700E-01, 0.10451500E+01, 0.52705400E+02, 0.49550000E+02, -.69479400E+02, -.98047900E+02, -.49740000E+03, 0.19286400E+02, 0.27207700E+03, -.16767300E+03, -.13851200E+03, 0.72689700E+02, 0.90077100E+02, -.14972600E+03, -.16856600E+03, -.25727600E+03, 0.51644700E+01, 0.61643700E+03, -.30084800E+03, -.30816500E+03, 0.12310000E+03, -.59795100E+02, -.23750300E+03, -.15171900E+03, -.33297100E+03, 0.70142800E+02, 0.30932000E+03, -.16362500E+03, -.16035100E+03, -.63743600E+02, -.19515000E+03, -.50231200E+02, 0.46622500E+02, -.53875800E+02, -.15127300E+03, 0.22327300E+03, -.68408200E+02, -.12132400E+03, -.29623200E+01, 0.77230500E+02, -.75815000E+02, -.34498700E+02, -.35939700E+02, 0.38880000E+02, -.71536100E+03, 0.40215200E+03, 0.34313300E+03, 0.19709900E+03, 0.20635800E+03, 0.63942400E+02, -.83110300E+02, 0.83017200E+02, 0.32568100E+03, 0.26508700E+03, -.13657300E+03, -.12468500E+03, 0.14476100E+03, 0.51596300E+02, -.15023600E+03, -.11067500E+03, -.23547500E+03, 0.16681600E+03, -.58818700E+03, 0.30044100E+03, 0.30564500E+03, 0.16280900E+02, 0.17657700E+03, 0.15367400E+03, 0.93132900E+02, 0.35170400E+03, 0.89105800E+02, -.82221200E+03, 0.39119400E+03, 0.43703000E+03, -.57411100E+02, -.14575600E+03, 0.28945000E+03, -.72568200E+02, 0.24003400E+03, -.32978200E+02, 0.68551300E+01, 0.28532800E+02, 0.11429400E+02, -.54718800E+01, 0.76708000E+02, -.49388900E+01, 0.14025400E+02, 0.89130200E+00, -.28098600E+02, 0.12180300E+02, -.37867200E+02, 0.12246700E+02, -.19750100E+02, -.90769200E+01, -.50983900E+02, 0.77008400E+02, -.10867200E+02, 0.34876900E+02, -.87299700E+02, -.37719100E+02, -.94957500E+02, -.18690900E+02, -.84614700E+02, -.38587400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15808400E+01, -.12677900E+01, -.61685500E+00, 0.44718800E+01, 0.94849800E+00, -.35263800E+01, 0.52786100E+01, 0.12223500E+01, -.40961400E+00, 0.24212000E+01, -.24116600E+00, -.10870500E+01, 0.97401000E+00, -.21676700E+01, 0.14047800E+01, -.52287700E+01, -.33987600E+01, 0.31531400E-01, -.27017200E+01, -.98213000E+00, -.14119200E+01, -.13147600E+00, -.14588100E+01, 0.36029800E+00, -.25053200E+01, 0.66799600E+01, -.65483500E+00, -.28690600E+01, -.51091400E+00, 0.19589200E+01, 0.89080700E+00, -.76368500E+00, 0.10121300E+00, 0.16148800E+00, 0.10698900E+01, -.63301800E+00, 0.22878300E+01, 0.34839200E+00, -.22324200E+00, 0.26426300E+01, 0.14576600E+00, -.12109700E+01, 0.33255100E+01, -.94105700E+00, 0.17462400E+01, -.11766000E+01, -.14045400E+00, -.25856200E+00, 0.56979300E+00, -.57768100E+00, 0.56492700E-01, -.36489300E+00, -.66430800E+00, -.30952800E+00, 0.67365500E+00, -.74225600E-02, 0.12278500E+00, 0.26698000E+00, 0.65748500E+00, 0.22710600E+00, 0.38630900E+00, 0.98630700E+00, 0.33030200E+00, 0.87535100E-01, 0.28726000E+00, -.42689900E+00, 0.26189800E+00, 0.14004900E+01, 0.21628500E-01, -.43374000E+01, 0.28934300E+00, -.37389400E+00, -.46093300E+01, -.14571700E+01, 0.89849300E+00, 0.45102200E-01, -.14927000E+01, 0.36546100E+00, 0.25949300E+00, -.32453200E+01, -.34359200E+00, 0.13485500E+01, -.65242200E-02, -.85077500E-01, -.88081600E-01, -.25952300E+00, -.43522400E+00, 0.20458700E+01, 0.16141700E+00, -.38935500E+00, -.10946300E+00, 0.22755600E-01, -.14574500E+00, -.23587800E+00, -.44542600E+00, -.10097100E+01, 0.40830400E-01, 0.13132100E+01, -.37018800E+00, 0.51801800E+00, 0.27816300E+00, -.26385600E+00, -.16956100E+01, 0.39271200E+00, -.18623600E+00, 0.21305500E+00, 0.36494000E+00, -.43139500E+00, -.55003400E+00, -.30403600E+00, -.11163200E+00, -.46350100E+00, -.22575000E+00, -.11248300E-01, 0.39709000E+00, 0.13987500E+00, 0.25926600E+00, 0.58756500E+00, -.30717200E-01, 0.89567600E+00, 0.63982000E-01, 0.16678500E+00, 0.47244300E+00, -.46658800E+00, -.32781200E+00, -.17305400E+00, -.91890900E+00, -.29639800E-01, -.43612800E-01, 0.18033200E+00, -.33188200E+02, 0.32349700E+02, 0.60992700E+02, 0.24866800E+03, -.23557700E+02, -.22083200E+03, 0.12032200E+03, 0.10717900E+03, -.58743200E+02, -.46160100E+02, 0.50956600E+02, -.68874000E+02, 0.78677100E+02, 0.20307400E+02, -.44075800E+03, 0.22993200E+03, 0.22060200E+03, -.32982500E+02, -.54714600E+01, 0.15598900E+03, 0.38066800E+02, 0.20785200E+03, -.84030700E+02, -.48900400E+03, 0.25100200E+03, 0.24681100E+03, 0.28170300E+03, 0.27314100E+03, 0.71413800E+01, -.29487800E+03, -.27792000E+03, 0.26413500E+03, 0.15015400E+03, -.92575500E+02, -.62765600E+02, 0.21674500E+03, -.30578600E+02, -.10789100E+03, -.15637800E+03, -.16192300E+03, -.85173700E+02, 0.68827900E+03, -.35092100E+03, -.32131400E+03, -.16241200E+03, -.19321500E+03, -.97502100E+02, 0.83759900E+02, -.85754100E+02, -.22266100E+03, 0.19820100E+03, -.98465900E+02, -.96436000E+02, -.12354700E+03, -.14744700E+03, 0.28452400E+01, 0.50911400E+02, 0.11384100E+03, -.19140700E+03, 0.50548900E+03, -.25906000E+03, -.25403900E+03, -.18005200E+03, -.17494000E+03, -.46500400E+02, 0.19781600E+03, 0.10289200E+03, -.15070100E+03, 0.65525900E+03, -.31216700E+03, -.33015500E+03, -.12714600E+02, 0.66714600E+01, -.20799900E+03, 0.73296500E+02, -.11755100E+03, -.78141400E+02, 0.19285600E+02, -.33278100E+02, 0.47616800E+01, 0.36515000E+01, -.30388800E+02, -.25866200E+02, -.26641500E+02, 0.22155300E+02, 0.95315000E+01, -.28091100E+02, 0.27533000E+02, -.37649400E+02, -.84934500E+01, 0.21144100E+01, 0.30467800E+02, -.60582300E+02, -.22411600E+01, -.12903700E+02, 0.25137400E+02, -.15229100E+02, 0.50008200E+02, -.18442800E+02, -.84566700E+01, 0.34726100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.60891900E+01, 0.29797900E+01, 0.31733900E+01, -.12993900E+02, 0.31001400E+01, 0.12886300E+02, -.12165700E+02, -.40686100E+01, 0.92659600E+00, -.31295000E+01, 0.10677200E+01, 0.22914800E+01, -.37769800E+00, 0.31751300E+01, -.37146200E+01, 0.36170900E+01, 0.28808100E+01, 0.32580600E+01, 0.43050400E+01, 0.46512700E+00, 0.70304000E+00, 0.61007000E+00, 0.34505000E+01, -.14678100E+01, 0.28213200E+01, -.73292100E+00, -.72739600E+00, 0.28249600E+01, -.23843600E+01, 0.78100500E+00, -.25156900E+01, -.17231800E+01, -.75844800E+00, 0.29260500E+00, -.59207000E+00, -.18668300E+01, -.49119000E+01, 0.16041600E+01, -.52416600E+01, -.46790500E+01, -.15489300E+01, 0.52988200E+01, -.38599600E+01, -.10430100E+01, -.26944800E-01, -.59838100E+00, -.81354800E-01, 0.48722600E+01, -.41574200E+00, -.14725400E+00, -.42750500E+00, -.15319200E+01, -.14019300E+01, 0.31004500E+01, -.22245900E+01, -.85633900E+00, 0.12123100E+01, 0.65200300E+00, 0.20199900E+01, 0.10996600E+01, 0.40347300E-01, -.50913800E+00, -.16448700E+00, -.13597800E+00, -.15812900E+00, 0.26072600E+00, -.60137200E+00, 0.12297900E+01, -.90726900E-01, -.24304800E+01, -.16828700E+00, 0.93801800E+00, -.29753900E+01, 0.63277700E+00, 0.14601500E+00, 0.29221300E+00, -.76965000E+00, 0.16495500E+00, -.39283400E+00, -.12845500E+01, 0.30942900E+00, -.76182900E-01, 0.14932100E+00, -.96562000E-01, 0.36596300E-01, 0.55911500E-01, -.94990000E-01, 0.10582300E+01, 0.59607900E+00, -.95991600E+00, 0.63617300E+00, -.40525500E+00, -.22769600E+00, 0.95595100E-01, 0.22064200E+00, 0.85839400E+00, -.50057500E+00, -.34611700E+00, -.93625000E-01, -.54344400E-01, 0.62785000E-02, 0.26613700E+01, -.16304000E+01, 0.28723600E+00, 0.64671300E-01, 0.83463400E+00, 0.91135100E+00, -.17765200E+00, 0.81134700E+00, -.47208600E-01, 0.19855000E+01, 0.33204400E+00, -.15992200E+01, 0.19545100E-01, -.42190300E+00, 0.16632300E+01, 0.91728900E+00, 0.44719200E+00, 0.24498000E+00, 0.74284300E+00, -.16597100E-01, -.25944600E+00, -.89947900E+00, 0.11906700E+01, -.57400900E+00, -.11769500E+00, -.23130900E+00, -.34663500E-01, 0.15806400E+01, -.22408200E+00, -.38623200E+00, -.86626300E+02, -.84595400E+02, -.41136300E+03, -.25502800E+02, 0.81153700E+03, -.40343900E+03, -.41790300E+03, -.24345800E+03, -.55233800E+01, -.25649600E+03, -.51558300E+02, -.16970800E+03, -.99838000E+02, 0.14127400E+04, -.72038200E+03, -.70502400E+03, 0.17663800E+03, 0.38294800E+02, -.53792900E+03, -.28726800E+03, -.69987100E+03, 0.55526600E+02, -.88420600E+03, 0.42651400E+03, 0.44770900E+03, -.57542200E+02, -.16658600E+02, 0.30671700E+03, -.17294100E+03, -.78698000E+02, 0.16556400E+02, 0.10333200E+04, -.49904400E+03, -.51462600E+03, 0.10530900E+02, 0.42365500E+03, -.43379000E+03, -.29988200E+03, -.42586400E+03, 0.58589000E+02, -.13686700E+04, 0.64795500E+03, 0.76660000E+03, 0.14909000E+03, 0.89830700E+02, 0.42171100E+03, 0.15268400E+03, 0.35655600E+03, 0.17600700E+03, -.25776400E+03, 0.12504300E+03, 0.14498900E+03, 0.10674200E+03, 0.13328300E+03, 0.53804700E+02, 0.85604800E+02, 0.53578700E+02, 0.20823600E+03, -.16033700E+03, 0.93550900E+02, 0.77176400E+02, 0.20547000E+03, 0.39738800E+02, -.83470500E+02, 0.14884000E+03, 0.23138800E+03, 0.74068600E+02, -.78171700E+03, 0.36399100E+03, 0.40015900E+03, -.95351800E+02, -.24763800E+03, 0.31737300E+03, -.70454800E+02, 0.32205600E+03, -.57581700E+02, 0.11600700E+02, -.71314500E+02, 0.21367100E+01, -.10715300E+00, -.17373000E+03, 0.32590900E+02, 0.23141400E+02, 0.24707000E+01, -.76906600E+02, 0.21648100E+02, -.53988700E+02, 0.96857300E+01, -.24032200E+02, -.12319900E+02, -.30506500E+02, 0.75032800E+02, 0.15470100E+03, 0.60791200E+02, -.20516800E+03, -.22960700E+02, 0.14909300E+03, 0.25502400E+02, -.14553400E+03, 0.45230400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13166900E+01, -.93827000E+00, -.44876400E+00, 0.38042100E+01, 0.99968600E-02, -.22306900E+01, 0.27425600E+01, 0.60764900E+00, -.11757100E+01, 0.15237300E+01, -.19063900E-01, -.95401000E+00, 0.70100800E+00, -.31525800E+01, -.19728400E+00, -.44277400E+01, -.28069700E+01, -.17287100E+01, 0.33724600E+00, 0.14511300E+01, -.25020500E+00, 0.19519800E+00, -.82791900E+00, -.34233700E+00, -.10405400E+01, 0.16872700E+01, -.62120900E+00, -.13633600E+01, -.77743000E+00, 0.20879700E+00, 0.12668700E+01, -.46254700E+00, -.62587200E-02, 0.22749500E+00, 0.56453600E+00, -.23192200E+00, -.19125500E+00, -.11440000E+01, -.37977600E+00, 0.31459000E+01, -.60112500E-01, 0.97376500E+00, 0.91693400E+00, -.16774800E+00, 0.55297800E+00, -.43580700E+00, -.63029100E-01, -.39185300E-01, 0.43621800E+00, -.97921800E+00, 0.56173100E-01, 0.73532000E+00, -.39643600E+00, 0.11739300E+00, -.35418200E+00, 0.49364100E+00, -.69102300E-01, -.86058700E+00, -.90936300E+00, -.97877800E+00, -.92779800E-01, 0.13396600E+00, -.12757200E-02, -.48131600E-01, -.49143500E-01, -.63546200E+00, -.48089700E+00, -.10046700E+01, -.11521600E+00, 0.20545300E+01, 0.35447100E+00, 0.12494900E-01, -.29164100E+00, 0.22881000E+00, -.31649400E+00, 0.29697500E+00, 0.49877700E+00, 0.39782100E+00, -.12796700E+00, 0.21118400E+01, -.23366400E+00, -.48539600E+00, -.70987500E-01, 0.30060300E+00, -.16628400E-01, 0.57305600E+00, -.98085200E-01, -.95417000E+00, 0.22114000E-01, -.69564300E+00, -.22587500E+00, -.17934900E+00, 0.11763500E+00, 0.44286400E+00, -.84349300E-01, -.42026600E+00, -.88503600E-01, -.33822200E-02, 0.17933700E-01, 0.18178200E+00, -.18791400E-02, -.16914800E+01, -.44975700E+00, 0.48079400E+00, -.79234200E-01, -.45069700E+00, 0.38971500E+00, 0.27271600E+00, -.13110800E+00, 0.17078100E+00, 0.72195300E-01, 0.59921900E+00, 0.44780500E+00, 0.22675200E+00, -.20413000E+00, -.33078500E+00, -.18444100E+00, 0.21943700E+00, 0.95288600E-01, 0.20482100E+00, -.12054200E+00, -.26986100E+00, 0.10382900E+00, -.20369100E+00, -.14691000E+00, 0.14491200E+00, -.29731300E+00, -.62304200E-02, 0.21148600E+00, 0.70588200E-01, -.68433400E-01, 0.22050000E+00, 0.18032700E+02, -.13467700E+02, 0.53184900E+01, 0.11764600E+03, -.48277500E+02, -.51879700E+02, -.68785500E+01, 0.15074300E+02, -.42497600E+02, -.38439600E+02, -.13141700E+02, 0.16087500E+02, -.17309100E+03, 0.90365600E+02, 0.86049400E+02, -.11614200E+03, 0.34824900E+02, 0.92116100E+02, 0.12126000E+03, 0.76977700E+02, 0.23259400E+02, -.17316100E+03, 0.87669300E+02, 0.84466600E+02, 0.17303500E+02, 0.40795300E+02, 0.40950100E+02, -.90699900E+01, 0.38257700E+02, 0.36210700E+02, -.10221700E+03, 0.42753100E+02, 0.44540400E+02, -.53060000E+02, -.19275100E+02, 0.59358700E+02, 0.56628100E+02, 0.58459300E+02, 0.10548100E+01, 0.34888700E+02, -.28643500E+02, -.50755400E+02, -.25383900E+02, -.47643300E+02, 0.24666300E+02, 0.45098200E+02, 0.15772100E+02, -.47020000E+02, -.91897700E+02, 0.46465600E+02, 0.38167400E+02, -.15360900E+02, 0.20060700E+02, 0.39781100E+02, 0.24582300E+02, 0.57931200E+02, -.74797000E+01, 0.10618400E+03, -.53591400E+02, -.54140000E+02, -.19147700E+01, -.68783200E+02, -.17581300E+02, 0.64883900E+00, -.55259900E+02, -.27441000E+02, -.12155700E+02, 0.13940500E+02, -.87896700E-01, 0.47517000E+01, 0.63857100E+02, -.12776700E+02, -.12379800E+02, -.68271200E+02, 0.29072700E+02, 0.10572100E+01, 0.26948000E+02, 0.54865800E+01, -.57392400E+01, -.54888000E+01, 0.15322900E+01, -.21354200E+01, 0.91772300E+01, -.15309800E+02, -.60223500E+01, 0.56451900E+01, -.41056700E+01, -.65381900E+01, 0.22277600E+01, 0.15715900E+01, 0.10812300E+01, 0.75588900E+01, 0.61484500E+01, 0.10759500E+02, 0.12539200E+02, 0.10938500E+02, 0.14351800E+01, 0.76902500E+01, -.14880800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25028200E+01, 0.11969800E+01, -.96542800E-01, -.14576900E+01, -.22975700E+01, 0.24886100E+01, -.20171700E+01, -.11105900E+01, -.18201200E+00, -.39212400E+00, -.14154500E+01, -.27981600E+01, -.11751800E+01, -.23635100E+01, 0.93639600E+00, -.10891600E+01, -.61987600E+00, -.46918700E+00, -.28738200E+00, -.83243800E+01, -.38248400E+00, -.24319800E+01, -.38953000E-01, 0.13826400E+01, -.12035300E+00, -.14420200E+01, 0.35170500E+00, 0.28730100E+01, 0.16020400E+01, -.63754500E+00, -.10299100E+01, -.70969000E-01, 0.99366200E+00, -.25557900E+00, -.14755300E+01, 0.16417100E+00, 0.10688100E+01, 0.29071800E+01, 0.58437100E+00, -.51608000E+01, 0.11154200E-01, -.23648300E+01, 0.14768500E+01, 0.51272000E+00, 0.89240300E+00, 0.68347100E-01, 0.33109700E+00, 0.18224800E+00, 0.12913300E+01, 0.45520900E+00, 0.44779600E+00, 0.11697000E+01, -.19988600E+01, 0.83457500E-01, -.34765800E+01, -.18053600E+01, -.29224500E+00, -.22438500E+01, -.29822600E+01, 0.21790800E+00, 0.47650100E+00, 0.50490200E+00, 0.71686200E-01, 0.32556500E+00, -.90486300E+00, 0.16651300E+00, 0.28569200E+00, -.71949300E+00, -.60592700E-03, 0.43000500E+01, -.21366900E+00, 0.76288200E+00, 0.10695700E+01, 0.61462300E+00, -.49762800E+00, 0.28730500E+00, 0.87605800E-01, -.12681200E+01, 0.72320300E+00, 0.36424100E+00, 0.27303500E+00, 0.12358900E+00, 0.94785500E-01, 0.21641200E+00, -.30578700E+00, 0.10539900E+00, -.20346900E+00, -.21429900E+01, -.22564800E+00, 0.51128300E+00, -.28130700E+00, 0.32968500E+00, 0.21441300E+00, -.69743200E+00, -.66190700E+00, 0.52166200E+00, -.10638700E+00, 0.91701700E+00, -.10666500E+00, 0.32693800E-01, 0.65771300E+00, -.32987500E+00, -.19818200E+01, 0.29632600E+00, -.34232900E+00, -.53522300E+00, 0.32434900E+00, 0.10250500E-01, 0.12548600E+01, 0.51683700E+00, -.20356700E+00, 0.84627200E+00, -.32520200E+00, 0.19298600E+00, -.26203700E+00, -.31691100E+00, -.10567600E+00, 0.14179700E+01, 0.63259300E-01, 0.82565000E+00, -.34925100E+00, -.71072100E+00, 0.26939200E-01, -.75728200E+00, -.31631600E+00, 0.14362500E+00, -.53814800E+00, 0.11473600E-01, -.38222600E-01, 0.54985000E-01, -.86047000E-01, 0.80558400E-02, 0.97070600E+00, 0.14149600E+03, -.40242500E+01, -.26752600E+03, 0.14627700E+03, 0.12886200E+03, -.12908100E+03, -.31150000E+02, 0.84173600E+02, -.39954600E+02, 0.10203800E+03, 0.44938700E+01, 0.79574900E+02, -.38523300E+02, -.39383900E+02, 0.16974800E+03, 0.38627700E+02, -.72808400E+02, -.14337800E+03, -.19792700E+02, -.11698600E+03, -.36278100E+03, 0.17977400E+03, 0.18317800E+03, 0.23520900E+03, 0.25565500E+03, -.24608600E+02, -.20884100E+03, -.36443500E+03, 0.23836700E+03, 0.34682200E+03, -.16230000E+03, -.16916900E+03, 0.31878800E+03, 0.37473300E+02, -.19079300E+03, -.23732700E+03, -.20480500E+03, -.64590500E+02, -.14424100E+03, 0.35359300E+02, 0.10757600E+03, -.71635000E+02, -.10989000E+03, 0.13883100E+03, 0.14732200E+03, 0.21316000E+03, -.16469500E+03, 0.26262400E+03, -.13014100E+03, -.12509000E+03, -.61716600E+02, -.10635600E+03, -.67533700E+02, -.14873200E+02, -.63020700E+02, -.13921300E+03, 0.48248100E+03, -.24076600E+03, -.24178500E+03, -.12416300E+03, -.10690100E+03, -.83131300E+02, 0.91199800E+02, 0.14057600E+03, -.13714300E+03, 0.54975500E+03, -.28430900E+03, -.27006600E+03, -.14829700E+02, -.59367000E+02, -.15511500E+03, 0.49281400E+02, -.10182600E+03, -.70994800E+02, -.12012800E+02, -.26848400E+02, -.44850000E+01, 0.49784800E+01, -.11131200E+03, -.20966600E+02, 0.27512800E+01, -.12100900E+02, 0.32308400E+02, 0.96988300E+01, 0.27839300E+02, 0.96799700E+00, 0.22618000E+01, 0.21172400E+02, 0.20713100E+02, -.13366200E+02, 0.64228700E+02, -.29178700E+02, 0.43449200E+02, -.50847300E+02, 0.11395900E+03, -.14977900E+02, 0.69026000E+01, 0.14899800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19870500E+01, 0.15117400E+01, 0.65236900E+00, -.51955400E+01, -.63587400E+00, 0.39021900E+01, -.56363800E+01, -.13474100E+01, 0.13621000E+01, -.16944900E+01, -.11373200E+00, 0.56108900E+00, -.85205800E+00, 0.79815800E+00, -.85058700E+00, 0.25895600E+01, 0.21887400E+01, 0.89328200E+00, 0.21318400E+01, -.32201200E+00, 0.34096900E+00, -.43893900E+00, 0.94485900E+00, -.55541000E+00, 0.17224600E+01, -.28279900E+01, -.39587600E+00, 0.25332300E+01, 0.99971600E+00, -.88725100E+00, -.15975100E+01, 0.13605300E+00, 0.12404900E+00, -.20433400E+00, -.11826800E+01, 0.43653500E+00, 0.44107000E+00, -.18600200E+01, -.75534700E-01, -.41979600E+01, -.15841100E+00, 0.26038800E+00, -.16709400E+01, 0.99329700E+00, -.86252100E+00, 0.58656200E+00, 0.13073600E+00, 0.44019100E+00, -.40879800E+00, 0.23754600E+00, 0.14722700E+00, -.17906300E+00, 0.56942300E+00, 0.33520700E+00, 0.73374000E+00, 0.27452400E+00, 0.40419500E-01, -.70322600E+00, -.27461600E+01, 0.20729200E+01, 0.30932900E+00, -.91287900E-01, -.89764300E-01, 0.60559500E+00, -.19105700E+00, 0.22470500E+00, -.57804400E+00, 0.41271900E+00, 0.23576500E+00, -.14260200E+00, -.76762600E-02, 0.38582600E+00, -.59314100E+00, -.42026300E+00, 0.47953500E+00, -.28043000E+00, -.92341400E+00, -.11080900E+01, 0.42332300E-01, -.42350500E+01, 0.51984900E+00, 0.54831800E+00, 0.14124600E-01, -.29612800E+00, 0.90584600E-01, -.26292700E+00, -.25209500E+00, 0.37077000E+01, 0.51001800E+00, 0.45741400E+00, 0.26474100E+00, 0.18141800E+00, -.18269400E+00, -.14420400E+01, -.29284600E+00, 0.31889000E+00, 0.34710900E-01, 0.57214800E+00, -.67917100E-01, -.31398800E-01, -.22796000E+00, 0.89373300E+00, 0.69560400E+00, -.48304400E+00, -.37489200E-01, 0.62989600E+00, -.40640300E+00, -.38989100E-01, 0.74270500E+00, 0.44235100E-01, -.75268100E-02, -.52997300E+00, -.48189100E+00, -.44488300E-01, -.38849700E-01, 0.58788700E+00, 0.11733900E+00, 0.54609700E-01, -.15405100E+00, -.33644400E+00, 0.17791800E+00, 0.57161000E+00, -.52574300E+00, 0.45664300E+00, -.39058000E-01, 0.67868500E-01, 0.26356000E+00, -.32705500E-02, -.30729700E+00, -.42395300E+00, -.24244800E-01, -.14002400E+00, -.10785400E+01, -.19164100E+00, 0.97571600E+01, -.17568700E+03, 0.79933800E+02, 0.86269900E+02, 0.69761800E+01, 0.28972600E+02, 0.45715800E+02, -.25215400E+02, -.20692000E+02, 0.50247300E+02, -.29229100E+03, 0.15710200E+03, 0.14621200E+03, -.57638500E+02, -.30052000E+02, 0.12079400E+03, 0.86167300E+02, 0.13625700E+03, 0.23311100E+02, 0.45316300E+02, -.22644000E+02, -.24449700E+02, 0.96009200E+02, 0.97264600E+02, -.60403400E+02, 0.40438000E+02, -.13132100E+03, 0.69053000E+02, -.10073500E+03, 0.62510200E+02, 0.49726600E+02, 0.14383700E+02, -.74964200E+01, 0.34852600E+02, 0.22429500E+02, 0.25842200E+02, -.13365700E+02, 0.25526700E+03, -.10562400E+03, -.12404200E+03, -.32817600E+02, -.55970600E+02, -.61129900E+02, 0.19148500E+01, -.52894700E+02, -.42367400E+02, 0.26358500E+02, -.13468900E+02, -.97538900E+01, -.73021700E+01, -.14634500E+02, 0.98641400E+01, -.63667700E+01, -.32999400E+02, -.43859100E+02, 0.20927700E+03, -.10529200E+03, -.10058200E+03, -.96619600E+02, -.12909800E+03, -.95834000E+01, -.22220900E+02, 0.11494100E+03, -.91461500E+02, -.11789100E+03, 0.65687400E+02, 0.67633700E+02, 0.26936000E+00, 0.35356000E+01, 0.31911800E+02, 0.30091700E+01, 0.13214800E+02, -.80620800E+01, -.15152500E+02, 0.17155900E+02, -.23878900E+01, -.13550500E+01, 0.47631700E+01, -.13953500E+02, 0.47806500E+01, -.94725600E+00, 0.13156300E+02, -.68982700E+00, -.64081500E+01, 0.34851300E+01, -.26011300E+01, 0.32039600E+01, 0.11662300E+02, 0.73570700E+01, 0.63059000E+01, -.63925100E+01, 0.76557100E+02, -.90667000E+01, -.19301800E+00, -.36893100E+01, 0.37847900E+02, -.13572100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21608800E+01, -.37865800E+01, -.17562200E+01, 0.48015000E+01, 0.25776200E+00, -.39055600E+01, 0.57354800E+01, 0.13961600E+01, -.51943500E+00, 0.22311000E+01, -.20057300E+00, -.86354000E+00, 0.74254800E+00, -.74091600E+00, 0.66179400E+00, -.32039700E+01, -.25516900E+01, -.43149900E+00, -.37973900E+01, -.77345100E+00, -.14201500E+01, 0.38767900E-01, -.14163500E+01, 0.75777700E+00, -.20324400E+01, 0.49262600E+01, -.82804200E+00, -.34035800E+01, 0.32142600E+00, 0.14315800E+01, 0.11750300E+01, -.11830300E+01, 0.30639800E-01, 0.94165800E-01, -.46629200E-01, -.29122000E+00, 0.41627700E+01, 0.24694000E+01, 0.67489100E+00, 0.27868600E+01, 0.46596500E+00, -.16888500E+01, 0.42690300E+01, -.10485500E+01, 0.17062200E+01, -.91445400E+00, -.13446700E+00, -.96191600E+00, -.12685200E+00, -.14891100E+01, 0.37450400E+00, 0.61648100E+00, -.43573800E+00, -.16664300E+01, 0.11563300E+01, 0.10574400E+01, -.77520500E-01, -.25999000E+01, 0.10077300E+01, -.27458700E+01, -.10570900E+00, -.19169000E-01, 0.16745600E+00, -.36640900E+00, 0.26130600E+00, -.53985700E+00, -.30527700E+00, -.27806400E+00, -.20380900E+00, 0.19146000E+01, 0.40756600E+00, -.88589200E+00, -.23524100E+01, -.14680800E+01, -.20605400E+00, 0.75234000E-01, -.41959700E+00, -.89325200E+00, 0.44018800E+00, -.11304500E+01, -.54691800E+00, 0.50806100E+00, -.91332800E-01, -.21677700E+00, -.57514900E-01, 0.46439100E+00, 0.37829900E+00, -.14740100E+01, -.26848300E-01, -.62584800E+00, 0.10292900E+00, -.30157900E+00, 0.14687000E+00, 0.46814000E+00, 0.14897400E+00, 0.60694700E+00, -.11456300E+00, -.13447400E+00, 0.53167600E-01, -.77080700E+00, 0.60036200E+00, -.18243200E+01, -.14768200E+01, 0.66198400E-01, -.21261300E-01, 0.25467800E+00, 0.70017700E+00, -.21551300E-01, 0.82134800E-01, 0.27431400E+00, 0.29235200E+00, 0.20938800E+00, 0.78018800E+00, -.86661200E+00, -.47899800E+00, 0.84295100E+00, 0.29131400E+00, -.34152500E+00, -.16019600E+00, 0.75399600E-01, 0.12621700E+00, -.35955600E+00, 0.15329000E+00, 0.22352100E+00, 0.95769000E+00, -.45609300E+00, 0.92660200E-01, 0.12948000E-01, -.28436000E+00, 0.37273200E+00, 0.10355400E+00, -.44564900E+00, 0.17716900E+00, 0.32784300E+00, 0.10360400E+01, 0.43634300E+03, -.21327700E+03, -.22826300E+03, -.19753100E+02, -.28368700E+02, -.10302500E+03, 0.10985600E+03, -.10484300E+03, -.11426600E+03, 0.48919800E+03, -.25901800E+03, -.24357400E+03, 0.10667200E+02, 0.39552800E+02, -.17678500E+03, -.52873800E+02, -.22275100E+03, 0.33436900E+02, 0.13736500E+02, -.70545700E+01, 0.28586000E+01, -.19031400E+03, -.22232100E+03, 0.12600700E+03, 0.51533300E+02, 0.36630400E+03, -.18506600E+03, 0.41191700E+03, -.22801300E+03, -.18559800E+03, -.16118300E+03, 0.57987400E+02, -.15748800E+03, -.41718000E+02, -.18311100E+03, 0.12114700E+03, 0.76640900E+02, -.42545500E+02, 0.25253900E+02, 0.64862500E+01, 0.88837200E+02, -.63556100E+02, -.45767200E+02, -.10063600E+03, 0.45318500E+02, -.48230300E+03, 0.24014900E+03, 0.24718900E+03, 0.14350900E+02, 0.12759100E+03, 0.12812300E+03, 0.50615500E+02, 0.15168400E+03, 0.14353800E+03, -.38235900E+03, 0.19228300E+03, 0.18182500E+03, 0.10997300E+03, 0.12164100E+03, 0.39983500E+02, 0.43311300E+02, -.14371400E+03, 0.11451400E+03, -.17920100E+03, 0.88888300E+02, 0.74089600E+02, 0.88149100E+01, -.11175100E+02, 0.62410500E+02, -.19911100E+02, 0.11535800E+03, 0.31133900E+02, 0.10189900E+02, -.35724100E+02, -.20161700E+01, -.63634100E+01, 0.37468300E+02, 0.30157900E+02, -.60582600E+00, -.80676600E+01, -.38261500E+02, 0.10054600E+02, 0.32738700E+01, 0.88891900E+01, 0.97483300E+01, -.12236400E+02, -.94015400E+01, 0.29712200E+01, -.42512600E+01, 0.25662100E+02, -.10040300E+03, 0.68366500E+02, -.43620100E+02, 0.35794900E+02, -.41385000E+02, 0.31201700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.45299000E+01, 0.34946400E+01, 0.16591100E+01, -.82242100E+01, -.11667000E+01, 0.74451300E+01, -.87937600E+01, -.25568000E+01, 0.67259400E+00, -.29378400E+01, 0.90314900E-01, 0.72108200E+00, -.98604600E+00, 0.17457600E+00, -.14622200E+01, 0.31922700E+01, 0.26206800E+01, -.25335000E+00, 0.43438600E+01, -.11979700E+01, 0.33235400E+00, -.11636200E+01, 0.19321000E+01, -.67338700E+00, 0.23207000E+01, -.34048900E+01, -.16551300E+01, 0.32876300E+01, -.14399000E+01, -.14778600E+01, -.81946400E+00, -.13730300E+01, -.92680200E-01, 0.19253300E+00, -.14235500E+01, 0.29445400E+00, -.22827700E+01, -.30808300E+01, -.39142300E+00, -.28428500E+01, -.64268500E+00, 0.14866800E+01, -.18542700E+01, 0.28822000E+01, 0.19961400E-01, 0.54043700E+00, 0.33480300E+00, 0.13155900E+01, -.13985600E+01, 0.26174200E+01, -.14647300E+00, -.12099900E+01, 0.93972900E+00, 0.91317200E+00, -.11759500E+01, -.23637800E+01, -.41251400E-01, 0.33709300E+00, -.91313000E+01, 0.76270600E+01, 0.11438600E+01, 0.72204500E+00, -.12784800E+00, 0.18868900E+01, -.92921900E+00, 0.50241000E+00, -.70242900E-01, 0.54406800E+00, 0.46971300E+00, -.72235800E+00, -.28491600E+00, 0.16180500E+01, 0.34877200E+01, -.85594600E-01, 0.13084500E+00, -.24968000E+00, 0.11124400E+01, 0.80006800E-01, -.11171800E+01, 0.18312300E+01, 0.11452700E+01, -.83566100E+00, 0.36014100E+00, -.22572000E+00, 0.11356600E+00, -.10338300E+01, 0.12404000E-01, 0.12809200E+01, 0.36211600E+00, -.22169200E+00, 0.15073000E+00, 0.55715400E+00, -.31273400E-01, 0.56833700E-01, 0.51037800E+00, 0.89653600E+00, 0.28452300E+00, -.12992800E+01, 0.17263100E+00, 0.73361100E+00, -.15694400E+01, -.15780700E+01, 0.34802900E+01, -.27264300E+00, -.91831300E+00, 0.45565700E+00, 0.33536600E+00, -.35383000E+00, -.28383100E+01, -.73637800E+00, -.16846100E+01, -.17424300E+01, 0.20439800E+01, -.21399900E+00, 0.14872400E+01, -.90719100E+00, -.88025200E+00, 0.87759200E+00, -.32806200E+00, -.45891800E+00, 0.10483900E+01, 0.18670300E+01, -.75947500E+00, 0.14030600E+01, 0.47459900E+00, -.25975500E+00, -.11745400E+01, 0.52159800E-01, 0.95602300E+00, 0.31037300E-01, 0.10814600E+01, 0.38291600E-01, -.95799500E+00, -.19608500E+01, -.11185900E+01, -.10939600E+01, -.84700100E+02, -.10965400E+02, -.43195800E+02, -.15450500E+03, 0.59406300E+02, 0.17920800E+03, 0.15162100E+03, -.10811600E+03, 0.18677500E+03, -.15326100E+03, -.92498100E+02, 0.44418700E+02, -.94673500E+02, -.73752500E+02, -.38882400E+02, -.59342700E+02, 0.94870300E+01, -.34532000E+03, 0.12620600E+03, 0.17748300E+03, -.12608400E+03, -.13908600E+03, 0.20145800E+03, 0.44307600E+02, 0.21667300E+03, -.86897100E+02, 0.70846900E+03, -.22813600E+03, -.34273700E+03, -.18216600E+01, 0.19581400E+03, -.29176900E+03, -.17363600E+03, -.33343900E+03, 0.28974100E+02, -.36672000E+02, 0.98787000E+02, 0.79512900E+02, 0.89054200E+02, 0.15216700E+03, -.86466900E+02, -.10853100E+03, -.13024100E+03, 0.16251500E+03, 0.11286500E+03, -.56767000E+02, -.45925700E+02, 0.49255300E+02, 0.21043000E+01, -.44526700E+02, 0.14345100E+02, 0.84884500E+02, 0.58538000E+02, -.40783900E+02, 0.60345500E+02, 0.18910800E+02, 0.19339700E+03, 0.13855500E+03, -.10081300E+03, -.72030000E+02, -.18509200E+03, 0.11521800E+03, -.29400800E+03, 0.13443100E+03, 0.14853700E+03, -.75339800E+02, -.96846400E+02, 0.12992900E+03, 0.19371100E+02, 0.28156000E+03, -.59690000E+02, 0.21179200E+02, -.46053900E+02, -.22381100E+02, 0.21352400E+02, -.92230000E+01, 0.24765900E+02, 0.11431400E+02, -.16115900E+02, 0.11922400E+02, 0.23270100E+02, -.27887000E+02, 0.15930800E+02, 0.17696100E+02, -.27489500E+02, 0.66770600E+01, 0.17289200E+02, -.37433800E+01, 0.80167300E+00, -.57203800E+02, 0.17946800E+01, -.45098300E+01, 0.23743700E+02, -.16726900E+02, 0.40098800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.15558000E+01, 0.16197300E+01, 0.58573500E+00, -.42302500E+01, 0.22683900E-01, 0.34200100E+01, -.31768600E+01, -.10383500E+01, 0.45191300E+00, -.10341600E+01, 0.13645700E+00, 0.16735400E+00, -.30551300E+00, 0.88296200E+00, -.66417500E+00, 0.26484800E+01, 0.98381900E+00, 0.25943800E-01, 0.96066500E+00, -.18001600E+01, -.62698800E+00, -.79749500E+00, 0.11260100E+01, 0.27992500E-01, 0.23794400E+00, 0.39777200E+00, -.14393200E+01, 0.10729500E+01, -.35847900E+00, -.30406900E+00, -.76007100E-01, -.11335400E+01, 0.19701800E+00, 0.19815000E+00, -.50679800E+00, 0.30975300E+00, 0.87433200E+00, -.39622500E+01, 0.23901000E+00, -.12270300E+01, -.31167700E+00, 0.58117600E-01, 0.47043100E+00, 0.16351900E+01, 0.48309100E+00, 0.11016500E+00, 0.62950100E-01, 0.46598700E+00, -.72082800E+00, 0.10009300E+01, 0.19662900E+00, 0.11186900E+01, 0.10907200E+01, -.10069100E+00, -.45775700E+00, -.52561100E+00, -.82999100E-01, 0.55480100E+00, -.18820600E+01, 0.11926600E+01, 0.26474300E+00, 0.29867900E+00, -.17626200E+00, 0.91706100E+00, 0.15392200E+00, -.37388700E+00, 0.52321900E-01, 0.40277300E+00, 0.51573700E-01, -.13073000E+01, 0.88401700E-01, 0.82164700E+00, -.94546000E+00, -.13823800E+01, 0.18801500E+00, -.12223800E+00, -.21104100E+00, -.18450200E+00, -.20915700E+00, -.21032000E+00, -.10702600E-01, 0.13594200E+00, -.96630200E-01, 0.70326100E-01, 0.10302300E+00, 0.20504700E+00, 0.52717700E+00, 0.87328100E+00, -.96317300E-03, 0.31669300E+00, -.18901700E+00, 0.15262100E+00, 0.10252100E-01, -.76337000E+00, -.31828700E+00, 0.55341200E-01, 0.50204400E-01, 0.24805500E+00, 0.11967000E-01, -.99938200E-01, 0.16928000E+00, -.11097600E+01, -.25813500E+00, -.16869700E+00, 0.90139500E-01, 0.73117600E-01, 0.12528700E+00, 0.93822800E-01, -.12633400E+00, -.20598500E+00, 0.31429400E+00, 0.14088200E-01, 0.48548300E+00, 0.74015200E-01, -.12132000E-01, 0.42141700E+00, -.18866700E+00, 0.46834200E+00, -.77801500E-01, -.32956900E+00, 0.82095900E-01, 0.19598800E+00, -.49434100E+00, 0.71880000E+00, 0.70937100E-01, 0.80305400E-01, -.10947800E+00, -.55492100E-02, -.72776100E-02, -.20956700E+00, -.31663500E-01, 0.88572900E-01, -.10249300E+01, -.17579100E+00, 0.26177000E+00, 0.16228100E+00, -.81284700E-01, 0.80301000E+01, 0.14138200E+01, 0.12669100E+02, -.30624900E+02, -.10218900E+03, -.34289800E+02, 0.43216700E+02, -.21981500E+03, 0.11137200E+03, 0.10920900E+03, -.71561900E+02, 0.33183800E+02, 0.10838600E+03, 0.12430400E+03, 0.11538400E+03, 0.25262300E+01, -.11058700E+03, 0.52609000E+02, 0.50995400E+02, 0.77829900E+02, 0.99568600E+02, -.15182200E+02, -.29580900E+02, -.12888900E+03, 0.73376000E+02, -.10809900E+02, 0.16211600E+02, -.64489500E+01, 0.65896900E+02, -.10081400E+02, 0.92555900E+01, -.87232500E+01, 0.45992800E+01, -.42908500E+02, -.60373000E+02, 0.31460200E+02, -.11032700E+02, -.77124200E+01, -.33465300E+02, 0.44865000E+02, 0.38690600E+02, 0.25121900E+02, -.10576100E+02, 0.17969700E+03, -.88371400E+02, -.97530400E+02, -.61530700E+01, -.45709200E+02, -.42937100E+02, -.12744400E+02, -.27998700E+02, -.48348000E+02, 0.14364600E+03, -.69610600E+02, -.70357200E+02, -.31194000E+02, -.81242700E+02, -.11502800E+02, -.13347600E+00, 0.62979700E+02, -.45000100E+02, 0.84888900E+02, -.36118400E+02, -.42696600E+02, -.15189000E+02, 0.28605500E+02, -.33975900E+02, -.59850400E+00, -.77990900E+02, -.14031300E+02, -.56330300E+01, 0.39395300E+02, -.67308800E+00, 0.64021100E+01, -.33996900E+01, -.11683200E+02, 0.52452700E+01, 0.20342200E+01, 0.17719200E+02, 0.27205800E+01, 0.97441400E+00, 0.17666600E+01, -.75111700E+01, 0.38739200E+01, 0.56974600E+01, 0.41658700E+01, 0.11006000E+02, -.19030700E+02, 0.31640900E+02, -.24472400E+02, 0.98540400E+01, -.91895800E+01, 0.11100800E+02, -.28896100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17874700E+01, 0.10984700E+01, 0.66331800E+00, -.28155500E+01, -.19727000E+00, 0.27237200E+01, -.22510200E+01, -.82840200E+00, 0.15315200E+01, -.74758100E+00, -.27126400E+00, -.48357300E+00, -.54088900E+00, -.16156800E+01, -.33634400E+00, 0.68049700E+00, 0.34547200E+00, 0.75344100E-01, 0.10071900E+01, -.35895500E+01, -.24008600E+00, -.14670200E+01, 0.20541800E+00, 0.29749300E+00, 0.83231500E+00, -.16915200E+01, -.10407300E+01, 0.22948300E+01, 0.47372600E-01, -.79144900E+00, -.64954600E+00, -.89421000E+00, 0.12413200E+00, 0.14271400E+00, -.91192000E+00, 0.40046900E+00, 0.23577400E+00, -.22444500E+01, 0.58527000E+00, -.20029900E+01, -.16706900E+00, -.20748000E+00, -.26431500E+00, 0.18976300E+01, -.20836500E-01, 0.54461600E+00, 0.17312400E+00, 0.25224100E+00, -.76766900E+00, 0.84094900E+00, 0.26590100E+00, 0.82970600E+00, 0.10883900E+01, 0.41465000E+00, -.35262500E+00, -.25173000E-01, -.60179400E-01, -.44821600E+00, -.90337300E+00, 0.14548200E+01, 0.25459900E+00, -.15736400E+00, -.66224800E-01, 0.32535100E+00, 0.24863200E-01, 0.25113000E+00, -.32849300E+00, 0.46524500E+00, -.11510100E-01, 0.81494200E+00, -.26438700E+00, -.35423100E-01, -.11343800E+01, 0.59435800E-01, 0.30282500E+00, -.17856600E-01, -.47146100E+00, -.29279100E+00, 0.13213700E+00, -.61708200E+00, 0.14464300E+00, 0.10611700E+00, 0.22347300E-01, 0.67809800E-01, 0.81559200E-02, -.32380600E+00, -.15590000E+00, 0.87957600E+00, 0.20961200E+00, 0.30323200E-01, 0.57763400E-01, 0.92000800E-02, 0.14102800E-01, 0.35835000E+00, -.24134400E+00, -.22123900E+00, 0.89188000E-02, -.14406400E+00, -.40035000E-01, -.49143700E+00, -.18023100E+00, -.14220000E+01, 0.16666800E+00, -.15089800E+00, -.79736300E-01, 0.23077500E+00, 0.10041500E+00, -.98477900E-01, -.30903500E+00, -.56187600E-01, -.15491200E+00, -.33543300E+00, 0.32665500E+00, -.61190300E-01, 0.10003900E+00, 0.10607200E+00, 0.53800000E-01, 0.26545300E+00, 0.34062800E-01, -.10678400E-01, 0.10766700E+00, -.17595700E+00, 0.24320200E+00, 0.10426900E+00, 0.22751200E+00, -.25359200E+00, -.57678200E-01, 0.33231900E-01, -.39130700E-01, -.92320200E-01, -.41956600E-01, -.24334600E+00, -.11025300E+01, -.54901300E+00, -.14244200E+00, 0.21975700E+00, -.78159300E-01, 0.43083700E-01, -.11915400E+03, 0.12768000E+02, -.35248300E+02, -.14284000E+03, -.28315900E+02, 0.30593300E+02, -.81671800E+02, 0.44535300E+02, 0.40953700E+02, 0.11290300E+02, 0.35865200E+02, 0.22053100E+02, -.10568900E+02, 0.37337800E+02, -.29828900E+02, -.52193000E+03, 0.25316400E+03, 0.26000300E+03, 0.22875100E+03, 0.24712100E+03, 0.37017700E+02, -.18109300E+03, -.34811400E+03, 0.24270200E+03, 0.26434100E+03, -.98740100E+02, -.13471800E+03, 0.24771500E+03, 0.77995000E+02, -.15452500E+03, -.18696000E+03, -.16309600E+03, -.53591200E+02, -.98651800E+02, 0.38377900E+02, 0.57759900E+02, -.67136500E+02, -.14239200E+03, 0.13151400E+03, 0.16518000E+03, 0.20488000E+03, -.13249900E+03, 0.25782200E+03, -.12976800E+03, -.12659000E+03, -.45468100E+02, -.74414700E+02, -.71781700E+02, -.14690000E+02, -.16001000E+02, -.11660100E+03, 0.49475000E+03, -.24179400E+03, -.24629700E+03, -.83851800E+02, -.13819100E+03, -.10114200E+03, 0.62592600E+02, 0.12842300E+03, -.12426600E+03, 0.15781900E+03, -.92015800E+02, -.73419100E+02, -.49526700E+02, -.33958800E+02, -.46973700E+02, 0.20953700E+02, 0.39425300E+01, -.58841900E+02, -.78358700E+01, 0.42341400E+01, 0.22201800E+01, -.66045000E+00, -.74054600E+02, -.25558200E+02, 0.19746800E+01, 0.59379900E+01, 0.75723800E+01, -.20279800E+01, 0.11746600E+02, -.85187200E+01, -.15305200E+02, 0.17208400E+02, 0.14161500E+02, 0.52289600E+01, 0.68303100E+02, -.79725400E+01, 0.37693900E+02, -.43502600E+02, 0.81418700E+02, -.16812700E+02, -.41569500E+00, -.28165700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20315800E+01, -.29402200E+01, -.13945200E+01, 0.43195800E+01, 0.82090300E+00, -.39895700E+01, 0.43491700E+01, 0.11805900E+01, -.12167600E+01, 0.16948000E+01, -.25984400E+00, -.65548300E+00, 0.55773700E+00, -.36575200E+00, 0.60511400E+00, -.43679500E+01, -.20068400E+01, 0.95537300E+00, -.25265300E+01, 0.11864700E+01, 0.24374000E+00, 0.14555500E+01, -.10807600E+01, 0.14083800E+00, -.11101400E+01, 0.18186900E+01, 0.17574500E+01, -.26741800E+01, -.67172500E+00, 0.10430000E+01, 0.85570200E+00, 0.21378800E+01, 0.78881600E+00, -.19168000E+00, 0.16860900E+01, -.14884100E+01, 0.61342900E+00, 0.43597300E+01, -.22170200E+00, 0.12729600E+01, 0.66304300E+00, -.82241800E+00, -.22418400E+00, -.22588000E+01, -.39695800E+00, -.59843300E+00, -.43407800E+00, -.11832300E+01, 0.17464200E+01, -.15166400E+01, -.15744700E+00, -.10141700E+01, -.14126500E+01, -.10281900E+01, 0.20399600E+01, 0.74790000E+00, 0.15250900E+00, 0.20904400E+01, 0.30222200E+01, -.33595100E+01, -.59214100E+00, -.21808300E+00, 0.82435600E-01, -.61715600E+00, -.30320300E+00, -.26683900E+00, 0.13820000E+00, 0.21579000E+00, 0.10308000E+00, -.25173700E+01, 0.14509400E+00, -.75618200E-01, 0.74141100E-01, 0.81849800E-01, -.63374900E+00, 0.15173100E+00, 0.18810600E+00, -.35595900E+00, 0.22544000E+00, -.18269300E+01, 0.12025400E+00, 0.57747600E+00, 0.11690600E+00, -.22595800E+00, -.21653200E+00, -.42592700E+00, -.75076600E+00, 0.57425300E+00, 0.19215800E-01, -.38982400E+00, 0.22289400E+00, -.16528800E+00, -.63742300E-01, 0.87993400E+00, 0.50506900E+00, -.15686400E+00, -.59361100E-01, -.13723800E+01, 0.22921800E+00, -.34036400E+00, -.26692300E+00, 0.72431800E+00, 0.31483800E+00, 0.31208600E-01, -.29776900E+00, 0.73143600E+00, -.52400000E+00, -.49627900E+00, 0.61842000E+00, -.47379800E-01, -.36104400E+00, -.54688800E+00, 0.30750300E+00, -.48901600E-01, 0.15464700E-01, 0.10225000E+00, 0.15478500E+00, 0.10785400E+01, 0.11493600E+00, 0.96664100E+00, 0.48682200E+00, -.15491300E+00, 0.32251900E+00, -.18417000E+00, -.85150100E-02, -.11585300E+00, 0.93731400E-01, 0.38877000E-02, -.31676100E+00, 0.94367100E-01, 0.32743500E+00, -.14662900E+00, 0.28546400E+00, -.24518300E+00, -.36568100E+00, -.42205400E+00, 0.50980800E-01, -.14665500E+01, 0.10447500E+00, 0.81765300E+02, -.39118300E+02, -.11245200E+03, -.90581800E+02, 0.57451600E+02, -.28363900E+03, 0.14254400E+03, 0.14163000E+03, -.87164400E+02, 0.16980100E+02, 0.12722200E+03, 0.12505400E+03, 0.13335500E+03, 0.26995600E+02, -.22659400E+03, 0.11250900E+03, 0.11198100E+03, 0.10133400E+03, 0.11891200E+03, 0.20683500E+02, -.51399600E+02, -.20915200E+03, 0.11005600E+03, 0.14225000E+03, -.63602500E+02, -.72743200E+02, 0.12313500E+03, -.64365900E+01, -.82087400E+02, -.85321200E+02, -.97710200E+02, -.16885000E+02, 0.35778600E+03, -.17045700E+03, -.18314100E+03, -.64627800E+02, -.98237600E+02, -.70810800E+02, 0.17188700E+02, -.89708200E+02, -.65985900E+02, 0.11616500E+03, -.58840500E+02, -.58555400E+02, -.13969600E+02, -.20698000E+02, -.26915600E+02, -.26185700E+02, 0.25437300E+02, -.31896500E+02, 0.30607200E+03, -.15258400E+03, -.15095300E+03, -.56989000E+02, -.11016000E+03, -.59043900E+02, 0.23666500E+02, 0.11247700E+03, -.80960300E+02, 0.27956000E+02, -.11005600E+02, -.11824700E+02, -.41184400E+02, 0.17640600E+01, -.16720900E+02, 0.11218300E+02, -.75186600E+01, -.39596900E+02, -.15133100E+02, 0.26225200E+02, 0.95860600E+00, -.15927900E+01, 0.24219900E+02, -.20447100E+02, 0.16852200E+01, 0.18639800E+01, 0.94879300E+01, 0.54104300E+00, 0.14590800E+02, -.14171200E+01, -.98620900E+01, 0.15210900E+02, 0.10061000E+02, 0.37226200E+01, 0.18501800E+02, -.69105100E+01, 0.37308200E+02, -.11358900E+02, -.11824600E+02, -.39733800E+01, 0.11977800E+02, -.16714200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20695700E+01, -.12177300E+01, -.90852300E+00, 0.19662900E+01, 0.71626200E+00, -.29446200E+01, 0.24113400E+01, 0.87805200E+00, -.10414800E+01, 0.12272000E+01, 0.21050600E+00, 0.92379400E-01, 0.79318400E+00, 0.29346800E+01, 0.12326700E+00, -.53624500E+00, -.51441000E+00, 0.13262700E+01, -.15131600E+01, 0.37171000E+01, -.87455400E+00, 0.12340900E+01, -.13697700E+00, 0.27892400E+00, -.11299200E+01, 0.34551400E+01, 0.10946300E+01, -.30668500E+01, -.20969000E+00, 0.15638200E+01, 0.46374900E+00, 0.65173900E+00, -.42671500E-01, -.20049800E+00, 0.45655400E+00, -.56124400E+00, 0.17766800E+01, 0.26345800E+01, -.35977600E+00, 0.88786600E+00, 0.27396800E+00, -.68447700E+00, 0.18795000E+01, -.21880600E+01, 0.48984700E+00, -.57914900E+00, -.29232200E+00, -.70802000E+00, 0.60175400E+00, -.23512400E+01, -.10354300E+00, -.95496100E+00, -.10037100E+01, -.44629500E+00, 0.10441100E+01, 0.28188800E+00, 0.44439700E-01, 0.64282000E-01, 0.77891300E-01, -.14451200E+01, -.43403800E-01, 0.62092300E+00, 0.91058000E-01, -.86891600E-01, -.36297600E+00, -.54175500E+00, 0.39206400E+00, -.15369500E+00, 0.14960000E+00, -.64963900E+00, 0.26093700E+00, 0.99350800E+00, 0.20074100E+00, 0.60643600E+00, -.66621400E+00, 0.37682900E+00, 0.82167500E+00, -.12509600E+00, -.29535000E+00, 0.24111900E+00, 0.11467000E+00, -.10766100E+00, 0.55211400E-01, 0.19524400E+00, -.61218300E-01, -.88612500E-01, -.53603200E-02, -.13513400E+01, 0.14302000E-01, -.33110300E+00, -.79075200E-01, -.39172500E-01, 0.88602300E-01, -.10038600E+00, 0.24777400E+00, 0.35557100E+00, 0.21665000E-01, -.72407800E+00, 0.15275800E+00, -.28860100E+00, 0.40777400E-02, -.19474800E+01, 0.15314800E+00, 0.79637100E-02, -.49264100E+00, 0.43210600E+00, -.82719900E+00, 0.29654000E-01, 0.11211400E+00, 0.25010800E+00, -.59272600E-02, 0.28164800E+00, 0.43029100E+00, 0.38079400E+00, -.18160600E+00, -.55067300E+00, -.40081600E+00, 0.85339100E-01, -.33911800E-01, -.53035900E+00, -.13791000E+00, -.35780900E+00, -.19393900E+00, -.12564400E+00, 0.10761100E+00, 0.71755800E-02, 0.12705700E-01, 0.11378900E-01, -.30145400E+00, -.12382500E+00, -.27379100E+00, -.27809800E+00, 0.95440300E+00, 0.51795300E+00, 0.20601300E+00, 0.11224500E+00, 0.17353700E+00, -.83752000E+00, -.93850400E-01, 0.78793600E+00, -.35831600E+02, -.87210100E+02, -.42513600E+02, 0.25638200E+02, -.69890100E+01, 0.15800300E+02, 0.34074500E+01, 0.75501700E+01, 0.36649700E+02, -.23350800E+01, -.32634000E+02, -.35501200E+01, -.58862900E+01, 0.11863900E+03, -.53873900E+02, -.61271500E+02, 0.12870200E+02, 0.16111600E+02, -.60318300E+02, -.46667400E+02, -.68596200E+02, -.11697500E+01, -.15044300E+03, 0.63541500E+02, 0.78306300E+02, 0.23013500E+02, -.95292300E+01, 0.63274300E+02, 0.38167700E+02, 0.64476100E+02, -.41775100E+02, -.26421200E+03, 0.13955800E+03, 0.12204900E+03, 0.41552400E+02, 0.28480000E+02, 0.72305100E+02, 0.58923000E+02, 0.11409300E+03, 0.40630300E+02, -.89378300E+02, 0.44583800E+02, 0.46563100E+02, -.12188900E+02, -.15638100E+02, 0.51792700E+02, 0.44552400E+02, 0.34830400E+01, -.33359300E+02, -.10765400E+03, 0.48643900E+02, 0.58095600E+02, -.90875500E+01, -.31497600E+02, 0.54225800E+02, 0.47900400E+02, 0.11254000E+03, -.63901500E+01, 0.16036300E+03, -.81777300E+02, -.72846200E+02, 0.26368100E+02, 0.10143200E+02, -.49107400E+02, 0.36543000E+01, -.68657300E+02, 0.13949700E+01, -.19378400E+01, -.74831800E+01, -.20664300E+01, -.53443300E+01, -.15324200E+02, 0.39063100E+01, -.91892700E+00, 0.36164200E+01, 0.21792600E+01, 0.15891500E+00, -.84289000E+01, 0.28270500E+01, -.21413600E+00, 0.19942400E+01, 0.51399700E+01, 0.14752100E+01, 0.22697300E+01, -.44569600E+01, -.14647000E+02, -.20556700E+02, 0.10189100E+02, -.14762900E+01, -.10879700E+02, 0.49642700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.33312000E+01, -.66862300E+00, -.10355400E+01, 0.37753000E+01, 0.62742300E+00, -.44607800E+01, 0.35432600E+01, 0.12868100E+01, -.19334200E+01, 0.10641500E+01, 0.82050500E+00, 0.74211500E+00, 0.12322200E+01, 0.20906300E+01, 0.92533600E+00, -.80116300E+00, -.70480000E+00, -.16220800E+00, -.25963500E+01, 0.37054400E+01, -.49445500E-01, 0.16489200E+01, -.30203000E+00, 0.17440900E+00, -.16326800E+01, 0.32702900E+01, 0.13101500E+01, -.33598300E+01, -.14751100E+00, 0.12884800E+01, 0.10254800E+01, 0.89986000E+00, -.19864100E+00, -.19371900E+00, 0.89013500E+00, -.47674600E+00, 0.79528700E+00, 0.19089900E+01, -.41654500E+00, 0.36935500E+01, 0.26092800E+00, -.34054400E+00, 0.22264200E+01, -.28885300E+01, 0.67023300E+00, -.91904600E+00, -.23704800E+00, -.55301100E+00, 0.12971100E+01, -.12723700E+01, 0.18258900E+00, 0.46542600E+00, -.18263800E+01, -.98250100E+00, 0.19498700E+00, 0.31843900E+00, -.83529200E-01, -.24494900E+00, -.10843500E+01, -.16825300E+01, 0.69222700E-01, 0.42346900E+00, 0.63201100E-01, 0.24513700E+00, -.37050400E+00, -.79821800E+00, -.15722600E-01, -.59219600E+00, 0.10175000E+00, 0.13449700E+01, 0.62672900E+00, 0.82128900E+00, -.20112500E+01, 0.10196500E+00, -.29169500E+00, 0.42388200E+00, 0.16125000E+00, -.69953500E+00, 0.28063300E-01, -.45187300E+00, 0.14482300E-01, 0.33692100E-01, -.54614900E-01, 0.48664600E+00, -.53819900E-01, 0.10506200E+01, 0.15162500E-01, 0.34415400E+00, 0.67505100E-01, 0.32158800E+00, -.35080400E+00, 0.23825100E+00, -.10371700E+00, -.44948100E+00, 0.31945800E-01, -.92512300E+00, 0.56266400E-02, 0.37345300E+00, 0.11759600E+00, -.42923500E-01, 0.51811700E+00, 0.18166600E+01, -.11941900E+01, 0.33564100E+00, 0.50294900E+00, 0.71489300E-01, -.48150900E+00, 0.67555300E+00, 0.14268500E+01, -.18164500E+00, -.18664200E+00, 0.53859700E-01, -.20970000E+00, 0.39855800E+00, 0.53748200E-02, -.18455300E+00, -.16264600E+00, 0.49261200E+00, 0.10699700E-01, -.25572000E+00, 0.40507500E+00, 0.61356800E-01, 0.51703000E-01, 0.56090100E+00, 0.64486600E+00, 0.50685500E-01, 0.52383700E+00, -.28903200E-01, -.18166800E-01, 0.77677900E-01, -.31191500E+00, 0.11612600E+00, 0.58295800E+00, -.21852400E+00, -.36531000E+00, -.46810700E+00, 0.10691600E+00, -.79926400E+00, -.32077700E+00, -.11489100E+00, 0.56526800E+00, -.68082800E+02, -.64770100E+02, 0.12719900E+02, -.21250700E+03, 0.10473400E+03, 0.10630500E+03, -.23113000E+02, -.38678700E+02, 0.94774600E+02, 0.79485900E+02, 0.10566000E+03, -.50278600E+02, -.25975600E+03, 0.13107200E+03, 0.13150700E+03, 0.92344900E+02, 0.10552400E+03, 0.35423900E+02, -.21942100E+02, -.70276800E+02, 0.95745300E+02, 0.19047900E+02, -.90964700E+01, -.10746100E+02, 0.36557400E+02, -.47336600E+02, -.43551600E+01, -.37659700E+02, -.29014600E+02, -.27289000E+02, 0.60778100E+03, -.29397500E+03, -.29282100E+03, -.64591400E+02, -.86581000E+02, -.17525300E+03, -.73311400E+02, -.20712300E+03, -.48601200E+02, 0.41926600E+03, -.20909900E+03, -.21112800E+03, -.45790200E+00, -.62969700E+02, -.16188600E+03, -.11184900E+03, -.86415500E+02, 0.13646800E+02, 0.36009600E+03, -.18108800E+03, -.18365000E+03, -.61812000E+02, -.34354000E+02, -.80596200E+02, -.53664800E+01, -.31301500E+02, -.56084500E+02, -.17021500E+03, 0.94220000E+02, 0.78801400E+02, -.28104000E+02, -.14454300E+02, 0.46999300E+02, -.17755800E+02, 0.43830200E+02, -.21087300E+02, 0.85901000E+01, 0.37191500E+02, 0.35525200E+01, 0.12009300E+02, 0.45051600E+02, -.22623800E+02, -.58083000E+00, 0.32669700E+01, 0.89602900E+01, -.10372700E+02, 0.12364200E+02, -.12524200E+02, -.57217100E+01, -.74960000E+01, -.57742800E+01, -.85741600E+01, -.75315300E+00, -.11528000E+02, 0.50363200E+02, 0.72686800E+00, -.34153900E+02, -.11105100E+02, 0.17790700E+02, -.30495300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.34900900E+01, -.33270100E+00, 0.10404200E+01, -.17504700E+01, 0.74167200E-01, 0.34035200E+01, -.33845500E+01, -.12894000E+01, 0.15604200E+01, -.13232800E+01, -.57576000E+00, 0.32555300E+00, -.10781100E+01, -.13285200E+01, -.53941100E+00, -.27666900E+00, 0.63500700E+00, -.55307000E+00, 0.17462300E+01, -.68266500E+01, 0.11529900E+01, -.21430700E+01, 0.62402600E+00, 0.12075500E+01, 0.19665700E+01, -.46589400E+01, -.92509900E+00, 0.15639700E+01, -.12939400E+01, -.85348400E+00, -.10080200E+01, -.23993400E+00, 0.21178500E-01, -.71267600E-01, -.54824600E+00, -.41359500E+00, -.26963400E+01, 0.62502100E+01, -.55278900E+00, -.30052900E+01, -.45219200E+00, 0.85405700E+00, -.24272800E+01, 0.83516400E+00, -.43290100E+00, 0.96890200E+00, 0.27726900E-01, -.19928100E-01, 0.87771800E+00, 0.66788400E-01, -.26728900E-01, 0.22468500E+00, -.12130500E+01, -.10073500E+00, -.92614300E+00, -.64056200E+00, 0.94021000E-01, 0.65035300E+00, 0.23331300E+01, -.10193900E+01, -.84759600E-01, -.13675200E-01, -.23384500E-01, -.95239600E-01, 0.33936400E-01, 0.90056000E+00, 0.82681900E+00, 0.14122500E+01, -.64614000E-01, -.13369800E-01, -.66059900E+00, -.32839000E+00, 0.26889100E+01, 0.11624600E+01, -.44960200E+00, -.43380700E+00, -.54088400E+00, 0.22914300E-01, 0.24413200E+00, -.21095000E+01, 0.36756200E+00, -.21663200E+00, 0.10635300E+00, -.26155200E+00, -.12162400E+00, -.37769700E+00, -.90023900E+00, -.14704100E+01, 0.37136600E-01, -.93618400E+00, 0.15802800E+00, -.36997300E+00, -.18427100E-01, 0.52438900E+00, -.83750400E-01, 0.89875600E+00, -.24982400E+00, 0.31729300E+00, -.10352800E+00, 0.12371200E+00, -.10419900E+00, 0.15676200E+01, 0.67063800E+00, -.24876100E+00, -.31356400E-01, 0.32234500E+00, -.18103300E+00, -.85794400E-01, 0.69981700E-01, 0.17329500E+00, 0.10888500E+01, -.25951000E+00, -.40923100E+00, -.27846200E+00, -.33164100E+00, 0.12954300E+01, 0.36185300E+00, -.85658900E+00, 0.13608300E-01, -.10131500E+00, 0.25042600E+00, 0.20321200E+00, -.94032800E-01, 0.63419600E-01, -.13745900E+00, 0.24510000E+00, 0.81588000E+00, 0.66212600E-02, -.59907400E+00, -.42042900E+00, -.19424500E+00, -.42545900E-01, -.11418000E+00, 0.97809100E-01, 0.22970500E+00, -.18225600E+00, 0.86245700E-01, -.18829000E+00, -.64188800E+00, 0.40265700E+00, 0.84854900E-01, -.26306200E+00, -.95985100E+02, -.80445400E+01, -.13649400E+02, 0.60887700E+01, 0.66945400E+01, 0.11285900E+02, -.40598700E+02, 0.32287800E+01, -.12141100E+02, -.29317900E+01, -.21014300E+02, -.13184300E+01, 0.76956500E+00, 0.84892000E-01, -.33145000E+01, -.62556200E+02, 0.20694200E+02, 0.22817500E+02, 0.10836000E+03, -.22269400E+02, 0.24619000E+01, -.38279300E+01, -.56809600E+01, -.49990600E+02, -.96990100E+01, 0.11623200E+02, 0.16643600E+02, 0.25514400E+02, 0.14028900E+02, 0.64019200E+02, -.33652900E+02, -.23443400E+02, 0.86275600E+01, 0.21412300E+02, -.39947200E+02, -.32706700E+02, -.44783600E+02, 0.22900800E+02, 0.14816300E+03, -.75171100E+02, -.71453400E+02, 0.22290100E+02, -.10362400E+02, -.63072700E+02, -.36667300E+02, -.48006800E+02, 0.21968600E+02, -.13220600E+02, 0.64303200E+01, 0.78700500E+01, -.20160000E+02, 0.64898100E+02, 0.55744700E+01, 0.18051000E+02, -.23550700E+02, 0.10612600E+02, -.40768200E+03, 0.20176400E+03, 0.21321400E+03, -.21685700E+02, -.22554000E+02, 0.13327900E+03, -.97340000E+01, 0.12998400E+03, 0.43205800E+01, 0.66047800E+01, 0.11825500E+02, -.31811200E+00, -.30000700E+00, 0.15571700E+02, -.80563800E+01, -.15262300E+01, 0.45127600E+01, -.84788600E+01, -.74991100E+01, -.11243100E+02, -.48674700E+01, -.27731100E+01, -.17053700E+02, -.71977800E+01, -.59899200E+01, -.43041200E+01, 0.69459800E+01, -.18556400E+01, 0.84119300E+00, -.16889800E+02, -.37377000E+01, -.70657500E+01, -.10492300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20481500E+01, -.14367100E+01, -.89102300E+00, 0.50497200E+01, 0.98929300E-01, -.33596800E+01, 0.40071300E+01, 0.95823600E+00, -.21312700E+01, 0.16708200E+01, 0.25531800E+00, -.43753500E+00, 0.10415800E+01, -.16815400E+01, 0.55172000E+00, -.50533500E+01, -.28225200E+01, -.17522500E+00, -.28537400E+01, 0.82031600E+00, 0.65116300E-01, 0.13154000E+01, -.13558800E+01, -.31087200E+00, -.16001200E+01, 0.43468600E+01, 0.88687300E+00, -.29236900E+01, 0.56799800E+00, 0.10780200E+01, 0.12853200E+01, 0.24338300E+00, 0.23076100E+00, -.43847200E-01, 0.18494600E+01, 0.82272000E-01, 0.73686500E+00, -.17245700E+00, -.29949800E+00, 0.45341800E+00, 0.32779300E-01, 0.31671500E+00, 0.20754800E+00, -.12778700E+01, -.36643700E+00, -.66060800E+00, -.24292600E+00, -.41256100E+00, 0.60590000E-01, -.10550000E+01, -.14278700E+00, 0.11208100E+01, 0.49843500E+00, 0.67028000E+00, -.26438100E+00, 0.54454300E+00, -.91284500E-01, 0.58016800E+00, -.11409100E+00, -.36853100E+00, -.33945200E-01, 0.22211600E+00, -.97296700E-01, 0.29604400E+00, -.25742400E+00, -.33652600E+00, -.43656400E+00, 0.73116700E-01, 0.17234200E+00, -.92421600E+00, 0.36096200E+00, 0.69168200E+00, -.62209500E+00, 0.70059900E+00, 0.23471000E-01, 0.51407600E-01, -.20903000E+00, -.10931600E+00, -.80389400E+00, -.10703200E+01, 0.37180700E+00, -.26172000E+00, -.29947300E-01, 0.19745400E+00, 0.28636700E+00, 0.46438800E+00, -.31593300E+00, 0.32669300E+01, 0.64893900E+00, -.25015700E-01, 0.12350900E-01, 0.50402500E-01, -.49229100E-01, -.15520300E+01, 0.87649900E-01, 0.33435100E+00, -.16680200E-02, -.47393700E-01, 0.97304000E-01, 0.96417600E+00, -.32403300E+00, 0.17041200E+01, 0.16652500E+01, -.19225900E+00, -.13478100E-01, 0.19843100E+00, -.34778400E+00, 0.42889200E+00, 0.92965900E+00, 0.27436400E+00, 0.56521000E+00, 0.15416700E+00, -.43343600E+00, 0.50745300E+00, -.24034300E+00, -.35562500E+00, -.44560500E+00, 0.27840700E+00, 0.71963500E-02, -.21233600E+00, 0.65693000E-01, -.71328100E+00, -.61405000E+00, 0.12178000E+01, 0.77173000E+00, -.34873500E+00, 0.21733900E+00, 0.54028900E-02, 0.22907700E+00, -.19239000E+00, -.22177500E+00, -.42268500E-01, -.99944900E+00, -.34821600E-02, 0.22540500E+00, -.12975800E+00, -.28953800E-01, 0.42538700E+00, 0.34902900E+00, -.68459700E-01, -.69628600E+00, -.38679900E+00, -.10122200E+00, -.37295800E+02, 0.13245300E+03, -.65875100E+02, -.66332100E+02, 0.33631200E+02, 0.56081200E+01, -.50841700E+02, -.48430900E+02, -.70660700E+02, -.59847800E+02, 0.75380400E+02, -.31158700E+02, -.37270500E+02, -.55442800E+02, -.10343100E+03, 0.12632700E+02, -.30862100E+02, 0.16104400E+03, -.76043600E+02, 0.11460400E+03, -.80746600E+02, -.51923900E+02, -.10967000E+02, -.32407400E+02, -.42691200E+02, -.28157300E+02, -.48178800E+02, 0.22359000E+02, -.10223600E+03, 0.55399000E+02, 0.42175400E+02, 0.43378400E+02, 0.65092900E+02, -.55804000E+01, -.15999800E+02, -.13583500E+02, 0.52956300E+02, -.52876500E+02, 0.25275600E+02, 0.25687800E+02, 0.28643600E+01, 0.20532000E+02, 0.17621300E+02, 0.33226400E+02, -.58544200E+02, 0.25023300E+02, -.20535800E+03, 0.96885500E+02, 0.10307400E+03, 0.44817700E+01, 0.77568600E+02, 0.57521800E+02, 0.79626100E+02, -.74822000E+01, 0.46445500E+02, -.39089300E+02, 0.14848800E+02, 0.17938500E+02, 0.93548700E+01, -.22060200E+02, 0.19259900E+02, -.52288200E+01, 0.32716300E+02, 0.99258900E+01, 0.23477300E+02, -.22017300E+02, 0.75134500E+01, -.46295500E+01, 0.70433500E+01, 0.86071900E+01, -.11524600E+02, 0.10869200E+02, -.23341900E+02, -.11382100E+02, -.62936200E+01, -.11608800E+02, -.11468700E+01, -.20922900E+02, -.10074900E+02, -.16732700E+02, -.20588300E+02, 0.96173300E+01, -.59547100E+02, -.14767300E+01, -.13259000E+02, -.26938900E+01, -.37729500E+02, 0.14974100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.44403000E+01, -.28422500E+01, -.22679600E+01, 0.70589700E+01, 0.80285900E+00, -.74374400E+01, 0.92609100E+01, 0.24217700E+01, -.16024800E+01, 0.30982900E+01, 0.13139300E+00, -.50621000E+00, 0.12371400E+01, 0.30897200E+01, 0.12634700E+01, -.20493600E+01, -.25310700E+01, 0.75579200E+00, -.59975400E+01, -.73707500E+00, -.29232200E+01, 0.27375100E-02, -.66875400E+00, 0.22103900E+01, -.39911700E+01, 0.79571700E+01, 0.10831600E+01, -.51449400E+01, 0.36763000E+00, 0.38855100E+01, -.22987200E-01, -.13837000E+01, -.71642400E+00, -.29812600E+00, -.25986200E+00, -.75066000E+00, 0.53524900E+01, 0.84695300E+01, 0.33354200E+00, -.83038100E+00, 0.24316500E+00, -.55920400E+01, 0.81271500E+01, -.26044200E+01, 0.25371000E+01, -.22693800E+01, 0.63404900E-01, -.72654300E+00, 0.16529600E+01, -.13431500E+01, 0.11283200E+01, -.18146600E+01, -.29068600E+01, -.98868900E+00, 0.27868500E+00, 0.54370300E-01, -.11407900E+00, -.40154400E+01, -.12255200E+01, -.12447000E+01, 0.41549800E+00, 0.84701300E+00, 0.47795900E+00, -.26639100E+00, -.59256300E+00, -.36471900E+00, 0.64309800E+00, 0.10720500E+00, 0.95970400E-01, 0.58076000E+01, -.54163600E+00, -.61819700E+00, 0.34568100E+01, 0.14010700E+01, -.15156500E+01, 0.38269600E+00, 0.13717200E+01, -.82997800E+00, 0.27610300E+00, 0.59504600E+00, -.23941400E+00, -.22352200E+00, -.67801800E-01, 0.51149400E+00, -.21488000E+00, -.64463500E+00, 0.28114400E+00, -.41368300E+01, -.39746100E+00, 0.39187100E+00, -.84198400E-01, -.21250100E+00, 0.30649100E+00, -.16133500E+00, -.23928200E+00, 0.54936500E+00, -.85689200E-01, -.23636600E+01, 0.44198500E+00, -.87958400E+00, -.51241000E+00, -.59785900E+01, -.37687100E+00, 0.17053700E+00, -.76643300E+00, 0.49310200E+00, -.10908400E+01, 0.23976800E+00, -.18094900E+01, -.37896000E+00, -.21166100E+00, -.21913500E+00, 0.97383700E+00, 0.64085400E+00, 0.65235800E+00, -.63918000E+00, -.64727700E+00, 0.10224500E+00, -.11797300E-03, -.74804200E+00, -.44050300E+00, -.39615000E+00, -.23166800E+00, 0.34522600E+00, 0.38097200E+00, -.44756400E+00, -.90666700E+00, 0.34661500E-01, -.24701300E+00, -.61956800E+00, 0.20706400E+00, -.38254800E+00, -.12076800E+01, -.59429100E+00, 0.10110500E+01, 0.47684300E+00, -.12212000E+00, -.75100100E+00, 0.13115800E+01, -.42295800E+00, 0.43204300E+00, -.11170000E+01, -.64763300E+00, 0.34176500E+00, -.48056800E+03, 0.23160000E+03, 0.24032100E+03, -.10205500E+03, -.61309700E+02, 0.22160900E+03, 0.23426900E+03, 0.23347600E+03, -.39667100E+02, -.25842200E+03, 0.12115700E+03, 0.12697600E+03, 0.33748600E+02, 0.53182300E+02, 0.74474300E+02, 0.19158200E+02, -.11069900E+03, 0.74578700E+02, 0.24132400E+03, -.92574400E+02, -.12858700E+03, 0.12731000E+03, -.46671700E+02, -.10380300E+03, -.10128900E+03, -.12758800E+03, -.70278800E+01, 0.48695500E+03, -.24468800E+03, -.24880900E+03, -.50992800E+02, -.37800100E+02, -.14358600E+03, -.96251200E+02, -.26576800E+03, -.16587100E+02, 0.47140400E+03, -.23593200E+03, -.23650400E+03, 0.22286600E+02, -.67197500E+02, -.16613200E+03, -.11180800E+03, 0.11595100E+02, -.12444700E+02, 0.30001600E+03, -.14344900E+03, -.14846100E+03, 0.13790200E+02, 0.11783900E+02, -.10378600E+03, -.65357800E+02, -.40392700E+02, -.23985600E+02, -.41724400E+03, 0.21859300E+03, 0.21681500E+03, -.10385200E+03, -.52024800E+02, 0.14405000E+03, 0.20776900E+02, 0.14895900E+03, -.75733800E+02, -.50210700E+01, 0.37483400E+02, -.68031000E+01, 0.15938700E+02, 0.36421700E+02, -.24632800E+02, 0.47525400E+01, -.42147100E+01, 0.19004700E+02, 0.63861000E+01, 0.75070400E+01, 0.16506400E+01, -.58128100E+01, -.90712800E+01, 0.43327200E+01, 0.58493000E+01, 0.10645100E+01, -.18770000E+02, 0.44766900E+02, -.28512300E+02, -.23635800E+02, -.83298100E+01, 0.26010200E+02, -.23112700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.82166700E+01, 0.73199700E+01, 0.41332400E+01, -.10301900E+02, 0.10978000E+01, 0.85445800E+01, -.10017900E+02, -.32795600E+01, 0.47545700E+01, -.28590000E+01, -.49420800E+00, -.23386900E+00, -.15567800E+01, -.42341500E+01, -.78070400E+00, 0.28402500E+01, 0.15123500E+01, 0.14091800E+00, 0.43319300E+01, -.54936600E+01, -.65887400E+00, -.32717100E+01, 0.16291900E+01, 0.40616400E-01, 0.22618800E+01, -.42682200E+01, -.37043600E+01, 0.72674400E+01, -.19048600E-01, -.24348700E+01, -.22782500E+01, -.21578600E+01, 0.40998400E+00, 0.26503000E+00, -.30279100E+01, 0.14392600E+01, 0.35638700E+00, -.93972300E+01, 0.65848700E+00, -.78623900E+01, -.68876800E+00, 0.11439100E+01, -.29975200E+01, 0.57240200E+01, -.99946500E+00, 0.19206000E+01, 0.72281400E+00, 0.14114400E+01, 0.20650100E+00, 0.19534200E+01, 0.80968600E+00, 0.41101900E+01, 0.28454900E+00, 0.23496200E+01, -.41867500E+01, 0.37487400E+00, -.19312200E+00, -.14844400E+01, -.50532000E+01, 0.47983300E+01, 0.11661800E+01, 0.48863200E+00, -.26034300E+00, 0.18123300E+01, 0.12065900E+00, 0.34188300E+00, 0.28608300E+00, 0.22739400E+01, 0.14626900E+00, 0.40299300E+01, -.89089700E+00, 0.11978100E+01, -.21471200E+01, 0.15845700E+01, 0.71003400E+00, 0.13120700E+00, -.11248300E+01, -.30480000E+00, -.24955800E+00, -.11539100E+01, 0.77626300E+00, -.75380400E+00, 0.14344400E+00, 0.11506200E+01, 0.31390100E+00, 0.25089700E+00, -.12851800E+01, 0.71743800E+01, 0.21008900E+01, 0.82018100E+00, 0.36241700E+00, 0.21563900E+00, -.17199400E+00, -.14865400E+01, -.14357700E+01, -.89431700E+00, -.12927800E+00, 0.63654500E+00, -.13618900E+00, -.15809500E+01, 0.15781300E+01, 0.32909200E+01, 0.52879600E+00, -.11515700E+01, 0.14829500E+01, 0.12776900E+00, 0.51899300E+00, 0.12680700E+01, 0.58239600E+00, 0.62539100E+00, 0.18150900E+01, 0.17687700E+01, -.29556300E+00, -.11052900E+01, -.94396400E+00, 0.25224900E+01, 0.64857100E+00, -.22867800E+01, 0.35628100E-01, -.23605900E+00, 0.76928300E-01, -.12373300E+01, 0.12161700E+00, 0.85151400E+00, 0.46330400E+00, -.44349100E+00, 0.13848100E+01, -.28303500E+00, -.21499100E+00, 0.12576600E+00, -.10221000E+01, -.47014300E+00, -.18976500E+00, 0.12543600E+01, 0.13332000E+01, 0.16217000E+01, -.19634100E+00, 0.10728100E+01, -.61832200E+00, 0.12833600E+00, 0.75886500E+00, 0.51676900E-01, -.58064100E+00, 0.74712800E+00, -.49378100E+00, -.64411400E+02, 0.36725100E+00, 0.26461400E+02, -.91348700E+02, 0.11740800E+02, 0.72253300E+02, 0.38909300E+02, -.52515900E+02, -.33328800E+03, 0.15567800E+03, 0.16778500E+03, -.35267500E+02, 0.17204700E+02, 0.12281200E+03, 0.52130700E+02, 0.42889900E+02, 0.65526700E+02, -.28626600E+03, 0.18827300E+03, 0.13586300E+03, 0.30851900E+02, -.80914000E+01, 0.10985300E+03, 0.34330100E+02, 0.12850700E+03, -.88800100E+01, 0.15876500E+03, -.10176200E+03, -.59225100E+02, -.40439400E+02, -.75499000E+02, -.29800500E+02, -.41422300E+02, 0.22917800E+02, -.48381200E+02, 0.68491900E+03, -.34371000E+03, -.33997100E+03, 0.29665200E+02, -.93530700E+02, -.29223900E+03, -.18434400E+03, -.17422000E+02, -.10587600E+02, 0.39598300E+03, -.19186400E+03, -.20101800E+03, 0.13058900E+03, 0.16401500E+03, -.21260400E+03, -.19669300E+03, -.41659800E+03, 0.58440800E+02, -.47398400E+03, 0.17113200E+03, 0.24342700E+03, -.76548700E+02, -.78766300E+02, 0.15122800E+03, -.26943200E+01, 0.30622300E+03, -.41116400E+02, 0.30378800E+01, -.28440700E+01, -.49772100E+01, 0.15855900E+02, 0.21689900E+02, -.17241400E+02, 0.39701000E+01, -.60991800E+01, 0.14232900E+01, -.53997600E+00, 0.14436500E+02, -.81505900E+01, -.50139700E-01, 0.16018800E+01, -.12540600E+02, 0.83569900E+01, 0.86549000E+01, 0.52105100E+01, 0.32037900E+02, -.80016200E+01, -.17012600E+02, -.20329200E+02, 0.33464500E+02, 0.84290600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21741000E+01, 0.53177000E+00, 0.78772200E+00, 0.16834100E+01, 0.86633700E+00, -.16020900E+01, -.82375100E+00, -.41849300E+00, 0.11052500E+01, -.18527800E+00, -.61185500E+00, -.83812800E+00, -.67894800E+00, -.23609600E+01, -.12761100E+00, -.25423900E+01, -.63335000E+00, 0.13101200E+01, -.84873600E+00, -.43413200E+01, 0.68683700E+00, -.61818000E+00, 0.39305000E-01, 0.12385200E+01, 0.10107700E+01, -.35152900E+01, -.17166000E+00, 0.11862300E+01, 0.97422600E+00, -.94257300E+00, -.39828000E+00, 0.14894400E+00, 0.38880000E-01, -.93745200E-01, -.50510200E+00, -.67825700E-01, -.40276500E+00, 0.22787900E+01, -.96347600E-01, -.66212500E+00, 0.17075900E-01, -.16598600E+00, -.21169400E+00, -.11393800E+00, -.13227100E-01, 0.11288900E+00, 0.99494500E-01, 0.22048200E+00, 0.79848100E+00, 0.22470800E+00, -.27789100E-01, -.71162800E-01, -.10232400E+01, -.63294100E-01, -.72824800E+00, -.10569300E+00, 0.66477000E-01, -.18598400E+00, -.11247000E+01, -.26605700E+00, 0.11237900E+00, 0.22142200E+00, -.28502100E-01, 0.80555000E-01, -.11109600E+00, 0.25252000E+00, 0.34946600E+00, 0.72740600E+00, 0.76180700E-01, 0.13040900E+01, -.30477900E+00, 0.34623600E+00, 0.69792700E+00, 0.79346900E+00, -.37133900E+00, 0.38089100E-01, -.38033300E+00, -.45722600E+00, 0.25499900E+00, -.16568700E+01, 0.54977000E-01, -.17923400E-01, -.27305200E-01, 0.70140100E-01, -.54973500E-01, 0.23255800E+00, -.73908000E+00, 0.82907900E+00, 0.31516200E+00, -.42830200E+00, 0.91328800E-01, -.23697100E+00, 0.31325800E-01, 0.42732100E+00, -.49525600E+00, -.10174800E+00, -.15856500E+00, 0.48263100E+00, -.11667900E+00, -.44078500E+00, 0.14457300E+00, -.16598000E+01, -.38504000E+00, 0.26156700E-01, -.58250200E-01, -.21801200E-01, -.40095500E+00, -.90535200E-01, 0.23426200E+00, 0.70204600E-01, 0.17275700E+00, -.52010400E-01, 0.48308400E-01, 0.17818200E+00, -.14092200E+00, 0.31693100E-01, 0.88087500E-01, -.48712600E+00, 0.53733200E-01, -.20812400E+00, -.36703200E-01, -.66637300E-01, 0.25045700E-01, 0.21982000E+00, 0.88350100E-01, 0.14221300E-01, 0.56048100E+00, 0.12967200E-01, -.29616800E-01, -.73804000E-01, -.29994100E+00, 0.10367100E+00, -.57468000E-01, -.26384100E+00, 0.22208700E-01, -.28500300E+00, -.32619300E-01, -.34058400E+00, 0.79304900E-02, 0.14983900E+00, -.39754700E+00, 0.97063900E-01, 0.23867600E+00, 0.50505800E-02, -.62493900E-01, -.44910800E-02, 0.24918700E+01, -.13845300E+02, 0.34337500E+02, -.42762500E+00, -.67240400E+01, -.26148000E+02, 0.14812000E+02, 0.29032400E+02, -.14834200E+02, -.14541800E+02, 0.15741700E+02, 0.12648200E+02, -.17856800E+02, -.20925200E+02, -.38739000E+02, -.12369400E+02, 0.65701300E+02, -.33634300E+02, -.30445000E+02, 0.70870600E+01, -.55503500E+01, -.27535500E+02, -.18095100E+02, -.37532500E+02, 0.27081000E+01, 0.23133300E+02, -.10705000E+02, -.10397400E+02, -.19883700E+02, -.35557400E+01, 0.94252000E+01, 0.29274500E+02, 0.97395900E+01, -.25457800E+02, -.19992100E+03, 0.10094100E+03, 0.99856400E+02, -.22259200E+02, 0.14855200E+02, 0.87679300E+02, 0.53388400E+02, 0.47507500E+02, -.12702900E+02, -.48809400E+02, 0.24256900E+02, 0.24320600E+02, -.25279100E+02, -.37115500E+02, 0.30478800E+02, 0.41120400E+02, 0.87480700E+02, 0.19344900E+01, 0.17864800E+03, -.87542900E+02, -.90661300E+02, 0.12820800E+02, 0.53146100E+01, -.57573800E+02, 0.40684400E+01, -.84143800E+02, 0.10433100E+01, -.19309100E+01, -.96509900E+01, 0.31926500E+01, -.10117700E+02, 0.24979800E+01, 0.22135500E+01, -.44842200E+01, 0.29138600E+01, -.10330300E+02, -.14236400E+01, 0.73516300E+01, -.57986600E+00, -.33404600E+01, 0.71146400E+01, 0.50203600E+01, -.25822200E+01, -.29150300E+01, 0.57445500E+01, -.10302700E+02, 0.83044600E+01, 0.10394400E-01, 0.40521800E+01, -.13943900E+02, 0.71629800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.29847000E+01, 0.37707900E+01, 0.18720000E+01, -.71263700E+01, -.10447000E+01, 0.62833100E+01, -.79017900E+01, -.19842300E+01, 0.76934800E+00, -.27080200E+01, 0.50140800E+00, 0.14909000E+01, -.74075500E+00, 0.21126900E+01, -.17185600E+01, 0.51586100E+01, 0.35480900E+01, 0.53854500E+00, 0.40326600E+01, -.38491500E+00, 0.73682200E+00, -.83811800E+00, 0.21102900E+01, -.60931800E+00, 0.24369100E+01, -.33824600E+01, -.82964200E+00, 0.30031400E+01, -.17037700E+01, -.14802100E+01, -.97634100E+00, -.54070700E+00, -.12956300E+00, 0.18103000E+00, -.36951000E+00, 0.62107700E+00, -.37341600E+01, -.27192100E+01, 0.15793700E+00, -.26176300E+01, -.58152400E+00, 0.20583500E+01, -.37863900E+01, 0.29119300E+01, -.83851000E+00, 0.12491300E+01, 0.39155200E-01, 0.63342400E+00, -.28551600E+01, 0.26145500E+01, -.52124400E+00, -.15277200E+01, 0.39980200E+01, 0.17177300E+01, -.51366900E+00, -.82161800E+00, 0.12849600E+00, 0.76089000E+00, -.29262100E+01, 0.54364200E+01, 0.25116900E+00, -.61887600E+00, -.16500800E+00, 0.54993300E+00, -.15687300E+00, 0.10965300E+01, -.71643300E-01, -.14124100E+00, 0.20320800E+00, -.68218900E+00, -.91037500E+00, 0.12178200E+00, 0.21943200E+01, 0.14457400E+01, 0.51889300E+00, -.25637200E+00, 0.66313500E+00, 0.67029600E+00, -.35106100E+00, 0.21501200E+01, 0.69253400E+00, -.81510000E+00, 0.20167800E+00, 0.33440800E-01, -.97627400E-02, -.16937200E+01, 0.94097000E+00, -.28419800E+01, -.48939900E+00, -.89090100E-01, 0.14930300E-01, 0.21688900E-01, 0.55615800E-01, 0.22432500E+00, 0.55909300E+00, 0.10706600E+01, -.20841300E+00, -.61900500E+00, 0.90630300E-01, -.51797200E+00, -.41633600E+00, -.85539300E+00, 0.13817100E+01, -.57746200E+00, -.19156000E+00, 0.42055000E-01, 0.45383900E+00, -.46077600E-01, -.12265700E+01, 0.13858200E+00, -.29587400E-01, 0.96200400E+00, 0.10417000E+01, -.67695000E+00, -.94310900E-01, 0.13380200E+00, -.31051300E+00, 0.59577400E+00, 0.41936400E-01, 0.14553700E-01, -.53920100E-01, 0.32404100E+00, -.30459500E+00, -.58174500E+00, -.47956300E+00, 0.16166700E+00, -.79161400E+00, 0.21139300E-01, 0.18621100E-01, -.25608600E+00, 0.40638600E+00, 0.68711800E-01, -.72628000E-01, 0.97516200E-01, 0.71845700E+00, 0.39738700E+00, 0.12835300E+00, 0.11090500E+01, -.26572700E+00, -.45683200E-01, 0.13617900E+00, -.59053800E+00, 0.55908400E-01, 0.61995700E+00, 0.17170600E+00, -.49339200E-01, 0.15438500E-01, 0.83961800E+02, -.18498200E+02, -.23630800E+02, -.68893100E+02, 0.40120300E+01, -.34569100E+02, 0.29977700E+02, -.14556200E+02, -.15485800E+02, -.44813400E+02, -.44219300E+02, 0.22719200E+00, -.16218600E+02, -.99864400E+02, 0.24361300E+01, -.21103100E+03, 0.11502100E+03, 0.10350800E+03, 0.76022100E+01, -.11449000E+01, 0.91136400E+02, 0.56727300E+02, 0.12807000E+03, -.11011000E+02, -.70046500E+02, 0.28970000E+02, 0.34035600E+02, 0.30068700E+02, 0.13974200E+02, -.93240100E+01, -.22746500E+02, 0.68886500E+02, 0.17452000E+02, 0.26448300E+03, -.13517500E+03, -.13118800E+03, 0.19358400E+02, -.30453100E+02, -.13185600E+03, -.10903800E+03, 0.58470300E-01, 0.13221500E+02, -.44042300E+02, 0.21422500E+02, 0.23198100E+02, 0.88478100E+02, 0.16529700E+03, -.47039700E+02, -.65623300E+02, -.94558200E+02, 0.64671400E+02, -.43964900E+02, 0.47519300E+01, 0.24614100E+02, 0.63485900E+00, -.32590700E+01, 0.19484800E+02, 0.11792400E+02, 0.67976800E+02, -.12879200E+02, -.10446900E+02, -.22458000E+01, -.73934500E+01, 0.43384600E+01, -.23347800E+01, 0.36288200E+01, 0.80107600E+01, -.13522300E+02, 0.19410700E+02, 0.10137700E+02, 0.16616900E+02, 0.91457800E+01, 0.98432500E+01, 0.13836400E+02, -.57970100E+01, 0.14445800E+02, 0.12977500E+02, -.10491200E+02, -.12269400E+02, 0.16366500E+01, -.36030400E+01, -.33888800E+01, 0.15652500E+01, 0.32038600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.17610100E+01, -.13283200E+01, -.62442100E+00, 0.46775600E+01, 0.10317100E+01, -.36970700E+01, 0.53081400E+01, 0.12477900E+01, -.74850700E+00, 0.24442800E+01, -.13440400E+00, -.95499000E+00, 0.11251400E+01, -.17613700E+01, 0.13277300E+01, -.53517100E+01, -.35045500E+01, 0.30196100E-01, -.28720900E+01, -.49109500E+00, -.13291200E+01, 0.17821300E+00, -.15488600E+01, 0.12249300E+00, -.24344800E+01, 0.72729100E+01, 0.38594000E+00, -.36148400E+01, -.14125100E+01, 0.23277800E+01, 0.10537600E+01, -.46818500E+00, 0.14269800E+00, 0.17977200E+00, 0.23278200E+01, -.90435600E+00, 0.12338200E+01, 0.11760300E+01, -.55207100E+00, 0.37277300E+01, 0.49392700E-01, -.15485000E+01, 0.39321900E+01, -.17718900E+01, 0.25422100E+01, -.17163400E+01, -.96127700E-01, 0.32188300E+00, 0.54402600E+00, 0.88469500E+00, -.48407500E+00, -.23033800E+01, -.13884300E+01, -.10494500E-01, -.24544700E+00, -.16734800E+01, 0.36813000E+00, 0.11421000E+01, -.30009300E+01, 0.31197600E+01, 0.74977900E+00, 0.13768900E+01, 0.40921400E+00, 0.46732500E+00, 0.94715500E-01, -.58100600E+00, 0.36366000E+00, 0.13209300E+01, 0.94498100E-01, -.56124800E+01, 0.31283300E+00, 0.14788600E+01, -.26934800E+01, -.20009600E+01, 0.24671100E+00, 0.16790700E+00, -.20415400E+00, 0.53586000E+00, -.42046000E+00, 0.48283500E+00, 0.31024800E+00, 0.47583400E+00, 0.76830300E-01, 0.20538500E+00, -.15840300E+00, 0.17170500E-01, 0.30484500E+00, -.26004400E+01, -.46407100E+00, -.31667300E+00, -.40304700E+00, 0.15447600E+00, -.17693400E-01, 0.39790000E+00, 0.11245000E+00, -.14514200E+00, 0.44651600E-01, 0.68691500E+00, -.24327600E+00, 0.16817800E+00, 0.33349700E+00, -.14343300E+01, -.15507500E+01, 0.25397000E+00, -.31037100E+00, -.63079900E-01, 0.43194700E+00, -.66357200E+00, -.12498700E+01, -.40053800E+00, 0.11587300E+00, -.48119900E+00, 0.48676900E+00, -.74654600E-01, 0.35674400E+00, 0.16598300E+00, 0.14410300E+00, 0.13283900E+00, -.33747300E-01, 0.42111300E-01, 0.15889500E+00, 0.26644300E+00, 0.84547100E-02, -.40772700E-01, -.40035400E+00, -.14200200E+00, -.90290000E+00, -.41798700E-02, -.41180600E+00, -.21913900E+00, 0.84220300E+00, -.12497600E+00, -.28591400E+00, 0.56726000E+00, 0.27928600E+00, 0.65596300E-01, 0.13165900E+00, 0.60201800E+00, -.11501600E+00, 0.33743100E+00, 0.19476900E+00, -.59217100E+00, 0.89324300E+00, 0.32562600E+00, 0.16879200E+00, -.21981900E+00, 0.84904300E-01, 0.14769200E+00, -.62891900E+02, 0.11628700E+01, 0.18319200E+02, 0.88123200E+01, 0.36643800E+02, 0.46051100E+02, -.19787300E+02, -.22330900E+02, -.32006300E+02, -.23763000E+01, -.13588600E+01, 0.48472500E+02, 0.39334400E+01, 0.73264300E+01, -.20744700E+03, 0.10553900E+03, 0.10430800E+03, -.32436100E+02, -.13904400E+02, 0.69549400E+02, 0.40554400E+02, 0.76146200E+02, -.77763400E+01, 0.13805000E+03, -.58674400E+02, -.76390400E+02, 0.21714800E+02, -.13545200E+01, -.59835000E+02, -.60948500E+02, -.71589600E+02, 0.43157800E+02, 0.13150900E+03, -.66683300E+02, -.67164000E+02, 0.16184500E+02, -.15269500E+02, -.64924500E+02, -.62351900E+02, -.54300300E+01, 0.24161400E+02, 0.90088000E+02, -.48325600E+02, -.46348000E+02, 0.37546600E+02, 0.27749100E+02, -.51750400E+02, -.82424200E+02, -.12354400E+03, 0.57785200E+00, -.16340500E+03, 0.75162000E+02, 0.74995400E+02, 0.28387100E+01, -.84926500E+00, 0.38618600E+02, -.29410900E+02, 0.89133400E+02, 0.31929700E+01, -.41526900E+01, 0.13128900E+02, -.43733400E+01, 0.63616000E+01, 0.13798900E+02, -.47858500E+01, 0.51087700E+01, -.41536300E+01, 0.42117100E+01, 0.17609000E+01, -.21343700E+01, 0.10204500E+01, 0.53976300E+01, 0.49565100E+01, -.36915900E+01, 0.49693000E+01, 0.66910700E+01, 0.68691600E+01, 0.24424200E+02, 0.96406800E+01, -.15003200E+02, -.88836800E+00, 0.27917700E+02, -.10508700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20318000E+01, -.55611000E+00, 0.21743100E+00, 0.10088200E+00, -.81699100E+00, 0.14650900E+01, -.10021000E+01, -.63855400E+00, 0.64485100E+00, -.11905200E+01, -.36726600E+00, -.36559200E+00, -.78710700E+00, -.11710900E+01, -.32187400E+00, -.91495200E+00, 0.34396000E+00, -.37711600E+00, 0.12395300E+01, -.35182100E+01, 0.82242500E+00, -.10927500E+01, 0.72170700E-01, 0.62820700E+00, 0.10771400E+01, -.28050800E+01, -.32717200E+00, 0.11350900E+01, -.10791700E+01, -.10650500E+01, 0.11121900E+00, 0.47190600E+00, 0.47576800E+00, -.72135500E-01, -.30764800E+00, -.19273800E+00, -.17844000E+01, 0.33117400E+01, 0.38300900E+00, -.79333500E+00, -.41235100E-01, 0.20372700E-01, -.17469900E+01, 0.56352800E+00, -.26209300E+00, 0.68671200E+00, 0.32599100E-01, -.51521400E+00, 0.11582100E-01, 0.11408200E+01, -.27626600E+00, -.12539000E+00, -.32906700E+00, -.65650600E+00, -.65237600E+00, -.63985200E+00, 0.58546300E-01, 0.43839500E+00, 0.12634900E+01, 0.97640000E-01, -.77850300E-01, -.86634500E-01, -.40068700E-01, 0.12462500E+00, 0.25739800E+00, 0.48154200E+00, 0.67706600E+00, 0.89173900E+00, 0.34858200E-01, 0.53413900E+00, -.28640900E+00, -.59772400E+00, 0.15974300E+01, 0.23684100E-01, -.88649600E-01, -.32833200E+00, -.30772600E+00, 0.34217100E+00, -.91395700E-01, -.65771400E+00, 0.10649600E+00, -.28557500E+00, -.69770700E-01, -.15808900E+00, 0.26891600E-01, -.98049800E-01, 0.26290500E+00, -.96948900E+00, -.18161900E+00, -.81917700E-02, 0.26685600E-01, -.14313900E+00, 0.69057500E-01, -.22079800E+00, -.11613000E+00, 0.99168500E+00, -.24951900E+00, 0.38681400E+00, -.31136900E-01, -.75831800E-01, 0.20543400E+00, -.39929800E+00, -.36574600E+00, -.24315500E-02, -.76196500E-01, -.44157300E-01, 0.28994700E-01, -.97556300E-01, -.68821700E+00, -.18785100E+00, -.19294400E+00, -.38939800E-01, 0.16530200E+00, -.43767300E-01, 0.14545400E+00, -.26812700E+00, -.95695000E-01, 0.45162500E+00, 0.15381000E-01, 0.15368600E+00, -.15465900E+00, 0.63836700E+00, 0.25548300E+00, -.77870700E+00, -.32554500E+00, 0.32560500E+00, -.56542100E+00, -.21939800E-01, -.90073500E-01, -.58070300E-01, 0.48373200E+00, 0.20832900E+00, 0.67944500E+00, -.15615400E-01, 0.40489200E+00, -.22948400E+00, 0.39159300E-01, 0.30241200E-01, -.35533100E+00, -.28940800E+00, -.46928400E-01, -.10644800E+00, 0.28672500E+00, 0.20589400E+00, -.92281400E-01, 0.51975200E-01, -.44527400E-01, 0.85903700E-01, -.12527200E+00, 0.11056300E+02, 0.50524700E+02, 0.12713100E+02, 0.33137200E+02, 0.14605900E+03, -.73700000E+02, -.73708700E+02, -.34225200E+02, -.26861900E+02, -.30922000E+02, 0.31401300E+02, -.29301500E+02, -.31895700E+02, 0.15162200E+03, -.73028200E+02, -.77263800E+02, 0.26705200E+02, -.83712800E+01, -.56334700E+02, -.38199500E+02, -.59097200E+02, -.11510800E+02, -.43468400E+02, 0.24879500E+02, 0.12500700E+02, 0.36520800E+02, 0.58658100E+02, -.18081300E+02, -.46475200E+02, -.78787600E+02, 0.64454900E+02, 0.30573800E+02, -.15118300E+02, -.16948400E+02, 0.21214500E+02, -.32725700E+01, -.10461000E+02, -.11719400E+02, 0.18305800E+02, 0.18789200E+02, -.10574500E+03, 0.53706800E+02, 0.53551200E+02, 0.29714500E+02, 0.14862200E+02, 0.23358200E+02, -.27213400E+02, 0.14114000E+02, 0.12546300E+02, -.32996800E+01, 0.85515600E+01, -.24469700E+00, -.76846400E+01, 0.10909200E+02, -.24297800E+01, -.13619800E+02, -.24824500E+02, -.48808500E+01, -.94185500E+01, 0.33350100E+02, -.97738800E+01, 0.10474300E+02, -.44970600E+01, -.32621500E+01, 0.12085000E+02, -.14030400E+02, 0.24367500E+02, 0.17972800E+02, 0.46433600E+01, 0.16445700E+02, 0.60563300E+01, 0.64314000E+01, 0.40465800E+01, 0.13942100E+02, 0.11937600E+02, -.16040400E+02, 0.54268600E+01, -.29995300E+01, 0.24461800E+01, 0.77989000E+01, 0.12090100E+02, -.27332600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.79996900E+01, -.53169800E+01, -.42659100E+01, 0.12105400E+02, -.12628600E+01, -.12195400E+02, 0.12509700E+02, 0.39558000E+01, -.36027800E+01, 0.40214900E+01, 0.14077700E+00, -.83193800E+00, 0.19940300E+01, 0.23164100E+01, 0.67415900E+00, -.45981700E+01, -.39862500E+01, 0.17390900E-01, -.61873400E+01, 0.18388300E+01, -.23108800E+01, 0.11083500E+01, -.96212500E+00, 0.17241300E+01, -.60782800E+01, 0.61182400E+01, 0.22179100E+01, -.39069300E+01, 0.40337600E+01, 0.22378400E+01, 0.36721300E+00, -.12375900E+00, -.26734200E+00, -.66440600E+00, 0.35359200E+00, 0.35787400E+00, 0.46703200E+01, 0.83262500E+01, 0.14261600E+01, 0.45283900E+01, 0.88456900E+00, -.52174700E+01, 0.76056800E+01, -.52305400E+01, 0.15032400E+01, -.24533100E+01, 0.12282900E+00, -.21190000E+01, 0.25410600E+01, -.31027600E+01, 0.47805500E+00, -.11964100E+01, -.39377800E+01, -.23453000E+01, 0.54147400E+00, 0.76963300E+00, -.24137100E+00, -.44253100E+01, -.87255500E+01, -.14755900E+01, 0.64619100E-01, 0.58727300E+00, 0.26991000E+00, 0.55681100E+00, -.61168400E+00, -.94761900E+00, 0.10743100E+01, -.33032800E+01, 0.15076300E+00, 0.10925200E+02, 0.11085400E+01, 0.46457700E+00, 0.68075300E+01, -.17556400E+01, -.21488500E+01, -.24170400E-01, 0.24093400E+01, -.20863300E+01, 0.64331300E+00, -.56998700E-01, -.17016700E+00, 0.74639100E+00, -.40364500E+00, 0.77569000E-01, -.62888800E-01, -.28643400E+00, 0.16128400E+01, -.56347600E+00, -.27543000E+00, 0.19573800E+01, 0.40662300E+00, -.16732700E+00, 0.23040200E+00, -.55678300E+00, -.60576600E+00, -.14234000E+01, -.17272600E+00, -.21434100E+01, 0.42418900E+00, 0.78753100E-01, 0.90664900E+00, 0.46890900E+01, -.34144400E+01, 0.87150500E+00, 0.11347900E+01, -.20569100E+01, 0.15638000E+00, 0.89473700E-01, 0.77692100E+00, -.57737000E+00, -.13091400E+00, 0.12736000E+01, 0.19817300E+00, 0.11326600E+01, 0.72853300E+00, -.31461500E+00, -.88249500E+00, -.12303600E+01, -.13143700E+00, -.92707600E+00, 0.25476100E+00, -.26565600E+00, -.76509700E+00, 0.12203600E+01, -.19718900E-01, -.83998000E+00, 0.11798400E+00, -.71213500E-02, 0.32444600E+00, -.65512000E+00, 0.86147100E+00, 0.27909800E+00, -.21502300E+01, -.80409300E+00, -.19199000E+00, 0.14454000E+00, 0.96797300E-01, 0.25029900E+01, 0.53963900E+00, -.31809600E+00, -.57776000E+00, -.75264400E+00, 0.14061600E+01, -.20325200E+01, -.24677700E+00, -.35161600E+00, -.21831100E-01, 0.13205500E+01, 0.91778600E+00, 0.19487000E+01, -.11013800E+03, -.39388800E+02, -.24845200E+03, 0.61345300E+02, -.13268300E+02, -.31419100E+02, -.11416400E+03, -.15350900E+03, 0.63985800E+02, 0.88029500E+02, 0.67597900E+03, -.17628400E+03, -.30254600E+03, 0.93776100E+02, 0.17484500E+03, -.15396900E+03, -.84742400E+02, 0.15807200E+03, 0.12291600E+03, 0.13238300E+03, -.24171800E+02, -.10067500E+03, 0.58551600E+02, 0.21718600E+02, 0.55997800E+02, 0.24442000E+02, -.92926300E+00, 0.12406700E+02, 0.37298900E+02, 0.20146800E+02, -.36078400E+03, 0.17840400E+03, 0.18113000E+03, -.38885700E+02, 0.39700600E+02, 0.17869500E+03, 0.22243700E+03, -.10646200E+03, 0.10170000E+02, -.10700600E+03, 0.37508800E+02, 0.59991800E+02, -.25934100E+02, -.11685700E+02, 0.39494500E+02, 0.32648700E+02, -.29204700E+03, 0.80230000E+02, -.79989300E+02, 0.24475300E+02, 0.46114700E+02, 0.81928100E+02, -.51790900E+02, 0.51423500E+02, 0.43690500E+02, 0.11573200E+03, 0.41563500E+02, 0.64812000E+02, -.12045400E+03, 0.23875700E+02, -.20239200E+02, -.53990000E+02, 0.27826100E+02, -.38358400E+02, 0.44650000E+02, -.89405100E+02, -.54218700E+02, -.45120700E+02, -.44212300E+02, -.88425200E+01, -.73676900E+02, -.91516700E+01, -.56608100E+02, -.53763700E+02, 0.33695800E+02, -.58881800E+02, -.11440700E+02, 0.42215600E+02, -.29096900E+01, -.39375500E+02, 0.90582500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.43797400E+01, -.10829900E+01, -.14981200E+01, -.34248500E+01, -.15812200E+01, 0.33457000E+01, 0.14821500E+01, 0.79384300E+00, -.21688700E+01, 0.42044400E+00, 0.12563300E+01, 0.17958300E+01, 0.13765600E+01, 0.47344600E+01, 0.22193400E+00, 0.51240200E+01, 0.12653800E+01, -.26477600E+01, 0.17384100E+01, 0.88161400E+01, -.12445200E+01, 0.13246100E+01, -.98828000E-01, -.25112800E+01, -.19180800E+01, 0.68169700E+01, 0.47688400E+00, -.24137600E+01, -.19259100E+01, 0.19070300E+01, 0.78360400E+00, -.21191300E+00, -.90017400E-01, 0.18067100E+00, 0.11360800E+01, 0.10408500E+00, 0.57428700E+00, -.43274300E+01, -.11265900E+00, 0.12567400E+01, -.10539000E+00, 0.65253400E+00, 0.86116300E-01, 0.61868200E-01, 0.15886100E-01, -.15699300E+00, -.23648400E+00, -.34464400E+00, -.16435100E+01, -.80975500E+00, -.19036700E-02, 0.21904400E+00, 0.19874400E+01, 0.22076100E+00, 0.15602900E+01, 0.13978100E+00, -.12380600E+00, 0.45435100E+00, 0.29166600E+01, 0.25768100E+00, -.27286100E+00, -.48438700E+00, 0.61316500E-01, -.28888600E+00, 0.28564700E+00, -.34194800E+00, -.78664300E+00, -.15405900E+01, -.17650300E+00, -.29480200E+01, 0.72980300E+00, -.78740200E+00, -.18931600E+01, -.15028400E+01, 0.95592100E+00, -.82411000E-01, 0.60440100E+00, 0.10667000E+01, -.52806100E+00, 0.33416700E+01, -.13032300E+00, 0.25317300E-01, 0.76332900E-01, -.25973500E+00, 0.74757400E-01, -.44409700E+00, 0.14055800E+01, -.23263300E+01, -.74306600E+00, 0.68202200E+00, -.25342200E+00, 0.50356200E+00, -.10223000E+00, -.71627200E+00, 0.10409300E+01, 0.66877300E-01, 0.38577900E+00, -.76635600E+00, 0.19941700E+00, 0.86798400E+00, -.22226400E+00, 0.42836200E+01, 0.93535300E+00, -.17712500E+00, 0.11209900E+00, 0.21056500E+00, 0.82398400E+00, 0.10939800E-01, -.27982900E+00, -.84968100E-01, -.38591100E+00, 0.93888700E-01, -.24853200E+00, -.34983700E+00, 0.26297700E+00, -.12274300E+00, -.13285300E+00, 0.13905700E+01, -.43191900E-01, 0.58968100E+00, 0.90239500E-02, 0.43997100E+00, 0.11789900E+00, -.83141100E+00, -.15562200E+00, 0.10655600E+00, -.10997700E+01, -.18285700E-01, 0.11364400E+00, 0.34554600E+00, 0.48261500E+00, -.19703500E+00, 0.70318800E+00, 0.79638400E+00, -.13998500E+00, 0.47759700E+00, 0.11345100E+00, 0.32804900E+00, -.26899500E+00, -.26996000E+00, 0.81392300E+00, -.12307200E+00, -.21028300E+00, -.23385900E+00, 0.10813800E+00, 0.46527600E-01, 0.24080900E+00, 0.14884300E+00, 0.79669300E+00, 0.96135700E+00, 0.16526700E+00, 0.53232800E+02, -.44554600E+02, -.29643300E+03, 0.14566900E+03, 0.14874700E+03, 0.53318500E+02, 0.46874200E+02, 0.67822000E+02, -.53166200E+02, 0.69348200E+01, 0.81749400E+02, -.56237000E+00, -.28619000E+01, -.44746300E+01, -.55689300E+01, 0.53267000E+02, 0.36374900E+01, 0.11022000E+02, 0.11774800E+02, 0.14953500E+02, -.48633500E+02, 0.12794700E+02, 0.40975200E+02, -.29312000E+02, -.64971600E+02, 0.38490300E+02, 0.39205700E+02, 0.93408800E+02, -.56294200E+02, 0.28791700E+03, -.14471300E+03, -.14192300E+03, 0.94231000E+01, -.23043500E+02, -.11512700E+03, -.54289000E+02, -.97716300E+02, -.21965900E+02, 0.15966400E+03, -.76279500E+02, -.80637600E+02, -.13393700E+02, -.29669300E+01, -.42340800E+02, 0.27532000E+02, -.13973600E+02, -.38566800E+02, -.17161200E+03, 0.86617300E+02, 0.91056700E+02, -.33403100E+02, -.47559000E+01, 0.64361700E+02, 0.16952500E+02, 0.81636700E+02, -.47992900E+01, 0.10548800E+02, -.14673500E+01, 0.30695100E+01, 0.99710400E+01, -.41694100E+01, -.84025500E-01, -.13322400E+01, 0.74833000E+01, 0.92477600E+01, -.95128200E+01, -.15008300E+02, -.11204800E+02, -.31703900E+01, -.17977500E+02, -.59179100E+01, -.63946700E+01, -.49688400E+01, -.10118300E+02, 0.16633400E+01, -.16132100E+02, 0.52784300E+01, -.13103800E+02, -.32549700E+01, 0.50669200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11820300E+01, -.14045100E+01, -.55877400E+00, 0.33138400E+01, -.66920500E-01, -.25710500E+01, 0.25941100E+01, 0.79158100E+00, -.75247000E+00, 0.81432200E+00, -.60664400E-01, -.22309800E+00, 0.36055000E+00, -.47288400E+00, 0.28367600E+00, -.21734200E+01, -.95305300E+00, 0.10385300E+00, -.12084500E+01, 0.13389700E+01, 0.37270500E+00, 0.81089000E+00, -.92105300E+00, -.13954400E+00, -.28831000E+00, 0.26792400E+00, 0.99292800E+00, -.16130600E+01, -.98025300E+00, 0.29296800E+00, 0.61147100E+00, 0.95215900E+00, 0.18665000E+00, 0.63752500E-02, 0.15830700E+01, -.63987000E+00, -.74342100E+00, 0.29934400E+01, 0.35496400E-01, 0.23137500E+01, 0.30537700E+00, -.69788600E-01, -.58527200E+00, -.98733600E+00, -.39998200E+00, -.10290400E+00, -.17832900E+00, -.76964200E+00, 0.28129600E+00, -.18705200E+00, -.51987600E+00, -.16108200E+01, -.16791800E+00, -.40031500E+00, 0.11817000E+01, 0.31019600E+00, 0.22028600E+00, 0.68531600E+00, 0.44706000E+00, -.87463300E+00, -.26765800E+00, -.24198400E+00, 0.56867200E-01, -.37681300E+00, -.11604200E+00, -.16753800E+00, -.30549500E+00, 0.70281200E-01, -.81132900E-01, -.19273500E+01, 0.15765400E+00, -.58028400E+00, 0.38225900E+00, -.23261100E+00, -.45863400E+00, -.58275100E-01, 0.25923600E+00, -.12255000E+00, -.72234400E-02, -.56481200E+00, 0.13693500E+00, 0.36425500E-01, 0.11058800E+00, -.52800600E-01, -.64664500E-01, 0.90523700E-01, -.45752700E+00, 0.15347000E+01, 0.23512600E+00, -.63412600E+00, 0.12524700E+00, -.13389400E+00, -.64215300E-01, 0.26607100E+00, 0.36379900E+00, 0.14616900E+00, -.14964600E+00, -.29234200E+00, 0.75396300E-01, 0.50572600E+00, -.21904200E+00, 0.25793300E+01, 0.21713500E+00, 0.65397700E-01, 0.16351800E+00, 0.40790500E+00, 0.25111600E-01, -.21816900E+00, 0.73435700E+00, 0.27939900E+00, 0.39224000E+00, 0.10035500E+00, -.51488700E-01, -.25872300E+00, -.28318600E+00, 0.35180300E+00, 0.14468400E+00, -.13191500E+00, -.14318400E-01, 0.33988600E+00, 0.94084400E-01, -.18676000E+00, 0.33304200E-01, 0.66780600E-01, 0.11972900E+00, 0.19054300E-01, 0.41404600E+00, -.44131500E-02, -.19519500E-01, 0.11874400E+00, -.46516200E-01, -.41726100E-01, 0.52357700E+00, 0.10402300E+00, 0.75365600E-01, 0.88146100E-01, 0.32628800E-01, -.54161300E+00, -.54070000E+00, 0.50960700E+00, 0.24819100E+00, 0.58673500E-01, -.15887600E+00, -.15092600E+00, -.13964600E+00, 0.37339400E-01, 0.10470500E-02, -.88790900E-02, -.67590900E-01, -.13612300E+00, -.76930800E-01, -.92583900E-01, -.24427700E+02, -.15250500E+03, 0.72977200E+02, 0.75736400E+02, 0.19722300E+02, 0.28194600E+02, 0.40504100E+02, -.30322400E+02, -.13131500E+02, 0.42405700E+02, 0.64943400E+02, -.23203800E+02, -.34480700E+02, 0.35872000E+02, 0.10038300E+02, -.29478400E+02, -.31177100E+02, -.29815000E+02, 0.45504900E+01, 0.20469400E+02, -.16837100E+02, -.94544300E+01, -.15379200E+02, -.22677500E+02, 0.27202300E+01, -.36243500E+01, 0.20523500E+00, -.18742800E+02, 0.98471100E+02, -.49027100E+02, -.48400900E+02, 0.21766700E+01, -.13503500E+02, -.32390600E+02, -.55161700E+01, -.24924300E+02, -.88585400E+01, 0.10083400E+03, -.47706800E+02, -.49482700E+02, -.53539500E+01, -.44797000E+01, -.32250800E+02, 0.10788600E+02, -.10927600E+02, -.23109200E+02, -.66433300E+02, 0.29718300E+02, 0.37108900E+02, -.21242900E+02, -.15406700E+02, 0.21681100E+02, 0.14863100E+00, 0.34986300E+02, -.24788600E+01, 0.43958000E+01, -.40548500E+00, 0.18715500E+01, 0.22157800E+01, -.38436800E+01, -.50638300E+01, -.33532100E+00, 0.31220000E+01, -.46014500E+01, -.23540200E+01, 0.25244200E+00, -.48417800E+01, -.40171200E+01, -.31863900E+01, -.24843600E+00, -.22294700E+01, 0.24125300E+01, 0.40281700E+00, -.23621500E+01, -.10003800E+02, 0.61912400E+01, -.41731400E+01, -.17957400E+01, -.83462100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.53454200E+01, -.16805400E+01, -.11852500E+01, 0.45284000E+01, -.46856700E+00, -.41706800E+01, 0.27234200E+01, 0.12610100E+01, -.28491400E+01, -.66990400E+00, 0.70397400E+00, 0.94991600E+00, 0.54345700E+00, 0.38613400E+01, -.25977000E+00, 0.53516900E+01, 0.16414800E+01, -.33445400E+01, -.25373500E+01, 0.47938100E+01, 0.10987200E+00, 0.16091000E+01, 0.10535500E+01, -.54420200E-01, -.16445000E+01, -.18838000E+01, 0.23271600E+01, -.12149900E+01, 0.54665100E+00, 0.16939000E-01, -.16844300E+00, 0.67462500E+00, 0.11314500E+00, -.10059700E+00, 0.92994200E+00, -.38034800E+00, -.15070900E+01, 0.18994500E+01, -.14349600E+00, 0.73560500E+00, 0.55054900E-01, -.18049700E+00, -.11724800E+01, -.67158700E+00, 0.41476800E+00, 0.28525200E+00, -.13862100E+00, -.45646800E+00, -.66846400E+00, 0.32460800E+00, -.38473700E+00, -.50048300E+00, -.27708200E+00, -.12801900E+01, 0.12159300E+01, -.72964800E+00, 0.14480500E+00, 0.66330900E+00, 0.32734000E+01, 0.39952200E+00, -.20915700E+00, -.57784700E+00, 0.18282700E-01, -.47992400E+00, 0.94873600E-01, 0.18972700E+00, -.26424600E+00, -.23062400E+00, -.88419100E-01, -.43433300E+00, 0.60987700E+00, 0.51717900E+00, -.15068300E+01, -.59895700E+00, 0.44237400E+00, -.68725100E-01, -.75513800E+00, 0.13651200E+00, 0.28993500E-01, -.15635200E+00, 0.17333800E+00, 0.39014900E+00, -.30901500E-01, -.49199500E+00, -.23693400E+00, 0.88858400E-03, 0.16259700E+00, -.63660200E+01, -.91771400E+00, -.61267500E+00, -.37968600E+00, 0.58953600E-02, -.13421600E+00, -.23427800E+00, 0.46473700E+00, -.86540400E-01, 0.27023100E+00, 0.42844700E+00, 0.34868200E-01, -.60777000E+00, 0.76636400E+00, 0.14285400E+01, 0.38308100E+00, -.74789700E+00, 0.10618400E+00, 0.81580500E-01, 0.13380500E-01, -.42439700E+00, -.10158100E+01, 0.26261400E-01, 0.21814000E+00, -.29441900E-01, -.25005600E+00, -.57444000E+00, -.16278400E+00, 0.42020700E+00, 0.21666900E+00, -.97671300E+00, -.33620300E-01, -.12498100E+00, 0.34354400E-01, 0.79619500E+00, -.17794600E+00, -.74553200E+00, -.95457300E+00, 0.53443800E+00, 0.40214600E+00, -.34105800E-01, -.57174300E+00, -.24439200E+00, -.36559800E+00, -.14719000E+00, 0.42294800E+00, 0.78562500E+00, 0.22451400E+00, -.25192700E-01, 0.49305800E-01, -.54227600E+00, -.96759900E+00, 0.11397400E+00, 0.13110500E+01, 0.82727300E+00, 0.12444100E+00, -.20952700E+00, -.18135800E+00, 0.26656700E+00, 0.25181400E-02, -.36014700E+00, 0.65828500E+00, 0.12065700E+01, 0.19794800E+00, -.75599400E-01, 0.17766400E+00, -.32539900E+03, 0.15157100E+03, 0.16365900E+03, 0.76809600E+02, -.42992700E+02, 0.89393500E+02, -.50918100E+02, 0.82921700E+02, 0.21650600E+02, 0.25264600E+03, -.11356700E+03, -.12561700E+03, 0.16962700E+02, 0.69395300E+02, -.88783200E+02, -.44409400E+02, -.85915100E+02, 0.75865100E+01, -.42087300E+03, 0.18012000E+03, 0.22412200E+03, -.20466200E+02, -.70612800E+00, 0.16290000E+03, 0.10081700E+03, 0.22132400E+03, -.42388800E+02, 0.17424600E+03, -.87640600E+02, -.85687300E+02, 0.11377800E+02, -.10738100E+02, -.65951300E+02, -.14707900E+00, -.83055200E+02, -.45447500E+02, 0.49337500E+02, -.13323400E+02, -.26158300E+02, -.34888700E+02, 0.96092000E+02, -.40602000E+01, 0.76007300E+02, 0.82486200E+01, 0.36619600E+02, -.45105900E+03, 0.23928800E+03, 0.22795400E+03, -.51473900E+02, -.74057200E+01, 0.15131000E+03, 0.14342800E+02, 0.14450900E+03, 0.23524700E+02, 0.94449000E+01, 0.22302400E+01, 0.83099400E+01, -.57229800E+01, -.83801200E+01, -.57696500E+01, -.42622800E+01, 0.10611600E+02, -.48811600E+01, -.78928100E+01, -.17395100E+02, -.85412600E+01, -.12954900E+02, -.11119100E+02, -.11132100E+02, -.81503400E+01, -.59418700E+01, 0.55353500E+01, -.21486000E+02, -.21766400E+02, 0.92534800E+01, -.19278400E+02, -.44782700E+02, 0.10005800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25780200E+01, 0.30207700E+01, 0.15021600E+01, -.58645500E+01, -.87768100E+00, 0.54031700E+01, -.56430400E+01, -.15754400E+01, 0.14666200E+01, -.20545300E+01, -.56208400E-01, 0.25576600E+00, -.90982200E+00, -.37855300E+00, -.78653100E+00, 0.47840900E+01, 0.19855800E+01, -.16567400E+01, 0.37739600E+01, -.22832800E+01, -.38448900E+00, -.19175900E+01, 0.15155900E+01, -.44969100E+00, 0.91411600E+00, -.26449300E+01, -.21915900E+01, 0.39028400E+01, -.12416400E+01, -.15027400E+01, -.67575500E+00, -.13220100E+01, -.14380300E+00, 0.25260600E+00, -.16260700E+01, 0.91571200E+00, -.26209600E-02, -.46861600E+01, 0.65110500E+00, -.28516100E+01, -.57618700E+00, 0.31524100E+00, -.21372100E+00, 0.29436700E+01, 0.44176900E+00, 0.86042800E+00, 0.32663400E+00, 0.91529300E+00, -.27280200E+01, 0.25490900E+01, 0.24252900E-01, 0.10936600E+01, 0.20137800E+01, 0.92646800E+00, -.20976400E+01, -.14106900E+01, -.18515600E-01, -.32021100E+00, -.42303500E+01, 0.46010000E+01, 0.66497900E+00, 0.38025000E+00, -.13605100E+00, 0.12309300E+01, 0.62995200E+00, 0.22114200E+00, 0.27079000E+00, 0.68246600E+00, -.22783000E-01, -.75312300E+00, -.32023000E+00, 0.51377900E+00, -.16144600E+00, -.22556800E+01, 0.49091500E+00, -.35078200E+00, -.52792700E+00, -.12014500E+00, -.20983800E+00, 0.94563600E+00, -.57165200E-01, -.86508600E-01, -.18238800E+00, -.10532400E-01, 0.21564900E+00, 0.20385300E+00, 0.12980300E+01, 0.37696100E-01, -.17739400E+00, 0.16029400E+00, -.15317400E+00, -.19867000E-01, 0.12735400E+00, -.30257900E+00, -.27767100E+00, 0.69280600E+00, 0.28528800E-01, 0.13419800E+01, -.33307700E+00, 0.99534200E+00, -.37944400E-01, -.18465400E+00, -.70933800E+00, 0.28143100E+00, 0.45914900E+00, -.78895400E+00, 0.89206100E+00, 0.56653200E+00, -.22859200E+00, -.11455400E-01, 0.14218300E+00, 0.24158500E+00, -.16823700E+00, -.33388100E+00, 0.14027800E-01, 0.51266800E+00, 0.13302200E+00, -.75894700E+00, -.65241200E-01, -.26116500E+00, 0.14996300E+00, 0.15137300E+00, -.61390100E+00, 0.58623000E+00, 0.13333900E+00, -.16193500E+00, 0.57698100E+00, -.13403400E-01, 0.39594700E-01, -.11281700E+00, 0.44150700E+00, 0.75221800E-01, -.19555200E+01, -.72880700E+00, 0.28180600E+00, -.12540500E+00, -.31604500E+00, 0.84468400E+00, 0.65543500E-01, -.33631700E+00, -.96013300E+00, 0.84817900E-01, -.73905200E+00, 0.11715700E+01, -.40051600E+00, 0.16032100E+00, 0.48981300E-02, 0.61357900E+00, 0.62937300E+00, 0.19375700E-01, 0.12987800E+00, -.44967100E+00, -.55831700E+00, 0.21710000E+00, -.21311700E+02, -.14785900E+01, 0.52455500E+02, 0.28845200E+01, -.10573900E+02, 0.90154000E+01, -.28598500E+01, 0.16290100E+02, 0.51260100E+03, -.21215000E+03, -.27110400E+03, 0.85802900E+02, 0.38341400E+02, -.18934000E+03, -.11882400E+03, -.18968000E+03, 0.38489600E+02, -.46306400E+03, 0.19504000E+03, 0.24931000E+03, -.14114400E+02, 0.40930800E+02, 0.16217500E+03, 0.78084900E+02, 0.94260800E+02, -.14849200E+02, -.11419000E+03, 0.60186100E+02, 0.59894000E+02, 0.23760200E+02, 0.40529200E+02, 0.45441600E+02, 0.50312800E+02, 0.45716100E+02, -.81838800E+00, -.75697400E+02, 0.57865400E+02, 0.38655500E+02, -.54324100E+02, -.70051600E+02, 0.62052100E+02, 0.49044100E+02, 0.13430700E+03, -.71594600E+02, -.82616100E+01, 0.25844300E+02, 0.19481800E+02, -.49931200E+02, -.57682200E+01, 0.13717700E+02, 0.10780500E+02, -.99145200E+02, 0.19795900E+01, -.54912300E+01, 0.27049600E+02, -.13068700E+01, 0.36547500E+01, -.12436900E+02, -.38018400E+01, 0.40614500E+01, -.73694500E+01, 0.90330100E+01, 0.12024300E+02, -.73668700E+01, 0.12752600E+02, -.24612900E+01, -.56968200E+01, 0.23308800E+01, 0.73371100E+01, 0.19213100E+01, -.92529300E+01, 0.15685300E+02, -.31455000E+02, 0.14469100E+02, 0.55338600E+01, 0.57676500E+01, -.25273800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.38665800E+01, 0.25584000E+01, 0.22116900E+01, -.83875200E+01, 0.65345700E+00, 0.79809500E+01, -.91611300E+01, -.25916700E+01, 0.22803000E+01, -.23784600E+01, 0.27518200E+00, 0.60169900E+00, -.61352900E+00, -.79256000E+00, -.20013200E+01, 0.33973800E+01, 0.22778400E+01, 0.26851000E+00, 0.39870500E+01, -.77523500E+00, 0.10497200E+01, -.54348900E+00, 0.11386800E+01, -.89559500E+00, 0.30358400E+01, -.50821200E+01, -.10848800E+01, 0.35894600E+01, -.75226300E+00, -.19015600E+01, -.46383800E+00, -.54659300E+00, -.77518300E-01, 0.25678400E+00, -.50574000E+00, 0.59050600E+00, -.27835100E+01, -.50077500E+01, 0.40146900E+00, -.23559000E+01, -.37423700E+00, 0.26948000E+01, -.39141700E+01, 0.27389200E+01, -.12164300E+01, 0.16682400E+01, 0.40581000E-01, 0.10303200E+01, -.25358300E+01, 0.87622200E+00, -.10858100E+00, 0.14992900E+01, 0.37155000E+01, 0.16974800E+01, 0.75188700E+00, -.50217900E+00, 0.13441400E+00, 0.29558300E+01, 0.39185100E+01, 0.19334900E+01, -.11515300E+00, -.81247700E+00, -.56342300E+00, 0.51957700E+00, -.77270800E-01, -.12402100E+00, -.11461300E+01, 0.12776600E+01, 0.23109500E+00, -.41866500E+01, 0.33671300E+00, 0.12949900E+01, -.49586600E+01, -.54498000E+00, 0.16067800E+01, 0.43275100E-01, -.12037400E+01, 0.30803300E+00, -.86125300E+00, -.25612800E+00, 0.50511200E+00, -.21419400E+00, 0.83785000E-01, 0.16395500E+00, 0.99637600E-01, 0.42042900E+00, 0.34477600E+00, -.90327800E+00, 0.11986400E+00, -.87935100E-01, 0.33710700E-01, 0.14968400E+00, -.18816600E+00, -.19151800E+00, 0.49939100E+00, 0.63349000E+00, -.11455900E+00, 0.96223700E+00, -.26115200E+00, -.71155800E+00, -.49338300E+00, -.37724100E+01, -.60099700E+00, 0.25379500E-01, -.13843400E+00, 0.95893500E-01, 0.34608200E+00, 0.58478100E-01, -.73809200E+00, -.32559500E+00, 0.34874000E+00, -.67079800E+00, -.25564000E+00, -.20052200E+00, 0.88740600E-01, 0.11054300E+01, 0.45891800E+00, 0.95810100E+00, 0.80642100E-01, 0.18222200E+00, 0.94192200E-01, 0.32679300E+00, 0.71015500E+00, -.75779000E+00, -.13293700E+00, 0.25679000E-01, 0.83015300E-01, 0.29012400E-01, -.10303300E+01, -.78572400E+00, 0.51222000E+00, -.24265600E+00, -.18286800E+01, -.78001100E+00, 0.27711400E+00, -.42838400E+00, -.12383500E+00, -.14147400E+01, 0.60165700E+00, 0.57075500E+00, 0.11888300E+01, 0.46330400E+00, 0.44322200E+00, 0.30089800E+00, -.20591800E+00, 0.10141000E+00, -.26375400E+00, -.49306100E+00, 0.45892600E+00, 0.79310200E+00, -.10564200E+00, -.31614800E+00, 0.13983900E+01, -.72450000E+00, 0.97754500E+00, 0.62163700E+01, 0.24387400E+02, -.13717100E+03, 0.14421900E+02, 0.35636600E+02, 0.16877200E+03, -.77089700E+02, -.14463700E+03, 0.72982800E+02, 0.58687700E+02, -.77739600E+02, 0.25366000E+02, 0.72458600E+02, 0.82565400E+02, 0.98802600E+02, -.18164700E+02, -.43580800E+03, 0.20396400E+03, 0.18441900E+03, 0.23872600E+02, 0.33290300E+02, 0.14702800E+03, 0.78565100E+02, 0.23284500E+03, -.65882400E+01, 0.16351700E+03, -.86313700E+02, -.93055900E+02, -.54268900E+01, -.21448600E+02, -.69613400E+02, -.12737700E+02, -.81094300E+02, -.63512000E+02, -.17029700E+03, 0.86042400E+02, 0.75808100E+02, 0.46012700E+01, 0.21626800E+03, 0.33270000E+02, -.17122400E+02, -.15156200E+03, 0.15265500E+03, -.35886100E+03, 0.17755900E+03, 0.16845600E+03, 0.13524700E+02, 0.44084900E+02, 0.11512600E+03, 0.29971400E+02, 0.19333200E+03, 0.35028100E+02, 0.13719900E+02, -.12195300E+02, 0.99766200E+01, -.86794100E+01, -.10359000E+02, 0.65755800E+01, -.76493500E+01, 0.13818400E+02, -.11416500E+02, -.16082800E+02, -.14204900E+02, -.12862000E+02, -.70845600E+01, -.86420600E+01, -.15687300E+02, -.12255100E+02, -.11252200E+02, 0.11156500E+02, -.15858300E+02, 0.43300100E+01, 0.67486400E+01, -.24558800E+02, -.43666100E+02, 0.18626100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.67874200E+01, -.66462100E+01, -.37387000E+01, 0.71849800E+01, -.11769200E+01, -.59257600E+01, 0.79156000E+01, 0.26263100E+01, -.35198400E+01, 0.27531300E+01, -.38424900E+00, -.11437700E+01, 0.95004500E+00, 0.32043800E+01, -.40804500E+00, -.29411400E+01, -.22549600E+01, 0.20664300E+00, -.25753400E+01, 0.19140300E+01, -.13935100E+00, 0.20941000E+01, -.10672200E+01, -.24016600E+00, -.23164700E+01, 0.41877600E+01, 0.25366300E+01, -.62661800E+01, -.33330100E+01, 0.21502800E+01, 0.22336900E+01, 0.25400500E+01, -.73347900E+00, -.45311800E+00, 0.23762100E+01, -.20855700E+01, -.64329300E+00, 0.80748500E+01, -.16902100E+01, 0.96098800E+01, 0.46063300E+00, -.82193000E-01, 0.39230200E+01, -.50205200E+01, 0.27630000E+01, -.23623300E+01, -.67547300E+00, -.42939400E+00, 0.27197700E+01, -.14735800E+01, -.97563500E+00, -.35980600E+01, -.31790200E+01, -.21145800E+01, 0.20518300E+01, -.84759600E+00, 0.53519900E+00, 0.18117100E+01, 0.27585000E+01, -.37422800E+01, -.61806000E+00, 0.61567100E+00, 0.37532900E+00, -.15036600E+01, 0.25116400E+00, -.74682700E+00, -.90862000E+00, 0.22414300E-01, -.48474300E+00, -.63117800E+01, 0.72798000E-01, 0.20505500E+00, 0.61563900E+01, -.20696400E+01, -.21189300E+01, -.37675300E+00, 0.16449100E+01, -.33582600E+00, 0.75647900E+00, 0.11297600E+01, -.57375100E+00, 0.37997700E-02, 0.64870200E-01, -.69581300E+00, -.63145400E+00, 0.26333800E+00, 0.30370400E+00, -.37609400E+01, -.12027500E+01, -.12746200E+01, 0.63098600E-01, -.55476800E+00, 0.40651600E+00, 0.17188300E+01, 0.44818500E+00, 0.20085800E+01, -.47295500E+00, -.18756700E+01, 0.51859100E+00, 0.16208600E+01, -.13492600E+01, 0.38164700E+01, 0.11727200E+01, 0.55344800E+00, -.67196800E+00, 0.38636700E+00, 0.44452900E+00, -.10947700E+01, 0.10557300E+01, 0.94063500E+00, -.10009500E+01, -.47550900E+00, 0.92759900E-01, -.32720100E+00, 0.84894800E-01, -.10803700E+01, -.10361500E+00, 0.14129200E+01, 0.14052400E-01, 0.15781500E+01, 0.12052700E+00, 0.45268000E+00, -.95724300E-01, 0.27584300E+00, 0.87664400E+00, -.34506100E+00, -.95647700E-02, 0.37079100E-01, 0.99969500E+00, 0.96117300E+00, 0.44472100E+00, 0.30510400E-01, 0.76490500E+00, -.50682300E+00, 0.96424600E-01, 0.67791200E-01, -.59244200E+00, -.20737300E+01, 0.70628300E-01, -.93835400E+00, -.98777000E-01, -.54762700E+00, -.56151000E-01, -.17102100E+00, 0.96801200E+00, 0.53277200E+00, -.23675600E+00, -.13156000E+01, -.21261100E+01, -.12495500E+01, -.48422400E+00, 0.67673300E+00, -.35377800E+01, 0.10313700E+01, 0.34668200E+00, -.34174700E-01, -.22449700E+03, 0.47516300E+02, 0.65786500E+02, -.38878800E+02, -.12241700E+03, 0.93818300E+01, -.22318100E+03, 0.16251100E+03, 0.12833900E+03, -.23777800E+02, -.43718200E+02, 0.59540200E+02, 0.48465100E+01, 0.34183200E+02, -.40116600E+02, 0.92565200E+03, -.40836400E+03, -.53500700E+03, 0.11544600E+03, 0.10700400E+02, -.41569900E+03, -.32475800E+03, -.54718800E+03, 0.18522500E+03, 0.44325600E+02, -.20522500E+02, -.32780500E+02, 0.15205000E+02, -.23752300E+02, 0.61819000E+01, -.15964000E+02, 0.95547400E+02, 0.12477700E+03, 0.70960300E+02, -.40238600E+02, -.31882700E+02, 0.22881900E+03, -.41320700E+02, -.13739200E+03, -.12035300E+03, -.18090500E+03, -.12098100E+02, 0.65672400E+03, -.39214800E+03, -.36069400E+03, 0.53029700E+02, 0.10258000E+02, -.24766900E+03, -.84254500E+02, -.78040800E+02, -.28268100E+02, 0.28608700E+01, 0.13069200E+02, -.21404700E+02, 0.20790900E+02, -.18507700E+02, 0.71463300E+01, 0.17865200E+02, -.17488400E+02, 0.16010300E+02, 0.19347700E+02, 0.31812100E+02, 0.94134800E+01, 0.22368300E+02, 0.17400500E+02, 0.21270200E+02, 0.18339300E+02, 0.35093100E+02, -.14120200E+02, -.49682100E+02, 0.47180900E+02, 0.12046600E+02, 0.37766900E+02, 0.46614500E+02, -.14519700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12768400E+01, -.84523300E+00, -.48648400E+00, 0.32995600E+01, -.59441700E-01, -.24633300E+01, 0.24526600E+01, 0.73096000E+00, -.11458000E+01, 0.12030800E+01, -.13990200E+00, -.51675100E+00, 0.41060800E+00, -.23039900E+01, 0.12481000E+01, -.28992600E+01, -.15446000E+01, -.16773000E+01, -.20095600E+00, 0.24190200E+01, 0.21747500E-02, 0.46470600E+00, -.11348800E+01, -.51686500E+00, -.66589100E+00, 0.58845000E+00, -.62410400E+00, -.10637900E+01, 0.96032100E+00, 0.37266200E+00, 0.97699500E+00, -.10451800E+01, -.67033100E+00, 0.64299900E+00, -.44834500E+00, -.42494200E-01, -.17857700E+00, 0.16944500E+01, -.52029800E+00, -.17021400E+01, -.23300100E+00, 0.81552200E-01, -.67065500E+00, 0.60203500E+00, 0.45181000E+00, 0.14173700E+00, -.65422200E-01, -.10506300E+00, -.66400200E-02, 0.68315300E-01, 0.72419200E-01, 0.25278400E+00, -.29238500E-01, 0.86631200E-01, -.32332000E+00, -.18808000E+00, -.84306000E-01, -.89611700E+00, -.13851700E+01, 0.90436100E+00, 0.14702900E+00, -.29710600E+00, -.93987200E-02, 0.24224400E+00, -.99176000E-01, 0.66779200E-01, -.41353300E+00, 0.19495400E+00, -.25519800E-01, 0.11118000E+00, -.15696300E+00, -.10716200E+00, -.34893600E+00, -.20148300E+00, 0.77434400E-01, 0.17047300E-01, -.11190600E+00, 0.11383900E-01, -.24160800E+00, -.69861000E+00, 0.25040600E+00, -.13166400E+00, 0.78880700E-01, 0.31712600E-01, 0.90063600E-02, -.22511300E+00, 0.16904500E+00, -.56132600E+00, 0.10381200E+00, -.10776800E+00, 0.17806100E+00, -.50740800E-01, -.54746100E-01, -.36571600E+00, 0.61533000E-01, 0.64821000E+00, -.11224700E+00, -.40119100E+00, 0.52410600E-01, -.48822400E+00, -.24970000E+00, -.75364600E+00, 0.15591700E+00, -.27383200E+00, -.14952800E+00, 0.53514100E+00, 0.27303500E-01, -.82515100E-01, -.35743300E+00, -.26867100E-01, 0.27075300E+00, -.15417200E+00, -.92635100E-01, -.33225300E-01, 0.17704200E-01, 0.42006300E+00, 0.14336800E+00, 0.12231100E+00, 0.61630000E-01, 0.13578900E+00, -.13436300E+00, -.51336700E-01, 0.36290400E+00, -.73136600E-01, -.29888300E-01, -.11663600E+00, -.48532500E+00, 0.11662000E-01, -.70029200E-02, -.27462500E-01, 0.72270000E-01, -.80639400E-01, 0.14817500E+00, 0.22672800E+00, -.48337700E+00, 0.70085500E-01, 0.21127700E-01, -.47949900E+00, -.27251900E+00, 0.50014000E+00, 0.32409200E+00, 0.44645500E+00, 0.41513500E-01, -.21749300E+00, -.26826500E-01, -.98049100E-01, 0.32516200E-01, -.27382500E-01, -.66869200E-03, -.98626300E-01, -.90430600E-01, 0.16997100E+00, -.55873800E+00, -.18470400E+00, 0.39414400E+00, -.25215900E+00, 0.28335800E-01, -.63381200E+02, 0.11130400E+02, 0.18457600E+02, 0.90272700E+02, -.32247600E+02, -.26045500E+03, 0.14101800E+03, 0.13360800E+03, -.44898200E+02, 0.18270700E+02, 0.10339900E+03, 0.77334700E+02, 0.12242300E+03, -.22221500E+02, -.11909100E+03, 0.49180300E+02, 0.34113700E+02, 0.21042200E+02, -.85458500E+01, 0.30046300E+02, -.25138600E+02, 0.14019600E+03, 0.17318100E+02, 0.11866300E+03, -.62237100E+02, -.60298600E+02, -.11677900E+02, -.30436600E+02, -.40181000E+02, -.55951100E+01, -.80599600E+02, -.49642600E+02, -.11551900E+02, 0.44823300E+01, 0.76962500E+01, 0.13855200E+02, 0.12037000E+03, -.19567200E+02, -.33253400E+02, -.13482200E+03, 0.92132100E+02, -.32830200E+03, 0.14107400E+03, 0.16725100E+03, 0.17249400E+01, -.10183100E+02, 0.10228600E+03, 0.63796200E+01, 0.19976700E+03, 0.13997500E+02, 0.63858500E+01, -.18018900E+02, 0.53694000E+01, -.59721600E+01, -.73041400E+01, -.33845700E+01, -.16982600E+01, 0.10501100E+02, -.78465400E+01, -.11233900E+02, -.10596900E+02, -.11081700E+02, -.69515500E+01, -.32966500E+01, -.55994600E+01, -.65098500E+01, 0.19777500E+01, 0.80873500E+01, -.11215200E+02, -.14480900E+01, 0.46781800E+01, -.16326200E+02, -.22218400E+02, 0.15598100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.69451600E+01, -.76189200E+01, -.42259500E+01, 0.74824400E+01, -.12872700E+01, -.56054200E+01, 0.96453800E+01, 0.27460800E+01, -.30281500E+01, 0.28927800E+01, 0.43342800E+00, -.37914800E+00, 0.15804800E+01, 0.16125600E+01, 0.16983900E+01, -.20599600E+01, -.24376000E+01, -.24940300E+01, -.34209900E+01, 0.34710500E+01, -.14999700E+01, 0.73258700E+00, -.16337600E+01, 0.26125700E+00, -.30163400E+01, 0.64477700E+01, 0.15934200E+00, -.61870800E+01, -.13527900E+01, 0.22617000E+01, 0.20633300E+01, -.14346600E+00, -.37218100E+00, -.32796000E-01, 0.82894700E+00, -.93987500E+00, 0.49478100E+01, 0.91034500E+01, 0.49092100E+00, 0.67757100E+01, 0.32275000E+00, -.29608500E+01, 0.92706300E+01, -.41275200E+01, 0.37514100E+01, -.20154500E+01, -.58099600E+00, -.17627500E+01, -.43321400E+01, -.37265900E+01, 0.33308900E+00, -.51475400E+00, 0.15269600E+01, -.34234800E+01, 0.51691100E+01, 0.18532500E+01, 0.16345100E+00, -.58189800E+01, 0.28995900E+01, -.26884100E+01, -.14221800E+00, -.72161200E+00, 0.78575000E+00, -.21857700E+01, -.51233900E+00, -.79349600E+00, -.18622600E+01, -.34831000E+00, -.12111200E+01, 0.38622200E+01, 0.65633500E+00, 0.17075200E+00, -.46268200E+01, -.10822600E+01, -.70885200E+00, 0.10589000E+00, -.12893400E+01, -.18301800E+01, 0.52999500E+00, -.47263300E+01, -.59538100E+00, 0.70412700E+00, -.12139100E+00, -.36899000E+00, -.10666100E+00, 0.60048300E+00, 0.97925400E+00, -.40651900E+01, 0.23530900E+00, -.24392700E+01, 0.40750900E+00, -.99517400E+00, 0.28075100E+00, 0.12080400E+01, 0.58909000E+00, 0.15794300E+01, -.28325100E+00, -.42762600E+00, 0.11203500E+00, -.92485800E-01, -.32564200E+00, -.25231700E+01, -.74432500E+00, 0.29380900E+00, -.77213100E-01, 0.56035400E+00, -.72311000E+00, 0.61484900E+00, 0.11783500E+01, 0.16879600E+01, 0.21114300E+00, 0.11078700E+01, 0.76990000E+00, -.10948700E+01, -.13204800E+01, 0.22051300E-01, 0.39027200E-02, -.38151200E+01, -.40740700E+00, -.23085700E+01, 0.49922300E+00, -.53635600E+00, -.12041000E+01, 0.31848300E+01, 0.23882000E+01, -.79184300E+00, 0.20103100E+01, 0.28049400E-01, 0.53171700E+00, 0.77215200E+00, -.14364500E+01, -.50133300E+00, 0.74726000E+00, 0.40602600E+00, 0.11114600E+01, 0.16078800E+01, 0.54190700E-01, -.46272800E+00, -.13538600E+01, 0.10606300E+01, 0.11658900E+01, 0.19027500E+01, -.61687100E+00, 0.25520400E-01, -.58444800E+00, -.31836200E+00, 0.19578500E+00, 0.56999900E+00, 0.37188000E+00, 0.93233000E-01, -.71751800E-01, -.40577300E+00, 0.34108700E+01, -.28582100E+00, 0.86768600E+00, 0.41695100E+00, 0.57672000E-01, -.78995900E+00, -.29321900E+02, -.24029600E+01, 0.15698100E+03, -.14134500E+02, -.13232600E+04, 0.69947600E+03, 0.68386300E+03, -.24282600E+03, -.96558600E+02, 0.52966900E+03, 0.36211300E+03, 0.55995800E+03, -.16884600E+02, 0.11791800E+03, -.51354900E+02, -.50627900E+02, -.56143500E+02, -.12985200E+03, 0.35734200E+02, 0.74621200E+02, 0.28010700E+03, -.12161600E+03, 0.22515200E+02, -.12144500E+02, -.51971900E+01, -.58406100E+02, -.41198200E+02, -.24898100E+02, -.37360200E+02, -.11565100E+03, -.68108500E+02, 0.98168000E+02, -.54480500E+02, -.47606900E+02, -.35327600E+02, 0.65218800E+02, -.98074800E+01, 0.45571800E+01, -.15265500E+03, 0.76662000E+02, -.19669600E+03, 0.74646100E+02, 0.10074000E+03, 0.52279800E+02, -.20913000E+02, 0.60667200E+02, 0.17835100E+01, 0.12583300E+03, 0.17329400E+02, 0.92413300E+01, -.63192900E+02, 0.19866200E+02, -.29293700E+02, 0.10133600E+02, -.82485500E+01, -.25130800E+02, 0.31301200E+02, -.32476800E+02, -.42886000E+02, -.12812500E+02, -.36788600E+02, -.16997600E+02, -.54003400E+01, -.19254700E+02, -.30075700E+02, -.27067100E+02, 0.31374600E+02, -.10685800E+02, 0.36659100E+02, -.10642700E+02, -.32424700E+02, -.29642800E+02, 0.51803000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17961100E+01, 0.12719300E+01, 0.52855500E+00, -.32362000E+01, -.71327500E+00, 0.30267400E+01, -.28732200E+01, -.90799600E+00, 0.12579000E+01, -.10158500E+01, -.30333600E+00, -.43546200E+00, -.70193500E+00, -.13127700E+01, -.78953700E+00, 0.24327400E+01, 0.72021700E+00, -.97147200E+00, 0.19178200E+01, -.36604500E+01, -.81004100E+00, -.20868000E+01, 0.10428100E+01, 0.32944000E+00, 0.47178900E+00, -.16587500E+01, -.23947200E+01, 0.26396800E+01, -.13520100E+01, -.11867700E+01, -.12312300E+00, -.14453500E+01, 0.19918500E+00, 0.34026200E+00, -.15550800E+01, 0.51784500E+00, 0.17896900E+01, -.46573000E+01, 0.11791500E+01, -.17777100E+01, -.21031200E+00, -.52299800E+00, 0.12441200E+01, 0.28177800E+01, 0.52203500E+00, 0.31525000E+00, 0.24730300E+00, 0.44090300E+00, -.10437300E+01, 0.21450100E+01, 0.55134200E+00, 0.12000800E+01, 0.12628300E+01, 0.15330700E-01, -.91517500E+00, -.21615900E+00, -.10037900E+00, -.53228200E+00, -.26686600E+01, 0.13788000E+01, 0.24128400E+00, 0.18674300E+00, -.95718200E-01, 0.63305600E+00, 0.59414200E+00, 0.73732200E-01, 0.32566200E+00, 0.10499100E+00, -.46006200E-01, 0.23108500E+01, -.35461500E+00, -.23738100E+00, 0.10835700E+01, -.14255000E+01, -.21405500E-01, -.24882100E+00, -.10067300E+00, -.91996500E-01, 0.24109600E+00, 0.28728500E+00, -.47060500E+00, 0.35026500E-01, -.24472500E+00, -.50370500E-01, 0.10480400E+00, 0.56974500E+00, 0.12521600E+01, 0.55036900E+00, -.34190700E+00, 0.68621900E+00, -.39808100E-01, -.23505800E-01, 0.16897300E+00, 0.11484900E+00, -.78191900E+00, -.81095900E+00, 0.14260500E+00, 0.71300800E+00, -.18794600E+00, 0.10122200E+01, 0.17208900E+00, -.72968000E-01, -.12384500E+01, 0.37014800E+00, -.55454000E-01, -.32828400E+00, 0.74494100E+00, -.67820500E+00, -.48037600E+00, -.48394300E+00, 0.29924200E-01, -.55229500E+00, -.55654800E+00, 0.25803900E+00, 0.31658300E+00, -.36144200E+00, 0.10099800E-01, -.32580800E+00, 0.42914100E-01, -.50514700E+00, -.39629500E-01, 0.69660700E+00, -.56095500E+00, 0.72930300E+00, -.28456000E+00, 0.12237300E+00, -.48053000E+00, -.10387900E-01, 0.72198100E-01, -.11894200E+00, 0.25512600E+00, 0.22246200E+00, -.12219300E+01, -.53896400E-01, 0.13655900E+00, -.15932400E+00, -.15404000E+00, 0.94658400E+00, -.25847600E+00, -.16630100E+00, -.42315500E+00, 0.46589400E-01, -.17748400E+00, 0.47587300E+00, -.42167000E-01, 0.35808100E-01, 0.42015600E-01, -.29143700E+00, 0.70579500E+00, -.91231900E+00, -.62576100E-01, -.28855200E+00, -.11725600E+00, 0.54281300E-01, 0.35754600E+00, -.97884800E-01, 0.11783600E+00, 0.10813200E+01, 0.17079400E+00, -.41377600E+02, -.12485800E+03, 0.10044100E+02, 0.53934900E+03, -.29728000E+03, -.27648500E+03, 0.48957200E+02, -.11123500E+02, -.18860200E+03, -.11783700E+03, -.21219300E+03, 0.15459100E+02, -.20860500E+03, 0.99425400E+02, 0.12697400E+03, 0.11943700E+02, 0.77980200E+02, 0.51833700E+02, 0.64127100E+02, -.63724200E+02, 0.13852300E+02, -.12333400E+03, 0.62454300E+02, 0.61476400E+02, 0.38031200E+02, 0.44691300E+02, 0.42142500E+02, 0.19810700E+02, 0.90728600E+02, 0.57865200E+02, -.16731100E+03, 0.87054700E+02, 0.82166000E+02, 0.50777100E+00, -.42308400E+02, 0.64962000E+02, 0.80531600E+02, 0.23961900E+03, -.65384000E+02, 0.20115900E+03, -.66066900E+02, -.10051300E+03, -.18788200E+02, 0.24862400E+02, -.47399500E+02, 0.20688500E+02, -.15981900E+03, -.91668600E+01, -.56365400E+01, 0.24621700E+02, -.10483700E+02, 0.71367900E+01, -.15162200E+02, 0.78436200E+01, 0.55685000E+01, -.16906100E+02, 0.10302600E+02, 0.21654600E+02, 0.66838600E+01, 0.22020400E+02, 0.79504300E+01, -.15232700E+01, 0.39460300E+01, 0.13277500E+02, -.77155400E+00, -.10560100E+02, -.13288300E+02, -.85030900E+01, 0.13334100E+02, 0.19085600E+02, 0.77550000E+00, -.17661200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.39103100E+01, 0.28507300E+01, 0.26620600E+01, -.10841600E+02, 0.11095900E+01, 0.10359100E+02, -.13788300E+02, -.34191500E+01, 0.12563000E+01, -.35711500E+01, 0.11520100E+01, 0.22901400E+01, -.38209800E+00, 0.21666900E+01, -.38783300E+01, 0.69031400E+01, 0.43631400E+01, 0.88047300E+00, 0.72332700E+01, 0.83232400E+01, 0.19414700E+01, 0.17380500E+01, 0.28950100E+01, -.28718700E+01, 0.45897800E+01, -.68044100E+01, -.27750100E+01, 0.22087300E+01, -.35521500E+01, -.28146600E+01, 0.10432000E+01, -.13543400E+00, -.52110300E+00, 0.67119100E+00, -.37883900E+00, 0.21029400E+00, -.35658300E+01, -.12280400E+02, 0.69527200E+00, 0.31875100E+01, -.94848200E-01, 0.64680000E+01, -.60721500E+01, 0.35105400E+01, -.21328900E+01, 0.17210200E+01, -.29246500E+00, 0.14847300E+01, -.22215700E+01, 0.21855600E+01, -.60357000E+00, -.18155700E+00, 0.50465800E+01, 0.13945500E+01, 0.23336500E+01, -.14325400E+00, 0.21572700E+00, 0.81197400E+01, 0.49751300E+01, -.13493800E+01, -.12830400E+01, -.70708600E+00, -.91426300E+00, 0.21941300E+00, 0.59445300E+00, -.50203200E+00, -.35993000E+00, -.41929900E+00, 0.27860100E+00, -.10616800E+02, 0.92732900E+00, 0.39797900E+00, 0.31655400E+00, -.39490300E+01, 0.11824000E+01, -.60765000E+00, 0.71229900E+00, 0.18556800E+01, -.16046700E+01, 0.28602600E+01, -.13640300E+00, -.33127500E+00, -.10295100E+00, -.11843400E+01, 0.31642700E+00, 0.12014000E+01, 0.24253500E+01, 0.52629700E+00, -.97831500E+00, 0.16296700E+01, 0.10948600E+01, -.97902100E-01, 0.12663500E+00, 0.25859700E+01, 0.14191200E+01, -.30880700E-01, 0.16556300E+00, -.34503100E+00, -.29939600E+00, 0.14508900E+01, -.73828700E+00, -.28814400E+01, -.12624900E+01, 0.12467900E+01, -.65499400E+00, -.41271300E+00, 0.11224400E+01, -.45281800E+00, -.66300900E+00, -.59693900E+00, 0.45463200E+00, -.10059500E+01, -.22663500E+00, -.23422000E+00, 0.33968100E+00, 0.75326400E+00, 0.50353600E+00, -.12375000E+00, -.29232700E-01, -.50625500E+00, 0.63131200E+00, 0.14365800E+00, -.25934400E+00, 0.10100900E+01, 0.56965000E+00, -.54630900E+00, 0.19859300E+00, 0.37403600E-01, -.12179200E+01, -.87315200E-01, 0.94793700E+00, -.75884000E+00, -.33001100E+01, -.73015500E+00, -.60225800E+00, 0.29164100E+00, -.24831700E+00, 0.49964700E+00, 0.90989500E+00, 0.71091900E+00, 0.65765600E+00, -.99118900E-01, 0.32626700E+00, 0.40972000E-01, 0.54392300E+00, -.12382600E+00, -.97513700E-02, 0.11167900E+00, 0.99414200E+00, -.17836900E+01, -.23419900E-01, -.13464200E+00, -.14727500E+01, -.59012600E+00, 0.91398900E+00, 0.97626300E+00, 0.18359100E+00, -.60704900E+00, 0.62976400E-01, 0.77626700E+00, 0.20367700E+03, 0.22412200E+02, -.37145700E+03, 0.19563100E+03, 0.21041700E+03, -.15630300E+02, 0.51385000E+01, 0.13778800E+03, 0.80101900E+02, 0.18190000E+03, -.10679300E+02, -.14700100E+03, 0.57884800E+02, 0.77933100E+02, 0.13953400E+02, -.61097300E+01, 0.36460100E+02, -.85909600E+02, 0.70306400E+02, 0.35806900E+02, -.18107600E+02, 0.80993000E+01, 0.15063400E+02, -.22633300E+02, -.18854900E+02, 0.20887000E+02, 0.66282900E+02, -.10629100E+03, -.59796800E+02, 0.15106900E+03, -.77632000E+02, -.72049600E+02, -.40695800E+02, -.95782000E+01, -.30364100E+02, -.99601800E+01, -.21118800E+03, -.10195800E+02, -.34309200E+03, 0.14633900E+03, 0.16802600E+03, 0.10679500E+02, -.15950800E+02, 0.84987600E+02, -.42527900E+02, 0.13834500E+03, 0.65537500E+02, -.28885900E+01, 0.40160700E+01, 0.66234100E+01, -.51214500E+01, -.25904100E+02, -.20724400E+02, 0.50009900E+01, 0.99300400E+01, -.73005600E+01, -.79999800E+01, -.10766500E+02, -.99893500E+01, -.11226400E+02, 0.22172900E+01, 0.20593500E+01, -.51306200E+01, 0.19475700E+02, 0.70728100E+01, -.12216500E+01, -.14478100E+02, 0.23338800E+02, -.11029300E+02, 0.45316200E+00, -.15475800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13052200E+01, 0.20798100E+00, 0.41130900E+00, 0.16911900E+01, 0.26642000E+00, -.11938300E+01, -.29606300E+00, -.26841800E+00, 0.54663800E+00, -.31217200E+00, -.36327000E+00, -.61098300E+00, -.44005200E+00, -.14980200E+01, 0.42299900E+00, -.17015500E+01, -.35563000E+00, 0.97837800E+00, -.72408100E+00, -.27749000E+01, 0.51535000E+00, -.31796700E+00, -.96402200E-01, 0.84954000E+00, 0.56655500E+00, -.22481300E+01, 0.11408200E+00, 0.87979400E+00, 0.78267900E+00, -.62895600E+00, -.19586500E+00, 0.25144200E+00, 0.54374800E-01, -.12073300E+00, -.37760900E+00, 0.26899100E-01, -.57159300E+00, 0.18698800E+01, 0.14407500E+00, -.35624800E+00, 0.25071400E-01, -.56736700E+00, -.20325000E+00, -.18105900E+00, 0.22443800E+00, 0.11915600E+00, 0.98255900E-01, 0.11287700E+00, 0.13678500E+00, 0.71461900E+00, -.18750000E+00, -.50046800E+00, -.48718200E+00, -.71264200E-01, -.85932400E+00, -.65443100E+00, 0.66982500E-01, -.51415100E-01, -.94466900E+00, 0.36337800E+00, 0.24287000E-02, 0.75682800E-01, -.55435600E-01, 0.19109800E+00, 0.15072200E-01, 0.23583600E+00, 0.37586000E+00, 0.42419100E+00, 0.10981700E+00, -.31704400E+00, -.60476100E-01, -.32740700E+00, 0.23289400E+00, -.60140300E+00, 0.21522600E+00, -.12948800E+00, -.30356500E+00, 0.55206800E-01, -.49271100E-01, -.79045200E+00, -.19175400E+00, 0.27810400E-01, -.11835300E+00, -.22407900E+00, 0.88722700E-01, 0.78179500E-02, 0.51099800E-01, 0.16465600E+01, 0.76202800E-01, -.22358000E+00, 0.47914900E-01, -.16090400E+00, 0.39099200E-01, 0.27312800E+00, -.24247400E+00, 0.49058700E-01, -.10643500E+00, 0.31798000E+00, -.81738600E-01, -.29491700E+00, 0.11686800E+00, -.15887200E+01, -.41774700E+00, 0.10816500E+00, -.84388700E-01, -.97213200E-01, -.25797100E+00, -.32958300E-01, -.95126200E-01, -.36976600E-01, -.79618300E-02, -.47981800E-01, 0.85055800E-01, 0.89069500E-01, -.26022100E-01, -.72359000E-01, 0.42709900E-01, -.25904600E+00, 0.28631400E-01, -.10394500E+00, -.73125400E-01, 0.17362500E+00, 0.46502500E-01, -.12290500E+00, -.13259800E+00, 0.12496800E+00, 0.96472600E-01, -.10483000E-02, -.98261500E-01, -.11598300E+00, 0.13271100E+00, 0.14309900E+00, -.22365700E+00, -.35526900E+00, 0.15093900E+00, -.17344000E+00, -.71862500E-01, 0.90690800E-01, -.37427400E-02, 0.42265200E-01, -.34082900E+00, 0.89604000E-01, -.86959500E-02, 0.17365100E+00, -.15822900E+00, 0.30141400E-01, -.10113300E-01, 0.10397900E+00, -.13865300E+00, 0.28005300E+00, 0.96865300E-01, -.34322400E+00, -.75598900E+00, 0.38118600E+00, 0.15395000E+00, -.11916700E+00, -.66792900E-02, -.39142100E+00, 0.42259000E-01, 0.15402400E-01, -.14848100E+00, 0.18831400E+02, -.17711100E+03, 0.10029200E+03, 0.87264000E+02, 0.19218400E+01, 0.10443000E+02, 0.61803200E+02, 0.34822800E+02, 0.82410000E+02, -.69361200E+01, -.75757700E+01, -.14640000E+01, -.10716300E+02, 0.67906600E+01, -.18405400E+02, -.14387300E+01, -.42514500E+02, 0.38991400E+02, 0.10777100E+02, 0.10119100E+03, -.51923500E+02, -.51130800E+02, -.61339200E+01, -.22957000E+02, -.35474400E+02, -.12523000E+02, -.48953000E+02, -.28243800E+02, 0.50724500E+02, -.26538700E+02, -.24413100E+02, 0.94084000E+01, 0.37383400E+02, -.30115700E+02, -.35554800E+02, -.85959400E+02, 0.14074500E+02, -.12780200E+03, 0.43524800E+02, 0.65942600E+02, -.34952300E+00, -.32756300E+01, 0.32379900E+02, -.81282300E+01, 0.92478800E+02, 0.91749300E+01, -.91533400E+00, 0.43887300E+00, 0.15369600E+01, 0.10982900E+00, -.55880900E+01, -.61837200E+01, 0.36771200E+01, 0.33533700E+01, -.19927700E+01, -.29836400E+01, -.95371700E+00, -.47688100E+01, -.35322000E+01, 0.36376000E+01, -.98894200E-01, 0.35285600E+00, 0.10661400E+02, 0.22918500E+01, 0.17439200E+01, -.40485300E+01, 0.55367800E+01, -.78252000E+01, 0.22039400E+01, -.17327200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18404600E+01, -.14982500E+01, -.90755200E+00, 0.45767400E+01, 0.32466500E+00, -.35740500E+01, 0.54203800E+01, 0.11948800E+01, -.18622200E+01, 0.16911900E+01, 0.24792800E+00, -.39310700E+00, 0.92016400E+00, 0.70379600E-01, 0.69248100E+00, -.22635100E+01, -.20873200E+01, -.13491100E+00, -.33268400E+01, -.24056000E+00, -.96261300E+00, 0.50646000E+00, -.23231000E+00, 0.92180300E+00, -.21311600E+01, 0.39721300E+01, 0.48303300E+00, -.28827900E+01, -.39383400E+00, 0.14346700E+01, 0.12392600E+01, -.97377100E+00, -.76021700E-01, 0.25458200E+00, 0.11562900E+01, -.81958600E+00, 0.66658000E+00, 0.17140300E+01, 0.35470700E+00, 0.43982200E+01, 0.36674600E+00, -.14944300E+01, 0.38466300E+01, -.13728900E+01, 0.15601000E+01, -.14019100E+01, -.24990600E-01, -.25717200E-01, 0.36251300E+00, 0.42704100E+00, -.66345200E-01, -.18785900E+01, -.83728500E+00, -.18743900E+00, -.36231200E+00, -.63492100E+00, 0.28255500E-01, 0.14770200E+00, -.11843200E+01, -.39891600E+00, 0.11750400E+00, 0.64562800E+00, 0.10267800E+00, -.65203200E-01, 0.10539700E-01, -.25847900E+00, 0.31452700E+00, -.56311800E+00, 0.14566400E-01, 0.92391200E+00, -.40384700E-01, 0.52768700E-01, 0.11047400E+01, 0.38765900E+00, -.74065900E+00, 0.46271900E+00, 0.12126200E+01, 0.50200600E+00, -.23035100E-01, 0.41905600E+01, -.16921200E+00, -.84794500E+00, -.77117200E-02, 0.49241700E+00, -.10324100E+00, 0.64264000E+00, 0.36159600E+00, -.19552000E+01, -.46663400E+00, 0.28105500E-01, -.49581200E+00, 0.13137800E+00, 0.14840200E+00, 0.66304400E+00, -.26049300E+00, -.21620700E+00, -.62044400E-01, 0.50372400E+00, -.41642500E-01, 0.83956000E-01, 0.22882800E+00, -.19784700E+01, -.13726100E+01, 0.35077400E+00, -.14210300E+00, -.27637000E+00, 0.38220800E+00, -.21574300E+00, -.86947900E+00, -.28768000E+00, -.10501900E+00, 0.31342100E+00, 0.21639900E+00, 0.15989500E+00, 0.32650100E+00, -.55375900E+00, -.12062600E+00, 0.46959000E+00, 0.10234500E+00, -.15230000E-01, -.96150600E-01, 0.39476400E+00, 0.32355100E+00, -.20911000E+00, -.11711600E+00, 0.35145500E+00, -.45272800E+00, -.63190400E-02, 0.22137900E-02, 0.17346600E+00, 0.12670500E+00, 0.27814700E+00, 0.92057400E+00, 0.99863900E-01, 0.64965000E-01, -.18100900E+00, -.42602800E-01, 0.20426000E+00, -.25219000E+00, -.34783000E+00, -.12240400E+00, -.12396200E+00, 0.62597000E+00, -.42531400E+00, -.15455300E-01, -.39457800E-02, 0.22350100E-01, -.54748800E+00, 0.79536600E-01, 0.33125700E+00, -.16368000E-01, -.12074700E+00, 0.27829100E+00, 0.39651700E+00, -.31965700E+00, 0.18936600E+00, -.73245100E-01, -.15212300E+01, 0.10538900E+00, 0.76880800E+00, -.41514100E-01, -.52741600E-01, -.57822000E+03, 0.33093000E+03, 0.30110200E+03, -.10704800E+02, 0.28956000E+02, 0.19288700E+03, 0.11389700E+03, 0.21076400E+03, -.42255500E+02, 0.38287200E+03, -.19072400E+03, -.24375300E+03, 0.20093000E+02, -.80380500E+02, -.15071700E+03, -.18052300E+03, 0.23565200E+02, 0.43139000E+02, 0.12726400E+03, -.68144500E+02, -.65935000E+02, -.55158600E+02, -.77998400E+02, -.27177500E+02, 0.88797700E+01, -.63816700E+02, -.74088200E+02, 0.12647600E+03, -.68132900E+02, -.59538000E+02, 0.35712200E+02, 0.10596000E+03, -.87932800E+02, -.97554800E+02, -.24166000E+03, 0.11549900E+03, -.15409000E+03, 0.90861900E+01, 0.75251700E+02, 0.15505200E+02, -.43175400E+02, 0.27977700E+02, -.20481600E+02, 0.23637800E+03, 0.14273900E+01, 0.91747900E+01, -.40464300E+02, 0.88969300E+01, -.54228900E+01, 0.17603600E+02, -.87098100E+01, -.18417400E+01, 0.17574900E+02, -.11468900E+02, -.19854900E+02, -.55603000E-01, -.24813600E+02, -.71087400E+01, 0.10533100E+02, 0.25853600E+01, -.88635900E+01, 0.14826900E+02, 0.12434900E+02, -.51083700E+01, 0.61270400E+01, -.17359200E+02, -.16954700E+02, -.12520300E+02, 0.28270700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.64366200E+01, 0.51673400E+01, 0.31505100E+01, -.79653400E+01, 0.34203600E+00, 0.72641400E+01, -.76495500E+01, -.26024800E+01, 0.30663400E+01, -.28662100E+01, -.92557800E-01, 0.58109200E+00, -.14578000E+01, -.16034400E+01, 0.71010700E+00, 0.40586800E+01, 0.29601900E+01, 0.17144300E+00, 0.22752600E+01, -.64848600E+01, 0.63486000E+00, -.26534600E+01, 0.92780800E+00, 0.19601900E+00, 0.37155500E+01, -.28786600E+01, -.16249200E+01, 0.38203100E+01, -.25187100E+01, -.14479200E+01, -.13986200E+01, -.26809700E+00, 0.14391700E+01, 0.39363300E+00, -.47145500E-01, -.15412100E+00, -.28646900E+01, -.40480100E+01, 0.70260200E+00, -.80220600E+01, -.39330700E+00, 0.90848600E+00, -.55335900E+01, 0.55844200E+01, -.12148400E+01, 0.20484300E+01, 0.22060000E-01, -.19676600E+00, -.27067800E+00, 0.37854800E+01, 0.42161100E+00, 0.11762000E+01, 0.18230800E+01, 0.36242700E+00, -.89519200E+00, 0.77737400E+00, 0.82167500E-01, -.11459900E+01, -.13245800E+01, 0.32558200E+01, 0.62951500E+00, -.27808900E-01, 0.13101300E+00, 0.58970200E+00, -.43398600E+00, 0.86827900E+00, 0.12677800E+00, 0.28460200E+01, -.51509400E-01, 0.74384800E+00, -.14945800E+01, -.62269500E+00, -.31769400E+01, 0.15190500E+01, 0.90740000E+00, 0.19397300E+00, -.11516100E+01, 0.11600500E+01, -.28581700E+00, 0.19708800E+01, 0.31118000E+00, -.11611300E+01, 0.13898700E+00, 0.10119700E+01, 0.40161100E+00, 0.64826200E+00, -.11400700E+01, 0.38884500E+01, 0.14025500E+01, -.92231500E+00, -.39337600E+00, 0.23845100E+00, -.42237900E+00, -.13176500E+01, 0.41304200E+00, 0.10765100E+00, 0.43728400E-01, 0.20404100E+01, -.52976900E+00, -.53349000E+00, 0.24858600E+00, -.21660300E+01, -.38661200E+00, -.10891100E-02, 0.15473800E+00, 0.53734600E+00, 0.14404900E+00, 0.11364700E+01, -.83241400E+00, -.62458200E+00, 0.49235900E+00, -.93445900E+00, -.79763700E+00, 0.44660700E-01, 0.43942500E+00, 0.25902200E+00, 0.28591600E+00, -.24974100E+00, 0.45762000E-01, -.69632100E-02, 0.15669200E+00, 0.30770000E+00, 0.55892700E-02, 0.49252300E+00, -.50824200E-01, -.16024300E+00, -.63601000E+00, -.12193000E-01, -.12928200E+00, -.18028000E+00, 0.64222600E+00, 0.41706300E-01, -.13137600E+01, -.26350100E+00, -.37310800E+00, -.38574400E+00, -.77309700E-01, 0.26655900E+00, -.39112000E-01, 0.14145000E+00, -.15559100E+00, 0.26204200E+00, -.23064800E+00, 0.80214700E+00, -.38975000E+00, 0.68028200E-01, 0.75790100E-01, -.22224400E+00, 0.14645500E+01, -.35023100E+00, -.17704000E-01, -.33833200E+00, 0.31638700E+00, 0.14468100E+00, -.64297700E-01, -.31470500E+00, -.27399300E+00, 0.99647000E+00, 0.17908000E+00, -.78432600E-01, -.67636100E+00, 0.14760100E+01, -.15837900E+01, 0.82107700E+02, 0.20351500E+02, 0.96236200E+02, 0.72319800E+02, -.34662700E+02, -.34694100E+02, -.28405000E+02, -.38556200E+02, 0.23120900E+03, -.12687600E+03, -.16622200E+03, 0.56925100E+02, -.55885300E+01, -.15074400E+03, -.23533600E+03, -.94784200E+02, 0.12190800E+03, -.60600300E+02, 0.26298300E+02, 0.27637000E+02, -.41005200E+02, -.48268300E+02, 0.65500000E+02, 0.11886900E+03, 0.33168100E+02, -.55867100E+02, 0.32241700E+02, -.82485800E+01, -.11089300E+02, 0.38814400E+02, 0.40650300E+02, -.44557800E+02, -.75528200E+02, -.16628400E+03, 0.71202400E+02, -.47634100E+01, -.62949000E+02, -.50424200E+01, -.16970200E+02, -.50277400E+02, -.19194800E+02, -.28289800E+02, 0.14513800E+03, 0.94731600E+01, 0.11032100E+02, -.20193500E+02, 0.29639200E+01, 0.42020000E+01, 0.49230000E+01, -.73695000E+01, 0.54701700E+01, 0.93828200E+01, 0.85719900E+00, -.56838300E+01, -.19295200E+01, -.12809500E+02, -.25872000E+01, 0.95786400E+01, 0.14069800E+02, 0.52370100E+00, 0.25353500E+02, 0.49231500E+00, -.34567800E+01, -.17383700E+02, -.62850700E+01, 0.12313600E+01, -.34233100E+01, 0.54262000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24292100E+01, 0.19335200E+01, 0.11272100E+01, -.52656500E+01, -.29740600E+00, 0.44070500E+01, -.44911900E+01, -.12739200E+01, 0.28583800E+01, -.20937400E+01, -.71258800E-01, 0.46487800E+00, -.11382400E+01, 0.39184700E+00, -.71967100E+00, 0.45294300E+01, 0.24141100E+01, -.11413700E+01, 0.27893300E+01, -.32074300E+01, 0.26147900E+00, -.16790500E+01, 0.87710200E+00, -.14271700E+00, 0.20080500E+01, -.27054100E+01, -.20910100E+01, 0.22358500E+01, -.13413800E+01, -.11991000E+01, -.43680800E+00, -.57491800E+00, 0.22194400E+00, 0.21804900E+00, -.12796700E+01, 0.49525200E+00, 0.40093500E+00, -.49865000E+01, 0.60750800E+00, -.33024900E+01, -.33731200E+00, 0.39295100E+00, -.15279400E+01, 0.29680700E+01, -.16056500E+00, 0.11588900E+01, 0.11236100E+00, 0.14599400E+00, -.85070900E+00, 0.11934600E+01, 0.34046200E+00, 0.15865300E+01, 0.15480400E+01, 0.17289100E+00, -.91992600E+00, 0.72451400E+00, 0.33495600E-01, -.13067600E+01, 0.87123600E+00, 0.10258600E+01, 0.89424400E-01, -.46929900E+00, 0.10150300E-01, 0.12151000E+00, 0.24539800E+00, 0.76403900E+00, 0.15015400E+00, 0.13690800E+01, -.12205400E+00, 0.16290500E+01, -.10501200E+01, -.12190100E+01, -.21637400E+01, 0.89550100E+00, 0.77606400E+00, 0.15296200E+00, -.64562500E+00, 0.70589200E+00, 0.22989300E+00, 0.10008000E+01, -.11216300E+00, -.25771100E+00, 0.86225500E-01, 0.20731800E+00, 0.54164200E-01, -.43506700E-01, -.21423400E+00, 0.30130900E+00, 0.24318700E+00, -.33541200E+00, -.19576000E+00, 0.17590300E+00, -.15835200E+00, -.25153500E-02, 0.15608800E+00, -.35940900E-01, 0.14612800E+00, 0.67054600E+00, -.19957600E+00, -.90889800E+00, -.92130600E-01, -.34817900E+01, 0.38395600E+00, -.32320400E+00, -.46688400E+00, 0.26241200E+00, 0.82069000E-01, -.22771200E+00, -.66945500E+00, -.22551000E+00, -.19343700E+00, -.64009700E+00, 0.23953000E+00, -.33663700E-01, 0.86441200E-01, -.37338400E-01, 0.25758500E+00, 0.30943500E+00, 0.78112400E-01, 0.28427800E+00, -.12980700E-01, 0.19565000E+00, 0.28075900E+00, -.45529000E+00, -.39618500E+00, 0.48581100E-01, -.61243400E+00, 0.99395900E-02, -.20357300E+00, -.45139400E-01, 0.22193200E+00, -.10161100E-01, -.19744500E+00, -.15301400E+00, -.20896900E+00, -.39973700E+00, -.25436700E-01, -.53815500E+00, 0.57843700E+00, -.13645700E+00, -.17366000E+00, -.93325700E-01, 0.25847500E+00, 0.54776700E+00, 0.27147300E+00, -.92865100E-01, 0.44578400E-01, -.41175800E+00, 0.24056200E+00, -.83218300E-01, -.15777600E+00, 0.41312500E-01, 0.35107500E-01, -.60295300E-01, -.79684300E-01, 0.10933000E+00, 0.77019500E-02, -.42467800E-01, 0.10765500E-01, -.55747000E+00, -.23756300E+00, 0.90626100E+00, -.78757600E+00, 0.71600000E-01, 0.15492800E+02, 0.12110500E+02, 0.14453200E+02, -.98698700E+01, -.86426200E+01, -.18661800E+02, -.15535900E+02, 0.14811800E+03, -.74452200E+02, -.76781800E+02, -.11318100E+01, -.81301500E+01, -.62404800E+02, -.53423000E+02, -.12071600E+02, 0.12708900E+02, -.18303800E+03, 0.89691200E+02, 0.92978900E+02, -.31927800E+02, -.64553200E+01, 0.83140900E+02, 0.71445300E+02, 0.92967900E+02, -.13715800E+02, 0.26000500E+02, -.14709000E+02, -.10821400E+02, 0.10094700E+02, 0.13663900E+02, -.23410500E+02, -.23087900E+02, -.60055600E+02, 0.25556100E+02, 0.16240200E+03, -.95770100E+02, -.85539900E+02, 0.17511800E+02, -.12196800E+02, -.52463700E+02, 0.13263100E+02, 0.11800800E+02, -.17002100E+01, 0.41183700E+00, -.29742600E+02, 0.13230200E+00, -.37763700E+01, 0.73099900E+01, 0.37692100E+01, -.15022500E+01, 0.98306600E+00, -.52961700E+01, -.44357700E+00, 0.70167800E+01, -.24612800E+01, 0.12474000E+01, 0.88104400E+01, 0.90043700E+01, 0.16607500E+01, 0.62358300E+01, 0.50925300E+01, -.50184100E+01, 0.88000100E+01, -.67549400E+01, 0.81891400E+01, -.51876500E+01, 0.21414500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.15698400E+01, 0.14053900E+01, 0.72202500E+00, -.41064500E+01, -.65475400E+00, 0.34595400E+01, -.45889200E+01, -.11591200E+01, 0.51718100E+00, -.15058400E+01, 0.36563800E-01, 0.32233200E+00, -.62231800E+00, 0.35192800E+00, -.11155200E+01, 0.29159500E+01, 0.18266400E+01, -.40534100E+00, 0.24877200E+01, 0.18099600E+00, 0.56548500E+00, -.26353900E+00, 0.85005500E+00, -.53282500E+00, 0.15131900E+01, -.35831300E+01, 0.64326700E-01, 0.24485300E+01, -.87926700E-01, -.11647100E+01, -.58363400E+00, -.97521700E-02, -.16521800E+00, -.17948800E-01, -.52465500E+00, 0.52931700E+00, -.15331200E+01, -.16448600E+01, -.13730700E+00, -.23959400E+01, -.35641300E+00, 0.70180800E+00, -.17156700E+01, 0.10166700E+01, -.68627900E+00, 0.61496200E+00, 0.18183400E+00, 0.72796200E+00, -.17555500E+01, 0.11913200E+01, -.17113900E+00, 0.42034200E-01, 0.15813100E+01, 0.82054100E+00, -.48540400E+00, -.75207300E+00, 0.33287000E-01, 0.89223800E-01, -.10292800E+01, 0.28549300E+01, 0.22021000E+00, -.46758700E+00, -.22127400E+00, 0.48182900E+00, 0.76450700E-03, 0.29934200E+00, -.56248200E+00, -.61201500E-01, 0.17623300E+00, 0.69047600E+00, -.10329600E+00, 0.10928300E+01, 0.63343000E-02, 0.62027600E+00, 0.20544600E+00, 0.68003600E-02, 0.50581700E-01, -.38832400E+00, -.47923900E+00, 0.79942700E+00, 0.41273300E+00, -.61443100E+00, -.30216000E-01, 0.22234600E-01, 0.11892800E-01, 0.10420700E+00, 0.67858200E+00, -.28508200E+01, -.37916000E+00, 0.17333700E+00, -.14418000E+00, 0.74093900E-01, 0.25320200E-01, -.18167300E+00, 0.40816700E+00, 0.85161100E+00, 0.13616800E-01, 0.18072600E+00, 0.26185400E-02, 0.11257300E+00, -.49798600E+00, -.13532000E+01, 0.53744300E+00, -.26411700E-01, 0.83841700E-01, -.38264800E-01, -.43809700E-01, 0.45768800E+00, 0.18868300E+00, -.11511400E+00, -.41161800E+00, -.11998900E+00, -.21789700E+00, 0.78586900E-01, 0.37873200E-01, -.12990000E+00, -.18149100E+00, 0.65616300E+00, 0.36260400E-01, -.32639400E+00, 0.45474400E-02, 0.38705800E+00, -.85526700E-02, -.21231100E+00, 0.14696900E+00, 0.13379100E+00, 0.66232400E+00, 0.12904800E-01, -.17439800E-01, -.14846400E+00, -.67581400E+00, -.25217500E-01, 0.39544200E+00, 0.13670600E+00, -.27817500E+00, -.45714900E+00, 0.10521100E+00, -.95434300E+00, -.21956300E+00, 0.12469200E+00, 0.48115400E+00, 0.10755200E+00, 0.50796500E+00, 0.26184500E+00, -.26644700E-01, -.25174300E-01, 0.64151100E-01, -.23487700E+00, 0.25618800E+00, 0.41174700E+00, -.58018600E-01, -.89548400E-02, 0.68344800E+00, 0.13118300E+00, -.32535700E-01, 0.22907200E+00, -.19104200E+00, -.13567400E+01, -.81583600E-01, 0.11689500E+00, 0.54778600E-01, -.39738900E+00, 0.89326800E+00, -.30771700E-01, 0.24290900E+00, -.59611200E+02, -.15863200E+01, 0.13722200E+02, 0.23978100E+02, 0.12585600E+02, 0.17408400E+02, -.11913500E+03, 0.60244600E+02, 0.62178900E+02, -.58230600E+01, 0.63585400E+01, 0.52868000E+02, 0.60009900E+02, 0.36577000E+02, -.26393500E+02, 0.50707500E+01, -.18566400E+01, -.27045400E+01, 0.11242600E+02, 0.15941400E+02, -.86229000E+01, -.22916000E+02, -.32420400E+01, 0.56167900E+01, -.46325200E+02, 0.24055700E+02, 0.22676000E+02, -.50223800E+01, -.16702800E+02, 0.20901500E+02, 0.21666200E+02, 0.43172000E+02, -.17917500E+02, 0.61732900E+02, -.21118400E+02, -.32926900E+02, 0.10396000E+02, 0.13960800E+02, -.11275800E+02, 0.18234200E+02, -.15948700E+02, -.13481500E+02, -.14291400E+01, -.16191300E+01, -.26983300E+01, -.34395300E+00, -.11247500E+02, 0.25766300E+01, -.10126400E+01, -.27210000E+01, 0.81569600E+00, 0.15617500E+01, -.19453000E+01, 0.31780300E+01, -.46021500E+00, -.60515700E+01, -.16564200E+01, 0.61093700E+00, -.72919800E+01, -.12900100E+01, -.35474600E+01, 0.12381600E+02, 0.10806800E+02, -.15294700E+00, -.63330400E+00, 0.52520400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15385600E+01, -.13230700E+01, -.53842800E+00, 0.48547600E+01, -.23772600E+00, -.36558200E+01, 0.35973300E+01, 0.10855400E+01, -.89322000E+00, 0.15507600E+01, -.47035800E+00, -.10730900E+01, 0.29528000E+00, -.26453500E+01, 0.99457400E+00, -.38547600E+01, -.18502000E+01, -.52652000E+00, -.12196700E+01, 0.59079100E+00, 0.51020400E+00, 0.60272500E+00, -.14177200E+01, -.21111800E+00, -.75308700E+00, -.76716300E+00, 0.12603700E+01, 0.73333600E-01, 0.22166500E+01, -.37618200E-02, -.46968400E+00, 0.10832600E+01, -.22705700E-01, -.32529200E+00, 0.15151600E+00, 0.43702900E-01, -.41475700E+00, 0.34532900E+01, -.29435200E+00, 0.80991100E-01, 0.23337300E+00, 0.10318300E+00, -.11047400E+01, -.10483700E+01, -.79048100E+00, 0.10058600E+00, -.62184200E-01, -.67941800E+00, 0.14364400E+01, -.13959800E+01, 0.91107400E-01, 0.10426500E+01, -.12739400E+01, -.21248600E+00, -.17279000E+00, 0.72493100E+00, -.18726500E+00, -.67695000E+00, -.30495400E+01, -.21585900E+01, -.17228700E+00, 0.56022100E-01, -.96663600E-01, 0.42283200E+00, -.43312900E+00, -.55040500E+00, -.65108900E+00, -.94568000E+00, -.62186600E-02, 0.45500900E+00, 0.67463300E+00, -.20241800E+00, -.49804400E-01, -.35388500E+00, -.30210000E+00, 0.64453200E-01, -.14829900E+00, -.22282900E+00, -.48012500E+00, -.10465800E+01, 0.35948400E+00, 0.10987900E+00, -.94203900E-02, 0.11832300E+00, 0.13444900E+00, 0.88971500E+00, -.12533300E+01, 0.20581800E+01, 0.56118300E+00, -.26846200E+00, 0.29551100E-01, -.40374300E-01, -.10851700E+00, -.77463300E+00, -.12612100E-01, 0.16239100E-01, -.47889300E-02, 0.49907400E+00, -.15055400E+00, 0.45077100E+00, -.24539900E+00, 0.36388300E-01, -.29500700E+00, 0.17466000E+00, 0.53660600E-02, 0.13147200E+00, -.21751600E+00, 0.45923300E+00, 0.21310900E+00, 0.36050200E-01, 0.48036800E+00, -.12275700E+00, -.71629600E+00, 0.12309300E+00, 0.11718000E+00, 0.48237700E+00, -.10536200E-01, 0.23051400E+00, -.78241000E-01, 0.11247300E+00, 0.51780500E-01, -.22499400E+00, 0.62552200E-01, 0.42728500E+00, 0.51471500E+00, -.22717000E+00, 0.28154100E+00, 0.86566900E-02, -.42016200E-01, 0.18234000E-01, -.16620600E+00, -.11615500E+00, -.45933700E+00, 0.19238300E+00, -.32397300E-01, 0.96432300E-01, -.55217800E-01, 0.82966600E-01, 0.24119600E-01, 0.17761900E-01, 0.22018200E+00, 0.34611000E+00, -.13505200E+00, -.14959900E+00, -.14523300E+00, 0.62673100E-01, -.80669000E-02, -.34676800E+00, -.13567700E+00, 0.17481600E+00, 0.50236400E-01, 0.10769000E+00, 0.45670400E-01, -.19619100E+00, 0.22728900E+00, 0.82230200E-01, 0.15526000E+00, 0.74961700E+00, 0.20496500E+00, 0.16528700E+00, -.16770900E+00, 0.44239400E+00, -.47813400E+00, -.33773700E-01, 0.49661100E+00, 0.89853600E-01, 0.24337000E+02, 0.41104200E+01, 0.12353200E+02, 0.97273900E+01, 0.36767800E+01, -.35568000E+02, 0.10407900E+02, 0.22076700E+02, 0.13209900E+02, -.10733600E+02, 0.54965000E+00, -.26788300E+02, -.10206700E+02, 0.16085300E+02, 0.18426400E+03, -.92117400E+02, -.90908400E+02, 0.94009900E+01, -.25656300E+02, -.71276600E+02, -.36956900E+02, -.44741000E+02, -.50792800E+01, -.31950800E+02, 0.16938300E+02, 0.15611800E+02, 0.33086500E+02, 0.20187600E+02, -.37145100E+01, -.28032400E+02, -.36400100E+02, 0.20408100E+02, -.16435900E+03, 0.81017900E+02, 0.82535500E+02, -.13948000E+02, 0.68781100E+00, 0.46676600E+02, -.22506100E+02, 0.26471500E+02, 0.95090400E+01, 0.14538400E+01, 0.20481900E+02, -.85468400E+00, 0.66792700E+01, -.15670700E+01, -.66245200E+00, 0.37838500E+01, 0.67741600E+00, 0.68557900E+01, -.39450600E-02, -.49023500E+01, -.31963600E+00, 0.75231400E+00, -.38004400E+01, -.26633300E+01, 0.16485900E+01, 0.35570900E+01, -.58419300E+01, 0.16664000E+01, -.87247400E+01, -.65084200E+00, -.50559100E+01, 0.47703900E+01, -.16695300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.71929400E+01, 0.49837500E+01, 0.25601800E+01, -.16193100E+02, -.32069000E+01, 0.13081900E+02, -.16781800E+02, -.42089600E+01, 0.33537100E+01, -.78470100E+01, 0.34452400E-01, 0.20312400E+01, -.33336500E+01, 0.37563000E+01, -.38570100E+01, 0.17090700E+02, 0.10050900E+02, -.27254700E+01, 0.92855700E+01, -.50163500E+01, 0.30154800E+01, -.28575300E+01, 0.53825800E+01, 0.40573300E+00, 0.59091300E+01, -.19656700E+02, -.22081900E+01, 0.12362600E+02, 0.14197600E+01, -.72259300E+01, -.22023300E+01, 0.69864900E+00, 0.77616900E+00, -.23746800E+00, -.63257000E+01, 0.22011100E+01, -.37243900E+01, -.25377000E+01, 0.34958200E+01, -.92907600E+01, -.26527500E+00, 0.70331600E+00, -.71121700E+01, 0.71350300E+01, -.29211600E+01, 0.44894600E+01, 0.58546900E+00, -.88967900E+00, -.35568300E+01, 0.23625300E+01, 0.98588400E+00, 0.58515400E+01, 0.39278400E+01, -.40950500E+00, -.29057900E+01, 0.11450900E+01, -.73911200E+00, -.48765400E+01, 0.62182600E+01, -.31595900E+01, -.11899200E+01, -.36955100E+01, -.89158100E+00, -.68160800E+00, -.15085200E+00, 0.21318500E+01, -.93982200E+00, -.24332800E+01, -.61803000E+00, 0.20992100E+02, -.11595600E+01, -.27668200E+01, 0.74673900E+01, 0.54613500E+01, -.15262800E+01, 0.86019700E-01, 0.66420800E+00, -.17505500E+01, 0.15409300E+01, 0.86706000E+00, 0.65399600E-01, -.11291300E+01, -.13392300E+00, -.36237300E+00, -.64636100E+00, -.20666400E+01, 0.13859800E-01, -.95489000E+01, -.13855000E+01, 0.90204400E-01, -.10984500E+01, 0.15819800E+00, 0.54593200E+00, -.20023800E+01, -.14032000E+01, 0.41267200E-01, 0.31229700E+00, -.79679300E+00, 0.67134200E+00, -.43705300E+00, 0.34397100E+00, -.17100600E+01, 0.30439700E+01, -.11822900E+01, -.32664300E+00, 0.24156000E+00, -.11652100E+01, 0.37355400E+00, -.17858300E+01, 0.73356800E+00, 0.21607300E+00, 0.98567700E+00, 0.26167300E+01, -.19967000E+00, -.26852700E+00, -.77763600E+00, -.85765300E+00, 0.18409500E+01, 0.21118300E+00, -.90104800E+00, 0.44623000E+00, 0.14112300E+01, -.20132100E+00, -.99694200E+00, 0.83798600E+00, 0.86020600E+00, 0.14781600E+01, 0.71938900E-01, -.89633800E-01, 0.10073000E+00, -.18866500E+01, -.28766200E+00, 0.20726200E+01, 0.10363900E+01, 0.37842600E+00, 0.21453200E+00, 0.45816500E+00, -.27932400E+00, -.20409400E+00, -.74809100E+00, 0.28428700E+00, -.13259600E+01, 0.12666000E+01, -.52828300E+00, 0.69077200E+00, -.19767000E+00, -.10229400E+00, -.43051700E-01, 0.10855100E+00, 0.69411100E+00, 0.11559100E+00, 0.35492700E+00, -.85769600E-01, 0.83307300E+00, -.17619000E+01, 0.23869500E+00, -.14654900E+00, -.25398100E+01, -.76642300E+00, -.17507500E+01, -.40360800E+00, 0.67492300E+00, 0.68973500E-01, 0.28274800E-01, 0.61271500E+00, 0.22233700E+00, -.32533500E+01, 0.48353600E+02, 0.59233400E+02, 0.57536300E+02, -.57619300E+01, -.22608200E+03, 0.86869900E+02, 0.13421100E+03, 0.11645800E+03, 0.39985200E+02, -.23864500E+02, -.16449200E+03, -.96305600E+02, 0.15444500E+03, 0.78937200E+03, -.39490100E+03, -.38860000E+03, 0.87086400E+02, -.74658500E+02, -.31591900E+03, -.19634500E+03, -.24232000E+03, 0.36225900E+02, -.11937600E+03, 0.60370700E+02, 0.59641000E+02, 0.85602100E+02, 0.50019700E+02, 0.12180700E+02, -.40825500E+02, 0.13679000E+02, 0.36063900E+02, -.83446300E+03, 0.43392600E+03, 0.42626800E+03, -.10033300E+03, -.11354200E+03, 0.29150800E+03, -.40471100E+02, 0.17402700E+03, -.40858400E+02, 0.81064400E+01, 0.41106700E+02, -.24732500E+01, 0.17717100E+02, -.20995700E+02, -.67358100E+01, 0.49329900E+01, 0.24968500E+01, 0.22239600E+02, 0.62042000E+00, -.28991000E+02, 0.31967800E+01, -.13010300E+01, -.31762900E+02, -.25715400E+02, 0.11005500E+01, -.49887800E+01, -.18786300E+02, 0.25111600E+01, -.59218600E+02, 0.33109500E+01, -.25220000E+02, 0.10156800E+02, -.36727000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36869000E+01, -.21730700E+00, 0.49823500E+00, -.38078200E+01, 0.37339800E-01, 0.38946600E+01, -.22011300E+01, -.10219900E+01, 0.25997500E+01, 0.18593200E+00, -.81260500E+00, -.88227300E+00, -.90131600E+00, -.29066900E+01, -.20921700E+00, -.29811200E+01, -.53052800E+00, 0.16850600E+01, 0.17856200E+01, -.36862400E+01, 0.17903700E+00, -.13202300E+01, -.11986500E+01, -.23780500E+00, 0.23147000E+01, -.86825500E+00, -.10039000E+01, 0.11070900E+01, 0.39269000E+00, -.30502800E+00, -.71188100E+00, -.67874900E+00, 0.68574500E-01, 0.93789600E-01, -.48570400E+00, 0.47661700E-01, 0.41531500E+00, -.28796900E+01, -.47492700E+00, -.14988400E+01, -.25190400E+00, 0.31097300E+00, -.51316500E+00, 0.95557600E+00, 0.16300100E+00, 0.28303900E-01, 0.65585600E-01, 0.66493500E+00, -.81734100E+00, 0.28311400E+00, -.56953200E-02, -.60672700E+00, 0.10027300E+01, 0.18872300E+00, 0.43106800E+00, -.50347300E-01, 0.48713300E-01, -.58330400E+00, -.57185200E+00, 0.13867900E+01, 0.12475000E+00, -.18134000E+00, 0.74317400E-01, -.73028800E-01, -.19906600E+00, 0.38696500E+00, -.35358600E+00, 0.29597400E-01, -.85570300E-02, 0.46568200E+00, -.67472700E-01, -.49765700E-01, -.18976100E+00, 0.28084800E+00, 0.48235100E+00, -.10617100E-01, -.44495700E-01, 0.19629900E+00, -.15596000E+00, 0.83845600E+00, 0.35345400E+00, -.48665100E+00, 0.14320200E+00, 0.79932400E-01, 0.23437400E-01, -.50638700E+00, 0.44552800E+00, 0.82952700E-01, 0.15947100E+00, 0.16063000E+00, -.15582900E+00, 0.37608400E+00, -.13306800E+00, -.14356000E+01, 0.30499000E+00, 0.73487100E+00, -.24225500E-01, 0.94949200E+00, -.65798800E-01, -.15730700E+00, 0.16760300E+00, -.18333200E+00, 0.96077400E-01, -.41985400E+00, -.39647100E-01, 0.26144000E-01, 0.29612900E+00, -.23691100E+00, -.56422500E+00, -.33992700E-01, 0.59135800E+00, 0.25365300E+00, -.26115400E-01, -.31714100E+00, -.10165700E+00, 0.28212800E+00, 0.11103900E+00, 0.21665400E+00, -.66913600E-01, -.13032400E+00, 0.78099100E-01, 0.56224900E+00, -.57418300E+00, -.56636600E-01, -.26278700E+00, 0.31845800E-01, 0.15687000E+00, 0.31480000E-02, -.42212900E+00, -.37614300E+00, 0.25178300E+00, -.13789100E+00, -.11694700E+01, 0.12333800E+00, 0.44866700E+00, -.16709200E+00, -.29090400E-01, 0.12095700E+00, -.48056300E-01, 0.14399500E+00, -.31095100E-01, 0.47636000E-01, 0.49918500E+00, -.44522700E-01, -.13727500E+00, -.12600900E+00, 0.25567900E-01, 0.30947400E-02, 0.61290100E+00, 0.36043000E+00, 0.15333400E+00, -.20798100E+00, -.20547100E+00, -.22146700E+00, 0.52991100E+00, 0.12881700E+00, -.60094800E-01, 0.58386800E+00, 0.45295600E-01, 0.39462300E+00, -.32052400E-01, 0.35936900E+00, -.15239600E+00, 0.14396200E+00, 0.39570600E+00, 0.21535900E+00, -.45011300E+00, -.67299300E-01, 0.85931900E+01, -.35280500E+00, 0.10886400E+01, 0.50615900E+02, -.18586900E+02, -.13325100E+02, 0.12989700E+02, -.14359500E+02, -.22497600E+02, -.18753300E+02, -.63365200E+02, 0.16528800E+02, 0.28130900E+03, -.14021700E+03, -.13913300E+03, 0.21152800E+02, -.20614500E+02, -.11893900E+03, -.89464900E+02, -.97293100E+02, 0.15241800E+02, -.21402600E+01, -.36844700E+00, -.45170500E+00, 0.15413100E+02, 0.13135100E+02, -.31457700E+00, -.13512400E+02, -.10442100E+02, 0.74976900E+00, -.22190200E+03, 0.11120300E+03, 0.10802700E+03, -.18805100E+02, -.84092800E+01, 0.73310500E+02, -.20356800E+02, 0.87540100E+01, -.38088800E+01, 0.25925100E+01, 0.21361500E+02, 0.69322100E+00, 0.77680900E+01, 0.58995700E+01, 0.13892000E+01, 0.18793700E+01, 0.24267000E+01, 0.80728300E+01, -.24478500E+01, -.85840400E+01, -.11745200E+01, 0.16503200E+01, -.87922800E+01, -.86400800E+01, -.21558300E+01, -.22669800E+01, -.69420400E+01, 0.72200100E+01, -.83826900E+01, -.83727300E+01, -.88242400E+01, 0.76733200E+01, -.15202100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36307600E+01, 0.32852300E+01, 0.18254100E+01, -.81461300E+01, -.32009700E+00, 0.65542500E+01, -.84344900E+01, -.21413700E+01, 0.34835700E+01, -.28572200E+01, -.20783000E-01, 0.10189500E+01, -.13369800E+01, 0.81245900E+00, -.10595300E+01, 0.47797000E+01, 0.36191300E+01, 0.14023000E+01, 0.31460100E+01, -.25265100E+01, 0.64831100E+00, -.14267800E+01, 0.14364200E+01, -.17529900E+00, 0.28336200E+01, -.44603600E+01, -.12473300E+01, 0.44593100E+01, 0.71829800E+00, -.17216000E+01, -.19100000E+01, -.83461900E+00, 0.10901400E+00, 0.11990800E+00, -.19479600E+01, 0.81899900E+00, -.16306200E+01, -.47652000E+01, 0.83126600E+00, -.47349300E+01, -.36683400E+00, 0.10757200E+01, -.38498600E+01, 0.34317300E+01, -.12606200E+01, 0.17785800E+01, 0.12671700E+00, 0.30988800E+00, -.15924100E+01, 0.13869400E+01, 0.13846400E+00, 0.42951300E+00, 0.33133700E+01, 0.14184800E+01, -.36607000E+00, 0.59362800E+00, -.10710500E-01, -.58938400E+00, 0.27839600E+01, 0.15908500E+01, -.11333600E+00, -.94789300E+00, -.28880200E+00, 0.21617500E-01, -.40399200E+00, 0.12909700E+01, -.96838100E-01, 0.85315900E+00, 0.16094200E+00, 0.26728200E+01, -.92898600E+00, -.97607100E+00, -.66076100E-01, 0.29927900E+01, 0.82049500E+00, -.32351600E-01, -.69595800E+00, -.27994900E+00, 0.68560600E+00, -.26691800E+01, 0.29346500E+00, 0.65953200E+00, 0.18169500E+00, -.31953200E+00, -.28029500E+00, -.18298100E+01, -.69028200E+00, -.12463300E+01, -.11424700E+00, -.86641900E-01, 0.29832300E+00, -.55627800E-01, -.69086500E-01, -.21523000E-01, -.27874100E+00, -.29914100E+00, -.11785800E+00, 0.46357100E-01, -.76185600E-01, -.10247000E+01, -.10601100E+00, -.15979800E+01, 0.48129000E+00, -.34323400E-02, -.33025600E+00, 0.67600900E-01, -.51572800E+00, -.72958300E-01, -.20561500E+00, 0.79204900E-01, -.11391200E+01, 0.27385400E+00, 0.75056700E+00, 0.16503500E+00, -.18174100E-01, -.62020600E+00, -.72741800E-03, 0.84807800E+00, 0.16595900E+00, 0.83270400E+00, -.16757000E+00, 0.87226600E+00, 0.28014000E+00, -.15641100E+01, -.84786000E+00, 0.48843100E+00, -.51741700E+00, -.68144500E-02, 0.44650900E+00, 0.46055800E+00, 0.61396500E+00, 0.34294700E+00, 0.10206600E+01, -.48130000E+00, -.46793300E+00, -.28292000E+00, 0.99164100E-01, -.19602400E+00, -.18778100E+00, -.42388100E+00, -.37422800E+00, 0.25186600E+00, -.32016200E+00, -.45593900E+00, -.31152900E-01, 0.11806600E-01, -.21655400E-01, 0.44684600E+00, -.39128100E+00, 0.48672700E+00, 0.88130600E-01, -.95135900E-01, 0.62139700E+00, 0.20817700E+00, -.42368400E+00, 0.95325400E-01, -.22854400E-01, -.98736900E+00, -.15233400E+00, -.48231100E+00, -.13570900E+00, -.13452300E+01, 0.68634800E+00, -.14725900E+00, -.22308200E+00, -.11633100E+00, 0.23728600E+00, 0.89148100E-01, -.45051300E+00, 0.26059300E+02, 0.13515200E+02, -.24626200E+03, 0.10995400E+03, 0.14121600E+03, -.24362500E+02, 0.79851700E+01, 0.10331000E+03, 0.66835700E+02, 0.15139500E+03, -.36975100E+02, -.19565000E+03, 0.96685900E+02, 0.10108700E+03, -.22774500E+02, 0.25899000E+02, 0.75737700E+02, 0.53865800E+02, 0.26443700E+02, -.44937500E+02, 0.59370300E+02, -.28610100E+02, -.29613100E+02, -.15113400E+02, -.14701200E+02, -.19377300E+02, 0.53593400E+01, 0.14786700E+01, 0.43019000E+01, 0.54148600E+02, -.35173500E+02, -.21420700E+02, 0.74634700E+01, 0.13802700E+02, -.10053300E+02, 0.30747300E+02, -.42053300E+01, 0.15089600E+02, -.94637100E+01, -.14467600E+02, -.12034500E+01, -.10293300E+02, -.83057100E+01, 0.10771700E+01, 0.17253800E+01, -.20492700E+01, -.93476100E+01, 0.35944400E+01, 0.48210100E+01, 0.40537900E+01, -.26329500E+01, 0.70051800E+01, 0.92263300E+01, 0.53449100E+01, 0.51054900E+01, 0.82625200E+01, -.75636500E+01, 0.33918300E+01, 0.93669500E+01, 0.31836800E+01, -.96519000E+01, 0.11129500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.92904700E+01, 0.50213500E+01, 0.45108100E+01, -.14442700E+02, 0.71257700E+00, 0.14983900E+02, -.16169300E+02, -.49268000E+01, 0.42151900E+01, -.50192700E+01, -.58171400E+00, 0.21807300E+00, -.23775900E+01, -.27019300E+01, -.31235100E+01, 0.35818900E+01, 0.39035600E+01, 0.10241300E+01, 0.10084100E+02, -.46656900E+00, 0.32837000E+01, -.66533700E+00, 0.18233000E+01, -.23331800E+01, 0.68256100E+01, -.10367100E+02, -.20275900E+01, 0.68245700E+01, -.17179500E+01, -.43431600E+01, -.67181300E+00, 0.12711600E+01, 0.99758000E+00, 0.32905300E+00, -.11548500E+01, 0.15862500E-01, -.62101100E+01, -.10601600E+02, -.25407800E+01, -.53586500E+01, -.12169900E+01, 0.80309800E+01, -.12101400E+02, 0.47709400E+01, -.29723400E+01, 0.34949300E+01, -.28065000E+00, 0.20492100E+01, -.40855400E+01, -.44857900E+00, -.15329600E+01, 0.13284500E+01, 0.56154500E+01, 0.38269600E+01, -.25216000E+00, -.66730900E+00, 0.30273700E+00, 0.63099400E+01, 0.10234500E+02, 0.22494100E+01, -.75943600E+00, -.16364100E+01, -.79353800E+00, -.58079900E+00, 0.44461500E+00, 0.15394700E+01, -.27864100E+00, 0.14405700E+01, 0.15301100E+00, -.94471100E+01, -.82830300E+00, 0.79606500E+00, -.41871200E+01, 0.48838700E+01, 0.23368000E+01, 0.41415800E-01, -.12182100E+01, 0.20329600E+01, -.70492400E+00, -.18161200E+01, 0.81377900E+00, -.28798400E+00, 0.59555500E+00, 0.65174900E-01, 0.30384900E-01, -.16344200E+01, -.13959200E+01, 0.21060200E+01, 0.26678000E+00, -.14386400E+01, 0.28774400E+00, -.14464400E-01, -.18736600E+00, 0.12895200E+01, -.20576900E+00, 0.13219900E+00, -.17314000E+00, 0.13837100E+01, -.30137000E+00, -.81282700E+00, -.43769600E+00, -.72355900E+00, 0.31061200E+01, -.10297300E+01, -.94575900E+00, 0.15434100E+01, -.10900000E+01, -.14351200E+01, -.14789300E+00, 0.10760400E+01, -.17287100E+01, 0.49007900E-01, 0.57631700E+00, -.15838800E+00, -.77529800E+00, -.15574400E+01, 0.19474100E+00, 0.32388800E+01, 0.47409500E+00, 0.20124700E+01, -.10315700E+01, 0.15577800E+01, 0.20318000E+00, -.29457300E+01, -.15934500E+01, 0.15817800E+01, -.68114200E+00, 0.23429500E-01, -.36989000E+00, 0.80846600E+00, 0.25814700E+00, -.40581100E+00, 0.10458600E+01, 0.51850800E+00, 0.67300100E+00, 0.19395300E+00, -.36447000E+00, -.23601800E+01, 0.16283700E+00, -.88174600E+00, -.17199700E+00, 0.93239500E+00, -.16319500E+01, -.10774600E+00, 0.53172400E+00, 0.44844000E+00, -.39238500E+00, -.17265100E+01, -.27549400E+01, -.89661900E+00, -.61381600E+00, 0.35971800E+00, -.15486000E+01, -.13965600E+00, -.13797100E+00, 0.27843600E+00, 0.46106700E+00, 0.81637500E+00, 0.28874900E+00, 0.16846700E+01, 0.20938100E+00, -.66045900E+00, 0.58693500E+00, -.46193900E-01, -.14657200E+01, 0.20200300E+00, 0.77456700E+00, -.38556000E+00, 0.20304300E+01, 0.10667100E+01, -.53114000E+02, 0.12130400E+03, -.86085800E+02, -.87873800E+02, 0.59734900E+01, 0.18797700E+02, -.64482000E+02, -.96790200E+02, 0.74212000E+01, 0.34675000E+02, -.40217300E+03, 0.19676700E+03, 0.19941700E+03, -.51445600E+02, -.15565900E+02, 0.19017200E+03, 0.17150200E+03, 0.27295100E+03, -.37818200E+02, -.11921100E+02, 0.49286100E+01, 0.12517500E+02, 0.40265000E+02, 0.51769000E+02, -.34606800E+02, -.56847700E+02, -.16899300E+03, 0.78898600E+02, 0.14037500E+03, -.82959000E+02, -.58302200E+02, 0.26816300E+02, -.31448800E+02, -.65647400E+02, -.20717700E+02, 0.56677500E+02, 0.19322300E+02, 0.28052900E+01, -.41838700E+02, -.43647200E-01, -.65107500E+01, 0.79964200E+01, 0.58020600E+01, -.40755100E+01, 0.17111500E+01, -.89856000E+01, -.22034100E+01, 0.11417600E+02, -.57738900E+01, 0.62919300E+01, 0.17119100E+02, 0.16938600E+02, 0.40581600E+01, 0.14648000E+02, 0.85517900E+01, -.72041600E+01, 0.13124400E+02, -.58602100E+01, 0.14591900E+02, -.61762300E+01, 0.25028500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.32917300E+01, -.12367000E+01, -.11610900E+01, 0.35124600E+01, -.91573300E-01, -.39945200E+01, 0.31224700E+01, 0.12999600E+01, -.16917600E+01, 0.13175200E+01, 0.65641400E+00, 0.47002200E+00, 0.12855100E+01, 0.30310900E+01, 0.49271600E+00, 0.50894000E+00, -.44370000E+00, 0.93474700E+00, -.21352700E+01, 0.55099100E+01, -.56067700E+00, 0.20877600E+01, 0.10341900E+00, -.18169600E+00, -.17303000E+01, 0.40722900E+01, 0.11891600E+01, -.34192300E+01, -.29315900E+00, 0.14390100E+01, 0.12273000E+01, 0.77996200E+00, -.63468100E+00, -.19226300E+00, 0.10095100E+01, -.14618700E+00, 0.64737200E+00, 0.12205500E+01, -.54208300E+00, 0.42122400E+01, 0.31949100E+00, -.78250700E-01, 0.21955500E+01, -.19678600E+01, 0.15112700E+01, -.11938000E+01, -.25664200E+00, 0.60642300E-01, 0.17474800E+01, -.24253600E-01, -.12348100E+00, -.64770900E+00, -.13177000E+01, -.57624100E+00, 0.34382700E+00, -.41441700E+00, 0.45345900E-01, 0.57275000E+00, 0.15025800E+01, -.17113600E+01, -.17933900E+00, 0.38267700E+00, 0.98596200E-01, -.43638300E+00, 0.19402400E+00, -.63382800E+00, -.14185000E+00, -.29497300E+00, -.45281000E-01, -.21191200E+01, 0.34382000E+00, 0.75712100E-01, 0.10684800E+01, -.12753800E+01, -.42104500E+00, -.73193900E-01, 0.43426200E+00, -.23507500E-01, 0.28487100E-01, 0.34613800E+00, -.52139900E+00, 0.83078300E-01, -.73722000E-01, -.17123300E+00, -.96695800E-01, 0.68047400E+00, 0.50042500E+00, -.98396700E+00, -.47860800E+00, -.30205500E+00, -.10551400E+00, -.14355500E+00, 0.21340300E+00, 0.76068100E-01, -.13443300E+00, 0.49723100E+00, -.10568700E+00, -.12186500E+00, 0.16047600E+00, 0.84285200E+00, -.10055000E+00, 0.16003100E+01, 0.11402400E+00, 0.22449600E+00, -.25699700E+00, -.48410900E-01, 0.65810400E+00, -.50804400E+00, 0.87771500E+00, 0.32796000E+00, 0.52229500E-01, 0.10188300E+00, -.46164100E+00, -.16006200E+00, -.37996100E+00, -.11233700E+00, 0.24104900E+00, 0.56225500E+00, 0.75424500E-01, 0.64913100E+00, -.35404700E+00, 0.59256900E-01, 0.56658300E+00, -.69815500E+00, 0.25369000E+00, 0.11824900E+00, -.67923900E+00, 0.96804300E-02, 0.16712400E+00, 0.39922500E+00, 0.18101600E+00, 0.11036000E+00, 0.11972300E+01, 0.26521300E+00, 0.49077200E+00, -.81163200E-01, -.76219600E-02, -.70155000E+00, -.30416400E+00, -.32269000E-01, -.49256900E+00, -.10929000E+00, 0.29919300E+00, 0.23955200E+00, -.83659400E-01, 0.11005000E+00, 0.30427200E-01, -.52238000E+00, -.72823800E+00, -.35978300E+00, -.26069500E+00, 0.12569600E+00, -.25667300E+00, -.15987400E+00, -.86495700E-01, 0.13948600E+00, 0.25537800E+00, 0.62519800E-01, 0.21026400E+00, 0.57665100E+00, -.17360700E+00, 0.31113500E+00, -.22378900E-01, -.79862600E-01, 0.59667300E+00, -.32979100E+00, 0.89326500E+00, -.24612300E-01, -.24012400E+00, 0.29095700E+00, 0.39608300E-04, -.13522300E+03, 0.65086900E+02, 0.59882300E+02, -.12246000E+01, 0.15844700E+02, 0.57836400E+02, 0.36027700E+02, 0.28424500E+02, -.23163900E+01, -.21780300E+01, 0.22137700E+01, 0.11472400E+00, 0.10290600E+02, 0.16926700E+02, -.29997800E+01, -.52750600E+01, 0.85330700E+01, -.98288200E+01, -.20461600E+01, 0.16974000E+01, 0.21828700E+00, -.59813900E+00, -.46305700E+01, 0.51082200E+01, 0.36925500E+01, 0.54216200E+01, -.44335400E+01, -.87334600E+02, 0.52147800E+02, 0.41846100E+02, -.81883600E+01, -.93022500E+01, 0.25912800E+02, -.10795700E+02, -.23435000E+01, -.46407100E+00, -.49799900E+00, 0.36755600E+01, -.76875400E-01, 0.76096000E+00, 0.37703400E+01, -.93592600E+00, -.30397300E+01, 0.13768000E+01, 0.15501100E+01, -.26265200E+01, -.58176300E+01, -.12731000E+01, 0.61176200E+00, -.29387100E+01, -.26700500E+01, -.19664300E+01, -.56941800E+01, -.14180100E+01, 0.40581300E+01, -.59209400E+01, -.24564700E+01, -.39393400E+01, 0.41731600E+01, -.29141900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14720200E+01, 0.17395500E+01, 0.79138600E+00, -.37551100E+01, -.40133500E+00, 0.31570700E+01, -.38994900E+01, -.10376300E+01, 0.34963300E+00, -.12885500E+01, 0.50906900E+00, 0.97165000E+00, -.16028900E+00, 0.12401700E+01, -.87766300E+00, 0.20189000E+01, 0.16725000E+01, 0.14314300E+01, 0.15707900E+01, 0.36988400E+01, 0.59676600E+00, 0.13034700E+01, 0.12244300E+01, -.98868700E+00, 0.89162600E+00, -.10822800E+01, 0.11220300E+01, 0.16396700E+01, 0.42160200E+01, -.92492000E+00, -.70617100E+00, -.62773700E+00, -.53660500E+00, -.62063900E-01, 0.44193400E+00, 0.10844600E+01, -.18261500E+01, 0.30201400E+01, 0.13999700E+01, 0.48812900E+01, 0.95149300E+00, -.67095100E+00, 0.27653900E+01, -.13502600E+01, 0.42086300E+00, -.84303900E+00, 0.75268000E+00, 0.19626000E+01, -.10288500E+01, 0.12736800E+01, -.89015200E+00, -.38277200E+01, -.44746600E+00, 0.10255800E+01, -.42168300E+00, -.21261700E+01, 0.43945400E+00, -.24767700E+00, -.39990300E+00, 0.40284000E+01, 0.53980400E+00, 0.27873100E+00, -.17060400E-01, -.10111800E+00, 0.20847000E+00, 0.47634800E-01, 0.56455200E+00, 0.43688300E+00, 0.45416700E-01, -.23567600E+01, 0.12753600E+00, -.17143600E+00, 0.95754200E+00, -.25408000E+00, 0.28657800E+00, -.38692500E+00, 0.58684000E-01, 0.32828300E+00, -.76067600E-01, -.26533200E-01, 0.95709400E-01, -.34680900E-01, 0.76164300E-01, -.13519700E-01, 0.24514600E-01, -.28740000E+00, -.12245300E+00, 0.67405300E+00, 0.30102200E-01, -.14397200E-01, -.12516000E+00, 0.16663300E+00, 0.17611800E-01, 0.41206400E+00, 0.13445800E+00, -.79621600E-01, 0.21897800E+00, 0.27230100E+00, -.54341300E-01, -.15438800E+00, -.52320900E-01, -.16412100E+01, 0.92868200E+00, -.44573100E+00, -.38515400E+00, 0.11575400E+00, -.46832800E+00, -.54849200E+00, -.52666000E+00, 0.22601700E+00, -.19445300E+00, -.52904400E+00, 0.51518400E+00, -.26145300E+00, -.22180400E+00, -.94597700E-01, 0.20775500E-01, -.56615200E+00, 0.92772000E-02, -.77757700E+00, 0.12028000E+00, 0.26927700E+00, 0.30173400E+00, -.30013000E+00, 0.35729400E+00, -.20267600E-01, 0.16297700E+00, 0.22242300E-01, -.31732000E+00, 0.17432200E+00, 0.23314300E+00, -.19686200E+00, -.26197600E+00, -.19984200E+00, 0.18002100E+00, 0.11880600E+00, -.18484100E+00, -.17321000E+00, 0.10802600E+00, -.80676200E-01, -.70352300E-01, -.33071200E+00, -.14399900E-01, -.26805800E+00, 0.21415500E+00, 0.19059100E+00, -.67404300E-01, -.12682700E-01, -.79869900E-01, 0.16353300E-01, 0.12552500E+00, 0.71451000E-01, -.79485700E+00, 0.36205900E+00, 0.16319700E+00, 0.73137000E-01, 0.18927700E+00, -.49990600E+00, 0.21962800E-01, 0.14861800E+00, 0.65878000E-01, -.32528700E+00, 0.32853800E+00, -.68835300E-01, -.13951700E+00, 0.17573200E-01, 0.19555700E+00, -.12573400E+00, 0.18065000E+00, -.69414900E-03, -.46304900E-01, -.43576500E+00, -.21563700E+02, -.36165300E+01, 0.25656500E+02, -.29953900E+02, -.16033100E+02, -.51967800E+02, -.16550000E+02, 0.34367500E+02, 0.58491000E+02, -.28432800E+02, -.28996600E+02, 0.46987000E+01, -.27523800E+01, -.23949800E+02, -.19626800E+02, -.33182400E+02, 0.14880700E+02, 0.11292900E+02, -.40800000E+01, -.51342300E+01, 0.12632300E+01, 0.10608000E+02, -.41677700E+01, 0.18262600E+01, 0.86789200E+01, 0.30865300E+01, -.45498700E+02, 0.29024100E+02, 0.24454300E+02, -.47273800E+01, -.26891700E+02, 0.19475400E+02, 0.17169700E+01, 0.25744800E+02, -.13742900E+02, 0.28282300E+01, -.98213000E+01, 0.16103600E+01, -.73447700E+00, -.57731200E+01, 0.19571400E+00, -.34414300E+01, 0.31551000E+01, -.55742300E+00, -.32992600E+01, -.11993000E+01, -.33581000E+01, -.44361900E+00, -.31099700E+01, -.37371800E+01, -.35433400E+01, -.25550800E+01, 0.54394800E+00, -.18294400E+01, -.20442200E+01, 0.25735500E+01, -.23471100E+01, -.26330900E+01, 0.66453600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.25394100E+01, -.24337600E+01, -.13193700E+01, 0.50833800E+01, 0.37231600E+00, -.42831700E+01, 0.47998400E+01, 0.13201400E+01, -.28368800E+01, 0.17407300E+01, 0.18695900E+00, -.16943900E+00, 0.10682300E+01, 0.10098800E+01, 0.45620300E+00, -.37376100E+01, -.19772800E+01, 0.57337200E+00, -.21865700E+01, 0.36741800E+01, -.12134700E-01, 0.20167500E+01, -.61069200E+00, -.11293100E+00, -.15632500E+01, 0.31360000E+01, 0.17724400E+01, -.40248300E+01, -.11391300E+01, 0.13845400E+01, 0.15465800E+01, 0.11130900E+01, -.66642900E-01, 0.66339400E-02, 0.21545600E+01, -.14914100E+01, -.15949200E+01, 0.53956000E+01, -.84282200E+00, 0.47269700E+01, 0.48973700E+00, 0.36772900E+00, 0.67063100E+00, -.26776600E+01, 0.36293800E+00, -.12557400E+01, -.37525800E+00, -.38013500E+00, 0.84541400E+00, -.27420800E+00, -.69144600E+00, -.29733300E+01, -.10488500E+01, -.10626500E+01, 0.17857300E+01, -.35422000E+00, 0.28330800E+00, 0.19940700E+01, 0.38801400E-01, -.12782300E+01, -.30288700E+00, 0.20910800E+00, 0.13131000E+00, -.50892900E+00, 0.45390800E-01, -.54540700E+00, 0.23631700E+00, -.61722200E+00, 0.27667800E-01, -.45947200E+01, 0.27148300E+00, 0.10012900E+01, 0.24987500E+01, -.10478600E+01, -.10552400E+01, -.15042800E+00, 0.85599800E+00, -.25832600E+00, 0.12495400E+00, 0.11689400E+00, -.56751200E-01, 0.15811900E+00, 0.88429100E-02, -.25965200E+00, -.11813600E+00, 0.96065400E-01, 0.17038900E+00, -.20718200E+00, -.36215900E+00, -.53564800E+00, 0.50375000E-01, -.25388800E+00, 0.54886800E-01, 0.40503700E+00, 0.50740700E+00, 0.78149100E+00, -.26564600E+00, -.58800800E+00, 0.21873600E+00, 0.93052500E+00, -.19721000E+00, 0.40441000E+01, 0.11970000E+00, 0.22586100E+00, 0.34702000E+00, -.16042200E-01, 0.23462600E+00, -.46242100E+00, 0.55931400E+00, 0.13969400E+00, -.28822400E-01, -.88581500E-01, -.51912300E-01, -.37498200E+00, -.84873500E-01, 0.76027000E-01, 0.40208700E-01, -.59013700E+00, -.56070400E-01, 0.27154800E+00, 0.33625000E+00, 0.19391000E+00, -.34089600E+00, 0.50397000E+00, 0.55834300E-01, 0.43608200E-01, 0.85785900E+00, -.23583800E-01, 0.22881600E+00, 0.15881100E+00, 0.17682200E+00, 0.15833900E+00, 0.15462500E+00, -.46595700E+00, 0.11354800E+00, 0.26523600E-01, -.20686300E-01, 0.20046000E-01, -.55964600E+00, 0.19798600E+00, -.33716700E+00, 0.56480800E-01, -.44945000E+00, -.45979400E+00, -.46199400E+00, 0.10445200E+00, -.58928700E-01, 0.44206500E+00, 0.68327700E-01, 0.46655800E+00, 0.21934700E+00, -.37924900E+00, 0.15462900E+01, 0.51794000E+00, -.13688300E+00, -.75915400E-01, -.11466100E+00, -.74842500E+00, 0.90308400E-01, 0.86772300E+00, 0.12286800E+00, -.17957200E+00, 0.68187600E+00, 0.33586700E-01, -.91580000E+00, 0.16931500E+00, 0.52866800E-02, -.25648700E+00, 0.66144300E+00, 0.23665800E+00, -.35075700E-01, -.93970500E+00, 0.12499000E+00, -.26732700E+02, 0.35282600E+02, 0.38359700E+02, -.28571700E+02, -.57597800E+02, -.30212800E+02, 0.60125900E+02, -.75249700E+02, 0.38261200E+02, 0.35490700E+02, 0.33123100E+01, 0.11226300E+02, 0.31331200E+02, 0.18910300E+02, 0.56501800E+02, 0.87782400E+01, -.74034800E+01, 0.26257200E+01, 0.44653200E+01, 0.10649500E+02, 0.10924700E+01, -.37894900E+01, 0.20625100E+01, 0.26938400E+01, 0.94698800E+01, -.50505700E+02, 0.25953500E+02, 0.27424100E+02, -.61260800E+01, -.47272600E+02, 0.20282200E+02, -.46451000E+01, 0.51072500E+02, -.25949300E+02, 0.30630600E+01, -.19262300E+02, -.31729400E+00, -.17851600E+01, 0.12762300E+02, 0.40916200E+00, -.78673500E+01, 0.29707100E+01, -.95536600E+00, -.41600100E+01, -.38375300E+01, -.41563300E+01, 0.59684300E+00, -.53166800E+01, -.94108200E+00, -.31619400E+01, -.12039700E+02, 0.91398400E+00, -.48948200E+01, -.47833900E+01, -.14727700E+02, 0.16713700E+01, -.32481300E+01, 0.13461500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.26769300E+01, -.28352300E+01, -.15487200E+01, 0.58165000E+01, 0.82051200E-01, -.45839900E+01, 0.63012300E+01, 0.15509000E+01, -.22801400E+01, 0.22942000E+01, 0.54925200E-01, -.68730100E+00, 0.10648500E+01, -.28680000E+00, 0.90559700E+00, -.34581800E+01, -.27722200E+01, -.17620700E+00, -.44508200E+01, -.83535400E+00, -.12683100E+01, 0.31726900E+00, -.13716900E+01, 0.74831900E+00, -.21782900E+01, 0.57622600E+01, 0.93021100E+00, -.42250900E+01, -.12909600E+01, 0.20328000E+01, 0.12824100E+01, -.27552000E+00, -.58696200E-01, -.39151800E-01, 0.14497200E+01, -.47022900E+00, 0.31382400E+01, 0.43294200E+01, 0.31634000E+00, 0.31048600E+01, 0.38452800E+00, -.22612100E+01, 0.53559000E+01, -.26838600E+01, 0.20396300E+01, -.16052900E+01, -.11312200E+00, -.38728300E+00, 0.23781400E+00, -.23857700E+00, -.38237900E-01, -.68499800E+00, -.16400600E+01, -.12702500E+01, 0.68032000E-01, -.87127900E+00, 0.85699700E-01, -.12625100E+01, -.34977600E+01, 0.35421700E+00, 0.43467200E+00, 0.71502800E+00, 0.29390800E+00, 0.13938000E+00, 0.56835500E-01, -.70050100E+00, -.13212900E+00, -.30884200E+00, -.11480800E+00, 0.66058800E+00, 0.35642400E+00, 0.98690200E+00, -.26210200E+00, -.13893400E+01, -.95027500E+00, 0.28037400E+00, 0.96911500E+00, -.70967000E+00, -.34458700E+00, 0.24444000E+01, -.12607200E+00, -.58079300E+00, -.92966200E-01, 0.17408300E+00, 0.10704700E-01, 0.10145200E+01, 0.10463700E+01, -.30193800E+01, -.35580300E+00, -.58109400E+00, -.13504500E+00, -.28074200E+00, 0.28962900E+00, 0.14595800E+01, 0.38218000E+00, 0.73463700E+00, -.13968700E+00, -.48283300E+00, 0.12390800E+00, -.17700400E+00, 0.44409800E+00, -.18559500E+01, -.15920400E+01, 0.37086100E+00, -.61907600E-01, 0.11234900E+00, 0.74924900E+00, 0.18341600E+00, 0.24102300E+00, 0.15581300E+00, 0.22693000E+00, 0.53592900E+00, 0.30361600E+00, -.52915200E+00, -.39972900E+00, 0.20972300E+00, 0.63861100E-01, -.32766900E+00, -.13659900E+00, -.32888500E+00, 0.11972400E+00, -.18059200E+00, -.84624000E-01, 0.50890200E+00, 0.76096500E+00, -.25265100E+00, 0.13126400E+00, 0.57864600E-02, -.27570000E+00, 0.22337000E+00, -.49232300E-01, -.21462500E+00, 0.28577900E+00, 0.48594100E+00, 0.28949500E-02, 0.41770000E+00, 0.74501400E-01, -.17285100E+00, -.60218500E+00, 0.79155500E+00, 0.49407200E+00, 0.64947000E+00, 0.18018100E+00, -.55406100E-01, -.51864000E+00, -.12944000E+00, 0.10823100E+00, -.31235300E-01, 0.83532400E+00, -.34890000E+00, -.10097300E+00, -.18201200E+00, 0.56166100E+00, -.21684000E+00, 0.47428100E+00, -.20616200E+00, -.13779900E+00, 0.74941500E+00, 0.96522800E-01, 0.17096000E+00, -.53944500E-01, 0.26919400E+00, -.66518800E-01, 0.21747000E-01, 0.21899100E+00, 0.22475600E+00, -.58512200E+00, 0.16117900E+00, 0.92208700E+00, -.32581200E+00, -.21022100E+00, -.34951500E+00, 0.88763500E-01, 0.82469800E+00, -.51895000E+02, -.69571800E+01, 0.35753600E+02, 0.83976700E+02, 0.42938100E+02, -.79957600E+02, -.31215600E+03, 0.15448200E+03, 0.15369100E+03, -.34953300E+02, 0.14242000E+02, 0.13983200E+03, 0.12528800E+03, 0.12238600E+03, -.48268500E+02, -.26952500E+02, 0.16208200E+02, 0.14454100E+02, -.17299200E+02, -.18191700E+02, 0.13313900E+02, 0.95078900E+00, -.17141400E+02, -.23078200E+01, 0.25189800E+03, -.12892400E+03, -.12664600E+03, 0.17218500E+02, 0.60284400E+02, -.97776600E+02, 0.69689600E+01, -.80019000E+02, 0.43730600E+02, -.48896300E+01, 0.52019100E+01, -.24412500E+01, -.41125300E+01, -.14229100E+02, 0.39083200E+00, 0.61783800E+01, -.58623600E+01, -.57005000E+01, 0.70651200E+01, 0.12682300E+02, 0.52394700E+01, 0.14162000E+01, 0.15665500E+02, 0.16437600E+02, 0.66799700E+01, 0.14704200E+02, 0.46891500E+01, 0.30520900E+01, 0.14520500E+02, 0.20769500E+02, 0.11322600E+02, 0.23778600E+01, -.51281700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.64059000E+01, 0.61926800E+01, 0.30513500E+01, -.98388800E+01, 0.17787000E+01, 0.78529600E+01, -.85742200E+01, -.31161300E+01, 0.10237700E+01, -.27042300E+01, 0.17991900E+01, 0.27415000E+01, 0.40172900E+00, 0.25385300E+01, -.30776900E+00, 0.35680500E+01, 0.30057600E+01, 0.42509100E+01, 0.94492800E+00, 0.72841200E+01, -.38954000E+00, 0.19866700E+01, 0.29570800E+01, -.10586200E+01, 0.11703100E+01, 0.21278900E+01, 0.71241900E+00, 0.42318000E+01, 0.12044200E+02, -.46360300E+00, -.26797000E+01, -.22388700E+01, 0.99031400E+00, 0.25207300E+00, -.94123300E+00, 0.15184100E+01, 0.17914700E+00, 0.77681800E+01, 0.39047700E+01, -.10198300E+02, 0.15760500E+01, -.35181900E+01, 0.11231800E+01, 0.21809600E+01, -.13565100E+00, 0.78225300E-01, 0.69695800E+00, 0.17401800E+01, -.59437700E+01, 0.21993100E+01, -.12960000E+00, -.33075900E+01, 0.48143500E+01, 0.26880300E+01, -.19055400E+00, -.31217300E+01, -.11106200E+00, -.36471000E+01, 0.37830400E+00, 0.57753400E+01, 0.10338700E+01, -.50522600E+00, 0.29774900E-01, 0.34343200E+00, -.13172800E+01, 0.79210300E+00, 0.78884700E+00, -.28748200E+00, 0.43969000E+00, 0.92430700E+00, 0.73889900E+00, -.21692100E+01, -.70069000E+01, 0.12053300E+01, 0.26747400E+01, 0.22621000E-01, -.10521400E+01, 0.11341800E+01, -.24556100E+01, -.19987800E+01, 0.12179600E+00, 0.76131200E+00, -.21905300E+00, -.15428200E+00, 0.11252900E+01, -.17776400E+00, 0.26694900E+00, 0.17771000E+00, 0.20159300E+00, 0.33442400E+00, 0.29084900E+00, -.14974300E+00, -.14824300E+00, -.17290300E+01, -.37851200E+00, 0.50015600E+00, -.36568400E+00, -.64859100E+00, 0.18896300E+00, -.76955600E+00, 0.74102300E+00, 0.26223800E+01, -.13700600E+01, -.16651300E+00, 0.52996900E+00, 0.82009800E+00, 0.87120200E+00, 0.55681800E+00, 0.14022500E+01, -.73077300E+00, 0.75189000E+00, 0.10024500E+01, -.13864000E+01, 0.48359700E+00, 0.14829400E-01, 0.61521400E+00, 0.27157900E+00, 0.19858100E+01, 0.91727500E-01, 0.16062100E+01, -.67772600E+00, -.53331700E+00, 0.16032200E+00, -.86779300E+00, -.91746300E+00, 0.32296100E+00, -.72857800E+00, -.51139600E-01, -.27366400E+00, -.51375300E+00, 0.82851600E-01, 0.31090400E+00, -.12468400E+00, 0.45754200E+00, 0.10123700E+00, -.44097400E+00, 0.40435100E+00, 0.64679100E+00, 0.10415100E+00, 0.76167000E+00, -.54322100E+00, 0.16648700E+00, 0.18107800E+00, 0.17389800E+00, -.63218600E+00, -.40232200E+00, 0.13083100E+00, 0.33295400E+00, 0.40043800E+00, 0.48431400E+00, 0.19190700E-01, -.23588300E+00, 0.25133900E+01, -.15771600E+01, -.45622200E+00, 0.10171500E+00, -.57570500E+00, 0.12104800E+01, 0.14164200E+00, 0.27602300E+00, 0.34109400E-01, 0.69476700E+00, -.97059200E+00, 0.80774600E-01, 0.55674400E+00, 0.37060600E-01, 0.55290900E+00, -.37262800E-01, 0.46367900E+00, -.38035300E+00, 0.63604000E-02, 0.16775400E+01, -.27249900E+01, 0.54072800E+00, -.52081200E+00, -.99955600E+02, -.97218400E+01, -.60541200E+02, 0.65939300E+02, -.13196200E+02, -.18872200E+03, 0.91905300E+02, 0.94278200E+02, -.45690500E+02, -.19899500E+02, 0.98630300E+02, 0.10006100E+03, 0.88648800E+01, -.22708600E+02, 0.40128000E+02, -.15422900E+02, -.16919700E+02, -.20110800E+02, 0.22966100E+02, -.17119200E+02, -.55565500E+01, -.24768900E+02, 0.17430500E+02, 0.26852800E+03, -.12967100E+03, -.12840600E+03, 0.25359300E+02, 0.28530800E+02, -.94717100E+02, 0.21436300E+02, -.49108100E+02, 0.35091500E+02, 0.22975500E+00, -.16461300E+02, 0.22906300E+01, -.77220200E+01, -.38546400E+02, 0.25298800E+01, 0.54799700E+01, -.53706100E+00, -.96183300E+01, 0.39295700E+01, 0.17895800E+02, -.36814200E+00, -.98561600E+00, 0.16010800E+02, 0.13623200E+02, 0.25756000E+01, 0.23952400E+02, 0.83828500E+01, -.56639600E+01, 0.17335400E+02, 0.37096100E+02, 0.87106100E+01, -.10643100E+02, 0.84020600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19412100E+01, 0.14530200E+01, 0.63434700E+00, -.55947400E+01, -.12450200E+01, 0.44185700E+01, -.69362300E+01, -.15886800E+01, 0.21148800E+00, -.22736400E+01, 0.60258100E-01, 0.89967600E+00, -.10935000E+01, 0.13999500E+01, -.17196100E+01, 0.40204900E+01, 0.31262500E+01, 0.57336400E+00, 0.40975700E+01, 0.24151700E+01, 0.15487200E+01, 0.43005100E+00, 0.16025400E+01, -.10774500E+01, 0.31042000E+01, -.68445600E+01, 0.27048200E+00, 0.29124900E+01, 0.58172800E-01, -.21418500E+01, -.68113500E+00, 0.69903400E+00, -.48851200E-01, -.50335400E-01, -.91665200E+00, 0.38108500E+00, -.23949400E+01, -.27200100E+01, -.58116100E+00, -.19957100E+01, -.30018800E+00, 0.20192500E+01, -.38318800E+01, 0.12236800E+01, -.13242800E+01, 0.74602300E+00, 0.17251700E+00, 0.95032900E+00, -.59768800E+00, 0.79744200E+00, -.37326600E+00, -.18953000E+01, 0.63129000E+00, 0.98804100E+00, 0.30114800E+00, -.58551700E+00, 0.35267800E-02, 0.68957000E+00, -.44859200E+01, 0.26265700E+01, -.15186600E+00, -.54852600E+00, -.16574000E+00, 0.27687000E-01, -.42294600E-01, 0.47898700E+00, -.73482400E+00, -.22188400E+01, 0.16432200E+00, 0.17176000E+01, 0.23413800E+00, 0.68800900E+00, 0.47119500E+01, 0.11064300E+00, -.12144700E+00, -.32154900E+00, 0.12270200E+01, -.22091000E+00, -.75130800E+00, 0.22388200E+01, 0.75527600E+00, -.10599500E+01, 0.94542200E-02, -.58607700E+00, 0.74079400E-01, 0.24148300E+00, 0.13984500E+01, -.25697300E+01, -.77538000E+00, 0.15527200E+01, 0.59677600E+00, 0.10795200E+00, 0.17309300E+00, 0.81837500E+00, 0.30684300E+00, 0.67975300E+00, -.13239600E-01, -.77243800E+00, 0.20195800E+00, -.76037500E+00, 0.30209500E+00, -.11436000E+01, 0.15693600E-01, -.19383000E+00, -.25532500E+00, -.11837500E+00, -.36710800E-01, -.37765400E+00, -.78846800E+00, -.30408000E-01, 0.19659600E+00, 0.30581400E+00, 0.72345400E+00, 0.20629000E+00, -.29722400E-01, -.70456900E+00, -.18001700E+00, 0.17782900E-06, 0.12549200E+00, -.42791900E+00, -.16871100E+00, -.25973300E+00, 0.54682500E-01, 0.29690900E-01, -.74474100E-03, -.12418300E+00, -.36909400E+00, 0.27593400E-01, -.23162100E-01, -.10627500E+00, 0.49328200E-01, 0.19465600E-01, 0.30941000E+00, 0.41933300E+00, -.69384400E-01, 0.13865300E+00, 0.12572600E+00, 0.54539800E+00, 0.35738000E-01, 0.46123800E+00, 0.15482400E+00, -.28347800E+00, 0.64982300E+00, -.39580200E-01, 0.19177100E+00, -.23914500E+00, 0.74355800E-01, 0.33186200E+00, 0.76619800E+00, -.27490900E+00, 0.20133200E-01, 0.81794300E-01, -.99652700E+00, -.18097900E+00, 0.12571400E+00, -.11017500E+00, -.31441500E-01, 0.39814000E+00, -.91090900E-01, 0.45098600E+00, 0.29096900E+00, -.62147300E+00, 0.46403700E+00, 0.13405300E-01, -.70128100E+00, -.32912500E+00, 0.36957200E+00, -.26388400E+00, -.78202100E+00, 0.96460100E-01, 0.24262000E-01, -.36183100E+00, -.36259200E+00, -.55143900E+00, -.45371400E+00, 0.20562500E+00, 0.15870600E+02, 0.27063400E+02, -.36950600E+02, -.95001500E+00, 0.19626600E+03, -.96109200E+02, -.98299800E+02, 0.27550400E+02, 0.50506000E+01, -.88032900E+02, -.66959300E+02, -.45539900E+02, 0.11540400E+02, -.37592700E+02, 0.16718300E+02, 0.17250100E+02, 0.26614400E+02, 0.15167900E+02, 0.66492100E+01, -.12351600E+02, 0.28288600E+01, 0.83293400E+01, -.27199300E+03, 0.14559900E+03, 0.13381400E+03, -.42774300E+02, -.66591100E+02, 0.98435200E+02, -.11193600E+02, 0.53098700E+02, -.34152500E+02, 0.49547400E+01, -.47887600E+01, 0.35663100E+01, 0.25967400E+01, 0.14330600E+02, -.14784500E+01, -.84087700E+01, 0.67073900E+01, 0.40460100E+01, -.92339200E+01, -.12994400E+02, -.78183000E+01, -.16389900E+01, -.13207600E+02, -.13231100E+02, -.76003500E+01, -.17884000E+02, -.29425200E+01, 0.23723000E+00, -.13361300E+02, -.13725300E+02, -.12197800E+02, 0.25773400E+01, 0.36945100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.84646900E+01, -.46484900E+01, -.28856600E+01, 0.17045500E+02, -.10519900E+01, -.15122000E+02, 0.14187100E+02, 0.48547900E+01, -.85791300E+00, 0.45597700E+01, -.41474100E+00, -.14309500E+01, 0.13353200E+01, -.38052700E+01, 0.41739900E+01, -.49728700E+01, -.37425000E+01, -.43471300E+01, -.52760900E+01, 0.58414000E+01, -.34871100E+00, 0.99535200E+00, -.52058500E+01, 0.52483100E+00, -.28711900E+01, 0.12216200E+01, 0.34374700E+00, -.71350600E+01, -.12848300E+00, 0.24766800E+01, 0.21644400E+01, -.74669000E+00, -.36598900E+01, 0.96626600E-01, 0.17498100E+01, 0.21318900E+01, 0.16249600E+01, 0.64173900E+01, -.33203700E+01, 0.87301000E+00, -.15343800E+01, 0.12058700E+01, -.25448300E+01, 0.11493200E+01, 0.42303100E+00, 0.11589100E+01, -.73397900E+00, -.39615900E+01, -.13866300E+01, 0.81507700E-01, 0.75965100E+00, 0.41202000E+01, 0.15416700E+01, -.47968200E+00, 0.17320700E+01, 0.14146500E+01, -.11188700E+01, -.16568200E+01, -.13847400E+01, 0.55153300E+01, 0.33173000E+00, -.32592200E+01, -.10797100E+00, 0.55068000E+00, -.37649400E+00, 0.78376400E+00, -.87079800E+00, 0.11940000E+01, 0.19558100E+00, 0.66150100E+01, -.80576800E+00, 0.10373400E+01, -.61039800E+01, 0.29222200E+01, 0.13537600E+01, 0.73952000E+00, -.22575300E+01, -.12753900E+01, -.64484800E+00, -.71678200E+01, 0.13578700E+01, 0.33478200E+00, 0.26361500E+00, 0.35037500E+00, 0.21632600E+00, -.62407000E+00, -.30368100E+00, 0.24068800E+01, 0.98543100E+00, 0.77651400E+00, 0.24046200E+00, 0.50045000E+00, -.33595600E-01, -.33801100E+01, -.97303100E+00, 0.22776400E+01, -.24161400E-01, 0.24671300E+01, -.22063800E+00, -.11108900E+01, -.23042200E+00, -.65355200E+01, 0.13467100E+01, -.90047900E+00, -.98597200E+00, 0.10752400E+01, -.15183100E+01, -.22307500E+00, -.26381800E+01, 0.44992700E+00, 0.51138000E+00, -.83991800E+00, 0.60125900E-01, -.26938200E+00, -.68789900E+00, 0.61933400E+00, 0.25291100E+00, -.19584000E+01, -.25503500E+00, -.23574200E+01, -.16417300E+00, 0.29572700E+00, 0.85251300E+00, -.51333000E+00, 0.45178900E+00, 0.94330400E-01, -.57456600E+00, -.14433700E-01, -.40324800E+00, 0.24309400E+00, -.48566800E+00, -.76533100E+00, 0.14529800E+01, 0.62002100E+00, -.12103500E+00, -.17068900E+00, 0.24424300E+00, -.29572600E+01, -.96773000E+00, 0.15062400E+01, 0.24418800E+01, 0.28321400E+01, -.99674000E+00, -.85377700E-02, -.47009800E+00, 0.13415800E+00, 0.12142800E+00, -.36142300E+00, -.13332100E+00, 0.94029700E-01, -.26893600E+00, 0.21283000E+00, -.52605700E+00, 0.50796300E+00, 0.67228700E+00, -.46813200E+00, 0.14098300E+00, 0.53796300E+00, 0.83435700E-01, -.25597600E+01, -.10051700E+01, 0.11575900E+01, -.12963500E+01, -.16456800E+00, 0.11171400E+01, 0.98615200E+00, 0.39569600E+01, -.20749100E+00, -.12535100E+01, 0.67993100E+00, 0.59723300E+00, 0.27895100E+01, -.13629200E+01, -.77221300E+00, -.10014100E+01, 0.10149400E+00, -.23211500E+01, 0.92621200E+02, -.52808200E+02, -.43714400E+01, 0.22549000E+02, -.10100300E+02, -.14074400E+02, 0.18591400E+02, 0.23711800E+02, -.16278000E+02, 0.19103800E+02, -.72706000E+02, 0.22593400E+02, -.60982200E+02, 0.25844800E+02, 0.29023800E+02, -.38198900E+01, 0.12339200E+01, 0.26503700E+02, 0.23570000E+01, 0.10314700E+03, -.19572800E+02, -.16901400E+03, 0.83203300E+02, 0.80826800E+02, -.77338100E+02, -.13378700E+03, 0.10441400E+03, 0.58279100E+02, 0.44342800E+02, -.70505000E+02, 0.66688900E+01, -.56457500E+02, 0.28595300E+01, -.47991500E+01, 0.53078200E+02, 0.26878700E+01, -.87335400E+01, 0.66591000E+01, -.70018200E+00, -.40400000E+01, -.15439200E+02, -.21690600E+01, -.68191100E+00, -.14710300E+02, -.99651900E+01, -.66516500E+01, -.24851800E+02, 0.22985000E+01, 0.42949300E+01, -.11432200E+02, -.50948000E+02, -.25488700E+01, 0.37306400E+01, 0.41265700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18143600E+01, 0.14270600E+01, 0.74068300E+00, -.43392300E+01, -.64421200E+00, 0.36554600E+01, -.46790600E+01, -.12221300E+01, 0.98657800E+00, -.14951900E+01, -.77012800E-01, 0.13726700E+00, -.76704400E+00, -.28142900E+00, -.88251200E+00, 0.26093800E+01, 0.18452100E+01, 0.91118300E-01, 0.20953900E+01, -.89526200E+00, 0.56417300E+00, -.56426900E+00, 0.72444000E+00, -.20384500E+00, 0.17387200E+01, -.41559900E+01, -.59870400E+00, 0.29888100E+01, 0.81393600E+00, -.14063000E+01, -.83576500E+00, -.44012500E+00, -.17785600E+00, 0.18036200E-01, -.12663300E+01, 0.65114100E+00, -.95423700E+00, -.24823700E+01, 0.10089200E+00, -.26323500E+01, -.26612500E+00, 0.10035900E+01, -.22384100E+01, 0.16587800E+01, -.11984900E+01, 0.10160800E+01, 0.13027100E+00, 0.26622500E+00, -.15140500E+01, 0.51748500E-01, 0.22260900E+00, 0.14475900E+01, 0.20388300E+01, 0.67407300E+00, 0.11554200E+00, 0.54133100E+00, -.14020000E+00, -.28202100E+00, 0.74196400E+00, 0.82899200E+00, -.66661800E-01, -.82847700E+00, -.28350300E+00, 0.23901900E+00, -.30636900E-01, 0.38543900E+00, -.60601400E+00, -.15674800E+00, 0.14109200E+00, 0.25316700E+01, -.18209600E+00, -.91229300E-01, -.13559600E+01, 0.14056100E+01, 0.51422900E+00, 0.80139300E-01, -.65903700E+00, -.50287800E+00, -.64258000E-01, -.13857900E+01, 0.15607100E+00, -.11989700E+00, -.36684300E-01, -.35833500E-01, 0.14361800E-01, -.12437400E+00, -.17134600E-01, -.22791500E+00, 0.90057300E-01, 0.11291700E+00, 0.16489900E-01, 0.29699900E-01, -.54313800E-01, -.53914900E+00, 0.12657000E-01, 0.14751000E+00, 0.24016100E-02, 0.31906700E+00, -.41293800E-01, -.29686300E+00, -.43682400E+00, -.21330800E+01, 0.35493500E+00, -.35933600E-01, -.31068200E-01, 0.31993300E+00, -.40632000E+00, 0.46085600E+00, 0.36049200E-01, -.13683000E+00, -.40789700E+00, -.17634900E+00, -.84864000E-04, 0.17865900E+00, 0.12209400E+00, -.97501300E-01, -.15361800E+00, 0.11272000E+01, 0.83842000E-01, 0.14939200E+00, 0.62555300E-01, 0.40249500E+00, 0.34588200E+00, -.54416700E+00, 0.73705400E-01, 0.14153200E+00, 0.45033900E+00, 0.14239100E-01, -.31894400E-01, -.16741000E+00, -.46203100E+00, 0.21000100E-01, 0.48934800E+00, -.23548900E+00, 0.68513700E+00, -.23094200E+00, 0.48025600E-01, -.76019800E+00, 0.72889200E-01, -.31704200E+00, 0.40153400E+00, 0.11866400E+00, 0.11009000E+00, 0.65604100E+00, -.23409500E+00, 0.19264600E+00, -.14221600E-01, 0.61162300E-01, -.17127100E+00, 0.33501700E+00, -.14257300E+00, -.10713700E+00, 0.96794500E+00, 0.20324100E+00, -.10142500E+00, 0.18443700E+00, -.17224600E+00, -.12538900E+01, -.17195400E+00, -.21834800E+00, -.48839300E-01, -.78609400E+00, 0.66311600E+00, 0.20858100E-01, 0.28222600E+00, 0.31606100E+00, -.10134600E+01, 0.10723800E+00, -.21443300E+00, 0.15349600E+00, 0.14549900E+00, -.43152700E+00, 0.42216000E-01, 0.66614200E-01, -.22348200E-01, 0.14032300E+00, 0.75383400E+00, -.14719900E+00, -.57081500E+02, 0.27287700E+00, 0.24576200E+03, -.12274600E+03, -.12419500E+03, 0.17361500E+02, -.28510800E+02, -.94571200E+02, -.65252500E+02, -.10118200E+03, -.28767900E+01, -.14756100E+02, 0.85939500E+01, 0.56603700E+01, -.26411700E+01, -.52694000E+01, 0.14036900E+02, 0.33883600E+01, 0.22020200E+02, -.14069800E+02, -.24784500E+02, 0.15180100E+02, 0.62931400E+01, -.52518000E+01, 0.42009100E+02, 0.54199400E+01, -.16332100E+01, -.21462200E+02, 0.88021000E-01, 0.16493200E+01, 0.35427400E+02, -.38909800E+01, 0.99120600E+01, -.19191100E+01, -.57294400E+01, 0.58822200E+01, -.17166000E+01, 0.97755800E+01, 0.25541500E+01, -.36803200E+01, 0.27520600E+01, -.60525200E+00, -.61938300E+01, -.26084300E+01, -.41887000E+00, 0.13872000E+01, -.89026800E+01, 0.76074700E+01, -.34831400E+01, 0.29327100E+01, -.64899200E+01, 0.75845400E+01, -.23313200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24878700E+00, 0.16815700E+01, 0.35285100E+00, -.98102400E+00, -.30592400E+00, 0.10219300E+01, -.24738000E+01, -.55721900E+00, -.57763900E+00, -.43517500E+00, 0.21677500E+00, 0.35595900E+00, 0.21667300E+00, 0.45185200E-01, 0.38242000E+00, 0.53628200E-01, 0.91564000E-01, -.41884100E+00, 0.57811700E+00, 0.68269800E+00, -.15695800E+00, 0.84338700E-01, 0.51815300E+00, -.91788500E-01, -.25488500E+00, 0.15421100E+01, -.93248500E+00, -.48321400E+00, -.16862400E+01, 0.11203300E+00, 0.97994200E+00, -.28932700E+00, 0.22710300E+00, 0.20745000E+00, -.18914100E+00, -.18689500E+00, 0.77738700E+00, -.16449500E+01, -.57006200E-01, -.42255200E+00, -.10200300E+00, 0.13739900E+00, 0.73521100E+00, 0.79984700E+00, 0.21091300E+00, -.21373300E+00, -.31641400E-01, 0.31968300E+00, -.10705000E+01, 0.64974200E+00, 0.38994600E-01, -.12839800E+00, 0.12596600E+01, 0.61938600E-01, 0.24783700E+00, -.75999600E-01, 0.23860300E-01, 0.22221300E+00, 0.10737900E+01, -.62994200E-01, 0.35481800E-01, 0.71985400E-01, 0.30137100E-01, -.18029500E+00, -.20436600E-02, -.93989600E-01, -.77622000E-01, 0.23121700E+00, -.22269200E-01, -.41163000E+00, 0.57640400E-01, 0.22353900E+00, -.50355400E+00, 0.14699600E+00, 0.62426600E-01, 0.41802200E-02, -.90813900E-01, 0.69813300E-01, 0.42095900E-01, -.85855500E-01, -.13737800E+00, -.11293100E+00, -.21889300E-01, 0.11867800E+00, 0.60335800E-01, 0.11236000E+00, 0.16034700E+00, 0.91719300E+00, 0.13810300E+00, -.12825600E+00, -.21506800E-01, -.29380800E-01, -.17667100E-01, -.21135400E-01, -.83418000E-01, -.30318600E+00, 0.26095000E-02, 0.14584600E+00, -.36786500E-01, 0.32050200E+00, -.71724500E-02, 0.31877800E+00, -.14337400E+00, 0.15763600E+00, 0.72263700E-01, 0.24362400E-01, -.63987900E-02, 0.70934100E-01, 0.74919700E-01, -.29108300E-01, 0.13343600E+00, -.13653300E+00, -.22440900E+00, 0.95084300E-01, 0.10913000E-01, -.45849400E-01, 0.27727100E-01, -.34436300E+00, 0.63811300E-03, -.18185700E+00, 0.12539800E-02, -.24558500E-01, -.12890100E+00, 0.33568300E+00, 0.62817800E-01, -.47249600E-03, 0.12121300E+00, -.46215400E-02, 0.59606700E-01, -.28113000E-01, -.12909300E+00, 0.25445600E-01, -.85699600E-01, -.22865900E-01, -.72855900E-02, -.47370000E-01, -.28914000E-01, -.82643900E-01, -.13193600E+00, 0.95720000E-01, -.29794000E-02, 0.81728100E-01, -.14190300E+00, 0.21163100E+00, -.10307000E+00, 0.34884000E-01, 0.15917000E-01, -.77024500E-01, 0.13266200E+00, -.26722500E+00, -.65306800E-01, -.71002100E-01, 0.17405000E+00, 0.68812300E-01, 0.10992900E+00, -.34047200E-01, -.22989700E-01, 0.34387800E-01, 0.86309700E-01, -.29717900E-01, -.11378400E+00, 0.49637700E-01, -.17352300E+00, 0.68879500E-01, 0.12659100E+00, -.22104600E+00, -.12084600E-01, 0.12234500E-01, -.88164200E-01, 0.37483300E-01, 0.57152300E-01, -.21171000E-01, -.16886500E+00, 0.26386000E+00, -.95644500E-01, 0.11432700E+00, 0.26869200E+00, 0.57045700E-01, 0.20605300E+00, -.37740200E+01, 0.11049600E+02, -.59251400E+01, -.56706500E+01, -.38566600E+00, -.18646800E+01, -.29214700E+01, -.48159600E+01, -.18258500E+02, -.56786200E+01, 0.13676700E+02, -.67781300E+01, -.65935000E+01, -.10941400E+02, -.67850900E+01, 0.14786600E+01, 0.62398900E+01, -.13046000E+01, -.66718500E+01, 0.24825800E+02, -.17719300E+02, -.13822000E+02, 0.13037600E+02, 0.28852200E+02, -.14627100E+02, -.50635900E+01, -.38003400E+01, 0.14079600E+02, -.12634400E+01, 0.12030300E+02, -.98820600E+00, 0.15723500E+01, -.11011400E+02, -.62821800E+00, 0.44148700E+01, -.22417700E+01, 0.62496800E+00, 0.24496700E+01, 0.25027700E+01, 0.24427000E+01, 0.52041500E+00, 0.27147900E+01, 0.20900800E+01, 0.18964500E+01, 0.64697000E+01, -.91342400E+00, 0.34246700E+01, 0.27776300E+01, 0.10659400E+02, 0.11046300E+00, 0.20335900E+01, -.86784300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.80042700E+01, 0.45948400E+01, 0.40832300E+01, -.12765900E+02, 0.16307200E+01, 0.12490800E+02, -.12760100E+02, -.39926300E+01, 0.48473000E+01, -.31181000E+01, -.56076000E+00, 0.27486500E+00, -.17226800E+01, -.35379700E+01, -.23001000E+01, 0.36225500E+01, 0.19030800E+01, -.54033400E+00, 0.68161100E+01, -.73087600E+01, -.10219900E-01, -.39009100E+01, 0.20665800E+01, -.38337800E+00, 0.34478200E+01, -.53896200E+01, -.47120500E+01, 0.64013300E+01, -.17285900E+01, -.24311000E+01, -.20826400E+01, -.25296200E+01, -.21811900E+00, 0.48950300E+00, -.22021200E+01, 0.10794900E+01, -.12575500E+01, -.74921900E+01, -.35887300E+00, -.67558600E+01, -.11425700E+01, 0.42720900E+01, -.43232600E+01, 0.53554900E+01, -.11938300E+01, 0.23677600E+01, 0.20162800E+00, 0.21833400E+01, -.24772100E+01, 0.37425500E+00, 0.83649600E+00, 0.43726600E+01, 0.35504200E+01, 0.26754400E+01, 0.32726300E-01, -.20876700E+00, -.90874200E-01, 0.23836200E+01, 0.22367600E+01, 0.29114400E+01, 0.66410100E+00, 0.33798500E+00, -.48750900E+00, 0.12793100E+01, 0.78779100E+00, -.99451600E-01, -.50121300E+00, 0.28727700E+01, 0.11717600E+00, -.78176900E+01, -.70654800E-01, 0.49737800E+00, -.72081500E+01, -.13714900E+01, 0.25993100E+01, -.54160900E+00, -.33799000E+01, 0.41797700E+00, -.53728200E+00, -.40067700E+01, 0.49135200E+00, -.52809100E-01, 0.19936600E+00, 0.70181500E+00, 0.47860300E+00, -.50690100E-01, -.10548300E+01, 0.81507500E+01, 0.19723700E+01, -.59005100E+00, 0.39245500E+00, 0.79937600E-02, -.38945600E+00, -.65172200E+00, -.99291100E+00, 0.28417500E+00, -.19653800E+00, 0.21857200E+01, -.52408000E+00, -.12221000E+01, -.49276100E+00, -.23033200E+01, 0.14456200E+01, -.13710700E+01, 0.48986200E+00, 0.35077700E+00, 0.84328100E+00, 0.25749100E+00, -.87902300E+00, 0.46717100E+00, 0.19435800E+01, 0.45388800E+00, 0.40484700E+00, -.16083100E+01, -.72981100E+00, 0.33609100E+01, 0.96292400E+00, -.19840700E+01, -.36088200E+00, 0.23367300E+00, -.57907600E-01, -.17385700E+01, 0.38107200E+00, 0.97758900E+00, 0.54324300E+00, -.76546000E+00, 0.76285200E-01, 0.19691800E-01, -.24195000E+00, -.10068200E+00, -.30788500E+00, -.42190000E+00, -.29977100E+00, 0.57310500E+00, 0.63194100E+00, 0.33348100E+00, -.51079600E-01, -.12962000E+00, -.29721300E+00, 0.25095500E+00, 0.63568400E+00, 0.32274300E+00, -.10334700E+01, 0.16050000E+01, 0.32068500E-01, 0.95097700E-01, 0.23160500E+00, -.52827900E+00, 0.82962900E+00, 0.41320900E+00, -.29731700E+00, -.38831800E+00, 0.35903000E+01, -.32889700E+00, 0.49902700E+00, -.38117100E+00, 0.16340900E+00, 0.27998900E+01, 0.16786200E+00, -.57203100E+00, -.78362500E+00, -.10110400E+01, -.44045300E+00, -.34255100E+00, 0.49900900E+00, -.41461800E-01, 0.28379100E+01, -.17255200E+00, -.11731800E+01, 0.71691400E+00, -.36280600E+00, -.73826900E+00, -.15690800E+00, -.22752900E+01, -.67402900E+00, -.91559900E+00, -.15465400E+01, -.23679900E+00, 0.11197600E+01, -.56393200E+01, -.62397300E+03, 0.31334700E+03, 0.31366200E+03, -.34249400E+02, 0.96129900E+02, 0.24632800E+03, 0.19345900E+03, 0.30247800E+03, -.21158600E+02, 0.83993400E+01, -.32414800E+01, 0.21411000E+01, -.22324500E+02, 0.11346900E+02, -.22050400E+01, 0.22070300E+01, -.94740800E+02, 0.21757700E+02, 0.59235700E+02, -.20006600E+02, -.33361800E+02, 0.10689500E+02, -.94294900E+02, -.32601200E+02, -.12629700E+02, 0.56538400E+02, 0.14343600E+02, -.28561800E+01, -.74253600E+02, 0.67372900E+01, -.16864000E+02, -.12077300E+02, 0.71961300E+01, -.11126100E+02, 0.29415500E+00, -.20162300E+02, -.55386600E+01, 0.15953000E+02, -.65565300E+01, 0.65890400E+01, 0.20367000E+02, 0.11625800E+02, 0.11145800E+00, 0.90111600E+00, 0.17298600E+02, 0.67346300E+01, 0.18368400E+02, 0.11241300E+02, 0.15867700E+02, 0.21033300E+01, 0.44084100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.70590400E+01, 0.57585300E+01, 0.34215400E+01, -.10039900E+02, -.86847000E+00, 0.93740000E+01, -.10967800E+02, -.31926500E+01, 0.33809600E+01, -.40530600E+01, -.94557900E+00, 0.24565600E+00, -.26450600E+01, -.39717900E+01, -.36123200E+00, 0.40671700E+01, 0.34800300E+01, -.25207500E+01, 0.45672800E+01, -.11001300E+02, 0.19399300E+01, -.34214500E+01, 0.17104200E+01, -.10115400E+00, 0.33044600E+01, -.90971400E+01, -.18539000E+01, 0.77476300E+01, -.13365100E+01, -.31813700E+01, -.18115600E+01, -.53939900E+00, 0.32048200E+00, 0.17124100E+00, -.16616100E+01, 0.84634800E+00, -.20360700E+01, 0.27509600E+01, 0.13115800E+01, -.69015800E+01, -.96467400E-01, -.11948600E+01, -.24557800E+01, 0.39920700E+01, -.13735600E+01, 0.15920500E+01, 0.92787200E+00, 0.12733500E+01, -.10586400E+01, 0.42131500E+01, -.22083600E-01, -.38006800E+00, 0.42613000E+00, 0.82214700E+00, -.28726700E+01, -.15954900E+01, 0.26298400E+00, -.23687300E+01, -.32284300E+01, 0.50024400E+01, 0.70658600E+00, -.14171700E+01, -.10440400E-01, 0.37967800E+00, 0.66373700E-01, 0.14560200E+01, -.10344600E+01, 0.14378200E+01, -.17704300E+00, 0.27833100E+01, -.14708600E+01, -.53330800E+00, -.19742400E+01, 0.11829200E+01, -.35716300E+00, 0.44255700E+00, -.11466800E+01, -.11476000E+01, 0.78808000E+00, -.16735500E+01, 0.26801300E+00, 0.79018100E-01, 0.83961400E-01, -.35352300E+00, -.41885600E-01, -.51346400E+00, -.88584100E+00, 0.44058900E+01, 0.41400700E+00, -.11525400E+01, 0.18581300E+00, -.36239100E+00, 0.11971800E+00, 0.74197300E+00, 0.20724500E+00, 0.12228900E+01, -.35409800E+00, 0.87780900E+00, -.38632100E+00, 0.25451200E+01, -.11371000E+01, 0.20892000E+01, 0.17070800E+00, 0.11267700E+01, 0.70878300E-01, -.27254900E+00, 0.16399200E+01, 0.87373400E+00, -.11480500E+01, 0.28268600E+00, -.17328200E+00, -.37717000E+00, -.98896300E+00, -.14390000E+01, 0.10210300E+01, 0.16163500E+01, 0.50888300E+00, 0.19764000E+01, -.39435800E+00, 0.19077500E+01, 0.14732100E+01, 0.57637300E+00, 0.54495800E+00, -.11729900E-01, 0.64996200E+00, -.37769600E+00, -.38726700E+00, 0.27496400E-01, 0.21853500E+00, 0.66502300E+00, 0.40069400E+00, -.37309300E+00, 0.45407500E+00, 0.68395700E+00, -.98520800E+00, 0.55007700E+00, 0.12758100E+00, -.89119000E-01, -.25038900E+00, 0.64251000E+00, 0.74258200E+00, 0.61683600E+00, -.32347700E+00, -.33872000E+00, -.25959400E+00, 0.36789700E-01, 0.89288800E-01, 0.34806700E+00, 0.99097400E+00, 0.52480000E+00, 0.23476500E+00, -.35642300E-01, -.71172000E+00, 0.49549800E+00, 0.35379400E+00, -.71769100E-02, -.13949800E+00, -.94716500E+00, 0.63798200E-01, 0.40630000E+00, 0.32458300E+00, 0.69495400E-01, 0.86907700E+00, -.12548600E+00, -.10399000E+01, 0.23759500E+00, 0.86960500E+00, -.35271500E+00, -.49130800E+00, -.15570300E+00, -.53355200E-01, -.70058100E+00, 0.97459800E-01, -.36549300E+00, -.17849200E+00, 0.43590100E-01, 0.46439300E+00, -.18105900E-01, -.82541000E+00, -.13471600E+01, -.84289100E-01, 0.15820400E+02, 0.35579900E+00, -.23632800E+01, -.81752700E+01, -.11075800E+01, 0.68129200E+01, -.40118900E+02, -.29568200E+01, -.18374900E+00, 0.12090300E+01, 0.85357100E+00, -.18130500E+02, -.20757400E+02, 0.13717800E+02, 0.17698500E+02, 0.26279500E+02, -.17443600E+02, -.76697300E+02, 0.14999700E+02, 0.37492000E+02, -.84846900E+01, 0.15987100E+02, 0.26320000E+02, 0.10228900E+02, 0.63766700E+02, 0.11556000E+02, 0.26688400E+00, 0.44816400E+01, 0.53572100E+00, -.16472500E+01, -.78803100E+01, -.31697300E+01, 0.41438200E+01, -.82827300E+00, -.12328300E+01, 0.10458300E+01, -.44919700E+01, 0.15690500E+01, -.26509700E+01, -.11593700E+01, -.38369000E-01, 0.83693900E+00, 0.40335100E+01, 0.13062000E+01, 0.14164700E+01, -.36055700E+01, 0.78068100E+01, -.76896900E+00, -.69742500E-01, -.24978500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.68701600E+01, 0.44747500E+01, 0.36541100E+01, -.11247500E+02, 0.45099500E-01, 0.11545500E+02, -.12600500E+02, -.35912800E+01, 0.33071000E+01, -.43569100E+01, 0.59748700E-01, 0.10609300E+01, -.16909300E+01, -.31140800E+01, -.17202000E+01, 0.48013600E+01, 0.40005600E+01, -.15958400E+01, 0.73579800E+01, -.72759300E+00, 0.29313400E+01, -.59698100E+00, 0.19005900E+01, -.24648300E+01, 0.45242900E+01, -.87202300E+01, -.20403200E+01, 0.65109700E+01, -.25307000E+01, -.44302600E+01, 0.27588700E+00, 0.14656500E+01, 0.98354300E+00, 0.47470600E+00, 0.11136500E+00, 0.73726800E+00, -.32741700E+01, -.92828500E+01, 0.42653100E+00, 0.52698400E+00, 0.17602700E+00, 0.47801600E+01, -.62266900E+01, 0.28635900E+01, -.21922600E+01, 0.20270500E+01, 0.23563000E+00, 0.19239900E+01, -.12625400E+01, 0.29362200E+01, -.96772800E+00, 0.11913200E+01, 0.22439100E+01, 0.15763300E+01, -.74522300E+00, -.44967300E+00, 0.67572400E+00, 0.44971000E+01, 0.34655200E+01, 0.17562400E+01, -.45660400E+00, -.16106100E+01, -.47258500E+00, -.38631400E+00, 0.68966100E+00, 0.40601200E+00, -.69531500E+00, 0.63448900E+00, -.22873200E+00, -.55951200E+01, -.21937500E+00, 0.22045000E+01, -.73749700E+01, 0.62638400E+00, 0.20031400E+00, 0.12179100E+01, -.75893100E+00, 0.73379000E+00, 0.35102300E+00, 0.13639600E+01, -.17364300E+00, 0.37900500E+00, 0.10630000E+00, -.16210700E+00, 0.99306700E-01, 0.13756100E+01, -.82332800E+00, 0.78772100E+01, 0.52540900E+00, -.14252800E+01, 0.22240400E-01, -.10368400E+00, -.16013900E+00, 0.26895500E+01, 0.56319100E+00, -.17389700E+01, 0.34354900E-01, 0.28634300E+01, -.86743400E+00, 0.37085200E+01, -.12710800E+00, 0.62352200E+01, -.17256800E+01, 0.17992800E+01, 0.28683500E+00, -.10446800E+01, 0.19898100E+01, -.10432400E+00, 0.18805300E+01, 0.35499700E+00, -.10993800E+01, 0.23081300E+00, -.13658900E+01, -.10951800E+01, 0.24345200E+00, 0.37118100E+00, 0.53132100E+00, 0.41264600E+01, -.11063800E+00, 0.27686200E+01, 0.14620600E+01, 0.15124500E+01, -.94684300E+00, 0.31443700E+00, -.16312200E+00, 0.36589600E+00, 0.28226900E+00, -.44070100E-01, 0.11095300E+01, 0.97309300E+00, -.18800500E+00, 0.37125100E+00, 0.65053900E+00, 0.37033100E+00, -.25478300E+00, 0.28426000E-01, -.15571200E+00, 0.52830900E+00, 0.21053900E-01, -.60880400E+00, -.10642700E+01, 0.34558400E+00, 0.43961800E+00, -.10520200E+01, -.37389000E+00, 0.11498600E+00, 0.60106800E-03, -.42064700E+00, -.26319300E+00, -.92014700E-01, 0.22824100E+00, 0.89730500E-01, -.10576800E+01, 0.11067200E+01, -.72308700E+00, 0.33480800E+00, 0.44973800E-01, -.31519700E+01, 0.31279000E+00, 0.70952500E+00, -.36696700E-01, 0.76428400E+00, 0.69319200E+00, 0.46720600E-01, -.83540600E+00, -.98465400E+00, -.12192700E+00, -.19427600E+00, 0.77672100E-01, -.26616900E+00, 0.63668200E+00, 0.15786200E+00, 0.32241300E+00, 0.95908900E-02, 0.98788300E-01, 0.83025100E-01, 0.54314600E+00, -.32502900E+00, 0.12424300E+00, -.19518500E+01, 0.20473000E-01, -.77193700E-01, 0.43956200E+01, -.45453400E+00, 0.70408700E+01, -.74746400E+01, -.28269200E+02, -.14671200E+03, -.88541500E+01, 0.10477200E+03, -.54716500E+02, -.54026100E+02, -.43332700E+02, -.51512200E+02, -.54157200E+01, 0.46841200E+02, 0.10782900E+03, -.46448600E+02, -.14950800E+03, 0.46586900E+02, 0.70989700E+02, 0.79096100E+01, 0.20272000E+02, 0.69292800E+02, 0.43201000E+02, 0.13475100E+03, -.16223900E+01, -.10276400E+02, -.45777400E+01, -.63411900E+01, -.29755500E+01, -.15508600E+02, -.47655300E+00, 0.11492300E+02, -.80437500E+01, -.25272900E+01, 0.97511100E+01, -.28915200E+01, 0.12097500E+02, -.83312300E+00, -.20882400E+01, 0.37444200E+01, 0.68055200E+01, 0.86769100E+01, 0.23348400E+01, 0.42753800E+01, -.12846700E+01, 0.15799100E+02, 0.40471300E+00, -.82111900E+00, 0.80900500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12143500E+01, -.19672300E+01, -.83663400E+00, 0.39084700E+01, -.70844000E+00, -.26483100E+01, 0.36300900E+01, 0.95244300E+00, -.18823700E+00, 0.11963200E+01, -.29397100E+00, -.88498300E+00, 0.26128900E+00, -.17182800E+01, 0.96921200E+00, -.18919600E+01, -.13939600E+01, -.10693600E+01, -.10793800E+01, 0.56093800E+00, -.53614300E+00, -.12613600E+00, -.11157500E+01, 0.37798300E-01, -.82523600E+00, 0.10792100E+01, -.16050800E+00, -.10425100E+01, 0.16635900E+00, 0.28207600E+00, 0.68886600E+00, -.31608400E+00, -.28623900E+00, 0.10128000E+00, -.31680100E+00, 0.38055600E+00, 0.17148900E+01, 0.78350700E-01, 0.66030700E+00, 0.21501100E+01, 0.17792700E+00, -.83546800E+00, 0.25303900E+01, -.52925400E+00, 0.10178200E+01, -.38878300E+00, 0.27247800E-01, -.21483900E+00, -.19568100E+00, 0.32146000E+00, 0.26864100E+00, 0.69381900E+00, -.16628400E+00, -.59242800E+00, -.10589000E+00, 0.24922900E+00, -.60964600E-01, -.12232400E+01, -.25435000E+00, -.27262300E+00, 0.84965300E-01, 0.92355500E-01, 0.10825700E+00, -.18742000E+00, 0.19224700E+00, -.25841500E-01, 0.13284700E-01, -.72084600E-01, -.15208300E+00, 0.22775400E+01, 0.47087100E-01, 0.49337900E-01, -.39997400E+00, -.33063700E+00, -.23061800E+00, 0.12654600E+00, -.29193400E-01, -.20528000E+00, 0.13860800E+00, 0.10195800E+01, -.14825700E+00, -.12387600E+00, -.49238600E-01, -.79102300E-01, 0.36136000E-01, 0.22697100E+00, -.13544700E+00, -.27872900E+00, 0.10338800E+00, -.50718300E+00, -.65623400E-01, -.13844100E+00, 0.17047700E+00, 0.77235000E+00, -.10967100E+00, 0.33009000E+00, 0.13872700E-01, 0.45307100E-01, -.49456900E-01, -.61993500E+00, 0.32929500E+00, -.31015000E+01, -.45069900E+00, -.42675500E-01, -.26091700E+00, 0.28314200E-01, 0.36684800E+00, -.19538400E+00, -.78368700E+00, 0.16281900E+00, -.19893100E+00, 0.11233400E+00, 0.79114700E+00, -.44963800E+00, -.24545000E+00, 0.18594200E-01, 0.25625100E-01, -.78674700E-01, -.77608400E-01, 0.25058900E-01, -.18336700E+00, 0.89863500E-01, -.27132000E+00, -.37356700E+00, -.14152000E+00, 0.33560800E-01, -.22100300E+00, 0.87866900E-02, -.93733100E-01, 0.24329500E+00, 0.10826000E+00, -.22466500E+00, -.11635400E-01, 0.19473000E+00, 0.29435600E+00, 0.44734600E+00, -.62039400E-01, 0.80917900E-01, 0.11377000E+00, 0.57446300E-01, -.18000000E+00, -.13698200E+00, -.56589300E-01, -.23059900E+00, -.10951300E+00, 0.58219300E-01, 0.23759200E-01, -.27675000E+00, -.22529200E+00, 0.37810500E-02, -.32922100E-01, 0.81725300E-01, -.19973400E+00, 0.11660700E-01, -.54334900E-01, 0.46703500E-01, 0.14883000E-01, -.89874300E-01, 0.10107700E+00, 0.72047200E-01, 0.27414200E-01, 0.29935400E-01, -.15532300E+00, 0.72014500E-01, 0.12972000E-01, -.32651100E+00, -.20206500E+00, 0.61972200E-02, -.80627000E-02, -.12265200E+00, -.14018200E-01, 0.43385500E+00, 0.50516500E-01, -.53514500E-01, -.10864200E-01, 0.10518200E-01, -.16094300E+00, -.15292000E-01, -.15602400E+00, 0.34098700E+00, -.10685100E+00, -.40839300E-01, 0.54422700E-01, -.84741100E+01, -.81783300E+01, 0.31724700E+01, 0.11147700E+02, 0.32867600E+02, -.15756400E+02, -.12232500E+02, 0.53462000E+01, 0.65374400E+01, 0.17548900E+02, 0.15620100E+02, -.72609800E+01, -.19841400E+02, -.43208700E+02, 0.19482600E+02, 0.35781200E+01, -.62236500E+01, -.16829600E+01, -.57748700E+01, -.12811300E+02, -.29848500E+00, 0.10605100E+01, 0.17102300E+02, -.60308900E+01, 0.22975900E+01, -.89537200E+01, 0.31384000E+00, -.98439400E+00, 0.37488600E+01, 0.49795300E+01, -.19962400E+01, 0.15662700E+01, -.16950100E+01, -.22060000E+01, 0.23797900E+01, -.25282300E+01, 0.20935900E+01, 0.91680000E+00, 0.12759500E+01, -.29754000E+00, -.18111600E+01, 0.18689300E+01, -.70570900E+00, 0.23513000E+01, -.37348100E+01, -.10033200E+01, 0.60580300E+00, 0.70028900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13884400E+01, 0.13187000E+01, 0.52221100E+00, -.43547600E+01, 0.61628700E-02, 0.32047000E+01, -.38528800E+01, -.10256500E+01, 0.66810500E+00, -.12125300E+01, 0.56214100E-01, 0.67163900E+00, -.52724000E+00, 0.15033900E+01, -.66095100E+00, 0.29228100E+01, 0.16282400E+01, 0.62579400E-01, 0.14673500E+01, -.91284600E+00, -.23159900E+00, -.56526500E+00, 0.14432700E+01, 0.12009200E+00, 0.37555400E+00, -.12145200E+01, -.78921500E+00, 0.15744100E+01, -.23754800E-01, -.28339400E+00, -.45389400E+00, -.97760400E+00, -.60700400E-01, 0.21366400E+00, -.60628400E+00, -.27616400E-02, -.35163200E+00, 0.17080200E+01, 0.67189300E+00, -.12321300E+01, 0.72881900E-01, -.86402700E+00, 0.84243300E+00, 0.10011400E+01, 0.18980700E+00, 0.12090300E-01, 0.25814500E+00, 0.64608600E+00, -.11887700E+01, 0.13836300E+01, 0.25691700E-01, -.13057200E+01, 0.75043200E+00, -.22899600E+00, -.63299900E-01, -.63970200E+00, 0.69327700E-01, -.11449900E+01, 0.34446600E+00, 0.20713900E+00, -.35367600E-01, -.72259000E+00, 0.42331200E-01, -.39276400E+00, -.19427700E-01, 0.30987300E+00, -.14124400E+00, -.19632600E+00, -.24514800E+00, 0.53711500E+00, -.16586400E+00, -.62451200E-01, -.46429400E+00, -.38068200E-01, -.20282100E-01, 0.53250500E-01, -.18966500E-01, 0.16808700E+00, 0.23327800E+00, -.30449700E+00, -.31110000E+00, 0.32331300E+00, -.28832000E-01, -.37040600E+00, -.11194300E+00, -.50589400E+00, 0.38785500E+00, -.21988000E+01, -.46467200E+00, -.82604000E-02, 0.27575600E+00, -.26104500E+00, 0.51695000E-01, 0.14010800E+01, 0.28303100E+00, -.42978500E+00, 0.55068500E-01, -.83054600E+00, -.81333000E-01, -.78951100E-01, -.62346200E-01, -.11797000E+01, -.15228300E+01, 0.48751800E+00, -.75446600E-01, 0.76283200E-01, 0.25543300E+00, -.13057300E+00, -.52215200E+00, -.25038500E+00, -.24544500E+00, -.29438400E+00, -.11520300E+00, -.96591200E-01, 0.37511200E+00, 0.94592700E-01, 0.23880700E+00, 0.20631800E+00, 0.24134100E-01, 0.15656600E+00, -.20045700E+00, 0.29335900E+00, 0.77909200E+00, -.71343700E+00, 0.11034500E+00, 0.11341500E+00, -.30203900E+00, 0.13790900E-01, -.10806200E+00, 0.19231300E+00, 0.27386400E+00, 0.78613100E-01, 0.56272900E+00, -.24785300E+00, 0.17245800E+00, 0.19634800E-01, -.28978200E-01, -.41514800E+00, -.17893200E+00, -.63051800E-01, 0.21772100E-01, 0.12711000E+00, -.16616800E+00, -.40940500E+00, 0.17988200E-01, 0.53862100E-01, -.49659600E-01, -.34525300E-01, -.33008500E+00, 0.12159600E+00, -.30380200E-01, -.18234800E-01, 0.32364100E-01, -.91615400E-01, 0.70928800E-01, 0.42974700E-01, 0.78224000E-01, 0.14733500E+00, 0.21052800E-01, 0.18456600E+00, 0.62130800E-01, -.21038500E+00, 0.66771300E-01, -.25896900E-01, -.11912100E-02, -.85336000E-01, 0.44963600E+00, -.61890000E-01, -.51317500E+00, -.58927300E-01, -.68502300E-01, 0.27862600E+00, -.37442600E-01, -.43384700E+00, -.15180400E+00, -.39870700E-01, -.21404900E+00, 0.47961900E-02, -.16534600E+00, -.54070200E+00, -.99106700E-01, 0.14100600E-01, 0.42760400E-01, -.33969200E+00, -.88612000E+01, 0.90107800E+01, 0.30711200E+02, 0.58466800E+02, -.11805000E+02, -.26744000E+02, 0.12289500E+02, 0.14217500E+02, 0.17470100E+02, 0.30617600E+02, -.39844200E+01, -.20893900E+02, -.64412500E+02, 0.27000200E+02, -.41258300E+02, 0.16679700E+02, 0.20665100E+02, -.76843400E+01, -.28773400E+02, 0.10739800E+02, -.93997800E+01, 0.22526000E+02, -.87696600E+01, 0.53568300E+01, -.74080800E+01, 0.22407300E+01, 0.10549900E+01, 0.52673700E+00, 0.94565700E+00, -.23245100E+01, 0.31292700E+01, 0.39673100E+00, -.42050200E+01, 0.10291300E+00, -.54353300E+01, 0.99470600E+00, -.58254300E+00, 0.22392100E+00, -.16917500E+01, -.21354300E+01, -.34437900E+00, -.57823700E+00, 0.20924300E+00, -.64621200E+00, -.17868900E+01, -.24250800E+00, 0.35184700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.69901700E+01, -.26227600E+01, -.29201400E+01, 0.11236200E+02, 0.33314300E+00, -.11048000E+02, 0.12213200E+02, 0.34483100E+01, -.29832400E+01, 0.38600600E+01, 0.45816600E+00, -.39820700E+00, 0.16789300E+01, 0.79709000E+00, 0.35289200E+01, -.40583400E+01, -.34187700E+01, -.15814200E+01, -.83275300E+01, -.24217600E+00, -.19458800E+01, 0.58577600E+00, -.22749500E+01, 0.20064100E+01, -.46294800E+01, 0.76526600E+01, 0.16213800E+01, -.61603500E+01, 0.10771800E+01, 0.34263800E+01, 0.10455500E+01, -.50065800E+00, -.78048900E+00, -.43852600E+00, -.10213500E+00, -.49229300E+00, 0.60910200E+01, 0.59451900E+01, 0.16236300E-01, 0.44130500E+01, 0.38781600E+00, -.54315400E+01, 0.94941500E+01, -.47323300E+01, 0.31845800E+01, -.27421800E+01, 0.61917400E-01, -.13871600E+01, 0.21241100E+01, -.12504100E+01, 0.89580700E+00, 0.98549500E+00, -.47628800E+01, -.27703900E+01, -.20490400E+01, -.40043100E+00, -.49995000E+00, -.46559100E+01, -.83922600E+01, -.33149200E+00, 0.94479400E+00, 0.12060900E+01, 0.40887800E+00, 0.12321700E+01, -.50122800E+00, -.98649000E+00, 0.74494500E+00, -.14458000E+01, 0.10603600E+00, 0.96025900E+01, 0.22688400E+00, 0.88331900E+00, 0.13302000E+01, -.87360400E+00, -.21258800E+01, 0.57009300E+00, 0.12982600E+01, -.32633700E+01, 0.60916200E+00, 0.24451800E+00, -.55655100E-01, 0.24984700E+00, -.30433800E+00, 0.14646100E+00, -.24990200E+00, 0.12601100E+01, 0.12128800E+01, -.41676200E+01, -.79023000E+00, 0.16746700E+01, -.62421400E+00, 0.40356300E+00, 0.31726100E+00, -.84640500E+00, -.26881400E-01, 0.47765800E+00, 0.11446800E+00, -.81999100E+00, 0.58411900E+00, -.37070300E+00, 0.74690500E+00, -.11436700E+01, -.10791700E+01, 0.12133100E+00, 0.67508200E+00, -.17490000E+00, -.94229300E+00, 0.13621000E+01, 0.92282800E+00, -.41528200E+00, -.32745200E+00, 0.45326000E+00, 0.12211000E+01, -.32706300E-01, -.11410200E+00, 0.11655600E+00, -.62049600E+00, -.98454200E+00, -.33290100E+00, -.23241400E+01, 0.10516000E+01, 0.44491200E+00, -.50257200E+00, 0.14915200E+01, 0.10854000E+01, 0.16473200E+00, 0.47962300E+00, -.50348200E-01, -.10754300E+01, -.66919500E+00, -.50513800E+00, -.18089800E+00, 0.73645500E-01, 0.17196100E+00, -.61395900E+00, -.49409300E+00, 0.39609900E+00, -.14454400E+01, -.11969800E+01, 0.10566200E+01, 0.31604300E+01, 0.22580300E+01, 0.62162900E+00, -.66199800E+00, -.88226700E-01, -.28033200E+00, -.11283900E+00, -.19155800E+00, 0.17584200E+01, 0.15236200E+01, 0.27390800E+00, -.42239900E+00, 0.23174400E+01, -.21265200E+00, 0.56485900E+00, 0.15538800E+00, -.22543500E+00, 0.11492000E+01, 0.18261500E+00, -.49962600E+00, -.50532000E+00, 0.14297600E+01, -.83615100E+00, 0.53917500E-01, 0.13260700E+01, 0.89420100E+00, 0.76008300E+00, -.42699700E-01, 0.93267200E+00, 0.11240400E+01, -.20914700E+00, -.10105300E+01, -.10118500E+01, 0.19187600E+01, -.71366100E+00, 0.28830700E+00, 0.59847400E+00, 0.72173100E+00, 0.30055300E+00, 0.63559300E+01, 0.42562100E+00, 0.15378000E+00, -.19244400E+00, -.23282800E+01, 0.35942400E+01, -.28226300E+02, -.83191200E+02, -.10533700E+03, 0.84097800E+02, -.57019300E+02, 0.38486900E+02, 0.23494600E+02, -.23036800E+02, -.86031100E+02, 0.37733600E+02, 0.44589800E+02, 0.21415500E+03, -.82450400E+02, 0.58608400E+03, -.25125700E+03, -.28856600E+03, 0.21195300E+02, 0.12710300E+03, -.19369000E+03, 0.80645700E+00, -.33508400E+03, 0.27695600E+02, -.98096300E+01, 0.47859900E+02, -.28108300E+01, -.12465500E+01, 0.97025200E+01, 0.61698500E+01, 0.67943200E+00, -.73376200E+01, 0.16923900E+01, 0.12380400E+02, 0.30078400E+01, 0.14720300E+02, -.75230400E+00, 0.62397500E+01, -.95590600E+01, 0.26291200E+01, 0.72060200E+01, -.68800100E+00, -.92663300E+01, -.72842800E-01, -.90306200E+01, 0.10084600E+02, -.35670900E+00, -.29699100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10721400E+02, 0.89414300E+01, 0.49429800E+01, -.13722000E+02, -.12155000E+01, 0.12749500E+02, -.14743200E+02, -.46013800E+01, 0.57959100E+01, -.60346100E+01, -.10864000E+01, -.24390600E+00, -.31459600E+01, -.39384800E+01, -.20879800E+01, 0.60224900E+01, 0.40121600E+01, -.21234600E+01, 0.69504600E+01, -.15385000E+02, 0.14843000E+01, -.52456800E+01, 0.27896800E+01, 0.44887400E+00, 0.43056500E+01, -.10324100E+02, -.32939000E+01, 0.10056700E+02, -.24612800E+01, -.46064200E+01, -.20792300E+01, 0.37974300E+00, 0.17557700E+01, -.14801300E+00, -.33205100E+01, 0.11438600E+01, -.72891800E+00, 0.76783500E+00, 0.24579200E+01, -.12814000E+02, -.65950200E-01, -.13718000E+01, -.42909400E+01, 0.68546800E+01, -.13299200E+01, 0.26768400E+01, 0.96765900E+00, 0.88227300E+00, 0.35335700E+00, 0.45229800E+01, 0.36530500E+00, 0.12780000E+01, 0.12555100E+00, 0.99479100E+00, -.34585300E+01, -.14397600E+01, 0.20121200E+00, -.35672800E+01, -.69265600E+01, 0.61344000E+01, 0.12437200E+01, -.58888800E+00, -.42513000E-01, 0.13608200E+01, -.51565100E-01, 0.16786700E+01, -.10158900E+01, 0.27059400E+01, 0.88560800E-01, 0.37229400E+01, -.17361600E+01, -.37512500E+00, -.11047300E+01, 0.79769800E+00, -.36893600E-01, 0.23253100E+00, -.70060500E+00, -.13021800E+01, 0.60617900E+00, -.13344600E+01, 0.48324000E+00, -.49861000E+00, 0.19258900E+00, 0.35494400E-01, 0.96058600E-01, -.26197400E+00, -.94611200E+00, 0.65490200E+01, 0.12396500E+01, -.11602700E+01, 0.59623600E+00, -.36786300E+00, 0.14499800E+00, 0.86285500E+00, -.18785100E+00, 0.12697400E+01, -.53883200E+00, 0.14093900E+01, -.65942900E+00, 0.21848000E+01, -.16250400E+01, 0.17088100E+01, -.64589500E+00, 0.14214400E+01, -.47192100E+00, -.47849600E-01, 0.17802200E+01, 0.46884400E+00, 0.29585200E+00, 0.10227100E+01, -.13391400E+00, -.76514200E+00, -.15676100E+01, -.10856600E+01, 0.60677400E+00, 0.14548600E+01, 0.85250100E+00, 0.30075300E+01, 0.62443000E+00, 0.32140400E+01, 0.21182800E+01, -.80889200E+00, 0.63302400E+00, 0.96186100E+00, 0.12841100E+01, -.13203300E+01, 0.26369800E+00, 0.61860600E-01, -.89771300E-01, 0.10082600E+01, 0.21150000E+01, -.10785700E+01, -.22735500E+01, 0.12187200E+00, -.18510900E+01, 0.14618500E+01, 0.16335600E+00, 0.10865700E+01, -.14293300E+00, 0.14443000E+01, 0.64152300E+00, 0.82514500E+00, -.10840400E+01, 0.28975400E+00, -.75995700E+00, -.12757500E+00, 0.24598100E+00, 0.14656500E+01, 0.32025500E+01, 0.36054000E+00, 0.39393700E+00, -.57122100E+00, 0.10571200E+01, -.49330400E+00, 0.16962700E+01, 0.22204400E+00, -.44725200E-01, 0.14047100E+01, 0.15689400E+00, -.12307300E+00, 0.44014000E+00, 0.13958300E+00, -.51053200E+00, -.25257100E+00, -.74298900E+00, -.17629700E+00, 0.14002800E+01, -.25976800E-01, -.96966300E+00, -.52376600E+00, -.61738500E+00, 0.17714500E+00, 0.76345300E+00, -.15659400E+01, 0.56834600E+00, -.27557500E+00, -.91553300E+00, -.29535200E+00, -.13174600E+01, -.42336400E+01, -.38601300E+00, -.90872200E+00, 0.53804400E+00, -.20000300E+00, -.22176600E+01, -.61700300E+00, 0.75533300E+02, 0.15797300E+03, 0.27994000E-01, -.21352700E+03, 0.10896200E+03, 0.11103500E+03, 0.40458800E+02, 0.44771300E+02, 0.45854100E+02, -.36130800E+02, -.11025300E+03, 0.49188000E+02, -.10252500E+00, -.92285500E+02, 0.59731900E+01, -.77655600E+02, -.10770100E+03, -.41502100E+00, -.49024300E+01, 0.74782000E+02, -.30677500E+02, 0.30408500E+02, -.47369000E+02, 0.22110900E+02, -.12476700E+02, 0.18418000E+02, 0.60223400E+00, -.24768300E+02, 0.22614400E+02, -.11993000E+02, -.29422700E+02, -.16250400E+02, -.30887200E+02, -.94584500E+01, -.11649700E+02, -.18255100E+02, -.21019400E+02, -.23781900E+02, 0.12252900E+02, -.18653400E+02, -.16519800E+02, -.19040200E+02, -.13059200E+02, -.11955200E+02, 0.28728600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17175100E+01, 0.15152200E+01, 0.72121600E+00, -.43945200E+01, -.74732400E-01, 0.34505500E+01, -.40875100E+01, -.11241700E+01, 0.12254100E+01, -.13261000E+01, 0.26522800E+00, 0.67485700E+00, -.41516400E+00, 0.95465200E+00, -.95531900E+00, 0.20994500E+01, 0.16703300E+01, 0.12167700E+01, 0.18655400E+01, 0.19610800E+01, 0.50724600E+00, 0.68039100E+00, 0.11856200E+01, -.84707100E+00, 0.94814300E+00, -.13382300E+01, 0.60116800E+00, 0.22526200E+01, 0.25486500E+01, -.11100600E+01, -.96927900E+00, 0.11590700E+01, 0.37080400E+00, -.45511300E+00, -.57828100E+00, 0.99565200E+00, 0.15588000E+01, 0.30930700E+00, 0.17190900E+01, 0.23059000E+00, 0.11519100E+01, -.80784500E+00, 0.15537400E+01, -.13955000E+01, -.13762200E+01, -.11746000E+00, 0.53312000E+00, 0.93161500E+00, 0.38740700E+00, -.66511400E+00, -.39560400E-01, -.43192900E-01, -.87370300E+00, 0.27033800E+00, -.99925700E-01, -.14768200E+00, 0.15541600E+00, 0.61507900E+00, 0.70964200E+00, -.59303800E+00, -.10789100E+00, -.17365600E+00, -.17057500E-01, -.39383700E+00, 0.93147800E-01, -.97006100E-01, 0.11386800E+00, -.62334400E+00, 0.26714700E-01, -.78546000E+00, 0.12326000E+00, 0.13247100E+01, -.11462200E+01, 0.68050100E+00, -.14354000E+00, 0.42711100E+00, 0.12896300E+00, 0.21779800E+00, 0.10909200E+00, 0.43991600E+00, -.13877400E+00, 0.46617500E-01, -.66448200E-02, -.46033300E-01, 0.74683800E-02, -.24924100E-01, -.84502800E-01, 0.75613200E+00, -.69486600E-01, 0.11070700E-01, -.19933600E+00, 0.12603600E+00, 0.44985000E-01, 0.37155600E+00, 0.16615200E-01, -.38317100E+00, 0.17429200E+00, 0.52485400E+00, -.70323700E-01, 0.23661400E+00, 0.14608100E+00, -.30018200E+00, 0.33680100E+00, -.75558100E-01, -.11422700E+00, -.24589900E+00, -.24233000E+00, -.40117600E+00, -.29046600E+00, 0.12465900E+00, -.18241700E+00, -.30421400E+00, 0.35302000E+00, -.15285700E+00, -.14870200E+00, -.23763500E+00, -.47857700E-01, -.74361200E+00, -.37159500E-01, -.73958300E+00, 0.59370400E-01, 0.17165300E+00, -.13518100E+00, 0.46074100E-02, 0.24211200E+00, -.45773600E-01, 0.35990500E+00, 0.91015300E-02, 0.25411500E-01, 0.16278000E+00, 0.43294900E-01, -.58705400E-01, -.30411900E+00, -.19894400E+00, 0.34597200E+00, 0.61035700E-01, -.81712300E-01, 0.30229400E+00, 0.18008000E+00, -.27855100E+00, -.68340200E+00, -.51501500E+00, -.44651800E-01, 0.30082100E+00, -.41355900E-01, 0.12016800E+00, -.34722000E-01, 0.21578600E+00, -.31825700E+00, -.22988700E+00, 0.64909600E-02, 0.11232500E-01, -.51321200E-02, 0.17636000E+00, -.18517700E+00, 0.69360200E-01, 0.55620200E-01, -.70432200E+00, -.19255800E-02, -.31812700E+00, -.46467800E-01, 0.96155700E-01, -.14562700E+00, -.20985000E-01, 0.13522900E+00, -.88923800E-01, -.67625000E+00, 0.17991600E+00, 0.25880000E+00, -.24287600E+00, 0.31544800E-01, 0.70910300E-02, 0.50009300E+00, 0.27667600E+00, 0.62699900E+00, -.12603200E-01, -.37673600E-01, -.11660000E+00, 0.29641200E-01, 0.18246200E+01, -.65162600E-01, 0.91529800E-01, 0.15845100E+00, -.30704200E+00, -.21657500E+00, 0.12369400E-01, 0.13340500E+00, 0.40465200E+02, 0.44330400E+01, -.72363200E+00, -.12526100E+01, -.76177900E+00, 0.34946600E+02, 0.24855200E+02, -.19337900E+02, -.25312100E+02, -.21024900E+02, 0.25455200E+02, -.12574000E+03, 0.86496000E+02, 0.63341500E+02, -.21240300E+02, -.68461800E+02, 0.55719400E+02, 0.65186000E+01, 0.30230800E+02, -.33232900E+02, -.90585300E-01, -.25245300E+02, -.41422300E+00, -.58231300E+00, 0.20563800E+02, 0.21741300E+01, -.72889700E+01, 0.25096600E+01, 0.12350700E+01, -.32483100E+01, -.22021800E+01, -.32697000E+01, 0.16108400E+01, -.55622400E+01, -.13602300E+01, -.14211600E+01, -.14295900E+02, -.58083200E+00, -.39829100E+01, -.26985500E+01, -.20571500E+02, 0.40322100E+00, -.12500000E+01, 0.18498300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.16634200E+02, -.95755100E+01, -.66002700E+01, 0.24412100E+02, 0.18215600E+00, -.22283000E+02, 0.22099100E+02, 0.71782100E+01, -.95026100E+01, 0.66845300E+01, 0.23907700E+01, 0.18711700E+01, 0.45389700E+01, 0.86859200E+01, 0.37700400E+01, -.69313200E+01, -.33132400E+01, 0.19359900E+01, -.13122400E+02, 0.22033900E+02, 0.10605500E+01, 0.10248600E+02, -.43043700E+01, -.64033800E+00, -.57323600E+01, 0.11825100E+02, 0.92643400E+01, -.15959200E+02, 0.17757800E+01, 0.61639200E+01, 0.47523600E+01, 0.45344100E+01, -.12618300E+01, -.69690700E+00, 0.59109900E+01, -.24713400E+01, -.64458900E-01, 0.14331300E+02, -.19323600E+01, 0.16435800E+02, 0.15783100E+01, -.21674100E+01, 0.53680100E+01, -.12656300E+02, 0.16626600E+01, -.40765100E+01, -.10948500E+01, -.19398500E+01, 0.36978400E+01, -.34597800E+01, -.17583100E+01, -.69207800E+01, -.49988200E+01, -.33720800E+01, 0.37339600E+01, -.10699500E+01, 0.36793400E+00, 0.50269500E+01, 0.10328100E+02, -.11167500E+02, -.24054300E+01, -.50355500E+00, 0.20844600E+00, -.31054100E+01, -.71186000E+00, -.12849900E+01, 0.60834800E+00, -.44729300E+01, 0.71098600E-01, -.65852100E+01, 0.20658200E+01, 0.13076900E+00, 0.50453800E+01, -.12372200E+01, -.25532300E+01, 0.54810500E+00, 0.41343300E+01, 0.84448300E+00, -.10589000E+00, 0.56474000E+01, -.12745700E+01, 0.11895900E+01, -.23590200E+00, -.17788400E+01, -.70971700E+00, 0.12851200E+01, 0.12823000E+01, -.14776200E+02, -.40643000E+01, -.40351700E+00, -.54140200E+00, -.37473300E+00, 0.44685200E+00, 0.42983000E+01, 0.27176400E+01, -.89919800E+00, 0.64115500E+00, -.29658900E+01, 0.58216900E+00, 0.24190100E+01, 0.96451900E+00, 0.38592900E+01, -.22388700E+01, 0.20885300E+01, -.12346600E+01, 0.34985500E-01, -.29295200E+00, -.16582400E+01, 0.16857800E+01, -.54835700E+00, -.28124000E+01, -.18073000E+01, -.18374200E+01, 0.15501900E+01, 0.54475700E+00, -.41501800E+01, -.49519900E+00, 0.37684600E+01, 0.56861800E+00, 0.12816000E+01, -.53175600E+00, 0.11689400E+01, 0.62882200E+00, -.29972100E+01, -.88954300E+00, 0.11264600E+01, -.82852700E+00, -.87506800E-01, 0.43940200E-01, 0.62911700E+00, 0.37278400E+00, 0.43521800E+00, 0.30894500E+01, 0.25810700E+00, -.11584400E+01, -.32308600E+00, 0.59354400E-01, -.12127200E+01, -.39711000E+00, -.14821700E-01, 0.35699400E+00, 0.41126500E+00, -.19275600E+00, -.10960500E+01, 0.33192300E+00, 0.33447000E+00, -.20179400E+00, 0.51905200E+00, -.21407400E+01, -.24327500E+01, -.27144700E+00, 0.70349900E+00, -.65761600E+01, 0.60586600E+00, -.75877500E+00, -.15478900E+01, -.47619000E+00, 0.58160400E+00, -.41643600E+00, 0.21422400E+01, 0.18483500E+01, -.84312000E-01, 0.83386800E+00, 0.51271900E+00, -.44816100E+01, 0.15570200E+00, -.34739000E+01, -.71855600E+00, 0.31983500E+01, -.20235600E+01, 0.53938200E+00, 0.10297700E+01, 0.86120200E+00, 0.32338700E+01, 0.77882300E+00, 0.69434000E+00, -.39849700E+00, 0.10735700E+00, -.45765000E+00, 0.10112200E+02, -.81367800E+00, -.13861600E+00, 0.31907800E+00, 0.26901500E+01, 0.93919300E+00, 0.12496700E+00, 0.53592400E+00, -.18161300E+01, 0.53225700E+02, -.10716000E+03, 0.44985900E+02, 0.49335800E+02, 0.12860000E+03, 0.68835000E+02, -.46248000E+02, -.83057400E+02, 0.76733300E+02, 0.85683500E+02, -.71595400E+02, 0.16435300E+03, 0.29614200E+02, -.69038400E+02, -.23435900E+03, 0.11365700E+03, 0.10003100E+03, -.62659100E+02, -.14871300E+03, -.18478600E+01, -.10844200E+03, 0.24722600E+01, -.82939000E+01, 0.58238300E+02, -.28877800E+01, -.31296500E+02, 0.13650200E+02, 0.16676900E+01, -.78305300E+01, -.14441100E+02, -.10607400E+02, -.13893700E+02, -.26648700E+02, -.11563000E+02, -.84304000E+01, -.51355600E+02, 0.92043700E+00, -.51740200E+02, -.19460600E+02, -.58172400E+02, 0.25061800E+01, -.37190500E+02, 0.84323200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.62910600E+01, 0.41839200E+01, 0.33388700E+01, -.89868700E+01, 0.10712600E+01, 0.89959700E+01, -.90293900E+01, -.29520200E+01, 0.30295100E+01, -.29951100E+01, -.27582100E+00, 0.36935000E+00, -.16419800E+01, -.16274300E+01, -.69285800E+00, 0.36934800E+01, 0.28410300E+01, 0.12619600E+00, 0.36785200E+01, -.41692700E+01, 0.12828900E+01, -.16381000E+01, 0.63125700E+00, -.83070800E+00, 0.44883300E+01, -.37403900E+01, -.18284200E+01, 0.29584800E+01, -.20908900E+01, -.15136700E+01, -.82102100E+00, -.36332000E+00, 0.71122000E+00, 0.55810300E+00, 0.38979500E+00, -.22843100E+00, -.36158600E+01, -.70933000E+01, -.58734500E-01, -.52319600E+01, -.50913500E+00, 0.36132100E+01, -.63592600E+01, 0.47886800E+01, -.13570800E+01, 0.21961700E+01, -.16291700E+00, 0.99383200E+00, -.45963800E+00, 0.27878400E+01, 0.22937300E+00, 0.19996000E+01, 0.22102600E+01, 0.12590300E+01, 0.71281100E-01, 0.79377800E+00, 0.22342300E+00, 0.20474900E+01, 0.49194400E+01, 0.44046200E+00, 0.13801900E+00, 0.31305800E-01, -.10503600E+00, -.81295700E-01, 0.44988400E+00, 0.61250800E+00, -.44262000E+00, 0.32240300E+01, -.16425500E+00, -.69922300E+01, -.84802100E+00, -.42225600E+00, -.67155700E+01, 0.12942100E+01, 0.19346100E+01, 0.55333900E-01, -.21603900E+01, 0.19149700E+01, -.53217400E+00, 0.89000400E+00, 0.61629000E-01, -.96605900E+00, 0.27797300E+00, 0.80163400E+00, 0.40098500E+00, 0.11606300E+01, -.19245100E+01, 0.49946400E+01, 0.14961200E+01, -.18381500E+01, -.22535800E+00, 0.60811000E-01, -.50579900E+00, 0.55361100E+00, 0.39365100E+00, -.46751100E+00, 0.17183600E+00, 0.26212000E+01, -.75311600E+00, -.24936600E+00, -.26542800E+00, -.22463700E+01, 0.34025200E+00, -.11036500E+00, -.19786400E+00, 0.10947000E+01, 0.25800600E+00, 0.65734800E+00, 0.16249400E+00, 0.54996400E-01, 0.46040700E+00, -.10037200E+01, -.92653200E+00, -.44334300E+00, -.18361600E+00, 0.48883100E+00, 0.63606800E+00, 0.90343500E-01, 0.30721800E-02, 0.10483800E+01, -.43105500E+00, -.75498800E+00, 0.77091500E+00, -.45755100E-01, 0.63843300E+00, -.22798100E+00, -.18878000E+00, -.19953800E-02, 0.27569400E+00, 0.50584500E+00, -.19795800E+00, 0.45401800E-01, 0.99198100E+00, 0.65358600E-01, 0.80859900E-01, -.12739000E+00, -.18522600E+00, -.16984300E+01, -.36744400E+00, 0.25157200E-01, 0.19546100E+00, 0.62973600E+00, -.16670200E+01, 0.14496900E+01, 0.79872200E-01, 0.35714600E+00, 0.50292100E-02, -.95951700E+00, -.72916600E+00, -.17114800E+01, -.75577500E+00, -.10074000E+00, 0.76851700E+00, -.10616100E+00, 0.25290700E+00, 0.35046300E+00, 0.26730400E+00, 0.32505800E+00, 0.34934900E+00, -.13064500E+00, -.43004800E+00, 0.73635200E+00, -.93505800E+00, -.26611400E-01, 0.14142500E+01, -.41422500E+00, 0.90882400E+00, 0.14068900E+00, -.10246400E+01, 0.41109200E+00, 0.76351500E-02, 0.22328400E+00, -.24503800E+00, 0.74313200E-01, -.31864700E+00, 0.23070100E+00, 0.62180700E+00, 0.42589400E-01, 0.49066600E+00, 0.73626600E+00, -.92462200E-01, 0.68389600E-01, 0.76818800E+00, -.12373800E+01, 0.10415500E+01, -.34276300E+00, -.12321000E+00, 0.12291100E+01, 0.38287700E+00, -.10061800E+03, 0.61714200E+02, 0.59689200E+02, -.80448100E+02, -.66673400E+02, 0.80328600E+02, 0.50947100E+02, 0.48671600E+01, -.68200200E+02, 0.46802300E+03, -.29364100E+03, -.21744800E+03, 0.41666300E+02, 0.20096300E+03, -.22697000E+03, -.90904100E+02, -.23957100E+03, 0.11355100E+03, 0.87927900E+01, 0.98281700E+02, 0.52366000E+01, 0.58481700E+01, -.38265000E+02, 0.93751100E+00, 0.12974400E+02, -.22121600E+01, 0.82656400E+00, 0.17221700E+01, 0.51697900E+01, 0.17013300E+01, 0.19232500E+01, 0.17093500E+02, -.16371300E+00, -.13423700E+01, 0.34770700E+02, -.21736600E+01, 0.20096700E+02, 0.62785900E+01, 0.38230200E+02, -.81679100E+00, 0.18946700E+02, -.77005600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.82096800E+01, -.65909000E+01, -.39733900E+01, 0.10796800E+02, -.24973500E+00, -.99040700E+01, 0.10671600E+02, 0.34929500E+01, -.36066000E+01, 0.38757900E+01, 0.14722400E+00, -.87687500E+00, 0.19871500E+01, 0.23104800E+01, -.11334800E+01, -.48759500E+01, -.40596800E+01, 0.13881900E+00, -.39843600E+01, 0.69307500E+01, -.12680300E+01, 0.29603800E+01, -.12963600E+01, 0.39828000E-01, -.49319800E+01, 0.49623300E+01, 0.21822300E+01, -.48873300E+01, 0.42571700E+01, 0.22084100E+01, 0.10794700E+01, 0.11000300E-01, -.12044200E+01, -.43611200E+00, 0.12058100E+01, 0.19480100E+00, 0.32212000E+01, 0.39946500E+01, -.57431800E+00, 0.87305300E+01, 0.51300100E+00, -.10546600E+01, 0.58812800E+01, -.67012000E+01, 0.12202000E+01, -.23517400E+01, -.12390000E+00, -.27625600E+00, 0.25168000E+01, -.48147400E+01, -.26254000E-01, -.12124300E+00, -.39291000E+01, -.11139200E+01, 0.14099800E+01, 0.66163900E+00, -.11468500E+00, -.75137600E+00, -.90216500E+00, -.49776400E+01, -.46692300E+00, 0.59761500E+00, 0.44951800E-01, -.40730000E+00, 0.26823000E+00, -.15748100E+01, 0.37561700E-01, -.27254500E+01, -.91860500E-01, 0.97682900E+00, 0.19602900E+01, 0.62319200E+00, 0.20418900E+01, -.23559600E+01, -.89168100E+00, -.23360300E+00, 0.86025400E+00, -.10130000E+01, 0.75478400E-01, -.22086100E+01, -.55109100E+00, 0.10245400E+01, -.28096300E+00, -.35274300E+00, -.44614600E-01, 0.58079300E+00, 0.39739800E+00, 0.50801900E+00, -.75926800E-01, 0.91550700E+00, 0.77912400E+00, -.47776700E+00, 0.13635900E+00, 0.14704400E+01, -.73020600E+00, -.18225800E+01, -.41618700E-01, -.21320100E+01, 0.31520200E+00, -.96183700E-01, -.12339000E+00, 0.22326100E+01, -.17269800E+01, 0.35460000E+00, 0.64450800E+00, -.10888300E+01, -.98868300E-01, -.50270000E+00, 0.14573300E+01, 0.24175400E+00, 0.17423300E+00, 0.76351000E+00, 0.13257500E+00, 0.40631600E+00, -.11292700E+00, 0.66070900E+00, -.18981600E+00, -.20165100E+01, -.21414300E+00, -.46717500E+00, -.45660400E+00, -.16004600E+01, 0.36814300E+00, 0.83768300E+00, 0.94521900E+00, -.86720900E+00, 0.11838200E+01, 0.29283300E-01, 0.70021100E+00, 0.15222600E+00, -.79323600E+00, 0.23286400E+00, 0.72291100E+00, -.45752200E+00, 0.13202300E+00, 0.57996300E+00, 0.13298800E-03, 0.20998800E+00, 0.58886100E-01, -.44544600E+00, 0.98261100E-01, 0.84011600E-01, -.70355100E+00, -.13968300E+01, 0.30341900E+00, -.69458500E-01, -.16182800E+00, 0.31080300E+00, -.16729900E+01, 0.17138800E+00, 0.97795800E-01, 0.18422100E+00, 0.12767500E+01, -.13346400E+00, -.57640400E+00, 0.60078300E-01, 0.36534600E+00, 0.48957700E+00, 0.71947700E-01, -.27528000E+00, 0.13123900E+00, -.91867100E+00, 0.18243000E+00, -.38912600E+00, -.40334300E+00, 0.10579900E+00, 0.31235600E+00, 0.20354500E+00, -.84227500E+00, 0.24872400E+00, -.57209000E-01, 0.11502200E-01, 0.35361800E+00, -.81372000E+00, 0.73633400E-01, -.28994900E+00, -.68776400E+00, -.13588900E+00, 0.20070900E+00, -.21336000E+01, 0.88453000E-01, 0.11399600E+00, 0.76200500E-01, -.87453500E-01, 0.96966000E+00, -.10931100E+00, -.21059400E+00, 0.10539700E+00, 0.22319300E+00, 0.51678600E+00, 0.13702600E+02, -.47966800E+01, 0.10958300E+02, 0.16400300E+01, -.67369600E+01, -.53548200E+01, 0.10312200E+02, 0.72640800E+01, -.62928900E+02, 0.14589700E+02, 0.27998900E+02, -.49183000E+01, -.45564500E+02, 0.37490900E+02, 0.13163800E+02, 0.32867400E+02, -.31631700E+02, 0.17313500E+01, -.20105300E+02, 0.62978300E+00, -.48126800E+00, 0.77118300E+01, 0.86181400E+00, -.40727000E+01, 0.17008800E+01, 0.10063100E+01, -.23030400E+01, -.47669300E+01, -.20591300E+01, -.71086100E+00, -.76002600E+01, -.14313900E+01, -.16770800E+01, -.96671300E+01, -.74467300E+00, -.37720900E+01, -.44146700E+01, -.77759700E+01, -.11849700E+01, -.30509700E+01, 0.15569800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.28663100E+01, 0.23014400E+01, 0.13004500E+01, -.66476000E+01, -.55599500E+00, 0.53997900E+01, -.67374700E+01, -.16818800E+01, 0.28502600E+01, -.25030300E+01, -.34485800E+00, 0.60581600E+00, -.15123100E+01, 0.61129700E-01, -.69637600E+00, 0.49426700E+01, 0.31381900E+01, -.10576600E+01, 0.36803700E+01, -.32282700E+01, 0.53838400E+00, -.18691100E+01, 0.12695000E+01, -.21197700E+00, 0.20049600E+01, -.52436500E+01, -.20594800E+01, 0.43777900E+01, -.24907200E-01, -.18587600E+01, -.14676800E+01, -.15244900E+00, 0.69609300E-01, -.93431300E-01, -.24155100E+01, 0.65965700E+00, 0.55426900E+00, -.63506900E+00, 0.56152900E+00, -.42142600E+01, -.20770000E+00, -.48333600E+00, -.12145000E+01, 0.26437800E+01, -.26910400E+00, 0.10372000E+01, 0.41118900E+00, 0.73690200E+00, -.64221400E+00, 0.15994100E+01, 0.43252300E+00, 0.12113300E+01, 0.58598700E+00, -.48056300E+00, -.43637800E+00, -.19480100E+00, -.18180300E-02, -.17740200E+01, 0.21796400E+01, -.85742100E-01, -.15905400E+00, -.14559600E+01, 0.11047400E-01, -.57607100E+00, 0.16568100E+00, 0.83682500E+00, -.30302600E+00, 0.99722200E-01, -.37022800E+00, 0.23888300E+01, -.55086900E+00, -.98181500E+00, -.13412400E+01, 0.14245200E+00, 0.28835100E+00, 0.10540100E-01, -.74735300E+00, -.30070300E+00, 0.99985300E+00, -.22492200E+01, -.49963200E+00, 0.99812700E+00, 0.10492100E-01, -.76396400E+00, -.26175700E+00, -.85587300E+00, -.19680000E+00, -.17534600E+01, -.42936600E+00, 0.32810800E-01, 0.41780100E+00, -.21584700E+00, -.35311700E-01, 0.13098800E+01, 0.67170000E-01, -.35703100E+00, 0.10009000E+00, -.26305500E+00, -.14086300E+00, -.48976900E+00, -.76351300E-01, -.45912600E+00, -.79537600E+00, 0.27955200E+00, 0.16287100E+00, -.17113300E+00, 0.21544400E+00, 0.49278100E-03, -.22530600E+00, -.99212100E-01, -.75103400E+00, -.70420900E+00, 0.23810800E-01, -.50864400E+00, 0.30825200E+00, 0.59908400E+00, 0.42735800E+00, -.64959400E+00, -.14627700E+00, 0.79587200E-01, 0.25649300E+00, 0.52216500E+00, 0.60021000E+00, -.35578700E+00, -.85357700E-01, -.30296900E-01, 0.24466900E+00, 0.99341200E-02, 0.23517900E+00, 0.24798100E+00, -.52743700E-01, 0.14441000E+00, 0.64900200E+00, -.43995800E+00, -.59091800E+00, 0.18287600E+00, 0.99177500E-01, -.37192100E+00, -.47934100E+00, 0.46070000E+00, 0.32902300E+00, 0.88773200E+00, -.69687900E+00, -.10507100E+01, -.18018400E+00, -.90409600E-01, 0.24458100E-01, 0.65467600E+00, -.10773400E+00, 0.34252700E+00, 0.20742500E+00, -.32177500E-01, 0.51091000E-02, 0.11697300E+00, 0.13373500E+00, -.16130300E+00, -.94333500E-01, -.76881300E-01, 0.11171400E-01, 0.12273300E+00, 0.23897400E+00, -.11018200E+00, 0.37622900E+00, -.33268400E-01, -.79341800E+00, 0.18078600E+00, 0.47844100E+00, -.27176200E+00, -.66785900E+00, -.60157100E-01, -.10070200E+00, -.45070400E+00, -.93122700E-01, -.46830500E+00, -.36389500E+00, 0.19167700E-01, 0.40812000E+00, -.33231500E-02, -.68975100E+00, -.11203000E+01, -.86768800E-02, 0.84105700E-02, 0.84407200E-01, -.46920900E+00, 0.17933700E+01, 0.39293200E+00, 0.48780600E-02, -.74394600E+00, 0.10350300E+00, -.57416500E+00, 0.29478300E+00, 0.72851100E+01, -.47621400E+02, -.25801600E+02, 0.30996600E+02, 0.31715400E+02, -.35768900E+02, -.35692300E+02, 0.46533600E+02, -.72013900E+02, -.11998900E+02, 0.25429500E+02, 0.11083000E+03, -.57694200E+02, -.46394300E+02, -.36739800E+01, 0.67772800E+02, 0.13629500E+01, 0.54323400E+02, -.13083100E+01, 0.49618000E+01, -.22503700E+02, -.53700200E+00, 0.13129600E+02, -.48374000E+01, 0.16087800E+01, 0.42568300E+01, 0.52195300E+01, 0.43333700E+01, 0.42835400E+01, 0.10346700E+02, 0.42080500E+01, 0.38080200E+01, 0.21315500E+02, -.23679300E+01, 0.18637900E+02, 0.71096800E+01, 0.22426000E+02, 0.27433900E+01, 0.15094400E+02, -.41602800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14236900E+02, 0.54037200E+01, 0.52214200E+01, -.22089600E+02, -.22374100E+01, 0.21062700E+02, -.23222100E+02, -.66211400E+01, 0.61247800E+01, -.76202300E+01, -.18116100E+01, 0.32588500E+00, -.42692800E+01, -.20747600E+01, -.56035900E+01, 0.84812400E+01, 0.67068800E+01, 0.16903400E+01, 0.14720500E+02, -.77343300E+01, 0.25843400E+01, -.39607300E+01, 0.45503600E+01, -.19419200E+01, 0.77736500E+01, -.15734300E+02, -.31431900E+01, 0.14278100E+02, 0.46379000E-01, -.59056900E+01, -.44008600E+01, -.10028200E+01, 0.10945600E+01, 0.54275500E+00, -.19957200E+01, 0.13671800E+01, -.10270200E+02, -.54069400E+01, 0.80535600E+00, -.15085700E+02, -.11029800E+01, 0.36943400E+01, -.14262000E+02, 0.11078900E+02, -.51529600E+01, 0.44247000E+01, 0.82297600E+00, 0.20069400E+01, -.32045000E+01, 0.47574100E+01, -.79795500E+00, -.39226700E+01, 0.67530900E+01, 0.43715600E+01, 0.44968100E+00, 0.79294100E+00, 0.49453700E+00, -.16006900E+01, 0.43425200E+01, 0.58570100E+01, -.42507300E+00, -.24521200E+01, -.10782300E-01, -.16762700E+01, 0.40996900E-02, 0.32824900E+01, -.21100400E+01, 0.25140600E+01, -.48563700E+00, -.73327700E+00, -.21420000E+01, -.46391500E+01, 0.63317200E+01, 0.33589100E+01, 0.28624900E+01, -.16789000E+01, -.23207500E+01, 0.41376600E+01, -.23831600E+00, -.35582800E+01, 0.50733800E+00, -.74570300E+00, 0.38667900E+00, -.70712500E+00, 0.21482000E-01, -.43602100E+01, -.21458700E+01, 0.78337000E+00, 0.91005600E+00, -.16090300E+01, 0.10799500E+01, -.61306700E+00, -.40989000E+00, -.28268700E+01, -.88377900E+00, 0.13855700E+01, -.53364100E+00, -.72591900E+00, -.35109700E+00, -.10806300E+01, -.24571800E+01, -.19574100E+01, 0.35343900E+01, -.88680200E+00, -.10699400E+01, 0.57479600E+00, -.98822800E-02, -.10743300E+01, -.45612400E+01, 0.86441800E-01, 0.18540400E+01, -.14074100E+01, -.20775200E+01, 0.96404600E+00, 0.13207300E+01, 0.50917500E+00, 0.77887000E+00, -.19183600E+01, 0.58134700E+00, 0.11476800E+01, -.14486000E+01, -.34283900E+00, 0.15482800E+01, -.18977000E+01, -.18399100E+01, -.44509500E+00, 0.15456500E-01, 0.15648000E+00, 0.71716500E+00, 0.43654400E-01, 0.62964900E+00, -.11862000E+00, -.21619700E+01, -.93615400E+00, -.55664000E+00, 0.45010000E+00, -.36725400E+00, 0.41043800E+00, 0.18765800E+01, 0.30412900E+00, -.26721100E+01, -.25792400E+01, -.77196400E+00, -.71840000E+00, -.12281300E+00, 0.11404200E+00, -.15722000E+00, -.11993100E+00, -.21879300E+01, -.90413900E+00, -.55436200E-01, 0.63515800E+00, -.26620700E+01, -.10264500E+01, 0.36613100E+00, 0.21640700E+00, 0.40789900E+00, 0.15003300E+01, -.30637000E+00, 0.70923800E+00, 0.10232800E+01, -.24126100E+01, 0.42307200E+00, 0.58915800E-02, -.12700200E+01, -.80864600E-01, 0.37598600E+00, 0.46927900E-01, -.15777500E+01, -.65676200E+00, -.20750200E-01, -.43439800E+00, 0.10059000E+00, -.13675400E+01, 0.96622300E+00, 0.36487800E+00, 0.17894500E+01, -.41755800E+00, -.18046000E+01, -.48645900E+01, -.98251000E+00, -.16076000E+00, 0.89727800E+00, 0.43732800E+01, -.21281200E+01, -.30233200E+00, -.73242100E-01, 0.42184600E+01, -.47913600E+00, -.56500100E+00, 0.75118100E+00, 0.18894900E+01, -.78882700E+02, -.10799600E+02, 0.30315100E+02, 0.28301800E+02, -.25573600E+02, -.26483900E+02, 0.70206400E+03, -.31119000E+03, -.37198800E+03, 0.98461200E+02, 0.19001600E+03, -.27509300E+03, -.24566300E+02, -.35971900E+03, 0.94677500E+02, 0.15535900E+01, 0.63862200E+02, 0.91618700E+01, 0.29382500E+01, -.38416700E+02, -.18776900E+02, 0.51987000E+01, 0.80755100E+00, -.22183900E+01, 0.64211800E+00, 0.15101700E+02, -.88402000E+00, -.13225900E+02, 0.22365100E+02, 0.11111800E+01, -.48575700E+01, 0.31237700E+02, -.60820300E+00, 0.54580900E+00, 0.14300800E+02, 0.38004900E+02, -.10071900E+01, -.83857800E+01, -.49645500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20054100E+01, 0.18607700E+01, 0.10291800E+01, -.48059600E+01, -.10070300E+01, 0.45827300E+01, -.43127900E+01, -.12155700E+01, 0.10464300E+01, -.22045800E+01, 0.17333300E+00, 0.75052200E+00, -.83805000E+00, 0.13440200E+01, -.10933300E+01, 0.48926700E+01, 0.23288700E+01, -.75076300E+00, 0.25092500E+01, -.35421100E+01, 0.90819800E-01, -.16502500E+01, 0.12789900E+01, 0.45625600E-01, 0.18514600E+01, -.19780800E+01, -.15445300E+01, 0.13709900E+01, -.30034300E+01, -.77180900E+00, -.71795700E-01, -.10220900E+01, -.26431600E+00, 0.33769500E+00, -.29075000E+00, 0.36150500E+00, -.86726800E+00, -.31409800E+01, 0.46965400E+00, -.97024500E+00, -.48195300E+00, 0.23950300E+00, 0.16422400E+00, 0.20282800E+01, 0.57462400E+00, 0.52113200E+00, 0.12765300E+00, 0.67784300E+00, -.21196900E+01, 0.22210900E+01, -.13306000E+00, -.35148700E+00, 0.19380700E+01, 0.79702600E-01, -.63263700E+00, -.89211200E+00, 0.18708300E+00, -.14027900E+00, -.15776700E+01, 0.36201500E+01, 0.39023600E+00, -.47678900E-01, 0.13796100E+00, 0.16931300E+00, 0.55944200E+00, 0.70294900E+00, 0.17872800E+00, 0.11111600E+01, -.19881600E+00, -.10854400E+01, -.93935900E+00, -.56594000E+00, -.53903800E+00, -.39982400E+00, 0.70201900E+00, -.14540300E+00, -.21343200E-01, 0.12267600E+01, -.15851400E+00, 0.34838200E+01, -.31134200E+00, -.91469300E+00, -.13037400E-01, 0.17770200E+00, 0.17293500E+00, 0.21842400E+00, 0.96648800E+00, -.12950700E+01, -.19827800E+00, -.46334500E+00, -.29838500E+00, 0.42272600E-01, -.57747000E-01, -.19817300E+00, 0.21870600E+00, 0.78775700E+00, -.82670500E-01, 0.75135800E+00, -.80769200E-01, -.22452500E-01, -.21777800E+00, 0.14535500E+00, 0.26681500E+00, -.37448000E+00, 0.16148900E+00, 0.86220000E-01, 0.71681200E+00, -.23946700E+00, -.11745500E+01, -.73212800E-01, 0.55287300E+00, -.15298300E+00, -.42958500E+00, -.47234600E+00, 0.14836800E+00, 0.20833100E+00, 0.21973400E+00, -.95526100E+00, -.12281900E-01, -.51271100E-01, -.46217700E-01, 0.17769000E+00, 0.10340200E+00, 0.33154400E+00, 0.10808500E-01, 0.70822200E-02, 0.42574000E+00, -.35301300E-03, 0.12456400E+00, 0.42466800E-01, 0.85628500E-01, 0.15383300E+00, -.86564700E+00, -.63089700E+00, -.30540200E+00, -.18325600E+00, -.18012600E+00, 0.10024100E+00, -.83522600E-01, -.37128700E+00, -.38235900E+00, 0.42196600E+00, -.54210800E+00, -.24607200E+00, -.32124800E+00, 0.69707600E-01, -.29220100E-01, -.39663500E+00, 0.10001800E+00, -.87792300E-02, 0.17850700E-01, -.15288100E+00, 0.53891700E+00, 0.24107800E+00, 0.23313100E+00, -.13400100E+00, 0.49238100E-01, 0.33785800E+00, 0.15852800E+00, -.32734100E+00, -.36209500E+00, 0.19971900E+00, -.61615200E+00, 0.13729100E+00, 0.35080700E+00, -.25528900E+00, 0.57818000E+00, 0.15155900E+00, -.53600000E+00, 0.18770700E+00, 0.23332800E+00, 0.37011600E-01, -.84462400E+00, 0.29811100E+00, -.47641300E+00, 0.32395400E+00, 0.57238400E+00, 0.29460700E+00, 0.17090900E+00, 0.18844600E+01, 0.58780000E-01, -.45952400E-01, -.13175300E+00, -.27807500E-01, 0.19351200E+00, 0.14822600E+00, -.47285200E-02, -.45661600E+00, -.66704300E-01, -.21428600E+00, -.15542600E-01, 0.59804900E-01, 0.68712000E-01, 0.13629000E+02, -.19386700E+01, 0.33714200E+01, 0.96453500E+01, 0.19466900E+01, -.15588800E+02, -.10539900E+01, 0.97159400E+01, 0.62851800E+01, 0.16238200E+02, 0.47898500E+01, 0.97412100E+00, -.14142500E+00, 0.78377700E+00, 0.80805300E+00, 0.70246900E+01, -.19322000E+01, 0.17608700E+01, -.26422400E+01, 0.16151100E+01, 0.25085000E+00, -.63624000E+00, 0.17050900E+01, 0.10820700E+01, 0.75499500E-01, 0.66524700E+00, 0.91550000E+00, -.17180400E+01, 0.36793500E+00, 0.10181900E+00, -.20438100E+01, -.19113600E+01, -.23349900E+01, 0.48019100E+00, 0.26504400E+01, 0.67344900E+00, -.23944500E+01, -.31731600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.38751200E+01, -.24321800E+01, -.16641700E+01, 0.37887900E+01, -.34222100E-01, -.44406000E+01, 0.33659200E+01, 0.14470300E+01, -.16777200E+01, 0.10614100E+01, 0.67993700E+00, 0.69048900E+00, 0.13235800E+01, 0.36759200E+01, -.13049400E+01, 0.36131100E+00, -.93049800E+00, 0.34855100E+00, -.20346300E+01, 0.31144800E+01, -.99868100E+00, 0.12515700E+01, 0.65491200E+00, 0.40307600E+00, -.25820900E+01, 0.40862800E+01, 0.33185900E+00, -.33219700E+01, -.59820100E+00, 0.14821700E+01, 0.12389200E+01, -.49338100E+00, -.46054400E+00, 0.89242000E-02, 0.11753300E+01, -.73667200E-02, 0.19595900E+01, 0.13420900E+01, 0.10399800E+00, 0.49781500E+01, 0.18664700E+00, -.61923300E+00, 0.37990000E+01, -.30136800E+01, 0.12236700E+01, -.14050100E+01, -.16647900E+00, -.45680800E-01, 0.92666900E+00, -.11212800E+01, -.14505900E+00, -.91536300E+00, -.10381700E+01, -.83811400E+00, 0.98294500E+00, -.49815200E+00, 0.17504800E-01, 0.29627600E+00, -.50523100E+00, -.18124100E+01, -.18160200E+00, 0.34210800E+00, 0.11929700E-02, 0.19964800E-01, 0.31869600E+00, -.72885100E+00, 0.32059400E+00, -.11155700E+01, 0.78031600E-01, -.14547100E+01, 0.80031700E+00, 0.22516800E+00, 0.13213400E+01, -.21115400E+01, -.60020000E+00, -.16073300E+00, 0.11132100E+01, -.36659500E+00, -.34643900E-01, -.63595700E-01, -.74557400E+00, 0.56881300E+00, -.31126100E+00, -.51610100E+00, 0.10130500E+00, 0.19515300E+00, 0.14429400E+01, 0.55027400E+00, -.60909400E+00, 0.63820300E+00, 0.36039000E+00, -.34709300E+00, 0.17386700E+00, 0.14578600E+01, -.19845500E+00, -.11469300E+01, 0.39328200E-01, -.13185400E+01, 0.18059700E+00, 0.96995800E+00, -.13708600E+00, 0.16907800E+01, -.96822700E+00, 0.43668500E+00, 0.37136600E+00, -.79038200E+00, 0.79747100E+00, -.76679300E+00, 0.22456100E+00, -.23597700E+00, 0.91505300E-01, 0.10888900E+00, 0.23363900E-01, 0.21955700E+00, 0.19548900E+00, 0.16555900E+00, -.15435800E+00, -.70996200E+00, -.93453400E-01, -.14019000E+00, -.62416400E-01, -.95920700E+00, 0.17630300E+00, 0.59267800E+00, 0.44045000E+00, -.63679000E+00, 0.49288200E-02, -.40875700E-02, 0.36496000E+00, 0.30090200E-01, 0.75370000E-01, 0.13299200E+00, 0.48455200E+00, -.28364300E-01, -.49175300E+00, 0.17766600E-01, 0.14961400E+00, 0.12296000E+00, -.17526000E+00, 0.15309700E+00, 0.39899200E+00, 0.10460000E+00, -.21455100E+00, -.27373200E+00, 0.54950800E-02, -.97656700E-01, -.21570700E-01, 0.44167900E+00, 0.20412800E+00, 0.26532900E+00, 0.49552300E-01, -.12589600E+00, 0.12552100E+01, -.28238900E-01, -.18930500E+00, -.47573100E-01, -.80897400E-01, 0.36865600E-01, -.27538000E-01, -.20637000E+00, -.54189700E-01, -.56440400E+00, 0.28513500E+00, -.12412400E+00, -.16067000E+00, 0.18971500E+00, 0.32015200E-01, -.15373300E-01, -.11987900E+00, 0.46783900E+00, -.82157600E-01, -.67321500E+00, 0.51922600E-01, 0.20623000E+00, 0.12304400E+00, -.12058500E-01, 0.18380400E+00, -.38825500E-01, 0.36552000E+00, -.27763600E+00, 0.67230800E-01, 0.65221900E-01, 0.15040800E-01, -.89618300E+00, 0.77316500E+00, 0.16761900E-01, -.50177700E-02, -.18500500E+00, 0.11733000E+00, 0.27544400E+00, -.11694800E+00, -.37863400E+00, 0.60538900E-01, -.28881300E+00, 0.56585300E+01, 0.47677600E+01, -.11056400E+02, -.39185400E+01, -.15344600E+03, 0.57667700E+02, 0.80248600E+02, -.56951200E+01, -.14063800E+02, 0.50477500E+02, -.36082200E+01, 0.77162000E+02, -.81842100E+00, 0.11643100E+00, -.39505600E+01, -.19919100E+01, 0.13967700E+01, 0.34836300E+01, 0.25857400E+01, 0.22881700E+01, -.83336600E+00, 0.14663700E+01, 0.39976200E+00, -.21022400E+01, 0.91357700E+00, 0.29677000E+01, -.28177600E+01, 0.14296500E+01, 0.17987500E+01, -.13636400E+01, -.14185300E+01, 0.61367800E+01, -.99738000E+00, -.35153400E+01, 0.86709400E+00, 0.59497400E+01, 0.29232900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.91072000E+01, -.62434600E+01, -.30648400E+01, 0.17062100E+02, 0.26888400E+01, -.15698200E+02, 0.17914700E+02, 0.52172400E+01, -.13334300E+01, 0.60356300E+01, 0.31541100E+00, -.86845800E+00, 0.24573600E+01, -.35744600E-01, 0.35580800E+01, -.62613100E+01, -.50938600E+01, 0.10108200E+01, -.94106800E+01, 0.50619800E+01, -.79740500E+00, 0.29869800E+01, -.38787200E+01, 0.12327200E+01, -.48532100E+01, 0.78482600E+01, 0.34886800E+01, -.69013300E+01, 0.22725700E+01, 0.32770800E+01, 0.16593400E+01, 0.28387600E+01, 0.18827200E+00, -.40281400E+00, 0.28793000E+01, -.62184900E+00, 0.44855100E+01, 0.56892200E+01, 0.63912200E+00, 0.57936600E+01, 0.12711600E+01, -.27585400E+01, 0.34493900E+01, -.58807800E+01, -.13556100E+00, -.10886200E+01, -.68374100E+00, -.25658900E+01, 0.32364600E+01, -.51630600E+01, 0.30398800E+00, 0.26305300E+01, -.21944700E+01, -.17599900E+01, 0.20491400E+01, 0.19019700E+01, -.27308700E+00, 0.28439600E+01, 0.11057400E+02, -.11233600E+02, -.16101000E+01, -.23319100E+00, -.14994700E+00, -.11998300E+01, -.74520000E-01, -.11599900E+01, 0.12997900E+01, -.38860600E-01, -.11460300E+00, -.45086100E+01, 0.12250100E+01, -.19304000E+01, -.63169600E+01, -.73612400E-01, 0.64899400E+00, 0.74439200E+00, 0.24180700E+00, 0.22666700E+01, -.46200400E+00, 0.15423600E+01, -.12927900E+01, 0.86894400E+00, 0.71717800E-01, 0.11888500E+00, 0.12425800E+00, 0.11147700E+01, -.10765700E+01, 0.66360500E+00, 0.21473800E+00, -.10023400E+01, -.35607000E-01, -.94036400E-01, -.20193200E+00, 0.18992900E+01, 0.93537300E+00, -.18341100E+01, 0.51062600E+00, -.69649000E+00, -.13366300E+00, -.21492800E+00, -.30664800E+00, -.31804900E+01, -.10779200E+00, 0.27041600E+00, -.76949800E+00, 0.26501300E+00, -.14734300E+01, -.66867800E+00, -.39830700E+00, -.19080700E-01, 0.93063500E+00, -.69680200E+00, -.26292700E+00, 0.31758600E+00, -.22093700E+00, 0.72852700E+00, 0.41835100E+00, -.58164400E+00, 0.18186200E+00, -.16104300E+00, 0.43435700E-01, -.97935300E+00, 0.88406400E+00, -.22048700E+00, -.31070100E+00, -.46155200E-01, -.62157500E+00, 0.35464800E-01, -.60610300E+00, -.25430300E+00, -.16529100E+00, 0.42512600E-01, 0.58661100E+00, 0.10201000E+01, -.11017700E+01, -.42706100E+00, 0.29717700E+00, 0.44848500E+00, -.13407000E+00, 0.11063500E+01, 0.11768200E+00, -.42705700E-01, 0.98695100E+00, 0.41135400E+00, -.19456400E+00, -.35732300E+00, 0.19407200E+00, -.46839900E+00, 0.11203400E+01, -.76275000E+00, -.14757900E+00, -.12840600E+00, 0.43268100E+00, -.57224800E+00, -.10029700E-01, -.23599400E+00, -.21459700E+00, 0.12497700E+01, -.75520400E-01, 0.59205100E+00, -.26663700E+00, -.15570700E+00, 0.51749100E+00, -.79972200E-01, 0.39002700E+00, 0.48113500E+00, -.10282900E+01, 0.12382100E+00, 0.54963300E+00, 0.74270800E+00, -.31171300E+00, -.21415900E+01, -.85253000E-01, 0.92819900E+00, 0.76055100E+00, -.14093300E-01, 0.13211900E+01, -.27058300E+00, 0.14978300E+01, -.18909000E+01, 0.46002500E+00, -.72961300E-02, 0.36153100E-01, -.69529300E+00, 0.12698400E+01, 0.67992100E+00, 0.14714000E+00, -.28863700E+00, -.33803600E+00, -.70799100E+00, 0.38174300E-01, 0.99548900E+00, -.36205200E+00, 0.23373800E+01, -.71686100E+00, -.30458800E+02, -.67269900E+02, 0.19834400E+02, -.12544200E+03, 0.13564200E+03, 0.51401200E+02, 0.19465800E+02, -.22527800E+02, 0.23323700E+02, -.42624700E+02, -.69138800E+02, 0.64759000E+02, -.72249700E+01, -.38934300E+01, 0.94015500E+01, -.13455800E+01, 0.15999800E+02, -.17424700E+02, 0.20189300E+01, 0.56280100E+01, -.16357600E+01, -.32438500E+01, -.11047600E+01, -.21482300E+01, -.11433000E+02, 0.10492200E+02, 0.15132000E+01, 0.10713300E+01, 0.16839400E+02, 0.94255600E+00, 0.49791100E+01, -.31330500E+01, -.16265100E+02, -.19284000E+01, 0.10374700E+01, -.94098700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.90633400E+01, 0.57971800E+01, 0.40839700E+01, -.13819200E+02, -.27752800E+01, 0.14050200E+02, -.17752700E+02, -.46442700E+01, 0.32423900E+01, -.61173700E+01, -.96155000E+00, 0.91832000E+00, -.31908300E+01, -.61472200E+01, -.76150900E+00, 0.41950100E+01, 0.52008200E+01, -.25577200E+01, 0.92954200E+01, -.62569300E+01, 0.39878100E+01, -.28581400E+01, 0.12466900E+01, -.22307100E+01, 0.63194500E+01, -.14298200E+02, -.30192700E+01, 0.11025400E+02, 0.77347200E+00, -.58393300E+01, -.24255100E+01, -.81148400E+00, -.13817700E+00, 0.39006700E+00, -.23726400E+01, 0.19774300E+01, -.81629300E+01, -.10182800E+02, -.97816800E+00, -.57542700E+01, -.14330500E+01, 0.56421100E+01, -.11310400E+02, 0.67595600E+01, -.32604800E+01, 0.33883600E+01, 0.65915600E+00, 0.20261700E+01, -.30645600E+01, 0.51997300E+01, -.58586900E+00, 0.26293600E+01, 0.38022900E+01, 0.18762600E+01, -.29125300E+01, -.54799500E+00, 0.65423300E-01, 0.14260000E+01, -.40701400E+01, 0.72101900E+01, 0.11237500E+00, -.23263600E+01, -.57057200E+00, 0.11159300E+01, 0.59780100E+00, 0.95660900E+00, -.15415600E+01, -.10507900E+00, -.27500300E+00, 0.35153500E+00, -.36644700E+00, 0.98494400E+00, -.60712100E+00, -.36788300E+00, 0.84125300E+00, -.83315600E+00, -.22120700E+01, -.10852700E+01, 0.47290400E+00, -.38292100E+01, 0.10609400E+01, 0.68486800E+00, -.10091200E+00, -.65013700E+00, 0.27598900E+00, -.69313600E+00, -.46841100E+00, 0.61248400E+01, 0.61289100E+00, -.18888500E+00, 0.16202800E+00, -.61559500E-02, -.36703500E+00, -.10950600E+01, -.29452000E-01, -.72687100E+00, 0.13374300E+00, 0.23103400E+01, -.25775700E+00, 0.12491500E+01, 0.38869000E+00, 0.45460300E+01, 0.30044900E+01, -.80269600E+00, 0.17090200E+01, -.13355900E+01, 0.91326600E+00, 0.11689900E+01, -.61895100E-01, 0.34958000E+00, 0.93927100E+00, 0.52064900E+00, 0.99347600E+00, -.19003100E+01, -.10804300E+01, 0.21375400E+01, 0.33499000E+00, -.46375300E+01, -.62292800E+00, -.41742200E+00, 0.20267900E+01, -.78858300E+00, -.17465900E+01, 0.32535600E+01, -.82300400E+00, 0.24137100E+00, 0.31277100E+01, -.15947300E+00, 0.10526300E+00, -.71681400E+00, -.83932500E+00, 0.68938600E+00, -.11054100E+01, -.66029700E+00, -.71036700E+00, -.33788000E+00, 0.18794400E+00, 0.21899900E+01, -.22350100E+01, 0.42081200E+00, 0.82370400E+00, 0.21410400E+01, -.85416100E+00, 0.14352900E+01, -.11496600E+01, -.16016900E+00, 0.24856100E+00, 0.13948400E+01, 0.23205900E+01, -.16286900E+00, -.94216600E-01, -.11053000E+01, 0.40660400E+01, 0.38271700E+00, 0.40672800E+00, -.52132400E+00, -.62441200E+00, 0.94464300E+00, -.33801700E+00, -.63472600E+00, 0.26749300E+00, -.10943900E+01, 0.19206400E+00, 0.70644900E-01, -.15270000E+01, -.14904900E+00, -.13457200E+01, 0.27219500E+00, 0.34955400E+00, 0.15961100E+00, -.24887000E+00, -.22116400E+01, -.11306000E+01, 0.14336700E+01, 0.44760300E+00, 0.32765300E+00, 0.11240100E+01, 0.24532100E+00, 0.50434400E+00, 0.46689600E+01, 0.53052100E+00, 0.30084600E+00, 0.52295600E-01, -.12824700E+01, -.27274600E+01, 0.42090700E+00, 0.87663500E+00, 0.45686900E+01, -.48014600E+00, 0.32893900E+00, -.56033000E+00, -.59247300E+00, -.26819700E-01, 0.19737800E+01, -.28586900E+01, 0.27250700E+00, -.10092000E+03, 0.80632300E+01, 0.33908400E+03, -.20275700E+03, -.16234300E+03, 0.10214900E+03, 0.61369400E+02, -.85825000E+02, 0.77688700E+02, 0.44139900E+02, -.52767200E+02, -.65594100E+01, -.17922900E+02, -.11767800E+02, 0.12143000E+02, -.24532400E+02, 0.16685700E+02, 0.15514400E+02, -.12588500E+02, 0.74671500E+01, 0.14562900E+02, 0.14504200E+02, 0.13501900E+02, 0.93134100E+01, 0.23891300E+01, 0.10489600E+02, 0.15558600E+02, 0.12710500E+02, -.84459600E+01, 0.38333500E+01, 0.16956300E+02, 0.24526400E+02, 0.92277200E+01, 0.45116400E+01, 0.25620200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.31602900E+01, -.25116100E+01, -.14463200E+01, 0.70925100E+01, 0.35685200E+00, -.58302600E+01, 0.63701400E+01, 0.17369100E+01, -.35256200E+01, 0.27339300E+01, 0.92553400E-01, -.71109100E+00, 0.14792600E+01, -.89283300E+00, 0.11479900E+01, -.57225300E+01, -.32924500E+01, 0.79978200E+00, -.31635700E+01, 0.40493800E+01, -.42086200E+00, 0.19139500E+01, -.11857900E+01, 0.29207600E+00, -.26340300E+01, 0.32194300E+01, 0.23839700E+01, -.27204800E+01, 0.17243400E+01, 0.15179800E+01, 0.50518000E+00, 0.46700300E+00, -.36872300E+00, -.20947500E+00, 0.14784900E+01, -.61506500E+00, -.62791900E+00, 0.57583600E+01, -.85345300E+00, 0.44360600E+01, 0.36664700E+00, -.35220500E+00, 0.20485600E+01, -.36839100E+01, -.52318000E-01, -.13287200E+01, -.10962600E+00, -.35970100E+00, 0.13305800E+01, -.23212600E+01, -.10325200E+00, -.11997400E+01, -.25196000E+01, -.59441700E+00, 0.14171300E+01, 0.86802000E-01, -.88951100E-01, 0.78612900E+00, -.19590100E+01, -.18096700E+01, 0.91944000E-02, 0.85503400E+00, 0.81846500E-01, -.18623100E-01, -.21072200E+00, -.12444800E+01, -.30936300E-01, -.13122900E+01, 0.81380100E-01, -.14351400E+01, 0.12767600E+01, 0.11400100E+01, 0.14161600E+01, -.15899600E+01, -.63839600E+00, -.25673300E+00, 0.26652500E+00, -.48119400E+00, -.33212100E+00, -.87334000E+00, 0.30817500E-01, -.37188600E-01, -.14467600E+00, 0.36737800E+00, 0.17366700E+00, 0.64026700E+00, -.11729300E+00, 0.26586500E+01, 0.56771100E+00, 0.24120400E+00, 0.17305800E+00, -.19356600E+00, 0.11459500E-01, -.49586400E+00, -.33002000E+00, -.62854300E+00, -.16140300E+00, -.50093700E+00, 0.12292200E+00, 0.60270100E+00, 0.26780600E+00, 0.36870000E+01, -.12209100E+01, 0.43474400E+00, 0.87514500E+00, -.37535000E+00, -.31595300E+00, 0.79737200E+00, 0.84948400E+00, 0.67586000E-01, 0.81993100E+00, 0.65857100E+00, -.60648900E+00, 0.24930500E+00, 0.20060600E-01, 0.53888900E+00, -.23224400E+00, -.13151500E+01, -.12166800E+00, -.73146100E+00, -.94395700E-01, -.79336100E+00, -.41037000E+00, 0.14507100E+01, 0.70579500E+00, -.41700900E+00, 0.74857500E+00, -.18701800E-02, 0.31302700E+00, -.23503300E+00, -.47539800E+00, 0.60624700E-01, -.10253800E+01, -.29118100E+00, 0.38027700E+00, 0.42163800E+00, -.15843700E+00, 0.97429200E+00, -.24275000E+00, -.19316200E+00, -.64408800E-01, 0.48763300E-01, -.52472900E+00, -.14709900E+00, -.12228000E+00, 0.14147400E+00, -.56483600E-01, 0.16809800E+00, -.57422100E+00, -.95817700E-01, 0.99079200E-01, 0.13171600E+00, -.45088600E+00, 0.19452800E+00, 0.22270900E+00, -.15771100E+00, 0.71717400E-01, 0.16978600E+00, 0.15096400E+00, 0.16812800E+00, 0.37108300E-01, -.26540400E+00, 0.16694000E+00, 0.20388900E-01, -.59089400E+00, -.12216600E-01, 0.15845800E+00, 0.15909600E+00, -.39992800E+00, -.14727100E+00, 0.27112000E+00, 0.62946700E+00, -.51785800E+00, -.10758700E+00, -.50499800E+00, 0.17087300E+00, 0.10759500E+00, 0.26387000E+00, -.35094600E-01, 0.26000400E+01, 0.42296200E-01, 0.18195500E-01, -.12294900E+00, 0.59701200E+00, -.22990900E+00, 0.10355200E-01, 0.64865600E-02, -.27981100E+00, 0.27436600E-01, 0.75387200E-01, -.23829600E-01, -.36986000E+00, -.12836200E-01, -.41664300E-01, -.25652000E-01, -.69872300E-01, -.37588000E-01, 0.63857600E+01, -.15003400E+02, 0.10272000E+01, 0.83624100E+01, 0.17395700E+02, 0.38718800E+02, -.32991300E+01, -.10680500E+02, -.58076400E+01, 0.15613100E+02, -.13174000E+01, 0.21505200E+02, -.23009700E+01, 0.49426400E+01, -.26975600E+01, -.27764400E+01, 0.41557300E+01, -.28656200E+01, 0.49364400E+01, 0.36163700E+01, 0.42431300E+00, 0.31058400E+01, 0.96754400E+00, 0.58279200E-01, 0.27029300E+01, 0.25703000E+01, 0.23574400E+01, -.49631900E+01, 0.15723700E+01, 0.59609000E+00, 0.26998100E+01, 0.27248000E+01, 0.11872300E+01, -.14878700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.94214700E+01, 0.87244100E+01, 0.50202900E+01, -.11334400E+02, 0.76417800E+00, 0.10192100E+02, -.13459900E+02, -.41809400E+01, 0.42443300E+01, -.43513300E+01, 0.38267700E+00, 0.17323000E+01, -.14394400E+01, -.18304800E+01, 0.80475800E+00, 0.38894300E+01, 0.42708200E+01, 0.18732800E+01, 0.46497400E+01, -.35355400E+01, 0.12052500E+01, -.22578400E+01, 0.21650800E+01, 0.21578400E+00, 0.44120300E+01, -.57617800E+01, -.20927900E+01, 0.68685200E+01, -.12637000E+01, -.26748800E+01, -.23550200E+01, -.48482200E+00, 0.10501300E+01, 0.44859800E-01, -.28101500E+01, 0.69155700E+00, -.38730500E+01, -.37152100E+01, 0.54221200E+00, -.12370200E+02, -.75137100E+00, 0.17131100E+01, -.87432000E+01, 0.69540200E+01, -.29672300E+01, 0.30740900E+01, 0.26021800E+00, 0.46237700E+00, -.32716200E+01, 0.35477200E+01, 0.26745400E-01, 0.76032400E+00, 0.55433900E+01, 0.28107300E+01, -.23061300E+01, -.98117200E+00, -.21808300E+00, 0.20343800E+01, 0.20873500E+01, 0.51185600E+01, 0.12627700E+00, -.11109100E+01, -.65721500E+00, 0.12994800E+01, -.68671300E+00, 0.22238400E+01, 0.12662400E+01, 0.12694500E+01, 0.81557400E+00, -.29576600E+00, -.17300900E+01, -.92035100E+00, 0.11163900E+01, 0.39815600E+01, 0.12795800E+01, -.20180800E+00, -.28384400E+00, 0.45535500E+00, -.28880000E+00, -.11677300E+01, 0.97237600E+00, -.19995800E+00, 0.36446500E+00, -.30398600E+00, -.33956100E-01, -.29511500E+01, -.23239100E+00, -.61991100E+00, -.14624300E+00, 0.72299900E-01, 0.16500400E+00, 0.22266100E+00, -.51727000E-02, -.11396900E+01, 0.19444800E+00, 0.14059200E+01, -.20890800E+00, -.24765100E+00, 0.31914100E-01, -.10126400E+01, 0.12148300E+01, 0.14609400E+01, 0.17871300E+01, -.60187100E+00, -.35990900E+00, 0.98647500E+00, -.67723400E-01, 0.20309800E+00, -.91786400E+00, -.42178900E+00, -.64096900E+00, 0.50832800E+00, -.27137100E+00, -.13359000E+00, -.87581600E-01, -.24591100E+00, 0.27557400E+00, 0.38834800E+01, 0.46414300E+00, 0.15033000E+01, -.47573300E+00, 0.23883000E+01, 0.48589300E+00, -.42121400E+01, -.20938400E+01, 0.15212300E+01, -.17881700E+01, 0.73745500E-02, -.96994900E+00, 0.20255000E+00, 0.17488200E+01, -.17164500E+00, -.38042300E+00, 0.97006000E+00, 0.55511800E+00, 0.51667700E+00, -.12312800E+00, 0.15625200E+01, -.10254300E+00, -.40210000E+00, -.65762100E-01, -.57661900E+00, -.18829400E+00, 0.81739100E+00, -.41996400E-01, 0.77669200E+00, -.64103100E-01, 0.10751300E+01, 0.10254300E+00, 0.14867300E-01, 0.18286000E+00, 0.18790300E+00, -.37103300E+01, -.29010000E+00, 0.74177900E+00, -.15156600E+00, -.29269500E+00, -.36102800E+00, -.28010300E+00, 0.16364800E+01, 0.83611800E+00, -.85245000E+00, 0.15192400E+01, -.21022100E+00, -.10143500E+01, 0.15792100E+00, 0.72377700E+00, -.80074100E+00, 0.13759500E+01, -.93350100E-01, 0.35312800E+00, 0.68836500E+00, -.11738100E-01, 0.83659300E+00, -.65314900E+00, 0.27921700E+00, 0.15878400E+00, 0.22203600E+00, -.46186100E+00, 0.44304400E+01, -.30739900E+00, -.12266900E+00, -.28736900E+00, -.11835900E+00, 0.11205700E+00, -.12772400E+00, 0.20144400E+00, -.30645200E+01, 0.39471000E+00, -.13966600E+00, 0.90542900E+00, 0.41372600E+00, -.58025900E+00, -.92619100E-01, -.12463000E-01, 0.13529400E+00, -.39065500E+00, 0.10730600E+01, 0.25250900E+03, 0.17321300E+02, -.13443800E+03, 0.59689700E+01, 0.13580000E+02, -.67211700E+02, 0.57314800E+02, -.81846600E+02, -.14052400E+02, -.93849000E+01, -.22297000E+02, -.40831200E+01, -.18438300E+01, -.22124600E+01, 0.55425900E+01, -.23874800E+00, -.42158700E+01, -.33582600E+01, 0.49541700E+01, 0.97459800E+01, 0.47946700E+01, 0.30370600E+01, 0.90197200E+01, 0.31318300E+01, 0.36322400E+01, 0.20640000E+01, 0.29462500E+01, -.36252400E+01, 0.93440500E+01, 0.23812000E+01, 0.32764200E+01, -.26085500E+01, 0.22721200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.88049100E+01, -.63084100E+01, -.27068000E+01, 0.19649600E+02, 0.40789200E+01, -.16083300E+02, 0.21958000E+02, 0.55255300E+01, -.27073100E+01, 0.72681500E+01, 0.56868000E+00, -.77791800E+00, 0.34214200E+01, -.26439000E+00, 0.48733400E+01, -.12636200E+02, -.77666700E+01, 0.51871300E+00, -.11832700E+02, 0.35986900E+01, -.19179600E+01, 0.29680100E+01, -.56977100E+01, 0.13849800E+01, -.70748100E+01, 0.15936000E+02, 0.45011900E+01, -.11062500E+02, 0.26469300E+01, 0.67975400E+01, 0.66429500E+00, 0.10422600E+01, -.13825600E+01, -.67586900E+00, 0.43062700E+01, -.12356900E+01, 0.19910800E+01, 0.15782200E+02, -.13463600E+01, 0.67119900E+01, 0.82992500E+00, -.27524400E+01, 0.68935500E+01, -.91768200E+01, 0.12078000E+01, -.24812200E+01, -.69064900E+00, -.17816700E+01, 0.31546800E+01, -.59842200E+01, -.51035000E-01, 0.13990200E+01, -.41922000E+01, -.11853000E+01, 0.13363000E+01, 0.10090300E+01, 0.22252800E+00, 0.63301700E+00, 0.48122400E+01, -.50494500E+01, 0.58431300E+00, 0.21842700E+01, 0.33554600E+00, 0.39155600E+00, -.94795200E+00, -.22483300E+01, 0.14047400E+01, 0.42427400E+01, 0.20163900E+00, -.12627300E+02, 0.20123200E+00, 0.15511800E+01, -.99513900E+01, -.10889900E+01, -.50104400E-01, 0.48004100E+00, -.22444300E+01, -.43886700E+00, 0.66837700E+00, -.60848400E+01, -.34235000E+00, 0.20935300E+01, 0.30293300E+00, 0.18340900E+01, 0.21846100E+00, 0.42756700E+00, -.50895500E+01, 0.98806300E+01, 0.33646000E+01, -.40655100E+01, -.43197800E+00, -.54254200E+00, -.69956400E+00, -.92833900E+00, -.11458100E+00, 0.25056200E+00, -.49185100E+00, -.31015900E+00, -.82879600E-01, -.14211000E+01, -.77480600E+00, 0.56444700E+01, 0.19186700E+01, -.90393900E+00, 0.10795400E+01, 0.72500700E+00, -.13276900E+01, 0.95360500E+00, 0.41381100E+01, 0.89234600E+00, 0.10554600E+01, -.17137900E+00, -.20050700E+01, -.54810700E+00, -.12384800E+01, 0.31375900E+01, 0.10811600E+01, -.29762100E+01, -.31768400E+00, 0.49764100E+00, -.48375400E+00, -.17988600E+01, 0.81904700E+00, 0.45896900E+00, 0.64432600E-01, -.11326600E+00, 0.44558800E+00, -.20132600E-01, -.90624300E+00, -.99400400E+00, -.96868900E-01, -.16639600E+00, -.14114600E+01, -.67685700E+00, 0.11859900E+01, 0.39636900E+00, -.32655700E+00, -.20870600E+00, -.84310000E-01, 0.66070000E+00, -.39223900E+00, 0.63539800E+00, -.11224500E+01, -.66604700E+00, -.93606000E+00, 0.12854700E+00, -.55950700E-01, -.65220700E+00, -.31753800E-01, 0.32107700E+00, 0.23361300E+00, -.40236800E+00, 0.13434700E+01, -.37671100E+00, 0.11824800E+01, -.47667800E+00, 0.23376100E-01, 0.26543800E+01, 0.79773800E+00, 0.90680000E+00, -.11941900E+01, 0.36517600E+01, -.15036900E+01, 0.18936800E+00, 0.13135000E+01, -.57190900E+00, 0.18967300E+01, -.21205000E+00, -.25558200E+00, 0.15706100E+00, 0.34031000E+00, -.10969200E+01, -.17012200E+01, -.47454200E+00, -.14131300E+01, 0.12139800E+00, 0.13843100E+01, 0.11365000E+00, 0.23914800E+01, -.14632700E+01, 0.11866800E+01, -.47521300E-02, -.63037600E+00, -.14128500E+01, 0.18476500E+00, 0.76783000E-01, -.42309100E+00, -.34432600E+01, 0.15077900E+00, -.51308400E+00, 0.27031100E+00, 0.62435400E-01, 0.15540300E-01, -.23820000E+01, 0.14250600E+00, -.76444000E+00, -.12637200E+00, 0.11917600E+01, -.11210900E+01, 0.16822100E+03, 0.36186300E+01, 0.18889200E+02, 0.29930600E+02, -.42858600E+01, -.20543400E+01, -.13284400E+03, 0.37629900E+02, -.71926200E+01, -.24943900E+01, 0.44550000E+00, -.29149300E+01, 0.19776300E+02, 0.98350600E+01, -.27463100E+01, 0.45730000E+01, -.32251300E+01, -.15272200E+01, -.27302800E+01, 0.17795000E+00, -.24667000E+01, 0.53624800E+01, 0.10536800E+01, 0.14479500E+01, 0.17223700E+01, 0.20552400E+01, -.13283000E+02, -.34051500E+01, -.19594300E+02, 0.82696400E-01, -.11481900E+02, 0.55239500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.50456400E+01, 0.29155600E+01, 0.19173900E+01, -.46785100E+01, -.11966900E+01, 0.61191900E+01, -.46842300E+01, -.19485600E+01, 0.35220000E+01, -.26185100E+01, -.63115300E+00, -.60021700E+00, -.15746500E+01, -.33207200E+01, -.66803600E+00, 0.87978300E+00, 0.10029000E+01, -.14709600E+01, 0.31176900E+01, -.88706400E+01, 0.41587800E+00, -.32585000E+01, 0.24673300E+00, 0.17858400E+00, 0.19747900E+01, -.37506600E+01, -.21346400E+01, 0.44960500E+01, -.43719900E+00, -.20380000E+01, -.14524300E+01, 0.14572200E+00, 0.95000800E+00, -.28559700E+00, -.20479000E+01, 0.85176100E+00, 0.12492400E+01, -.57048900E+00, 0.11173000E+01, -.74561300E+01, -.14695300E+00, -.90010500E+00, -.15888300E+01, 0.33328100E+01, -.45678600E+00, 0.12227700E+01, 0.43619700E+00, 0.34565000E+00, 0.59930500E+00, 0.17038100E+01, 0.39258000E+00, 0.18148400E+01, -.13560000E-01, 0.31917700E+00, -.14860900E+01, -.25387800E+00, 0.69960600E-01, -.23311900E+01, -.47165700E+01, 0.31005200E+01, 0.77920000E+00, -.64476100E-01, 0.42513700E-02, 0.96538000E+00, -.25844700E+00, 0.73687000E+00, -.65233000E+00, 0.17498100E+01, 0.29634200E-01, 0.16894900E+01, -.10020300E+01, 0.66315900E+00, -.19765300E+00, 0.48913500E+00, -.37518100E+00, 0.10531500E+00, -.39037400E+00, -.15869300E+01, 0.44955200E+00, -.23664600E+01, 0.62598800E+00, 0.21696400E+00, 0.14205000E+00, -.78491200E-03, -.44067000E-01, -.11302900E+00, -.12082800E+01, 0.32311000E+01, 0.78032700E+00, -.39417900E+00, 0.40410600E+00, -.16379500E+00, 0.64901700E-01, 0.72245900E+00, -.51580900E-01, 0.70934400E+00, -.16892200E+00, 0.57771300E+00, -.35229500E+00, 0.97466700E+00, -.87773100E+00, 0.33997200E+00, -.83270400E-01, 0.75771300E+00, -.27751200E+00, -.11644900E-01, 0.29951100E+00, 0.87160600E+00, 0.17322400E+01, 0.55588600E+00, -.65440700E+00, -.35912700E+00, -.95906200E+00, -.44003600E+00, -.42920800E-01, 0.72843600E+00, 0.30003500E+00, 0.19781900E+01, -.58703700E-01, 0.13904200E+01, 0.59712000E+00, -.43853500E+00, 0.81523100E+00, -.31347500E+00, 0.93900000E+00, -.42128400E+00, -.11597500E+00, 0.42054300E-01, -.27616200E+00, 0.33810700E+00, 0.62163800E+00, -.47169200E+00, -.81206700E+00, -.21498300E+00, -.49940900E+00, 0.55294200E+00, -.14791100E+00, -.34918800E+00, 0.57839200E+00, 0.42281800E+00, 0.49421900E+00, 0.27213600E+00, -.90589000E-01, -.12244400E+01, 0.30781900E-01, 0.52940200E-01, -.23665500E-01, -.49838000E-01, 0.12451600E+00, -.23335800E+00, 0.24340300E+00, 0.16831700E+00, -.13906300E+01, -.55005700E+00, 0.84054900E+00, 0.23477100E+00, 0.41034100E+00, 0.15618600E+01, 0.23309100E+00, 0.26854200E+00, 0.27227100E-01, 0.86977500E+00, -.11512200E+01, 0.92312600E-03, 0.66289500E+00, -.48180600E+00, 0.19542700E+01, -.19871000E+00, -.96868200E+00, -.32395200E+00, -.15947000E+00, 0.13138700E+01, -.16155000E-01, -.11843300E+01, -.75337900E+00, -.13792400E+00, -.97619800E+00, 0.36230000E-01, -.30119900E+00, -.11206000E+01, -.17719100E+00, -.76420000E-01, 0.10429400E+00, 0.13069500E+00, -.34809400E+00, -.44833800E+00, 0.25082200E+00, -.43458300E+00, 0.59791200E-01, -.48043300E-01, 0.12389800E+00, -.93825200E-01, 0.14952700E+00, -.65480600E+00, 0.16476000E+00, -.27090300E+00, -.18790800E+00, 0.43127800E-01, 0.14826900E+00, 0.71694700E-01, 0.82015300E+01, 0.11835300E+02, 0.41336200E+01, -.86625500E+01, -.25901900E+02, -.38495800E+02, 0.45372200E+01, -.24118600E+01, 0.14059300E+02, -.35741100E+01, 0.53348400E+01, -.36310700E+01, 0.29410000E+01, 0.50863700E+01, -.38601300E+01, 0.48631100E+01, 0.51810100E+01, 0.18700200E+01, 0.43292500E+01, 0.39791500E+01, 0.14618700E+01, 0.23494700E+01, 0.45986100E+01, 0.63925300E+01, -.49175600E+01, 0.48484900E+01, 0.16734800E+01, 0.36840200E+01, 0.23638000E+01, 0.49575600E+01, -.12845500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.42595900E+01, 0.34919400E+01, 0.18119100E+01, -.93081200E+01, -.10172300E+01, 0.76765200E+01, -.90293800E+01, -.23717000E+01, 0.39421200E+01, -.34899800E+01, -.49843400E+00, 0.39063600E+00, -.19788200E+01, -.18667300E+00, -.14732700E+01, 0.69039400E+01, 0.39153400E+01, -.33209400E+00, 0.46603000E+01, -.57744900E+01, 0.54417300E+00, -.28487100E+01, 0.20589400E+01, 0.31081700E+00, 0.28206500E+01, -.77127900E+01, -.23727400E+01, 0.67702300E+01, 0.81437000E-01, -.29645100E+01, -.17136400E+01, -.75568000E+00, 0.47306700E+00, 0.19165500E+00, -.28300500E+01, 0.71502200E+00, -.10804600E+01, -.29819400E+01, 0.15839900E+01, -.36854900E+01, -.13300900E+00, 0.22842400E-01, -.21610400E+01, 0.40209600E+01, -.42657800E+00, 0.17825800E+01, 0.39336200E+00, 0.48894000E+00, -.13117000E+01, 0.21380900E+01, 0.42340100E+00, 0.13402100E+01, 0.17350500E+01, -.42550000E+00, -.60926700E-01, -.78472300E-01, -.37974400E-01, -.94923300E+00, 0.35030600E+01, -.33253500E+00, -.24393400E+00, -.13270900E+01, -.16148100E+00, -.43912000E+00, 0.44136100E+00, 0.93369500E+00, -.34853500E+00, 0.42592900E+00, -.38186100E+00, 0.16655900E+01, -.45595700E+00, -.15544900E+01, -.21050500E+01, -.12271900E+00, 0.69187800E+00, -.15020400E+00, -.84719400E+00, 0.10640800E+00, 0.12446800E+01, -.11880700E+01, -.69313900E+00, 0.86926100E+00, 0.11592200E-02, -.68086300E+00, -.22771700E+00, -.10143700E+01, -.22631700E+00, 0.42254800E+00, -.23571300E+00, -.27057600E+00, 0.32319000E+00, -.20994200E+00, -.35135000E-01, 0.22931800E+01, -.38844600E+00, -.17244800E+01, 0.19358500E+00, 0.31869800E+00, -.31534900E+00, -.54403900E+00, 0.28284400E+00, -.10235400E+01, -.14859300E+01, 0.38560300E+00, 0.33420500E-01, -.15847500E+00, 0.30764100E+00, -.45764100E+00, 0.24772800E+00, -.24308400E-01, -.65549900E+00, -.79306700E+00, 0.37657400E+00, -.52640600E+00, -.18065300E+00, 0.83312400E+00, 0.64951700E+00, -.73985700E+00, -.56709400E-01, 0.32993500E+00, 0.89888500E-01, 0.11046700E+00, 0.40174900E+00, -.33709000E+00, -.57853700E+00, -.29230400E-01, 0.49168600E-01, 0.15132000E-01, -.16809600E+00, -.66080200E-01, 0.39469200E+00, 0.11837100E+00, -.74548700E+00, -.71645400E+00, -.99781300E-01, 0.11259900E-03, -.79368200E-01, 0.23260400E+00, 0.23869800E+00, 0.10801500E+00, -.61327100E+00, 0.10286700E+00, -.16611600E+00, -.51547500E-01, 0.19751000E-01, -.91664600E-01, 0.43033900E-01, 0.39489100E+00, -.28608000E+00, -.86652000E+00, -.11151100E+00, 0.98145300E-01, -.10327100E+01, -.29740800E+00, 0.23378100E+00, -.16157800E+00, 0.19336400E-01, 0.43732700E+00, -.33041800E-01, -.39989200E+00, 0.55135200E-01, 0.23805500E+00, -.44890800E+00, 0.14713800E-01, -.27919500E-01, -.35548900E+00, -.62823900E+00, 0.15187300E+00, -.31899400E+00, -.24560900E+00, 0.10883700E+00, 0.61539500E+00, -.21639900E+00, -.24212300E+00, 0.23089600E+00, 0.44758500E-01, 0.49029900E-01, 0.76373000E-01, -.20400800E+00, 0.41736300E+00, 0.41498100E-01, 0.64651600E-01, 0.93176700E-01, 0.12048800E+01, 0.17071400E+00, -.34472000E-01, 0.22701500E-01, -.46582600E+00, 0.13697200E+00, -.25107700E+00, 0.31888300E+00, 0.22419300E+00, 0.12790300E+00, -.11122400E+01, 0.38095300E+00, -.29529800E+00, -.23155500E+00, 0.13389200E+00, 0.58595600E-01, 0.15013800E-01, 0.60905800E+00, 0.39453900E+02, 0.70538000E+02, -.95027000E+01, -.29588500E+01, -.12861000E+02, 0.30365200E+02, -.24069100E+01, 0.28663200E+02, -.10208800E+01, 0.60150400E+01, -.57257300E+01, -.62450100E+01, 0.62227800E+01, -.29514500E+01, 0.57344600E+01, 0.37029200E+01, 0.80485100E+00, 0.41355700E+01, -.19203100E+01, 0.51155600E+00, 0.36040700E+01, 0.28810800E+01, 0.49628500E+01, -.62394200E+01, -.11356900E+00, 0.96386700E+00, 0.55148900E+01, 0.33252300E+01, 0.56509300E-01, -.18948300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10273600E+02, 0.64763400E+01, 0.56371000E+01, -.16297400E+02, 0.89753100E+00, 0.17324900E+02, -.18613200E+02, -.55497400E+01, 0.58804700E+01, -.62172500E+01, 0.23864500E+00, 0.19810000E+01, -.20130700E+01, -.18032700E+01, -.35367600E+01, 0.76751800E+01, 0.50164900E+01, -.17647500E+01, 0.97406000E+01, -.51281900E+01, 0.23096400E+01, -.26693500E+01, 0.30668200E+01, -.18232500E+01, 0.56107100E+01, -.94865400E+01, -.41936800E+01, 0.75258100E+01, -.40710600E+01, -.38927200E+01, -.13894400E+01, -.34925700E-01, 0.21213500E+00, 0.22884700E+00, -.20718900E+01, 0.93833100E+00, -.30558700E+01, -.62186300E+01, -.18509700E+00, -.73700500E+01, -.78556900E+00, 0.47958400E+01, -.69921400E+01, 0.56056000E+01, -.17815800E+01, 0.27373800E+01, 0.38700100E+00, 0.29768200E+01, -.44553700E+00, 0.31606900E+01, 0.76321300E-01, 0.25521100E+01, 0.20621200E+01, 0.25072600E+01, -.95470900E+00, -.95804700E+00, 0.57426400E+00, 0.25573100E+01, 0.17490500E+01, 0.29134700E+01, 0.27277600E+00, -.10279800E+01, -.49586200E+00, 0.71898300E+00, 0.25399300E+00, 0.33435600E+00, -.16305900E+01, 0.32757500E+01, -.63056200E-01, -.83916600E+01, -.63455200E+00, 0.13387100E+01, -.65455500E+01, -.13514100E+01, 0.10690800E+01, 0.21408400E+00, -.18962600E+01, 0.20820400E-01, -.12446000E+00, -.31749900E+01, 0.20473300E+00, 0.49179600E+00, 0.15954600E+00, -.30788900E+00, 0.22761500E+00, 0.10843500E+01, -.14262400E+01, 0.83279600E+01, 0.12678300E+01, -.14479600E+01, 0.89259200E+00, -.51572600E+00, -.22524200E+00, 0.21892300E+01, 0.22452200E+00, -.13267500E+00, -.32743100E+00, 0.18527500E+01, -.85845500E+00, 0.22521700E+01, -.14601800E+01, 0.16444900E+01, -.84926200E+00, 0.13557100E+01, -.20081800E+00, -.89935900E-01, 0.17925000E+01, 0.25463500E+00, 0.15630600E+01, 0.42179300E+00, 0.23946500E+00, -.12435100E+01, -.21237800E+01, -.14489300E+01, 0.84357600E-02, 0.28097400E+01, 0.15083900E+01, 0.19604100E+01, -.18117200E+00, 0.22104300E+01, 0.11806100E+01, -.57257800E-01, 0.33985600E+00, 0.44215700E+00, 0.10768000E+01, -.58031400E+00, 0.71069600E+00, 0.31726200E-01, 0.50227100E+00, 0.86631900E+00, 0.47678200E+00, -.11612500E+00, -.84355600E+00, -.56789400E+00, -.14020300E+01, 0.29958700E+00, -.20359200E+00, -.25359000E+00, 0.78946000E-01, 0.60755900E+00, 0.46265500E+00, 0.70307300E+00, -.77045400E+00, -.68796600E+00, -.13629200E+00, 0.20382600E+00, -.14944400E+00, 0.49724000E-01, 0.47017600E+00, -.96768500E+00, 0.13953400E+00, -.19073300E+00, 0.42030900E+00, -.13455300E+00, 0.78820900E+00, 0.17684600E+00, 0.48053800E+00, 0.14677600E+01, 0.27552300E+00, -.77835300E+00, -.37487700E+00, 0.43240000E+00, -.14117100E+01, -.25285200E+00, 0.25981700E-01, -.15373600E+01, 0.27251900E+01, -.80665800E-01, -.26831800E+01, -.35220600E+00, -.37048500E+00, 0.10013400E+01, 0.33671300E+00, -.21076900E+01, -.54733200E+00, -.48029100E+00, -.17351600E+01, -.24694000E+00, -.29810800E-01, -.55457900E+01, 0.13442800E-01, -.98531700E-01, -.86111800E+00, 0.18409900E+00, -.56252800E+00, -.66614600E+00, -.18465200E+00, -.40689700E+01, 0.13287700E+00, -.33262700E+00, -.18139400E+00, -.42173300E+00, -.19301500E+00, -.19826400E+01, 0.26289000E+00, -.84739800E+00, -.48290400E+00, 0.84149000E+00, -.58215800E+00, 0.69322700E+00, -.21764400E+01, 0.10738600E+01, -.16328000E+03, 0.27172100E+02, -.89198700E+01, -.17419700E+01, -.84358500E+02, -.53074500E+01, -.58810600E+02, -.81541400E+01, 0.72797500E+01, 0.13251300E+00, 0.16955100E+02, 0.34912500E+01, -.85552700E+01, 0.65560800E+01, 0.89496500E+01, 0.39240800E+01, 0.73742400E+01, 0.14965000E+02, -.30906600E+01, 0.23593700E+01, 0.91009300E+01, 0.40938400E+01, -.64024200E+01, 0.18045000E+02, 0.48788900E+01, -.45541400E-01, 0.18042700E+01, 0.17064800E+02, 0.34949700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.82138100E+01, -.54131900E+01, -.31734800E+01, 0.15832900E+02, 0.15944500E+01, -.13757500E+02, 0.15648200E+02, 0.45500300E+01, -.45327600E+01, 0.49402900E+01, 0.67902700E+00, 0.64392800E+00, 0.23317100E+01, 0.32330100E+01, 0.28140000E+01, -.62641400E+01, -.41610700E+01, 0.31533300E+00, -.68648900E+01, 0.97537700E+01, -.99241000E+00, 0.38119700E+01, -.23032700E+01, 0.37705800E-02, -.49330700E+01, 0.10656000E+02, 0.21133000E+01, -.99718200E+01, -.19372500E+00, 0.41765300E+01, 0.21341500E+01, 0.17204800E+01, -.65389400E+00, -.26053200E+00, 0.28468800E+01, -.15558200E+01, 0.30364900E+01, 0.71037000E+01, -.12700100E+01, 0.96738500E+01, 0.90209100E+00, -.34205300E+00, 0.48394300E+01, -.68004300E+01, 0.12215400E+01, -.26413900E+01, -.70560900E+00, -.13312000E+01, 0.45544000E+01, -.35071200E+01, -.44620600E+00, -.22556000E+01, -.52341300E+01, -.22814400E+01, 0.11289300E+01, 0.53343200E+00, 0.61381600E-01, 0.28663300E+01, 0.19724000E+00, -.74459300E+01, -.76815000E+00, 0.19382700E+01, 0.38281400E+00, -.78526100E+00, 0.83808600E-01, -.15113500E+01, 0.27957000E+01, -.12439600E+01, -.10325500E+00, -.78090400E+01, 0.61042400E+00, -.50364600E+00, 0.44507700E+01, -.36101100E+01, -.18417700E+01, -.30564900E+00, 0.17075000E+01, 0.77669400E+00, 0.62400200E+00, 0.52130200E+00, -.10767000E+01, 0.13409900E+01, -.35312000E-01, -.34452500E+00, 0.55406900E-01, 0.84418500E+00, -.65192400E+00, 0.41708600E+01, 0.87870000E-01, -.13979200E+00, 0.47117400E+00, -.37899600E+00, 0.89248600E-01, 0.16184300E+01, 0.88968400E-01, -.86537900E+00, 0.87090400E-01, -.11106700E+01, 0.73315700E-01, 0.16297400E+01, 0.96069600E+00, 0.76827000E+01, -.11780600E+01, 0.63238800E+00, 0.29285500E+00, -.65781900E+00, 0.19565000E+00, -.52044000E+00, 0.24992800E+01, 0.49224000E+00, 0.67660100E+00, 0.50189200E+00, -.15319000E+01, -.51308800E-01, -.59221200E+00, 0.18282000E+00, 0.40021700E+00, -.37010600E+01, -.25580600E+00, -.67447700E+00, -.11985600E+00, -.14074300E+01, -.14583200E+01, 0.21852900E+01, -.18757400E+00, -.41151700E+00, -.49819400E+00, -.27184600E-01, 0.50655000E+00, 0.85717400E+00, -.24661800E-01, -.17268000E+00, 0.30517200E+00, 0.14039600E+01, -.10129000E+01, 0.10180700E+01, -.10598400E+00, 0.10514700E+01, -.64051200E+00, 0.34317700E+00, -.10536800E+00, 0.75730500E+00, -.14849600E+01, -.17824900E+01, 0.35574500E+00, -.85945400E-01, -.15903400E+00, -.41779600E+00, -.24832700E+00, -.12672000E+01, 0.45059400E+00, 0.88060600E-01, -.23107700E+01, 0.41319200E+00, -.10791300E+00, -.59874100E+00, 0.32750400E+00, 0.19245500E+01, 0.62543300E+00, 0.15196800E+01, 0.30005800E+00, 0.19435400E+01, -.95330100E+00, -.55111400E-01, -.22483700E+01, -.59691000E+00, 0.47721900E+01, -.96440100E+00, 0.21876900E+00, 0.19502000E-01, 0.50321000E+00, -.11760700E+01, -.10948800E+01, 0.13726700E+01, -.82032000E+00, 0.13789000E+00, -.99746900E-01, 0.53647900E+00, -.81667800E+00, 0.18850400E+01, 0.42418100E+00, -.75937800E-01, -.17533600E+00, -.47861900E+00, 0.20974100E+00, 0.23075900E+00, -.26022400E+00, -.34629900E+00, -.19650300E-01, -.26053200E+00, 0.22838800E+00, 0.29425100E+00, 0.37247100E+00, -.21867400E+01, -.27440600E+00, -.63050700E+00, -.15792000E+00, 0.92245600E-01, -.48053200E+00, 0.30990400E+00, 0.54353200E+00, -.49582800E+00, 0.32791100E-01, 0.35902500E+02, 0.75030900E+02, 0.12654400E+02, -.24133000E+02, -.36597800E+01, -.24635900E+02, -.43676700E+00, -.14450600E+01, 0.38297300E+00, 0.18827200E+00, 0.10530500E-01, 0.23831800E+01, -.57545900E-02, 0.10320000E+00, -.62082800E+01, 0.18164400E+01, -.74167000E+01, -.56712400E+01, 0.17453000E+01, 0.12844400E+01, -.13248000E+01, -.85062500E-01, -.11396600E+02, -.52984800E+01, -.42415300E+00, 0.10182900E+01, -.11119900E+02, 0.25541400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13814700E+02, 0.67853200E+01, 0.53389300E+01, -.19364700E+02, -.53318800E+00, 0.18614900E+02, -.18497700E+02, -.60833900E+01, 0.69546000E+01, -.67503900E+01, -.22819400E+01, -.11200500E+01, -.48946200E+01, -.78034400E+01, -.34713700E+01, 0.60806300E+01, 0.39808800E+01, -.39699800E+01, 0.10974900E+02, -.22538200E+02, 0.10744300E+01, -.93126300E+01, 0.28000900E+01, 0.12402300E+01, 0.64823000E+01, -.15295600E+02, -.69169800E+01, 0.14614100E+02, -.16046100E+01, -.60631300E+01, -.41920700E+01, -.41982100E+01, 0.20823300E+01, 0.90339500E+00, -.49790800E+01, 0.18267200E+01, -.76985200E+00, -.12027600E+02, 0.24066700E+01, -.17407700E+02, -.18001500E+01, 0.77039400E+00, -.69578800E+01, 0.10066200E+02, -.46425700E+01, 0.48129300E+01, 0.11432500E+01, 0.38718100E+00, -.53129900E+01, 0.76973300E+00, 0.15360700E+01, 0.54611900E+01, 0.50389000E+01, 0.23413500E+01, -.22445700E+01, 0.23848400E+01, -.44965900E+00, -.51192200E+01, -.82886500E+01, 0.70856300E+01, 0.12152200E+01, -.71432900E+00, -.30418000E+00, 0.21628700E+01, -.12698100E+00, 0.19292300E+01, -.24061900E+00, 0.19412900E+01, -.41213800E-01, 0.11095800E+02, -.13784800E+01, -.55191200E+00, -.54927000E+01, 0.41440800E+01, 0.26248300E+01, 0.55054500E-01, -.28690400E+01, 0.50722700E+00, -.42402100E+00, -.23422700E+01, 0.14907200E+01, -.11914300E+01, 0.79849900E-01, 0.12811700E+01, 0.82584000E+00, -.13788900E+01, -.11932400E+01, 0.88622700E+01, 0.28795700E+01, 0.96392400E+00, 0.31711300E+00, 0.50749700E+00, -.76281800E+00, -.17507600E+01, -.42243800E+00, -.19275700E+01, 0.36783500E+00, 0.24497200E+01, -.96390200E+00, -.26473600E+01, -.23408500E+00, -.11143900E+02, 0.30126400E+00, -.11693400E+01, 0.38394100E+00, -.49722400E+00, -.14208800E+01, 0.13669400E+01, -.47153900E+01, -.99707000E+00, 0.71458800E+00, -.35932500E+00, 0.16856000E+01, 0.50722400E+00, 0.10941500E+01, 0.86770100E+00, -.58763300E+00, -.43527700E+01, -.28515700E+00, -.38172600E+01, 0.69317600E+00, -.34107200E+00, -.94035900E+00, 0.23309100E+01, -.89293600E+00, -.25924000E+00, -.20112600E+00, -.76375900E-02, -.52876700E+00, -.16577000E+01, -.44584800E+00, -.19701900E-01, -.25738900E+01, -.40172800E+00, -.14390400E+01, -.26070400E+00, 0.33521700E+00, 0.30132800E+01, 0.30691800E+00, 0.74781800E-01, 0.82078400E+00, 0.76860500E+00, -.94870400E-01, 0.10657800E+00, -.47897200E+00, -.86699800E+00, 0.23329700E+00, 0.14795800E+01, 0.45139100E+01, 0.19966100E+01, 0.85470500E+00, -.10689300E+01, 0.33535400E+01, 0.81459300E+00, 0.46276400E+00, -.46254800E+00, -.78183500E+00, 0.21899500E+00, -.34270100E+00, -.12849500E+01, -.73477800E+00, -.65970800E+00, 0.46776700E+00, 0.17297000E+00, -.41230000E+00, 0.57506200E-01, -.67848000E+00, 0.29305100E+00, -.11418900E+01, 0.80593300E+00, -.21036000E+00, -.32425000E+01, -.20469600E+01, -.10549900E+01, -.17205400E+01, -.16404500E+00, 0.66822900E+00, 0.54961600E+00, 0.50676800E+00, -.27269600E+00, 0.10714300E+01, 0.50044900E-02, -.18715800E+00, 0.53039500E+00, 0.20463800E+01, 0.54316900E+00, -.64543800E+00, 0.29762300E+00, -.45640900E+00, 0.53112100E+00, -.42455200E+00, -.10590600E+01, -.21537700E+00, -.15032300E+01, 0.62067000E+00, -.96397700E+00, -.18527400E+00, 0.32716700E+01, -.31055900E+00, 0.55364100E+00, -.79931100E+00, 0.13766800E+00, 0.66219300E+00, 0.38746000E+00, 0.39819700E+02, 0.47539700E+02, 0.28172400E+02, 0.45616200E+01, -.25275700E+02, 0.12080200E+02, -.15294900E+02, -.60114400E+01, -.32266900E+02, -.15491900E+02, 0.14454500E+02, -.14363000E+02, -.15133300E+02, -.62936500E+01, -.14170200E+02, -.27561900E+02, -.59685100E+00, -.46823400E+01, -.13590400E+02, -.79177100E+01, 0.13106300E+02, -.24627800E+02, -.95811700E+01, 0.52572100E+01, -.72980200E+01, -.26123500E+02, 0.15618000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23411800E+01, 0.16570400E+01, 0.10459100E+01, -.56781500E+01, 0.22188300E+00, 0.39256200E+01, -.40902000E+01, -.11141700E+01, 0.25649000E+01, -.22683200E+01, 0.86793900E-01, 0.87427500E+00, -.96603300E+00, 0.27762200E+01, -.21760300E+01, 0.52421500E+01, 0.26225000E+01, 0.79958500E+00, 0.13151400E+01, -.37204000E+01, 0.15760700E-01, -.13439800E+01, 0.13243100E+01, 0.22790500E+00, 0.20348200E+01, -.17279600E+01, -.84087700E+00, 0.10014500E+01, -.13502000E+01, -.46950200E+00, -.74453300E+00, -.85007500E+00, 0.13708700E+00, 0.24437500E+00, 0.59224200E+00, 0.15545200E+00, -.11519100E+01, -.32969600E+01, 0.62572900E+00, -.10205700E+01, -.23557600E+00, 0.31681600E+00, -.14473900E+01, 0.15573000E+01, 0.46550600E+00, 0.65300500E+00, 0.39872500E-01, 0.27933800E+00, 0.71580200E+00, 0.20595800E+01, -.23842800E+00, -.92047400E+00, -.29508100E-01, 0.27892000E+00, -.72740600E+00, -.46494600E+00, 0.30278100E+00, 0.91504600E-01, -.13478100E+00, 0.26979600E+01, 0.15741800E+00, -.36766700E+00, 0.18840300E-01, 0.13324600E+00, 0.27969500E+00, 0.82177700E+00, 0.40851700E+00, 0.13504800E+01, -.28602800E-01, -.27734200E+00, -.12239800E+01, 0.30216700E+00, 0.70551200E+00, 0.70247600E+00, -.24919400E+00, 0.12102400E+00, 0.56801300E+00, -.41490500E-01, 0.18179900E+00, 0.67470100E+00, -.81436400E-01, 0.12989700E+00, 0.13153900E-02, -.41061000E+00, -.14789200E+00, -.53983000E+00, 0.54373300E+00, -.21056400E+01, -.68972800E+00, -.13509800E-02, -.62644300E-02, -.57428400E-01, 0.13778600E+00, 0.87161100E+00, 0.18648800E+00, 0.21246400E+00, 0.54663000E-01, -.17729300E+00, 0.12237600E-01, 0.47133700E+00, -.24733100E+00, -.72900400E+00, 0.38954800E+00, 0.17000100E+00, -.31330000E+00, -.35768700E-01, 0.16072200E+00, -.40565100E+00, -.20435800E+00, 0.53300800E-01, -.76628900E+00, -.33027800E-01, 0.55318600E+00, 0.27120700E-02, -.16660300E-01, -.80892500E+00, -.22295100E+00, 0.70488600E+00, 0.56278800E-01, 0.30621500E+00, 0.61678600E-01, 0.23377200E+00, -.79781900E-02, -.46605800E+00, -.22543600E+00, 0.16991300E+00, -.33911600E+00, -.16510300E-01, 0.30947800E+00, 0.27845100E+00, 0.33901100E+00, 0.18862500E+00, 0.12207800E+01, 0.48421100E-01, -.26334600E+00, -.12296900E+00, 0.15505700E+00, -.18964000E+00, -.47260500E+00, 0.22736500E+00, 0.75361700E-01, 0.18048800E+00, -.41066100E-01, -.24686900E+00, -.13250200E+00, -.55220100E-01, 0.21699400E-01, 0.52199200E+00, 0.19441500E+00, 0.20924100E+00, 0.42356800E-01, -.16029500E+00, 0.46428700E+00, 0.35017900E-01, -.10666800E+00, -.55616700E-02, -.10600400E+00, -.46229800E+00, -.26313500E-01, 0.86177100E-01, 0.37889700E-02, -.69871100E+00, 0.49901400E+00, -.28919100E-01, -.31843100E+00, -.29180500E+00, 0.35476800E-01, -.15594800E+00, -.28306700E+00, 0.48187800E+00, -.86774800E-01, -.47527200E+00, 0.59081200E-01, 0.15217600E+00, -.50093800E-01, 0.39006700E-01, 0.40033400E+00, -.12424100E+00, 0.36212800E+00, -.57611700E+00, 0.13961900E-01, -.14434000E-01, 0.52834500E-01, -.93240900E+00, 0.36347600E+00, 0.16752100E-02, 0.69407200E-01, -.24628000E+00, 0.17247100E-01, -.11400300E+00, 0.56815100E-02, 0.22077200E+00, -.30899400E-01, -.21656700E-01, 0.37273500E+00, -.35285000E-01, 0.48734200E-01, -.97508300E-01, 0.87565400E-01, 0.38318600E-01, -.15106800E+00, -.20160500E+00, 0.24083700E-01, -.18252200E+00, -.93134400E-01, -.28401700E+02, 0.10896200E+02, 0.31212000E+00, 0.31923700E+00, 0.30662200E+01, -.16123300E+01, 0.94596200E+00, -.53144000E+01, -.13275200E+01, 0.28120900E+01, -.10014000E+01, -.22565800E+01, -.20612000E+01, -.19087700E+01, -.51854000E+01, 0.28253800E+00, -.10044600E+01, -.15574000E+01, 0.24609300E+01, 0.78037900E+00, -.44829100E+01, -.28831700E+01, -.10541500E+01, -.13128300E+01, -.44895900E+01, -.22018300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14651500E+02, -.24090200E+01, -.29050200E+01, 0.17659300E+02, 0.34484000E+00, -.16534700E+02, 0.12149000E+02, 0.45827600E+01, -.86848800E+01, 0.30983300E+00, 0.31976200E+01, 0.30183200E+01, 0.29089600E+01, 0.10014800E+02, 0.14727300E+01, 0.82992000E+01, 0.28272900E+01, -.50416900E+01, -.10778100E+02, 0.16829900E+02, 0.11976400E+01, 0.69698000E+01, 0.63263400E+00, 0.35646300E+00, -.46160400E+01, -.53289700E-01, 0.75657800E+01, -.75624700E+01, 0.14364000E+01, 0.10907800E+01, 0.24817300E+01, 0.34961400E+01, 0.28018900E-01, -.47765700E+00, 0.33258700E+01, -.96162300E+00, -.25764700E+01, 0.89841400E+01, 0.11932300E+01, 0.10067300E+02, 0.11531600E+01, -.53334100E+00, -.39515100E+00, -.54219800E+01, 0.51278200E+00, 0.25062800E+00, -.62062800E+00, -.31405500E+01, 0.17365300E+01, -.15537200E+01, -.90527400E+00, 0.51741100E+00, -.36961600E+01, -.32970100E+01, 0.17205100E+01, -.37974600E+00, 0.13267400E+00, 0.48002000E+01, 0.86979400E+01, -.54472300E+01, -.12585700E+01, -.68066100E+00, -.46886800E+00, -.56362000E+00, 0.54773800E+00, -.12192900E+01, 0.11186200E+01, -.12225900E+01, 0.75151300E-01, -.34364100E+01, 0.16277600E+01, 0.17837500E+01, -.23907900E+01, -.18342600E+01, -.12787600E+01, 0.15548600E+00, -.48682100E+00, -.11281400E+01, 0.65469300E+00, -.28825900E+01, -.60731100E+00, 0.28028900E+01, -.45725800E+00, -.12785200E+01, -.50894500E+00, 0.22568200E+01, -.12111600E+01, -.11728900E+02, -.22721200E+01, -.13748500E+01, -.24115000E+00, -.93138800E+00, 0.14904700E+00, 0.36622700E+01, 0.40300300E+00, -.25856300E+01, 0.74370600E+00, -.24662000E+01, 0.40482900E+00, -.13934600E+00, 0.10552800E+01, 0.51828400E+01, 0.93869500E+00, -.13363700E+00, 0.21436900E+00, 0.31189800E+00, -.13710400E+01, -.17469100E+00, 0.43867200E+00, 0.40304900E+00, -.18971400E+01, -.90697300E+00, -.16296500E+00, -.23445600E+00, 0.39290000E-01, -.52573700E+00, -.18365200E+00, -.13523000E+01, 0.31422200E-01, 0.17810900E-01, 0.24002400E+00, 0.53682700E+00, 0.91172100E+00, -.11034700E+01, -.43920600E+00, 0.10068200E+01, 0.11871600E+01, -.58945000E-01, 0.39483900E+00, 0.98476500E+00, -.22961000E+01, -.82772000E-01, 0.48557300E+01, 0.21070500E+01, -.92686500E+00, 0.91638800E+00, 0.39291200E+00, -.11045800E+01, -.22939600E+01, -.73369400E-01, 0.30869100E+01, 0.13088100E+01, -.10965500E+01, -.12047000E+01, 0.26595800E+00, 0.77403400E+00, -.16724800E+00, -.87111500E+00, -.90593600E+00, 0.87766700E+00, 0.22395100E-01, 0.83184500E+00, 0.53660100E+00, 0.27932300E+01, -.23015900E+01, -.65593000E+00, 0.17251900E+00, -.19266100E+01, -.83829800E-01, -.19796600E+01, -.26765200E+00, 0.11670800E+01, -.80954800E+00, -.24276300E+00, -.89259100E+00, -.67043300E+00, 0.25632600E+00, 0.55519700E+00, -.19504100E+01, -.62192000E+00, 0.25903100E+00, 0.12311400E+01, -.42525800E-02, 0.70218000E+00, -.31471500E+00, 0.41609000E-01, -.11037500E+01, 0.37769600E+00, -.63683800E+00, 0.45635000E+01, -.12868600E+00, -.18625600E-01, -.15854900E+00, -.10973800E+00, 0.73898300E+00, 0.92528600E-01, -.52083500E-01, -.86239000E+00, 0.28755500E+00, 0.16631100E+00, -.34903800E-01, -.35960600E+00, -.20721600E-01, -.10242400E+01, -.21883200E+00, -.45735000E+00, 0.15232000E+00, 0.54174600E+00, -.45485800E+00, 0.38686300E+00, -.83135900E+00, -.61372900E+00, 0.61714700E-01, 0.22306600E+00, -.44949400E+00, -.14053800E+01, 0.35130100E+02, 0.11512400E+01, -.35244400E+00, 0.89975700E+01, -.68736300E+01, -.60250400E+01, -.28246400E+02, -.38461600E+01, 0.67540400E+01, -.56033000E+01, -.60145800E+01, -.41753600E+01, -.60943500E+01, -.20379100E+02, 0.88460300E+00, -.18409300E+01, -.54128100E+01, 0.32789200E+01, 0.45638200E+01, -.14879600E+02, -.73280600E+01, 0.54301700E+01, -.35654600E+01, -.15692000E+02, -.70341300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.35552400E+01, 0.35607000E+01, 0.17680400E+01, -.85720300E+01, -.16139200E+01, 0.77247900E+01, -.87106000E+01, -.22858600E+01, 0.12453900E+01, -.32686200E+01, -.36971500E+00, 0.45327400E+00, -.17707000E+01, 0.89663200E+00, -.24624700E+01, 0.72267000E+01, 0.37883200E+01, -.27575000E+01, 0.68848800E+01, -.34326300E+01, 0.63937100E+00, -.24666600E+01, 0.24601800E+01, -.67189300E+00, 0.25789200E+01, -.72614900E+01, -.12784100E+01, 0.51069300E+01, -.35407900E+01, -.26405900E+01, -.58346600E+00, 0.55968700E-01, 0.26495500E+00, 0.18277200E+00, -.10636600E+01, 0.42253500E+00, -.22842200E+01, 0.26024900E+00, 0.94838500E+00, -.38903600E+01, -.52170100E+00, 0.16611100E-01, -.72622800E+00, 0.29241500E+01, 0.52495000E+00, 0.97817300E+00, 0.40105300E+00, 0.12205600E+01, -.26443900E+01, 0.30319500E+01, -.23281000E+00, -.11826800E+01, 0.15662400E+01, 0.66427300E+00, -.12945300E+01, -.20781600E+01, 0.27596500E+00, -.25284400E+01, -.39716100E+01, 0.55779300E+01, 0.71015000E+00, -.43270500E+00, 0.17693800E+00, -.49870500E-01, 0.25929500E-01, 0.10437500E+01, -.32652200E+00, -.65280900E-01, -.28564100E+00, 0.39895400E+01, -.79235400E+00, 0.41989300E+00, 0.13911800E+01, 0.77655700E+00, -.33274100E+00, 0.15232300E+00, 0.48295700E+00, -.67443800E-01, 0.43992800E+00, 0.29864700E+01, -.13680300E+00, -.69893000E+00, -.12572000E+00, -.71615100E-01, -.90744100E-01, -.44202700E+00, 0.16246600E+01, -.23319600E+01, -.83795300E+00, -.25163300E+00, -.16188000E+00, -.26010300E+00, 0.27992900E+00, 0.13267600E+01, -.12435600E+00, -.72846400E+00, -.13487600E+00, 0.25610500E+00, -.25322000E+00, 0.19548200E+01, -.13489200E+00, 0.75974800E+00, -.30978100E+01, 0.14238700E+01, 0.65525600E-01, -.48906600E+00, 0.11467000E+01, -.22525800E+00, -.16055800E+01, -.30551700E+00, 0.61955200E+00, 0.25675900E+00, -.63619600E+00, -.11768600E+00, 0.70002700E+00, 0.63799400E-01, 0.28832700E+00, 0.27094800E+00, 0.12170200E+00, 0.46602600E+00, 0.10882400E+00, 0.10758500E+01, 0.47232200E+00, -.10072600E+01, -.41923500E+00, 0.46894400E+00, -.22725400E-01, -.80972000E-02, -.72729800E+00, 0.41349100E-01, 0.83870300E+00, -.16338000E+00, -.17846400E+00, -.10147800E-01, -.77857000E-01, -.35350600E+00, -.17617800E+00, -.50212300E+00, -.46961100E-02, -.27850800E+00, 0.13340700E+00, -.29689700E+00, 0.66006000E+00, -.33413200E+00, -.72920600E-01, 0.13085000E+00, -.35271200E-01, -.97603300E+00, 0.95733400E+00, 0.42172200E+00, 0.55562100E-01, -.33241400E+00, 0.31635300E+00, -.17271300E+00, 0.54196800E+00, 0.29656100E+00, 0.26102900E+00, 0.10168900E+01, 0.11262500E+00, 0.62426700E+00, -.25901500E+00, -.13719900E+00, -.36582700E+00, 0.34023900E-01, 0.80505800E+00, -.39325600E+00, 0.15126800E+01, -.83518600E-01, -.50850200E+00, 0.74711400E-01, -.26809500E+00, 0.37360300E+00, 0.47038100E-01, -.72953500E+00, -.27733300E+00, -.97935800E-01, -.80466000E+00, -.17391800E+00, 0.78552700E+00, -.24197300E+01, -.67056100E-01, -.79412100E-01, 0.81878000E-01, 0.49187100E+00, 0.31809800E+00, -.21593200E+00, -.12689000E-01, -.32979000E+00, -.10140200E+00, 0.17495400E+00, -.34559400E+00, -.42095200E+00, 0.42909700E-01, 0.63679600E+00, -.53484800E-01, 0.72978700E-01, -.13463900E+00, 0.14419200E-01, -.62888500E-01, 0.88022600E-01, 0.51618600E+00, -.56868300E+00, 0.28566600E+00, 0.30112400E+00, 0.30893700E+00, -.52079200E+00, 0.13158200E-01, 0.53893800E+01, -.35504600E+01, 0.50715900E+01, -.16032800E+01, 0.96909400E+01, 0.40306200E+01, -.45992900E+01, 0.36139700E+01, -.12266400E+01, -.67115600E+01, -.14081700E+01, -.55246800E+01, 0.30328800E+01, -.21442700E+01, -.55012500E+01, -.62442800E+01, -.78053700E+01, 0.15555100E+01, 0.22651400E+01, -.35518600E+00, -.98669200E+01, -.50216900E+01, 0.25318600E+01, 0.37054300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21300700E+01, -.23403700E-01, -.52195800E+00, 0.14225700E+01, 0.20612400E+00, -.23091100E+01, 0.12129900E+01, 0.57279000E+00, -.74710500E+00, 0.78424800E+00, 0.35344000E+00, 0.24942700E+00, 0.24286900E+00, 0.87240500E+00, 0.50655500E+00, -.38257600E+00, -.11767600E+00, 0.72521000E+00, -.19641200E+01, 0.20105500E+01, -.10869600E+00, 0.10823100E+01, -.28844900E+00, 0.40808900E-01, -.58003300E+00, 0.13935400E+01, 0.52292500E+00, -.12695700E+01, 0.12320700E+01, 0.61766200E+00, 0.10835900E+00, -.45428100E-01, -.19097300E+00, -.25498200E-01, 0.33356100E+00, -.10325300E+00, 0.63193600E+00, 0.13996300E+00, -.13660200E+00, 0.13536100E+01, 0.21807200E+00, 0.11319400E+00, 0.24839500E+00, -.93364300E+00, -.39023300E+00, -.21801500E+00, -.14521600E+00, -.41021300E+00, 0.20845400E+00, -.13200300E+01, 0.43497700E-01, 0.25092800E+00, 0.66574400E-01, -.25598000E+00, 0.89372100E+00, 0.78696200E+00, -.84024900E-01, 0.69279300E+00, 0.14204300E+01, -.20715700E+01, -.33659900E+00, -.94485000E-01, -.51896800E-01, -.23855900E+00, -.87179300E-01, -.28694100E+00, 0.55856300E-01, -.49709100E+00, 0.41146000E-01, -.81393100E+00, 0.25188200E+00, -.38867500E+00, -.85288400E+00, 0.52612300E-01, 0.91633600E-04, 0.87330800E-01, -.36733000E-01, -.99606400E-02, 0.35540500E-01, -.58299200E+00, -.15823400E+00, 0.33981300E+00, 0.12111400E-01, -.64657100E-01, -.18740400E-01, 0.99514700E-01, -.38974900E+00, 0.61453900E+00, 0.96853800E-01, -.32772600E-02, 0.10554600E+00, -.27042300E-01, -.41403700E-01, 0.17652900E+00, 0.16074500E+00, -.35399600E+00, 0.85957300E-01, -.25150900E+00, 0.12048100E-01, -.57053300E-01, -.59555800E-01, -.37708900E+00, -.68371400E-01, 0.12691800E+00, -.54809700E-01, 0.21919100E+00, -.37597500E+00, 0.23502000E+00, 0.38283600E+00, 0.16303300E-01, -.14381200E+00, 0.14355300E-01, -.15052700E-01, 0.61264300E-01, -.51859000E-02, -.58805300E-01, -.87418400E-01, 0.23905000E+00, -.31964800E-01, 0.11119800E+00, 0.22272100E-01, -.23816700E+00, 0.13162200E+00, -.14605700E-01, 0.12212700E+00, -.96663200E-01, -.12438500E-01, 0.41700900E-03, 0.25603900E-01, 0.56460900E-01, -.17043400E+00, -.60453300E-01, 0.42247000E+00, 0.21477000E+00, 0.38817000E+00, 0.29742100E+00, 0.19858400E-01, 0.55055700E-01, -.67505700E-01, 0.33764300E-01, 0.31477000E+00, 0.88331000E-01, -.24276600E+00, -.15594100E-01, -.50805500E-01, 0.80837000E-01, -.37577300E-01, 0.14374900E+00, -.22803800E+00, 0.33274100E-02, 0.11688100E-01, 0.14718000E-01, -.35947700E-01, 0.56911600E-01, -.34431000E-01, -.35500000E-01, -.21371400E-01, -.70768300E-01, 0.28785200E-02, 0.49805400E-02, 0.81934800E-01, 0.15841500E+00, -.36332600E-01, 0.45417200E-02, -.15736800E+00, -.32953700E-02, -.84158900E-02, -.36383900E-01, -.24971900E-01, -.16543800E+00, 0.85535300E-01, -.15895600E+00, -.54113000E-01, 0.78014900E-01, -.12706800E+00, 0.53459100E-01, 0.17509300E+00, 0.14927400E-01, 0.13122900E+00, 0.44725500E+00, -.29544100E-02, -.29073500E-02, -.56915800E-01, -.30206900E+00, -.16549800E+00, -.73281800E-02, 0.32076500E-01, -.67552500E-01, -.17630400E-01, 0.14150400E-01, -.10458200E-01, -.72538700E-01, -.39422900E-01, -.10319100E+00, -.23819300E+00, -.18408200E-01, 0.69756800E-01, 0.11163900E+00, -.79415400E-01, 0.80147800E-01, -.17508700E+00, -.23141700E+00, -.38782300E-01, 0.20447500E-01, -.61365000E-01, 0.18076400E+00, -.88876300E-01, -.26390400E+00, 0.14164600E+01, 0.79728100E+00, -.23598000E+00, -.18455700E+00, -.30113700E+01, -.26481700E+00, 0.35594800E-01, 0.96062000E-01, -.15938800E+00, -.39864700E+00, -.37484600E+00, -.15145500E+01, -.44841300E+00, -.40694600E+00, -.72260000E-01, -.11390800E+01, -.15497500E+00, -.58152700E+00, -.54481500E+00, 0.80922200E-01, -.52215800E+00, -.62627600E+00, -.14277100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.38595100E+01, -.12772100E+01, -.14264700E+01, 0.67754100E+01, -.27466800E-01, -.57742700E+01, 0.62182000E+01, 0.16838900E+01, -.22146500E+01, 0.17862100E+01, 0.56260400E+00, -.44589300E+00, 0.12876900E+01, -.48426500E+00, 0.91402100E+00, -.36411700E+01, -.26535100E+01, -.63748800E+00, -.28207900E+01, 0.25323000E+01, -.66753400E+00, 0.11071600E+01, -.97955800E+00, 0.33622700E+00, -.20553800E+01, 0.42707300E+01, 0.41704300E+00, -.39679200E+01, -.92087500E+00, 0.12984600E+01, 0.17961400E+01, 0.13044500E+00, -.10549500E-01, 0.70878200E-01, 0.11257300E+01, -.57184500E+00, 0.21252400E+01, 0.20957000E+01, -.12259200E+00, 0.40139600E+01, 0.21290800E+00, -.86840600E+00, 0.33008500E+01, -.21400900E+01, 0.11551200E+01, -.11327500E+01, -.24586300E+00, -.51249500E+00, -.19404300E-01, -.15751600E+01, -.13927100E+00, -.50086400E+00, -.32328800E+00, -.66243900E+00, 0.10614600E+01, -.18007600E+00, 0.21985200E-01, 0.12019200E+01, -.32376200E+00, -.13368000E+01, -.13437000E+00, 0.51130700E+00, 0.30790500E-01, -.56976700E-02, 0.17146100E+00, -.63480100E+00, 0.56481800E+00, -.52073300E+00, 0.11032000E+00, -.11533200E+01, 0.26265100E+00, 0.46672600E+00, 0.28573000E+00, -.36390500E+00, -.67766800E+00, 0.20723300E+00, 0.80002300E+00, -.17386700E+00, -.10949800E+00, 0.13308200E+01, -.24956900E+00, -.57895900E-01, -.81707800E-01, 0.14834200E+00, 0.16987800E-01, 0.72840700E+00, 0.38301200E+00, -.13637600E+01, -.24049100E+00, -.10368600E+00, -.68304900E-01, -.13791900E+00, 0.11885600E+00, 0.71406600E+00, 0.26599600E+00, -.10116300E+00, 0.73320200E-02, -.39883600E+00, 0.49753700E-01, 0.28616900E+00, 0.12886500E+00, -.72447900E+00, -.96776900E+00, 0.51093600E+00, 0.46217100E-01, -.57726800E-01, -.18870000E+00, 0.15374900E+00, 0.15429000E+00, -.75357200E-01, -.23677300E+00, 0.14256200E+00, 0.12921900E+00, 0.38935800E+00, 0.52367200E-01, -.61471700E+00, -.25695900E+00, 0.45245200E-01, 0.85218900E-01, -.24102900E+00, -.59468600E-01, -.50471600E-01, -.11422800E+00, 0.41316400E+00, 0.93337200E-01, 0.10848500E+00, -.16102300E+00, -.94027600E-02, 0.17581600E+00, 0.15288100E+00, -.12773300E+00, 0.10397300E+00, 0.47067600E+00, 0.15183100E+00, 0.57628200E-01, 0.13136400E+00, -.35426200E-01, 0.29254000E+00, -.12127400E+00, -.43131800E-01, -.23476600E+00, -.12619400E+00, 0.55357100E-01, 0.40357200E-01, -.89552600E-01, 0.93895800E-02, 0.21196800E-01, -.53937200E-01, -.26385100E-01, -.17753600E+00, -.57103500E-01, -.99793800E-01, 0.28573900E+00, 0.16606900E+00, -.16860900E+00, -.27425500E-01, -.91016700E-01, -.61949600E+00, 0.87502700E-01, 0.19596700E+00, 0.18631900E-01, -.13016900E+00, 0.29477700E+00, 0.14809500E-01, -.13835500E+00, -.77464800E-01, -.50943600E+00, 0.58146800E-01, 0.59089400E+00, -.54582300E-01, 0.29284900E-01, -.10012000E+00, 0.22519400E+00, 0.75648400E+00, 0.43684200E+00, 0.37551100E-01, 0.11067200E-01, 0.17253800E-01, -.79982400E-02, 0.13395100E+01, -.87570500E-01, 0.11271300E-02, 0.66216000E-01, -.10433800E+00, -.12328800E+00, 0.20124300E-01, 0.44472700E-01, 0.45886100E+00, 0.13111400E-01, 0.58885500E-01, 0.14446500E-01, 0.54620600E-01, -.19728800E-01, 0.33061900E+00, 0.27803400E-01, 0.11989000E+00, 0.25916300E-01, -.14959200E+00, 0.14070100E+00, -.14560900E+00, -.61376100E-01, -.31284200E-01, -.58068200E-01, -.63769300E-01, -.81822700E-01, 0.10325100E+00, 0.75554600E-01, -.59623900E-01, -.10552600E+01, 0.14750100E+01, -.21614300E+01, -.31637600E+00, -.12834500E+01, -.11128400E+01, 0.87014500E+00, -.21995000E+01, -.79044000E+00, 0.24525400E+01, -.91453500E+00, -.18497600E+01, 0.14685900E+01, -.13914200E+01, -.56432400E+00, -.95356600E+00, 0.21039700E+01, -.21230900E+01, 0.23762200E+01, 0.20616000E+00, -.15458000E+01, -.21653700E+01, -.22157100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.39016100E+01, 0.19403700E+01, 0.14559500E+01, -.45226300E+01, 0.28833100E+00, 0.45336100E+01, -.36509900E+01, -.14486500E+01, 0.26579000E+01, -.10280500E+01, -.73425500E+00, -.76212200E+00, -.11489300E+01, -.31529400E+01, -.38840800E+00, -.49624000E+00, 0.17809400E+00, 0.22317000E+00, 0.21985200E+01, -.55625700E+01, -.16140400E+00, -.24130800E+01, 0.47011400E-01, 0.18894100E+00, 0.16708400E+01, -.27091600E+01, -.16573100E+01, 0.34106300E+01, 0.47232000E+00, -.11990200E+01, -.16469500E+01, -.97918800E+00, 0.26216500E+00, 0.81673500E-01, -.10943200E+01, 0.45007700E+00, -.31508800E+00, -.24329700E+01, 0.16668300E+00, -.37101200E+01, -.31875000E+00, 0.74970100E+00, -.18464500E+01, 0.25690500E+01, -.68202000E+00, 0.98367100E+00, 0.18680700E+00, 0.29596300E+00, -.59872500E+00, 0.24427500E+00, 0.20344900E+00, 0.10458700E+01, 0.11704500E+01, 0.78069000E+00, -.55854700E+00, 0.31008900E+00, -.76094200E-01, -.44599000E+00, -.26670700E+01, 0.23553900E+01, 0.49745800E+00, 0.24782100E-01, -.10955200E+00, 0.77268800E+00, -.20184200E+00, 0.28449800E+00, -.14428900E+00, 0.81802900E+00, 0.54799500E-01, 0.28491400E+00, -.45695600E+00, 0.48123900E+00, -.99515800E+00, 0.99028500E+00, 0.22801100E+00, 0.15790800E-01, -.50679500E+00, -.53693700E+00, -.16537500E-01, -.13637700E+01, 0.66615100E+00, -.15681900E+00, 0.20234600E+00, 0.41712800E+00, 0.10797100E+00, -.59971200E+00, -.86280900E+00, 0.39060800E+01, 0.10586600E+01, 0.11832600E+00, 0.17228100E+00, 0.20530300E+00, -.14984200E+00, -.90360800E+00, -.33335400E+00, 0.17317000E+00, -.73168100E-01, 0.14552400E+00, -.32038300E-01, -.55058400E+00, -.27147500E+00, -.17239200E+00, 0.11528100E+01, -.65040700E+00, 0.32944000E+00, 0.32865800E+00, -.30447600E+00, 0.66351400E+00, -.28079100E-01, 0.31028000E+00, 0.71950800E+00, 0.52885400E+00, 0.60566800E+00, -.55462500E+00, -.19045300E+00, 0.12317300E+01, -.33109600E-02, -.57334700E+00, -.25727000E+00, -.25944900E+00, 0.37381500E+00, -.69336700E+00, -.49668700E+00, 0.11266500E+01, 0.56135200E+00, -.57342000E+00, 0.89204900E+00, 0.29460700E-01, -.48598900E-01, -.10140900E+00, -.61197800E+00, -.45113200E+00, -.97516200E+00, 0.44863700E+00, 0.20049300E+00, 0.59294600E+00, 0.55844000E-01, 0.26929200E+00, 0.65812300E-01, 0.45847800E+00, 0.71084800E+00, 0.10396000E+00, -.14284700E+00, -.90241400E-01, 0.94377300E-01, -.71745200E-01, 0.23051100E-01, 0.44553300E-01, 0.16923100E+00, 0.43676500E+00, 0.10661300E+00, 0.76093300E-01, 0.12353100E+01, -.25459300E+00, 0.92221000E-01, 0.33608200E+00, 0.81891500E-01, -.76080400E-01, 0.35420000E-01, -.89401200E+00, -.17053400E+00, 0.20444200E+00, -.44519600E+00, -.11772700E+00, 0.81495400E+00, 0.21862000E+00, 0.71272800E+00, 0.99422400E-01, -.47725100E-01, -.13827400E-01, -.20673800E+00, 0.22006100E+00, 0.29356900E+00, -.61545300E+00, 0.21487100E+00, -.26574100E+00, -.64592600E+00, -.50442300E-01, -.54377300E+00, -.18871300E+01, -.87900200E-01, 0.31772600E-01, 0.41576400E-01, -.79033100E+00, -.13261400E+00, -.12097900E+00, -.47061400E-01, 0.83365200E+00, -.11889700E+00, 0.15571000E+00, 0.39472700E-03, 0.15876300E-01, 0.40317800E-01, 0.54101500E-01, 0.53990600E-01, -.10293500E-01, 0.60412500E-01, 0.68691700E-01, -.42819500E-02, 0.24372700E-01, -.39265400E+00, -.37263500E+00, 0.29387300E-01, -.31490200E-01, 0.65630300E-01, -.57278100E+00, 0.10351000E+00, -.52614600E+00, 0.82591000E+00, 0.85108200E+00, 0.26900500E+01, 0.39738300E+01, 0.55556600E+01, 0.34994400E+01, -.15051300E+01, 0.26886300E+01, 0.91339000E+00, -.17767800E+01, 0.14546500E+01, 0.47424000E+01, -.64676100E+00, 0.28764300E+00, 0.73201600E+00, 0.29729700E+01, -.24090500E+01, 0.44578500E+01, -.11877000E+01, -.38347400E+01, 0.61783700E+00, 0.46929900E+01, 0.84331300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13032700E+02, -.64864100E+01, -.41561500E+01, 0.24371800E+02, -.11059200E+01, -.21970000E+02, 0.19596400E+02, 0.70324300E+01, -.18799300E+01, 0.65495700E+01, 0.38743700E-01, -.12719600E+01, 0.27168500E+01, -.32894500E+01, 0.55979700E+01, -.64520900E+01, -.49116300E+01, -.48078400E+01, -.73073400E+01, 0.13043000E+02, -.37417000E+00, 0.30139900E+01, -.69016600E+01, 0.21670900E+00, -.44900100E+01, 0.41729500E+01, 0.58475300E+00, -.10625900E+02, 0.11323400E+01, 0.23068300E+01, 0.44547200E+01, 0.64703700E+00, -.33319400E+01, 0.38748500E-01, 0.28906000E+01, 0.31322200E+01, 0.51109000E+01, -.29408700E+01, -.19903100E+01, 0.11239100E+02, -.69475500E+00, 0.12587600E+01, -.99942100E-01, -.12884200E+01, -.16342900E+00, 0.65433000E+00, -.77701600E+00, -.48045600E+01, 0.33830000E+00, -.15301000E+01, 0.71276700E+00, 0.51561600E+01, 0.15966100E+01, -.18923400E+01, 0.41332200E+01, 0.27153900E+01, -.11654100E+01, 0.37026500E+01, 0.27157700E+01, 0.89673900E-01, -.81900700E+00, -.22099500E+01, -.23130400E+00, 0.20800700E+00, 0.92446500E+00, 0.33588200E-01, 0.10135000E+01, -.80500400E+00, 0.51113600E+00, 0.19927600E+01, 0.54536500E+00, 0.24521000E+00, -.52647500E+01, 0.63304200E+00, 0.26571400E+01, 0.29240600E+00, -.12267300E+01, 0.35774200E+00, -.37541700E+00, -.30344700E+01, 0.50196300E+00, 0.63569000E+00, 0.15413300E+00, 0.41146900E+00, 0.20637700E+00, 0.32312600E+00, -.88714500E-01, 0.64889400E+00, -.18890200E+00, 0.17779000E+01, -.10289000E+01, 0.14526100E+01, 0.14858600E+00, -.19125800E+01, -.82270500E+00, -.47146700E+00, 0.11607000E+01, 0.56910100E+01, -.71932400E+00, 0.48468200E-01, 0.55398600E+00, -.99661300E+01, 0.16361200E+01, -.51557100E+00, -.12693600E+01, -.12225300E+01, -.28760300E+01, -.79144500E+00, -.37235500E+01, 0.81823000E+00, -.22398900E+00, -.18764900E+01, 0.17083500E+01, -.80041500E+00, -.13880300E+01, 0.16723300E+00, 0.43302000E-01, -.34447000E+01, -.45148500E+00, -.48596000E+01, 0.26973100E+00, 0.15074700E+01, 0.11484900E+01, -.16549000E+01, 0.90765400E+00, 0.66679400E+00, 0.22185600E+00, -.56631700E-04, -.13887400E+01, 0.41540600E+00, -.70604600E+00, -.12156400E+01, 0.21572100E+01, 0.37551400E+00, 0.47632000E+00, -.41807300E+00, 0.48028800E+00, -.34609700E+01, -.96642700E+00, 0.12602500E+01, 0.26576500E+01, 0.24568600E+01, -.13514200E+00, -.54111300E+00, -.36646100E+00, 0.11730000E+00, 0.16655100E+00, -.49473800E+00, -.65558400E+00, 0.88802400E+00, -.12951200E+00, 0.38258100E+00, 0.23063200E+00, 0.58725100E+00, -.29980900E+00, 0.31509200E+00, 0.67498300E-01, -.22258900E+01, -.76542700E-02, -.26067900E+01, -.89123000E+00, 0.90301100E+00, -.46053500E+00, -.26904000E+00, 0.16771900E+01, 0.10837000E+01, 0.29226400E+01, 0.76580200E-01, -.13564500E+01, 0.88309500E+00, 0.18884600E+00, 0.25828100E+01, -.72676900E+00, -.10221600E+01, -.84383200E+00, -.29495600E-01, -.95080600E+00, 0.38980900E+00, -.10556200E+01, -.19365200E+01, 0.10472000E+00, -.14015300E+00, -.46918000E+00, 0.12863900E+01, 0.17236800E+01, 0.50324600E+00, -.33797500E+00, -.43956500E+01, 0.12115200E+00, -.97927400E+00, 0.39864700E+00, 0.10753600E+01, -.20809100E+00, -.56354100E+00, 0.25947700E+00, 0.12471700E+00, -.62842400E+00, -.55860200E+00, 0.10278700E+01, -.93709200E+00, 0.21113100E+01, 0.85769700E+00, 0.13369700E+00, 0.80951300E+00, -.37924700E-01, 0.70254000E-01, -.17145900E+00, 0.16581100E+01, -.58176800E+01, 0.67990500E+00, -.14276200E+01, 0.42822600E+02, -.14316900E+02, -.23348200E+01, 0.27426500E+01, 0.38715600E+01, -.72109500E+00, -.12286500E+02, -.91264500E+00, -.94909500E+01, -.93153700E+01, 0.42523400E+01, 0.80485600E+00, -.12473400E+02, -.43440600E+01, -.66905700E+01, -.13267800E+02, -.42113500E+02, 0.39252200E+01, -.60304900E+01, -.29245600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21817600E+01, -.21647100E+01, -.13062000E+01, 0.56881400E+01, 0.13038100E+00, -.42144200E+01, 0.48445100E+01, 0.11026900E+01, -.13829900E+01, 0.18983400E+01, -.65242500E-01, -.12807500E+01, 0.62205200E+00, -.19695000E+01, 0.49760500E+00, -.43677000E+01, -.26754400E+01, -.55304900E+00, -.34347600E+01, 0.13655000E+01, -.57427400E+00, 0.95062800E+00, -.17413200E+01, 0.26241300E+00, -.11900900E+01, 0.31850400E+01, 0.92352800E+00, -.30853700E+01, 0.16501200E+00, 0.10579100E+01, 0.12809800E+01, -.33869600E+00, 0.32888300E+00, 0.12984100E+00, 0.86490800E+00, -.50933500E+00, 0.21043000E+01, -.22679600E+01, -.37400900E+00, 0.29290900E+01, 0.15187400E+00, -.34113500E+00, 0.18090100E+01, -.10636400E+01, 0.93567700E+00, -.93860100E+00, -.10797000E+00, -.39199100E-01, 0.11163600E+01, -.48145700E+00, -.81745400E-02, -.18869300E+00, -.11098200E+01, -.42259500E+00, -.38808000E+00, 0.15252200E+00, -.22191100E-01, 0.29357800E+00, -.10742100E+01, -.12535900E+01, -.12970200E+00, 0.36618400E+00, -.40136600E-01, 0.21832900E+00, -.10666400E+00, -.55768000E+00, 0.47894300E+00, -.66816700E+00, 0.18161800E+00, 0.11686700E+01, 0.31776000E+00, 0.45101600E+00, 0.21182000E+00, -.14170000E+00, -.41329200E+00, 0.23310600E+00, 0.71992800E+00, -.25688400E+00, 0.79340900E-01, 0.15972500E+01, -.11214500E+00, -.23491000E-01, -.55436600E-01, 0.18566000E+00, -.51335000E-02, 0.10468800E+01, 0.29629900E+00, -.19065100E+01, -.29587700E+00, 0.73394400E-01, -.18025900E+00, 0.62454900E-01, 0.17628400E-01, 0.13341600E+00, 0.21981300E+00, -.11997400E+00, 0.18727100E-01, -.18206500E+00, 0.83362600E-01, -.52788200E+00, 0.40152500E+00, -.10497500E+01, -.91027600E+00, 0.17770500E+00, -.81953500E-01, -.43434900E-01, 0.10294100E+00, -.13972100E+00, -.45183400E+00, -.31310100E+00, 0.74103200E-01, -.10725800E-01, 0.10033000E+00, 0.26597900E+00, 0.77677100E-01, -.32899000E+00, -.10190500E+00, 0.10421600E-01, 0.64900400E-01, -.59827300E-01, -.18855600E+00, 0.18268700E+00, -.13117200E-01, -.12744500E+00, -.30902500E+00, 0.14655300E+00, -.38948000E+00, -.14347000E-01, 0.15976400E+00, 0.13836100E-01, 0.15373400E+00, 0.25180900E+00, 0.33981000E+00, -.49435600E-01, 0.12561700E+00, -.11014100E+00, -.18974500E-01, 0.24553400E+00, -.74654600E-01, -.22884700E+00, -.34371400E+00, -.19917100E+00, 0.78109800E-01, 0.13424000E+00, -.82689300E-01, 0.59970200E-01, 0.13026000E-02, -.39019700E-01, -.94311000E-01, 0.50000000E-01, -.36737900E-01, -.18640200E-02, -.11749200E+00, 0.20492200E+00, -.18355300E+00, -.43779200E-01, -.45837500E-01, -.53586800E+00, -.10507000E-01, 0.10270800E+00, -.32994700E-01, -.23984400E+00, 0.33485200E+00, -.23251700E-02, -.50283600E-01, -.34077800E-01, -.42451000E+00, 0.31306800E-01, -.78719100E-01, 0.73348200E-01, 0.50814700E-01, -.16826800E+00, 0.61543700E-01, 0.28220800E+00, 0.15358200E+00, 0.10511300E+00, 0.43799400E+00, -.30706400E-01, 0.10007000E+00, 0.19672200E+00, -.74413500E-01, -.41704200E-02, 0.54524500E-01, 0.24725900E+00, -.67606100E-02, 0.22142900E-01, -.66340500E-01, 0.10869500E+00, -.21157700E-01, 0.38824100E-01, 0.29379400E-01, 0.26704000E-01, 0.80645800E-03, 0.17374600E+00, 0.36923500E-01, 0.11561400E+00, 0.23636700E-02, -.18298700E+00, -.32351200E-02, -.51315500E-01, -.37576800E-01, 0.41257500E-01, -.73213800E-01, -.17872600E-01, -.79152100E-01, 0.16962500E+00, -.39547000E-01, -.25670400E-01, -.15856200E+01, 0.64669200E+00, 0.24871800E+00, -.33416600E-01, -.62403500E+01, -.14096200E+01, 0.20611500E+00, 0.63694400E+00, -.14077600E+00, -.25789700E+01, -.79387100E+00, -.28093900E+01, -.18895500E+01, 0.34025000E+00, -.36444200E+00, -.32343800E+01, -.73861800E+00, -.10245900E+01, -.28144200E+01, -.13748000E+00, 0.36091900E-01, -.11300700E+01, 0.37429000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.44176600E+01, 0.15795800E+01, 0.13313800E+01, -.64742000E+01, -.10365900E+01, 0.63953000E+01, -.67534700E+01, -.20784600E+01, 0.18167400E+01, -.25243100E+01, -.50149900E+00, -.27768900E-01, -.12962100E+01, -.10509700E+01, -.11009900E+01, 0.21166800E+01, 0.18835400E+01, -.26887400E+00, 0.38619300E+01, -.39295300E+01, 0.54303900E+00, -.18729700E+01, 0.11245800E+01, -.93139600E-01, 0.22770700E+01, -.45798700E+01, -.14040000E+01, 0.38941100E+01, -.15778000E+00, -.18297800E+01, -.11530500E+01, -.52261400E+00, 0.37933400E+00, 0.32070700E-01, -.15208200E+01, 0.40673300E+00, -.14917800E+01, -.22949500E+01, 0.17727100E+00, -.39904100E+01, -.40168600E+00, 0.86029500E+00, -.27741800E+01, 0.27564800E+01, -.57622900E+00, 0.11794800E+01, 0.22245500E+00, 0.41967000E+00, -.89907900E+00, 0.11698100E+01, 0.12407000E+00, 0.33190300E+00, 0.10114600E+01, 0.45605900E+00, -.40990900E+00, -.62596000E-01, -.21740600E-02, -.12969400E+01, -.21098400E+01, 0.26940700E+01, 0.31948700E+00, -.36421700E+00, -.65426400E-01, 0.42346000E+00, -.16690400E-01, 0.57482600E+00, -.44415700E+00, 0.34027700E+00, 0.36126700E-02, 0.26108400E+01, -.29854700E+00, 0.97458700E-01, 0.40846800E-01, 0.60197300E+00, 0.42789300E+00, -.18373000E+00, -.95572000E+00, -.65407600E+00, 0.33323400E+00, -.25327100E+01, 0.42584700E+00, 0.16495200E+00, -.88419200E-03, -.13675100E+00, -.13684100E-01, -.49826400E+00, -.20268100E+00, 0.12546200E+01, 0.27000000E+00, 0.25706300E-01, 0.84405800E-02, 0.89047600E-01, -.98628500E-01, -.10626100E+01, -.39345400E+00, -.36656900E-01, -.70004100E-01, 0.81960600E+00, -.97414700E-01, -.44990900E-01, 0.14760500E+00, 0.58679000E+00, 0.65420400E-01, -.14403900E+00, 0.11530700E+00, -.50117300E-01, 0.86544100E-01, 0.44137400E-01, -.17523600E+00, 0.57131800E-01, 0.21364300E+00, 0.19606800E-01, 0.22922900E-01, -.44638500E-01, -.22552600E-01, 0.27206800E+00, 0.71723800E-01, 0.47720000E-01, -.19124600E-01, 0.19649200E+00, 0.13333100E+00, 0.78494500E-01, -.17620500E+00, 0.50947400E-01, -.22584000E+00, 0.79181500E-01, 0.13007000E+00, -.15130600E-01, -.11285700E-01, -.12751900E+00, 0.14898700E+00, 0.15005600E-01, -.22649000E+00, -.30671000E+00, -.11797600E+00, -.29027400E+00, 0.17729800E-01, -.36015700E+00, 0.12745000E+00, -.89817100E-01, 0.29641100E-01, 0.16632500E+00, 0.54246500E-01, 0.29949900E-01, -.11093300E+00, 0.25908000E-01, -.53193000E-02, -.78053500E-01, -.33486600E-01, 0.27091600E+00, -.27216600E-01, 0.18979700E-01, 0.40667400E+00, -.19145400E+00, 0.42328800E-01, 0.50218900E-01, 0.36497500E-01, 0.45545200E+00, -.81152200E-01, -.34207800E+00, -.10681700E+00, -.43109700E+00, -.27192300E+00, 0.97481900E-02, 0.23697900E+00, -.21846600E+00, -.13599300E+00, 0.60623200E-01, -.36736000E-01, 0.12865600E+00, -.12148700E+00, 0.15905100E+00, 0.14820900E+00, -.15477200E+00, 0.12820600E+00, -.94174300E-01, -.32262300E+00, -.80485300E-01, 0.24248700E+00, -.57448400E+00, 0.19047000E-01, -.10660600E-01, 0.15542500E+00, 0.51647600E+00, 0.20357100E+00, -.96876200E-02, 0.50532800E-01, 0.31528600E+00, 0.50997300E-01, -.77073000E-02, 0.12146000E-01, 0.10821300E+00, 0.95506200E-01, 0.75851800E-01, 0.21781400E+00, -.45333500E-01, -.46928800E-01, -.14239900E-02, 0.52513000E-01, -.14998600E-01, 0.32451000E+00, 0.10246800E+00, 0.64624200E-01, 0.13209700E-01, 0.13423200E+00, -.33659000E+00, 0.13444900E+00, 0.46416300E+00, 0.26894900E+00, -.12439400E+01, -.31444700E+00, -.39146500E-01, -.53223800E+00, 0.11515100E+01, -.48357800E+00, -.38670600E-01, 0.12748800E+01, 0.16042600E+01, 0.78503500E+00, -.10010600E+00, 0.83575600E+00, 0.49650300E+00, 0.15033000E+01, 0.18307000E+01, -.77064000E-01, -.32263800E+00, 0.17047500E+01, 0.29898900E-01, 0.41866100E+00, -.30816600E+00, 0.22907300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.31891900E+01, 0.27814700E+01, 0.15132800E+01, -.63973900E+01, -.59685500E+00, 0.56956800E+01, -.59783700E+01, -.17229900E+01, 0.26251100E+01, -.19652400E+01, -.35977000E+00, -.15809600E+00, -.12729300E+01, -.17151800E+01, -.60727100E+00, 0.39756700E+01, 0.19696500E+01, -.10210500E+01, 0.34526000E+01, -.38481600E+01, -.17870100E+00, -.23144500E+01, 0.12134700E+01, -.58077500E-01, 0.14412600E+01, -.40935700E+01, -.30143200E+01, 0.50119200E+01, 0.44603100E+00, -.20585800E+01, -.11771100E+01, -.15756300E+01, 0.14049800E+00, 0.26452800E+00, -.25050700E+01, 0.97496300E+00, 0.73510400E+00, -.61930300E+01, 0.10007700E+01, -.31424700E+01, -.44322800E+00, 0.44575400E+00, -.10925300E+01, 0.38967900E+01, 0.19836300E-01, 0.14541000E+01, 0.25781800E+00, 0.24673700E+00, -.20633100E+01, 0.86040300E+00, 0.55446100E+00, 0.31068500E+01, 0.23176600E+01, 0.80661500E+00, -.14542700E+01, 0.26125700E+00, -.24029100E+00, -.54313000E+00, -.12489000E+01, 0.17861200E+01, 0.25274600E+00, -.18913800E+00, -.26032600E+00, 0.94914200E+00, 0.37484100E+00, 0.32796700E+00, 0.21052400E+00, 0.63961800E+00, -.25489300E-01, 0.25904800E+01, -.39761800E+00, -.96682900E+00, -.24289500E+01, -.47553600E+00, 0.86078500E+00, -.74044300E-01, -.12008100E+01, -.58988600E-01, 0.23874200E+00, -.76615100E+00, 0.16952300E-01, 0.22621000E+00, -.36560500E-01, 0.20591300E+00, 0.35037800E-01, -.40013600E+00, -.29685900E-01, 0.89450700E+00, 0.35104600E+00, 0.13333900E+00, -.80507700E-01, 0.91609000E-01, -.10113400E-01, -.12701600E+00, -.83130100E+00, -.67303100E+00, 0.10775800E+00, 0.77958700E+00, -.23950700E+00, -.10507500E+01, 0.35050000E+00, -.36626700E+01, -.77351400E+00, -.10050500E+00, -.28382200E-01, -.18686900E-01, -.13900500E+00, 0.44627700E+00, -.75850500E+00, -.15077200E+00, 0.23822800E+00, 0.28398900E+00, 0.99043100E+00, -.13598000E+00, -.70764600E-01, 0.62263500E+00, 0.74086900E-01, 0.95407200E-01, -.26605800E-01, 0.38824700E-01, 0.13024800E+00, -.27067300E-01, -.17063900E+00, 0.27724800E+00, -.17620900E+00, -.22014100E-01, -.26416400E-01, 0.70889400E-02, -.27763000E+00, -.21352700E+00, 0.74393400E-01, -.42610000E-01, -.93827500E+00, -.12046800E+00, 0.29655200E+00, -.10455900E+00, -.12208900E+00, 0.29255700E+00, 0.24817000E+00, -.12364100E-01, -.20335300E+00, -.13880000E+00, 0.29675500E+00, 0.13926600E+00, -.23865800E-01, -.49499800E-02, 0.27230700E-01, -.30295800E+00, 0.14007900E+00, 0.44904500E+00, 0.46166500E-01, -.16764500E-02, -.66077600E-01, -.21386500E+00, 0.27237900E+00, 0.26639700E+00, 0.70616700E-01, 0.18206800E+00, 0.26002000E-01, -.11036200E+00, -.13782000E+00, 0.88028000E-01, -.12238900E+00, -.40740800E-01, 0.73793500E+00, -.13795800E+00, -.58045300E-01, 0.11342400E+00, 0.73357300E-01, -.11541400E+00, -.30934700E+00, -.12426000E+00, 0.48523900E+00, -.45038800E+00, 0.53733900E+00, -.26182900E+00, -.24108300E+00, -.27890400E+00, 0.86933200E-01, -.24666300E+01, -.19112300E-01, -.18527100E-01, 0.12466800E+00, -.58122200E+00, -.70379000E+00, -.18480300E+00, 0.86376400E-01, 0.12605700E+01, -.20257100E+00, 0.19216100E+00, -.17883900E+00, -.13414300E+00, -.18697800E-01, 0.72775800E+00, -.50089200E+00, 0.24824100E+00, 0.21040500E+00, -.23532300E+00, -.45346500E-01, -.16402400E-01, -.23382900E+00, -.37487800E+00, -.63357400E-01, -.12117500E+00, -.82613300E-01, -.38515300E+00, -.54991000E-01, -.25612900E-02, 0.14917500E+01, 0.61742300E+00, 0.14327300E+00, -.48185400E-01, -.27976500E-01, 0.57448500E+00, 0.12246800E+01, 0.19037600E+00, -.72255800E+00, -.18212000E+01, -.18564400E+00, -.72463800E+00, -.26626500E-02, 0.18308700E+00, -.12366600E+01, 0.51845200E+01, -.40246700E-01, -.60818700E+00, -.23876600E+01, 0.20343000E+00, 0.43599500E+00, -.72403100E+00, 0.91303600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.32725300E+01, 0.30982400E+01, 0.16118800E+01, -.56937300E+01, -.20516500E+00, 0.48426000E+01, -.56083200E+01, -.16446900E+01, 0.16715000E+01, -.18109900E+01, -.30180900E+00, 0.54757900E-01, -.95038900E+00, -.67990200E+00, -.85063600E+00, 0.17005800E+01, 0.14227700E+01, 0.69152400E-01, 0.25705100E+01, -.48595400E+01, 0.42082900E+00, -.17773700E+01, 0.99743700E+00, 0.25536600E+00, 0.17991200E+01, -.36666100E+01, -.94157200E+00, 0.30061800E+01, -.31142100E+00, -.13043800E+01, -.10336700E+01, -.49439900E+00, 0.28667600E+00, 0.15585100E-01, -.85746000E+00, 0.31946100E+00, -.12635300E+01, 0.66925300E+00, 0.32791300E+00, -.39747000E+01, -.28688800E+00, 0.34669400E+00, -.20465200E+01, 0.20667400E+01, -.61166200E+00, 0.10063300E+01, 0.19951400E+00, 0.23013100E+00, -.71915300E+00, 0.84398200E+00, 0.29671000E-01, 0.23454000E-01, 0.76521200E+00, 0.59073900E+00, -.40625900E+00, -.16841400E+00, 0.57253500E-01, -.90932300E+00, -.73632500E+00, 0.20089200E+01, 0.34183700E+00, -.22845800E+00, -.13023200E-01, 0.20962800E+00, -.68914800E-01, 0.61831500E+00, -.44848900E+00, 0.96580600E+00, -.40365300E-01, 0.63309200E+00, -.49757000E+00, 0.24687600E+00, 0.34774600E+00, 0.10483300E+01, 0.90854100E-01, -.13436400E+00, -.53562400E+00, -.55454800E+00, 0.35557800E-01, -.16763800E+01, 0.48419800E+00, -.16338500E+00, 0.87464400E-01, 0.15201900E-01, 0.53862700E-01, -.41492600E+00, -.36914700E+00, 0.16310300E+01, 0.41620900E+00, -.11738700E+00, 0.17530700E+00, -.35943400E-01, -.27617500E-01, -.31350400E+00, -.18821500E+00, 0.47282800E+00, -.16167300E+00, 0.29625500E+00, -.62865400E-01, 0.16607400E+00, -.24010600E+00, 0.40018400E+00, 0.57516100E+00, -.20378300E+00, 0.25511000E-01, 0.18674400E+00, 0.13108100E+00, 0.28886500E-01, -.35096500E+00, 0.16665900E+00, 0.24716900E+00, -.90165800E-01, 0.22278700E-01, -.29540700E+00, 0.99327200E-02, 0.43839600E+00, 0.94874800E-01, 0.85666800E-01, -.76767400E-01, 0.16663900E+00, 0.15001100E+00, -.80754200E-01, 0.76620600E-01, 0.27617600E-01, 0.27231000E+00, -.15910400E+00, 0.21326700E+00, 0.96454500E-02, -.66382600E-01, 0.19250800E-01, 0.44001700E-01, -.20864200E+00, -.47777400E+00, -.11339300E+00, -.16413500E+00, 0.12489900E+00, -.93627400E-02, -.19957000E+00, 0.15013900E+00, 0.13946200E+00, 0.29017600E+00, 0.11566400E+00, -.10507000E+00, -.79010400E-01, 0.23048000E-01, 0.89880600E-02, -.14592800E-01, 0.89126300E-02, -.29284000E-01, 0.16885400E+00, -.22275000E-02, 0.93878400E-01, 0.44449800E+00, -.26221900E+00, 0.15852900E+00, 0.10070600E+00, 0.73705500E-01, 0.50425800E+00, -.13569100E-01, -.33523100E+00, -.18822400E-01, -.14207700E+00, -.33936900E+00, -.23065700E-01, 0.25638700E+00, -.23269700E-01, 0.58349200E-01, 0.55287300E-01, -.28166000E-01, -.65838700E-01, -.14119500E+00, 0.40493500E+00, 0.17191400E+00, -.38093000E+00, -.23060800E-02, -.12798900E+00, -.54130500E+00, -.29859200E-01, -.21386500E+00, -.51871500E+00, -.71099400E-01, 0.15591200E-01, 0.26690400E-01, 0.24313600E-01, 0.15102300E+00, -.75583500E-01, 0.48150700E-01, 0.17683300E-02, 0.51128700E-01, 0.64145900E-01, -.11934300E-01, -.38738200E-01, -.27453300E-02, 0.85103600E-01, 0.17950000E+00, -.19562000E-01, -.29478000E-01, 0.14718600E+00, 0.57067700E-01, 0.11909100E-02, -.46050300E-01, -.41478300E-02, 0.56318800E-01, -.70832800E-01, 0.73541900E-01, -.23363400E+00, 0.84265400E-01, 0.11877400E-01, 0.35614000E+00, -.63311900E+00, 0.47727800E+00, -.38257900E-01, 0.14122600E+00, -.56543000E+00, -.17063500E-01, -.34281900E+00, 0.89112700E+00, 0.32407900E+01, 0.33364400E+00, -.96529700E+00, 0.13380800E+01, 0.17280100E+00, 0.13050900E+01, 0.80426800E+00, 0.15491300E+00, -.17138500E+01, 0.32062000E+01, 0.89419400E-02, 0.57564000E-01, -.17216000E+01, -.29447000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.39277000E+01, 0.43302800E+01, 0.21275100E+01, -.54508900E+01, 0.12846200E+00, 0.46673000E+01, -.56539800E+01, -.17483400E+01, 0.20169100E+01, -.20688600E+01, -.28486800E+00, 0.14595900E+00, -.10770200E+01, -.10579600E+01, -.52264500E+00, 0.13424600E+01, 0.14884600E+01, 0.82632600E-01, 0.23189900E+01, -.43219300E+01, 0.62924500E+00, -.16702700E+01, 0.91237400E+00, 0.60571800E+00, 0.18877500E+01, -.39970700E+01, -.75256900E+00, 0.30713800E+01, -.29650600E+00, -.14139300E+01, -.89129600E+00, -.35209900E+00, 0.32258400E+00, -.13603100E-01, -.89778600E+00, 0.32304200E+00, -.15815400E+01, 0.34432700E+00, 0.35884900E+00, -.38090700E+01, -.29070600E+00, 0.30998900E+00, -.23646700E+01, 0.19819800E+01, -.69089100E+00, 0.10945300E+01, 0.20636800E+00, 0.18838300E+00, -.77874600E+00, 0.91976700E+00, -.21621400E-02, 0.26815900E+00, 0.72418000E+00, 0.55205000E+00, -.58027100E+00, -.42845000E+00, 0.26070400E-01, -.51396400E+00, 0.96457700E-01, 0.20241000E+01, 0.26846200E+00, -.25241000E+00, -.70334500E-01, 0.33231000E+00, 0.38448500E-01, 0.64451800E+00, -.22999900E+00, 0.90601200E+00, 0.29968900E-01, 0.33786600E+00, -.37265900E+00, -.46651800E-01, 0.13917300E+00, 0.63981700E+00, 0.34668000E+00, -.21004500E+00, -.59971200E+00, -.24690000E+00, -.78311400E-01, -.13669000E+01, 0.44075700E+00, -.18599300E+00, 0.66546700E-01, -.76272100E-01, 0.57048300E-01, -.44804300E+00, -.12404600E+00, 0.10333700E+01, 0.25097800E+00, -.32077800E-02, 0.11674900E+00, 0.25727600E-01, -.36090700E-01, -.49919600E+00, -.14322100E+00, 0.62482500E+00, -.14798600E+00, 0.40041100E+00, -.56270500E-01, 0.35402000E-01, -.85337500E-01, 0.43286100E+00, 0.45598300E+00, -.26572300E+00, 0.80407400E-02, 0.20000500E+00, 0.16163100E+00, -.75420100E-03, -.51441700E+00, 0.81611100E-01, 0.20021900E+00, -.61520400E-01, 0.20923700E-01, -.32695000E+00, 0.45297700E-01, 0.39015200E+00, 0.87022700E-01, 0.36971500E+00, -.70772700E-01, 0.25707400E+00, 0.77575800E-01, 0.15163100E+00, 0.14921700E+00, -.30833300E+00, 0.10927300E+00, -.40934100E-01, -.17540500E-01, 0.12116000E-02, -.15994100E+00, -.46099700E-01, 0.24891400E+00, -.14909300E+00, -.39314900E+00, -.11348800E+00, 0.11828700E-01, 0.45202500E-01, -.12069900E-01, -.16418800E+00, 0.64794900E-01, 0.67414500E-01, 0.33063200E+00, 0.12155100E+00, -.46286600E-01, -.15377900E-01, -.80514500E-02, 0.50636900E-01, -.30892000E-01, 0.51572400E-01, 0.12646000E-01, 0.47990400E+00, 0.26215300E-01, 0.75664600E-01, 0.16898300E+00, -.24460700E+00, 0.24184900E+00, 0.79532700E-01, 0.59513900E-01, 0.53528700E+00, -.34495100E-01, -.21148300E+00, 0.14130900E-01, -.63800700E-01, -.25638700E+00, -.30171400E-01, 0.21386400E+00, 0.19954900E-01, 0.16697700E+00, 0.53469900E-02, -.46243300E-01, -.90538200E-01, -.13312800E+00, 0.46267400E+00, 0.14787200E+00, -.46787000E+00, -.74708800E-01, -.11194400E+00, -.51404400E+00, -.21614800E-01, -.24751700E+00, -.53120700E+00, -.80534400E-01, 0.19995600E-01, 0.47529300E-02, -.25354900E-01, 0.12206800E+00, -.10677900E+00, 0.44732800E-01, -.12643400E+00, 0.81146600E-01, 0.87363400E-01, -.15780900E-02, -.75511500E-01, -.17891700E-02, -.84729300E-03, 0.21211400E+00, -.51732600E-01, -.35422300E-01, 0.16977200E+00, 0.50393500E-01, 0.21438000E-01, -.58857800E-01, -.18872200E-01, 0.51856200E-01, -.73492900E-01, 0.75198400E-01, -.26742500E+00, 0.72320200E-01, 0.39569900E-02, 0.63253400E+00, -.71397000E+00, 0.43331700E+00, -.28193700E-01, 0.32078300E-01, -.44903500E+00, 0.82585900E-02, -.10039800E+01, 0.16862000E+01, 0.62215400E+01, 0.61835400E+00, -.17232600E+01, 0.25334000E+01, 0.24796300E+00, 0.24247700E+01, 0.16218700E+01, -.72519000E-01, -.30896500E+01, 0.61982400E+01, 0.46237900E-02, 0.14066100E-01, -.31043900E+01, -.38913000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.31693400E+01, -.70630800E+00, -.94994600E+00, 0.33954400E+01, 0.23254600E+00, -.41605700E+01, 0.30686200E+01, 0.12518400E+01, -.15612900E+01, 0.84070500E+00, 0.53002900E+00, 0.90640200E+00, 0.49827600E+00, 0.28246400E+01, 0.86562200E+00, 0.56536200E+00, 0.61225900E+00, 0.81097700E+00, -.29070600E+01, 0.35798100E+01, 0.40663800E+00, 0.17919200E+01, -.39331500E+00, 0.32702100E+00, -.64653500E+00, 0.38271200E+00, 0.16152900E+01, -.21192000E+01, 0.21358600E+01, 0.88075500E+00, -.16574100E+00, 0.52521900E+00, -.60211300E+00, -.30678200E+00, -.61407200E-01, 0.24312300E-01, 0.57676200E+00, 0.40061800E+01, -.39497600E+00, 0.12748300E+01, 0.24699300E+00, 0.55763300E-01, 0.89452300E-01, -.22983200E+01, -.95952400E+00, -.51009600E-01, -.21525100E+00, -.95730800E+00, 0.52123700E+00, -.31650500E+01, 0.10139700E+00, 0.24487600E+00, -.30654900E+00, -.53188800E+00, 0.14869300E+01, 0.13948800E+01, -.21676000E+00, -.12120300E+00, 0.26700800E+01, -.39023200E+01, -.56413200E+00, -.36534000E+00, -.10458100E+00, -.44829800E+00, -.39302300E+00, -.14553100E+00, 0.12862900E+00, -.87034700E+00, 0.95241700E-01, -.17158900E+00, 0.22563200E+00, -.10634700E+01, -.75365900E+00, 0.10038900E+01, -.12106600E+00, 0.33861900E-01, -.68185800E-01, -.69762600E+00, 0.52360200E+00, -.21255700E+01, -.31300700E+00, 0.77792300E+00, 0.23973200E-01, -.22881400E+00, 0.10850700E+00, 0.27203900E+00, -.78195100E+00, 0.32944900E+01, 0.45384400E+00, 0.20722100E-01, 0.44629600E+00, -.12819600E+00, -.14651100E+00, 0.38251900E+00, 0.44449600E+00, -.45563100E+00, 0.71933200E-01, -.39997200E+00, 0.16341100E-02, 0.22200300E+00, -.17622000E+00, 0.12675300E+01, 0.20614100E+00, 0.21341300E+00, 0.63533300E-01, 0.24886200E+00, -.50302900E+00, 0.38058700E+00, 0.14145200E+01, 0.16121800E+00, -.33834200E+00, -.67901400E-01, -.77062600E+00, 0.11611400E+00, -.13644500E+00, -.10739400E+00, 0.19522000E-01, -.13767500E+00, -.68115300E-01, 0.25948000E+00, -.13720000E+00, -.50854500E+00, 0.23770700E+00, -.85443200E-01, 0.12305700E+00, -.61062100E-01, 0.92032000E-01, -.16871600E-01, 0.88658100E-01, 0.10022000E+00, -.28553200E+00, -.16488500E-01, 0.49241100E+00, 0.74441200E-01, 0.11988500E+00, 0.24396200E+00, -.40134000E-01, -.24894100E+00, -.12442000E+00, 0.72927400E-01, 0.19751600E+00, 0.39583300E+00, -.62141600E+00, -.28056500E+00, -.13524600E+00, 0.10898300E+00, -.56733800E-01, -.93289300E-02, -.59940400E+00, 0.73724900E-01, 0.46422500E-01, 0.13754700E-01, -.65860200E-01, 0.15871000E-01, 0.35529800E-01, -.15244200E+00, -.60624200E-01, 0.16046200E+00, 0.51028500E-01, 0.23304100E+00, 0.11976200E+00, 0.40728500E+00, 0.50563700E-01, -.20024900E-02, -.34568100E+00, 0.30006700E+00, 0.25835000E+00, -.11018000E+00, 0.36798100E+00, -.27100500E+00, 0.54427000E-01, -.20510700E+00, -.67719600E-01, 0.21053100E+00, 0.33687700E-02, -.88366400E-02, -.82198700E-01, 0.49118300E-01, -.97312700E-01, 0.28291300E+00, 0.54400100E-01, -.16632400E-02, -.59615800E-01, -.32070700E+00, -.17492300E+00, 0.32777700E-01, 0.24041600E-01, -.63954900E-01, -.67036000E-02, -.22281800E-01, 0.89992100E-02, 0.17214900E-02, -.24134500E-01, -.41547200E-01, -.26848400E+00, -.52413000E-02, 0.80587200E-01, 0.22915100E+00, -.12683100E+00, 0.10936900E+00, -.17409400E+00, -.28600300E+00, -.47717800E-01, 0.29843900E-01, -.46457900E-01, 0.54741800E-01, -.52145900E-01, -.25829200E+00, 0.66792300E+00, 0.28298500E+00, 0.16498000E+00, -.13771500E-01, 0.14873400E+00, 0.65674800E-02, -.45870800E-01, 0.42969100E-01, 0.22880700E+00, -.16543800E+01, 0.18315700E-01, 0.23532300E+00, -.70516900E+00, -.43135900E-01, -.85660700E+00, 0.55639800E-01, 0.19405800E-01, 0.53728200E+00, -.17908300E+01, 0.23102200E-01, 0.58217800E-01, 0.48597800E+00, -.60523200E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21630900E+02, -.13620900E+02, -.84791600E+01, 0.30515600E+02, 0.46420800E+01, -.29758600E+02, 0.31205300E+02, 0.96821800E+01, -.11677300E+02, 0.12888600E+02, 0.22000200E+01, 0.18007300E+00, 0.64263700E+01, 0.71500400E+01, 0.46385800E+01, -.14368500E+02, -.91120000E+01, 0.54930000E+01, -.17365800E+02, 0.28042600E+02, -.26155500E+01, 0.11037000E+02, -.61884900E+01, -.25210500E-01, -.91737400E+01, 0.20957600E+02, 0.78511800E+01, -.21063800E+02, 0.42820000E+01, 0.97289500E+01, 0.44829400E+01, -.58172800E-01, -.34161200E+01, 0.16714600E+00, 0.74735300E+01, -.25824300E+01, 0.99846100E+00, 0.76084300E+01, -.43772600E+01, 0.23827000E+02, 0.59843000E+00, 0.18701800E+01, 0.73294200E+01, -.14470000E+02, 0.15245200E+01, -.47630000E+01, -.19910500E+01, -.29537000E+01, -.49889900E+00, -.96182500E+01, -.11666100E+01, -.34013900E+01, -.71266700E+00, -.22150800E+01, 0.70418300E+01, 0.13904200E+01, -.45454900E+00, 0.10029900E+02, 0.13078600E+02, -.11436500E+02, -.22246100E+01, 0.17728000E+01, -.24503600E+00, -.13851100E+01, 0.30350500E+00, -.32773700E+01, 0.33352000E+01, -.40105900E+01, 0.72845300E+00, -.12994700E+02, 0.34551600E+01, -.18967300E+00, 0.10576800E+01, -.39211700E+01, 0.26690100E+00, -.76675800E+00, 0.16496900E+01, 0.26383700E+01, -.19635600E+01, 0.46069100E+01, -.80798300E+00, 0.44680800E+00, -.28328900E+00, 0.56971700E-01, 0.28915900E+00, 0.74187000E-02, 0.22841400E+01, -.87545800E+01, -.16490700E+01, 0.13517900E+01, -.65247900E+00, 0.29475500E+00, -.12112700E+00, -.15595200E+00, 0.16820600E+01, -.28125300E+00, 0.83270100E+00, -.41226300E+01, 0.12089800E+01, -.42461400E+01, 0.17043600E+01, -.59068100E+01, 0.28081000E+01, -.29355800E+01, 0.16865600E+00, 0.93780400E+00, -.24363700E+01, -.14343100E+01, -.28453900E+01, -.10855200E+01, -.29407000E+00, 0.64012400E+00, 0.34439500E+01, 0.11744600E+01, -.45606600E+00, -.24609000E+01, -.15212300E+01, -.57887900E+01, 0.71824100E-03, -.52134800E+01, -.16928300E+01, 0.83824900E-01, -.14454100E+01, 0.10469400E+01, -.17586700E+01, 0.59391500E+00, -.16614700E+01, -.93470500E-01, 0.11177400E+01, -.61304600E+00, -.23104300E+01, 0.10267900E+01, 0.45125000E+01, 0.21762500E+01, 0.11148300E+01, -.50549400E+00, 0.92200600E+00, 0.15730400E+01, -.26829300E+01, -.14180300E-01, 0.10834600E+01, 0.17167400E-01, 0.32479000E+00, 0.28054500E+01, 0.29083200E-01, -.30082500E+00, 0.62467700E-01, 0.65887800E+00, -.32471200E+00, 0.13330600E+01, -.62914300E+00, -.10044200E+00, 0.34767200E+01, 0.16908100E+01, -.26376000E+01, -.11439700E+01, -.14087400E+01, -.44626200E+01, -.60776700E+00, -.50638500E+00, 0.27327800E+00, -.16354700E+01, 0.37179500E+01, -.58810900E-01, -.26458700E+01, 0.26409500E+01, -.36719500E+01, 0.34190600E+00, 0.22028600E+01, 0.90624400E+00, 0.63837900E+00, -.34762900E+01, -.15263200E+01, 0.43236200E+01, 0.73523400E+00, 0.80084100E+00, 0.28058300E+01, 0.10411500E+01, -.75501700E+00, 0.11660600E+02, 0.37650600E+00, 0.28123500E+00, -.94295900E+00, -.14444200E+01, 0.44112800E+00, 0.15348400E+01, -.25146300E+00, 0.23633900E+01, -.65120900E+00, 0.33080700E+00, -.47138500E+00, -.49326900E+00, -.81302700E+00, 0.23700100E+01, -.16071400E+01, 0.95362500E+00, 0.83282900E+00, 0.76381600E+00, 0.16169100E+00, -.41829500E+00, -.37691000E+01, -.66458700E-01, -.22689700E+00, -.28500500E+00, -.58221900E+00, 0.36020400E+01, -.69044500E+00, -.68660200E+00, 0.46073900E+01, -.41049800E+01, -.33647800E+01, 0.20134900E-01, -.70600900E+00, 0.40316900E+01, 0.23939800E+01, 0.14873700E+01, -.24416100E+01, -.39014200E+01, -.18380800E+01, -.35476800E+01, -.32746300E+01, -.34543500E+01, -.39763600E+01, -.15741100E+02, 0.41276200E+00, -.61472600E+01, 0.40220200E+00, -.57348900E+00, -.51377000E+01, -.60067900E+01, -.41127600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12958400E+02, -.85998900E+01, -.57318700E+01, 0.17303900E+02, 0.89080800E-01, -.16374900E+02, 0.16034100E+02, 0.54373300E+01, -.61173500E+01, 0.60791900E+01, 0.15664600E+01, 0.47494400E+00, 0.42538300E+01, 0.42835200E+01, 0.30601700E+00, -.74859500E+01, -.53840600E+01, 0.94891100E+00, -.62218900E+01, 0.16038500E+02, -.16317600E+01, 0.57814900E+01, -.13109800E+01, -.20408500E-01, -.78600200E+01, 0.85516300E+01, 0.31606200E+01, -.84424800E+01, 0.22131300E+01, 0.36130300E+01, 0.27285700E+01, 0.86224000E+00, -.25440000E+01, -.80689900E+00, 0.55018000E+00, 0.12706600E+00, 0.51182600E+01, 0.10715500E+02, -.12160800E+01, 0.15100100E+02, 0.87425500E+00, -.13240400E+01, 0.97703200E+01, -.11002600E+02, 0.16532600E+01, -.38364100E+01, -.37847000E+00, -.29833700E+00, -.32853200E+00, -.70844100E+01, -.68445700E+00, -.21614300E+01, -.15938700E+01, -.13644500E+01, 0.35576200E+01, -.17913700E+01, -.33628200E+00, 0.39283800E+01, 0.31878900E+01, -.69202700E+01, -.12958600E+01, 0.30555800E+00, -.41899600E+00, -.52041000E+00, 0.34733500E+00, -.19162400E+01, 0.32137600E+00, -.53852100E+01, 0.54662000E+00, -.61304800E+01, 0.32264400E+01, 0.47400600E+00, 0.51894300E+01, -.47202300E+01, -.13121700E+01, -.60417400E+00, 0.23287500E+01, -.16547400E+01, -.67676700E-01, -.31898000E+01, -.79100700E+00, 0.22976000E+01, -.39138900E+00, -.20808400E+01, -.41542000E+00, -.14830400E+01, 0.28115000E+01, -.44548300E+01, -.26605700E+01, 0.19044500E+01, 0.80757000E+00, -.52491500E+00, 0.75091400E+00, 0.29342800E+01, -.20141300E+00, -.17845100E+00, -.46127800E-02, -.42776500E+01, 0.10307300E+01, 0.12978400E+01, -.23721600E+00, 0.54096500E+01, 0.14750700E+01, -.15820900E+00, -.74878100E-01, -.88917300E+00, 0.65434500E+00, -.23610400E+01, 0.86191100E+00, 0.49029600E+00, -.90416900E+00, 0.13573900E+01, 0.15182600E+01, -.40848300E+00, -.46569100E+00, 0.12364000E+00, -.36888300E+00, 0.19906600E+01, -.27100500E-01, 0.74868500E+00, -.14323200E-01, -.31726100E+00, 0.41508400E+00, -.17127300E+01, -.14614000E+00, 0.14985000E+00, -.14697400E+00, 0.61286000E-02, -.28652800E+00, 0.19503400E+00, 0.11080000E+00, -.28059700E+00, 0.16012900E+01, 0.59589600E+00, 0.46090800E+00, 0.64772600E+00, 0.27607000E+00, 0.16155600E+00, 0.22667800E+00, -.17203100E+00, 0.55251300E+00, -.79627900E+00, 0.65779200E+00, -.82415900E+00, 0.78393200E+00, -.44506000E-01, -.12185900E+00, 0.86948700E+00, -.16682100E+01, 0.10739700E+01, 0.13065300E+00, 0.57611600E+00, -.14727800E+01, -.44153700E+00, -.10002700E+01, 0.20486800E+00, -.14034600E+00, -.15003900E+01, -.98001800E+00, 0.56997900E+00, 0.16172700E+01, -.22976300E+01, 0.30028200E+01, -.51160300E+00, -.26858100E+01, 0.21884700E+01, -.20070200E+01, 0.44693000E-02, 0.14104700E+01, -.65295900E+00, -.49337600E+00, 0.36371200E+00, 0.18206700E+01, -.14884600E+01, 0.14106000E+01, -.82515700E+00, -.20702200E+01, -.48029200E+00, -.19424500E+01, -.62567700E+01, -.32466500E+00, 0.64835300E-01, 0.37811600E+00, 0.30813800E+00, -.11455400E+00, -.17625300E-01, 0.17702400E+00, 0.16045100E+01, -.57269400E-02, 0.22936300E+00, 0.57145600E-01, 0.37673300E+00, -.12402100E+00, 0.94902900E+00, -.85632200E-01, 0.48364000E+00, -.11811600E+00, 0.80454000E+00, 0.11404100E+01, -.90987500E+00, 0.68498400E+00, 0.30038100E+00, 0.79263600E-01, -.29455200E-01, -.17590500E+00, 0.99624700E+00, 0.14669500E+00, 0.13344400E+01, -.61264300E+01, 0.27270700E+01, -.85010900E+00, 0.84435600E-01, 0.77727700E+00, 0.15014400E+01, 0.17823800E+01, -.55708200E-01, -.25041600E+00, 0.46520000E+01, 0.23365800E+00, -.42886200E+01, -.13042700E+01, 0.22369900E+01, 0.75997400E+01, -.65343100E+01, -.81107400E+00, -.70437200E+01, 0.32315800E+00, -.19865900E+00, 0.11628900E+01, -.81692800E+01, -.67114700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.39824700E+01, -.16054000E+01, -.13247700E+01, 0.58972100E+01, 0.80491200E+00, -.57622800E+01, 0.57274700E+01, 0.17655200E+01, -.16944600E+01, 0.22503000E+01, 0.38497300E+00, -.14027700E+00, 0.12072000E+01, -.66796700E-01, 0.16087800E+01, -.31490800E+01, -.22005800E+01, 0.42866500E+00, -.40433900E+01, 0.28115200E+01, -.76033700E+00, 0.14525000E+01, -.12072700E+01, 0.26111900E+00, -.20881200E+01, 0.46543700E+01, 0.11019500E+01, -.37033000E+01, 0.25023800E+00, 0.19114200E+01, 0.89264400E+00, -.80815200E-01, -.41841900E+00, 0.24472100E-01, 0.12723800E+01, -.47193000E+00, 0.19312000E+01, 0.13772900E+01, -.40802700E-01, 0.37343900E+01, 0.34237000E+00, -.11662100E+01, 0.32345500E+01, -.23233300E+01, 0.68320700E+00, -.12109600E+01, -.19975700E+00, -.37372600E+00, 0.52126200E+00, -.10935000E+01, -.12442500E-01, -.44070200E+00, -.59173700E+00, -.60761800E+00, 0.82151800E+00, 0.41055200E-01, -.11256800E-03, 0.15072700E+01, 0.10851700E+01, -.22037000E+01, -.25333300E+00, 0.42689800E+00, 0.27468500E-01, -.19984600E+00, -.39828000E-01, -.67178700E+00, 0.53914400E+00, -.26503000E+00, 0.21542700E-01, -.20518700E+01, 0.28839600E+00, 0.31058700E+00, 0.30557900E+00, -.66077800E+00, -.55794500E+00, 0.14111000E+00, 0.82461400E+00, 0.14039800E+00, -.19432100E+00, 0.15035500E+01, -.27317700E+00, 0.93080000E-01, 0.45009700E-02, 0.10521100E+00, -.48094300E-01, 0.59806500E+00, 0.20759200E+00, -.21000900E+01, -.30316200E+00, -.66290700E-02, 0.20996200E-01, -.87078500E-01, 0.92908500E-01, 0.51918700E+00, 0.40356600E+00, 0.33691900E+00, 0.51675800E-01, -.68765600E+00, 0.94830900E-01, 0.10477200E+00, -.15978200E+00, -.61602500E+00, -.24819400E+00, 0.30280200E+00, -.59851000E-01, 0.68272000E-01, -.34740600E+00, 0.18294500E+00, 0.35545400E+00, -.92139800E-03, -.14674800E+00, 0.25738400E-01, 0.27473400E-01, 0.23493500E+00, -.20632700E-01, -.26678900E+00, -.14543500E+00, -.19473800E+00, 0.21728100E-01, -.31871500E+00, -.56249300E-01, -.17018200E+00, -.93543900E-01, 0.36972900E+00, 0.17313600E+00, -.34814900E-01, 0.86199600E-01, 0.64989500E-02, 0.13229900E+00, 0.10966200E+00, -.20402600E+00, 0.48396200E-01, 0.15983800E+00, 0.11929500E+00, -.23711000E-01, 0.17887500E+00, -.21913500E-01, 0.25517600E+00, -.15729300E+00, 0.18856900E+00, -.11668800E+00, 0.79316500E-02, -.18030200E+00, 0.13907400E-01, -.32079300E-01, -.20309000E-01, 0.23821100E-01, 0.16182400E+00, -.45640000E-01, -.37976200E+00, -.22466300E-01, -.41518300E-01, -.19488200E+00, 0.97969400E-01, 0.13777200E-01, -.68101400E-01, -.52681500E-01, -.34686300E+00, 0.64449600E-01, 0.13246000E+00, 0.14246300E+00, 0.25007600E-01, 0.18555000E+00, 0.14946400E-02, -.29323400E+00, 0.78325500E-01, 0.18844900E-02, -.24227300E-01, 0.25185000E-01, -.16512300E+00, 0.51918100E-01, -.10438600E-01, -.35582300E-01, 0.33183400E+00, 0.80288900E-01, 0.92196800E-01, 0.16971000E+00, 0.95449400E-01, -.32560000E+00, 0.10128200E+01, -.89533500E-01, 0.83076700E-03, -.23871500E-01, -.17420300E-02, 0.28408300E-01, 0.60168400E-01, -.16032300E-01, 0.15199800E-01, -.36367600E-01, -.25530100E-01, 0.23984800E-01, 0.46373800E-01, -.50830400E-01, 0.73412200E-01, -.12383100E+00, 0.64548600E-01, 0.18653300E-01, 0.48389300E-01, 0.22363300E-01, -.35110700E-01, -.21155700E+00, -.53111300E-01, -.42965900E-01, -.16734600E-01, -.79231600E-01, 0.30979000E+00, -.72679900E-01, -.27616400E+00, -.28991900E+00, 0.91080500E+00, 0.13111800E-01, 0.20673600E-01, 0.16678700E+00, -.30830100E+00, -.60966500E-01, 0.70793300E-01, -.21390900E+00, -.46676400E+00, -.55917600E-02, -.50636900E-01, 0.56282300E+00, 0.60477000E-01, -.79084200E-01, -.33104400E+00, 0.38063100E-01, -.39372500E-01, -.15344200E+00, 0.12040900E-02, 0.47103600E-01, -.15228000E+00, -.18389300E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14223600E+02, -.92475100E+01, -.60970400E+01, 0.21677200E+02, 0.29758900E+01, -.20986700E+02, 0.22856900E+02, 0.66287800E+01, -.68372500E+01, 0.85407600E+01, 0.15709100E+01, -.10964400E+01, 0.50552600E+01, 0.73258900E+01, 0.54261600E+00, -.97288100E+01, -.77887500E+01, 0.55323700E+01, -.10904900E+02, 0.16975000E+02, -.35280300E+01, 0.63729500E+01, -.36562300E+01, 0.10595300E+01, -.67537600E+01, 0.17604600E+02, 0.42870200E+01, -.15978600E+02, 0.13402500E+01, 0.64735400E+01, 0.38914400E+01, 0.16145900E+01, -.38644500E+00, -.38205200E+00, 0.42032600E+01, -.21216700E+01, 0.34361400E+01, 0.57989400E+01, -.17350400E+01, 0.11730000E+02, 0.58528200E+00, 0.12801500E+01, 0.41840200E+01, -.81962600E+01, 0.18891400E+01, -.24981800E+01, -.19328800E+01, -.40197000E+01, 0.12453500E+01, -.91540000E+01, -.42106700E+00, -.70205800E+00, -.46341000E+00, -.21413600E+01, 0.68340600E+01, 0.22938900E+01, -.44520100E+00, 0.60152300E+01, 0.65890100E+01, -.91231400E+01, -.11796900E+01, 0.30483100E+01, -.53418400E-01, -.21141300E+00, 0.35610400E-01, -.24967900E+01, 0.27330200E+01, -.96627600E+00, 0.79205700E+00, -.10137300E+02, 0.25243100E+01, -.27530400E+00, 0.35759900E+01, -.35919400E+01, 0.87368400E+00, -.13430300E+01, 0.22473000E+01, 0.24814600E+01, -.22781200E+01, 0.38090200E+01, -.28038400E+00, -.84770600E+00, -.78930600E-02, 0.81757000E+00, 0.54776300E+00, 0.24144200E+00, 0.19125100E+01, -.48418400E+01, 0.14036900E+00, 0.98175300E+00, 0.31147900E+00, 0.83008700E-01, -.36409700E-01, -.32230700E-01, 0.58286400E+00, 0.30493800E+00, 0.24733200E+00, -.30526600E+01, 0.68308900E+00, -.49693400E+01, 0.16308000E+01, -.52475000E+01, 0.67658000E+00, -.23711700E+01, -.72925300E+00, 0.13797300E+01, -.17934600E+01, -.21087900E+01, 0.28452900E+00, -.10676600E+00, 0.35742300E+00, 0.11873600E+00, 0.18067700E+01, 0.17751900E+01, -.15692900E+01, -.22906900E+01, -.51625600E+00, -.31389100E+01, 0.56522000E+00, -.26299600E+01, -.31317800E+01, -.13611800E+01, 0.15264300E+00, -.13637300E+01, -.71429100E+00, -.17431900E+00, -.17802000E+01, 0.42497400E-01, -.62161300E+00, -.46999300E+00, 0.89454400E+00, -.25114400E+00, -.81449200E+00, 0.20921700E+00, 0.14669800E+01, 0.14320400E+00, -.97429300E-01, 0.36968600E+00, 0.71921900E+00, -.58395900E+00, -.74038000E+00, -.17878100E+01, 0.36285600E+00, 0.14414300E+01, 0.72699100E+00, 0.76420100E-01, -.14124000E+00, -.23913400E+00, -.69391900E+00, -.46965200E+00, -.38894700E+00, 0.22587800E+00, -.17710200E+00, -.76893200E+00, -.81676800E-01, -.12344100E+00, 0.20198900E+00, 0.16881300E+01, -.14872900E+00, -.49113300E+00, -.32002800E+00, 0.24609500E-01, -.97048100E+00, 0.71283000E-02, 0.13711900E+01, 0.29492600E+00, -.98604200E+00, 0.41094400E+00, 0.15287900E+01, 0.28584500E+00, 0.88940400E-02, 0.10349300E+01, 0.28750800E+00, 0.82970800E+00, 0.74454100E+00, -.14273500E+00, -.10502700E+01, 0.19428200E+00, 0.17071700E+00, 0.25448000E+01, -.20076100E+00, 0.93121800E-01, -.57614500E-01, -.12522700E+01, -.16990100E+01, -.81624900E+00, -.21712300E-01, 0.31436100E+01, 0.32737000E+00, 0.11460500E+01, 0.11346800E+00, -.90631700E+00, 0.54704300E+00, -.10289200E+01, 0.16979800E+01, -.26316900E+00, 0.13865100E+00, -.80079100E+00, 0.85390100E-01, -.22140400E+00, -.15365200E+00, 0.23592900E+00, -.61524200E+00, -.65567600E+00, -.28876200E+00, -.29783100E+00, 0.73797700E+00, -.16938100E+01, -.78514400E+01, 0.34229000E+01, 0.22212200E+01, -.97798400E-02, 0.30305200E+00, -.27842600E+01, -.16709600E+01, -.18281300E+01, 0.21029300E+01, 0.51652500E+01, -.24216200E+00, 0.15457200E-03, 0.19008200E+01, -.33318500E+01, 0.43912800E+01, 0.19303500E+01, -.71376300E-01, -.75813400E-01, 0.63267000E-01, -.32040500E-01, -.41487400E+01, 0.30558100E+00, 0.29705800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.34187700E+01, -.86412000E+00, -.10867700E+01, 0.40824100E+01, 0.39509700E+00, -.46709400E+01, 0.36118600E+01, 0.13842400E+01, -.19160600E+01, 0.16995700E+01, 0.35670200E+00, 0.33100700E+00, 0.86857600E+00, 0.14891600E+01, 0.97606400E+00, -.18387200E+01, -.79930800E+00, 0.10700000E+01, -.29822000E+01, 0.41712600E+01, -.19141700E-01, 0.20073000E+01, -.81207000E+00, -.13318900E+00, -.11772500E+01, 0.26599300E+01, 0.16882400E+01, -.28890500E+01, 0.14982600E+01, 0.13503300E+01, 0.24831100E+00, 0.57365200E+00, -.40623400E+00, -.18682800E+00, 0.10527300E+01, -.34127500E+00, 0.37121100E+00, 0.24723200E+01, -.72371400E+00, 0.24003100E+01, 0.28512300E+00, -.13333700E-01, 0.71967500E+00, -.25746200E+01, -.27730200E+00, -.73124300E+00, -.21579500E+00, -.39861100E+00, 0.61893600E+00, -.19036400E+01, -.22769700E+00, -.80240600E+00, -.77680100E+00, -.27597400E+00, 0.11000800E+01, 0.44189900E+00, -.98734700E-02, 0.84063600E+00, 0.18789500E+00, -.17651900E+01, -.28309000E+00, 0.16643300E+00, 0.12438200E-01, -.23664200E+00, -.21252300E+00, -.48829200E+00, 0.13026000E+00, -.87527300E+00, 0.11658700E+00, -.20707600E+01, 0.44514200E+00, 0.24512400E+00, 0.19118100E-01, -.18437200E+00, -.24520400E+00, 0.66506600E-01, 0.41569700E+00, -.64854400E-01, -.19011700E+00, 0.93267100E-01, 0.12873500E-01, 0.18181800E+00, 0.41187900E-01, -.43589500E-01, -.15504400E-02, 0.27180100E+00, -.34741600E+00, -.24142600E+00, 0.26639300E-01, -.89567500E-01, 0.11847900E+00, -.45649900E-01, -.41594300E-01, 0.24344800E+00, 0.40399200E+00, 0.13015300E+00, 0.39453900E-01, -.56928600E+00, 0.11527200E+00, -.20605800E+00, -.31167300E-01, 0.64838900E+00, 0.31622300E+00, -.34935200E-01, 0.48030000E-01, 0.15989100E+00, -.54859200E+00, 0.24316400E+00, 0.67443000E+00, 0.17372600E+00, 0.62870800E-02, 0.21973000E+00, -.11436500E+00, 0.26625400E-01, -.21122600E+00, -.28956800E-01, -.90142600E-01, -.30150400E+00, -.47539100E-01, -.95987800E-01, -.82087200E-01, -.37626600E+00, -.18934000E-01, 0.96218600E-01, 0.61722300E-01, -.36718900E-01, 0.20739300E+00, -.35311900E-02, -.14767400E-01, -.64297500E-01, -.35152700E+00, -.36486200E-01, 0.49067700E+00, 0.35482900E+00, 0.25351300E+00, 0.24826200E+00, 0.38424400E-01, 0.14336500E-01, -.23696500E+00, 0.23863300E+00, 0.28219900E+00, 0.12856800E+00, -.17188900E+00, -.15491900E+00, -.67710700E-01, 0.35189700E-02, -.17152300E-01, 0.68934800E-01, -.10748100E+00, 0.17964800E-01, 0.50090000E-01, 0.83307000E-02, -.21953500E+00, 0.56654100E-01, 0.33280100E-01, -.17654900E+00, -.64049900E-01, 0.17237900E+00, 0.51945400E-01, 0.29218200E+00, 0.81878700E-01, 0.48161700E+00, 0.66799100E-01, 0.20149900E-01, -.33338200E+00, 0.21608300E+00, 0.23246500E+00, -.10985900E+00, 0.20975200E+00, -.22158200E+00, 0.10164700E+00, -.24812400E+00, -.21902600E+00, 0.14811500E+00, -.14400300E+00, 0.61749200E-01, 0.20591000E+00, 0.83067100E-01, -.37383100E-01, 0.59050700E+00, 0.78239300E-01, 0.41902100E-02, -.97963900E-01, -.36248200E+00, -.16860100E+00, 0.45602900E-01, -.59360400E-02, -.12970800E+00, -.19152400E-01, -.20096200E-01, 0.22277200E-02, -.44231800E-01, -.29608900E-01, -.18510400E+00, -.27295300E+00, -.46049100E-01, 0.80608500E-01, 0.19754700E+00, -.14418700E+00, 0.11736300E+00, -.20552400E+00, -.21517200E+00, -.44661500E-01, 0.28205500E-01, -.64793000E-01, 0.12224000E+00, -.62334500E-01, -.24532200E+00, 0.59796500E+00, 0.27918600E+00, 0.10301000E-01, 0.47901200E-02, 0.55315000E-01, -.48012100E-01, 0.15203000E-01, -.34272200E-01, 0.33030900E-01, 0.38022300E+00, -.10617900E+00, 0.12674700E+00, -.38450600E+00, 0.18845700E+00, -.22880200E+01, -.14497800E+01, 0.16584600E+00, -.31401800E-01, -.73944300E-01, -.30264800E-01, 0.87026500E-01, 0.12028800E-01, -.10319800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.28935300E+01, 0.52619600E+00, 0.94905100E+00, -.35250300E+01, -.34616800E+00, 0.38648100E+01, -.35718200E+01, -.11859700E+01, 0.18376600E+01, -.15646100E+01, -.38439500E+00, -.82719600E-01, -.86584600E+00, -.10220600E+01, -.47893600E+00, 0.15548600E+01, 0.10887500E+01, -.30895900E+00, 0.22007300E+01, -.33740800E+01, 0.28931700E+00, -.15700100E+01, 0.46906400E+00, 0.25942500E+00, 0.13255600E+01, -.28811000E+01, -.12344300E+01, 0.27341400E+01, -.10636700E+00, -.11221800E+01, -.77419300E+00, -.30360600E+00, 0.25783100E+00, -.16621700E-01, -.14881800E+01, 0.42821900E+00, 0.94758800E-01, -.13630200E+01, 0.47400400E+00, -.33492700E+01, -.21616000E+00, -.67712400E-01, -.13344800E+01, 0.18045800E+01, -.35519000E+00, 0.95392600E+00, 0.16801600E+00, 0.66389900E-01, -.65925800E+00, 0.40333000E+00, 0.26447900E+00, 0.11004100E+01, 0.70498800E+00, 0.26333400E+00, -.32405600E+00, 0.65585000E-01, -.56438800E-01, -.36319600E+00, 0.25049700E+01, 0.68534700E+00, 0.55052300E-01, -.33965200E+00, -.72003800E-01, 0.47979700E-01, 0.24472500E+00, 0.68995600E+00, 0.17746400E+00, 0.10983900E+01, -.75629400E-02, 0.14468600E+01, -.40978700E+00, -.85860800E+00, -.68151000E+00, 0.60563400E+00, 0.65345300E+00, -.18831000E+00, -.82521100E+00, 0.69587000E-01, 0.15203400E+00, -.15443200E+01, 0.33894700E-01, 0.59292500E-01, 0.19857300E-01, -.14551400E+00, 0.33257500E-01, -.61993500E+00, 0.11530500E+00, 0.68183200E+00, 0.20403300E+00, 0.21641500E+00, 0.21470600E+00, 0.56012800E-02, -.40963100E-01, -.42870700E+00, -.24480600E+00, 0.41684500E+00, -.66859500E-01, 0.38215300E+00, -.92190800E-01, -.42199100E+00, -.21539200E-01, -.90068100E+00, 0.28006700E+00, -.22115100E+00, -.14066900E+00, 0.17531300E+00, -.42936900E-01, -.97013500E-02, -.37513300E+00, -.40879100E-01, -.22439700E+00, -.19738600E+00, 0.10156300E+00, -.13577400E+00, 0.14245100E-01, 0.20136000E+00, 0.11208400E+00, 0.70833000E-01, -.42641900E-01, 0.55077400E-01, 0.66971000E-01, 0.39033000E+00, -.10921900E+00, -.11613100E+00, -.20556300E+00, 0.98692800E-01, -.92858800E-01, -.73426400E-02, -.64721800E-01, -.10557400E+00, 0.17488700E+00, -.16527000E-01, -.25081600E+00, -.31208400E+00, 0.80311000E-01, -.26209500E+00, 0.28957900E-01, -.46103700E+00, 0.10512600E+00, -.97220500E-01, 0.77967100E-02, -.27491200E-01, 0.19489100E+00, -.94562700E-02, 0.30749000E-01, 0.76516900E-03, 0.28807800E-02, -.79735400E-01, -.12652800E+00, 0.23048700E+00, -.51349400E-01, 0.51776200E-01, 0.34900500E+00, -.52677900E-01, -.12047900E+00, 0.10305300E+00, -.83027400E-04, -.23111900E+00, -.51045100E-01, -.43437000E+00, -.10594400E+00, -.25441100E+00, -.13482200E+00, 0.50651500E-02, 0.34205300E+00, -.83454500E-01, -.26280000E+00, 0.94796700E-01, 0.37591200E-01, 0.15781900E+00, -.54696800E-01, 0.20778000E+00, 0.14415900E+00, 0.75590800E-01, 0.17473700E+00, -.31201800E-01, -.16300600E+00, -.19226300E-01, 0.31686200E-01, 0.37824400E-01, -.38040000E-01, 0.11992400E-01, 0.36978800E-01, 0.29163000E+00, 0.44104200E-03, -.21345600E-01, 0.20186300E-01, 0.20984000E+00, 0.25549100E-01, 0.71251000E-02, 0.21973000E-01, 0.47308800E-01, 0.44893400E-01, 0.12041000E+00, 0.15200100E+00, 0.47491800E-01, -.33605900E-01, -.32360100E+00, 0.17104100E+00, -.16912100E+00, 0.28027700E+00, 0.28629000E+00, -.14706700E-01, -.36893700E-01, -.16426700E-01, -.56349900E-01, 0.55213300E-01, 0.30751200E+00, -.10377600E+01, -.10502000E+00, -.24228100E+00, 0.11347800E-01, -.35319200E-01, 0.31265400E+00, 0.50415400E+00, 0.21094400E-01, 0.53636100E-01, 0.29951500E+00, 0.51198300E-01, -.63616900E-01, -.40809600E+00, -.97649800E-01, -.82336900E+00, -.33137600E+01, 0.17489300E-01, -.16022700E+00, 0.14568500E+00, -.12556800E+00, -.22748800E+00, -.73644600E-01, -.10117000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.37874600E+01, -.42081300E+01, -.20527700E+01, 0.52966700E+01, 0.10320500E+00, -.46819200E+01, 0.55581300E+01, 0.17190500E+01, -.15754200E+01, 0.20098400E+01, 0.24552300E+00, -.13896100E+00, 0.10082700E+01, 0.92370400E+00, 0.58606800E+00, -.13856700E+01, -.14852100E+01, -.12960700E+00, -.22748900E+01, 0.42218100E+01, -.60058900E+00, 0.15728700E+01, -.90517800E+00, -.45387400E+00, -.18405700E+01, 0.38638600E+01, 0.77639700E+00, -.30380700E+01, 0.34653500E+00, 0.13904600E+01, 0.89618500E+00, 0.30871300E+00, -.33529100E+00, 0.28642100E-01, 0.95170000E+00, -.33012500E+00, 0.15387000E+01, -.55403100E+00, -.36531100E+00, 0.38585100E+01, 0.28102400E+00, -.27068100E+00, 0.23598200E+01, -.19776200E+01, 0.62278200E+00, -.10965900E+01, -.21101500E+00, -.19315000E+00, 0.75620200E+00, -.10306000E+01, 0.34714000E-01, -.13847100E+00, -.67139500E+00, -.51044100E+00, 0.64929000E+00, 0.52297700E+00, -.32775800E-01, 0.44693200E+00, 0.18041800E+00, -.20688700E+01, -.27235800E+00, 0.22153800E+00, 0.76764500E-01, -.35486800E+00, -.21636300E-01, -.63633800E+00, 0.17454300E+00, -.94689400E+00, -.43684400E-01, -.28885500E+00, 0.36184800E+00, 0.59807800E-01, -.14525200E+00, -.59361400E+00, -.36784700E+00, 0.21511200E+00, 0.60740400E+00, 0.21486800E+00, 0.89934800E-01, 0.13648900E+01, -.41605900E+00, 0.19157500E+00, -.57095700E-01, 0.91471800E-01, -.67597400E-01, 0.45195700E+00, 0.13441500E+00, -.12158500E+01, -.26640400E+00, 0.55471000E-01, -.12522800E+00, 0.25260700E-03, 0.28731000E-01, 0.39974900E+00, 0.16317200E+00, -.58565300E+00, 0.15329000E+00, -.40979700E+00, 0.64091100E-01, 0.19768200E-03, 0.58761600E-01, -.20616100E+00, -.42535700E+00, 0.24163900E+00, -.10746700E-01, -.18704300E+00, -.16984600E+00, -.13956900E-01, 0.53235200E+00, -.81453000E-01, -.18755300E+00, 0.42262500E-01, -.33799900E-01, 0.32862200E+00, -.41274600E-01, -.37387600E+00, -.88113700E-01, -.34970000E+00, 0.68487800E-01, -.27267800E+00, -.69217100E-01, -.14363700E+00, -.16077400E+00, 0.32822300E+00, -.10163100E+00, 0.38364100E-01, 0.34594700E-02, -.68665200E-03, 0.14339600E+00, 0.31039700E-01, -.24620900E+00, 0.14024800E+00, 0.36670200E+00, 0.12808400E+00, -.59627800E-02, -.57699300E-01, 0.16718600E-01, 0.15629300E+00, -.58872600E-01, -.63658100E-01, -.33040100E+00, -.15866400E+00, 0.94777100E-01, 0.78002000E-03, 0.34627300E-01, -.65077500E-01, 0.33775000E-01, -.69080100E-01, 0.82704600E-02, -.47299800E+00, -.27779300E-01, -.60597900E-01, -.12774000E+00, 0.22156400E+00, -.25715700E+00, -.58061300E-01, -.56315500E-01, -.53667900E+00, 0.30052200E-01, 0.20643800E+00, -.81886600E-02, 0.75836100E-02, 0.26079500E+00, 0.29819500E-01, -.19188100E+00, -.10358600E-01, -.15910900E+00, -.39932300E-02, 0.24478000E-01, 0.90078700E-01, 0.12528000E+00, -.44726600E+00, -.14544500E+00, 0.43061400E+00, 0.56680500E-01, 0.10824100E+00, 0.50594400E+00, 0.15657100E-01, 0.23585300E+00, 0.41178600E+00, 0.80651500E-01, -.21095600E-01, -.51746200E-02, 0.36267600E-01, -.91547400E-01, 0.11026700E+00, -.51642800E-01, 0.88102400E-01, -.81389400E-01, -.99398400E-01, 0.34743900E-02, 0.95152700E-01, -.26952600E-02, 0.88126300E-02, -.21929300E+00, 0.64626300E-01, 0.30484700E-01, -.18628000E+00, -.48154200E-01, -.34126800E-01, 0.79132900E-01, 0.18907400E-01, -.55279600E-01, 0.76014400E-01, -.75412900E-01, 0.26861500E+00, -.72606400E-01, 0.11963400E-01, -.72097600E+00, 0.72868400E+00, -.43106500E+00, 0.34617200E-01, -.28949000E-01, 0.41368800E+00, -.65233400E-02, 0.22632700E+00, -.58987800E+00, -.14220100E-03, 0.67054200E-02, -.16607600E-02, 0.80634000E-01, -.30317300E-02, -.37516300E-01, 0.33872400E-02, 0.20693500E+00, -.24265400E-01, -.51824700E-02, 0.17565900E-02, 0.13863600E-01, -.32586300E-02, 0.27042700E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.19113300E+02, -.10371000E+02, -.77151000E+01, 0.28037300E+02, 0.17130900E+01, -.27696000E+02, 0.29821200E+02, 0.92471600E+01, -.84457600E+01, 0.10059500E+02, 0.27621200E+01, 0.50908400E+00, 0.63449700E+01, 0.57527800E+01, 0.31437600E+01, -.76048500E+01, -.78245600E+01, 0.26306500E+00, -.15602700E+02, 0.16712700E+02, -.31715300E+01, 0.69844400E+01, -.36730800E+01, 0.52664000E+00, -.10445700E+02, 0.19039900E+02, 0.50230900E+01, -.16153700E+02, 0.31406400E+00, 0.73639600E+01, 0.45555500E+01, 0.15515500E+01, -.16162200E+01, -.18270900E+00, 0.68667500E+01, -.91072700E+00, 0.72156200E+01, 0.11912900E+02, -.31473500E+00, 0.22007800E+02, 0.21482400E+01, -.27127300E+01, 0.14010100E+02, -.13940800E+02, 0.35955000E+01, -.55635700E+01, -.97403600E+00, -.22098600E+01, 0.69895300E+01, -.50354500E+01, 0.28136300E+00, -.13395200E+00, -.87411000E+01, -.57594800E+01, 0.53037100E+01, 0.85999100E+00, -.12964900E+00, 0.12112500E+01, -.31728000E+01, -.11387400E+02, -.17322500E+00, 0.31027400E+01, 0.73370200E+00, -.42852500E+00, 0.10814800E+01, -.50383100E+01, 0.18967000E+00, -.26161300E+01, -.91685300E-01, -.84131500E+01, 0.40205700E+01, 0.52909900E+00, -.56905900E+01, -.11474700E+02, -.17128600E+01, 0.32789100E+00, 0.93862900E+00, -.26089400E+00, -.70012000E+00, 0.53596400E+01, -.23465500E+01, 0.44172600E+00, -.80418300E+00, 0.71816000E+00, 0.82300300E+00, 0.55196500E+01, 0.19807600E+01, 0.77094400E+01, 0.54169100E+00, 0.38420000E+00, -.44355900E+00, -.23518600E+00, -.23527500E-01, 0.25734900E+01, 0.78003400E+00, -.24749400E+01, 0.64661600E+00, 0.27495600E+00, -.18563200E+00, 0.24939500E+01, 0.15308900E+01, 0.37676900E+01, -.53354400E+01, 0.11603700E+01, 0.17155600E+01, -.19046100E+01, 0.47653200E+01, -.39619100E-01, 0.21334000E+01, -.13615400E+01, 0.25387200E+01, -.40960100E+00, -.16136000E+01, -.93423900E+00, 0.32722700E+00, 0.32002000E+01, 0.80267800E+00, -.35947100E+00, -.57171500E+00, 0.12285300E+01, 0.41707800E+00, -.49382500E+01, 0.17424500E+01, 0.21830000E+01, 0.29065700E+01, -.30140100E+01, -.12486800E+01, -.55603000E-01, -.10309900E+01, -.45669100E+00, 0.63773700E+00, -.70652000E+00, -.65953700E+00, 0.11549200E+01, -.70819500E+00, -.17090500E+00, 0.68172500E-01, -.11624000E+01, 0.10515500E+01, 0.83739000E+00, 0.11292100E+01, -.27599800E+00, 0.94173500E+00, 0.61180300E+00, 0.34957300E+00, -.17242500E+00, -.35335700E-01, -.10852700E+01, 0.21669100E+01, -.95022500E-01, -.15815100E+00, -.37011400E+00, 0.81297200E+00, -.60508400E+00, 0.29503700E+00, -.86641500E-01, -.20924400E+00, 0.21838800E+01, -.18264400E+00, 0.15690700E+00, -.20857300E+00, 0.17899100E+01, -.10841700E+01, 0.22815400E-02, 0.10714900E+01, 0.86740400E+00, 0.38783800E+00, -.29104700E+00, 0.21331300E+01, 0.11213200E+00, -.15468400E+00, -.16171600E+01, -.46481500E-01, 0.12695500E+01, 0.66324800E+00, 0.43834100E-01, 0.25017700E+00, 0.13188000E+00, 0.17775700E+00, 0.49333900E-01, 0.24390200E+00, 0.18629300E+00, -.20675500E+00, -.31885400E+01, 0.68266100E-02, -.55936400E-02, 0.14068900E+00, 0.42124900E+00, -.23244700E-01, 0.57607300E+00, -.33586800E+00, -.82748200E+00, -.12712400E+00, 0.25445400E+00, 0.67056700E-01, 0.38700000E+00, 0.37011700E-01, -.17221700E+01, 0.22754000E+00, -.26419400E+00, 0.36894600E+00, 0.93465000E+00, -.61001600E-01, 0.16599300E+00, -.47614100E-01, -.14592600E+01, -.12743100E+00, 0.37559800E+00, -.15568000E+01, 0.55892800E+00, -.54386100E+00, -.38475400E-01, 0.68118900E+00, 0.50614100E+00, 0.17622100E+01, 0.14034900E+01, -.55869100E+00, 0.11253900E+01, 0.21656500E+00, 0.67416100E+00, 0.60170400E-01, 0.41302100E+00, 0.16499900E+01, -.48889900E+00, 0.12257800E+01, 0.54825600E+01, 0.55409200E-01, -.36144300E-01, 0.96580000E+00, 0.66647200E+01, -.10283900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.40418400E+01, -.13628700E+01, -.12426100E+01, 0.71687700E+01, 0.43977500E-01, -.57326700E+01, 0.59213400E+01, 0.16517400E+01, -.23449300E+01, 0.18916000E+01, 0.61358300E+00, -.21040600E+00, 0.13749800E+01, -.34097600E+00, 0.10209900E+01, -.37472100E+01, -.27065500E+01, -.58230800E+00, -.29293200E+01, 0.26118200E+01, -.66958200E+00, 0.12031000E+01, -.92854400E+00, 0.31094900E+00, -.20834000E+01, 0.43555500E+01, 0.39954900E+00, -.41195800E+01, -.57693000E+00, 0.15663300E+01, 0.14570100E+01, -.74239800E-01, -.23387800E+00, 0.29144200E-01, 0.11079400E+01, -.62087900E+00, 0.17895000E+01, 0.27106800E+01, -.15577700E+00, 0.38921200E+01, 0.21936600E+00, -.85046400E+00, 0.33402800E+01, -.20142400E+01, 0.10529800E+01, -.11901100E+01, -.25017600E+00, -.52206400E+00, 0.10093700E+00, -.16256800E+01, -.41049800E-01, -.49772300E+00, -.26403000E+00, -.61340800E+00, 0.10291700E+01, 0.45681000E-01, -.17817200E-01, 0.82538100E+00, -.71091500E+00, -.15723200E+01, -.13413800E+00, 0.47865700E+00, 0.20566800E-01, -.43171200E-02, -.16892300E+00, -.65941900E+00, 0.51679700E+00, -.57236500E+00, 0.67417100E-01, -.59160300E+00, 0.16696700E+00, 0.49114000E+00, 0.84208000E+00, -.11093000E+00, -.89635000E+00, 0.23729300E+00, 0.92637600E+00, -.26350200E+00, -.58489400E-01, 0.14355800E+01, -.18294400E+00, -.94619600E-02, -.45307900E-01, 0.19032600E+00, -.18016200E-01, 0.68882500E+00, 0.15057600E+00, -.14358800E+01, -.20390400E+00, -.13529900E+00, -.12606000E-01, -.17538000E+00, 0.15118800E+00, 0.74977000E+00, 0.29572400E+00, -.17633400E-02, 0.88852400E-02, -.63999400E+00, 0.52570600E-01, 0.49777300E+00, -.11680400E+00, -.10194300E+01, -.73297600E+00, 0.62795100E+00, -.13861000E+00, -.66534400E-01, -.21757900E+00, 0.25489300E+00, 0.35762200E+00, 0.11374900E-01, -.22733400E+00, 0.25441100E+00, 0.28872700E-01, 0.43810500E+00, 0.21847300E-01, -.60754200E+00, -.25962500E+00, 0.27616000E+00, 0.96013000E-01, -.10102000E+00, -.11071400E+00, -.17636700E+00, -.14061400E-01, 0.24365100E+00, 0.11746900E+00, 0.12033700E+00, -.16146800E+00, -.30289800E-02, 0.14406100E+00, 0.18607800E+00, -.14164600E+00, 0.96572300E-01, 0.61436600E+00, 0.24508400E+00, 0.21677000E-01, 0.14688300E+00, -.36569300E-01, 0.23854500E+00, -.14476600E+00, 0.29641000E-01, -.17974400E+00, -.62237500E-01, -.15734800E-01, 0.10893000E-01, -.10332900E+00, 0.17918600E-01, 0.18614400E-01, -.47120300E-02, -.11319800E+00, -.20724600E+00, -.59102600E-01, -.72809200E-01, 0.17250600E+00, 0.10173000E+00, -.10266100E+00, -.10699000E-01, -.76002200E-01, -.57727600E+00, 0.77411100E-01, 0.16315700E+00, 0.79766200E-01, -.13258900E+00, 0.28374500E+00, 0.80219700E-02, -.16036200E+00, -.25899100E-01, -.41620700E+00, 0.66265300E-01, 0.43228400E+00, -.15736800E+00, -.84206300E-02, 0.41524400E-02, 0.24283400E+00, 0.60635100E+00, 0.43973400E+00, 0.27497300E-01, -.27854800E-01, 0.48004800E-02, -.14463100E+00, 0.10855300E+01, -.12165800E+00, -.99150200E-02, 0.54281900E-01, -.58650600E-02, -.17674100E+00, 0.31570600E-02, 0.42306000E-01, 0.38849100E+00, 0.14415300E-01, 0.25125400E-01, 0.31022000E-01, 0.10302100E+00, -.12666100E-01, 0.28116300E+00, 0.14115800E-01, 0.10526200E+00, 0.19598300E-01, -.95296800E-01, 0.15160900E+00, -.14969000E+00, -.56304200E-01, -.48006200E-01, -.55050600E-01, -.59689000E-01, -.97073500E-01, 0.18100300E+00, 0.59701400E-01, -.44351000E-01, -.91766500E+00, 0.97136300E+00, -.65088000E-01, 0.17489600E-01, -.55328600E-01, -.21250900E-01, -.25144300E-02, 0.89313200E-01, -.35239700E-01, -.89363900E-01, 0.53331700E-02, -.48098600E-02, -.17422200E-02, -.96104800E-02, 0.34856100E-01, -.46163900E-01, 0.19531800E-01, -.51588000E-03, -.43794700E+00, 0.31813200E-02, -.58818700E-02, -.60471600E-01, 0.95245000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23091100E+01, -.64628600E+00, -.92848800E+00, 0.24107800E+01, 0.11962100E+01, -.28249000E+01, 0.41558500E+01, 0.95623600E+00, -.19688300E+01, 0.13837400E+01, 0.43970200E+00, -.91080300E-01, 0.81805000E+00, 0.19933400E+01, 0.25178100E+00, -.12724100E+01, -.12287800E+01, 0.84369600E+00, -.18651900E+01, 0.21398000E+01, -.60742800E+00, 0.13089100E+01, 0.20300100E+00, 0.24561100E+00, -.15537600E+01, 0.34308700E+01, 0.78191600E+00, -.33487800E+01, -.12383000E+01, 0.12837100E+01, 0.13407000E+01, 0.72052700E+00, -.64187500E+00, -.12530800E+00, 0.21030700E+00, -.12876100E+01, -.23854600E+01, 0.42631000E+01, -.13868000E+01, 0.25656400E+01, 0.11137000E-01, 0.22304400E+01, -.32258400E+00, -.77841500E+00, 0.19073100E+01, -.77637700E+00, -.76375500E+00, -.30148800E+00, 0.71907600E-01, -.90230300E-01, -.35088600E-01, -.23661600E+00, 0.10214700E+00, -.41193900E+00, 0.37312500E+00, -.41863500E-01, -.45025700E-01, 0.31744900E+00, 0.32642500E+00, -.87075600E+00, -.57488300E-01, 0.36117900E+00, 0.31534600E-01, -.17698200E+00, 0.63263700E-01, -.12253100E+00, 0.16330100E+00, -.29780000E+00, -.16017000E-01, -.93540900E+00, 0.11272500E+00, 0.13846600E+00, 0.61157000E+00, -.19620000E+00, -.21967700E+00, -.13879300E-01, 0.30877900E+00, 0.15510300E+00, 0.10855100E+00, 0.92691700E+00, -.18275400E+00, -.36013100E-01, -.31286400E-01, -.38305800E-01, -.24169900E-01, 0.29340700E-02, 0.59681000E-02, -.94755000E-01, -.14350400E+00, -.50805700E-01, -.10164300E+00, -.13614300E-01, 0.31290800E-01, 0.43288300E+00, 0.79905200E-01, -.29621200E+00, 0.44359400E-01, -.18138100E+00, 0.31408800E-01, 0.10778600E+00, 0.64696900E-01, 0.38149700E+00, -.42163900E-02, 0.13516700E-01, 0.76832400E-01, -.13737700E+00, 0.71317400E-01, -.10707300E+00, 0.12303300E+00, -.21624000E-01, -.16179100E+00, -.30685400E-02, 0.17808700E+00, -.51362600E-03, 0.54931800E-01, -.21420000E+00, -.81856000E-01, -.76235100E-01, 0.18364400E-01, -.77518600E-02, 0.35740600E-02, -.36974600E-01, -.47418300E-01, -.71644000E-02, 0.96845400E-02, -.31444700E-01, 0.10327200E+00, 0.55296800E-02, -.43095400E-01, 0.11288200E-01, 0.11663000E+00, 0.14880800E-01, -.25135400E+00, -.95359900E-01, 0.49374100E-01, 0.40227700E-01, -.53802900E-01, 0.40899400E+00, 0.13709000E+00, -.21050400E+00, -.42021600E+00, -.39967700E+00, 0.65737400E-01, 0.82247200E-01, 0.41242000E-01, 0.52922200E-02, -.21523600E-01, 0.85749500E-01, -.23744600E-01, -.91498100E-01, 0.20868400E-01, -.30282600E-01, 0.35171500E-01, -.40595600E-01, -.62922300E-01, 0.32631800E-01, -.36761700E-02, -.52366800E-01, -.58316200E-02, 0.23670200E+00, 0.98371200E-01, -.84101000E-01, 0.75203200E-01, 0.20156700E-01, -.10964000E+00, -.13648100E+00, -.53687500E+00, 0.47413500E-01, 0.17832200E+00, -.14076600E+00, -.45244800E-01, -.28727900E+00, 0.20606200E+00, 0.14132200E+00, 0.22797700E+00, -.39392500E-02, 0.19601900E+00, -.11513900E+00, 0.65348100E-01, 0.31598600E+00, -.22494100E-01, 0.21498000E-01, 0.66796700E-01, -.14958800E+00, -.16027300E+00, -.36998900E-01, 0.42637600E-01, 0.42703200E+00, -.54007900E-02, 0.58734200E-01, -.21162700E-01, -.57301100E-01, 0.13731300E-01, 0.40942500E-01, -.24976000E-01, 0.36683100E-02, 0.38284000E-01, -.12098600E-02, -.55247100E-01, 0.43706500E-01, -.90135700E-01, -.52139500E-01, -.18365900E-01, -.45031600E-01, -.63438500E-02, -.15576900E-01, 0.10788300E-01, -.87290700E-01, 0.27870800E+00, -.50270200E-01, 0.61906900E-01, -.44462600E-01, -.37218100E-01, 0.22888900E-02, -.40244300E-01, -.11043100E-01, -.22401900E-02, -.76210300E-03, -.62797000E-02, -.46513600E-02, 0.57619000E-01, 0.99113800E-02, 0.23839700E-01, -.44601800E-01, 0.74951100E-02, -.15336100E-02, -.10805300E-01, 0.21084600E+00, -.10870600E-01, -.11667800E-01, 0.22890400E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.27289600E+01, -.46430300E+00, -.54615800E+00, 0.47843600E+01, -.31269300E+00, -.36020400E+01, 0.30033500E+01, 0.10219300E+01, -.11093900E+01, 0.12761300E+01, 0.13980600E+00, -.44889400E+00, 0.68950100E+00, -.27951500E+00, 0.21342900E-01, -.21525400E+01, -.16636700E+01, -.30465000E+00, -.12915600E+01, 0.99640200E+00, -.21794500E+00, 0.50046400E+00, -.96075900E+00, -.64816900E-01, -.85369600E+00, 0.23056300E+01, 0.50569400E+00, -.23188200E+01, -.69426300E+00, 0.70310600E+00, 0.73907800E+00, 0.55157600E+00, -.46647100E-01, -.13891200E+00, 0.84117600E+00, -.21589700E+00, 0.52572300E+00, 0.10111200E+01, -.44544200E+00, 0.16542400E+01, -.50355000E-01, 0.29600300E+00, 0.83292900E+00, -.12214500E+01, 0.55822800E+00, -.48028800E+00, -.24169500E+00, -.32637000E+00, 0.53014000E+00, -.10335900E+01, -.77862700E-01, 0.47180000E+00, -.46836800E+00, -.50499100E-01, 0.21570700E+00, 0.26021100E-01, -.50750200E-02, -.14355100E-02, -.68356100E+00, -.15041800E+00, 0.11531300E+00, 0.59962200E+00, 0.84170700E-01, 0.21759900E-01, -.10541000E+00, -.20088200E+00, 0.18238700E+00, -.19704100E-01, 0.85834100E-01, 0.20499900E+00, 0.72160000E-01, 0.42622700E-01, 0.71335000E+00, 0.29262700E+00, -.21346300E+00, 0.75484300E-01, 0.47188900E+00, 0.18708200E+00, -.20974000E+00, 0.15191900E+01, 0.10621500E+00, -.49875200E+00, 0.30025700E-01, 0.34679600E+00, -.13072100E-02, 0.13810800E+00, 0.10350000E-01, -.45645800E+00, 0.26555900E-01, -.14109100E+00, -.21461800E+00, 0.52408400E-01, 0.70187100E-01, -.27810500E-01, -.11405200E+00, 0.49527100E-01, -.43653900E-01, -.71831800E-01, 0.57219900E-01, -.15399800E+00, -.18331700E-01, -.12462500E+01, -.62403100E-01, -.28043000E-01, -.25512300E+00, 0.20482900E+00, -.15351200E+00, -.13025200E+00, -.33000400E+00, 0.61668600E-02, 0.10984500E+00, 0.19709400E+00, 0.22773800E+00, 0.16590700E+00, -.42406600E-01, -.29755600E+00, -.11177400E+00, 0.35173900E+00, 0.90279100E-01, 0.36946600E-01, -.26483800E+00, -.13527900E+00, 0.10255800E+00, -.34113200E+00, -.51358000E-01, 0.53393800E-01, -.38848500E+00, 0.10193700E-01, -.13026600E+00, -.11462200E-01, 0.15321000E+00, -.48775000E-01, 0.11423700E+00, 0.13773500E+00, 0.24687300E+00, -.49992100E-01, -.25026000E-01, -.14641800E+00, 0.17680300E+00, -.14342900E+00, -.59408200E-01, -.38486200E+00, 0.24080400E+00, 0.18379300E+00, 0.14828200E+00, 0.35782600E-01, -.29790000E-01, -.28144000E+00, -.13550500E+00, -.16213500E-01, -.83346800E-01, 0.51167600E-01, -.43414000E-01, -.65046600E-01, -.82515100E-01, 0.68151700E-01, 0.55592200E-01, -.34914200E-01, 0.95819500E-02, -.57151300E-03, -.97308500E-01, -.23408900E-02, -.51263300E-01, -.76161800E-02, 0.36020200E+00, 0.56476400E-01, -.32448500E-01, 0.59684800E-01, 0.20245700E+00, 0.57468100E-01, 0.36891600E-02, 0.25227200E+00, 0.11856600E+00, 0.12489500E+00, 0.12905400E+00, -.22886400E-01, -.23371600E+00, 0.92484800E-02, 0.88305700E-01, 0.16360500E+00, -.70403100E-01, -.40648800E-02, -.21731700E-01, 0.49484300E-01, -.19849700E+00, -.12704700E+00, -.43466000E-01, 0.19447000E+00, 0.11288600E-01, 0.17039800E+00, -.29542600E-01, -.18870300E+00, 0.29201600E-01, -.44999000E-02, 0.24235900E+00, 0.30370600E-01, -.41777000E-01, -.10441000E+00, 0.46807400E-01, -.56458300E-01, -.94924400E-02, 0.24643000E-03, -.30795100E-01, -.32805500E-01, -.15367900E-01, -.13962200E-01, 0.31950200E-01, -.57858600E-01, -.57574700E+00, 0.28557800E+00, 0.13977100E+00, -.22666000E-02, 0.92201300E-01, -.88371200E-01, 0.35876300E-01, -.11076000E+00, 0.12132100E+00, 0.37034000E+00, 0.70049700E-02, 0.38996200E-02, -.14293900E-01, -.40248800E-01, -.28375000E+00, 0.21069700E+00, 0.16774300E-01, -.14905800E-01, 0.24439900E-01, 0.12682000E-01, -.28577900E+00, 0.72577900E-01, -.42928000E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.16528600E+02, 0.10960300E+02, 0.72171600E+01, -.23318300E+02, -.53400700E+00, 0.22143300E+02, -.22278900E+02, -.72729300E+01, 0.72105900E+01, -.81934000E+01, -.16717800E+01, 0.16357800E+00, -.53234000E+01, -.56256800E+01, 0.51150600E+00, 0.93905000E+01, 0.77179800E+01, -.17138500E+01, 0.99916900E+01, -.15097100E+02, 0.28278200E+01, -.60287300E+01, 0.19483600E+01, -.79901100E+00, 0.10323400E+02, -.12737300E+02, -.42771700E+01, 0.10655100E+02, -.55565500E+01, -.51320400E+01, -.20799700E+01, -.46441400E+00, 0.19789100E+01, 0.90355900E+00, -.30961200E+01, -.21035700E+00, -.56848700E+01, -.12113200E+02, 0.79597300E+00, -.16017700E+02, -.12114300E+01, 0.15949000E+01, -.99983200E+01, 0.13225700E+02, -.13163300E+01, 0.43131300E+01, 0.65804300E+00, 0.15432600E+01, -.40691500E+01, 0.89891300E+01, -.12542700E+00, 0.59044200E-02, 0.53787500E+01, 0.29821200E+01, -.49269500E+01, -.51191800E+00, 0.51487000E+00, -.12392400E+01, 0.22735400E+01, 0.97934500E+01, 0.82838000E+00, -.17409100E+01, 0.18237400E+00, -.49770400E+00, -.29377400E+00, 0.33390800E+01, -.11436500E+01, 0.52157900E+01, -.61033700E+00, 0.45915600E+01, -.41940900E+01, 0.90304800E-01, -.24395200E+01, 0.75670600E+01, 0.97620500E+00, 0.81849200E+00, -.16172000E+01, 0.14962900E+01, 0.52888300E+00, 0.31492500E+01, 0.12979800E+01, -.20245100E+01, 0.71861400E+00, 0.72452900E+00, -.45280600E+00, -.70554300E+00, -.18379400E+01, -.59518400E+01, 0.49629700E-01, -.21085300E+01, -.14143200E+01, 0.89655100E+00, -.19623400E+00, -.30012600E+01, 0.66959100E+00, 0.29610800E+01, 0.69354200E-01, 0.39611100E+01, -.50676800E+00, -.24042700E+00, -.21776800E+00, -.52757800E+01, 0.31755100E+01, -.54404600E+00, -.14377200E+01, 0.21422800E+01, -.16903200E+01, 0.12567400E+01, -.17726400E+01, 0.58504700E+00, -.35396400E+00, -.96689700E+00, -.19011500E+00, -.34393800E+00, -.50146500E+00, -.22294100E+01, 0.12364300E+00, 0.51756700E+00, 0.30390200E+00, -.81563900E+00, 0.51324000E+00, 0.29777000E+01, -.14615100E+01, -.62384700E-01, -.13204000E+01, 0.20536300E+01, 0.62333900E+00, -.30206100E-01, -.42866900E+00, -.10032900E-01, -.10301400E+01, -.10620000E+00, 0.51269800E-01, 0.36633800E+00, 0.38906000E+00, -.79054300E+00, -.20385100E+00, -.15418000E+01, -.51110000E+00, 0.75814700E+00, -.57709000E+00, 0.41240700E+00, 0.91590900E+00, 0.13174300E+01, -.72256800E+00, 0.11021100E+00, 0.25632900E+00, -.13773500E+01, 0.80951900E+00, -.12682500E+01, -.38420200E+00, -.11683900E+00, -.13243000E+01, 0.43090600E+00, 0.67288500E+00, 0.16842100E+00, -.13248400E+00, -.13631100E+01, 0.40466600E+00, -.10238200E+00, -.43910400E+00, 0.14689800E+01, -.12026600E+01, 0.64397100E+00, 0.14480600E+01, -.14848900E+01, -.55572400E+00, -.14231600E-01, 0.44589600E-01, -.74353800E+00, 0.25684800E+00, 0.70215300E+00, -.59565000E+00, 0.14001800E+01, -.19461000E+00, 0.63615000E+00, 0.14530200E+01, 0.16470900E+00, 0.22839000E+00, 0.39255600E+01, -.26504000E+00, -.20407900E+00, 0.12076100E+00, 0.16214500E+01, -.17863800E+01, 0.18579800E+00, 0.14111200E+00, 0.10616400E+01, -.52209500E+00, -.12256500E+01, 0.50131500E+00, 0.20762500E+01, -.22724600E+00, 0.18493000E+01, -.21503300E+01, 0.34526800E+00, -.53906400E-01, -.11965500E+00, 0.11940800E+01, -.86188900E+00, 0.72351800E+00, 0.80894500E-01, 0.12938600E+00, -.13010400E+00, -.27404800E+00, 0.25006700E+01, 0.11933000E+00, 0.15763000E+01, -.66605700E+01, 0.24914100E+01, -.11634900E+01, 0.10210000E+00, 0.99770200E+00, 0.19814900E+01, 0.19715000E+01, -.85653200E+00, 0.29866700E+00, 0.59840800E+01, 0.24745600E+00, 0.11611000E+01, -.72843100E+00, -.30759000E-02, 0.57680500E-01, 0.33287900E+00, -.21090900E+00, -.47254800E+00, -.20845900E+00, -.17322900E+00, -.15524500E+01, 0.30593500E+01, -.48982000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25472300E+01, 0.30632600E+01, 0.16651700E+01, -.59961400E+01, -.12518500E+00, 0.44569500E+01, -.50482900E+01, -.11889500E+01, 0.14182100E+01, -.19982100E+01, -.12138600E+00, 0.11402300E+01, -.78403600E+00, 0.15523300E+01, -.33676200E+00, 0.39512800E+01, 0.24470200E+01, 0.10011200E+01, 0.38178800E+01, -.14389000E+01, 0.50812300E+00, -.99688100E+00, 0.17102100E+01, -.47861500E+00, 0.99006200E+00, -.28872500E+01, -.68244700E+00, 0.36692000E+01, -.39048000E+00, -.96174900E+00, -.14465300E+01, 0.61650200E+00, -.44338100E+00, -.19430900E+00, -.70554100E+00, 0.60268900E+00, -.25225100E+01, 0.28641900E+01, 0.35218500E+00, -.36085700E+01, -.11713300E+00, 0.29075800E+00, -.19231100E+01, 0.76000200E+00, -.14458300E+01, 0.92092900E+00, 0.15782200E+00, 0.11330000E+00, -.92051900E+00, 0.70271100E+00, -.52240000E-01, 0.40242400E-01, 0.84495400E+00, 0.53661500E+00, 0.15480600E-01, -.33060100E+00, 0.40859300E-01, -.20630600E+00, 0.57660500E+00, 0.16379600E+01, 0.19946200E+00, -.29264500E+00, 0.35696400E-01, -.12202700E+00, 0.11316800E+00, 0.57268100E+00, -.43007400E+00, 0.79257400E+00, -.15878300E+00, -.13629700E+01, -.36486200E+00, -.28032400E+00, 0.12742500E+00, 0.17342300E+00, 0.37739100E+00, -.23146400E+00, -.55482200E+00, 0.30579500E+00, -.17303100E+00, -.13517000E+01, 0.16120500E+00, -.81401700E-01, 0.68120500E-01, -.14517400E+00, 0.48028800E-01, -.10091800E+01, -.22827800E+00, 0.26475300E+01, 0.37029600E+00, 0.37184700E-01, 0.19356800E+00, -.12341000E-01, -.17575000E-01, -.31513800E+00, -.21978100E+00, 0.24604100E+00, -.20876600E-01, 0.30444900E+00, -.10468100E+00, 0.79026900E+00, -.50143400E+00, 0.13073100E+01, 0.10377900E+01, -.21996800E+00, 0.98668200E-01, 0.33347000E-01, -.42992800E-01, 0.13288200E+00, 0.58206700E+00, 0.35999700E+00, -.13487600E-01, 0.49067300E-01, -.25213500E+00, -.24856900E+00, -.72655900E-01, 0.33844500E+00, 0.94018800E-01, -.16201600E-01, -.63723100E-01, 0.69511200E-01, 0.19082300E+00, -.22882300E+00, 0.98214300E-02, 0.16381100E+00, 0.29785200E+00, -.16116500E+00, 0.36362300E+00, 0.14685600E-01, -.21297500E+00, -.69629600E-01, -.10176000E+00, -.26266800E+00, -.43290000E+00, 0.15324700E-01, -.65697400E-01, 0.92975900E-01, 0.12980200E-01, -.25059600E+00, 0.11116700E+00, 0.22577200E+00, 0.31503500E+00, 0.17645900E+00, -.47956200E-01, -.11293000E+00, 0.93081400E-01, -.82544300E-01, 0.13059000E-02, 0.24297000E-01, 0.12287200E+00, -.40209200E-01, 0.31753100E-01, -.13042100E-01, 0.13704400E+00, -.25970900E+00, 0.22541200E+00, 0.77481200E-01, 0.48930100E-01, 0.57251300E+00, 0.13636700E-01, -.68645400E-01, 0.27256000E-01, 0.24884100E+00, -.33298100E+00, 0.12697900E-01, 0.11834200E+00, 0.57979700E-01, 0.36985400E+00, -.24948000E-01, 0.13544000E+00, -.36291600E-01, -.58391400E-01, 0.15188100E+00, -.63545500E-01, -.32822400E+00, -.15368000E+00, -.10607600E+00, -.40088700E+00, 0.18341200E-01, -.72021300E-01, -.30679400E+00, 0.78519200E-01, 0.35282900E-02, -.44594400E-01, -.29642300E+00, 0.16782200E-01, -.18969600E-01, 0.71079000E-01, -.41346200E-01, 0.12943300E-01, -.23925900E-01, -.48620100E-01, -.40125300E-01, 0.25845500E-03, -.11504700E+00, -.42234700E-01, -.10172500E+00, 0.90451200E-02, 0.19384600E+00, -.41832600E-02, 0.50779800E-01, 0.41987800E-01, -.59567100E-01, 0.69210700E-01, 0.85195500E-02, 0.85990300E-01, -.18506200E+00, 0.31136600E-01, 0.37583000E-01, 0.17822200E+01, -.70492900E+00, -.27532600E+00, 0.34464100E-01, -.10877400E+01, -.26728900E-02, 0.95733600E-02, -.25883600E-01, 0.10079000E-01, 0.70686200E-02, 0.93196800E-02, -.12178000E-01, 0.78454200E-01, -.15580800E-01, -.83791500E-01, -.43977600E-01, 0.18109400E-01, -.30986400E-02, -.54079600E-01, -.87022900E-02, 0.39357300E-02, -.38666400E-02, 0.24663200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
        },
        {
            { -.73739700E+06, 0.35503200E+06, 0.35109400E+06, -.13464600E+06, -.77545200E+05, 0.37457100E+06, 0.36134300E+06, 0.61119800E+06, -.27222400E+05, 0.59179800E+06, -.29408600E+06, -.27454300E+06, 0.22973400E+06, 0.16745600E+06, -.40938200E+06, -.53404500E+06, -.80587200E+06, 0.10074700E+06, -.73458700E+06, 0.34081300E+06, 0.36029000E+06, -.23625000E+06, -.19270100E+06, 0.45721800E+06, 0.52443900E+06, 0.78219600E+06, -.11591800E+06, -.82259600E+06, 0.38256300E+06, 0.39104100E+06, -.22190500E+06, -.16915200E+06, 0.46726200E+06, 0.47124000E+06, 0.81833100E+06, -.97372500E+05, 0.94892400E+06, -.46207600E+06, -.45874000E+06, 0.10915500E+06, 0.33728100E+05, -.41200000E+06, -.31459100E+06, -.53910100E+06, -.28508100E+05, 0.16077600E+06, -.75762900E+05, -.76565100E+05, 0.34226100E+05, 0.24853300E+05, -.85480100E+05, -.86429900E+05, -.13931500E+06, 0.11697100E+05, 0.67047400E+06, -.33025500E+06, -.32399600E+06, 0.80638100E+05, 0.17640700E+05, -.29184500E+06, -.22457100E+06, -.32472400E+06, -.21950200E+05, -.42581200E+06, 0.20097700E+06, 0.20018800E+06, -.10449900E+06, -.11607300E+06, 0.25462400E+06, 0.27393200E+06, 0.48691800E+06, -.64556700E+05, 0.63424400E+06, -.29892600E+06, -.30749500E+06, 0.88365100E+05, 0.51106200E+04, -.28085900E+06, -.23079700E+06, -.28830300E+06, -.16289100E+05, 0.53693300E+06, -.24816900E+06, -.26343600E+06, 0.19206000E+06, 0.15903600E+06, -.33778100E+06, -.36322000E+06, -.64151500E+06, 0.10741000E+06, -.71264500E+06, 0.34589900E+06, 0.33575200E+06, -.66861000E+05, 0.25247900E+04, 0.28972600E+06, 0.19203400E+06, 0.32428100E+06, 0.32268600E+05, 0.13961600E+06, -.68906100E+05, -.58795500E+05, 0.46555200E+05, 0.83732900E+05, -.10806800E+06, -.13056400E+06, -.29956400E+06, 0.60054300E+05, -.66491800E+06, 0.32211700E+06, 0.30948200E+06, -.11093000E+06, -.79897400E+05, 0.30959800E+06, 0.22146100E+06, 0.71931700E+06, -.38101500E+05, -.57080200E+06, 0.28009800E+06, 0.26553100E+06, -.15736300E+06, -.10480000E+06, 0.33363900E+06, 0.36246700E+06, 0.61325900E+06, -.55080200E+05, -.90533600E+06, 0.43949200E+06, 0.44009200E+06, -.21311200E+06, -.14918600E+06, 0.49623100E+06, 0.50261700E+06, 0.77510800E+06, -.71958300E+05, -.42485100E+06, 0.19898500E+06, 0.21046200E+06, -.84396100E+05, -.38010900E+05, 0.21275800E+06, 0.20830900E+06, 0.27089600E+06, -.23168300E+04, 0.15941000E+06, -.70966400E+05, -.77698300E+05, 0.83064300E+05, 0.68120200E+05, -.11440800E+06, -.13539300E+06, -.28193500E+06, 0.53576000E+05, -.59052700E+06, 0.29090800E+06, 0.28637500E+06, -.26144900E+06, -.19184700E+06, 0.43052100E+06, 0.57432000E+06, 0.83981900E+06, -.13949700E+06, -.75735000E+06, 0.35934600E+06, 0.36240500E+06, -.16691200E+06, -.13008600E+06, 0.40909900E+06, 0.41497900E+06, 0.69151400E+06, -.63099400E+05, -.17732100E+06, 0.79471700E+05, 0.88976700E+05, -.31549700E+05, -.33031600E+05, 0.81903900E+05, 0.52556400E+05, 0.24667900E+06, -.10962100E+05, 0.20824800E+06, -.10039000E+06, -.98183500E+05, 0.26146300E+05, 0.48382000E+04, -.94912400E+05, -.83667700E+05, -.10221500E+06, -.80515400E+04, -.24012400E+06, -.14980900E+06, -.14353400E+06, 0.10679100E+06, -.17060800E+06, -.42482000E+05, 0.51652100E+05, -.80783300E+04, -.12767100E+06, -.11597200E+06, -.15487100E+06, -.18043600E+06, -.20440900E+06, 0.33664000E+06, -.11838700E+06, -.31913300E+04, -.49800700E+05, 0.21585900E+06, -.19539200E+06, -.23924200E+05, -.39386200E+06, -.10993900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11050100E+00, -.23731800E+05, 0.27062500E+04, -.36603500E+05, -.59492800E+05, 0.30321100E+05, 0.47305400E+05, 0.72648500E+05, -.37096600E+05, -.99404600E+05, 0.51720300E+05, 0.44306300E+05, 0.54715500E+05, 0.70405000E+05, -.13315200E+05, -.73182100E+05, -.80540900E+05, 0.54844300E+05, -.89461300E+05, -.77726800E+04, 0.48013000E+05, -.64198200E+05, -.11329800E+06, 0.75656900E+05, 0.69478100E+05, 0.13517500E+06, -.62678700E+05, -.81794300E+05, -.15381500E+05, 0.46166200E+05, -.67306700E+05, -.11746700E+06, 0.72319900E+05, 0.67570700E+05, 0.13662400E+06, -.66188800E+05, 0.12400300E+06, -.39933100E+05, -.64306200E+05, 0.33522400E+05, 0.60081400E+05, -.64566100E+05, -.43527900E+05, -.89991500E+05, 0.24152600E+05, 0.16025100E+05, 0.88125900E+03, -.89707300E+04, 0.10486600E+05, 0.18729200E+05, -.12878400E+05, -.11321500E+05, -.22492200E+05, 0.10170600E+05, 0.11503300E+06, -.49814000E+05, -.59315600E+05, 0.18571300E+05, 0.32067200E+05, -.50492000E+05, -.29537700E+05, -.59098700E+05, 0.73749900E+04, -.42015200E+05, -.49498900E+04, 0.24284000E+05, -.38765600E+05, -.74282000E+05, 0.43480800E+05, 0.41643400E+05, 0.85692800E+05, -.43611100E+05, 0.15111700E+06, -.37236700E+05, -.76595000E+05, 0.24366200E+05, 0.49708500E+05, -.59530000E+05, -.90967600E+04, -.64569200E+05, 0.14515100E+05, 0.65086200E+05, 0.32172000E+04, -.35258100E+05, 0.51523400E+05, 0.93955700E+05, -.58636200E+05, -.58939200E+05, -.11389100E+06, 0.53255200E+05, -.14488000E+06, 0.50916200E+05, 0.75262800E+05, -.24694800E+05, -.50469600E+05, 0.60399500E+05, 0.15610400E+05, 0.71092100E+05, -.16367900E+05, -.16976200E+05, 0.10392400E+05, 0.56248800E+04, 0.21041000E+05, 0.46011000E+05, -.14419100E+05, -.25717900E+05, -.48325900E+05, 0.32248600E+05, 0.11475100E+06, -.79864300E+05, -.50321500E+05, -.51873400E+05, -.83516800E+05, 0.14508900E+04, 0.47817000E+05, 0.78004400E+05, -.65313500E+05, 0.61231700E+05, -.40315600E+05, -.26114200E+05, -.40723800E+05, -.56308400E+05, 0.12365800E+05, 0.46662600E+05, 0.62591100E+05, -.42306900E+05, -.61160600E+05, 0.87866900E+04, 0.33473400E+05, -.48998000E+05, -.79790900E+05, 0.60561200E+05, 0.73263300E+05, 0.11324900E+06, -.44151700E+05, -.70388200E+05, 0.10001100E+05, 0.35825900E+05, -.20813200E+05, -.34546100E+05, 0.36347800E+05, 0.22259300E+05, 0.47717000E+05, -.14019600E+05, -.15890400E+05, 0.22437700E+05, 0.70878900E+04, 0.22889000E+05, 0.37271800E+05, -.11522900E+05, -.23705800E+05, -.40032800E+05, 0.25785600E+05, 0.74789100E+05, -.45228400E+05, -.32448800E+05, -.58760200E+05, -.84070400E+05, 0.23133400E+05, 0.72677600E+05, 0.93680800E+05, -.59815300E+05, -.73647900E+05, 0.67575100E+03, 0.40851000E+05, -.50877700E+05, -.93145500E+05, 0.62611300E+05, 0.57473000E+05, 0.11337900E+06, -.51784200E+05, 0.47605000E+05, -.45068700E+05, -.21560000E+05, -.21995700E+05, -.36498700E+05, 0.17323200E+02, 0.18079500E+05, 0.31475700E+05, -.28630600E+05, 0.43207100E+05, -.12683100E+05, -.22503800E+05, 0.80564300E+04, 0.14290600E+05, -.18489100E+05, -.75680400E+04, -.20456300E+05, 0.39368300E+04, -.25809100E+05, -.65644700E+05, -.59780400E+05, 0.52806800E+04, -.26005800E+05, -.47674100E+05, 0.86789800E+04, 0.58381600E+05, 0.23781500E+04, -.57637400E+05, -.10672700E+04, -.58148700E+05, -.10890300E+05, 0.77228600E+05, -.65986100E+05, 0.55037400E+05, 0.13910100E+05, 0.27770500E+05, -.48958200E+05, -.14071100E+05, -.77513500E+05, 0.31685500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12869300E+00, -.22613800E+00, -.14019700E+05, -.69592400E+04, -.18837100E+05, 0.16215000E+05, 0.48015900E+05, 0.71161100E+05, -.21373200E+05, -.52415000E+05, 0.26228600E+05, 0.50527600E+05, 0.10065900E+05, 0.30104100E+05, -.55082200E+04, -.61522700E+05, -.88665500E+05, 0.32113700E+05, 0.34658600E+05, -.16715500E+05, -.32192800E+05, -.15302600E+05, -.36195100E+05, 0.15785900E+05, 0.65715300E+05, 0.85684100E+05, -.39179800E+05, 0.25007400E+05, -.11946900E+05, -.35947200E+05, -.10647900E+05, -.32413000E+05, 0.16938000E+05, 0.60001500E+05, 0.90954600E+05, -.35874700E+05, 0.44091700E+05, -.22101600E+05, -.10322300E+05, 0.13415600E+04, 0.10786200E+05, -.25556400E+05, -.36730800E+05, -.58325900E+05, 0.11409300E+05, 0.40391400E+04, -.20913600E+04, 0.24751200E+04, 0.79373800E+03, 0.40675300E+04, -.45943700E+04, -.10342500E+05, -.16146000E+05, 0.44610500E+04, 0.43375000E+05, -.21602300E+05, -.13385400E+05, 0.83756500E+03, 0.53185700E+04, -.22413600E+05, -.23297800E+05, -.32871600E+05, 0.66228100E+04, 0.57619300E+04, -.23701200E+04, -.17953200E+05, -.54894100E+04, -.21366100E+05, 0.13315100E+05, 0.40325100E+05, 0.61988700E+05, -.20114200E+05, 0.60489900E+05, -.30750000E+05, -.25229600E+05, 0.17127400E+04, 0.47116500E+03, -.26126600E+05, -.19091400E+05, -.29311500E+05, 0.38866700E+04, -.49442300E+05, 0.24682600E+05, 0.36608400E+05, 0.14603100E+05, 0.33511100E+05, -.72675400E+04, -.49346900E+05, -.70528600E+05, 0.37672400E+05, -.67867300E+05, 0.34162200E+05, 0.20577700E+05, 0.24048400E+04, -.20483400E+03, 0.26941500E+05, 0.16991500E+05, 0.36443300E+05, -.25402400E+04, -.85800600E+04, 0.42682600E+04, 0.17131800E+05, 0.23308900E+04, 0.16025400E+05, -.66528500E+04, -.25703900E+05, -.45255600E+05, 0.14443700E+05, 0.62242400E+05, -.30684600E+05, -.62582800E+05, -.17835400E+04, -.23662400E+05, -.54065100E+04, 0.44158500E+05, 0.85724300E+05, -.28199700E+05, 0.33095500E+05, -.16445000E+05, -.37587700E+05, -.70896100E+04, -.22957400E+05, 0.67024800E+04, 0.44659000E+05, 0.67381100E+05, -.24062500E+05, 0.25614300E+05, -.12829200E+05, -.26284100E+05, -.15640700E+05, -.35975600E+05, 0.20946300E+05, 0.66459400E+05, 0.84831200E+05, -.38942200E+05, -.83529200E+04, 0.43280300E+04, 0.10712300E+04, -.43599500E+04, -.71510600E+04, 0.10211500E+05, 0.20223800E+05, 0.24415800E+05, -.75434700E+04, -.40613600E+05, 0.20380900E+05, 0.24724300E+05, 0.60661600E+04, 0.13660400E+05, 0.58540200E+04, -.19855500E+05, -.30701500E+05, 0.17058900E+05, 0.51221900E+05, -.25507200E+05, -.46963600E+05, -.13958900E+05, -.32440300E+05, 0.10056100E+05, 0.67637800E+05, 0.92451200E+05, -.39860500E+05, -.67009800E+04, 0.35637000E+04, -.15659300E+05, -.61248700E+04, -.23965500E+05, 0.20055100E+05, 0.52506400E+05, 0.80983400E+05, -.24848200E+05, 0.43688000E+05, -.21367500E+05, -.31280400E+05, -.89602700E+03, -.10822400E+05, -.89438800E+04, 0.14783100E+05, 0.27705900E+05, -.10859900E+05, 0.22849000E+05, -.11645000E+05, -.72525400E+04, -.46455100E+03, -.37538300E+03, -.93422400E+04, -.65826700E+04, -.10933400E+05, -.99370500E+02, -.31222100E+04, -.10381300E+05, -.79042100E+04, 0.17257700E+05, -.28271600E+05, -.17306500E+05, -.44390500E+04, 0.17035200E+05, 0.29056900E+03, -.28646200E+05, -.31601500E+05, -.36418300E+05, -.30224500E+04, 0.39672000E+05, -.73250900E+04, -.38602600E+04, -.14394900E+04, 0.36784400E+05, -.13229900E+05, 0.56744800E+04, -.46518700E+05, 0.27445300E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.58003500E-03, 0.94936200E-01, -.51577900E+00, -.26055400E+05, -.21765000E+05, 0.24251900E+05, 0.59139600E+05, 0.56307200E+05, -.22454000E+05, -.25373100E+05, 0.12770700E+05, 0.11801500E+05, 0.39109900E+05, 0.36129400E+05, -.27354100E+05, -.82447600E+05, -.77035600E+05, 0.33468500E+05, 0.45081400E+04, -.29898100E+04, -.25994700E+04, -.37309500E+05, -.33791900E+05, 0.32872700E+05, 0.80093500E+05, 0.75503900E+05, -.32549500E+05, 0.21535600E+05, -.11383400E+05, -.91052400E+04, -.38776800E+05, -.35251400E+05, 0.27819100E+05, 0.78564200E+05, 0.73556100E+05, -.35950700E+05, 0.38068500E+05, -.18821500E+05, -.19454500E+05, 0.21313300E+05, 0.13578600E+05, -.31811100E+05, -.51969500E+05, -.50582600E+05, 0.12288800E+05, 0.19894900E+04, -.88103300E+03, -.10773200E+04, 0.60752300E+04, 0.51080700E+04, -.61375800E+04, -.13467500E+05, -.13039600E+05, 0.50636100E+04, 0.45837200E+05, -.22890500E+05, -.24076400E+05, 0.13963600E+05, 0.55211200E+04, -.27440600E+05, -.35149900E+05, -.33236900E+05, 0.48971500E+04, 0.23419100E+05, -.12581600E+05, -.11090100E+05, -.20145100E+05, -.23141600E+05, 0.12128100E+05, 0.43699000E+05, 0.41797800E+05, -.22199200E+05, 0.63926700E+05, -.31005000E+05, -.32911600E+05, 0.13610900E+05, 0.69408800E+03, -.31922800E+05, -.32304600E+05, -.32883800E+05, 0.24154700E+04, -.29654300E+05, 0.14432500E+05, 0.14687000E+05, 0.31542400E+05, 0.30259300E+05, -.18601100E+05, -.61830100E+05, -.58055900E+05, 0.31781600E+05, -.46008200E+05, 0.22358100E+05, 0.25128000E+05, -.14031500E+05, -.38493700E+04, 0.26090500E+05, 0.30736600E+05, 0.30893000E+05, -.57370900E+04, -.42209900E+05, 0.21225500E+05, 0.20175400E+05, 0.11148300E+05, 0.17537300E+05, 0.20202700E+04, -.22619100E+05, -.21668500E+05, 0.18527600E+05, 0.10776500E+06, -.54702700E+05, -.52213300E+05, -.30370800E+05, -.37885200E+05, -.75834200E+04, 0.54874500E+05, 0.49836200E+05, -.42941300E+05, 0.24410300E+05, -.12471700E+05, -.11386400E+05, -.28416900E+05, -.26293600E+05, 0.17861200E+05, 0.58723600E+05, 0.54543000E+05, -.25687600E+05, -.41206700E+04, 0.21191600E+04, 0.27340000E+04, -.35879400E+05, -.30656700E+05, 0.35033100E+05, 0.79769800E+05, 0.73594700E+05, -.29927700E+05, -.29880900E+05, 0.14897600E+05, 0.14651300E+05, -.12721700E+05, -.66960000E+04, 0.20973500E+05, 0.30262600E+05, 0.29162600E+05, -.45476000E+04, -.30650600E+05, 0.14868400E+05, 0.16252700E+05, 0.13298300E+05, 0.14210200E+05, -.14168500E+04, -.24567700E+05, -.23302700E+05, 0.16155700E+05, 0.20158500E+05, -.10336700E+05, -.95731300E+04, -.41974900E+05, -.37101700E+05, 0.31766500E+05, 0.87393300E+05, 0.82354000E+05, -.38416700E+05, 0.17184700E+04, -.11615100E+04, -.62739600E+03, -.29742100E+05, -.27003700E+05, 0.26832800E+05, 0.65560500E+05, 0.63274400E+05, -.26421000E+05, 0.55773700E+05, -.28644100E+05, -.28255100E+05, -.99500600E+04, -.16134200E+05, -.87751700E+04, 0.17064200E+05, 0.15279300E+05, -.16371900E+05, 0.22564900E+05, -.10784400E+05, -.11971300E+05, 0.52667900E+04, 0.12955800E+04, -.11712100E+05, -.12622700E+05, -.12457700E+05, 0.55860600E+03, -.32435200E+03, -.14228900E+05, 0.59498900E+03, 0.13714400E+03, -.16352800E+05, -.16862900E+05, -.45302300E+04, 0.19209100E+05, -.11107700E+05, -.40796400E+05, -.15293100E+05, -.45509200E+05, -.18383900E+05, 0.37221400E+05, -.93205000E+04, 0.57672100E+04, 0.17941600E+05, 0.21508300E+05, -.57553200E+04, -.14024900E+04, -.39180700E+05, 0.23195900E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.16730700E+00, 0.26623500E+00, -.83184300E+00, 0.15651500E+01, 0.25483900E+05, -.13335200E+05, -.23561600E+05, -.62168700E+05, 0.12935800E+05, 0.80007600E+05, -.39707600E+05, -.35977800E+05, -.13006200E+05, -.48937100E+05, 0.14182600E+04, 0.44101400E+05, 0.84680000E+05, -.38917800E+05, -.54634100E+05, 0.25493300E+05, 0.22703400E+05, 0.71598800E+04, 0.47092400E+05, -.69597600E+04, -.40563900E+05, -.75186500E+05, 0.31885900E+05, -.64217500E+05, 0.30362200E+05, 0.27304400E+05, 0.32757400E+04, 0.44999200E+05, -.34094900E+03, -.26421000E+05, -.75463600E+05, 0.32983400E+05, -.42805700E+05, 0.21734300E+05, 0.21232500E+05, 0.10514500E+05, -.12458100E+05, 0.18857800E+05, 0.11148300E+05, 0.45567500E+05, 0.15535300E+03, 0.36922200E+04, -.15966200E+04, -.10554500E+04, -.45630500E+03, -.70512400E+04, 0.24666300E+04, 0.64276100E+04, 0.13831900E+05, -.42595100E+04, -.29924200E+05, 0.14880500E+05, 0.15234700E+05, 0.10747500E+05, -.60452500E+04, 0.10733800E+05, 0.26833500E+04, 0.18351400E+05, 0.27721800E+04, -.24650900E+03, -.17189400E+04, -.29055800E+04, 0.14308800E+05, 0.30424600E+05, -.20814700E+05, -.40419900E+05, -.69400700E+05, 0.20808100E+05, 0.20997700E+04, 0.91442200E+03, -.19521400E+04, 0.20096100E+05, -.18179400E+03, -.53818300E+04, -.93588600E+04, -.39183900E+04, 0.50462500E+04, 0.69674800E+05, -.35123900E+05, -.30593600E+05, -.36589100E+04, -.40805800E+05, -.58668200E+04, 0.16530100E+05, 0.58733500E+05, -.30402100E+05, 0.21926800E+05, -.12222800E+05, -.10715800E+05, -.16839000E+05, 0.15622000E+04, -.36337600E+04, 0.62570900E+04, -.11085700E+05, -.63688900E+04, 0.88619400E+04, -.41286200E+04, -.16639000E+04, -.13210700E+05, -.24480200E+05, 0.12744800E+05, 0.27713000E+05, 0.52799100E+05, -.19095000E+05, -.47494000E+05, 0.21794100E+05, 0.15564300E+05, 0.71589600E+04, 0.35599500E+05, 0.72430100E+03, -.12757800E+05, -.87394800E+05, 0.26179600E+05, -.46110700E+05, 0.22415000E+05, 0.19844500E+05, 0.29074800E+04, 0.31246400E+05, -.37572300E+03, -.21674600E+05, -.59529800E+05, 0.23771300E+05, -.12259400E+05, 0.62972900E+04, 0.38105900E+04, 0.18976400E+03, 0.38810200E+05, -.14951900E+05, -.30637200E+05, -.73609300E+05, 0.21556000E+05, 0.49546600E+04, -.27992900E+04, -.30417400E+04, -.29498300E+04, 0.86012000E+04, -.61127500E+04, -.10514600E+05, -.18135200E+05, 0.18634600E+04, 0.55986200E+05, -.28517100E+05, -.27253000E+05, 0.26954400E+03, -.18487600E+05, -.12365400E+05, 0.57846200E+03, 0.22298800E+05, -.15564100E+05, -.11427400E+06, 0.56436400E+05, 0.49318200E+05, 0.93758600E+04, 0.55694600E+05, 0.10207300E+05, -.38068000E+05, -.76348600E+05, 0.42541000E+05, -.16913700E+05, 0.77377100E+04, 0.51396700E+04, 0.45084400E+04, 0.36458400E+05, -.13844800E+05, -.33581700E+05, -.73004900E+05, 0.22515700E+05, -.15443600E+05, 0.60260200E+04, 0.28469500E+04, 0.62373500E+04, 0.12984100E+05, -.17627100E+04, -.88026800E+04, -.37651200E+05, 0.10939000E+05, -.15949400E+05, 0.88585100E+04, 0.81299500E+04, -.15965900E+03, -.17869200E+04, 0.74259800E+04, 0.71062600E+04, 0.92225100E+04, 0.11402700E+04, -.61076400E+04, 0.23323400E+05, 0.36404100E+05, -.15361400E+05, 0.31686500E+05, 0.17551600E+05, 0.25178700E+04, -.11448700E+05, -.50100100E+04, 0.29070000E+05, 0.25229200E+05, 0.26688300E+05, 0.40529900E+04, -.36990400E+05, 0.26395100E+05, -.71684000E+04, 0.37523600E+04, -.29494000E+05, 0.22824500E+05, -.50501500E+03, 0.41379000E+05, -.40084000E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.59986000E+00, -.83589200E+00, -.14732400E+00, -.79528600E+01, 0.22781600E+01, 0.42898900E+05, 0.18275700E+06, 0.14420100E+06, -.18641900E+05, 0.89578200E+05, -.44227300E+05, -.44879600E+05, -.19051400E+05, -.20758600E+05, -.71247400E+05, -.21736500E+06, -.19332000E+06, -.13495500E+05, 0.53560600E+05, -.30241300E+05, -.35086400E+05, 0.27804200E+04, -.21740900E+04, 0.41473100E+05, 0.22773900E+06, 0.15582300E+06, -.26422700E+05, 0.12555600E+06, -.65543500E+05, -.61040700E+05, 0.23596300E+05, 0.14185700E+05, 0.18103900E+04, 0.19584400E+06, 0.11860300E+06, -.24814400E+05, -.25671900E+05, 0.13656300E+05, 0.10011900E+05, 0.15237200E+04, 0.53776400E+04, -.39965900E+05, -.17148400E+06, -.11105300E+06, 0.24907300E+05, 0.11427600E+05, -.51530600E+04, -.51357300E+04, -.25976100E+04, -.44946900E+04, -.11053300E+05, -.37504600E+05, -.29380000E+05, 0.62951100E+03, -.10548900E+05, 0.51642200E+04, -.77097200E+02, 0.10121300E+05, 0.14903300E+05, -.39184000E+05, -.12365000E+06, -.69165000E+05, 0.30000300E+05, -.62041400E+04, -.14808300E+04, 0.17291200E+04, -.22898200E+04, 0.12103900E+05, 0.32257400E+05, 0.14487000E+06, 0.10828600E+06, -.17298000E+04, 0.97940700E+05, -.44134800E+05, -.55204400E+05, -.27760700E+04, -.46018800E+04, -.60965400E+05, -.85908400E+05, -.65454100E+05, 0.19022700E+05, -.18444000E+06, 0.89643600E+05, 0.98212900E+05, -.18404000E+05, 0.11730500E+04, 0.24093400E+05, -.14175500E+06, -.76315500E+05, 0.37299000E+05, -.73746000E+04, 0.48149700E+03, 0.15298800E+05, 0.15708800E+04, 0.40245400E+04, 0.28378500E+05, 0.85640300E+05, 0.46335500E+05, -.23959900E+05, -.38603800E+05, 0.20156800E+05, 0.17726400E+05, -.13627600E+05, -.21197000E+05, 0.92787200E+04, -.59341400E+05, -.47222100E+05, -.39748400E+04, 0.48286200E+06, -.24594300E+06, -.24325100E+06, 0.51630900E+05, 0.13949300E+05, -.14900800E+06, 0.11386400E+06, 0.32802200E+05, -.39425300E+05, 0.11330600E+06, -.57974500E+05, -.56088500E+05, 0.10498500E+05, -.76809400E+04, 0.41248500E+04, 0.15554100E+06, 0.10352300E+06, -.23527800E+05, 0.16884900E+06, -.83884900E+05, -.84246800E+05, -.20709800E+05, -.46340700E+05, 0.31556600E+05, 0.25689200E+06, 0.15508200E+06, -.70407500E+05, -.54225500E+05, 0.27375700E+05, 0.24623000E+05, -.11090300E+05, -.60246300E+04, 0.48665800E+05, 0.10164900E+06, 0.75766800E+05, -.31889900E+04, -.14959400E+06, 0.72063000E+05, 0.80825800E+05, -.34186000E+05, -.16788700E+05, 0.54223000E+05, -.27937800E+05, -.51111600E+04, 0.71361100E+04, -.64776400E+05, 0.30949300E+05, 0.24023800E+05, 0.35596800E+05, 0.31986900E+05, 0.55474500E+05, 0.20297100E+06, 0.17811800E+06, 0.26144000E+04, -.58934500E+04, 0.14880000E+04, -.46459500E+02, 0.13293000E+05, 0.19093300E+05, 0.38902800E+05, 0.18406800E+06, 0.13746700E+06, -.46841000E+04, 0.21307000E+06, -.11073700E+06, -.11597000E+06, 0.20579400E+05, -.95352000E+03, -.69125900E+05, 0.34997500E+05, 0.11362400E+05, -.11504300E+05, 0.10425000E+06, -.49441700E+05, -.55901100E+05, 0.18211900E+05, 0.24240600E+04, -.52637300E+05, -.58447700E+05, -.53946100E+05, 0.56152100E+03, -.23230000E+04, 0.49312300E+05, 0.50397400E+05, 0.32512200E+05, -.90414200E+05, -.12485600E+02, -.23680400E+05, 0.17468600E+04, -.11412100E+05, -.13022200E+06, -.13512400E+06, -.13522100E+06, -.14842800E+04, 0.55761500E+05, 0.36286900E+05, -.75479900E+05, 0.10146800E+05, 0.11960800E+06, 0.17947800E+05, 0.17164700E+05, -.38163800E+05, 0.11141700E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10048300E+00, 0.11762900E-01, -.77536600E+00, 0.65936200E+00, 0.63780900E+00, 0.54656100E-01, -.84193400E+05, -.60228700E+05, -.17766000E+05, -.59948000E+05, 0.29838900E+05, 0.37577400E+05, 0.34431700E+04, 0.22824000E+05, 0.73660100E+04, 0.10476800E+06, 0.87224700E+05, 0.40745900E+05, 0.48148400E+05, -.23903500E+05, -.28709400E+05, 0.10634400E+05, 0.17451000E+05, -.25922600E+05, -.12256800E+06, -.96728500E+05, -.14570900E+05, -.55885100E+04, 0.27973500E+04, -.11975200E+05, 0.11797500E+05, 0.11467700E+05, -.77567200E+04, -.10973500E+06, -.76284800E+05, -.12493400E+05, -.35833500E+05, 0.17845100E+05, 0.19644200E+05, -.15797000E+05, -.21662600E+05, 0.25955500E+05, 0.92144700E+05, 0.70661400E+05, 0.29674300E+04, -.18298500E+05, 0.91038300E+04, 0.10649400E+05, 0.26606900E+03, 0.12865100E+03, 0.47676100E+04, 0.19223500E+05, 0.17041200E+05, 0.58593300E+04, -.21428600E+05, 0.10720500E+05, 0.17796200E+05, -.23814400E+05, -.27063300E+05, 0.30030500E+05, 0.67132300E+05, 0.48184000E+05, -.82608800E+04, 0.25251700E+05, -.12396100E+05, -.20374300E+05, -.56089200E+04, 0.24008900E+04, -.51778800E+04, -.64913400E+05, -.52628600E+05, -.13117700E+05, -.10064400E+06, 0.50148800E+05, 0.53912800E+05, -.17577800E+05, -.69494600E+04, 0.44975100E+05, 0.47352300E+05, 0.46071600E+05, 0.11109600E+05, 0.47926800E+05, -.23728300E+05, -.16610000E+05, -.14681600E+05, -.22660400E+05, -.21214100E+04, 0.86218700E+05, 0.57520900E+05, -.12498100E+04, 0.61667700E+05, -.30739500E+05, -.41658900E+05, 0.15270000E+05, 0.11891200E+05, -.30468000E+05, -.48609700E+05, -.40956400E+05, -.78913900E+04, -.60883100E+03, 0.25468200E+03, 0.82893100E+04, 0.15302600E+05, 0.59396100E+04, -.13016100E+05, 0.27845800E+05, 0.24025900E+05, 0.12414400E+05, -.22240400E+06, 0.11112500E+06, 0.92377100E+05, -.18515800E+05, -.57416800E+04, 0.89439100E+05, -.73078800E+05, -.22108000E+05, -.91616800E+04, -.40238900E+05, 0.20161100E+05, 0.12347000E+05, 0.79760000E+04, 0.20318300E+04, 0.10075700E+05, -.87369200E+05, -.53350900E+05, -.90285700E+04, -.69439400E+05, 0.34658000E+05, 0.27975900E+05, 0.31904100E+05, 0.46048000E+05, -.13467700E+05, -.13844300E+06, -.85712300E+05, 0.16883000E+05, 0.52789600E+05, -.26419000E+05, -.26004300E+05, 0.12137700E+05, 0.93620800E+04, -.28080800E+05, -.52271900E+05, -.44262400E+05, -.43645400E+04, 0.26071200E+05, -.12878000E+05, -.16788900E+05, 0.88785000E+04, 0.97372500E+04, -.21274500E+05, 0.22676900E+05, 0.16336900E+05, 0.15396000E+05, 0.73914300E+05, -.36813300E+05, -.50491800E+05, -.39550100E+04, -.19017300E+05, -.15489500E+05, -.10618400E+06, -.91604600E+05, -.44841200E+05, 0.70420200E+05, -.35068200E+05, -.40570100E+05, -.25324500E+04, 0.19128800E+04, -.18305800E+05, -.95609300E+05, -.82268100E+05, -.24695300E+05, -.11483000E+06, 0.57424700E+05, 0.52268400E+05, -.59503100E+04, 0.31047600E+04, 0.39850200E+05, -.31007100E+05, -.83658600E+04, 0.51306100E+04, -.38665300E+05, 0.19193400E+05, 0.22803000E+05, -.63348100E+04, -.23782500E+04, 0.16965900E+05, 0.18404300E+05, 0.18195100E+05, 0.42224100E+04, 0.22312500E+05, 0.48667400E+04, -.11759300E+05, -.12345100E+05, 0.69963600E+05, -.38610100E+04, 0.24848900E+04, -.22021200E+04, 0.12824900E+05, 0.69763300E+05, 0.77339000E+05, 0.64155200E+05, 0.55168500E+04, -.39923500E+05, 0.47479300E+04, 0.21301100E+05, -.13436600E+05, -.62877100E+05, -.14559600E+05, 0.20353300E+04, 0.23127000E+05, -.39686800E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24046900E+00, 0.24870900E+00, -.27650600E+00, -.30734200E+00, -.45071000E+00, -.22804400E+00, -.19490100E+00, 0.11174400E+06, -.98840900E+04, -.10009600E+06, 0.50272100E+05, 0.48000200E+05, 0.12536800E+05, 0.33467100E+05, 0.16084600E+05, -.25479800E+05, -.16057200E+06, 0.40581100E+05, 0.15575300E+06, -.80968300E+05, -.77519000E+05, -.17260800E+05, -.24663100E+05, -.34319100E+05, 0.15803700E+05, 0.11004400E+06, -.45396200E+05, 0.58189300E+05, -.31998800E+05, -.27017800E+05, -.10256200E+05, -.13883500E+05, -.76488600E+04, 0.15264100E+05, 0.14898200E+06, -.29236900E+05, 0.20440400E+05, -.94712100E+04, -.10822600E+05, -.11539000E+05, -.24394300E+05, 0.50371300E+04, 0.24672700E+05, -.57401100E+05, -.87527800E+04, -.11796300E+05, 0.63557000E+04, 0.57295500E+04, 0.68618900E+03, -.18886100E+03, 0.35866000E+04, 0.34213500E+03, -.20245700E+05, 0.34880300E+04, -.18167200E+05, 0.89584100E+04, 0.79523400E+04, -.62521200E+04, -.14199200E+05, 0.12454800E+05, 0.18146600E+05, -.47570700E+04, 0.37389900E+03, 0.62146000E+05, -.34735400E+05, -.30179700E+05, -.90105000E+04, -.78996800E+04, -.14127300E+05, 0.70226300E+04, 0.88412800E+05, -.18096200E+05, -.25728600E+05, 0.16758300E+05, 0.11825900E+05, -.47865900E+04, -.11516700E+05, 0.12289600E+05, 0.10591300E+05, 0.10342000E+05, 0.38501200E+04, -.73023700E+05, 0.35204400E+05, 0.35618300E+05, 0.12757000E+05, 0.17938500E+05, 0.80164400E+04, -.22204800E+05, -.12737800E+06, 0.32285900E+05, -.17882200E+05, 0.63405900E+04, 0.11089700E+05, 0.91126800E+04, 0.22433800E+05, -.29592700E+04, -.16138000E+05, 0.11360400E+05, 0.68767200E+04, -.30825200E+05, 0.16000100E+05, 0.13814000E+05, 0.71337500E+04, 0.44557500E+04, 0.45344000E+04, -.10473300E+05, -.79078100E+05, 0.98571500E+04, -.15475100E+06, 0.73346200E+05, 0.79739200E+05, 0.16949200E+04, 0.37314100E+04, 0.51611400E+05, 0.18477500E+05, 0.25189300E+06, 0.73287000E+04, 0.31606700E+05, -.16924300E+05, -.14249900E+05, -.85252700E+04, -.21482400E+05, 0.13259100E+04, 0.14727400E+05, 0.12753200E+06, -.24582300E+05, 0.11191400E+06, -.55479400E+05, -.54601800E+05, -.12532700E+05, -.19698400E+05, -.23482400E+05, 0.66526100E+04, 0.10637600E+06, -.38858400E+05, 0.40001200E+05, -.20251400E+05, -.20394500E+05, 0.85826600E+03, 0.11556900E+04, -.14161100E+05, -.78628300E+04, 0.12536400E+05, -.69048400E+04, -.63364400E+04, 0.15981100E+04, 0.39759400E+04, 0.33645300E+04, 0.84446600E+04, -.42913600E+04, -.14466900E+05, -.80110400E+05, 0.11429500E+05, 0.12918600E+06, -.65503200E+05, -.63313900E+05, -.16042500E+05, -.34734800E+05, -.22359100E+05, 0.31516600E+05, 0.15869800E+06, -.50878400E+05, 0.62626100E+05, -.32537500E+05, -.30520000E+05, -.41850700E+04, -.27339100E+03, -.17718900E+05, 0.53988200E+03, 0.10804100E+06, -.17296000E+05, -.64647400E+05, 0.28819500E+05, 0.32307700E+05, 0.84832700E+03, 0.29317800E+03, 0.20374400E+05, 0.64640300E+04, 0.10617300E+06, 0.61277800E+04, -.90466400E+04, 0.64556100E+04, 0.36942200E+04, -.12002800E+03, -.25252900E+04, 0.39738200E+04, 0.31069900E+04, 0.15226500E+04, 0.19253900E+04, 0.19152600E+05, -.10533300E+05, -.11439800E+05, 0.25965600E+05, -.25633800E+05, -.21784400E+05, -.68643200E+04, 0.44959100E+04, -.16772000E+05, 0.21643900E+05, -.17430400E+05, 0.95490800E+04, 0.78234300E+03, 0.14448800E+05, 0.25266400E+05, -.20573500E+05, 0.23029200E+04, -.33883200E+04, -.12350100E+05, 0.33163200E+04, -.28654900E+05, -.13180200E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20626200E+00, 0.48204800E+00, -.13517700E+00, 0.11486400E+01, 0.41165600E-01, 0.99334900E-01, 0.24159500E+00, 0.20123200E+00, -.14408800E+05, -.32178400E+05, 0.15784100E+05, 0.14693000E+05, -.52704800E+04, -.12896800E+04, 0.16819700E+05, 0.15333200E+05, 0.13840100E+05, 0.13716400E+05, 0.33005500E+04, 0.68568700E+03, 0.12898900E+04, 0.78845300E+03, -.20553700E+04, -.12554600E+04, -.95578600E+03, 0.15868700E+04, -.19691300E+05, 0.24883100E+04, 0.86412000E+03, 0.92394500E+03, -.84478400E+03, -.82258600E+03, 0.76925900E+03, 0.23497700E+04, 0.23736800E+04, -.19275500E+05, 0.58828400E+04, -.34633000E+04, -.25265100E+04, -.83141500E+03, 0.12798100E+04, -.22664700E+04, -.15668400E+04, -.25798000E+04, 0.13639000E+05, 0.10510500E+04, -.86360600E+03, -.95952600E+03, -.17234700E+03, 0.40216700E+03, -.45144600E+03, -.58378200E+03, -.10667000E+04, 0.35953200E+04, 0.83491700E+04, -.41018300E+04, -.40793100E+04, 0.53702700E+03, 0.52248600E+03, -.40785700E+04, -.23556900E+04, -.42988600E+04, 0.10623600E+05, 0.36862600E+04, 0.86591500E+03, -.16076400E+03, 0.27201500E+04, -.23636200E+04, -.12124800E+04, 0.25031300E+03, 0.83282400E+03, -.93630800E+04, 0.54852100E+04, -.56174800E+04, -.17647700E+04, 0.24695100E+04, -.28651200E+04, -.41135700E+04, -.28308500E+04, -.55017800E+04, 0.12470000E+05, 0.15185300E+04, 0.21354100E+03, -.34668000E+04, 0.36319500E+04, 0.20992100E+04, -.28113200E+04, -.50296100E+04, -.40216400E+04, 0.17517200E+05, -.90737600E+04, 0.64398000E+04, 0.34550700E+04, -.26245100E+04, 0.14583900E+04, 0.55149000E+04, 0.36528500E+04, 0.71833600E+04, -.12847700E+05, 0.98418700E+04, -.53747200E+04, -.58850500E+04, 0.25620200E+03, 0.35078700E+04, -.44689300E+04, -.62200800E+04, -.64584200E+04, 0.52585000E+04, -.11620900E+05, 0.86679000E+04, 0.96407700E+04, -.58579100E+04, 0.77904700E+03, 0.53390700E+04, 0.88516100E+04, 0.47851800E+04, -.11635000E+05, 0.15604500E+05, -.69328400E+04, -.65683100E+04, 0.58509000E+03, -.28612200E+03, -.72687300E+04, -.65095700E+04, -.52406800E+04, -.11235700E+05, -.22794000E+04, 0.88068400E+03, 0.21557400E+04, -.10610800E+04, -.23135600E+04, 0.18394300E+04, 0.91911900E+03, 0.23925100E+04, -.20306700E+05, 0.10856300E+05, -.52581100E+04, -.48051400E+04, 0.16671700E+04, -.47632500E+03, -.48841100E+04, -.56919300E+04, -.42431200E+04, -.73098200E+04, 0.94266800E+04, -.35099500E+04, -.56532000E+04, 0.35676200E+04, -.14973600E+03, -.35900300E+04, -.43254900E+04, -.40454100E+04, 0.60484500E+04, 0.72379400E+04, -.28066300E+04, 0.94051100E+03, -.27058100E+04, 0.89989500E+03, -.25064000E+04, -.57404000E+03, 0.79963000E+03, -.21477300E+05, -.47305100E+04, 0.32881300E+04, 0.40898200E+04, 0.86979000E+03, -.27696500E+04, 0.16245400E+04, 0.19936200E+04, 0.42737900E+04, -.16428700E+05, 0.91116300E+04, -.20072200E+04, -.12642700E+04, -.73906200E+03, -.81777700E+03, -.26938600E+04, 0.35868400E+03, -.40721500E+04, -.22440500E+04, -.10077900E+05, 0.35939700E+04, 0.53989700E+04, -.30526700E+04, -.16876800E+04, 0.46770100E+04, 0.47609800E+04, 0.40921000E+04, 0.33081100E+04, -.14576200E+04, -.39809600E+03, 0.32955100E+04, 0.39755000E+04, 0.39946100E+04, -.82572000E+04, -.14551100E+03, 0.90804300E+04, 0.23001800E+04, 0.73772700E+04, 0.46764000E+04, 0.66662300E+03, 0.42477200E+04, 0.12835000E+04, 0.51715700E+04, 0.25820200E+04, -.98117300E+04, -.33347200E+04, -.14914300E+04, 0.40835300E+04, -.21695000E+04, 0.59763200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14727700E+01, 0.15769100E+01, 0.15455000E+01, 0.44004200E+01, -.14181000E+01, 0.75124400E+00, 0.11086000E+01, 0.83858300E+00, -.26577300E+01, -.10496200E+06, 0.50546200E+05, 0.43381900E+05, 0.38679100E+04, -.33457900E+04, 0.51784200E+05, 0.26228100E+05, 0.22597200E+05, 0.98654000E+04, 0.73934400E+05, -.19915600E+05, -.64774200E+04, -.75476500E+04, 0.59791900E+04, -.24732100E+05, 0.15798000E+05, -.65853400E+04, -.10040800E+05, 0.25517200E+05, 0.25021600E+04, -.46650400E+04, -.21857600E+05, 0.14290400E+05, 0.33866500E+04, 0.28981500E+05, 0.15502200E+05, 0.23851700E+04, 0.70259000E+04, -.73651400E+04, 0.29199300E+04, 0.77375500E+04, -.74235700E+04, -.17718400E+04, -.61785200E+04, -.12678300E+03, -.54645400E+03, -.12903000E+04, -.18178900E+04, -.30011500E+04, -.93937700E+03, -.96145100E+03, 0.56558800E+03, -.39508100E+04, -.25347400E+04, -.13421300E+03, 0.96582600E+04, -.43185800E+04, 0.45525900E+04, 0.17085300E+05, -.62217000E+04, -.36705800E+04, 0.24329300E+04, -.54214100E+04, -.13670300E+04, 0.91699400E+05, -.26070600E+05, -.35015000E+05, 0.44186300E+05, 0.11503200E+05, -.44539400E+05, -.22460100E+05, -.33026900E+05, 0.39299400E+04, 0.28044800E+05, -.35457500E+05, 0.17880900E+04, 0.30520300E+05, -.49998200E+05, -.10695400E+05, -.32084800E+05, -.76659500E+04, -.31090900E+05, -.61178100E+05, 0.37891200E+05, 0.67260500E+04, 0.43405700E+05, 0.65838600E+04, 0.12576400E+04, -.36956400E+05, -.12210200E+05, 0.12872800E+05, -.55025800E+05, 0.41639000E+05, 0.18790500E+04, -.87281800E+04, 0.47758000E+05, 0.14649600E+05, 0.18645100E+05, 0.15843000E+05, 0.36728000E+05, 0.12172600E+05, -.94618600E+04, -.88871700E+04, -.24319200E+05, 0.63201700E+04, 0.67452900E+03, -.15300200E+05, -.12377700E+05, -.54229000E+04, -.19111100E+06, 0.11644300E+06, 0.11953200E+06, -.18924800E+05, 0.73321400E+04, 0.76623800E+05, 0.74690400E+05, 0.77304900E+05, 0.27733900E+05, -.46838400E+05, 0.29455000E+05, 0.30046800E+05, -.22226300E+05, 0.29023800E+04, 0.18355600E+05, 0.23234500E+05, 0.33753900E+05, 0.21898100E+04, 0.15420200E+05, -.97375900E+04, -.32058500E+04, -.24462900E+05, -.12513900E+05, 0.19732700E+03, 0.54035500E+04, 0.11518300E+05, -.13061700E+05, 0.64089600E+05, -.30949000E+05, -.24034000E+05, -.18014400E+04, 0.61483000E+04, -.25711100E+05, -.15628800E+05, -.23195600E+05, -.12172500E+05, 0.72876300E+05, -.27538300E+05, -.52561100E+05, 0.42423800E+05, 0.95152400E+04, -.41657700E+05, -.50465200E+05, -.45580600E+05, 0.64279100E+03, 0.26434700E+05, -.74353700E+04, 0.25972400E+05, -.45649500E+05, -.82999200E+03, -.43511400E+04, 0.37713600E+05, 0.28742400E+05, -.71017900E+04, 0.91019500E+04, 0.21905400E+04, 0.10586100E+05, 0.67006700E+04, 0.35467900E+04, -.56134600E+04, 0.17090400E+05, 0.80504100E+04, -.13442600E+04, 0.38606700E+04, 0.16901600E+05, 0.30919500E+05, -.54410300E+04, -.52586900E+04, 0.11740100E+05, 0.29777500E+05, 0.39409300E+04, -.41521200E+04, -.97860800E+05, 0.38277000E+05, 0.57058800E+05, -.29293100E+05, -.23147000E+05, 0.50689900E+05, 0.47109800E+05, 0.48928700E+05, -.75687300E+04, 0.33132700E+04, 0.83456300E+03, 0.13457500E+05, -.48259600E+03, -.85415000E+04, 0.24039600E+04, -.22490100E+04, 0.21962100E+04, 0.18147900E+05, 0.31132300E+05, -.35465000E+04, 0.86328400E+04, 0.46565400E+05, 0.16567800E+05, 0.10505500E+05, -.11829500E+04, 0.97531100E+04, -.19760500E+05, 0.14174800E+05, 0.23065500E+04, -.20206500E+05, -.15104400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21618000E+00, -.24373300E+00, 0.81265100E-01, -.17501400E+01, 0.11584700E-01, 0.35519000E+00, 0.12813700E+00, -.73487900E+00, -.17857900E+00, 0.99490500E-01, 0.61632600E+03, -.28089600E+04, -.19653800E+04, -.16416000E+04, 0.57581100E+03, 0.35824100E+04, 0.88771500E+04, -.83983800E+03, -.24061700E+04, -.44569500E+04, 0.20503200E+04, 0.30966200E+04, 0.28811200E+04, -.19634100E+04, -.54220500E+04, -.11272000E+05, 0.27532900E+04, 0.65468000E+04, -.84331600E+04, 0.28220500E+03, 0.36322900E+04, 0.43638900E+04, -.65228200E+04, -.74656800E+04, -.13418700E+05, 0.23918000E+04, -.62312500E+04, 0.43792500E+04, 0.24703800E+04, -.18199100E+04, 0.71111300E+03, 0.11243500E+04, -.15069600E+04, -.15081400E+04, 0.18484000E+04, -.40393500E+03, 0.10110100E+04, -.10826700E+03, 0.27839000E+02, 0.12526500E+03, 0.20336300E+03, 0.51962400E+03, 0.13100800E+04, 0.15068000E+03, -.77597400E+04, 0.37003300E+04, 0.22480900E+04, -.32066300E+04, -.47037200E+03, 0.20563600E+04, -.20583900E+04, 0.78805800E+03, 0.11218000E+04, -.92574300E+04, -.18201300E+04, 0.62580900E+04, -.33644100E+04, -.10573200E+04, 0.37944600E+04, 0.15804200E+04, -.16923900E+04, -.13639300E+03, -.13555500E+05, 0.13612500E+05, 0.55783700E+04, -.84668400E+03, 0.40446300E+04, 0.36242000E+04, 0.33599300E+04, 0.29585900E+04, 0.42683300E+04, -.54443500E+04, 0.55124600E+03, 0.12058000E+04, -.87053100E+04, -.10267800E+05, 0.88079700E+04, 0.10231800E+05, 0.16744800E+05, -.69004300E+04, 0.22765400E+05, -.15874800E+05, -.84941100E+04, 0.51695400E+03, -.36402600E+04, -.64286500E+04, -.31173000E+04, -.47195500E+04, -.46924200E+04, 0.14189600E+04, 0.34723500E+03, -.29410400E+04, 0.21257500E+04, -.12253000E+03, -.11274300E+04, 0.71033000E+02, 0.37545100E+04, 0.27581800E+03, 0.38205800E+05, -.25745300E+05, -.14753000E+05, -.66217600E+04, -.81720200E+04, -.10927100E+05, -.57270300E+04, -.27810600E+04, -.88590000E+04, 0.12609600E+04, -.26329000E+04, 0.15708100E+04, 0.27341700E+04, 0.28511400E+04, -.33153600E+04, -.63213700E+04, -.65559500E+04, 0.20473500E+04, -.42578800E+03, 0.85617500E+03, 0.20347800E+04, 0.62105700E+04, 0.58407800E+04, -.29722100E+04, -.20048800E+04, -.65675500E+04, 0.39960300E+04, -.19353300E+04, 0.40066400E+03, 0.60463500E+03, 0.11101500E+04, 0.74557300E+03, 0.53593900E+03, 0.27185500E+03, -.74527700E+03, 0.10331800E+04, -.13241400E+05, 0.38453300E+04, 0.76896500E+04, -.56283400E+04, -.55585800E+04, 0.84751600E+04, 0.84874400E+04, 0.13376000E+05, -.33153100E+04, 0.76596800E+04, -.56626400E+04, -.11417800E+04, 0.50297000E+04, 0.23838300E+04, -.46300400E+04, -.93973900E+04, -.17127700E+05, 0.14379700E+04, 0.22397800E+04, -.33462200E+04, 0.17630700E+03, 0.70486000E+03, 0.10469500E+04, -.13164900E+04, -.24676000E+04, -.73041500E+04, 0.46956000E+03, 0.12772500E+05, -.12318100E+05, -.56804800E+04, -.58981200E+04, -.67971900E+04, -.26278500E+04, -.26138400E+03, 0.55841600E+04, -.58703100E+04, 0.53619300E+04, 0.69159200E+03, -.37299000E+04, 0.23926500E+04, 0.25989800E+04, -.33951400E+04, -.29789800E+04, -.36029900E+04, 0.16663200E+04, 0.69939400E+03, 0.11282800E+04, 0.12169600E+03, -.17017800E+04, 0.25435000E+04, -.62996100E+03, -.21607900E+03, -.41490300E+03, 0.56204500E+03, -.47687500E+04, 0.14638600E+04, -.32007900E+04, 0.44893300E+03, -.53094800E+04, 0.12159500E+04, -.14470500E+04, -.28558400E+03, -.63099700E+04, 0.63129600E+03, -.29759800E+03, 0.75552700E+04, 0.64528900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18744400E+00, -.67385300E+00, -.75226600E+00, -.82716400E+01, 0.25729700E+01, 0.17165700E+00, -.14630000E+01, 0.95666800E+00, 0.14459400E+01, -.46421600E+00, -.72537300E+00, -.12651900E+05, 0.78313300E+03, 0.19444000E+04, 0.49473700E+04, 0.11807900E+05, 0.68535700E+04, 0.17724300E+04, 0.91428900E+05, -.45469500E+05, -.34366600E+05, 0.10772900E+05, 0.20238100E+05, -.32999600E+05, -.11288000E+05, -.38583400E+05, 0.31939700E+04, 0.15721600E+06, -.78101400E+05, -.59807100E+05, 0.10147500E+05, 0.17130000E+05, -.54161400E+05, -.15470700E+05, -.56710700E+05, -.53690700E+04, -.61408900E+05, 0.30655400E+05, 0.30237500E+05, -.13596900E+05, -.15582900E+05, 0.22830200E+05, -.77707300E+03, 0.19918200E+05, -.41235400E+04, -.17276500E+05, 0.86127300E+04, 0.62371700E+04, -.84853600E+03, -.15859000E+04, 0.57440700E+04, 0.75748800E+03, 0.46510600E+04, 0.81330500E+03, -.43693600E+05, 0.21789500E+05, 0.17214500E+05, -.11918400E+05, -.10194100E+05, 0.12069600E+05, -.81891600E+04, 0.12273200E+05, -.16611600E+04, 0.62794800E+05, -.31515800E+05, -.20830100E+05, -.71116000E+04, 0.69331500E+04, -.14693000E+05, 0.82829100E+04, -.14869700E+05, -.35338000E+04, -.10827800E+06, 0.54107700E+05, 0.53894100E+05, -.16437000E+05, -.93825800E+04, 0.34627600E+05, 0.11515100E+05, 0.29902200E+05, 0.34124900E+04, -.12681000E+06, 0.62679400E+05, 0.51397100E+05, -.16320500E+05, -.25163500E+05, 0.52134900E+05, 0.23390100E+05, 0.59023400E+05, -.38160100E+04, 0.15075700E+06, -.75328900E+05, -.69431700E+05, 0.10207400E+05, 0.73782300E+04, -.45728100E+05, -.73180700E+04, -.37241700E+05, -.10129200E+05, -.51303600E+05, 0.25641000E+05, 0.15805900E+05, 0.87467600E+04, -.16069600E+04, 0.14433400E+05, -.29033800E+03, 0.12638900E+05, 0.52710900E+04, 0.19390600E+06, -.96968000E+05, -.69014600E+05, -.19034500E+05, -.14214500E+05, -.65916700E+05, -.26608800E+05, -.55134500E+05, -.29462400E+05, 0.41812400E+05, -.20931300E+05, -.10269700E+05, -.17813200E+03, -.28511800E+04, -.18511200E+05, -.17426200E+05, -.15076600E+05, -.55428200E+04, 0.18932300E+05, -.94447200E+04, -.15048800E+04, 0.10570400E+05, 0.12929400E+05, -.74011600E+04, 0.55729100E+03, -.15784800E+05, 0.54692700E+04, 0.16471000E+05, -.79359000E+04, -.72739300E+04, 0.56603700E+04, 0.73417300E+04, -.43096900E+04, 0.33942900E+04, -.45294700E+04, 0.33356700E+04, -.57458600E+05, 0.28173300E+05, 0.29619000E+05, -.12287300E+05, -.11339600E+05, 0.30421400E+05, 0.21962900E+05, 0.34166300E+05, -.31191600E+04, 0.66794600E+05, -.33304200E+05, -.10084700E+05, 0.22893600E+04, -.19208100E+04, -.22746200E+05, -.19855100E+05, -.27957600E+05, -.90640800E+04, 0.84728600E+05, -.42204000E+05, -.32904000E+05, 0.50133800E+04, 0.12687900E+05, -.29460000E+05, -.55275900E+04, -.27236900E+05, -.64040800E+03, 0.62068700E+05, -.31150200E+05, -.18284700E+05, -.11826100E+05, -.69255100E+04, -.20507100E+05, -.10528600E+05, -.17114700E+05, -.12138800E+05, -.11727000E+05, 0.60443800E+04, 0.35995700E+04, 0.21084500E+04, -.76527500E+02, -.73227100E+02, -.76497600E+04, -.24733500E+04, 0.15573900E+04, 0.28260100E+05, 0.11930000E+05, 0.11306400E+05, -.71642200E+04, 0.72314100E+04, 0.32713400E+04, -.99612300E+04, -.80299900E+04, 0.85036400E+03, -.23860700E+05, 0.34404700E+04, -.16248000E+05, 0.29339700E+04, -.34426300E+05, 0.15245100E+05, -.12345800E+05, 0.10538200E+05, -.33828200E+05, 0.16670200E+05, 0.24759000E+04, 0.46221000E+05, 0.37638400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14421800E+00, 0.13679200E+00, -.84110200E+00, 0.42297400E+01, 0.17148100E+00, -.13620300E+00, -.47868000E-01, 0.71177400E-01, -.49512400E+00, -.24825100E-01, -.94996200E+00, 0.24659400E+00, -.50285900E+04, -.79713100E+04, 0.47745300E+04, 0.88734300E+04, 0.13399500E+05, -.68046300E+04, -.37578000E+05, 0.18611300E+05, 0.21280400E+05, -.52060400E+03, -.62275000E+03, 0.88531200E+04, -.23019300E+04, 0.12374800E+04, 0.39287900E+04, -.49294900E+05, 0.24329800E+05, 0.22474300E+05, -.39359000E+03, 0.16582400E+04, 0.11456400E+05, -.27342600E+04, 0.66097100E+04, 0.69777800E+04, 0.21849900E+05, -.10875100E+05, -.10194800E+05, 0.55903000E+04, 0.79502300E+04, -.10172300E+05, -.38533200E+04, -.13092600E+05, 0.42034800E+04, 0.73349600E+04, -.36683500E+04, -.37857600E+04, -.50897900E+02, 0.69961800E+02, -.21761300E+04, 0.75159800E+02, -.91127300E+03, -.66652000E+03, 0.19324100E+05, -.96278600E+04, -.75692700E+04, 0.47052800E+04, 0.58182200E+04, -.72771400E+04, -.16316400E+04, -.10460600E+05, 0.31906100E+04, -.27312800E+05, 0.13628600E+05, 0.13287700E+05, 0.48763300E+04, 0.25760500E+02, 0.58159100E+04, -.21411800E+04, 0.18880500E+04, 0.46721300E+04, 0.27049300E+05, -.13264200E+05, -.11460000E+05, 0.45268800E+04, 0.44461600E+04, -.86537100E+04, -.27517900E+03, -.89496200E+04, 0.25353700E+04, 0.36432800E+05, -.18001800E+05, -.19643800E+05, 0.30998300E+04, -.16587800E+02, -.93833300E+04, -.14243700E+03, -.47452100E+04, -.43324900E+04, -.42232000E+05, 0.20943900E+05, 0.16615100E+05, -.28522400E+04, -.41030800E+04, 0.13655600E+05, 0.14070500E+04, 0.15535500E+05, -.25230700E+03, 0.22904200E+05, -.11491900E+05, -.10516400E+05, -.32619800E+04, -.67542900E+03, -.65759200E+04, -.27995000E+04, -.33679900E+04, -.43854700E+04, -.27719200E+05, 0.13827000E+05, 0.12387400E+05, -.53326600E+04, 0.14638000E+03, 0.12264300E+05, 0.11476500E+05, 0.20197400E+05, 0.42019100E+04, -.94828900E+04, 0.47215200E+04, 0.42645200E+04, 0.12321600E+04, 0.47991800E+04, 0.10214200E+04, -.19821200E+04, -.24598700E+04, 0.49235100E+04, -.12950300E+05, 0.65348500E+04, 0.60540200E+04, -.36347800E+04, -.27162000E+04, 0.33853400E+04, 0.17353800E+04, 0.44773000E+04, -.37754300E+03, -.64537100E+04, 0.29859500E+04, 0.40782400E+04, -.17705600E+03, -.18107600E+04, 0.61510700E+03, -.42653800E+04, -.12408300E+04, -.11072500E+04, 0.17457600E+05, -.86094100E+04, -.11220000E+05, 0.41877500E+04, -.15264300E+04, -.66955600E+04, -.29362400E+04, -.20007600E+04, -.28603000E+04, -.28291400E+05, 0.14117900E+05, 0.15577800E+05, 0.14361100E+04, 0.88199900E+04, 0.31848200E+04, -.40903100E+04, -.73355700E+04, 0.92972400E+04, -.37032100E+05, 0.18496600E+05, 0.19239700E+05, 0.40759400E+03, -.87739000E+03, 0.10721900E+05, -.34496300E+03, 0.46925200E+04, 0.34457900E+04, 0.64108900E+04, -.32348100E+04, -.10733000E+04, -.37171200E+04, -.33395900E+04, 0.96793800E+03, 0.69504900E+04, 0.83230400E+04, -.15905700E+04, -.18116600E+04, 0.89345400E+03, 0.23172500E+04, -.30237300E+04, 0.53929700E+03, 0.24713200E+04, 0.50791500E+04, 0.21103300E+04, 0.64304600E+03, -.12002800E+05, -.32392700E+04, -.30026500E+04, 0.18104400E+04, -.15677500E+04, -.74234900E+03, 0.44002300E+04, 0.30866600E+04, 0.45744900E+03, 0.72683500E+04, 0.31670900E+03, 0.45960800E+04, -.85821200E+03, 0.61808000E+04, -.30461000E+04, 0.29135200E+04, -.72365400E+04, 0.47855500E+03, -.41139800E+04, -.10884400E+04, -.65734000E+04, -.56658100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18933700E+00, 0.71024200E-01, -.53405200E+00, -.76547900E+00, 0.18268600E+01, 0.28634700E+00, 0.46124300E-01, -.29385300E+00, -.59362600E+00, 0.84117100E-01, -.67673500E+00, 0.34646600E+00, -.76193800E-01, 0.82194400E+04, -.43338800E+04, -.53764700E+04, 0.38295000E+04, 0.40664900E+04, 0.16526700E+05, -.85041800E+04, -.11417200E+05, 0.82252000E+04, 0.17727800E+05, -.11883200E+05, -.91350200E+04, -.23259100E+05, 0.12677300E+05, 0.18931700E+05, -.96543600E+04, -.90599900E+04, 0.10569400E+05, 0.14242000E+05, -.13545000E+05, -.14384800E+05, -.23060200E+05, 0.86528200E+04, -.21370700E+05, 0.10714800E+05, 0.96831100E+04, -.40378000E+04, -.10775700E+05, 0.10352100E+05, 0.88192600E+04, 0.93934100E+04, -.60410200E+04, -.55263600E+04, 0.27912300E+04, 0.30980300E+04, -.67310200E+03, -.24707900E+04, 0.25344900E+04, 0.17919400E+04, 0.45442200E+04, -.13877900E+04, -.17627500E+05, 0.87751500E+04, 0.68963400E+04, -.55882500E+04, -.10094400E+05, 0.99499900E+04, 0.82834200E+04, 0.10211500E+05, -.56771600E+04, 0.99712500E+04, -.53377400E+04, -.55149800E+04, -.39453100E+04, 0.10560600E+05, -.40206300E+04, 0.60340100E+03, -.12628800E+05, 0.70917000E+04, -.46796800E+05, 0.23780400E+05, 0.21011800E+05, -.12269600E+05, -.95860000E+04, 0.20413300E+05, 0.83047000E+04, 0.23357600E+05, -.16827600E+04, -.10771800E+05, 0.50936900E+04, 0.72171500E+04, -.13137000E+05, -.16802800E+05, 0.12413400E+05, 0.16683500E+05, 0.21018100E+05, -.10695700E+05, 0.36117300E+05, -.18271900E+05, -.13931400E+05, 0.86349000E+04, 0.12160200E+05, -.16512100E+05, -.75107700E+04, -.20375400E+05, 0.36341400E+04, -.26046000E+05, 0.13028600E+05, 0.12549600E+05, 0.43311300E+04, -.79144400E+04, 0.90004600E+04, 0.50350800E+04, 0.17048800E+05, -.28577800E+04, -.15962100E+05, 0.75742700E+04, 0.64687000E+04, -.32334400E+04, -.86967400E+04, 0.89206600E+04, -.51732900E+04, 0.13742200E+05, -.74555200E+04, -.16504800E+05, 0.81430300E+04, 0.82034200E+04, 0.81910700E+04, 0.33140300E+04, 0.71234100E+03, -.57561800E+04, -.41386700E+04, 0.47231500E+04, -.40009900E+04, 0.20559500E+04, 0.23610500E+04, 0.92405900E+04, 0.15383800E+05, -.66034600E+04, -.10441100E+05, -.96508500E+04, 0.12143700E+05, -.53134700E+04, 0.26955400E+04, 0.16266100E+04, 0.32361400E+04, 0.52138100E+04, 0.73352300E+02, 0.59227200E+03, -.20111400E+04, 0.57822500E+04, -.76370100E+04, 0.34934000E+04, 0.60041000E+04, -.64159300E+04, -.95337500E+03, 0.50213300E+04, 0.10032000E+05, 0.96463200E+04, 0.40016400E+03, 0.14216400E+05, -.71736400E+04, -.10685800E+05, 0.65787900E+04, -.18087000E+04, -.38692300E+04, -.37102800E+04, -.18362700E+05, -.14464800E+04, 0.27887000E+05, -.13990100E+05, -.15289900E+05, 0.26580800E+04, 0.13132100E+05, -.12469900E+05, -.85097100E+04, -.22196300E+05, 0.76017000E+04, -.59175300E+04, 0.25531600E+04, -.58043400E+03, -.38581300E+04, -.68711600E+04, 0.48460100E+04, 0.21297600E+04, 0.14000300E+05, -.46468600E+04, 0.28702600E+04, -.11841900E+04, -.26759700E+04, 0.20649000E+04, -.11866500E+04, -.25285600E+04, -.60740800E+04, -.14179900E+04, -.90582700E+03, 0.89737100E+04, 0.86450900E+04, 0.58781500E+04, -.44856900E+04, 0.68134400E+04, 0.59194500E+04, -.33050300E+04, -.11508000E+05, -.40020800E+04, 0.77279200E+04, 0.30205900E+04, 0.77677800E+04, -.83440900E+04, -.78454900E+04, 0.60491100E+04, -.95961400E+04, 0.29380700E+04, -.46469900E+04, 0.80212500E+04, 0.62708000E+03, 0.39117300E+04, 0.71644800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.55654100E+00, 0.41224000E+00, 0.10499700E+01, -.19024400E+01, -.12903500E+01, -.32243700E+00, -.72778000E-01, 0.65961800E+00, -.16163200E+00, -.13878800E+00, -.77848100E-01, 0.12242600E+00, 0.98830700E+00, 0.45184000E+00, 0.46954900E+04, 0.81046200E+04, -.87792600E+04, -.25355100E+04, 0.35999300E+05, -.17236800E+05, -.18411800E+05, -.64650200E+04, -.68436900E+04, -.40586500E+04, 0.90487300E+04, 0.12686900E+05, -.10315700E+05, 0.38142000E+05, -.18177000E+05, -.17284900E+05, -.39370500E+04, 0.14019900E+04, -.75554600E+04, 0.85285700E+04, -.16733300E+04, -.26635200E+04, -.20016800E+05, 0.98375200E+04, 0.99633900E+04, 0.14912900E+04, -.19306000E+04, 0.59061200E+04, -.79438500E+04, 0.10003600E+05, -.58870900E+03, -.44020700E+04, 0.21347800E+04, 0.20395200E+04, 0.36993600E+03, 0.55588300E+03, 0.11599200E+04, -.83995600E+03, -.13245200E+04, 0.82613400E+03, -.12059700E+05, 0.60222100E+04, 0.49155800E+04, 0.55850000E+04, 0.43977400E+03, -.75519700E+03, -.12944100E+05, 0.22311700E+04, 0.93793300E+03, 0.35005300E+05, -.16847200E+05, -.16914500E+05, 0.40154300E+04, -.16245500E+03, -.12054700E+05, -.63500600E+04, -.39146100E+04, -.31343000E+04, -.53990000E+05, 0.25848900E+05, 0.26457900E+05, 0.12719600E+05, -.10444700E+04, 0.14289200E+05, 0.86989900E+04, 0.10554000E+05, 0.27641200E+04, -.30431900E+05, 0.15217400E+05, 0.15664100E+05, 0.53335100E+04, -.12588500E+04, 0.30947000E+04, -.15995600E+05, -.26052100E+04, 0.38930200E+04, 0.58523600E+05, -.28577100E+05, -.27568700E+05, -.97837200E+04, 0.31121400E+04, -.15534300E+05, -.56913800E+04, -.14062800E+05, -.37418000E+04, -.13579700E+05, 0.67818500E+04, 0.65159100E+04, -.70060800E+04, -.21742500E+04, 0.83756300E+04, 0.66991700E+04, 0.22920200E+04, -.53730400E+03, -.29270900E+04, 0.20833100E+04, 0.33992300E+04, 0.18312300E+05, 0.19665500E+05, -.11681000E+05, -.13246300E+05, -.30957100E+05, 0.13437600E+05, 0.28088300E+05, -.13855100E+05, -.13721200E+05, -.55881200E+04, -.75733000E+04, -.63725300E+04, -.51298000E+04, 0.48483200E+03, -.67969400E+04, 0.11955000E+05, -.61619400E+04, -.62316100E+04, -.85194400E+04, -.89844100E+04, 0.74208600E+04, 0.19570100E+05, 0.96880900E+04, -.91319500E+04, 0.17872600E+05, -.86038300E+04, -.88385600E+04, -.61480000E+04, -.44583300E+04, -.86935900E+03, 0.55677600E+04, 0.45849400E+04, -.57926000E+04, 0.10453200E+05, -.50338300E+04, -.45194100E+04, -.55509500E+03, -.34459400E+04, -.25130600E+04, -.81025900E+04, -.84156500E+04, -.18985300E+04, 0.57866200E+04, -.27557300E+04, -.20040000E+04, -.57769600E+04, -.31630900E+04, 0.14242500E+03, 0.10202400E+04, 0.20467500E+05, -.34248100E+04, 0.25825600E+05, -.12719500E+05, -.12845900E+05, -.40014900E+03, -.15659800E+04, -.73210400E+04, 0.41111700E+04, 0.44400500E+04, -.41337600E+04, -.10793300E+05, 0.60643200E+04, 0.55066200E+04, 0.11957100E+05, 0.11944700E+05, -.33329500E+04, -.10306800E+05, -.20789300E+05, 0.92161200E+04, -.18909500E+05, 0.90698400E+04, 0.89800800E+04, 0.12592200E+04, -.19642500E+04, 0.70030500E+04, 0.50287700E+04, 0.67086400E+04, -.73064700E+03, 0.79362400E+04, 0.44415200E+03, 0.63368400E+03, -.14512800E+03, -.14036600E+04, -.89145600E+03, -.30654100E+04, 0.45623600E+04, 0.26990300E+04, -.45461900E+04, -.39497400E+04, -.35308600E+04, 0.14461000E+05, -.84234800E+04, 0.27902400E+04, 0.32984800E+03, 0.11161100E+05, -.13800400E+02, 0.19350000E+04, 0.81703300E+03, 0.11584800E+05, -.71466800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.28241000E+00, 0.52913500E-02, -.68086200E-01, 0.46667300E+00, -.30889900E+00, -.84460500E-01, -.23241500E-01, 0.35932700E+00, 0.66597600E-01, 0.71182200E-01, -.11237100E+00, -.21881800E+00, 0.29519400E+00, 0.23754300E+00, 0.40447700E+00, 0.31435700E+04, 0.35221100E+04, 0.98342100E+03, 0.22508400E+05, -.11078800E+05, -.14038300E+05, 0.65796500E+04, 0.71560600E+04, -.94894100E+04, -.67928500E+04, -.13892200E+05, 0.20329700E+04, 0.44419400E+05, -.21948000E+05, -.21158800E+05, 0.46017100E+04, 0.44675000E+04, -.16758700E+05, -.94163500E+04, -.18678500E+05, -.12916900E+04, -.17410900E+05, 0.86824200E+04, 0.79119900E+04, -.57496800E+04, -.48365100E+04, 0.73550500E+04, 0.35311800E+04, 0.73129100E+04, -.12082600E+04, -.47467300E+04, 0.23482700E+04, 0.26059200E+04, -.61682700E+03, -.60265700E+03, 0.16485900E+04, 0.66790500E+03, 0.20093500E+04, 0.11532800E+03, -.14651800E+05, 0.73226200E+04, 0.55587500E+04, -.61622600E+04, -.34730700E+04, 0.57669400E+04, 0.19810000E+04, 0.70894400E+04, -.77984900E+03, 0.12550400E+05, -.62093100E+04, -.64831100E+04, -.26539100E+04, 0.15083000E+04, -.16348800E+04, 0.38386500E+04, -.33668000E+04, -.13751600E+04, -.24558200E+05, 0.12366400E+05, 0.10230600E+05, -.74479600E+04, -.12028300E+04, 0.91522000E+04, 0.22797400E+04, 0.96746600E+04, -.15112100E+03, -.33894300E+05, 0.16664000E+05, 0.18729100E+05, -.73204300E+04, -.71663700E+04, 0.15888100E+05, 0.13626200E+05, 0.17869000E+05, -.19331100E+04, 0.39056700E+05, -.19588100E+05, -.15600100E+05, 0.44651300E+04, 0.86364800E+03, -.13099400E+05, -.17218400E+04, -.13546600E+05, -.22777600E+04, -.96770600E+04, 0.48450600E+04, 0.43227100E+04, 0.44469300E+04, 0.81657000E+03, 0.40959900E+03, -.28988700E+04, 0.12541900E+04, 0.22088300E+04, 0.53256200E+05, -.26703200E+05, -.26831200E+05, -.70956400E+04, -.32304600E+04, -.17693900E+05, -.10465600E+05, -.15585400E+05, -.76702100E+04, 0.87287500E+04, -.43568600E+04, -.42706100E+04, 0.72487300E+03, 0.10310200E+04, -.44833300E+04, -.43032300E+04, -.61924500E+04, -.10309500E+03, 0.58860500E+04, -.29073200E+04, -.27671800E+04, 0.65969300E+04, 0.59439400E+04, -.43605000E+04, -.50439700E+04, -.79913600E+04, 0.27668500E+04, 0.33940400E+04, -.15448800E+04, -.25623500E+04, 0.41348900E+04, 0.36078200E+04, -.22950800E+04, -.12675200E+04, -.35225900E+04, 0.20605600E+04, -.20481600E+05, 0.10067400E+05, 0.12385500E+05, -.34332900E+04, -.21382900E+04, 0.94513500E+04, 0.86910600E+04, 0.98824700E+04, 0.13208300E+03, 0.19618000E+05, -.98035200E+04, -.12383400E+05, 0.46105000E+04, 0.11456000E+04, -.75246000E+04, -.93921100E+04, -.12852700E+05, -.11972200E+04, 0.22285600E+05, -.11040000E+05, -.12193100E+05, 0.24737200E+04, 0.36589400E+04, -.76076700E+04, -.33163200E+04, -.94823500E+04, -.18532700E+03, 0.78922100E+04, -.40557500E+04, -.67289900E+04, -.27917700E+04, 0.10455500E+03, -.36041700E+04, -.45385200E+04, -.19562800E+04, -.13846500E+04, -.37466400E+04, 0.19042400E+04, 0.66799200E+03, 0.44682000E+03, 0.48291100E+03, 0.30806900E+03, -.20460100E+04, 0.47871300E+03, 0.73251200E+03, 0.76260300E+04, 0.42016900E+04, 0.42975000E+04, -.13361900E+04, 0.36956200E+04, 0.13992000E+04, -.27535700E+04, -.37568000E+04, 0.86559800E+03, -.74221400E+04, 0.23956100E+04, -.33776800E+04, -.23804900E+04, -.10881700E+05, 0.46823900E+04, -.39746000E+04, -.25340200E+03, -.10558100E+05, 0.43837600E+04, 0.12692700E+04, 0.12105600E+05, 0.13683200E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.57614900E+00, 0.23456200E+00, -.53814700E+00, 0.75955100E-01, 0.47628000E+00, 0.71631700E-01, -.10100300E+00, -.45703000E+00, -.78762100E-01, -.33370300E-01, -.25039500E+00, -.40468700E-01, 0.73497100E+00, 0.77227600E+00, -.26300500E-01, -.11149300E+00, -.10446500E+05, 0.28731700E+04, 0.11264700E+05, -.57692700E+04, -.55456400E+04, -.28969100E+04, -.12022900E+05, 0.34072000E+04, 0.93992900E+04, 0.15632700E+05, -.11363200E+05, 0.31024000E+05, -.15597200E+05, -.13639100E+05, -.27632300E+04, -.86606900E+04, -.36212300E+04, 0.72120300E+04, 0.49087600E+04, -.10768700E+05, -.31820900E+04, 0.15843300E+04, 0.15148300E+04, -.29724500E+04, 0.14533900E+04, 0.96471600E+03, -.36867500E+04, 0.36069900E+04, 0.13497400E+04, -.20520600E+04, 0.10557800E+04, 0.90308500E+03, 0.31680200E+03, 0.19250200E+04, -.97636900E+02, -.15315600E+04, -.22002300E+04, 0.16598100E+04, -.61817100E+04, 0.30533400E+04, 0.23920400E+04, -.20059500E+04, 0.17873600E+04, 0.23446900E+03, -.41157400E+04, 0.22856500E+04, 0.12619100E+04, 0.97674000E+04, -.49815100E+04, -.39304600E+04, -.37053600E+04, -.84288100E+04, 0.12078100E+04, 0.57003800E+04, 0.87466700E+04, -.85494000E+04, -.67205100E+04, 0.31507700E+04, 0.30112700E+04, 0.11392400E+04, 0.54283200E+03, -.74532500E+03, -.28117800E+04, -.27289400E+04, -.66352000E+03, -.28298600E+05, 0.14309300E+05, 0.13699000E+05, 0.15307900E+04, 0.84618600E+04, 0.41144700E+04, -.53545300E+04, -.38821700E+04, 0.95114100E+04, 0.27540100E+05, -.13586500E+05, -.12213900E+05, -.15692800E+04, -.34859700E+04, -.61759200E+04, 0.16388300E+04, -.47761600E+04, -.29394300E+04, -.40486600E+04, 0.20394400E+04, 0.11636300E+04, 0.18115500E+04, 0.70638900E+04, -.61293700E+03, -.28068300E+04, -.70575000E+04, 0.64270900E+04, 0.40316000E+05, -.20016000E+05, -.17461800E+05, 0.48449600E+04, 0.46192000E+04, -.18713600E+05, -.10938900E+05, -.27015700E+05, -.69021500E+03, 0.19891500E+05, -.99296400E+04, -.92493100E+04, -.32422200E+04, -.41121200E+04, -.35486300E+04, 0.91879400E+03, 0.19413900E+04, -.65091100E+04, 0.12429600E+05, -.62649800E+04, -.55792900E+04, -.16654300E+03, -.67345500E+04, 0.49254800E+03, 0.38831400E+04, 0.16179800E+04, -.65356000E+04, -.13513300E+04, 0.60025500E+03, 0.48548200E+03, -.20192500E+04, -.29459300E+04, 0.38175000E+04, 0.67542400E+04, 0.68813800E+04, -.28433500E+04, -.13980500E+05, 0.71135500E+04, 0.79356000E+04, -.21348600E+04, 0.64434300E+03, 0.56270300E+04, 0.13269500E+04, -.73569300E+02, 0.18119600E+04, 0.15119200E+05, -.75395400E+04, -.61301900E+04, -.97313200E+03, -.54213600E+04, -.13718800E+04, 0.21587300E+04, 0.14008500E+05, -.66661800E+04, 0.89531400E+04, -.45780100E+04, -.40429400E+04, -.18541100E+04, -.93909200E+04, 0.10803800E+04, 0.77675300E+04, 0.10953900E+05, -.86248800E+04, -.10013200E+03, 0.14628800E+03, 0.65372000E+03, 0.44672400E+04, 0.63213600E+04, -.45622200E+04, -.87350700E+04, -.14782900E+05, 0.32056100E+04, -.65334000E+03, 0.30543200E+03, -.20861200E+03, 0.15924100E+04, 0.29536900E+03, -.97072400E+03, -.20804000E+04, -.14552200E+04, -.29167400E+02, 0.34235600E+04, -.32705800E+04, -.30419900E+04, 0.21311700E+04, -.36654400E+04, -.36870400E+04, -.13417600E+04, 0.49654900E+04, 0.24238800E+04, -.13526700E+05, -.32656700E+04, -.10653800E+05, 0.29969600E+04, -.15572300E+04, -.15777300E+04, 0.38709000E+04, 0.13850900E+04, 0.17897700E+04, -.30658600E+04, 0.64268900E+03, 0.44654800E+04, 0.10224400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.27269700E-02, -.62955000E-01, -.76359800E+00, 0.55710900E+01, 0.44184200E+00, 0.18226100E+00, 0.16623000E+00, -.47621800E+00, -.38843700E+00, 0.33051400E+00, -.57661200E-01, -.13329200E+00, -.90503700E-02, 0.12434700E+00, -.52926700E+00, 0.76707700E+00, 0.39124400E+00, -.32801000E+04, -.19136100E+05, 0.93847300E+04, 0.12032400E+05, -.45174700E+04, -.56533400E+04, 0.72157300E+04, 0.30979100E+04, 0.84275800E+04, -.76745200E+03, -.16337700E+05, 0.79505800E+04, 0.66833500E+04, -.30494700E+04, -.86250200E+04, 0.62656300E+04, 0.22282900E+04, 0.11536600E+05, -.21965600E+04, 0.11011700E+05, -.54471500E+04, -.46322500E+04, 0.21562600E+04, 0.55577500E+04, -.44136500E+04, 0.66578600E+02, -.58561600E+04, 0.97763800E+03, 0.32965600E+04, -.16266800E+04, -.17811600E+04, 0.62411300E+03, 0.73967700E+03, -.13341400E+04, -.40431100E+03, -.16293800E+04, 0.10606600E+03, 0.11061700E+05, -.55083700E+04, -.31242500E+04, 0.12135000E+04, 0.48658900E+04, -.35114000E+04, 0.64169300E+03, -.58305400E+04, 0.15415400E+04, -.15850200E+05, 0.77602600E+04, 0.77983200E+04, -.25395500E+04, -.39784400E+04, 0.58690700E+04, 0.24766500E+04, 0.85208400E+04, 0.31985700E+03, 0.29988300E+05, -.14661800E+05, -.12703100E+05, -.22440800E+04, 0.63732200E+04, -.76534500E+04, 0.11756200E+04, -.80400800E+04, 0.10009100E+04, 0.18246300E+05, -.91155400E+04, -.10385500E+05, 0.49969200E+04, 0.90545800E+04, -.86044300E+04, -.47209400E+04, -.12603300E+05, 0.41104200E+04, -.45400000E+05, 0.22451600E+05, 0.18297000E+05, 0.49274000E+03, -.65164100E+04, 0.14628700E+05, 0.45680400E+04, 0.16611200E+05, -.14811700E+04, 0.86572500E+04, -.42953000E+04, -.36812700E+04, 0.13456600E+04, 0.13718400E+04, -.34609000E+04, -.14579800E+04, -.61375300E+04, -.38006300E+03, 0.56837100E+04, -.30261700E+04, -.27870200E+04, -.20058400E+04, -.95492100E+03, 0.14445700E+04, 0.94650900E+04, 0.69543300E+04, -.28218200E+04, 0.91902600E+04, -.46257800E+04, -.48544300E+04, 0.74594300E+03, -.16822800E+04, -.25307300E+04, 0.63623300E+03, -.17351200E+04, 0.37127100E+03, -.60950700E+04, 0.30898900E+04, 0.26456600E+04, -.34051200E+04, -.44181400E+04, 0.27014200E+04, 0.19786900E+04, 0.50453100E+04, -.18039700E+04, -.67212000E+04, 0.33058600E+04, 0.40626100E+04, 0.43218900E+02, -.17086700E+04, 0.12751800E+04, -.13101000E+04, 0.29337700E+03, 0.10364400E+04, -.49424800E+03, 0.23430900E+03, -.18251300E+04, 0.24297000E+04, 0.21112500E+04, -.23375700E+04, -.30406000E+04, -.30888100E+04, 0.26132600E+04, -.12734600E+05, 0.63232200E+04, 0.83448400E+04, -.20105300E+04, -.37419000E+03, 0.33658500E+04, 0.32314600E+04, 0.51777900E+04, 0.73356600E+03, -.16156100E+05, 0.80112700E+04, 0.89697900E+04, -.30618300E+04, -.43126000E+04, 0.63979100E+04, 0.16487500E+04, 0.80414700E+04, -.28602300E+03, 0.62022900E+04, -.32705900E+04, -.53094500E+03, -.12851100E+04, 0.18872200E+02, -.91701900E+03, 0.36708300E+04, 0.53399600E+03, 0.30807000E+03, 0.11231800E+05, -.55164900E+04, -.43568100E+04, 0.16144800E+03, 0.24907500E+04, -.36984800E+04, -.10829800E+04, -.43367400E+04, 0.18100300E+03, -.56430800E+04, -.39938900E+04, -.45163300E+04, 0.79064800E+03, -.24945200E+04, -.18768200E+04, 0.22661700E+04, 0.36350200E+04, -.22579800E+04, -.30201100E+03, 0.42803100E+03, -.97685900E+03, -.57812600E+04, 0.73172000E+04, -.51440800E+04, 0.39272000E+04, -.23087100E+04, 0.43759500E+04, -.39378400E+04, -.13343200E+04, -.63815600E+04, -.92561300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12085800E+01, 0.17284100E+01, 0.86207000E+00, 0.15499300E+01, -.15229700E+00, 0.27875700E+00, 0.47525800E+00, 0.12934000E+01, -.19550600E+01, 0.64678100E+00, -.42895800E+00, 0.41036000E+00, -.16551400E+01, 0.14731400E+01, 0.11500700E+01, 0.33240600E+01, 0.60734500E+00, 0.85860100E+00, -.60019600E+05, 0.28643900E+05, 0.40666100E+05, -.14736200E+05, -.13401300E+05, 0.20307000E+05, 0.19960900E+05, 0.16672200E+05, 0.13105300E+03, -.10041500E+06, 0.48304300E+05, 0.42899500E+05, -.11415200E+05, 0.88689800E+03, 0.30527800E+05, 0.16516900E+05, 0.31496600E+05, 0.97038500E+04, 0.50619400E+05, -.25060500E+05, -.22384900E+05, 0.16841600E+05, 0.11829000E+05, -.24125600E+05, -.15914900E+05, -.23029200E+05, 0.49238700E+04, 0.14210000E+05, -.70041200E+04, -.77450500E+04, 0.15376400E+04, 0.12849500E+04, -.54982800E+04, -.40122900E+04, -.40947600E+04, -.54131700E+03, 0.33077600E+05, -.16531500E+05, -.87333100E+04, 0.13492600E+05, 0.48871300E+04, -.10234500E+05, -.21395900E+04, -.12767400E+05, 0.96142000E+03, -.42510500E+05, 0.20545700E+05, 0.20587100E+05, 0.74005900E+04, -.15945200E+04, 0.10978200E+05, 0.10855200E+05, 0.11163600E+05, 0.60104300E+04, -.93053200E+04, 0.58804100E+04, 0.12716700E+05, 0.69296200E+04, -.12774000E+05, 0.84131500E+04, 0.50392500E+04, 0.12456400E+05, -.42718400E+03, 0.46357700E+05, -.22235800E+05, -.29955900E+05, 0.22360200E+05, 0.85391000E+04, -.20111400E+05, -.23172700E+05, -.20772300E+05, 0.59833000E+03, -.59896300E+05, 0.29273800E+05, 0.12750300E+05, 0.13309300E+04, 0.17499800E+05, 0.11254000E+05, -.57196700E+04, 0.82895200E+04, 0.15463700E+05, 0.33710300E+05, -.17002200E+05, -.13945000E+05, -.45297100E+04, 0.51277500E+03, -.13294100E+05, -.21629100E+05, -.14784100E+05, -.36181700E+04, -.21961700E+06, 0.10924700E+06, 0.10569500E+06, -.51619500E+04, 0.91830400E+04, 0.78029100E+05, 0.34521100E+05, 0.92839200E+05, 0.29101900E+05, -.44330100E+05, 0.21953500E+05, 0.20975500E+05, -.10162500E+03, 0.59043400E+04, 0.14239600E+05, 0.49586100E+04, 0.14216100E+05, 0.65186800E+04, -.11576500E+05, 0.60772700E+04, 0.49166700E+04, -.17435200E+05, -.91468200E+04, 0.30236900E+04, 0.90175300E+04, 0.97592000E+04, -.12568500E+04, -.86212300E+04, 0.31722500E+04, 0.76166900E+04, -.18807900E+04, -.65152100E+04, -.67292200E+03, -.87351700E+04, -.57058200E+04, -.26911200E+04, 0.45440800E+05, -.22234200E+05, -.32222600E+05, 0.17695500E+05, 0.42669600E+04, -.23424200E+05, -.17261500E+05, -.18004900E+05, -.22175600E+04, -.59138500E+05, 0.29423900E+05, 0.36894200E+05, -.13313700E+05, -.11384200E+03, 0.17329600E+05, 0.20124900E+05, 0.17665200E+05, 0.76472500E+04, -.62555400E+05, 0.30921300E+05, 0.34706300E+05, -.71935700E+04, -.72884300E+04, 0.23909300E+05, 0.20179300E+05, 0.17663500E+05, 0.21562400E+04, -.46825400E+05, 0.22889500E+05, 0.32923900E+05, -.88615800E+04, -.75786300E+04, 0.23941200E+05, 0.22622200E+05, 0.38428000E+05, 0.10325800E+04, -.17953300E+05, 0.91634900E+04, 0.14261700E+05, -.94758400E+04, -.48841400E+04, 0.12000800E+05, 0.13591100E+05, 0.11523400E+05, -.92735200E+03, -.21873700E+05, -.74940700E+04, -.76665900E+04, -.29710100E+03, -.77522500E+04, -.14596800E+04, 0.63962800E+04, 0.63044400E+04, -.16204100E+04, 0.22561400E+05, -.36355900E+04, 0.10836500E+05, -.50149100E+04, 0.25969300E+05, -.73369300E+04, 0.76869500E+04, -.39834100E+04, 0.51021000E+04, -.78633100E+04, -.30704100E+04, -.33867000E+05, -.10527800E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12277400E+01, -.15183500E+00, -.67400500E+00, 0.22278900E+01, -.10680900E+01, -.38198800E+00, -.13556700E+00, -.54790000E+00, 0.67164300E+00, -.39991400E+00, -.24347700E+00, -.35796000E+00, 0.17898000E+01, -.37510700E+00, 0.74827100E+00, -.89558900E+00, -.78608700E+00, -.94159400E+00, -.66919500E+00, -.82895400E+03, 0.69999400E+04, 0.30752900E+04, 0.79858300E+04, -.27152700E+04, 0.11406300E+05, 0.42783100E+03, 0.69137800E+04, -.88653300E+04, 0.33605700E+04, 0.18529400E+04, 0.69766300E+04, 0.17539200E+05, -.30429000E+04, 0.15204000E+04, -.11899700E+03, 0.11993400E+05, 0.27187500E+04, -.12266700E+04, 0.47676400E+03, 0.43751700E+03, -.18165600E+04, -.31147600E+04, -.60619500E+04, -.26761900E+04, -.34487900E+03, 0.13354800E+04, -.59845000E+03, -.11157800E+04, -.25487300E+03, -.53067300E+03, -.87440300E+03, -.25002600E+04, -.26401800E+03, -.40788500E+03, 0.56818000E+03, -.30486200E+03, 0.43972500E+04, -.13079000E+04, -.32912800E+04, 0.13045600E+04, -.19681700E+03, -.27662600E+04, -.20982800E+04, 0.53038400E+03, -.83119700E+03, 0.52138100E+03, 0.45732400E+04, 0.55398100E+04, -.50660300E+03, 0.10471500E+05, 0.10448400E+04, 0.37532200E+04, -.25814200E+05, 0.13664000E+05, 0.17865300E+05, -.87333700E+04, -.15974800E+05, 0.13812600E+05, -.19917300E+04, 0.17139700E+05, -.68241300E+04, -.10293500E+05, 0.55411400E+04, -.89752300E+02, 0.16922300E+03, -.97559500E+04, 0.55138800E+04, -.35828800E+04, -.10207900E+04, -.55541600E+04, 0.32835500E+04, -.20228200E+04, -.11123100E+05, 0.10121500E+05, 0.16818200E+05, -.60966200E+04, 0.38938000E+04, -.83667000E+04, 0.10484500E+05, 0.34018500E+04, -.17621800E+04, -.10720500E+04, -.65572400E+03, -.49066900E+03, -.39922000E+04, -.12738800E+05, -.51521000E+04, 0.40667700E+03, -.45965700E+05, 0.22635800E+05, 0.23775400E+05, -.79231900E+04, 0.13563900E+04, 0.21015600E+05, 0.14508700E+05, 0.31444000E+05, 0.30854600E+04, -.22319300E+05, 0.10994500E+05, 0.11246800E+05, 0.21909100E+04, 0.57621400E+04, 0.45950400E+04, 0.70450700E+03, 0.86627500E+04, 0.55419500E+04, -.77849100E+04, 0.40300600E+04, 0.45413700E+04, -.16145700E+04, 0.15456000E+04, -.35005500E+03, 0.29814800E+04, 0.13467700E+05, 0.37574500E+04, 0.52677500E+04, -.32070000E+04, -.99637700E+03, 0.33055000E+04, 0.25926700E+04, -.43911400E+04, -.11351300E+04, -.59298300E+04, 0.23741800E+04, -.66765300E+04, 0.34640900E+04, -.14477900E+04, 0.43687600E+04, -.19548300E+04, -.81020500E+03, -.28694600E+04, 0.93692800E+03, -.61196100E+03, -.66677100E+04, 0.32577100E+04, 0.96308300E+04, -.27399100E+04, 0.19140900E+04, 0.11966900E+04, 0.95993700E+04, 0.14605600E+04, 0.29661300E+04, -.11749200E+04, 0.38135000E+03, 0.33308600E+04, 0.16234600E+04, 0.36820500E+04, 0.20072000E+04, 0.11704600E+05, -.51105900E+03, 0.25107800E+04, -.56067700E+04, 0.24215700E+04, 0.97909200E+04, -.82735000E+04, -.54151800E+04, 0.72082300E+04, 0.10093600E+05, 0.15391400E+05, -.39775900E+04, -.76591400E+04, 0.40437000E+04, 0.66338800E+04, -.45406600E+04, -.30539200E+04, 0.46393200E+04, 0.23467200E+04, 0.42111900E+04, -.11910200E+04, -.95331800E+03, 0.34648800E+04, 0.34649700E+04, -.15228200E+03, -.39353600E+04, 0.27642800E+04, -.13268700E+04, -.40211000E+04, 0.10065500E+04, 0.45268000E+02, -.69166700E+04, -.36272000E+04, 0.13253500E+04, 0.31429100E+04, 0.44934300E+04, -.57006000E+04, 0.10251400E+04, -.53980900E+04, 0.35649300E+04, 0.66266800E+03, -.53192300E+04, 0.14203900E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25626800E+01, 0.78507000E+00, -.10690500E+01, -.93255200E+01, 0.40733500E+01, 0.50359100E+00, -.64168300E+00, -.22011000E+01, 0.40060300E+01, -.25063500E+00, 0.28017900E+01, -.60084700E+00, -.41106200E+01, -.56799800E+00, -.36537100E+01, -.42969100E+01, 0.71959900E+00, 0.75772700E+00, -.10492700E+01, -.13308400E+01, 0.10656900E+05, 0.74968900E+03, 0.23425700E+05, -.66327200E+04, 0.16899500E+05, -.36705900E+04, 0.16292200E+05, -.51479400E+05, 0.25345500E+05, 0.18368100E+05, 0.27737000E+04, 0.38981300E+05, 0.64413600E+04, 0.48439400E+04, 0.87750400E+04, 0.29695600E+05, 0.14613000E+05, -.71978000E+04, -.46731500E+04, 0.92753400E+04, -.10735900E+05, -.82505400E+04, -.80784900E+04, -.24237600E+04, -.37342000E+04, 0.47727400E+04, -.24998800E+04, -.31381900E+04, -.43028600E+03, -.36331900E+04, -.17052300E+04, -.41666200E+04, 0.15326600E+03, -.24241500E+04, 0.16333700E+05, -.80590300E+04, -.38150600E+03, 0.74921700E+04, -.11583600E+05, -.38269700E+03, 0.62767800E+04, -.39649000E+04, -.74211800E+04, 0.26234500E+04, -.11221500E+04, -.19611200E+04, 0.17967600E+05, 0.22541700E+05, -.75843900E+04, 0.97564800E+04, -.61796000E+04, 0.14216400E+05, -.45493600E+05, 0.24076200E+05, 0.30836500E+05, -.80230100E+04, -.44922200E+05, 0.30675000E+05, 0.36473200E+04, 0.41021200E+05, -.22968300E+05, -.12443500E+05, 0.61796200E+04, -.96277800E+02, 0.14530200E+05, -.22077000E+05, 0.23629400E+04, -.13870700E+05, -.80446600E+04, -.13496600E+05, -.18677400E+05, 0.83533200E+04, -.73724600E+04, 0.13929300E+05, 0.53595300E+05, -.10993800E+05, -.28121100E+04, -.20921200E+05, 0.36615200E+05, 0.14842700E+05, -.76479500E+04, -.48904700E+04, -.76093200E+04, -.94555400E+04, -.94427100E+04, -.29323000E+05, -.11834600E+05, -.55798100E+04, -.22688500E+06, 0.11257800E+06, 0.11042600E+06, -.14163200E+05, 0.79886300E+04, 0.86725300E+05, 0.41716000E+05, 0.94158900E+05, 0.26270300E+05, -.66545000E+05, 0.33082300E+05, 0.32562600E+05, -.14399800E+04, 0.65861700E+04, 0.21536200E+05, 0.98765800E+04, 0.25144200E+05, 0.93817400E+04, -.17733800E+05, 0.92879100E+04, 0.79458100E+04, -.15082900E+05, -.59748500E+03, 0.41415500E+04, 0.59611400E+04, 0.27025900E+05, 0.38773900E+04, 0.23666700E+05, -.12330000E+05, -.85513200E+04, 0.53362400E+04, 0.80815200E+04, -.16288000E+05, -.13608000E+05, -.21151200E+05, 0.28321100E+04, 0.34090000E+05, -.16973900E+05, -.26295900E+05, 0.18713200E+05, 0.13442900E+04, -.23129500E+05, -.18520100E+05, -.20573800E+05, -.31441900E+04, -.43427300E+05, 0.21656400E+05, 0.29389800E+05, -.87721300E+04, 0.89448100E+04, 0.99030500E+04, 0.23095100E+05, 0.13885300E+05, 0.12987300E+05, -.98473200E+04, 0.53359700E+04, 0.87448200E+04, 0.27658400E+04, 0.19399400E+05, 0.33850400E+04, 0.19458000E+05, -.40781700E+04, 0.11712000E+05, -.52693800E+05, 0.25690100E+05, 0.35480700E+05, -.12145200E+05, -.77171400E+04, 0.27463400E+05, 0.24829300E+05, 0.35754300E+05, -.23230300E+03, -.44750000E+05, 0.22408500E+05, 0.27347300E+05, -.13394000E+05, -.13984300E+05, 0.24592100E+05, 0.18681000E+05, 0.25335800E+05, -.51200600E+04, -.49786500E+04, 0.10521600E+05, 0.10395000E+05, -.19786000E+04, -.24051300E+04, 0.10375200E+05, -.19402000E+04, -.13141700E+05, -.16775800E+04, 0.34852800E+05, -.68862200E+04, 0.16805900E+05, 0.53533200E+04, 0.10157500E+05, 0.10737200E+05, -.12532600E+05, 0.40603400E+04, -.12170700E+05, 0.97045100E+04, 0.11278600E+04, -.19614400E+05, -.72280800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.50988300E+00, 0.61607600E-01, 0.11587800E+01, 0.19593000E+01, -.13472500E+00, -.17771100E+00, 0.22900600E+00, 0.42276100E+00, -.10694000E+01, 0.12865000E+00, -.77609700E+00, 0.29505600E+00, 0.70322200E+00, 0.21940600E+00, 0.28109600E+00, 0.11171600E+01, 0.38307400E+00, 0.39155400E+00, 0.35348200E+00, -.26359400E+00, 0.12583900E+00, 0.18734400E+04, -.18847600E+03, -.44886900E+03, -.29923200E+04, 0.47322400E+03, 0.23594900E+03, -.24662700E+03, 0.25690300E+03, 0.18308100E+04, 0.26101800E+04, -.71990400E+03, -.35675000E+03, -.22464900E+04, -.92087000E+03, -.51355100E+03, -.48275600E+04, 0.24011100E+04, 0.25248800E+04, -.25457200E+04, 0.95662500E+03, 0.22770500E+04, 0.14241800E+04, 0.33849500E+03, 0.42929000E+03, -.13473700E+04, 0.71853200E+03, 0.69606600E+03, 0.17777600E+01, 0.44310000E+03, 0.48924500E+03, 0.66814100E+03, 0.24292400E+03, 0.34258200E+03, -.38314200E+04, 0.18942100E+04, 0.18444600E+04, -.27577600E+04, 0.98155500E+03, 0.69494300E+03, -.94908900E+03, -.62186000E+03, 0.74972800E+03, 0.15468700E+04, -.92485900E+03, 0.82434700E+02, -.33626600E+04, -.18383000E+04, 0.34551900E+02, -.22126100E+04, -.56658500E+03, -.15197200E+04, 0.43762800E+04, -.24759400E+04, -.23358400E+04, 0.34637000E+02, 0.47447600E+04, -.37368800E+04, -.11721700E+04, -.54091500E+04, 0.32427800E+04, 0.11905900E+05, -.60997300E+04, -.65637700E+04, -.56430600E+04, -.20943800E+04, -.12532900E+04, 0.37430000E+04, 0.35635100E+02, -.26225000E+04, 0.66540400E+04, -.31297700E+04, -.23217200E+04, -.13069800E+04, -.69690900E+04, 0.33431200E+03, 0.36636300E+03, 0.21794100E+04, -.53946500E+04, -.34739300E+04, 0.18531900E+04, 0.94251100E+03, 0.10647800E+04, 0.23068500E+03, 0.25319300E+04, 0.61719800E+04, 0.40512200E+04, 0.36242500E+03, 0.39483300E+05, -.19671300E+05, -.17328800E+05, 0.13129800E+04, -.38562100E+04, -.13607900E+05, -.60334400E+04, -.12848500E+05, -.58672800E+04, 0.68027400E+04, -.33927800E+04, -.28976500E+04, 0.10686800E+04, 0.19936900E+03, -.32676900E+04, -.19673900E+04, -.20916100E+04, -.51374400E+03, -.51405600E+03, 0.12378800E+03, 0.11089400E+04, 0.46295200E+04, 0.19576800E+04, -.92111500E+03, -.10609000E+04, -.34262100E+03, 0.13056500E+04, -.34517500E+04, 0.19947800E+04, 0.12906100E+04, -.55428300E+03, -.16486400E+03, 0.23211500E+04, 0.27995200E+04, 0.37414000E+04, 0.51992000E+03, -.89043300E+03, 0.30369400E+03, 0.14792000E+04, -.49406200E+04, -.17887100E+04, 0.30911400E+04, 0.41974500E+04, 0.35601400E+04, -.12510900E+04, 0.10026800E+05, -.50168400E+04, -.39932600E+04, 0.18832000E+04, -.12864200E+04, -.23215800E+04, -.38498900E+04, -.39326700E+04, -.17274500E+04, 0.45803600E+04, -.24245300E+04, -.20225900E+04, -.17166600E+02, -.19503000E+04, -.18370000E+04, -.32759100E+04, -.94336800E+03, -.13150600E+04, 0.13526800E+05, -.66866600E+04, -.59387700E+04, 0.39517000E+03, -.90499400E+03, -.48121100E+04, -.25259700E+04, -.43611500E+04, -.19255500E+04, 0.67913300E+04, -.33432800E+04, -.38001000E+04, 0.31845900E+04, 0.19620900E+04, -.42226200E+04, -.41207800E+04, -.44843700E+04, 0.97305600E+03, 0.17915200E+04, -.93954000E+03, -.88426200E+03, 0.39548800E+03, 0.16379000E+03, -.13446000E+04, -.10883700E+03, 0.11047700E+04, -.34831500E+03, -.52413400E+04, -.24933800E+03, -.30419700E+04, -.92617000E+03, -.20304100E+04, -.52341400E+03, 0.97116600E+02, -.39303900E+03, 0.25662700E+04, -.65517500E+03, -.89897600E+02, 0.39070800E+04, 0.46499400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14690900E+00, 0.15299200E+00, -.19475600E+00, 0.11695200E+01, -.20671900E+00, -.87870100E-02, 0.98214700E-01, 0.11599900E+00, 0.22946600E+00, 0.40746300E-01, 0.64815300E-01, 0.86744400E-02, -.35151600E-01, -.12520200E+00, -.98839400E-01, 0.19770100E+00, 0.39852200E-01, 0.60645000E-01, 0.58355400E-01, -.90892200E-01, -.30491900E-03, 0.23449100E+00, 0.14749400E+04, -.34669200E+03, 0.57384400E+02, 0.38679700E+03, 0.96434900E+03, -.53276200E+04, 0.26312300E+04, 0.23456100E+04, -.29248100E+02, 0.19413100E+04, 0.12742800E+04, 0.30757200E+03, 0.12365800E+04, 0.16882700E+04, 0.69342000E+03, -.34890800E+03, -.36701200E+03, 0.76375300E+03, -.76545300E+03, -.27105300E+03, 0.12145900E+03, 0.23687500E+03, -.37005600E+03, 0.19318600E+03, -.10604900E+03, -.10139100E+03, -.36264200E+02, -.31810100E+03, 0.31341200E+01, 0.22052700E+02, 0.79560100E+02, -.20223800E+03, 0.15440400E+04, -.76787000E+03, -.71737200E+03, 0.88358000E+03, -.64144100E+03, -.32584800E+03, 0.33052700E+03, -.45946500E+03, -.40207500E+03, 0.17734500E+03, -.63701200E+02, -.24383400E+03, 0.12098800E+04, 0.14199400E+04, -.70151400E+03, -.61069100E+03, -.60666900E+03, 0.87921000E+03, 0.34457300E+02, 0.26906100E+01, 0.45470500E+02, 0.50074400E+03, -.14436300E+04, 0.57131300E+03, 0.21902200E+03, 0.94231600E+03, -.10935400E+04, 0.29330200E+04, -.14239500E+04, -.13267400E+04, 0.89245400E+03, -.98464600E+03, -.13937700E+04, -.13476600E+04, -.19349600E+04, -.63102000E+03, -.38502000E+04, 0.19133700E+04, 0.17221300E+04, -.36824800E+02, 0.20948500E+04, 0.63596600E+03, -.90394200E+02, 0.32374900E+02, 0.16671100E+04, 0.29242100E+03, -.17853800E+03, -.27616300E+02, -.66706900E+03, -.10034900E+04, 0.23046800E+02, -.43227800E+03, 0.10705800E+03, -.57493400E+03, -.13564600E+05, 0.67926400E+04, 0.64456200E+04, 0.31946900E+03, 0.10479900E+04, 0.48220000E+04, 0.22308400E+04, 0.35850000E+04, 0.18279400E+04, -.34050800E+04, 0.16985200E+04, 0.16274600E+04, -.38967100E+03, -.15951500E+03, 0.14220400E+04, 0.85039000E+03, 0.15517800E+04, 0.27939800E+03, -.15432100E+04, 0.78430900E+03, 0.61036400E+03, -.10881100E+04, -.75867800E+02, 0.80883300E+03, 0.55591300E+03, 0.22479400E+04, 0.55093600E+02, 0.15904800E+04, -.85417600E+03, -.72507100E+03, -.72611600E+01, 0.19115000E+03, -.82314900E+03, -.77865700E+03, -.71512500E+03, 0.21861100E+02, 0.32784500E+04, -.16179200E+04, -.18092100E+04, 0.95537700E+03, 0.67473000E+02, -.17968700E+04, -.15675600E+04, -.18519900E+04, -.23028300E+03, -.29329200E+04, 0.14690300E+04, 0.13023300E+04, -.23140600E+03, 0.74220500E+03, 0.69931100E+03, 0.89027100E+03, 0.12349300E+04, 0.70686200E+03, -.26971700E+03, 0.16361200E+03, 0.10245300E+03, 0.24110300E+03, 0.15137500E+04, -.19488900E+03, -.66140500E+02, -.43187100E+03, 0.95357500E+03, -.38272500E+04, 0.19200400E+04, 0.17635500E+04, 0.23128400E+03, 0.23154100E+03, 0.14450200E+04, 0.99752600E+03, 0.81633600E+03, 0.51873900E+03, -.18019900E+04, 0.89456100E+03, 0.97024700E+03, -.66490700E+03, -.56140600E+03, 0.11238800E+04, 0.11756800E+04, 0.12215500E+04, -.13193200E+03, -.20422000E+03, 0.67410500E+03, 0.63361300E+03, 0.72872500E+01, 0.15775400E+03, 0.67392600E+03, -.40835200E+02, -.82578300E+03, -.18843800E+03, 0.27376800E+04, -.12094600E+03, 0.17895800E+04, 0.61223300E+03, 0.51670200E+03, 0.53389100E+03, -.76896900E+03, 0.44049000E+03, 0.13070500E+02, 0.48096800E+03, 0.44851300E+02, -.11160300E+04, -.20897100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.80255000E+00, 0.38577200E+00, -.44105300E+00, -.50939600E+01, 0.35294800E+00, 0.34799500E+00, -.57620100E-01, -.50900500E+00, 0.24102800E+01, 0.21121900E+00, 0.20242400E+01, -.87391800E+00, 0.10296700E+01, 0.11504000E+01, 0.26294300E+00, 0.14251200E+01, -.18784700E-01, 0.11170200E+01, -.72956900E+00, -.29265700E+00, -.18934200E+00, -.48029200E+00, 0.30933400E+01, 0.49989100E+04, 0.21559600E+05, 0.83780700E+04, 0.64029700E+03, 0.52258500E+04, -.25548600E+04, -.28573100E+04, 0.49215500E+04, 0.14197700E+05, -.26993100E+03, 0.11957800E+05, -.72656200E+03, 0.73287000E+04, -.20316200E+03, 0.40691100E+02, -.27164300E+03, 0.83871400E+03, -.11036200E+04, -.35086700E+04, -.13926200E+05, -.20178900E+04, 0.15987700E+03, 0.10228000E+04, -.47505500E+03, -.60741900E+03, -.58865900E+02, 0.36498200E+03, -.11339700E+04, -.35587100E+04, -.12296800E+04, 0.17314100E+03, -.41278000E+04, 0.20081300E+04, 0.13164700E+04, 0.11097100E+04, -.29210900E+04, -.53404800E+03, -.87723500E+04, -.36254600E+03, -.19779300E+04, 0.77194700E+04, -.40030600E+04, -.39292500E+04, 0.16235500E+04, 0.38647800E+04, -.19240000E+04, 0.75050700E+04, -.11576100E+04, 0.73432000E+03, -.63916400E+05, 0.31336200E+05, 0.31429700E+05, -.27269900E+04, -.20766100E+05, 0.21678900E+05, 0.38498900E+03, 0.23270200E+05, -.58571100E+04, -.95950000E+04, 0.49030300E+04, 0.47147300E+04, -.23109300E+04, -.96073800E+04, 0.30126700E+02, -.13579700E+05, -.18337000E+04, -.54943900E+04, 0.57481100E+05, -.28263100E+05, -.27961600E+05, 0.34951300E+04, 0.19589300E+05, -.20536300E+05, -.18980100E+04, -.22824400E+05, 0.83355400E+04, -.27594500E+04, 0.14571100E+04, 0.11091200E+04, -.33367000E+04, -.47307400E+03, 0.76687600E+03, -.49261600E+04, 0.30663000E+03, 0.20949400E+04, -.34454200E+05, 0.17373300E+05, 0.16665900E+05, 0.90868700E+04, 0.79456000E+04, 0.90991700E+04, -.34146000E+04, 0.68493900E+04, 0.85911900E+04, -.68826500E+04, 0.34008200E+04, 0.37569300E+04, 0.24931500E+04, 0.32284600E+04, 0.11977100E+04, -.43252400E+04, 0.29962800E+04, 0.10909400E+04, -.64793800E+04, 0.30521500E+04, 0.34441100E+04, -.14749600E+04, -.28890400E+04, 0.49578000E+04, 0.10027700E+05, 0.91738800E+04, 0.71392500E+03, -.42680100E+03, 0.37311500E+03, 0.22643800E+03, -.27094800E+04, -.70465300E+03, 0.30632100E+04, 0.93785700E+04, 0.37590800E+04, -.22673300E+03, 0.40582700E+04, -.19984400E+04, -.19641900E+04, -.38307800E+04, -.38734900E+04, -.94984900E+03, -.79664600E+03, -.20024700E+04, -.37788200E+04, -.10054100E+05, 0.50263500E+04, 0.49029600E+04, -.15146600E+03, 0.50221100E+03, 0.57227700E+04, 0.10107100E+05, 0.72378900E+04, 0.33536600E+04, 0.22932800E+03, -.21122900E+03, -.27354000E+02, 0.98419200E+03, -.59138500E+02, 0.36125300E+04, 0.17059100E+05, 0.40818900E+04, -.79556300E+03, -.75033400E+04, 0.39606200E+04, 0.31878400E+04, 0.23746300E+04, 0.60951300E+02, 0.26430700E+04, -.56274100E+02, 0.16149500E+04, 0.40156400E+03, -.91961600E+04, 0.45615100E+04, 0.43175100E+04, 0.22817600E+04, -.44749500E+04, 0.24455900E+04, -.30364300E+04, 0.27473300E+04, -.24294700E+04, -.10572400E+01, 0.23975200E+04, 0.22156100E+04, 0.43809000E+03, -.54737900E+04, 0.19786900E+04, -.19969000E+04, -.26393600E+04, 0.74380300E+03, -.37375800E+04, -.12337200E+05, -.66002400E+04, 0.49247700E+04, -.46938000E+03, 0.38533100E+04, -.33597900E+04, 0.44816000E+04, 0.67218000E+04, 0.16411500E+04, 0.11546100E+04, -.12068700E+04, 0.30988700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13779600E-01, 0.12887100E-01, 0.46107900E+00, -.55555100E+01, 0.26035100E-01, -.23484400E+00, -.14336200E+00, 0.65259700E+00, 0.11085100E+01, -.17135200E+00, 0.53862700E+00, -.31387100E-01, -.10004100E+01, 0.35105900E+00, -.40841600E+00, -.18681300E+01, 0.40593800E+00, -.13326600E+00, -.53573500E+00, -.24368600E+00, 0.14543300E+00, -.14869700E+00, 0.10921100E+00, -.29249500E+00, 0.49536600E+04, -.92892500E+03, 0.76129200E+03, 0.86341800E+04, -.43536600E+04, -.62707400E+04, 0.32954800E+03, 0.45214100E+04, -.46676700E+04, -.24273800E+03, -.54474300E+04, 0.27473100E+04, 0.10138200E+04, -.51871600E+03, -.54776100E+03, 0.13597600E+04, -.66177800E+02, -.17603800E+04, -.31105000E+04, 0.12060000E+04, 0.69169300E+02, 0.10270100E+04, -.51442700E+03, -.48126400E+03, -.16992900E+03, -.12765500E+03, -.45388500E+03, -.12401800E+04, -.80284000E+02, -.27599300E+03, -.24873900E+04, 0.12373600E+04, 0.16018500E+04, 0.39683500E+03, -.19171900E+04, 0.16104800E+04, 0.11035600E+04, 0.38653100E+04, -.14934100E+04, -.13889300E+04, 0.67058500E+03, -.33524500E+03, 0.21713300E+04, 0.16155700E+04, 0.57716600E+03, 0.58627200E+04, 0.97474500E+03, 0.14563500E+04, -.40074800E+05, 0.20002500E+05, 0.20189800E+05, -.19730800E+04, -.78609000E+04, 0.15104200E+05, 0.33783800E+04, 0.16848900E+05, -.13492100E+04, -.22249600E+05, 0.11085300E+05, 0.11649900E+05, 0.27259000E+04, -.24349500E+03, 0.68201400E+04, -.64026600E+03, 0.65497500E+04, 0.11020900E+04, 0.27458500E+05, -.13669500E+05, -.15054400E+05, 0.28688500E+04, 0.87762800E+04, -.11649500E+05, -.38104500E+04, -.14235800E+05, 0.40089700E+04, 0.31481700E+04, -.15739100E+04, -.73566300E+03, -.27533400E+03, 0.37814200E+03, -.25873500E+04, -.84810800E+04, -.39703900E+04, 0.31226800E+03, -.43335100E+05, 0.21631000E+05, 0.18700600E+05, -.25356700E+04, 0.44028100E+04, 0.12775100E+05, -.11840900E+04, 0.12556900E+05, 0.67692100E+04, -.78639100E+04, 0.39078300E+04, 0.33809600E+04, -.65098000E+03, 0.11819300E+04, 0.28720000E+04, -.92599300E+03, 0.22726300E+04, 0.87306900E+03, 0.50906900E+04, -.25450500E+04, -.32897300E+04, -.31932300E+04, -.14162800E+04, -.91557300E+03, 0.64346900E+03, -.78788200E+03, -.94873700E+03, 0.27129600E+04, -.13421700E+04, -.10615100E+04, 0.15242900E+04, -.10955000E+03, -.16966800E+04, -.17279800E+04, -.35020300E+04, -.46631200E+02, -.49750800E+03, 0.18355000E+03, -.79813600E+03, 0.21693100E+04, -.10103400E+04, -.11261300E+03, -.19989800E+02, 0.81007800E+03, -.89744400E+03, -.44165800E+04, 0.21987100E+04, 0.87588400E+03, -.27732200E+03, 0.13500500E+04, -.45834200E+03, 0.22664900E+04, 0.44194200E+03, 0.29510300E+04, -.24514600E+04, 0.12409300E+04, 0.87526500E+03, 0.72227800E+03, 0.78785100E+03, 0.14390700E+04, 0.61571900E+04, -.24947500E+03, 0.99328900E+03, -.13957900E+05, 0.69623800E+04, 0.62464100E+04, -.31493400E+04, -.13560300E+04, 0.57115200E+04, 0.19498000E+04, 0.72684900E+04, -.66113100E+02, -.11167600E+05, 0.55761100E+04, 0.60079800E+04, -.22516400E+04, -.20192600E+04, 0.49548200E+04, 0.27063600E+04, 0.49892100E+04, -.62779900E+03, -.10461700E+04, 0.12985600E+04, 0.14761400E+04, -.49406700E+03, -.10999000E+04, 0.12995800E+04, -.44150900E+03, -.91300300E+03, 0.79000000E+03, 0.12660100E+03, -.15920300E+04, 0.20358500E+03, -.79386000E+02, -.10009300E+04, 0.17798300E+04, -.39954600E+03, 0.66105600E+02, -.42199800E+04, 0.15928500E+04, 0.29291800E+03, -.13227100E+04, 0.62519800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.77407700E+00, -.22231200E+00, 0.40237500E+00, 0.22441900E+01, -.61833600E-01, -.26438100E+00, 0.14138900E+00, 0.39459300E+00, -.13200000E+01, -.91582600E-01, -.85362400E+00, 0.74397500E+00, -.68235000E+00, -.82396700E+00, -.81302900E+00, -.17245300E+01, 0.11215000E+00, -.46559800E+00, 0.24734200E+00, -.36326500E+00, 0.23984100E+00, 0.11990000E+01, 0.72457600E+00, -.49127600E+00, 0.97353900E+00, 0.57023600E+04, -.11456800E+04, -.14531900E+05, 0.71878700E+04, 0.83520600E+04, 0.70135300E+03, 0.79565000E+03, 0.50945100E+04, 0.18173700E+04, 0.71024600E+04, 0.15547400E+04, -.34478900E+03, 0.17543100E+03, -.73251500E+01, 0.30416700E+03, 0.26285400E+03, 0.55858200E+03, 0.59564800E+02, -.10178500E+04, 0.55817200E+03, -.16824000E+03, 0.64515200E+02, 0.35639700E+01, 0.14288100E+03, 0.23173700E+03, 0.53714700E+02, 0.31499000E+03, -.31026300E+03, 0.25911400E+03, -.91787200E+03, 0.45920600E+03, -.37576700E+03, 0.14151600E+04, 0.86389300E+03, -.25223300E+03, -.14928600E+04, -.29376900E+04, 0.11016700E+04, 0.25383300E+04, -.10874500E+04, -.65592900E+03, 0.15353100E+04, -.36940700E+03, -.14868200E+04, -.36161800E+04, 0.66483600E+02, -.46133900E+03, 0.19119900E+05, -.95043100E+04, -.10021700E+05, 0.37970700E+04, 0.26011100E+04, -.72936100E+04, -.19707100E+04, -.85670800E+04, -.24515900E+03, 0.16767900E+05, -.81032700E+04, -.88140600E+04, -.60308400E+03, -.10820100E+04, -.57223300E+04, -.30659800E+04, -.93676400E+04, -.18381300E+04, -.18336300E+05, 0.91170600E+04, 0.10471200E+05, -.29136500E+04, -.23200000E+04, 0.71296400E+04, 0.18247600E+04, 0.82916000E+04, -.31670100E+03, -.23220700E+02, -.39198400E+02, -.54965500E+03, -.14148700E+04, 0.47529100E+03, 0.54284400E+03, 0.30879000E+04, 0.88775300E+03, -.28015300E+03, 0.39053800E+03, -.10800200E+03, 0.10394900E+04, 0.40511600E+04, 0.11650900E+04, 0.83418500E+03, 0.44313200E+04, -.15994400E+04, 0.77284100E+03, -.69091300E+04, 0.34892600E+04, 0.38742500E+04, 0.64540000E+03, 0.10858800E+04, 0.16302000E+04, 0.18919600E+04, 0.52670800E+04, 0.15858900E+04, -.34718100E+04, 0.18004700E+04, 0.22532700E+04, 0.64668800E+03, 0.88350900E+03, 0.87066500E+03, 0.18658600E+04, 0.74599400E+04, 0.26282200E+03, 0.18868800E+04, -.11284100E+04, -.10311100E+04, -.14842100E+04, -.35758100E+03, -.12296700E+03, 0.96480800E+03, 0.22151700E+04, -.14399700E+04, 0.45333100E+04, -.19504400E+04, -.16942300E+04, 0.93185900E+03, 0.13297600E+04, -.27342100E+04, -.38634200E+04, -.43648500E+04, 0.10695800E+04, 0.21912400E+04, -.10649400E+04, -.37286500E+03, -.20445500E+04, -.19814300E+04, 0.17013100E+04, 0.14601000E+04, 0.21923100E+04, -.25955300E+04, -.17259600E+03, 0.12080400E+03, 0.27996700E+03, -.38025000E+03, -.12281200E+04, 0.19378000E+03, -.10331400E+04, 0.23563700E+04, -.14164000E+04, 0.90674100E+03, -.37674800E+03, -.36422100E+03, 0.35683100E+04, 0.20932200E+04, -.69288200E+03, 0.34611500E+03, -.34331400E+04, 0.15356500E+04, 0.11375100E+04, -.68934700E+03, -.93440800E+03, 0.16626300E+02, -.22445600E+02, -.25425200E+01, 0.12288100E+04, 0.97099200E+02, -.36961200E+03, 0.21137400E+03, -.10111400E+04, -.10654400E+04, 0.10249000E+04, -.74954800E+03, -.10553100E+04, 0.21014300E+03, 0.83152800E+03, 0.73932600E+03, 0.19225400E+04, -.11224000E+04, 0.79043300E+03, 0.32236600E+04, 0.25298300E+04, -.62221200E+03, -.62945300E+03, 0.58216400E+03, 0.37068400E+04, -.10995200E+04, -.32020800E+01, -.23044700E+04, -.55813800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.98203100E-01, 0.24065500E+00, -.12807000E+00, 0.88110000E+00, -.22092600E+00, -.49168300E-01, 0.24349000E-01, 0.15212200E-01, -.73674600E-01, 0.30043200E-01, 0.17410300E+00, -.15485400E-01, 0.16371300E+00, 0.55352500E-01, 0.27801500E-01, 0.49176000E-01, 0.17766800E+00, 0.16776900E+00, 0.35176400E-02, 0.82151900E-02, -.24479900E-01, -.88883300E-01, 0.43787600E+00, -.76400300E-02, -.43721000E-01, -.92449500E-02, 0.29464800E+03, -.43143500E+03, 0.23290800E+03, 0.32104500E+03, 0.21222300E+03, -.60302500E+02, 0.18314200E+03, 0.11727300E+03, 0.76975400E+02, 0.20134300E+03, -.26284100E+02, 0.95760900E+01, 0.35736200E+02, -.96876600E+02, 0.18653700E+03, -.43385800E+02, -.16929200E+03, -.13279500E+03, -.94708900E+02, -.56776600E+02, 0.34627800E+02, 0.30687300E+02, 0.12375800E+02, 0.23293400E+02, 0.16294400E+02, 0.32949500E+02, 0.11360000E+02, -.42618600E+02, -.31048400E+02, 0.12533500E+02, 0.42928600E+02, -.94191000E+02, 0.24958300E+03, -.11609300E+03, -.32459300E+03, -.13774800E+03, -.16494000E+02, -.45036900E+02, -.15326300E+02, 0.64945500E+02, -.12903000E+03, -.16234700E+03, 0.85109700E+02, -.10078400E+03, 0.32452400E+02, 0.13614900E+03, 0.37550100E+03, -.23879800E+03, -.17307500E+03, -.14254000E+03, 0.64085000E+03, -.38025500E+03, -.48288500E+03, -.30675900E+03, 0.70182000E+03, 0.22631500E+04, -.11771200E+04, -.11492800E+04, -.18080200E+03, 0.17891200E+03, -.68219500E+03, -.56850500E+02, -.60970000E+03, -.45547800E+03, 0.12661000E+03, -.24217000E+02, -.42059500E+02, 0.10929700E+02, -.97405000E+03, 0.21943300E+03, 0.36117500E+03, 0.11693700E+03, -.58680900E+03, 0.39080400E+03, -.18518500E+03, -.23117300E+03, -.85633600E+02, -.10838300E+03, -.46092700E+01, 0.53081000E+03, 0.38904600E+02, -.33361500E+03, 0.23289300E+04, -.11486100E+04, -.99759100E+03, 0.17546000E+03, 0.17102900E+03, -.84781600E+03, -.57120400E+03, -.94908400E+03, 0.94019900E+02, 0.90161700E+03, -.45206300E+03, -.42853200E+03, 0.19034200E+03, 0.12311800E+03, -.39365800E+03, -.10425400E+03, -.30883900E+03, -.20900500E+03, 0.51331100E+02, -.50423900E+02, 0.42299300E+01, 0.10581600E+03, -.11613900E+02, 0.61759700E+01, 0.23756700E+03, 0.10367500E+03, 0.14416300E+03, 0.15211800E+03, -.28339700E+02, -.10204200E+03, -.62791000E+02, 0.34850900E+02, -.22395300E+02, 0.14640900E+03, -.30160500E+02, 0.34798500E+01, 0.20117000E+02, -.72717700E+02, 0.49710500E+02, -.33653100E+03, -.42730500E+03, 0.15911400E+03, 0.12011700E+03, 0.20859700E+03, -.30374100E+03, 0.29815000E+03, -.15005000E+03, -.84382500E+02, -.14779300E+03, -.16422500E+03, 0.64516200E+02, 0.42078300E+02, -.71604300E+02, 0.12266500E+03, 0.16772500E+03, -.10135600E+03, -.70893500E+02, -.16674200E+02, -.79854100E+02, -.51527100E+02, -.15533300E+03, -.28271100E+02, 0.18200500E+03, 0.68061900E+03, -.32881200E+03, -.26682600E+03, 0.21803700E+02, 0.66306600E+02, -.23290500E+03, -.17954700E+03, -.23645900E+03, 0.32374500E+02, 0.88869300E+03, -.41629200E+03, -.46149400E+03, 0.30916900E+03, 0.56181600E+03, -.46077800E+03, -.30263200E+03, -.47373100E+03, 0.19644100E+03, 0.68689100E+02, -.65234500E+02, -.39694600E+02, -.52757900E+02, -.14914700E+03, 0.44006100E+02, 0.13354500E+02, 0.15030200E+02, 0.10531400E+02, -.89114800E+03, -.17178000E+03, -.45791000E+03, -.83526000E+01, -.73840000E+02, -.24990600E+02, -.38632700E+01, 0.15981700E+03, 0.31575100E+03, -.91815700E+01, -.81304100E+02, 0.24342800E+03, 0.47604200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.83915600E+00, -.77512700E+00, 0.75690900E+00, -.46192400E+01, -.85967900E+00, 0.35097100E+00, -.21862000E+00, -.13576400E+01, 0.63452700E+00, -.26454200E+00, 0.92173000E+00, -.93567300E+00, 0.35219800E+00, -.50853700E+00, 0.26062600E+00, -.15438000E+01, -.10201100E+01, -.66706000E+00, -.62903600E+00, -.44116400E-01, 0.10149500E+00, -.39073200E+00, -.39213900E+01, 0.56236000E+00, 0.39336000E-01, -.19311300E+00, -.17055600E+01, -.25515900E+05, 0.12624900E+05, 0.13708300E+05, -.70226100E+03, 0.30676400E+04, 0.85213400E+04, 0.31943400E+04, 0.32831000E+04, 0.42235500E+04, 0.16146600E+04, -.82009300E+03, -.10684500E+04, 0.40530700E+04, 0.87332200E+03, -.11431000E+04, -.13869800E+04, -.75814600E+03, 0.10091600E+04, 0.95503700E+03, -.51527200E+03, -.51789400E+03, 0.11503800E+03, -.24308100E+03, -.16126900E+03, 0.43071300E+03, 0.47865300E+03, -.25662400E+03, 0.55538900E+03, -.27102600E+03, -.10868000E+04, 0.57903600E+04, 0.10614300E+04, -.15086600E+04, -.32458000E+04, -.18323900E+04, 0.21740900E+04, 0.82984400E+02, 0.17606600E+03, 0.58151700E+03, 0.76394700E+04, 0.15455300E+04, -.24896100E+04, -.61648100E+04, -.58716300E+04, 0.24251100E+04, 0.14909900E+05, -.74122200E+04, -.78678500E+04, 0.90908800E+04, 0.37718900E+04, -.63416000E+04, -.64373900E+04, -.50017700E+04, 0.21557500E+04, 0.27933400E+05, -.13708200E+05, -.14519200E+05, 0.21238700E+04, -.10691800E+04, -.11048200E+05, -.70501700E+04, -.83224800E+04, -.21917200E+04, -.22128900E+05, 0.11054100E+05, 0.12349400E+05, -.55031800E+04, -.22066500E+04, 0.85332900E+04, 0.61063100E+04, 0.57767100E+04, -.49311900E+03, 0.80592700E+04, -.41807700E+04, -.45539300E+04, -.49617500E+04, -.16954400E+04, -.17786700E+04, 0.29664400E+04, 0.25708600E+04, -.34723600E+04, -.45601000E+05, 0.22974900E+05, 0.23955100E+05, 0.61679800E+04, 0.85232000E+04, 0.15473800E+05, 0.59207700E+04, 0.89781300E+04, 0.11189500E+05, -.17450500E+05, 0.87630000E+04, 0.90698400E+04, -.42861800E+03, 0.32314800E+04, 0.45806400E+04, 0.29626500E+04, 0.36213000E+04, 0.45035000E+04, -.13380000E+04, 0.74388500E+03, 0.13133300E+04, -.27487000E+04, 0.14060100E+04, 0.14012300E+04, 0.40438500E+04, 0.38413000E+04, -.14111000E+03, 0.97541500E+04, -.51679600E+04, -.49407600E+04, -.11823700E+04, -.19896400E+04, -.34833200E+04, -.13136400E+04, -.18523400E+04, -.27291300E+04, 0.13002700E+05, -.63205500E+04, -.59895200E+04, 0.39069600E+04, -.88272700E+03, -.71160400E+04, -.79665300E+04, -.56505500E+04, -.15947800E+04, -.50196100E+04, 0.25491500E+04, 0.30798400E+04, -.42168400E+04, -.10234400E+04, 0.44844700E+04, 0.52274600E+04, 0.33949500E+04, -.14431100E+04, -.38928900E+04, 0.20396300E+04, 0.21339500E+04, 0.71985100E+03, 0.74595800E+03, 0.67910900E+03, -.20571500E+04, -.22793000E+04, 0.14688700E+04, -.18812800E+05, 0.95169800E+04, 0.92850500E+04, 0.48482000E+04, 0.38128900E+04, 0.58060200E+04, 0.11783500E+04, 0.46678200E+04, 0.52584400E+04, -.49597200E+04, 0.23850600E+04, 0.22126800E+04, -.27106200E+04, 0.85726200E+03, 0.35706000E+04, 0.56545700E+04, 0.43565900E+04, 0.16848100E+04, -.15346000E+04, 0.12917000E+03, 0.46133100E+03, -.17619800E+03, 0.39491400E+03, 0.22783400E+03, 0.72542600E+03, 0.12125400E+04, 0.34024700E+04, 0.23842600E+04, -.47125700E+03, 0.22530500E+04, 0.83548600E+04, 0.33489800E+04, 0.25513300E+03, -.68784400E+03, 0.22121100E+04, 0.28021000E+04, -.29201900E+03, -.24214500E+03, -.46747600E+04, -.39022100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14951100E+00, 0.10324500E+00, 0.44136800E+00, -.97388800E+00, -.90520400E-01, -.10677500E+00, -.35248900E-01, 0.27999300E+00, 0.16591500E+00, 0.60039400E-02, 0.18469900E+00, -.49520500E-01, 0.70843400E-01, 0.56223800E-01, 0.19136200E+00, 0.27481500E+00, 0.22230500E-01, 0.21586100E+00, -.34093600E-01, -.93109900E-01, 0.21954700E-01, 0.29362500E-01, 0.67010500E+00, 0.39080200E-01, 0.85193900E-01, 0.32135200E-02, 0.20795200E-01, 0.13355300E+00, 0.32357700E+02, 0.45960700E+02, 0.32344400E+03, 0.21566100E+02, -.10342800E+03, -.76929500E+02, -.11079400E+03, 0.19932300E+03, -.42236900E+03, 0.20939400E+03, 0.22989900E+03, -.39651700E+03, -.63858700E+01, 0.20516900E+03, -.40477400E+02, -.16075600E+02, -.66561600E+02, -.16100600E+03, 0.91710000E+02, 0.82254100E+02, -.98785200E+01, 0.62944000E+02, 0.49665700E+02, 0.28454600E+02, 0.18013100E+02, 0.16978400E+02, -.63745100E+03, 0.31429000E+03, 0.35300200E+03, -.46627700E+03, -.15809500E+02, 0.27023300E+03, 0.42468100E+02, 0.16108100E+03, -.20556000E+03, 0.85063300E+03, -.47984200E+03, -.42055100E+03, -.42574100E+03, -.13838600E+03, -.35902500E+03, -.41019700E+03, -.39788600E+03, -.86696500E+02, -.65715100E+03, 0.26455500E+03, 0.32122800E+03, -.24437100E+03, 0.26768700E+02, 0.85594700E+01, 0.35528500E+03, -.27754800E+03, 0.82575800E+02, 0.12849700E+04, -.70358200E+03, -.64981800E+03, -.53879800E+03, -.35387500E+03, -.21232400E+02, 0.27913600E+03, 0.25008100E+03, -.77396300E+03, 0.19870300E+04, -.95206600E+03, -.99414800E+03, 0.96448800E+02, -.19120500E+03, -.60017100E+03, -.74042900E+03, -.30254900E+03, -.10193500E+03, -.61166000E+03, 0.33426600E+03, 0.28638600E+03, -.11020600E+03, 0.25242100E+02, 0.50569900E+03, 0.69790900E+03, 0.62440400E+03, -.90917600E+02, 0.23446300E+04, -.11783300E+04, -.11396200E+04, 0.38476200E+03, -.39323600E+03, -.95440400E+03, -.66583500E+03, -.72662400E+03, -.52496000E+03, 0.96974600E+03, -.48953700E+03, -.46335700E+03, 0.31989900E+03, 0.45013600E+02, -.38413700E+03, -.31764500E+03, -.34319300E+03, -.30425700E+03, -.16325800E+02, -.25257600E+02, 0.29843300E+02, 0.61735000E+03, 0.11676800E+03, -.26149500E+03, -.23553200E+03, -.43747000E+03, 0.23600100E+03, -.70342900E+03, 0.43072600E+03, 0.32106000E+03, -.37069000E+03, 0.18482800E+03, 0.47810300E+03, 0.53482600E+03, 0.57808500E+03, -.40812700E+02, 0.56847300E+03, -.34957800E+03, -.24817300E+03, -.65170800E+03, -.18785700E+03, 0.98066500E+02, 0.23876000E+03, 0.22346000E+03, -.15541900E+03, 0.63918600E+03, -.32466600E+03, -.30315600E+03, 0.25072300E+03, -.10007600E+03, -.20967500E+03, -.41648900E+03, -.35602800E+03, 0.16034700E+03, 0.49632600E+03, -.28026800E+03, -.24267900E+03, -.16435500E+02, -.20784300E+03, -.15251500E+03, -.11968300E+02, -.31093700E+02, -.18257000E+03, 0.12012200E+04, -.59722200E+03, -.54526400E+03, 0.39369700E+02, -.24487600E+03, -.39794400E+03, -.14151600E+03, -.21573800E+03, -.40070800E+03, 0.43172800E+03, -.18506000E+03, -.23915000E+03, 0.62210000E+03, 0.98719000E+02, -.34232000E+03, -.36126000E+03, -.39667800E+03, -.19401900E+03, 0.25696400E+03, -.86913800E+02, -.13548900E+03, -.22061900E+02, -.12149800E+03, -.75922600E+02, -.57221900E+02, -.48084400E+02, -.86546000E+02, -.16951800E+03, -.20802700E+03, -.90235300E+02, 0.42794400E+02, -.14353000E+03, -.58113300E+02, 0.41376000E+02, 0.59653900E+02, 0.67249500E+03, -.19643700E+02, -.26866900E+01, 0.15782100E+03, -.10167000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13215000E+00, -.28466500E-02, -.29521200E+00, 0.60009300E+01, -.43789200E+00, 0.18729400E+00, 0.40122200E+00, -.51607600E+00, -.18118800E+01, 0.38975000E+00, -.18567900E+00, -.25271600E+00, 0.14607500E+01, 0.78820000E+00, 0.28301500E+00, 0.57826100E+00, 0.10384600E+01, 0.12903600E+00, 0.87005100E-01, -.93729200E-02, 0.14260200E+00, -.13625900E+00, -.37508400E+01, -.16342600E+00, -.29754000E+00, 0.39136200E+00, 0.28903200E+01, -.29934400E+00, -.28493900E+01, -.12551500E+04, 0.12140400E+04, -.54283500E+03, -.99920300E+03, -.25129300E+03, 0.14866400E+03, -.83212100E+03, -.13593300E+04, 0.67171200E+03, 0.82675400E+03, -.29352600E+03, 0.20783500E+03, 0.32780800E+03, 0.91092200E+03, 0.84803200E+03, 0.11811500E+03, -.16019300E+03, 0.84748400E+02, 0.13259000E+03, -.16205700E+03, -.23174800E+03, 0.18987000E+03, 0.34597300E+03, 0.17558200E+03, -.13455200E+03, 0.15241400E+04, -.75532000E+03, -.31786300E+02, -.63553200E+03, 0.11171400E+03, -.24942000E+03, 0.39183500E+03, -.23431000E+03, -.17970100E+03, -.24918300E+04, 0.11745700E+04, 0.51555700E+03, -.77349400E+03, -.12227400E+03, 0.35480300E+03, 0.36893800E+03, 0.11863300E+04, -.86048800E+01, -.35616000E+04, 0.17071800E+04, 0.22628100E+04, -.13171000E+04, 0.22020700E+04, 0.16715800E+04, 0.33328700E+04, 0.10444700E+04, 0.13026000E+04, 0.17362800E+04, -.90127400E+03, -.30043700E+03, -.31801400E+03, 0.12618700E+04, -.87145500E+03, -.14940300E+04, -.10474300E+04, 0.20322700E+04, 0.31505700E+03, -.96270300E+02, -.15281300E+04, 0.20283300E+04, -.10340100E+04, -.70710200E+03, -.25115800E+04, -.66114800E+02, -.88690400E+03, -.81609800E+03, 0.41889000E+03, 0.10573200E+04, 0.32639400E+03, -.77042600E+03, 0.13577200E+04, 0.13023300E+04, 0.48588500E+03, -.10738800E+03, 0.24836300E+04, -.11994100E+04, -.26928500E+04, 0.27967900E+04, 0.15293100E+04, -.24386800E+04, -.12518000E+04, -.14404100E+04, -.26835000E+03, 0.60996700E+04, -.30566500E+04, -.35251800E+04, -.21082500E+03, -.17829600E+04, -.10540600E+04, -.80517900E+03, -.19291000E+04, -.16523700E+04, -.57665300E+03, 0.24298500E+03, -.41603600E+03, -.57412000E+03, -.10851400E+04, 0.88073700E+03, 0.10075100E+04, 0.36044500E+03, -.71862500E+03, -.24006200E+04, 0.12518600E+04, 0.14000900E+04, -.30625300E+03, -.64040200E+03, 0.15261700E+04, 0.13365500E+04, 0.10649200E+04, 0.30281400E+03, -.25455000E+04, 0.11859400E+04, 0.54974600E+03, -.12761700E+04, -.80108400E+03, 0.99042600E+03, -.82437000E+01, 0.12722900E+04, 0.17821700E+03, -.14480000E+04, 0.71840600E+03, -.75703600E+02, 0.26750800E+04, 0.17745100E+04, -.18702300E+04, -.21535600E+04, -.76608200E+03, 0.13764300E+04, 0.83972800E+03, -.42751900E+03, -.64851700E+03, 0.50506900E+03, 0.89892100E+03, -.88115800E+03, -.12414400E+04, -.73441100E+03, 0.57349300E+03, 0.17391800E+04, -.83904600E+03, -.11256200E+04, 0.68182900E+02, 0.19534500E+03, -.86338900E+03, 0.30538400E+03, -.36137500E+03, -.55775700E+03, 0.38884300E+04, -.18953600E+04, -.15374000E+04, 0.31725400E+03, 0.67844600E+03, -.15633900E+04, -.64260700E+03, -.19058100E+04, 0.38838000E+03, 0.30298700E+03, 0.50760600E+03, 0.19219100E+03, 0.10437300E+03, -.99493900E+02, 0.14400800E+03, -.56785100E+02, 0.90604900E+02, -.62512300E+03, 0.64069800E+03, -.31839700E+03, 0.12184700E+04, -.12645700E+04, -.70085500E+03, -.97389500E+02, 0.81964200E+02, -.15405900E+03, 0.16695500E+04, 0.31763300E+03, 0.13696600E+03, 0.55151600E+03, -.76337600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.80082600E+00, -.27765500E+00, -.42522400E+00, 0.63995600E+01, -.58817700E+00, -.40037000E+00, 0.77933500E-02, 0.55557300E+00, -.85957100E+00, -.59505100E-01, -.10559100E+01, 0.22722500E+00, -.37804700E+00, -.44989300E+00, -.21370500E+00, -.41509100E+00, 0.12703600E+01, 0.83628600E+00, 0.32046000E+00, -.69811000E-01, 0.18660400E+00, -.22091000E+00, 0.13036400E+01, -.70078300E+00, -.13485000E+00, -.40776700E+00, 0.47304500E+01, 0.32613400E+00, -.31702900E-01, 0.31674100E+00, 0.21775200E+04, 0.45376300E+04, -.21507600E+04, -.15166100E+04, -.55968800E+04, 0.26157700E+04, -.49533300E+03, 0.27747800E+03, -.15406700E+03, -.93661200E+01, -.52091500E+03, -.36926700E+03, -.29744200E+04, 0.61256300E+02, 0.88352500E+02, -.82514900E+02, 0.49830300E+02, 0.39731700E+02, -.68853000E+02, 0.16188400E+03, 0.19901500E+00, -.18617600E+03, 0.89027200E+02, 0.99834700E+02, -.36476600E+04, 0.18217200E+04, 0.76165500E+03, -.48457900E+02, -.12130600E+04, 0.85666500E+03, -.22991200E+04, 0.17049300E+04, -.81528900E+03, 0.54910500E+04, -.26551300E+04, -.25252600E+04, -.14230300E+03, 0.13025500E+04, -.27764800E+04, -.20212800E+04, -.38720100E+04, 0.39530100E+03, -.23252100E+05, 0.11824700E+05, 0.10713100E+05, 0.27606100E+04, -.27770900E+04, 0.50431000E+04, 0.34308700E+04, 0.31315100E+04, 0.14204400E+04, -.11317700E+05, 0.56822300E+04, 0.47923800E+04, -.36492900E+04, -.56298400E+04, 0.71062000E+04, 0.23259400E+04, 0.10878000E+05, -.32020600E+04, 0.30876500E+05, -.15583100E+05, -.14248700E+05, -.14289300E+04, 0.33217500E+04, -.94364500E+04, -.66943300E+04, -.84186400E+04, -.80894200E+03, -.84047500E+04, 0.42817000E+04, 0.37957700E+04, -.11479100E+04, -.44131900E+03, 0.44639600E+04, 0.31370100E+04, 0.62797700E+04, 0.62678100E+03, -.12887800E+05, 0.62371700E+04, 0.52975000E+04, 0.25943700E+04, -.21241500E+03, 0.97213400E+03, -.57661100E+04, 0.13335200E+04, 0.61121800E+03, -.13887400E+04, 0.70351100E+03, 0.96125100E+03, 0.12069400E+04, 0.18136300E+04, -.76479900E+03, -.43588500E+04, -.15561200E+03, 0.74717600E+03, 0.16818900E+04, -.75902300E+03, 0.37933900E+02, 0.16408000E+04, 0.10807600E+04, -.14914600E+04, 0.51459200E+03, -.27847900E+04, 0.16008100E+04, -.18279300E+04, 0.95651300E+03, 0.73866400E+03, -.18137300E+04, -.38528200E+03, 0.23384800E+04, 0.22231200E+04, 0.32799400E+04, -.40103300E+03, 0.25143900E+04, -.10649800E+04, -.10176000E+04, -.22122100E+04, -.25874400E+03, 0.17763100E+04, 0.27066800E+04, 0.37890600E+04, -.73888000E+03, -.16634800E+04, 0.80741700E+03, 0.54797000E+03, -.23891600E+03, -.62711400E+03, 0.14813600E+04, -.42135400E+02, 0.60356500E+03, 0.26890600E+03, 0.83898900E+03, -.44878500E+03, -.46807500E+03, 0.42284200E+03, -.29844300E+03, -.42097600E+03, 0.86224600E+03, -.13389000E+04, -.57813800E+03, -.16271600E+04, 0.68771300E+03, 0.34925300E+03, 0.56991300E+02, -.24059700E+04, 0.30735700E+03, -.13839800E+04, 0.29128500E+04, -.18489400E+04, -.29335500E+04, 0.13545600E+04, 0.11704800E+04, 0.98041600E+03, -.26521500E+04, 0.13606600E+03, -.16040200E+04, 0.76566600E+02, -.16370500E+04, 0.31047200E+03, 0.71588900E+02, 0.68683900E+02, -.14354400E+03, 0.15786200E+03, 0.48985700E+02, -.18998000E+03, -.53806000E+03, 0.16133900E+03, 0.16473700E+04, -.12588100E+04, 0.71629900E+03, 0.21686600E+04, -.19701600E+04, 0.11709900E+04, -.26117500E+03, 0.89643500E+03, 0.36617700E+02, -.47315000E+02, 0.19604600E+03, 0.98942400E+03, -.38213300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.64380300E+00, 0.61817100E+00, -.12733300E+01, 0.56934100E+01, -.57643000E+00, -.37578400E+00, 0.10598100E+01, 0.41099100E+00, -.32965000E-01, 0.18225000E+00, -.49404700E-01, 0.21605300E+00, -.30344100E+00, 0.86536100E-01, -.51712200E+00, 0.63434400E-01, 0.64639800E+00, 0.66032400E+00, 0.73014900E-01, -.23851800E+00, 0.24126000E-01, -.86682000E+00, 0.19336100E+01, -.35542300E+00, -.18642800E+00, 0.33527000E+00, 0.36821100E+01, -.13199800E+00, 0.28569400E+01, 0.42405700E+00, 0.30840000E-01, 0.40038000E+04, -.22144800E+04, -.25275900E+04, -.42411400E+04, 0.22639100E+04, -.25818200E+04, 0.12847100E+04, 0.11248400E+04, 0.17849100E+04, 0.22246600E+03, -.34895300E+03, -.17670500E+04, 0.92467600E+03, 0.85814500E+03, 0.14130400E+03, -.63082400E+02, -.33088000E+02, -.43305700E+02, -.13046100E+03, 0.45684200E+02, -.19898300E+03, 0.16745300E+03, -.34333300E+01, -.22154000E+04, 0.10980800E+04, 0.94656100E+03, 0.13640200E+04, -.11280900E+04, 0.26709300E+02, -.15886300E+04, 0.91063200E+03, -.20924900E+03, 0.14918800E+04, -.67529800E+03, -.58842900E+03, 0.76967200E+03, 0.23089900E+04, -.16766000E+04, -.11073800E+04, -.24835000E+04, 0.56592800E+03, -.32083200E+05, 0.15984000E+05, 0.15837000E+05, 0.42505200E+04, -.34735900E+04, 0.97380300E+04, 0.32364800E+04, 0.93904500E+04, 0.21564400E+03, -.10563600E+05, 0.53938600E+04, 0.49256400E+04, -.62467900E+03, -.39405200E+04, 0.47037400E+04, 0.19061200E+04, 0.68918600E+04, -.73651400E+03, 0.31340400E+05, -.15624200E+05, -.15281600E+05, -.34755000E+04, 0.35049800E+04, -.10004200E+05, -.41776000E+04, -.10177600E+05, -.48266400E+03, -.37218900E+04, 0.19032700E+04, 0.16486500E+04, -.11322000E+04, -.21685000E+04, 0.24361800E+04, 0.93415900E+03, 0.37692400E+04, 0.12053400E+03, -.13106400E+05, 0.65206600E+04, 0.65054000E+04, 0.11807400E+04, 0.46464000E+03, 0.13173600E+04, -.62948600E+04, 0.42716500E+03, 0.16630700E+04, -.34321800E+04, 0.17197600E+04, 0.18314100E+04, -.18522100E+04, -.60148500E+03, 0.17521900E+04, -.22027500E+04, 0.13827300E+04, 0.16112800E+03, 0.21988300E+04, -.10943800E+04, -.64769000E+03, -.14942500E+04, -.28349500E+03, 0.10892800E+04, 0.18991700E+04, 0.47744400E+03, -.94731400E+03, 0.80216700E+03, -.42198400E+03, -.52342900E+03, -.73806300E+03, -.18327600E+04, 0.81900300E+03, 0.76207200E+03, 0.14953300E+04, -.57056500E+03, 0.81731300E+04, -.38928500E+04, -.39250300E+04, -.12038900E+04, -.11948300E+04, -.61923000E+03, 0.26065100E+04, 0.50343800E+03, -.20448400E+04, 0.75050400E+03, -.38372000E+03, -.44747700E+03, 0.11037000E+04, 0.11931700E+04, -.17090000E+04, -.17754900E+04, -.14942200E+04, 0.11711400E+04, 0.79953000E+03, -.41976600E+03, -.34367500E+03, 0.28654700E+03, 0.88787500E+03, -.77161800E+03, 0.49588700E+03, -.17279400E+04, 0.24935300E+03, -.17781600E+04, 0.90361800E+03, 0.70727300E+03, -.26718400E+03, -.15601800E+04, 0.30707900E+03, -.13292800E+04, 0.12115900E+04, -.11799000E+04, -.90271600E+04, 0.43765900E+04, 0.44375500E+04, 0.16995800E+01, -.23407900E+04, 0.29411300E+04, 0.21056900E+03, 0.30499100E+04, -.18433800E+03, -.70068800E+02, 0.71359700E+03, 0.93399400E+03, -.22489800E+03, 0.88294300E+03, 0.42709800E+02, -.18100500E+03, 0.74674900E+03, -.32221000E+03, 0.55097600E+03, 0.44678300E+03, 0.81707700E+03, 0.14043600E+04, -.33799100E+04, 0.13874100E+04, -.13540200E+03, 0.10616900E+04, -.27522600E+04, 0.92216700E+03, 0.17115800E+03, 0.29131000E+04, -.16268000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11919800E+01, -.13939200E+00, 0.18402100E+01, 0.81716200E+01, 0.16665400E+01, 0.10086900E+00, 0.81274900E-01, 0.87713600E+00, -.29012200E+01, 0.57194000E+00, -.19512300E+01, 0.76874400E+00, 0.15555900E+01, 0.10380000E+01, -.59765800E+00, 0.18249800E+01, 0.20498600E+01, 0.11438900E+01, 0.38885800E+00, -.47735200E+00, 0.13548600E+00, 0.18801800E+01, 0.46485900E+01, -.58754000E+00, 0.58616400E+00, 0.65438000E-02, 0.60786200E+01, -.73376900E+00, -.40747000E+01, 0.96212200E+00, 0.13864900E+00, -.26692400E-01, 0.21023200E+04, 0.51949700E+04, 0.25888400E+04, -.73198700E+03, 0.24044300E+04, -.11643000E+04, -.12612200E+04, -.96665100E+03, -.85766900E+03, -.84266500E+03, -.23331200E+04, -.18451400E+04, -.14496300E+03, 0.43631200E+03, -.22270600E+03, -.26393200E+03, 0.37379100E+02, 0.73655100E+02, -.26349600E+03, -.31375800E+03, -.42533200E+03, 0.13979400E+03, 0.75305100E+03, -.37319100E+03, -.91239600E+03, -.12740300E+04, -.97512800E+03, 0.14325000E+03, -.75347800E+02, -.59656600E+02, -.41314800E+03, -.72073400E+03, 0.48345900E+03, 0.32388000E+03, -.12388100E+04, -.25598700E+02, 0.15239600E+04, 0.31788400E+04, 0.26686900E+04, -.23853600E+03, -.30715100E+04, 0.17612400E+04, 0.11590600E+04, -.25398600E+04, -.36513600E+04, 0.10589700E+04, 0.62635700E+04, -.40994300E+03, 0.48271900E+03, -.43031400E+04, 0.22353700E+04, 0.20180300E+04, -.28476500E+03, -.10506400E+04, 0.95647000E+03, -.36245200E+04, 0.18000500E+04, -.10124900E+04, -.49578200E+04, 0.22369000E+04, 0.27909000E+04, 0.30155000E+04, 0.54598200E+04, 0.38960800E+03, -.71225400E+04, 0.16000900E+04, 0.31285400E+04, 0.69662800E+03, -.31663300E+03, -.24818200E+03, 0.14874100E+04, 0.18189500E+04, -.20443800E+04, -.55259900E+04, -.34155900E+04, 0.14675800E+04, -.21384200E+05, 0.10457300E+05, 0.98415400E+04, 0.67794300E+03, -.36330800E+02, 0.79581100E+04, 0.77431800E+04, 0.10183300E+05, 0.37889100E+04, 0.31228800E+02, -.36362200E+01, -.44674900E+02, 0.15819100E+04, 0.53876300E+03, -.38794200E+03, -.78991000E+03, 0.10022300E+04, 0.12091100E+03, -.34023700E+04, 0.18097800E+04, 0.16773600E+04, 0.10961200E+04, 0.34538800E+03, -.23848700E+03, -.11292900E+02, -.13895200E+04, 0.19753700E+04, -.73705500E+03, 0.29248700E+03, 0.46036600E+03, 0.11754700E+04, 0.16177200E+04, -.82093800E+03, -.37845400E+04, -.16965300E+04, 0.94088200E+03, -.18218700E+04, 0.11448300E+04, 0.77895700E+03, 0.67162000E+03, 0.23931200E+04, 0.19112700E+03, -.22465100E+04, -.24537900E+03, 0.10782200E+04, -.31825200E+04, 0.15784200E+04, 0.14792400E+04, -.77836100E+03, -.97565600E+03, 0.21644100E+04, 0.32102700E+03, 0.12371300E+04, -.66542500E+03, -.12245200E+04, 0.60856700E+03, 0.50169900E+03, -.42668700E+03, -.42094800E+03, 0.98746300E+03, 0.24272000E+04, 0.17676900E+04, -.68415500E+03, -.24716700E+04, 0.11066100E+04, 0.11315600E+04, -.71449200E+03, -.12254000E+04, 0.20306300E+04, 0.42192200E+04, 0.32842700E+04, 0.66087300E+03, 0.35191500E+03, -.27030500E+03, -.23304400E+03, -.45065400E+03, -.25313500E+04, -.83074600E+00, 0.38388300E+03, -.13384200E+03, -.15486900E+04, -.39072000E+03, -.28811700E+03, -.34082600E+03, 0.17677500E+03, -.10857000E+04, 0.33892500E+02, -.50633700E+02, -.12440000E+04, -.75970100E+03, 0.83940300E+04, -.24050800E+04, 0.39029500E+04, -.25438600E+04, 0.32060000E+04, -.30789600E+02, -.17027300E+03, -.18557000E+04, 0.36129900E+04, -.64197900E+03, 0.10483100E+03, -.36774800E+04, -.59475400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20877600E+00, -.31369400E+00, 0.14062900E+01, -.50664100E+01, -.63463000E-01, 0.13941800E+00, -.78631800E-01, -.13654600E+00, 0.31119700E-01, -.71749100E-01, 0.36983600E+00, 0.26181200E-01, -.10433400E+01, -.25310000E+00, -.19093600E-01, -.26321000E+00, -.42773300E+00, -.23123100E+00, 0.14450500E+00, 0.21584100E+00, -.81236900E-01, -.29050800E+00, -.64755500E+00, 0.97608300E-01, -.17174700E+00, -.56797300E-01, -.90540400E+00, 0.97738700E-01, 0.96797100E+00, 0.20209600E+00, -.12654600E+00, -.22833800E-02, 0.48676400E-01, -.83205000E+03, -.86611100E+02, -.31284500E+02, -.71344700E+03, 0.35672300E+03, 0.38227800E+03, -.16529000E+02, 0.11825200E+03, 0.50888600E+03, 0.79643100E+03, 0.67086600E+03, 0.18344000E+02, -.10402000E+03, 0.53801500E+02, 0.58455800E+02, -.17845300E+02, 0.35385700E+02, 0.46618000E+02, 0.68501500E+02, 0.70497900E+02, 0.58813300E+01, -.16900300E+03, 0.85465700E+02, 0.16811000E+03, 0.34986200E+03, 0.39917600E+03, 0.26239000E+02, 0.15369500E+03, 0.13549400E+03, 0.35408600E+03, 0.11032200E+04, -.55115100E+03, -.54919900E+03, 0.25042600E+03, 0.20076200E+03, -.64626000E+03, -.11482800E+04, -.85948100E+03, 0.26757500E+03, 0.23837200E+04, -.11936900E+04, -.11682200E+04, 0.21139100E+03, -.11001400E+03, -.28664700E+03, -.98830000E+03, 0.35215700E+03, -.40324200E+02, 0.24727900E+03, -.13282000E+03, -.11876200E+03, -.10293200E+02, -.16185300E+03, -.42971100E+03, -.39485600E+01, -.89356800E+03, 0.14813300E+03, -.90674000E+03, 0.46062600E+03, 0.40866400E+03, 0.12777200E+03, 0.16685700E+02, -.33960700E+02, 0.10171100E+04, -.54349200E+03, 0.16814200E+03, -.51592600E+03, 0.26291000E+03, 0.23104000E+03, -.43090500E+03, -.19752700E+03, 0.36748700E+03, 0.11877900E+04, 0.46041600E+03, -.39120700E+03, 0.22623300E+04, -.11168500E+04, -.10654000E+04, 0.49155200E+03, 0.30530200E+01, -.63466100E+03, -.98344200E+03, -.11505500E+04, 0.55659400E+03, -.40350900E+03, 0.20629200E+03, 0.22423400E+03, 0.17753600E+03, 0.33318400E+03, -.13674100E+03, 0.16794800E+03, -.24768400E+02, 0.22374600E+03, 0.10277600E+04, -.51748600E+03, -.49235800E+03, -.12750000E+03, -.19103700E+03, -.13327900E+03, 0.13714600E+03, 0.32204500E+03, -.46526800E+03, -.72424600E+02, 0.49770500E+02, -.86111300E+01, -.33914300E+03, 0.84723600E+02, -.59777100E+01, 0.61213400E+03, 0.49690900E+02, -.82775000E+02, 0.49182200E+03, -.25681600E+03, -.19637500E+03, -.75247700E+01, 0.15148300E+03, -.49396300E+03, 0.97637500E+02, -.67055700E+03, 0.12845300E+03, 0.16130100E+03, -.80898800E+02, -.67625000E+02, -.10552100E+03, -.24802400E+03, 0.20911200E+03, 0.48579800E+03, 0.32320500E+03, -.88170700E+02, 0.16269200E+03, -.88412500E+02, -.71744000E+02, 0.15038900E+03, -.11564700E+03, -.12366700E+03, -.58708600E+03, -.20883700E+03, 0.63106900E+02, -.53728900E+03, 0.27454500E+03, 0.34331300E+03, 0.55947100E+03, 0.57007300E+03, -.56955600E+02, -.74869600E+03, -.59852900E+03, 0.69080400E+03, -.33755800E+03, 0.16960900E+03, 0.14911400E+03, 0.21742000E+03, 0.30152300E+02, 0.17474900E+03, -.19924500E+03, 0.34162000E+03, 0.93139900E+02, 0.68537100E+02, -.11410300E+03, -.11991000E+03, 0.27498000E+02, 0.20243100E+03, -.25792800E+02, 0.37986500E+02, 0.28664200E+03, 0.22159300E+03, -.42474300E+03, 0.23700700E+03, -.20026800E+03, 0.78656600E+03, -.90587200E+02, -.81582000E+02, 0.79254600E+02, 0.27145600E+03, -.78617500E+02, -.11284200E+03, -.22702200E+02, 0.38362300E+03, 0.32343100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11155400E+01, 0.56840400E+00, 0.15385900E+00, 0.19122700E+01, -.16920300E+00, -.44169900E+00, 0.29487700E-01, 0.28232500E+00, 0.16818100E+00, -.26969900E+00, -.83752000E+00, 0.46482100E+00, -.10531300E+01, -.12536100E+01, -.12239700E+01, -.13580700E+01, 0.88680800E-01, 0.87680900E-01, 0.49159800E+00, -.46665400E+00, 0.51613700E-02, 0.11888100E+01, 0.43064700E+01, 0.22419200E+00, 0.27676300E+00, 0.32933900E+00, -.31702500E+01, 0.18508900E+00, 0.41316100E+01, -.26707100E+00, -.13951100E+00, -.92176500E-01, -.41187900E+00, -.12924800E+01, 0.17746400E+04, -.23596300E+03, 0.68954200E+03, -.31992300E+03, -.30182100E+03, 0.83807400E+03, 0.72530100E+03, -.77522900E+03, -.52730100E+03, -.82590100E+03, 0.69533100E+03, 0.35201700E+03, -.17860000E+03, -.13450500E+03, -.38035600E+01, -.19668100E+02, -.73846800E+02, 0.35229900E+02, 0.45006800E+02, -.72870800E+01, 0.20343500E+04, -.99970600E+03, -.87088000E+03, 0.13393500E+04, 0.15850400E+04, -.18115600E+04, -.22170100E+04, -.16883400E+04, 0.11608300E+04, 0.33055400E+03, -.11572800E+03, -.10151100E+03, 0.88320800E+03, 0.67155000E+03, -.32887600E+03, -.94716100E+03, -.87095600E+03, 0.51482700E+03, 0.23162800E+04, -.97758900E+03, -.11553800E+04, 0.10960000E+04, 0.11924900E+04, -.52664600E+03, -.47091600E+02, 0.93451000E+03, 0.15854700E+04, -.63565300E+04, 0.31099200E+04, 0.30551800E+04, -.48365500E+02, -.19986100E+03, 0.14820200E+04, -.16626300E+03, -.65004900E+03, 0.51183400E+03, -.22672000E+01, -.14046000E+03, -.62376300E+02, -.61598700E+03, -.93068800E+03, 0.13200200E+03, 0.98421800E+03, -.13229600E+04, -.89793800E+03, -.42380200E+03, 0.22520400E+03, 0.25787200E+03, -.93831800E+03, -.67679700E+03, 0.28858400E+03, 0.16036400E+04, 0.69696300E+03, -.49997600E+03, 0.98998500E+04, -.50387500E+04, -.50349000E+04, 0.96235000E+03, 0.16429300E+04, -.40693600E+04, -.98174700E+03, -.36536200E+04, 0.14657200E+04, 0.42432600E+04, -.21060900E+04, -.21615800E+04, 0.30248300E+03, 0.52457000E+03, -.18926800E+04, -.11539000E+04, -.19205600E+04, -.23609400E+02, 0.11329500E+04, -.51447700E+03, -.44207600E+03, -.11966800E+04, -.13349200E+04, 0.13150600E+04, 0.26769100E+04, 0.16362000E+04, -.87762400E+03, 0.10857000E+04, -.55886700E+03, -.61291500E+03, -.28557100E+03, -.69425300E+02, -.42975100E+03, 0.35265900E+03, -.72302900E+03, -.39392800E+03, -.49723500E+04, 0.24558900E+04, 0.25185600E+04, 0.35442900E+03, 0.73180900E+03, 0.14871100E+04, 0.41128700E+03, 0.96899500E+03, 0.77419700E+03, 0.12942400E+04, -.65934600E+03, -.68537400E+03, -.11723800E+04, -.81926800E+03, 0.15452400E+03, 0.11351600E+04, -.11573300E+03, -.79524100E+03, -.17862900E+04, 0.89759800E+03, 0.88776600E+03, 0.19713800E+03, 0.11309700E+03, 0.38919900E+03, -.83505900E+03, -.85692300E+02, 0.13298500E+03, 0.14369700E+04, -.80238600E+03, -.60067300E+03, 0.10107900E+04, 0.16093900E+04, -.12644500E+04, -.12974400E+04, -.11416600E+04, 0.15727600E+04, -.18045100E+03, 0.56521100E+02, 0.11502500E+03, -.31457900E+03, -.35670600E+03, 0.16786800E+03, -.43796900E+03, 0.73820700E+03, -.15705800E+03, -.69386300E+03, -.24133200E+03, -.23339200E+02, 0.15059900E+03, 0.11931500E+02, -.99155100E+02, 0.27381900E+03, 0.98380900E+03, 0.34653600E+03, -.78161400E+03, -.43320400E+02, -.47727700E+03, 0.15272000E+04, -.92228100E+03, 0.15345900E+03, 0.24107300E+03, 0.15271600E+03, -.12213500E+04, -.89970200E+02, -.20953800E+02, 0.19885500E+04, 0.20483000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.31056800E+00, -.88683500E+00, 0.11541700E+00, -.49493300E+01, 0.28054100E+01, 0.38259800E+00, -.69456200E+00, 0.93156200E+00, 0.58974500E+00, -.20337700E+00, -.99989900E+00, 0.62406400E+00, 0.30268600E+00, 0.16334700E+00, -.29859600E+00, 0.16597100E-01, 0.55331100E+00, 0.20148100E-01, 0.53273900E-01, -.27632700E-01, 0.15118000E-01, 0.56363600E+00, 0.55823600E+00, -.16783500E+00, 0.40251800E+00, 0.16640100E+00, 0.20395500E+01, -.22557400E+00, -.17542500E+01, 0.68509000E+00, -.15579200E+00, -.76505300E-02, 0.32548300E+00, 0.52354800E+00, -.18752500E+00, 0.53313100E+03, 0.25799500E+04, -.12660200E+04, -.12220400E+04, -.39517300E+03, -.44873700E+03, -.48968400E+03, 0.58983200E+02, -.55277400E+03, -.85043900E+03, 0.10665600E+03, -.59329500E+02, -.40583400E+02, 0.52889500E+02, 0.11874700E+03, -.11702800E+03, -.11588300E+03, -.81658500E+02, 0.58178000E+02, 0.50326900E+03, -.24239000E+03, -.17464100E+03, -.30476300E+03, -.11589200E+03, 0.75474900E+02, 0.32578900E+03, -.40995100E+02, -.83094500E+03, 0.16535000E+04, -.79614600E+03, -.83177700E+03, 0.40523200E+03, -.17297200E+03, -.55606400E+03, -.57281300E+03, -.91933000E+03, -.28924100E+03, 0.61202900E+04, -.28503200E+04, -.30298700E+04, 0.40368700E+02, -.54637200E+03, -.21247300E+04, -.41723900E+03, -.21720600E+04, -.24787800E+04, -.11706500E+04, 0.51139400E+03, 0.58770600E+03, -.66151000E+03, -.78599000E+03, 0.12375300E+04, 0.12269200E+04, 0.14019900E+04, -.13445500E+04, -.49986700E+04, 0.23327300E+04, 0.23753600E+04, -.46046400E+03, 0.37902400E+03, 0.18802000E+04, 0.73454800E+03, 0.19526200E+04, 0.15020400E+04, -.34791100E+03, 0.17084500E+03, 0.26621000E+03, -.39856600E+03, 0.60422000E+03, 0.17060300E+01, 0.17169800E+03, 0.52778700E+03, 0.57893900E+03, 0.95582500E+02, -.18223200E+03, -.16380300E+03, -.12749400E+04, -.69714000E+03, 0.69390100E+03, 0.24109600E+04, 0.32847700E+03, -.22840200E+04, -.29349900E+03, 0.14323000E+03, 0.74175900E+02, 0.35117700E+03, 0.58220200E+03, -.18619700E+03, 0.28653800E+03, -.25776600E+02, 0.49255300E+03, -.10315800E+04, 0.57962300E+03, 0.46242700E+03, 0.96606100E+03, 0.59951300E+03, -.56592400E+03, -.94355800E+03, -.55023400E+03, 0.11396500E+04, 0.11390500E+04, -.57990600E+03, -.56093800E+03, -.83666100E+02, 0.42988200E+03, -.42396500E+03, -.25834000E+03, -.11036200E+03, 0.10148700E+03, -.18133200E+04, 0.88430600E+03, 0.85524200E+03, 0.53808000E+03, 0.81024500E+03, 0.35979000E+03, -.32278500E+03, 0.64599300E+03, 0.86213000E+03, -.94470500E+03, 0.45987300E+03, 0.45805600E+03, -.12426300E+04, -.55255300E+03, 0.11789300E+04, 0.12716300E+04, 0.80630700E+03, -.67630900E+03, -.47570900E+03, 0.25742700E+03, 0.20082500E+03, -.16016400E+03, -.57500600E+03, 0.49066100E+03, 0.50310700E+03, 0.36481600E+03, -.48606200E+03, -.94724800E+03, 0.35683700E+03, 0.57864900E+03, 0.24507100E+02, 0.93152000E+02, 0.18343300E+03, 0.20025500E+03, -.22103800E+03, -.55431000E+03, 0.38238300E+03, -.18103900E+03, -.14521400E+03, -.21631600E+03, -.53517200E+03, -.10009600E+02, 0.12533400E+03, 0.10450900E+03, -.10323900E+04, -.16992200E+03, -.32399700E+03, -.20669300E+03, -.12390000E+01, -.12235800E+03, 0.12322100E+03, 0.55374800E+02, -.62690700E+03, 0.44984100E+03, 0.22660700E+03, -.12810700E+03, -.33249800E+03, 0.11358700E+04, 0.83773000E+03, -.18117000E+03, 0.36479700E+02, 0.25472700E+03, -.82041700E+02, -.25848200E+03, -.14139600E+02, -.13567400E+04, -.69251400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.63549300E+00, 0.56217500E+00, 0.30533400E+00, 0.50532900E+01, -.12992400E+01, -.12488000E+00, 0.85566000E-01, 0.11964000E-01, -.99737900E+00, 0.18293800E+00, -.49312700E+00, -.19013200E-01, 0.17142700E+01, -.18302600E+00, 0.58983500E-01, 0.66419700E+00, 0.32792600E+00, 0.43322600E+00, -.55521100E-02, -.31968100E+00, 0.71907000E-01, 0.12054300E+01, 0.16751700E+01, 0.17632100E+00, 0.29436900E+00, -.36276200E+00, -.87421600E+00, 0.38377300E-01, -.13276300E+01, -.44173300E+00, 0.61903100E+00, -.80888900E+00, -.28048300E+00, -.59909000E+00, 0.53138600E+00, 0.31291500E+00, -.37796200E+04, 0.18545900E+04, 0.19692400E+04, -.20132600E+03, 0.38649800E+03, 0.12869300E+04, 0.83068700E+03, 0.89737400E+03, 0.27447700E+03, -.29572700E+03, 0.14620200E+03, 0.12662500E+03, -.86343700E+02, -.92391200E+02, 0.17909600E+03, 0.19567200E+03, 0.10556300E+03, -.40156300E+02, -.19045200E+04, 0.93040100E+03, 0.10632000E+04, -.34891000E+03, -.15235900E+03, 0.94601900E+03, 0.10244900E+04, 0.36118500E+03, 0.19622900E+03, -.34323400E+03, 0.15561400E+03, 0.10099300E+03, -.99627700E+03, 0.19184100E+03, 0.10732100E+03, 0.54631800E+03, 0.79714300E+03, 0.31409200E+03, -.10402600E+05, 0.49645200E+04, 0.54314500E+04, -.37037100E+03, -.12080700E+04, 0.43148500E+04, 0.30096400E+04, 0.38707900E+04, 0.47986100E+03, 0.34671400E+04, -.15987000E+04, -.14628000E+04, 0.41346200E+03, -.42986200E+02, -.16874400E+04, -.11961800E+04, -.11688100E+04, 0.45276300E+03, 0.28542000E+04, -.12653400E+04, -.16966900E+04, 0.98627600E+03, 0.15874400E+04, -.19130800E+04, -.29614600E+04, -.12318200E+04, 0.52596200E+03, -.22268500E+04, 0.10816400E+04, 0.12881000E+04, 0.81893300E+03, -.53748500E+03, 0.91406500E+03, -.31209200E+03, 0.36985600E+03, -.40618300E+03, -.62348600E+04, 0.32278200E+04, 0.33546300E+04, 0.21266600E+04, -.19659500E+03, 0.18623900E+04, 0.20240300E+03, 0.27008300E+04, 0.19194900E+04, -.20243600E+04, 0.99951300E+03, 0.88376000E+03, -.42384500E+03, -.11051100E+04, 0.14341400E+04, 0.67940200E+03, 0.16127400E+04, -.44328600E+03, -.88427200E+03, 0.39051500E+03, 0.95832700E+02, -.28412900E+03, -.84851600E+02, 0.57083600E+03, 0.50080200E+03, 0.75625100E+03, -.73856600E+03, -.28838000E+04, 0.13775500E+04, 0.16001700E+04, 0.14571900E+01, -.45698500E+03, 0.10819600E+04, 0.15584600E+03, 0.92667800E+03, 0.26980800E+03, 0.46999700E+04, -.22606500E+04, -.25212800E+04, -.29016000E+03, -.18362400E+03, -.17327600E+04, -.66279000E+03, -.22991400E+04, -.35579900E+03, 0.12614400E+04, -.61060300E+03, -.54420700E+03, 0.20966000E+04, 0.96071000E+03, -.19735300E+04, -.27612900E+04, -.19060800E+04, 0.78229200E+03, 0.15193000E+04, -.75238000E+03, -.77587400E+03, 0.12415300E+03, 0.41431900E+03, -.75858000E+03, -.31743300E+03, -.34513500E+03, 0.40167000E+03, 0.82925800E+03, -.30056600E+03, -.39917700E+03, 0.25086200E+03, -.45041600E+03, 0.20973900E+03, 0.13826000E+04, 0.24380200E+03, 0.13124400E+03, -.11659700E+04, 0.56737900E+03, 0.70992300E+03, 0.14270300E+03, -.24358900E+03, 0.44936800E+03, 0.32807500E+03, 0.25504100E+03, 0.39143900E+03, 0.54717800E+03, 0.31623600E+03, 0.54460700E+02, -.29405400E+02, 0.68730700E+01, -.11162300E+03, -.15228000E+03, 0.35214600E+03, -.63899200E+03, 0.23636400E+04, -.11356700E+03, 0.19307700E+04, -.18365100E+04, 0.11911000E+03, -.49187400E+02, -.12489300E+03, -.38900900E+03, 0.12737500E+04, 0.26011000E+03, 0.39090700E+02, -.31354600E+02, -.21861000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.48724400E+01, 0.26058500E+01, 0.69604600E+01, 0.26922200E+02, -.42795300E+01, -.14536000E+01, 0.96016700E-01, 0.28408300E+01, -.55297600E+01, 0.18610500E+01, -.14501400E+01, 0.64250300E+00, 0.43416600E+01, 0.39994300E+01, 0.71098200E+00, 0.65977800E+00, 0.39498300E+01, 0.65883500E+00, 0.34689200E+00, -.14886200E+01, 0.10540500E+00, 0.68654500E+01, 0.12313200E+02, -.94376000E+00, 0.20836700E+01, -.10709000E+01, 0.61177400E+01, -.45335100E+01, -.28259500E+02, -.21590200E+01, 0.96245700E+00, -.51807700E+01, -.51133800E+00, -.68883600E+01, -.15526000E+00, -.22831400E+01, 0.89801600E+00, 0.17587900E+03, -.33066100E+03, 0.24787400E+04, 0.15819100E+04, -.17847200E+04, -.33147900E+04, -.79443400E+03, 0.22551500E+04, -.29202000E+03, 0.13253000E+03, 0.25641900E+03, 0.23969900E+03, -.47333400E+01, 0.14372800E+03, 0.88254100E+02, 0.64965900E+03, 0.39470800E+02, 0.16121600E+04, -.72041800E+03, -.96395300E+03, 0.28979100E+04, 0.35562800E+04, -.31943700E+04, -.72166500E+04, -.31730700E+04, 0.33067000E+04, -.22987400E+04, 0.13720200E+04, 0.98670900E+03, 0.32967800E+04, 0.16182200E+04, -.59074700E+03, -.23620100E+04, -.22797000E+04, 0.20966400E+04, 0.14100700E+05, -.55131900E+04, -.79853400E+04, 0.26547200E+04, 0.54865200E+04, -.31327700E+04, 0.95314900E+03, -.14615100E+04, 0.18980800E+04, -.93951800E+04, 0.43134900E+04, 0.37219900E+04, 0.66511800E+03, -.18842700E+04, 0.10882200E+04, -.38289300E+04, 0.30766100E+03, -.42158300E+03, -.56364400E+04, 0.16529500E+04, 0.36475400E+04, -.13456800E+04, -.22963300E+04, 0.11591200E+04, 0.24395300E+04, -.80988100E+03, -.29444200E+02, 0.57577000E+04, -.26974700E+04, -.33427600E+04, -.29900800E+04, -.77496500E+03, -.34084300E+04, -.56528700E+03, -.77960600E+03, -.17364300E+04, 0.24643900E+05, -.13300000E+05, -.13922500E+05, 0.56946900E+04, 0.59375800E+04, -.78143300E+04, 0.84010100E+03, -.24524100E+04, 0.30092600E+04, 0.80477900E+04, -.40042100E+04, -.35454100E+04, 0.32297500E+04, 0.46738300E+04, -.57084100E+04, -.53210600E+04, -.51480100E+04, 0.29929700E+04, 0.20395900E+04, -.57771900E+03, 0.34960600E+03, -.59639800E+03, -.37178200E+03, 0.18640000E+04, 0.61061100E+04, 0.38219000E+04, 0.18000700E+03, 0.19442100E+04, -.84751000E+03, -.16312100E+04, -.17498900E+04, -.11331300E+04, -.69349300E+03, 0.13489800E+04, -.64395700E+03, -.21184800E+04, -.15524300E+05, 0.79187400E+04, 0.83464100E+04, 0.84287400E+03, 0.34853400E+04, 0.20832800E+04, -.31788600E+04, 0.31956800E+04, 0.37386400E+04, 0.26449100E+04, -.14418000E+04, -.21880900E+04, -.11339500E+04, -.27575200E+04, 0.91508400E+03, 0.43387500E+04, 0.62809900E+03, -.25632000E+04, 0.44411300E+03, -.17023500E+03, -.19389300E+03, -.78071100E+03, 0.21633800E+03, -.18358900E+02, -.14223600E+04, -.27475100E+04, -.54818700E+02, -.16789400E+04, -.10320800E+02, 0.56267800E+03, 0.36491400E+04, 0.40499100E+04, -.79803900E+03, -.20706400E+04, 0.41982800E+04, 0.37180100E+04, -.30898600E+04, 0.14880400E+04, 0.97917200E+03, 0.94770300E+03, -.11788500E+04, 0.22250500E+04, 0.11840300E+04, 0.30872200E+04, -.11078600E+04, 0.19356500E+03, 0.88406000E+00, 0.12449200E+03, -.61232400E+03, 0.10354700E+04, -.35014300E+03, 0.60105000E+02, 0.20848600E+04, 0.62310000E+03, -.31288300E+04, 0.36553600E+03, -.17194600E+04, 0.34424200E+04, -.19533800E+04, 0.13145300E+04, -.18855500E+03, 0.13930400E+04, 0.10224700E+04, 0.23936600E+03, -.25736400E+03, 0.29980100E+04, -.12290500E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.90924400E+00, 0.31371400E+00, 0.40051900E+00, 0.10561300E+01, -.14408100E+00, 0.12097100E+00, 0.21445800E+00, 0.95539300E+00, -.10120700E+01, 0.46334200E+00, 0.19117100E-01, -.56364800E-01, -.10904600E+01, 0.83776700E+00, -.24735300E-01, 0.12612200E+01, 0.11752700E+01, 0.82708600E+00, 0.25789800E+00, -.40675000E+00, -.14684600E-01, 0.16127600E-01, 0.18148500E+01, -.47300000E+00, 0.93899500E+00, 0.24984200E+00, 0.18523600E+01, 0.10114800E+00, 0.19645500E+00, 0.23639800E-01, 0.61583000E+00, -.70695500E+00, 0.13044100E+00, -.76043600E-01, 0.36179500E+00, -.13161900E+01, 0.75792100E-01, 0.33286800E-01, 0.27404100E+03, -.67853800E+03, -.10583500E+04, 0.68680000E+03, 0.10629500E+04, 0.11304100E+04, -.10367400E+04, -.14109600E+03, 0.68024000E+02, 0.13354700E+03, 0.93070200E+02, 0.41138600E+02, -.39886100E+02, -.14915900E+03, -.64465700E+02, 0.16871400E+03, -.11415600E+04, 0.57133200E+03, 0.10722000E+04, -.10123800E+04, -.12092100E+04, 0.10452800E+04, 0.14802900E+04, 0.12035200E+04, -.11571500E+04, -.83564800E+03, 0.42994800E+03, 0.36614700E+03, -.12287400E+04, -.12518500E+03, 0.66693700E+03, 0.74998100E+03, 0.88668800E+03, -.10306500E+04, 0.56853100E+04, -.28581600E+04, -.24203400E+04, -.36521700E+03, -.14957800E+04, -.18118200E+04, -.57497600E+02, -.19750100E+04, -.33608000E+04, -.12387100E+04, 0.67667600E+03, 0.76466400E+03, -.12112900E+04, -.11744400E+04, 0.13383900E+04, 0.14889400E+04, 0.15219500E+04, -.47302300E+03, -.39045200E+04, 0.19535900E+04, 0.12440200E+04, -.34890500E+03, 0.13241400E+04, 0.14941700E+04, 0.36113600E+03, 0.17764600E+04, 0.18191200E+04, -.11513400E+04, 0.57589800E+03, 0.91721500E+03, 0.10618500E+04, 0.23438200E+03, 0.20363400E+03, -.53901700E+03, -.12542100E+03, 0.16871900E+04, 0.58762200E+04, -.29270100E+04, -.28041400E+04, -.17112100E+04, -.29656800E+04, -.93937200E+03, 0.20833900E+04, -.11337900E+04, -.40600200E+04, 0.35160200E+03, -.18712700E+03, -.51377300E+03, -.26272500E+03, -.60683400E+03, 0.16049900E+03, 0.90171700E+03, 0.49743000E+03, 0.18206500E+03, -.34639600E+03, 0.16532800E+03, -.14032100E+03, 0.10193600E+04, 0.87419000E+03, -.77299800E+03, -.10669000E+04, -.56851200E+03, 0.87847500E+03, 0.39999200E+01, -.44193100E+02, 0.92213100E+02, 0.60736600E+03, -.11215700E+03, -.72146400E+02, -.58859000E+03, -.29910300E+02, 0.96873700E+03, -.10533300E+04, 0.57889400E+03, 0.31398800E+03, -.48034000E+03, 0.73911700E+03, 0.74443300E+03, 0.12657900E+04, 0.90800800E+03, 0.40200900E+03, -.54028100E+03, 0.27058000E+03, 0.25748200E+03, 0.29132900E+03, 0.15533000E+03, 0.18348200E+03, -.48130700E+03, -.23375600E+03, -.38859400E+03, 0.16266000E+04, -.80265100E+03, -.93548700E+03, -.53310700E+03, -.20909000E+03, -.27073100E+03, 0.57302000E+03, -.88714100E+02, -.67316300E+03, 0.25842300E+04, -.12698900E+04, -.96389500E+03, -.89003500E+03, -.96700600E+03, -.60057000E+03, 0.72125800E+03, -.13425900E+04, -.16190400E+04, 0.27014000E+04, -.13821800E+04, -.10541300E+04, -.20071600E+02, -.79737500E+03, -.12532400E+04, -.11934900E+04, -.13720000E+04, -.66927400E+03, 0.27817700E+03, 0.45944200E+02, 0.11858300E+03, -.15599800E+03, 0.30018400E+03, 0.85554800E+02, -.18808200E+03, -.65538200E+03, -.68554000E+03, 0.10725000E+04, 0.15009200E+03, -.38310700E+02, -.13691900E+04, 0.58562400E+03, -.11034300E+03, -.22371000E+03, 0.22620200E+03, 0.10942400E+03, -.10433800E+01, 0.84676400E+02, -.82353400E+03, -.13355600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.25966200E+01, 0.14257800E+01, -.43624700E+00, 0.29843700E+02, -.43415400E+01, -.80269200E+00, 0.26631800E+01, 0.62710700E+00, -.65533000E+01, 0.14469100E+01, -.21696400E+01, 0.51662000E+00, 0.18907100E+01, -.70281800E+00, -.11784700E+01, 0.42366400E+01, 0.16412000E+01, 0.26360300E+01, 0.10659600E+01, -.13335100E+01, -.14846200E+00, 0.33641500E+01, 0.14493400E+02, -.28568900E+00, 0.15277800E+01, 0.36141500E+00, 0.16552900E+01, 0.41676100E-01, 0.37853700E+01, 0.13714800E+01, 0.19525900E+01, -.94085000E+00, 0.37366600E+00, -.34260000E+01, 0.13913700E+01, -.11493600E+01, 0.13883600E+01, 0.35691000E+00, 0.31197000E+01, 0.29250500E+04, 0.44103400E+04, -.24487200E+04, -.40364000E+04, -.55480700E+04, 0.32593900E+04, 0.11458300E+04, -.59034100E+03, -.52798400E+03, -.32642400E+03, -.65218300E+02, -.12388100E+03, 0.44834700E+03, -.29573800E+03, -.53002800E+03, 0.73186300E+04, -.36528600E+04, -.32210100E+04, 0.52377200E+04, 0.51961200E+04, -.58829800E+04, -.70926000E+04, -.75518900E+04, 0.42841100E+04, 0.52993900E+04, -.26615100E+04, -.22938900E+04, 0.52885400E+04, 0.76699400E+03, -.32339200E+04, -.54694100E+04, -.41039300E+04, 0.35395900E+04, 0.43366300E+04, -.20126400E+04, -.19493600E+04, 0.43789500E+04, 0.73281700E+04, -.34594700E+04, -.78576500E+04, -.25022500E+04, 0.11785500E+05, 0.11607900E+05, -.59980400E+04, -.58995700E+04, 0.32470600E+04, 0.38851500E+04, -.63842700E+04, -.40852400E+04, -.79190700E+04, 0.11007400E+04, -.22681100E+04, 0.10302800E+04, 0.12045600E+04, -.30004500E+04, -.98404800E+04, 0.32847000E+04, 0.78666300E+04, 0.34279700E+04, -.91188700E+04, 0.42953500E+04, -.22547400E+04, -.27166100E+04, -.52865100E+04, -.24248400E+04, 0.98442700E+03, 0.73377800E+04, 0.18895600E+04, -.68375800E+04, 0.17156100E+05, -.86089600E+04, -.73207500E+04, 0.29191200E+04, 0.60062500E+04, -.79715600E+04, -.77810200E+04, -.11172100E+05, 0.83842300E+04, 0.66346800E+03, -.32060900E+03, -.41521800E+02, -.11583500E+04, -.15635700E+03, -.83422100E+01, 0.32093000E+03, -.78200300E+03, -.22968300E+04, -.86188400E+03, 0.48735500E+03, 0.82238600E+03, -.56283300E+04, -.43935000E+04, 0.49456700E+04, 0.65423400E+04, 0.54146200E+04, -.46065400E+04, 0.37924500E+04, -.19585600E+04, -.22185100E+04, -.23285000E+04, -.30025500E+03, -.82845600E+03, 0.27856600E+04, 0.28333900E+03, -.35405400E+04, 0.76456500E+04, -.40354400E+04, -.33596200E+04, 0.10828100E+04, -.51405700E+04, -.21891900E+04, -.23947100E+04, -.38255200E+04, -.34010300E+04, 0.53588700E+03, -.26244400E+03, 0.13454200E+03, -.28092200E+04, 0.33529900E+02, -.51604500E+01, 0.13307800E+04, 0.78620100E+03, 0.11154700E+04, -.75516800E+04, 0.38287000E+04, 0.39956200E+04, 0.23495600E+04, 0.41257800E+03, 0.13903100E+04, -.27496800E+04, 0.22596200E+04, 0.24951600E+04, 0.65250500E+04, -.33631500E+04, -.30173500E+04, 0.33182100E+04, 0.33237300E+04, -.35065600E+04, -.48809600E+04, -.57821600E+04, 0.45778000E+04, -.33364700E+04, 0.18099100E+04, 0.15348400E+04, -.33191200E+03, 0.47901500E+04, 0.14505600E+04, 0.19182500E+04, 0.19802700E+04, 0.33393000E+04, -.21175300E+04, -.65032400E+03, -.48908800E+03, 0.11697500E+04, -.13047200E+04, -.38290900E+03, 0.10114100E+04, 0.35300400E+04, 0.32012200E+04, -.83780400E+04, -.81872500E+03, -.45507900E+04, 0.76156400E+04, -.21387100E+04, -.40589800E+03, 0.79046200E+03, 0.18263300E+03, -.22899400E+04, -.52206000E+03, -.19651700E+03, 0.56894700E+04, 0.95214800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10798100E+01, -.14891900E+00, 0.19444100E+00, -.54392800E+01, 0.12779100E+01, 0.26605700E+00, -.24868200E+00, -.10951400E+01, 0.87379800E+00, -.35025200E+00, 0.10189600E+01, -.18254500E+00, -.14145500E+01, -.25604800E+00, -.33350100E+00, -.27943300E+01, -.76199400E+00, -.95579400E+00, -.31782300E+00, 0.54851100E+00, 0.53881900E-01, -.99117800E+00, -.52518900E+01, 0.25270300E-01, -.49937300E+00, -.14052800E+00, 0.17784100E+00, -.39065100E+00, -.32216500E+01, 0.23061200E+00, -.61616600E+00, 0.14209400E+00, 0.11296900E+00, 0.65918100E+00, -.72045800E+00, 0.10215100E+01, 0.18018500E+00, -.38283900E-01, -.10478900E+01, 0.11106800E+00, -.11672900E+04, 0.48166900E+03, 0.98058500E+03, 0.21470900E+04, -.63912200E+03, -.16198100E+03, 0.81597200E+02, 0.13185400E+03, 0.73324100E+02, -.37840100E+02, 0.94370400E+01, -.14684000E+03, 0.18354800E+03, 0.14097200E+03, -.15272400E+04, 0.76825500E+03, 0.63167000E+03, -.31427400E+03, -.10059800E+04, 0.80040000E+03, 0.71183600E+03, 0.21012200E+04, -.47136500E+03, -.82262400E+03, 0.41879600E+03, 0.50435100E+03, -.48423500E+03, -.89829500E+02, 0.48238400E+03, 0.64747400E+03, 0.67590400E+02, -.84885400E+03, 0.77003500E+04, -.39130700E+04, -.39368200E+04, -.37524300E+02, -.45475500E+03, -.25461400E+04, -.11710800E+04, -.16852900E+04, -.25541200E+04, -.71960000E+04, 0.36119200E+04, 0.33204300E+04, -.47325900E+03, -.21487700E+03, 0.23603300E+04, 0.62406600E+03, 0.15314100E+04, 0.73315700E+03, -.18210600E+04, 0.95460000E+03, 0.93999100E+03, -.28603400E+03, 0.93772400E+03, 0.77506000E+03, 0.14038600E+04, -.63928400E+03, 0.13768900E+04, -.18313100E+04, 0.91612100E+03, 0.11131800E+04, 0.65178900E+03, 0.39311300E+03, 0.50817600E+02, -.83810000E+03, 0.23123800E+03, 0.17039000E+04, 0.57887000E+04, -.28266300E+04, -.33367000E+04, -.79918600E+03, -.67302100E+03, -.17652000E+04, 0.34543400E+03, -.28703100E+04, -.17562600E+04, 0.19745700E+04, -.98302400E+03, -.11845000E+04, 0.48197900E+03, 0.62131000E+03, -.11683100E+04, -.47484800E+03, -.10286900E+04, 0.11041000E+04, 0.30870500E+04, -.15666300E+04, -.14186000E+04, 0.61538100E+03, 0.61534600E+03, -.12293000E+04, -.78852600E+03, -.10480200E+04, 0.40860800E+03, 0.19454500E+03, -.11627400E+03, -.31682400E+02, 0.29876500E+03, -.32571300E+03, -.14542100E+03, -.32936000E+03, -.35429400E+03, 0.56514600E+03, -.74495100E+04, 0.36869200E+04, 0.35924100E+04, -.25326600E+02, 0.15380700E+04, 0.22999000E+04, 0.10316400E+04, 0.26672600E+04, 0.11991300E+04, -.46226600E+02, 0.27019300E+02, -.11669800E+03, -.16134400E+03, -.63857500E+03, 0.75735100E+03, 0.11848100E+04, 0.59759100E+03, -.11345700E+04, 0.16534700E+04, -.83131800E+03, -.92646500E+03, -.41256600E+03, 0.13030800E+03, -.41548500E+03, 0.15670700E+03, -.12504700E+04, -.49073300E+03, -.10818800E+04, 0.59946700E+03, 0.51713200E+03, -.44741400E+03, 0.12434300E+03, 0.81829500E+01, -.63072800E+03, -.29813000E+03, -.15193100E+03, 0.33946900E+04, -.17223300E+04, -.15440400E+04, -.20584700E+03, -.90081900E+03, -.12709000E+04, -.11518100E+04, -.99910700E+03, -.65830400E+03, 0.22557600E+03, 0.28093100E+03, 0.32908300E+03, -.29495600E+03, 0.55383100E+03, 0.25625400E+03, -.18371600E+03, -.49528500E+03, -.31619700E+03, 0.11681000E+02, 0.46756100E+03, -.35855500E+03, -.45920000E+03, -.29691500E+03, 0.35036400E+03, -.25773300E+03, 0.49922000E+03, -.57068000E+03, 0.13902200E+03, 0.85768100E+02, 0.25926900E+03, 0.28693500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14538700E+01, -.36516800E+00, -.93834300E+00, -.58073300E+01, 0.12359200E+01, 0.82169500E-01, -.21730400E+00, -.11337000E+01, 0.24541200E+01, -.47329900E+00, 0.12589700E+01, -.46330600E+00, -.53196600E+00, -.64695500E+00, -.55580000E+00, -.27132800E+01, -.92751800E+00, -.20151500E+00, -.73501500E+00, 0.15687500E+00, 0.28163400E-01, 0.25980000E-01, -.11893800E+01, 0.33435900E+00, 0.14869000E+00, -.42742900E+00, -.43669000E+01, 0.20209800E+00, -.51635300E+00, -.39221800E+00, -.20152600E+00, -.39479200E+00, -.19254500E+00, -.26908300E+00, 0.25890700E-01, 0.18005600E+01, 0.90417000E+00, 0.88059100E-01, -.73874800E+00, -.24146000E-01, 0.98548600E-02, -.34818400E+03, -.16017800E+03, 0.59917600E+03, 0.26441900E+03, 0.45127100E+02, -.22675800E+02, 0.10499900E+02, -.27308200E+02, -.41257200E+02, -.19026700E+02, -.82558800E+02, -.45945500E+02, -.14668700E+02, 0.12306600E+03, -.58396000E+02, 0.70648600E+02, -.22100100E+03, -.43139800E+03, -.17098100E+03, 0.35385700E+03, 0.81847400E+03, -.29363800E+02, -.12837700E+04, 0.60475000E+03, 0.70823200E+03, -.51863700E+03, -.12096400E+03, 0.86771200E+03, 0.11502400E+04, 0.12067700E+04, -.29112300E+03, -.23220700E+04, 0.11686500E+04, 0.11983200E+04, -.10154200E+04, 0.30517600E+03, 0.31088600E+03, -.98581200E+03, 0.11915400E+04, 0.76573600E+03, 0.43199700E+03, -.25802900E+03, -.34115900E+03, 0.42408100E+03, 0.10576900E+04, -.46357000E+03, 0.21648000E+03, -.89587900E+03, 0.45908600E+03, 0.25996500E+04, -.12884200E+04, -.13018300E+04, 0.33863000E+02, -.10839100E+04, -.13028200E+03, 0.82788100E+03, -.11085100E+04, -.11025000E+04, 0.17653800E+04, -.88014700E+03, -.10405600E+04, 0.46395700E+03, -.58974700E+02, -.85034900E+03, -.12107700E+04, -.17684300E+04, 0.11406900E+03, 0.33283400E+04, -.16611900E+04, -.14401200E+04, -.26577600E+04, -.95528200E+03, -.69816800E+03, -.13998200E+04, -.63371500E+03, -.88533000E+03, 0.18845000E+04, -.94922900E+03, -.87701800E+03, -.65092900E+03, -.79887300E+03, -.14595300E+03, 0.40133100E+03, 0.87827800E+02, -.83863100E+03, 0.28529800E+04, -.14342200E+04, -.12234600E+04, -.79701100E+03, -.59995800E+03, -.23330400E+03, -.20391600E+03, -.28457900E+03, -.89084000E+03, 0.58603100E+03, -.26435100E+03, -.42087700E+03, 0.43101100E+03, 0.36985900E+02, -.39084400E+03, -.66584600E+03, -.89032100E+03, 0.42725800E+02, 0.17486100E+04, -.92680000E+03, -.71607500E+03, -.80738100E+03, -.15422800E+04, 0.42603000E+03, 0.16918200E+04, 0.37632400E+03, -.15406700E+04, 0.10554100E+04, -.52979700E+03, -.52077600E+03, 0.21357200E+03, 0.55006100E+03, -.76690800E+03, -.65572400E+03, -.38913400E+03, 0.49702100E+03, 0.15927800E+02, -.86760600E+00, 0.16269700E+02, 0.14034600E+02, 0.13601400E+03, 0.70377800E+02, 0.39649400E+03, 0.18531300E+03, 0.18256000E+02, 0.20394700E+04, -.10292900E+04, -.94917700E+03, -.15478500E+04, -.93901300E+03, -.32097100E+03, -.16727500E+03, -.14293400E+03, -.80787300E+03, 0.54450500E+02, 0.24654900E+01, -.57455800E+02, 0.27640200E+03, 0.10152000E+04, -.42210600E+03, -.53383900E+03, -.39877100E+03, 0.77815400E+03, -.55081600E+02, 0.22281900E+03, 0.30460100E+03, 0.33494600E+02, -.96129900E+02, 0.78985900E+02, -.61951000E+02, 0.17566400E+03, -.24989900E+03, -.16197000E+04, 0.11259000E+03, -.92584800E+03, -.83017000E+03, -.63174300E+03, 0.12215600E+03, 0.56441700E+02, -.25641600E+03, -.11038900E+04, 0.26280700E+03, 0.51020600E+02, 0.82220500E+03, 0.25173100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14782300E+01, 0.82038800E+00, 0.16028700E+00, 0.14352600E+02, -.25333200E+01, -.41558100E+00, 0.12730500E+01, 0.44739300E+00, -.28075600E+01, 0.77859100E+00, -.62132300E+00, 0.27222900E+00, 0.15245500E+01, 0.44252300E+00, -.72406800E+00, 0.24874900E+01, 0.23827200E+01, 0.20322000E+01, 0.57469300E+00, -.14955100E+01, 0.29193800E+00, 0.22454900E+01, 0.78113000E+01, -.32068400E+00, 0.94972800E+00, 0.65987000E+00, 0.52353200E+01, 0.38026100E-01, 0.69698700E-01, 0.15492000E+00, 0.11212700E+01, -.54406600E+00, 0.19259300E+00, -.19448000E+01, 0.90621600E+00, -.21544400E+01, -.27935600E+00, -.51606400E-02, 0.10290700E+01, -.12108100E+00, -.42992300E+00, -.11148400E+01, 0.12604000E+04, 0.57266300E+03, -.30130900E+02, 0.19105000E+03, -.99335800E+02, -.61889200E+02, -.21284300E+03, -.10936100E+03, 0.41645500E+01, 0.87268500E+02, 0.25164500E+02, -.11052100E+03, 0.86400100E+03, -.43259300E+03, -.43049100E+03, 0.39098100E+03, -.28074200E+03, -.22687800E+03, 0.11644300E+04, 0.17633100E+03, -.43278000E+01, 0.18440400E+04, -.91334300E+03, -.69706900E+03, 0.83749600E+02, 0.70270500E+02, -.56933300E+03, -.41165700E+02, -.42970700E+03, 0.67037900E+02, 0.23917500E+04, -.11434100E+04, -.11683500E+04, -.49241400E+03, -.18070400E+03, -.64726000E+03, -.20438200E+04, 0.83768800E+03, -.22137900E+03, -.59847100E+03, 0.29863800E+03, 0.10100300E+03, 0.13295400E+04, 0.19126400E+04, -.10631000E+04, -.12330100E+04, -.24251000E+04, 0.17311500E+04, -.57211200E+04, 0.28154200E+04, 0.29437100E+04, 0.46667400E+03, -.54041000E+03, 0.22181100E+04, 0.24580200E+04, 0.76253300E+03, 0.10054000E+03, -.37761000E+04, 0.18758800E+04, 0.16914700E+04, 0.60390700E+03, 0.52364900E+03, 0.77418200E+03, -.31715900E+03, 0.93025900E+02, 0.45630500E+03, -.12671000E+04, 0.58901100E+03, 0.92529100E+03, -.13268600E+04, 0.97908100E+02, 0.90532000E+03, 0.40799700E+03, -.36659000E+03, 0.29266700E+03, -.18300200E+04, 0.90625600E+03, 0.92002800E+03, -.58759500E+03, -.54761500E+03, 0.10525100E+04, 0.12691000E+04, 0.49553400E+03, -.20817500E+03, 0.11849800E+04, -.57546400E+03, -.39643400E+03, -.12733400E+04, -.50172500E+03, 0.31107300E+03, -.36894000E+03, 0.72284600E+03, -.90783100E+03, -.29799200E+03, 0.11514300E+03, 0.79505600E+02, 0.74648800E+02, 0.14856900E+03, -.22724700E+03, -.33826000E+03, -.45520000E+03, 0.13935600E+03, 0.61438000E+02, -.49280200E+01, 0.64260200E+02, 0.47105900E+03, -.38137700E+03, -.21192600E+03, -.51380600E+02, -.11377500E+04, -.71251700E+02, 0.11218000E+04, -.56402000E+03, -.41521600E+03, 0.37839100E+03, 0.62623000E+03, -.85193300E+03, -.21253700E+03, -.19183400E+03, 0.11442000E+03, -.67268700E+03, 0.35369200E+03, 0.34725400E+03, 0.82121500E+03, 0.26131800E+03, 0.87441000E+02, -.36387700E+03, 0.10947900E+03, 0.46107500E+03, -.71154000E+03, 0.31700100E+03, 0.42958900E+03, -.48067000E+03, 0.13056400E+03, 0.14840600E+03, -.29344900E+02, -.59700500E+03, 0.30257600E+03, 0.10511500E+04, -.52508500E+03, -.48364400E+03, -.42012200E+03, 0.55697300E+03, -.38476800E+03, -.29027700E+03, -.10736500E+02, 0.34751100E+03, -.34361500E+03, 0.29400500E+03, 0.14655000E+03, 0.32233700E+03, -.28830900E+03, 0.26577500E+03, 0.88515200E+02, -.51776300E+02, 0.45643500E+03, -.68522500E+03, -.53359600E+02, -.41267000E+03, 0.43256800E+03, 0.30036300E+03, -.15028600E+03, -.74061900E+02, -.26722600E+03, -.60287000E+03, 0.37736900E+02, 0.14082900E+03, -.13059600E+03, 0.26935000E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.86011100E+00, -.27142200E+00, 0.34099900E+00, 0.13435800E+01, -.16507700E+01, -.24671900E+00, -.38012000E-01, 0.78622700E+00, -.80058400E+00, 0.82555300E-01, -.33482600E+00, -.20394000E+00, 0.57133600E+00, 0.62471100E+00, 0.15494900E+01, 0.18194600E+01, -.29926200E+00, -.19117800E-01, 0.26367300E+00, 0.52391300E+00, -.22172100E+00, -.56077800E+00, -.14936300E+01, -.10440200E+00, 0.12175300E+00, -.22449800E+00, -.21954300E+00, 0.14810800E+00, 0.63558500E+00, -.26772100E-01, 0.23287100E+00, -.53350200E+00, -.37758600E+00, 0.65519100E+00, 0.53102500E+00, -.16935300E+00, 0.43831200E+00, 0.67993700E-01, 0.29663900E-01, -.15657100E+00, 0.12623100E+00, 0.26710500E+00, -.66334500E-01, -.51930900E+03, -.54539100E+02, 0.30432100E+02, -.22465200E+02, -.43314400E+02, -.38711100E+02, -.61159000E+02, 0.35520000E+02, 0.41651400E+02, -.86617100E+02, -.35235100E+02, 0.92480800E+03, -.46985900E+03, -.46597700E+03, 0.56350800E+02, -.21537300E+03, -.42412800E+03, -.20237700E+03, -.85952700E+03, -.13154300E+03, 0.50303500E+03, -.17846000E+03, -.19308000E+03, -.13120600E+03, 0.22575000E+03, -.18611100E+03, -.12632100E+03, 0.22934400E+03, 0.10894100E+03, -.35170400E+04, 0.17710800E+04, 0.18550400E+04, 0.10224300E+03, -.39577500E+03, 0.12460300E+04, 0.68369200E+03, 0.16986000E+04, -.19054700E+02, 0.19173600E+04, -.86411500E+03, -.81250000E+03, 0.17660300E+02, 0.48239000E+02, -.59488800E+03, 0.34990800E+03, -.63896800E+03, -.50101800E+02, 0.14333900E+04, -.76644600E+03, -.71343700E+03, -.49502700E+03, 0.11844200E+03, -.48335100E+03, -.56107500E+03, -.50269100E+03, -.16972200E+03, -.55046800E+03, 0.24431200E+03, 0.21086600E+03, -.10209500E+03, -.40594900E+03, 0.52153900E+03, 0.37813900E+03, -.27964900E+02, -.19500400E+03, -.54080100E+03, 0.23368600E+03, 0.64866900E+03, 0.49220000E+03, -.32812700E+03, -.42915600E+03, -.63860500E+03, -.30555700E+03, -.15186800E+03, -.26106200E+03, 0.14141900E+03, 0.15971900E+03, -.67456500E+03, -.11126300E+04, 0.67596900E+03, 0.62222100E+03, 0.76804200E+03, -.74619400E+03, -.19444900E+04, 0.10124600E+04, 0.83811200E+03, -.25894800E+03, -.53617300E+02, 0.93611000E+03, 0.48108500E+03, 0.85539600E+03, -.10465700E+02, -.77521700E+03, 0.28843700E+03, 0.44116100E+03, -.13224300E+03, -.20457600E+03, 0.36918400E+03, 0.14542000E+03, 0.40309000E+03, 0.29940500E+02, 0.29577500E+04, -.13282000E+04, -.14864100E+04, -.28354600E+03, -.36869700E+03, -.54611900E+03, 0.28900900E+03, -.15505400E+04, -.48381500E+03, 0.32410300E+03, -.15433800E+03, 0.25114500E+02, 0.50759900E+03, 0.58149500E+03, -.76430700E+03, -.13585200E+04, -.53800800E+03, 0.15837400E+03, -.58730100E+02, 0.41549500E+02, 0.81232400E+02, 0.15288900E+03, 0.28797700E+03, -.23290400E+03, -.13474000E+03, 0.45027700E+03, 0.25552300E+03, 0.18129400E+04, -.91561400E+03, -.89909200E+03, 0.32742400E+03, -.17801500E+03, -.73421700E+03, -.85216600E+02, -.15265600E+04, -.13711800E+03, -.33392000E+03, 0.12698600E+03, 0.17904100E+03, 0.10631200E+03, 0.64307100E+02, -.26518600E+01, -.66431700E+02, 0.59828200E+02, 0.81054000E+02, -.29817700E+02, 0.56492900E+02, 0.31086500E+02, 0.12837300E+03, -.15793600E+03, 0.26321400E+02, 0.64446300E+01, -.11768600E+03, -.23308300E+03, 0.55795300E+03, -.97470000E+02, 0.48132300E+03, -.11428700E+03, -.17842400E+03, -.11204100E+03, -.11051100E+03, -.92293300E+02, 0.30970300E+01, 0.65611200E+02, 0.19446000E+02, 0.42622400E+03, -.71380100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23689100E+00, -.34339900E+00, 0.21629600E+00, -.43345300E+01, 0.72951300E-01, 0.53023800E-01, -.38276400E+00, -.15454700E-01, 0.11397300E+01, -.17091500E+00, 0.48664100E+00, -.12461400E+00, -.78277700E+00, -.27586200E+00, -.67180600E-01, 0.63553100E-01, -.47917900E+00, 0.28654800E-01, -.11016600E+00, -.21761700E+00, 0.76043600E-01, 0.49662500E+00, 0.38329500E+00, 0.18188400E+00, 0.29320500E+00, -.42676300E-01, -.21791100E+01, 0.21099800E+00, -.87611500E-01, -.22292100E+00, -.46965000E-01, -.10473300E+00, -.85294400E-01, -.10704800E+00, -.15789000E+00, -.78588400E-01, -.32678800E+00, -.23289100E-01, -.71628400E-01, 0.90644200E-01, 0.19933800E+00, -.71580100E-01, -.19711500E+00, 0.37873600E+00, -.15027300E+03, 0.43139100E+02, -.16937800E+02, -.14973800E+02, 0.31480200E+02, 0.23063100E+02, -.42134100E+02, -.46727700E+01, 0.50548300E+00, -.13990600E+02, -.69573000E+03, 0.34779700E+03, 0.22880000E+03, -.61471500E+01, 0.10812100E+03, 0.40208900E+03, 0.36929700E+03, 0.32595700E+03, -.10144400E+03, -.57467000E+03, 0.27557500E+03, 0.28712500E+03, -.20937300E+03, -.13585800E+03, 0.46335800E+03, 0.67603000E+03, 0.51710700E+03, 0.15028000E+03, -.45819000E+03, 0.21144700E+03, 0.13866300E+03, -.26326300E+03, -.26764400E+03, 0.35779200E+03, 0.10436400E+04, 0.13999100E+03, -.54081800E+02, -.10966600E+04, 0.56664400E+03, 0.43866500E+03, 0.28557500E+02, -.12096000E+03, 0.55753900E+03, 0.17209400E+03, 0.76964500E+03, 0.90284600E+01, -.19624400E+04, 0.99958100E+03, 0.10243700E+04, 0.68293900E+03, 0.70356900E+03, 0.33599500E+03, -.10104300E+04, 0.37353100E+03, 0.68141100E+03, -.33175400E+03, 0.19076400E+03, 0.19730200E+03, 0.68474600E+03, 0.52891200E+03, -.35508800E+03, -.76574500E+03, -.25506400E+03, 0.14944100E+03, -.33461000E+04, 0.16727600E+04, 0.13902300E+04, -.36074800E+03, -.18147500E+03, 0.18614100E+04, 0.19921300E+04, 0.27764600E+04, 0.49942400E+02, -.79818600E+03, 0.39316600E+03, 0.35544300E+03, 0.29501600E+03, 0.37973900E+03, 0.14325200E+03, 0.53353300E+02, 0.14583700E+03, 0.23251600E+03, -.99937800E+02, 0.34648700E+02, 0.96708400E+02, 0.29735200E+02, 0.14787800E+03, -.34386600E+03, -.12307000E+03, -.30020100E+03, 0.29254100E+03, 0.16371400E+03, -.54323000E+02, -.74838500E+02, 0.57244700E+03, 0.31708300E+03, -.27425300E+03, -.54107300E+03, -.38273300E+03, 0.13903400E+03, -.10623800E+04, 0.55404900E+03, 0.49666400E+03, 0.53131900E+03, 0.53311700E+03, 0.18425800E+02, -.39229600E+03, 0.22222100E+03, 0.69619800E+03, -.26188200E+03, 0.12645400E+03, 0.59011200E+02, -.26799000E+03, -.20740900E+03, 0.23421200E+03, 0.25774700E+03, -.11342500E+02, -.15266000E+02, -.22345500E+03, 0.10054600E+03, 0.51698800E+02, -.16749400E+03, -.13535900E+03, 0.27803600E+03, 0.26755000E+03, 0.75771300E+02, -.36263800E+02, -.76384900E+03, 0.39023600E+03, 0.36992000E+03, -.33550800E+03, -.21228100E+03, 0.65433200E+03, 0.11651200E+04, 0.16008000E+04, -.16510900E+03, 0.30491900E+02, -.30687300E+02, -.12581100E+01, -.41389900E+03, -.29092000E+03, 0.11124700E+03, 0.25379600E+03, 0.70609600E+02, -.29395400E+03, -.33708200E+02, -.76942300E+02, -.54608700E+02, -.72181000E+02, 0.72844500E-01, 0.24381500E+02, 0.20512700E+02, -.72986600E+02, -.27166900E+02, 0.10703400E+04, 0.18140100E+02, 0.62246400E+03, -.81704000E+03, 0.67138200E+03, -.49513800E+02, 0.54530900E+02, -.31436300E+03, 0.26136200E+02, -.48198500E+02, -.48686900E+02, -.10711500E+04, -.16944000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12868600E+01, 0.21917200E+00, 0.53683900E+00, 0.20094400E+01, 0.32407200E-01, 0.14843700E+00, 0.36750900E+00, 0.74185000E+00, -.12072300E+01, 0.52178300E+00, -.30839000E-01, 0.92197400E-01, -.96824400E+00, 0.11512400E+01, -.49948100E-01, 0.10396300E+01, 0.16636200E+01, 0.13381000E+01, 0.78797900E-01, -.32756200E+00, 0.16785500E+00, -.46639700E+00, 0.19356600E+01, -.85548100E+00, 0.74952600E+00, 0.35379300E+00, 0.58537900E+01, 0.48422000E+00, 0.22271000E+01, 0.64655900E+00, 0.83295800E+00, -.42670500E-01, 0.48685600E+00, 0.69445700E+00, 0.69341000E+00, -.15567100E+01, -.10351300E+00, -.10083500E+00, 0.52648000E+00, -.19963000E+00, -.78668400E-01, 0.43353000E+00, 0.20255300E+00, -.73103000E-01, -.53613000E-01, -.20203600E+03, 0.97255600E+02, 0.75151600E+02, 0.89103000E+02, 0.98658700E+01, 0.35994300E+02, -.85086100E+01, 0.11532600E+02, 0.63011100E+02, 0.89417500E+03, -.44814200E+03, -.36602300E+03, -.94117000E+02, 0.10747600E+03, -.36675400E+03, -.30088800E+03, -.72315600E+03, 0.41432300E+02, -.14630700E+04, 0.73494800E+03, 0.66706200E+03, -.39961500E+03, 0.79137400E+02, 0.49869400E+03, 0.14203600E+03, 0.82995400E+03, -.28514700E+03, -.12088900E+04, 0.64861900E+03, 0.65453000E+03, -.10503400E+03, -.56005600E+03, 0.77821100E+03, 0.76903900E+03, 0.56230800E+03, -.13562300E+04, 0.73285500E+03, -.33685700E+03, -.18464100E+03, -.49519100E+03, -.71491700E+03, 0.21587500E+00, 0.28407900E+02, 0.32139200E+03, -.31163300E+03, 0.13951900E+04, -.73151600E+03, -.73626500E+03, -.13794400E+03, 0.71789100E+03, -.70212500E+03, -.44204500E+03, -.17605400E+03, 0.85919500E+03, 0.15844200E+04, -.79266300E+03, -.79159600E+03, 0.13358100E+03, -.77793500E+02, -.59613100E+03, -.41675000E+03, -.83468700E+03, 0.35889200E+03, 0.34132500E+04, -.17463300E+04, -.15622700E+04, 0.68698900E+03, -.88660000E+03, -.10053300E+04, 0.11623500E+02, 0.72121900E+03, -.10660000E+04, -.21720400E+02, -.38502300E+00, 0.62641200E+02, -.88857000E+02, -.20144500E+03, 0.16798700E+02, -.99514200E+02, 0.21473400E+03, 0.17278500E+03, -.12618200E+04, 0.64554800E+03, 0.50444300E+03, 0.38915000E+03, 0.14808200E+03, 0.18611600E+03, 0.22914200E+03, 0.31168700E+03, 0.91661200E+02, -.58600300E+03, 0.26969100E+03, 0.31306700E+03, 0.48076700E+02, -.19688400E+03, 0.26566500E+03, 0.13530800E+03, 0.26149900E+03, 0.22337200E+03, 0.16966100E+03, -.27527600E+02, -.98941400E+02, -.41650000E+03, 0.29645900E+03, -.80691400E+02, 0.30144800E+03, -.41723700E+03, 0.27745900E+02, 0.33011900E+03, -.16755500E+03, -.11387400E+03, 0.77811200E+03, 0.31309400E+03, -.63948800E+03, -.10421200E+04, -.79922900E+03, 0.17084100E+03, 0.94460900E+03, -.45498600E+03, -.41691000E+03, -.40606500E+03, 0.60591600E+02, -.23297900E+03, 0.14725700E+02, -.11441700E+03, -.14826700E+03, 0.13648600E+04, -.71424500E+03, -.70006000E+03, 0.38743900E+03, -.16311700E+03, -.45615100E+03, 0.19445100E+03, 0.78990800E+02, -.41551800E+03, 0.86946100E+02, -.46681000E+02, -.81866200E+02, 0.39104900E+03, -.29069000E+03, -.11795300E+03, -.33381100E+03, -.24215900E+03, -.15957900E+03, 0.32622900E+03, -.11425200E+02, -.41654600E+02, -.15031000E+03, 0.21231400E+03, -.97898600E+02, -.96713600E+02, 0.42829100E+02, -.52672700E+03, 0.16179200E+03, 0.51808900E+02, 0.98282900E+02, -.69169200E+03, -.18395700E+03, -.63301600E+01, -.20312200E+02, 0.13162900E+03, 0.32725800E+03, 0.83029200E+02, -.46004200E+02, 0.13251200E+03, -.13240300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21803200E+00, -.69337600E-01, -.12292300E-01, -.86173600E-01, 0.67246900E-01, 0.34421300E-01, 0.40207800E-01, 0.56813900E-01, -.14155100E+00, 0.37145200E-01, -.17931000E-01, -.23475700E-01, 0.17298000E+00, 0.20518900E+00, 0.11314300E+00, -.33587100E-01, -.98097100E-02, -.19182900E+00, -.71921800E-01, 0.38635900E-01, 0.12060400E-01, -.57308400E-01, -.54018500E+00, -.82362900E-01, -.49010800E-02, 0.89669600E-01, 0.10684100E+01, -.10893200E+00, -.12865800E+01, 0.16765400E+00, -.52159800E-01, 0.94736100E-02, 0.97379500E-01, -.63335800E-01, -.45542800E-01, 0.12356100E+00, 0.76217700E-01, 0.70190800E-02, -.10018500E+00, -.17055700E-01, 0.54844400E-01, 0.34353100E-01, -.17138700E-01, -.96925400E-01, -.29843200E+00, 0.15299300E+00, 0.22638800E+01, 0.33216400E+01, -.28643700E+01, 0.79007500E+01, -.53292700E+00, 0.10758800E+01, -.19579300E+01, -.14952800E+02, -.10345500E+03, 0.51671000E+02, 0.33433500E+02, 0.33939300E+01, -.97716000E+01, 0.56937000E+02, 0.93183400E+02, 0.11721000E+03, -.23003600E+02, 0.14924600E+03, -.79082500E+02, -.51733000E+02, -.45252400E+02, -.39839500E+02, -.25593600E+02, -.19113200E+02, -.39593700E+02, 0.41390600E+02, 0.38399100E+03, -.19859600E+03, -.21214200E+03, -.16989700E+02, -.51863500E+02, -.21867300E+03, -.31016600E+03, -.19687300E+03, 0.15313700E+03, -.66332900E+02, 0.38564100E+02, -.62329800E+01, 0.58378000E+02, 0.13613500E+03, 0.24961100E+02, 0.19639300E+02, -.52298600E+02, 0.20361700E+02, -.84931800E+02, 0.51952600E+02, 0.65354800E+02, 0.67657000E+02, -.80217000E+02, 0.75371600E+02, 0.12614000E+03, 0.34202900E+02, -.48005000E+02, -.56140300E+01, 0.13574900E+02, -.24232800E+02, 0.66800000E+02, 0.11723100E+03, -.17963800E+02, -.24113300E+01, -.52416600E+02, -.73021900E+02, 0.27995900E+03, -.13593700E+03, -.15259800E+03, -.20921800E+03, -.20086700E+03, 0.72626100E+01, -.63512800E+02, -.10338000E+03, -.24389600E+02, -.90658100E+02, 0.45184300E+02, 0.52128100E+02, 0.22048700E+02, 0.10920500E+02, 0.36217500E+02, 0.86091700E+02, -.64207100E+02, -.11093900E+03, 0.34584500E+03, -.17866400E+03, -.13674100E+03, -.23062100E+02, -.58272900E+02, -.14731600E+03, -.14176500E+03, -.19858700E+03, -.50556200E+02, 0.43826500E+02, -.61139300E+01, -.38946100E+02, 0.49821900E+02, 0.13135400E+03, -.34087900E+02, -.77811400E+01, -.45793500E+02, -.44849500E+02, 0.22783400E+03, -.10355600E+03, -.95937900E+02, -.20935200E+02, -.50994400E+02, -.23030700E+02, 0.82767000E+02, 0.69880200E+01, -.41923600E+02, -.90377700E+01, 0.31840600E+01, 0.12104900E+02, -.67562000E+02, -.39329200E+02, 0.65383900E+02, 0.81947500E+02, 0.10931500E+03, 0.10543500E+03, -.96705500E+02, 0.41826800E+02, 0.42938000E+02, 0.87596800E+01, -.27167500E+02, 0.45470300E+02, 0.23942600E+02, 0.58970000E+02, 0.25232000E+02, 0.26619000E+03, -.12851100E+03, -.11636600E+03, -.12701500E+03, -.12639200E+03, -.29720100E+02, 0.63839100E+01, 0.66917800E+01, -.94368300E+02, 0.36752000E+02, -.22001200E+02, -.23478800E+02, 0.46693400E+02, 0.58179200E+02, -.51863600E+02, -.65855000E+02, -.60182100E+02, 0.46064900E+01, -.44099100E+01, -.21612800E+02, -.16204400E+02, 0.40257900E+00, -.34551800E+02, 0.77510000E+01, 0.63994600E+01, -.51655700E+00, 0.18097900E+02, -.10623000E+03, -.17572400E+01, -.99451100E+02, -.63019400E+02, 0.51791500E+02, -.40535300E+02, 0.39798600E+02, -.59201700E+02, -.28074900E+02, -.97249600E+01, -.13673500E+02, -.38949600E+02, 0.14282600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.90170900E+00, -.83478900E-01, 0.49046100E+00, -.41600800E+00, -.57903800E+00, -.72751400E+00, -.23697700E+00, 0.19456800E+01, 0.45532700E+00, -.17958600E+00, -.16142400E+00, 0.49550400E+00, 0.42507800E+00, -.16810300E+00, -.51960800E+00, -.22834900E+01, 0.36985900E+00, 0.64595300E+00, -.20222800E+00, -.67173300E+00, 0.31017500E+00, 0.78746500E+00, -.41434300E+00, -.19474100E-01, 0.55473100E+00, 0.29155700E+00, -.76368600E+00, 0.64922900E-01, -.37358700E+00, 0.22682200E+00, 0.27638800E-03, -.26376400E+00, -.25053400E+00, -.34204700E+00, 0.18558400E+00, 0.95307800E+00, 0.28865200E+00, 0.51033000E-01, -.16659800E+00, -.69987700E-01, -.38799600E+00, 0.67180300E+00, -.23564600E-01, -.13795100E+00, -.32616400E+00, 0.31114800E+00, 0.19738300E+01, -.55488600E+02, -.26738600E+02, -.52648900E+02, 0.29712300E+02, 0.53652700E+02, 0.55896500E+02, -.61897000E+01, -.50583700E+03, 0.24913600E+03, 0.26197700E+03, -.91802400E+02, -.20114000E+03, 0.24318400E+03, -.14072500E+03, 0.11237400E+02, -.68921400E+02, 0.49949600E+03, -.18066500E+03, -.34156600E+03, 0.10906700E+03, 0.33144100E+03, -.36595200E+03, -.96386500E+02, -.31508900E+03, 0.24838800E+03, -.72597400E+04, 0.35819000E+04, 0.36775700E+04, 0.18883700E+03, -.30348100E+03, 0.27940500E+04, 0.16916000E+04, 0.31814000E+04, -.21419900E+03, -.61148400E+03, 0.34467600E+03, 0.61705900E+03, -.40488400E+03, -.47282500E+03, 0.29613100E+03, 0.38752000E+03, 0.85533600E+03, -.15373900E+03, 0.30269200E+04, -.15104200E+04, -.15518200E+04, 0.42537600E+02, 0.83800900E+03, -.15396600E+04, -.14138400E+04, -.17542100E+04, 0.37827000E+03, -.19354200E+04, 0.94806700E+03, 0.10836800E+04, -.23006300E+03, -.51643000E+03, 0.91746600E+03, 0.54003900E+03, 0.10588100E+04, -.98182300E+02, -.79886400E+04, 0.40171400E+04, 0.41183000E+04, 0.10636400E+04, 0.11184400E+04, 0.20529500E+04, 0.44935400E+03, 0.36434000E+04, 0.79580900E+03, -.10495300E+04, 0.55501900E+03, 0.55563100E+03, -.31282900E+02, -.11476900E+02, 0.31833600E+03, -.63941100E+03, 0.55129000E+03, 0.26204600E+03, -.17618900E+04, 0.89623700E+03, 0.58761800E+03, 0.30491600E+03, 0.58314300E+03, 0.43501300E+03, 0.13075800E+03, 0.41160800E+03, 0.54486400E+03, -.92739000E+03, 0.41223500E+03, 0.57156400E+03, -.30721800E+03, -.44214900E+03, 0.48137600E+03, 0.31612900E+03, 0.49497100E+03, 0.17077000E+02, -.55859700E+03, 0.32733800E+03, 0.18695200E+03, -.68105800E+02, 0.21617300E+03, 0.10122200E+03, -.13652600E+02, -.20015600E+03, 0.30835500E+03, -.44918200E+03, 0.23376800E+03, 0.32611100E+03, 0.37494800E+03, 0.55747500E+03, -.28275000E+03, -.49941700E+03, -.32713100E+03, -.10301100E+02, 0.11183000E+03, -.72580700E+02, 0.10155300E+02, 0.12234300E+03, 0.20745100E+03, -.18988200E+03, -.12993100E+03, -.28147200E+03, 0.11770700E+03, -.15979400E+04, 0.83267600E+03, 0.77751400E+03, 0.33688700E+03, 0.88172600E+02, 0.56708700E+03, 0.57003200E+03, 0.94028300E+03, 0.12414300E+03, -.39206800E+03, 0.15643700E+03, 0.17446700E+03, -.13487700E+03, -.35112700E+03, 0.20286400E+03, 0.73173100E+01, 0.36537400E+03, -.22447500E+03, 0.30199200E+02, 0.15044500E+03, 0.15836300E+03, -.30985300E+01, 0.26598200E+02, 0.39663600E+02, -.25798800E+01, -.12949100E+03, -.31963300E+02, 0.82164700E+03, -.84469100E+02, 0.99325800E+03, 0.19959300E+03, -.76547900E+02, 0.27421800E+03, -.17784900E+03, 0.10224800E+03, 0.15205900E+03, 0.12071600E+03, 0.25185400E+02, -.31985700E+03, -.56091300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15361900E+01, 0.65074900E+00, 0.15169400E+01, 0.54317800E+01, -.59378700E+00, 0.82457200E-01, 0.36758200E+00, 0.14258800E+01, -.27112500E+01, 0.72094700E+00, -.85875300E+00, 0.58530300E+00, 0.43546400E+00, 0.98711800E+00, -.43561400E+00, 0.18002400E+01, 0.20686200E+01, 0.17199700E+01, 0.58097700E+00, -.12318200E+01, 0.24088500E+00, 0.14441200E+01, 0.34651900E+01, -.39187400E+00, 0.12113200E+01, 0.12572400E+01, 0.45300200E+01, 0.10640000E+00, -.10740600E+00, 0.39335500E+00, 0.37371200E+00, -.23157800E+00, 0.32694700E+00, 0.71794100E+00, 0.88737300E-02, -.19941500E+01, -.95870700E+00, -.70722800E-01, 0.97497200E+00, -.20623400E+00, -.26177400E+00, -.96074300E+00, 0.17891400E+00, 0.14621200E+01, -.31265600E+00, -.61307400E+00, 0.10047300E+01, -.50257900E+00, 0.11581700E+03, 0.10166200E+03, -.12059100E+03, -.95536900E+02, 0.68765200E+02, 0.10560900E+03, -.17625500E+04, 0.88672500E+03, 0.80670400E+03, -.13141400E+03, 0.42442000E+03, 0.71410300E+03, 0.60521300E+02, 0.35667200E+03, 0.23021400E+03, -.54391400E+03, 0.22418800E+03, 0.16223200E+03, 0.52032300E+01, -.46777700E+03, 0.63071000E+03, 0.99643000E+03, 0.13291200E+03, -.33062600E+03, 0.30519800E+04, -.15107200E+04, -.16729300E+04, -.61197200E+02, -.57550700E+02, -.10685500E+04, -.47749900E+03, -.15081800E+04, -.47857900E+03, -.49017100E+04, 0.23466700E+04, 0.24370900E+04, -.70889100E+03, -.76721600E+03, 0.23000600E+04, 0.67817900E+03, 0.26898900E+04, -.24658400E+03, -.26317300E+04, 0.13248100E+04, 0.13194100E+04, 0.63208100E+03, 0.43207500E+03, 0.82851500E+03, 0.61725600E+03, 0.88542400E+03, 0.65482800E+03, -.72760200E+03, 0.36562800E+03, 0.63271100E+03, 0.48113900E+03, 0.76180500E+03, -.53830700E+03, -.90376100E+03, 0.38015500E+03, 0.69226800E+03, 0.13502400E+04, -.66289900E+03, -.12895800E+04, -.63678100E+03, 0.11948600E+03, 0.31119900E+03, 0.24262900E+04, 0.19014200E+04, -.16485200E+03, -.11474300E+04, 0.55933300E+03, 0.48618500E+03, 0.10726500E+04, 0.17291000E+04, -.66237800E+03, -.11463400E+04, -.11974500E+04, 0.15317100E+04, -.65150500E+03, 0.30412400E+03, 0.26948900E+03, 0.10346800E+04, 0.96280200E+03, -.96857500E+03, -.80218000E+03, -.79376100E+03, 0.10292500E+04, 0.28640500E+03, -.11462400E+03, -.79719700E+02, 0.41934900E+03, 0.21835700E+03, -.32929600E+03, -.33464600E+03, -.33436800E+03, 0.24990100E+03, -.76637500E+04, 0.36560600E+04, 0.36848500E+04, 0.10825300E+04, 0.15287600E+04, 0.17046000E+04, -.45430700E+03, 0.25133100E+04, 0.17259600E+04, -.49183500E+03, 0.24113500E+03, 0.55918500E+02, -.75354000E+03, -.69159100E+03, 0.89167200E+03, 0.14123200E+04, 0.17098500E+03, -.48845900E+03, -.14701400E+02, 0.17000300E+02, -.40006800E+02, -.46611500E+03, -.47665800E+03, 0.54303400E+03, 0.35766100E+03, -.38116300E+03, -.48090800E+03, -.13013000E+04, 0.64240900E+03, 0.60520400E+03, -.24984100E+03, 0.26792400E+03, 0.55631400E+03, 0.80220000E+03, 0.22702800E+04, 0.17880300E+03, 0.10395700E+04, -.49127400E+03, -.50453000E+03, -.71525000E+03, -.63756400E+03, -.17018200E+03, -.11470300E+03, -.84374600E+02, -.50776000E+03, -.17711100E+02, -.14602300E+03, -.77464200E+02, -.20676000E+03, 0.29301700E+03, -.13969800E+03, 0.20870500E+02, 0.87833800E+02, 0.26858100E+03, -.34285000E+03, 0.16133100E+03, -.56042000E+03, -.31332000E+03, 0.48976800E+03, 0.10534200E+03, -.81455000E+01, 0.10856500E+02, -.67802300E+03, -.15138000E+03, -.57193400E+02, -.76892700E+03, 0.17784800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.72814700E+00, -.43597000E+00, 0.47138800E+00, -.31218000E+01, 0.68938000E+00, 0.59301300E+00, 0.11440500E+00, -.52199100E+00, -.72204800E+00, 0.34658000E+00, 0.13163500E+01, -.17472400E-01, -.16749800E+00, 0.96955900E+00, 0.53585900E+00, 0.85200700E+00, 0.44075900E+00, 0.22527800E+00, 0.65449100E-01, 0.13900700E+00, -.41461100E-01, -.12438000E+01, -.41860600E-02, -.46512400E+00, -.71087100E+00, -.65111500E+00, 0.98615200E+00, -.49854200E+00, 0.18675000E+00, -.91497700E+00, 0.13457800E+00, 0.23438000E+00, 0.12513300E+00, 0.11635900E+01, -.72926000E+00, -.11146400E+01, -.21363600E+00, 0.72409200E-01, 0.81616600E+00, 0.64931600E-01, -.54936100E+00, 0.11316500E+00, 0.26413900E-02, -.81312400E+00, 0.10969800E+01, -.20869200E+00, 0.74358000E+00, 0.64023400E+00, 0.19632900E+00, -.88575600E+02, 0.79827400E+02, 0.60891200E+02, 0.41145700E+02, -.28313200E+02, 0.74417000E+03, -.37570700E+03, -.30211000E+03, -.21268100E+03, -.11499200E+03, -.59453300E+03, -.66127200E+03, -.54051700E+03, -.72120400E+02, -.73534600E+03, 0.43777800E+03, 0.43250800E+03, 0.37176600E+03, 0.30798500E+03, 0.79622900E+02, -.17453200E+03, 0.29358500E+03, -.28546000E+02, -.72352300E+04, 0.35653800E+04, 0.38030400E+04, 0.48573000E+03, 0.42476000E+03, 0.19881800E+04, 0.57411100E+03, 0.26389000E+04, 0.73219800E+03, -.11978000E+04, 0.68204400E+03, 0.69795000E+03, -.24896100E+03, -.75002400E+02, 0.48900200E+03, 0.71904800E+03, 0.59072900E+03, 0.15654400E+01, 0.81738700E+04, -.40733800E+04, -.41650900E+04, -.10698700E+04, -.61857400E+03, -.24130700E+04, -.80353900E+03, -.29587300E+04, -.14622500E+04, 0.18067500E+04, -.92019900E+03, -.90612700E+03, -.10153100E+04, -.10082200E+04, 0.81279700E+02, 0.48177900E+03, -.28247300E+03, -.44613300E+03, -.44879700E+04, 0.22809000E+04, 0.26816100E+04, 0.19070600E+04, 0.18097800E+04, -.10579400E+04, -.36971000E+04, -.16929800E+04, 0.13559700E+04, -.36588700E+03, 0.21557800E+03, 0.13118600E+03, -.44418800E+03, -.36346800E+03, 0.15773000E+03, -.64202900E+03, 0.29397500E+03, -.58174200E+02, -.76467200E+03, 0.40254600E+03, 0.27718700E+03, 0.25336200E+02, -.50514600E+02, 0.86821900E+03, 0.82494900E+03, 0.55060700E+03, -.78270400E+02, 0.43560800E+02, -.58651800E+02, 0.60511400E+02, -.32538100E+03, -.58359400E+03, 0.32806800E+03, 0.39765700E+03, 0.14669800E+03, -.96297300E+02, 0.41398900E+04, -.19400700E+04, -.21156500E+04, -.36132700E+03, -.62152100E+03, -.62541700E+03, 0.32659400E+03, -.15568600E+04, -.96266100E+03, 0.13073100E+04, -.64017900E+03, -.52719600E+03, 0.33117300E+03, 0.15457500E+03, -.71911200E+03, -.92986800E+03, -.74366800E+03, -.22783900E+03, 0.14000200E+03, -.88545900E+02, -.35094400E+02, 0.61966400E+02, 0.42090300E+03, -.51371800E+03, -.49633900E+03, -.25278200E+03, 0.22249900E+03, -.15995700E+04, 0.84397100E+03, 0.75325800E+03, 0.95851200E+03, 0.73245000E+03, -.30766500E+03, -.13927000E+04, -.13307800E+04, 0.65883500E+03, -.23639300E+04, 0.11505400E+04, 0.12759300E+04, 0.11286200E+03, 0.49715500E+02, 0.78962400E+03, 0.54355100E+03, 0.86016300E+03, 0.38522800E+03, -.17156300E+02, 0.11258700E+03, 0.15010300E+03, -.23835000E+01, 0.84030300E+02, 0.45802900E+02, 0.31590500E+01, 0.30885500E+02, -.22148600E+03, -.49786500E+03, 0.10071700E+03, 0.25602000E+03, 0.62657400E+03, -.12617600E+04, 0.25550500E+03, -.13464000E+03, 0.25799700E+03, -.44179000E+03, 0.22918300E+03, 0.68966400E+00, 0.14940800E+04, -.58790000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20125700E+01, 0.13743700E+01, 0.10324000E+01, 0.21951100E+02, -.21699500E+01, -.82958900E+00, 0.13638600E+01, 0.71314100E+00, -.45206100E+01, 0.98410400E+00, -.19042900E+01, 0.68413200E+00, 0.14733400E+01, 0.53286300E+00, -.61757200E+00, 0.17671700E+01, 0.21152000E+01, 0.15766500E+01, 0.82095200E+00, -.53712100E+00, 0.23481700E-01, 0.11561100E+01, 0.62523800E+01, -.78893700E+00, -.16628100E-01, -.10558200E+00, 0.63183500E+01, -.13223000E+01, -.27609300E+01, 0.26397200E+00, -.36075300E-01, 0.34298300E+00, 0.77445000E+00, -.20570100E+01, -.52405700E+00, -.48077600E+00, 0.99924400E+00, 0.26211000E+00, -.10735000E+01, 0.71266200E-01, 0.51469500E+00, -.10286000E+01, 0.64130800E+00, -.23756500E+01, 0.12387300E+01, -.98047800E+00, -.95267400E+01, -.48417700E+00, -.18737200E+01, -.10681400E+01, 0.10123200E+03, 0.93991100E+01, 0.73699700E+02, -.14854700E+02, -.31478300E+03, 0.15382000E+03, 0.50035500E+03, -.99980900E+02, -.74806100E+02, -.89671400E+03, -.18317200E+04, -.65781200E+03, -.27483300E+03, 0.20252400E+04, -.92103900E+03, -.79239800E+03, 0.13929400E+03, 0.98893500E+03, -.14813300E+04, -.28589500E+04, -.21525200E+04, -.26988400E+03, -.41055400E+04, 0.20218400E+04, 0.22860200E+04, 0.28371200E+04, 0.83945900E+03, -.14422900E+04, -.56125900E+04, 0.91341300E+03, 0.79725800E+03, -.62728200E+04, 0.31889500E+04, 0.33434100E+04, -.22498200E+04, -.46481200E+03, 0.33296400E+04, 0.35131800E+04, 0.33497300E+04, -.70412100E+03, 0.17682600E+05, -.88184300E+04, -.88600500E+04, -.40056300E+04, -.34685500E+04, -.34178400E+04, 0.34187800E+04, -.52045900E+04, -.33775200E+04, -.10311300E+04, 0.50289400E+03, 0.44120600E+03, -.26557800E+04, -.23456800E+04, 0.32669400E+04, 0.58257900E+04, 0.32961600E+04, -.88110300E+03, 0.14447500E+05, -.71581400E+04, -.62719300E+04, 0.11687200E+04, -.98910900E+02, -.92565900E+04, -.94349500E+04, -.85430300E+04, -.13406600E+04, -.27486100E+03, 0.17685700E+03, 0.24417400E+03, -.76627300E+03, 0.30622700E+02, -.43639200E+03, -.20028300E+04, -.19364500E+04, -.35425200E+03, -.70527100E+03, 0.37082500E+03, 0.30494000E+03, 0.10034800E+04, 0.22315000E+03, 0.77370800E+03, 0.12223100E+03, -.75676700E+03, 0.89730600E+02, 0.57006600E+02, -.85437200E+02, -.53728700E+02, -.14423900E+04, -.60868000E+03, 0.13017500E+04, 0.27658200E+04, 0.14655200E+04, -.33419600E+03, 0.27937900E+04, -.13032500E+04, -.12922600E+04, -.28433800E+04, -.18569400E+04, 0.23499200E+04, 0.48340200E+04, 0.10774700E+04, -.22950800E+04, 0.40852800E+04, -.20259500E+04, -.16622900E+04, -.21059300E+03, 0.75463300E+02, -.12179700E+04, -.10876600E+04, -.11916200E+04, 0.34830000E+03, -.32982400E+03, 0.14682400E+03, 0.38750700E+03, 0.31876800E+03, 0.35963400E+03, -.78917500E+03, -.11257400E+04, -.51921900E+03, 0.12752200E+03, 0.55213200E+04, -.27075900E+04, -.26187200E+04, 0.91246300E+03, -.38666400E+02, -.33228400E+04, -.41771100E+04, -.42127000E+04, -.98670800E+03, 0.17903400E+04, -.96058200E+03, -.88624100E+03, 0.16880800E+04, 0.70830400E+03, -.20805500E+04, -.34230000E+04, -.15859400E+04, 0.25031500E+03, -.16504300E+03, -.11126000E+03, 0.30577600E+03, 0.38314100E+02, 0.10188200E+03, -.40530800E+02, 0.91531300E+02, 0.47520900E+03, -.25408400E+03, -.57502100E+04, 0.80307200E+02, -.32655900E+04, 0.27937800E+04, -.34123500E+04, 0.42377500E+03, 0.75107300E+02, 0.12271000E+04, -.21017300E+04, 0.45586000E+03, -.96285700E+01, 0.45180600E+04, 0.21850800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.52468600E+00, 0.49620000E+00, -.27411500E-01, 0.21160300E+01, -.24344100E+00, -.34351400E-01, 0.15079200E+00, 0.59021200E+00, -.43618400E+00, 0.27791200E+00, 0.11556800E+00, 0.19726600E-01, -.65291600E-01, 0.43794700E+00, 0.19757500E+00, 0.13685200E+01, 0.62540700E+00, 0.56884300E+00, 0.22631200E+00, -.18597500E+00, 0.29251500E-01, 0.17057400E+00, 0.24984800E+01, -.13779600E+00, 0.22185400E-01, 0.41691100E-02, 0.29572700E+00, -.77428100E-01, 0.14010700E+01, -.25189100E+00, -.40008300E-01, 0.17025800E+00, 0.11131000E+00, 0.33023400E+00, 0.18708000E-01, -.56292100E+00, -.38689100E+00, -.55856400E-01, 0.13746700E+00, -.35034000E-01, -.25187000E+00, -.36430500E-01, 0.18357800E-02, -.13703200E-01, 0.50190200E+00, 0.42217400E-01, -.14794800E+01, -.22173400E+00, -.26066100E+00, -.27293500E-01, 0.87442900E-02, 0.19967400E+02, 0.69395500E+02, -.50343600E+01, -.70671500E+03, 0.35427700E+03, 0.31997700E+03, -.65527300E+02, 0.88703000E+02, 0.21818800E+03, -.15291200E+03, 0.18864300E+03, 0.45963100E+02, 0.31120700E+03, -.16256700E+03, -.18726000E+03, 0.21989100E+03, 0.11802200E+02, -.17424500E+03, -.33589200E+02, -.41438900E+03, 0.11137900E+03, -.73522400E+03, 0.35938400E+03, 0.34354400E+03, 0.30160700E+03, 0.95035300E+02, 0.30717000E+02, -.26838100E+03, 0.80915700E+02, 0.20341000E+03, -.24756800E+04, 0.11908600E+04, 0.12458300E+04, -.23535300E+03, -.24854100E+03, 0.98716900E+03, 0.33857400E+03, 0.11091800E+04, -.48524700E+02, 0.11752900E+04, -.57782400E+03, -.60350500E+03, 0.38042400E+02, -.28344000E+02, -.35835800E+03, 0.26984000E+02, -.53338800E+03, -.17699200E+03, -.10786500E+04, 0.52822300E+03, 0.65665400E+03, -.17490500E+03, 0.49388100E+01, 0.39893200E+03, 0.23952100E+03, 0.75651000E+03, -.58720300E+02, -.23957900E+04, 0.12160500E+04, 0.10263900E+04, 0.57449600E+03, 0.74874800E+03, 0.29505300E+03, -.23298600E+03, 0.57521900E+03, 0.61298000E+03, -.87174300E+03, 0.44011800E+03, 0.38042600E+03, 0.43052500E+03, 0.69922600E+03, -.14310600E+03, -.63916300E+03, -.36899200E+03, 0.57576100E+03, -.91662800E+02, 0.43609000E+02, -.38691300E+01, 0.38848100E+03, 0.35095800E+03, -.23399100E+03, -.14481900E+03, -.30162000E+03, 0.39882400E+03, -.14588800E+03, 0.86296900E+02, 0.12400500E+03, -.12332500E+03, -.62928800E+02, 0.14611400E+03, 0.21043300E+03, 0.15157500E+03, -.79321200E+02, -.14436800E+04, 0.64703800E+03, 0.64529400E+03, 0.32026100E+03, 0.46519900E+03, 0.30920600E+03, -.15714700E+03, 0.51639600E+03, 0.48144200E+03, -.76049200E+01, 0.64905800E+01, -.49679300E+02, -.20141600E+03, -.25746600E+03, 0.29867800E+03, 0.51524800E+03, 0.10525700E+03, -.25428300E+03, -.71805200E+02, 0.33819800E+02, 0.16114100E+02, 0.22621900E+02, -.30394900E+02, 0.17025500E+02, -.11297500E+03, -.29514100E+03, -.63236200E+01, -.13131300E+04, 0.66287500E+03, 0.63100600E+03, 0.20678500E+03, 0.23623300E+03, 0.27675400E+03, -.15146900E+03, 0.65155700E+03, 0.26892500E+03, -.32670400E+03, 0.18734700E+03, 0.19926700E+03, -.23146800E+03, -.34104000E+03, 0.18490000E+03, 0.60774400E+02, 0.25843200E+03, -.18988200E+03, -.17989400E+02, 0.85625800E+01, 0.16264400E+02, -.42452500E+02, 0.62289700E+02, 0.81290700E+01, 0.22996800E+02, -.86876700E+01, 0.16936600E+03, -.18677500E+03, 0.24282500E+02, -.52898600E+02, 0.30088400E+03, -.52855200E+02, 0.13863400E+03, -.54093000E+02, 0.69783000E+02, -.15220400E+03, -.10681600E+02, -.95134500E+01, -.55851900E+02, 0.41801000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.99618900E+00, 0.54214300E+00, -.64671800E+00, 0.33303400E+01, -.89841200E+00, -.34091100E+00, -.16700800E+00, -.21756500E+00, 0.52617700E+00, -.18538800E+00, -.16626500E+00, -.40956000E+00, 0.55040400E+00, -.23223800E-01, 0.10203700E-01, -.29513800E+00, 0.11467300E+01, 0.31815900E+00, -.77541900E-01, 0.30781700E+00, -.11434500E+00, 0.76683600E+00, 0.43589500E+01, -.15044100E+00, 0.80323500E+00, -.48196500E+00, -.35079900E+01, 0.17632700E+00, 0.20449500E+01, -.96246000E+00, 0.56877500E+00, -.82380600E+00, -.24300000E+00, 0.23576900E+00, 0.35120700E+00, -.54844000E+00, -.38965800E-01, -.13923200E-01, 0.33500600E+00, 0.10927700E-02, -.14159900E+00, 0.71352700E+00, -.15931000E+00, 0.33892200E+00, 0.74309100E+00, -.78232600E-01, -.18024900E+01, -.17613500E+00, -.57416700E+00, -.53214500E+00, 0.12342300E-02, 0.17556900E+01, 0.99143800E+02, 0.36766300E+02, 0.36334800E+03, -.18310700E+03, -.24204400E+03, -.29860200E+02, 0.11731600E+03, -.17294100E+03, -.25719700E+03, -.61092300E+03, -.32156500E+02, -.25908700E+03, 0.16720500E+03, 0.16393900E+03, 0.11334600E+03, -.63697800E+02, 0.13472900E+03, 0.24419100E+03, 0.13946300E+03, -.27351600E+03, -.34936000E+04, 0.17417900E+04, 0.18324200E+04, -.21032400E+03, -.24702500E+03, 0.17183600E+04, 0.21477100E+04, 0.16257300E+04, -.32787100E+03, -.13443500E+04, 0.74291800E+03, 0.72345400E+03, 0.13135400E+03, -.33961300E+03, 0.46653500E+03, -.10122500E+03, 0.93446600E+03, -.10831000E+03, 0.24008900E+04, -.12110000E+04, -.12516000E+04, 0.40134400E+03, 0.10185700E+04, -.14477700E+04, -.17732900E+04, -.15651700E+04, 0.56014800E+03, 0.79010500E+02, -.31558500E+02, 0.13261000E+03, 0.73199300E+02, 0.19694000E+03, -.25750200E+03, -.44360500E+03, 0.36113700E+02, 0.43545100E+03, -.27796500E+04, 0.13772300E+04, 0.13996100E+04, 0.14852700E+04, 0.12590900E+04, 0.96534500E+01, 0.29721100E+03, 0.35167600E+03, 0.10432400E+04, -.73975300E+03, 0.37386000E+03, 0.22008600E+03, 0.31735800E+03, 0.40192400E+03, -.20881300E+02, -.83759100E+03, -.37269200E+03, 0.55436700E+03, -.21197900E+04, 0.10688200E+04, 0.90831700E+03, 0.23025000E+03, 0.46890200E+03, 0.52328800E+03, 0.26486900E+03, 0.41735600E+03, 0.65113100E+03, 0.33481100E+03, -.19604800E+03, -.92335900E+01, 0.19439800E+03, -.57735400E+02, -.21456600E+03, -.28634000E+03, -.38013500E+03, 0.12271300E+03, -.18468700E+04, 0.10242500E+04, 0.74393700E+03, 0.66561400E+03, 0.79402900E+03, 0.82144500E+02, -.99980800E+03, -.31086600E+03, 0.68235500E+03, 0.47420600E+03, -.23650800E+03, -.21211600E+03, 0.19243500E+03, -.56657600E+02, -.42188800E+03, -.34950900E+03, -.75712100E+03, -.84061200E+02, 0.23651200E+03, -.12133700E+03, -.14101000E+03, -.25255900E+02, 0.17394800E+02, -.88227500E+02, -.84281900E+02, -.52606400E+03, -.16036200E+03, -.16816400E+04, 0.84797300E+03, 0.74261900E+03, 0.69526900E+03, 0.81801500E+03, 0.13655000E+03, 0.25007400E+03, 0.32111000E+03, 0.66970400E+03, -.53908800E+03, 0.21939700E+03, 0.40446900E+03, -.42708900E+03, -.46023300E+03, 0.52105700E+03, 0.70831700E+03, 0.56272500E+03, -.26179700E+03, 0.16928900E+02, 0.27172500E+02, -.63558600E+02, -.72478000E+02, 0.14985000E+03, 0.28196900E+01, -.10897700E+02, -.70710000E+02, 0.64315500E+02, 0.11226700E+04, 0.79277900E+02, 0.92267800E+03, 0.77121300E+02, -.24102500E+03, 0.42093600E+02, -.64602000E+02, -.44332000E+01, -.38864300E+02, 0.56908800E+02, 0.35442800E+02, 0.21917200E+03, -.78619100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.57745200E+00, 0.17008700E+00, 0.21486100E+00, 0.73022000E+00, -.16180700E+01, -.22379400E+00, -.77226800E-01, -.69403400E-01, 0.47454600E+00, -.11042700E+00, 0.85729300E+00, -.39173700E+00, 0.33874100E+00, -.31320400E+00, 0.54570300E-01, -.60449100E+00, 0.69730100E+00, -.26353700E+00, 0.87464100E-01, 0.26671500E-01, -.66612600E-01, -.12956100E+00, 0.20758300E+01, -.21368700E+00, -.37589500E-01, 0.11383400E+00, 0.14685300E+01, -.69987300E+00, -.15244700E+01, -.49014800E+00, -.21819500E+00, 0.46462200E-01, -.98716700E-01, -.12494900E+00, -.34162000E+00, -.65182800E+00, -.33629800E+00, 0.40651100E-01, 0.27464100E-01, 0.23943500E-01, -.25089800E-01, -.27390700E+00, -.63648500E-01, 0.25780300E-01, 0.82937400E+00, -.65261500E-01, 0.11429600E+01, -.60692800E+00, 0.62650000E-03, 0.30090700E+00, -.12871300E+00, 0.52793600E+00, 0.55577800E+00, 0.42834800E+02, -.27999000E+03, 0.14000100E+03, 0.24149500E+03, 0.81274000E+02, 0.25801300E+02, -.17746400E+03, -.69893900E+03, -.88285000E+02, 0.18219100E+03, 0.10289000E+04, -.47481600E+03, -.50342900E+03, 0.14874000E+03, 0.44407200E+03, -.68762800E+03, -.93742500E+03, -.98219400E+03, 0.23896500E+03, 0.30531900E+04, -.15637100E+04, -.15487200E+04, 0.97360000E+03, 0.65186600E+03, -.15868200E+04, -.22691800E+04, -.90254700E+03, -.12221000E+03, -.90326900E+03, 0.46197500E+03, 0.49766800E+03, -.79562200E+03, -.39795100E+03, 0.53804400E+03, 0.67318400E+03, 0.38086900E+03, -.98018700E+02, -.71710000E+03, 0.37372600E+03, 0.36875500E+03, -.13306900E+04, -.12439600E+04, 0.10186200E+04, 0.24136400E+04, 0.72041600E+03, -.84021800E+03, -.28600800E+04, 0.14156700E+04, 0.14652200E+04, -.83018600E+03, -.11505700E+04, 0.17566000E+04, 0.22732000E+04, 0.21676200E+04, -.38874000E+03, 0.59409500E+04, -.29258500E+04, -.29401000E+04, -.11077300E+03, -.27038800E+03, -.21085300E+04, -.84908700E+03, -.10741100E+04, -.12177600E+04, 0.45772900E+03, -.20872900E+03, -.17908900E+03, -.33845400E+02, 0.26061300E+03, -.51361700E+03, -.42752400E+03, -.30100900E+03, 0.41129000E+03, -.73117800E+02, 0.38378400E+02, 0.47723400E+02, 0.36080100E+03, 0.24748800E+03, 0.89945900E+02, 0.18797700E+03, 0.20359200E+03, 0.10805600E+03, -.75286900E+03, 0.34527000E+03, 0.34107300E+03, -.69990900E+03, -.57837800E+03, 0.62514100E+03, 0.10383600E+04, 0.92694400E+03, -.14678300E+02, -.12139100E+04, 0.60219300E+03, 0.63934000E+03, -.63328900E+03, -.14844900E+03, 0.81159300E+03, 0.10347900E+04, 0.79074800E+03, -.42188600E+02, -.47863800E+02, 0.31253400E+02, 0.49716500E+02, -.12801400E+03, 0.24456700E+02, 0.32841700E+03, 0.42772400E+03, 0.27621800E+03, -.60958800E+03, 0.11825400E+03, -.68126600E+02, 0.25152900E+01, 0.12480700E+03, 0.25968400E+01, -.16066100E+03, -.37700900E+03, -.15907500E+03, 0.31941200E+01, 0.19828300E+04, -.95155200E+03, -.91579900E+03, 0.21498400E+03, -.83549100E+02, -.85157700E+03, -.89221000E+03, -.67434800E+03, -.21224600E+03, 0.10761500E+04, -.57000100E+03, -.57408300E+03, 0.36496400E+03, 0.89660700E+02, -.69106100E+03, -.10547500E+04, -.44123500E+03, 0.71546200E+02, -.67853900E+02, 0.22837200E+02, 0.16036000E+03, 0.57806600E+02, 0.93553200E+02, -.31802100E+02, 0.27511200E+02, 0.12154600E+03, 0.30987300E+02, -.18429200E+04, -.13079000E+01, -.12974700E+04, 0.10211700E+04, -.38986500E+03, 0.23657200E+03, -.14827900E+03, 0.51659100E+03, -.19737500E+03, -.29440000E+02, 0.23307500E+02, 0.62802300E+03, 0.90615000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.91652200E+00, -.76834100E+00, -.64938300E+00, -.69177200E+01, 0.12188600E+01, -.23182100E-01, -.81486300E+00, -.36607700E+00, 0.12793400E+01, -.45477200E+00, 0.45231800E+00, -.17890900E-01, -.83476000E+00, -.22722800E+00, 0.52297800E-01, -.30608500E+00, -.65111500E+00, -.37930300E-01, -.16278600E+00, 0.21323600E+00, -.98148800E-01, -.17480700E+00, 0.58463500E+00, 0.18235500E+00, 0.11955600E-01, -.34801900E+00, -.17963600E+01, 0.26286300E+00, 0.41707900E+00, -.50532300E+00, 0.17400300E+00, -.27125300E+00, -.55154600E-01, 0.79590500E+00, 0.20554400E+00, -.12324400E+01, -.77139900E+00, -.42762900E-01, 0.44667200E+00, -.14362200E+00, -.68517800E+00, 0.19764500E+00, -.17076100E-01, 0.35166100E+00, 0.72802900E+00, -.40329600E+00, -.47485100E+01, -.77772300E-01, -.48268700E+00, -.61483400E+00, 0.67992500E-01, 0.27517800E+00, 0.96855800E+00, -.63068500E+00, -.10427800E+04, 0.52074700E+03, 0.50097800E+03, -.45536400E+02, 0.10899800E+03, 0.18025700E+03, -.27057800E+03, 0.56467400E+03, 0.21250900E+03, 0.14889000E+04, -.75714600E+03, -.67128800E+03, 0.57354300E+03, 0.21180500E+03, -.83303300E+03, -.93236600E+03, -.12006800E+04, 0.21941700E+03, 0.17561700E+04, -.88419300E+03, -.10016300E+04, 0.11621300E+04, 0.26877100E+03, -.15904200E+04, -.26744900E+04, -.14109400E+04, 0.21947300E+03, -.19669900E+04, 0.92203400E+03, 0.92910100E+03, -.50525900E+03, -.57749500E+02, 0.85327500E+03, 0.54998200E+03, 0.58863800E+03, 0.10736900E+03, 0.31916900E+03, -.14860200E+03, -.55763900E+02, -.13076600E+04, -.11568600E+04, 0.88705000E+03, 0.21721500E+04, 0.87735800E+03, -.92424600E+03, -.11893900E+04, 0.57946300E+03, 0.60959500E+03, -.12954400E+04, -.60703000E+03, 0.92183800E+03, 0.10770900E+04, 0.13200000E+04, -.36440100E+03, 0.27407900E+03, -.11730900E+03, -.27722700E+03, 0.12273200E+03, -.14074800E+03, -.14119100E+03, -.12138000E+04, -.35578500E+03, -.49846800E+03, -.46032100E+03, 0.23513200E+03, 0.27220400E+03, 0.29470700E+03, 0.59769800E+03, -.25518100E+03, -.37402500E+03, -.25066200E+03, 0.44320500E+03, 0.16751100E+04, -.83743700E+03, -.77319700E+03, 0.53079300E+03, -.13348000E+03, -.55754000E+03, -.24662100E+03, -.81124100E+03, -.31503000E+03, -.86797100E+03, 0.45254900E+03, 0.39037400E+03, -.10391600E+04, -.26358800E+03, 0.77220600E+03, 0.10321000E+04, 0.12127000E+04, -.72335400E+02, 0.44004100E+03, -.30695500E+03, -.19790800E+03, -.35410400E+03, 0.36027100E+02, 0.13176400E+03, 0.38518700E+03, 0.42592800E+03, 0.33573600E+02, -.36213700E+02, 0.23092200E+02, 0.68443900E+02, -.35345500E+03, -.37401000E+03, 0.74977400E+03, 0.11005600E+04, 0.74963400E+03, -.61981100E+03, -.11202900E+03, 0.54459500E+02, 0.88740800E+02, 0.69439600E+02, -.34202600E+02, -.28906700E+02, -.15187600E+03, 0.15348500E+02, 0.47797200E+02, -.47875200E+02, 0.28301800E+02, 0.12587000E+03, 0.22116000E+03, -.31885500E+03, -.16075600E+02, -.99107500E+03, -.81052500E+02, -.26180700E+03, -.68999300E+03, 0.38319100E+03, 0.31008000E+03, 0.51226600E+03, -.13162200E+03, 0.39847900E+02, -.35171700E+03, 0.20581600E+03, -.72311900E+02, -.52364400E+02, -.10068900E+02, 0.77846800E+02, 0.48390700E+02, 0.42594800E+01, -.23901800E+02, 0.26717300E+02, 0.15320000E+03, 0.25423500E+03, -.16696900E+04, -.32003100E+01, -.12534400E+04, 0.15787700E+04, -.64366900E+02, 0.23143100E+03, -.11185300E+02, 0.54475000E+03, 0.16890500E+03, -.75746300E+02, -.80940600E+01, -.39328300E+02, -.11324300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.82111000E+00, 0.52974000E+00, 0.31298600E+00, 0.59526500E+01, -.86313500E+00, 0.71510000E-01, 0.35577500E+00, 0.37078000E+00, -.36717600E+00, 0.35073200E+00, -.31040800E+00, 0.44162300E-01, 0.98606500E+00, 0.57980200E-01, -.23646600E+00, 0.75925400E+00, 0.69127500E+00, 0.83290400E+00, 0.26936600E-01, -.43999200E+00, 0.14993000E+00, 0.10090100E+01, 0.14700700E+01, -.78652800E-01, 0.45751500E+00, 0.60439000E-01, -.20868900E+01, 0.19216300E+00, 0.91183800E+00, -.18736400E+00, 0.35866500E+00, -.53019700E+00, -.25729200E-01, -.52887900E-01, 0.34566700E+00, -.45118800E+00, 0.14860900E+00, -.10597200E+00, 0.19860900E+00, -.18354800E-01, -.95389500E-01, 0.22972600E+00, 0.78106300E-01, -.79769100E-01, -.19219600E+01, 0.38426400E+00, 0.40768100E+01, 0.50212900E-01, 0.42297200E+00, 0.36977600E+00, -.12990200E+00, 0.14647600E+01, -.48600000E+00, 0.75474600E+00, -.33488800E+00, -.71352800E+01, -.28974200E+03, -.93984000E+02, -.77986700E+02, 0.35570800E+03, 0.79346400E+03, -.92794400E+01, -.20474700E+03, -.11882200E+04, 0.60297800E+03, 0.60908500E+03, -.85880200E+03, -.30894600E+03, 0.93768800E+03, 0.14973800E+04, 0.15442500E+04, -.38094100E+03, -.87832500E+04, 0.44383600E+04, 0.43248000E+04, -.11318000E+04, -.14999900E+04, 0.44056100E+04, 0.60143200E+04, 0.36719000E+04, -.15014000E+04, 0.95426300E+03, -.37622900E+03, -.61559600E+03, 0.69810800E+03, -.25865100E+03, -.41494700E+03, -.39521600E+03, 0.29966200E+03, -.11357500E+02, 0.53001300E+03, -.31228600E+03, -.21989200E+03, 0.17455600E+04, 0.30855100E+04, -.17832500E+04, -.53442300E+04, -.14512400E+04, 0.27888200E+04, 0.46431200E+03, -.19840300E+03, -.16698400E+03, 0.16612700E+04, 0.11857800E+04, -.11830900E+04, -.24395800E+04, -.14759300E+04, 0.11157200E+04, -.10124000E+05, 0.49530300E+04, 0.47090000E+04, 0.55277100E+03, 0.10843700E+03, 0.42322100E+04, 0.36493600E+04, 0.48140700E+04, 0.58401200E+03, -.81621700E+03, 0.37934800E+03, 0.26195800E+03, -.64568700E+02, -.50497900E+03, 0.92921900E+03, 0.59855900E+03, 0.12857000E+04, -.25482300E+03, -.13725100E+04, 0.70133000E+03, 0.65399600E+03, -.28298700E+03, -.12558200E+02, 0.34800900E+03, 0.34387600E+03, 0.33285600E+03, 0.12425400E+03, -.24790400E+03, 0.98381800E+02, 0.23249300E+03, 0.10074700E+04, 0.53802300E+03, -.33903400E+03, -.13166500E+04, -.65929400E+03, 0.45825200E+03, -.18685800E+03, 0.26649300E+03, -.44971900E+02, 0.64647700E+03, 0.83408200E+03, -.54870200E+03, -.10972900E+04, -.77164100E+03, 0.89078200E+03, 0.10939900E+04, -.55796300E+03, -.61908400E+03, 0.47810800E+03, 0.20334100E+03, -.11279200E+04, -.14101900E+04, -.13774600E+04, 0.49336900E+03, 0.26136700E+03, -.11890700E+03, -.26394400E+03, -.29046400E+03, -.24839900E+02, 0.13337800E+03, 0.70781000E+03, 0.12985000E+03, -.21458300E+03, -.19710500E+04, 0.93026200E+03, 0.87715400E+03, -.31114500E+03, -.19041000E+03, 0.13631700E+04, 0.26979900E+04, 0.20087300E+04, -.42836400E+03, -.30395000E+03, 0.95167800E+02, 0.24267500E+03, -.59414900E+03, -.70357700E+03, 0.50733900E+03, 0.96520300E+03, 0.32841100E+03, -.84085100E+03, 0.15967900E+03, -.20891900E+01, -.13331000E+03, -.10061300E+03, -.64516300E+02, -.35729200E+02, -.82648400E+02, -.16832200E+03, -.38296300E+03, 0.41636300E+04, -.42626000E+02, 0.29836200E+04, -.19801000E+04, 0.85746500E+03, -.16948800E+03, 0.97005900E+02, -.69638900E+03, 0.62643500E+03, 0.14339100E+03, 0.27439000E+02, -.17739900E+04, -.26469200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.67333600E+00, -.87871400E+00, -.68117400E-01, -.54752500E+01, 0.12482200E+01, 0.22188300E+00, -.26272700E+00, -.20186000E-01, 0.85375500E+00, -.15733700E+00, 0.29363300E+00, -.73175100E-01, -.14848100E+01, 0.16250100E+00, 0.18090000E+00, 0.12370300E+00, -.47550100E+00, 0.15596200E-02, 0.23570100E-01, 0.47868700E+00, -.10104200E+00, -.14192200E+01, -.16371300E+01, 0.14275500E-01, -.36480800E+00, -.87500600E-02, -.22439100E+01, 0.39297000E+00, 0.44218600E+01, 0.18954800E+00, -.41709800E+00, 0.52698200E+00, 0.23046100E+00, 0.14198600E+01, -.15336300E+00, -.44130400E+00, -.54662400E+00, -.70453300E-01, 0.34783900E+00, 0.52679400E-01, -.57499200E-01, 0.25780600E+00, -.27098800E+00, 0.76278100E-01, -.14765300E+00, 0.58328000E-01, 0.32433400E+01, 0.10030800E+00, 0.30698600E+00, 0.36724900E+00, -.76859900E-01, -.11119900E+01, 0.54344100E+00, 0.54131300E+00, 0.58604400E+00, -.58274400E+00, -.20754500E+03, -.10575200E+03, -.60544700E+02, 0.44865100E+03, 0.87806700E+03, 0.98861500E+02, -.21593300E+03, -.20668200E+04, 0.98033900E+03, 0.87876400E+03, -.10843700E+04, -.41264400E+03, 0.12797000E+04, 0.18606600E+04, 0.17853000E+04, -.35038900E+03, -.83752500E+04, 0.42274000E+04, 0.41282000E+04, -.14267600E+04, -.10645200E+04, 0.42984000E+04, 0.61516400E+04, 0.34179900E+04, -.95565300E+03, 0.55761900E+03, -.30990900E+03, -.37648900E+03, 0.60925900E+03, -.34257800E+03, -.32289600E+03, -.48802400E+03, 0.40814900E+03, 0.61930300E+01, 0.12811600E+04, -.65765200E+03, -.68168300E+03, 0.23638300E+04, 0.32042600E+04, -.22444800E+04, -.56659700E+04, -.19110000E+04, 0.25465100E+04, 0.17719100E+03, -.71594900E+02, -.54250100E+02, 0.23268400E+04, 0.14473900E+04, -.12210400E+04, -.25426300E+04, -.15434500E+04, 0.12415300E+04, -.12647100E+05, 0.62536700E+04, 0.58716800E+04, 0.44872600E+03, 0.92324200E+03, 0.46366100E+04, 0.32599400E+04, 0.50625100E+04, 0.17057800E+04, -.80857700E+03, 0.37212100E+03, 0.30581600E+03, -.12537100E+02, -.24152700E+03, 0.80016800E+03, 0.40719500E+03, 0.12247100E+04, -.30622200E+01, -.12124100E+04, 0.59822700E+03, 0.59079100E+03, -.39166200E+03, 0.96886700E+02, 0.21709500E+03, 0.26037100E+03, 0.36590600E+03, 0.27168100E+03, 0.47789200E+02, 0.49541500E+01, 0.28238500E+02, 0.13825600E+04, 0.56682900E+03, -.56483000E+03, -.15554400E+04, -.10532800E+04, 0.43816900E+03, -.96558200E+03, 0.44599300E+03, 0.40177900E+03, 0.59475800E+03, 0.60711600E+03, -.22066800E+03, -.71519900E+03, 0.47600100E+02, 0.65307800E+03, 0.87790500E+03, -.45018100E+03, -.66913400E+03, 0.40009800E+03, 0.72085500E+02, -.10030700E+04, -.12695800E+04, -.12363900E+04, 0.48680600E+03, 0.22931600E+03, -.10010700E+03, -.26827800E+03, -.27503500E+03, -.39366300E+02, 0.16085000E+03, 0.72811000E+03, 0.72785800E+02, -.21094400E+03, -.38494800E+04, 0.18694100E+04, 0.17800600E+04, -.52397700E+03, 0.10978400E+03, 0.18608700E+04, 0.26086700E+04, 0.26071800E+04, 0.11117500E+03, 0.43256000E+03, -.18855700E+03, -.18875400E+03, -.85865300E+03, -.61982800E+03, 0.22385300E+03, 0.69742100E+03, -.66465100E+02, -.61583600E+03, 0.16290800E+03, -.86469100E+01, -.14604500E+03, -.11758400E+03, -.56581100E+02, -.32806500E+02, -.83556000E+02, -.19851300E+03, -.44490800E+03, 0.42670400E+04, -.73618200E+02, 0.31589600E+04, -.27259800E+04, 0.76021100E+03, -.14827000E+03, 0.86395100E+02, -.89489000E+03, 0.43779400E+03, 0.12112000E+03, 0.27765400E+02, -.16240600E+04, -.15974700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.75589500E+00, -.10981900E+01, -.65834000E+00, -.58024500E+01, 0.11182500E+01, 0.64527300E-02, -.62897100E+00, -.14278300E+00, 0.15931200E+01, -.41080600E+00, 0.63198200E+00, -.71198100E-01, -.67765800E+00, -.39707100E+00, 0.10558000E-01, -.58077400E+00, -.65613700E+00, -.16900100E+00, -.32286400E+00, 0.13842700E+00, 0.67547000E-01, -.20539500E+00, -.13335000E+01, -.62534800E-02, -.41298400E-01, 0.32347300E-01, -.15542700E+01, 0.18048700E+00, 0.38734900E-02, 0.26220900E+00, -.71879900E-01, 0.74219300E-01, 0.14322500E+00, 0.67641400E+00, -.19530700E+00, 0.34340800E+00, -.39258900E+00, -.16402800E+00, -.36742400E+00, 0.92998900E-01, -.41398200E-01, 0.53568300E+00, 0.35210400E-01, -.44583100E+00, -.17634700E+00, 0.22050900E+00, 0.15279400E+01, 0.24275000E+00, -.10756900E+00, -.75533500E-01, 0.91092000E-01, 0.10545300E+00, 0.50702700E+00, 0.19225200E+00, 0.78321300E+00, 0.40103800E+00, 0.19730300E+00, -.10789700E+03, -.80335100E+01, 0.20082500E+03, 0.25571300E+03, 0.17395700E+02, -.81154100E+02, -.92721500E+03, 0.44541100E+03, 0.34157300E+03, 0.11480700E+02, 0.18676800E+02, 0.31943000E+03, 0.50895900E+03, 0.56216600E+03, 0.83805400E+02, -.72127700E+03, 0.37273700E+03, 0.40543300E+03, -.51605200E+03, -.25345500E+03, 0.80813900E+03, 0.14233400E+04, 0.45939700E+03, -.66218100E+02, -.42009700E+03, 0.20593400E+03, 0.24962700E+03, 0.15195700E+03, -.12911600E+03, -.20472700E+02, -.31730700E+03, 0.74918600E+02, -.24179100E+02, -.46437400E+03, 0.22503700E+03, 0.13806900E+03, 0.81475000E+03, 0.88451000E+03, -.52544600E+03, -.12538400E+04, -.32974500E+03, 0.64750200E+03, 0.36656800E+03, -.17428700E+03, -.11501700E+03, 0.47249100E+03, 0.49288100E+03, -.56624400E+03, -.10754000E+04, -.79930000E+03, 0.29887000E+03, -.38949600E+04, 0.19218900E+04, 0.18349500E+04, 0.44046900E+03, 0.56185900E+03, 0.12339200E+04, 0.81855000E+03, 0.12005600E+04, 0.10094200E+04, 0.41918400E+02, -.32605400E+02, -.72789900E+02, 0.15814800E+03, 0.32205300E+02, 0.41920000E+02, 0.79794700E+02, 0.86091600E+02, 0.80848400E+02, -.35445400E+03, 0.17459700E+03, 0.11397700E+03, -.65446900E+02, 0.56561100E+02, -.16235300E+02, 0.64891300E+02, 0.26964100E+03, 0.23385900E+03, 0.84221900E+01, 0.61573200E+01, 0.39567900E+02, 0.34974200E+03, 0.18773500E+03, -.21428300E+03, -.55145800E+03, -.45337600E+03, 0.19656300E+02, -.86010200E+03, 0.42012200E+03, 0.37463600E+03, 0.44649800E+03, 0.56348500E+03, -.22396300E+03, -.59828100E+03, -.10016800E+03, 0.36079900E+03, -.43640700E+03, 0.21356500E+03, 0.90894500E+02, 0.20479300E+03, 0.83427200E+02, -.13187900E+03, -.28178600E+03, -.18287200E+03, 0.19430800E+03, 0.15566100E+02, -.31486800E+01, -.54500000E+02, -.63285100E+02, -.32971000E+02, 0.71361300E+02, 0.20252000E+03, 0.31690900E+02, -.50560300E+02, -.19432800E+04, 0.95477700E+03, 0.87844600E+03, 0.36951200E+02, 0.26741500E+03, 0.64572500E+03, 0.52366800E+03, 0.78847000E+03, 0.43406300E+03, -.29299700E+03, 0.14797500E+03, 0.17343000E+03, -.36632400E+03, -.37582500E+03, 0.33717400E+03, 0.40311800E+03, 0.15665200E+03, -.12655700E+03, 0.31424700E+02, -.95200800E+01, -.56174500E+02, -.31408500E+02, -.22773900E+02, -.95322200E+01, -.15849100E+02, -.97596800E+02, -.63697200E+02, 0.11934900E+04, -.70409100E+02, 0.83808100E+03, -.55395900E+03, 0.30378700E+03, -.70904800E+02, 0.18535600E+02, -.30275000E+03, 0.31125500E+03, -.85778900E+01, -.31266900E+00, -.43932700E+03, -.46358900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24570700E+01, -.94032600E+00, -.34235700E+01, -.17512500E+02, 0.17938100E+01, 0.38657100E+00, -.45880300E+00, -.83846300E+00, 0.48239500E+01, -.10280200E+01, 0.21530600E+01, -.11526800E+01, -.34612600E+01, -.96914400E+00, 0.84614800E+00, -.14648000E+01, -.25168100E+01, -.17612600E+01, -.42736000E+00, 0.10136900E+01, -.52210500E-02, -.21688900E+01, -.91997500E+01, 0.40987500E+00, -.57749300E+00, -.81209700E-01, -.71308000E+01, 0.92878400E+00, 0.18698700E+01, -.28131800E+00, -.69331800E+00, -.30916800E-01, -.40540800E+00, 0.16265000E+01, -.90338600E+00, 0.15785300E+01, -.66095500E-01, -.24565900E+00, -.83670700E+00, 0.20517500E+00, 0.89774100E+00, 0.40274900E+00, 0.53093700E+00, -.12585900E+01, 0.14079000E+01, 0.16890700E-01, -.15010600E+01, 0.19460500E+01, -.11471800E+01, -.33409500E+00, 0.10212500E+01, -.10116300E+01, 0.56005100E+00, -.43087600E+00, 0.24041000E+00, -.10561100E+01, 0.28108500E+01, -.10867500E+01, 0.81989700E+03, -.70623800E+01, -.31321700E+03, 0.37069300E+03, 0.45229000E+03, 0.14354600E+04, -.76661100E+03, -.79973100E+03, 0.27651500E+04, 0.52666200E+03, -.18182600E+04, -.22415800E+04, -.22612400E+04, 0.69163100E+03, 0.18230900E+05, -.90741400E+04, -.92600800E+04, 0.11861700E+04, 0.92260000E+03, -.63457200E+04, -.43654000E+04, -.84842800E+04, 0.12973400E+03, -.25629000E+03, 0.15293900E+03, 0.12752100E+03, 0.26442000E+03, 0.17026600E+02, -.94126400E+03, -.24130800E+04, -.14055600E+04, 0.25580400E+02, -.11815500E+05, 0.58791600E+04, 0.59231500E+04, -.13404500E+04, -.19393700E+04, 0.46718000E+04, 0.49535700E+04, 0.66642800E+04, -.60805000E+03, 0.35189000E+04, -.17244700E+04, -.15353700E+04, -.38078700E+04, -.86727800E+03, -.95287200E+03, -.58870800E+03, -.69719700E+02, -.10966800E+04, 0.20712500E+04, -.10992300E+04, -.15051400E+04, 0.17408700E+04, 0.15126700E+04, 0.36180500E+03, -.63972600E+03, -.49446200E+04, 0.95929500E+03, 0.38446000E+04, -.19559000E+04, -.19351600E+04, 0.11089300E+04, 0.96999500E+03, -.17155000E+04, -.22143900E+03, -.27753300E+04, 0.48865500E+03, 0.29024600E+04, -.14534800E+04, -.14569600E+04, 0.31011100E+03, -.15128000E+04, -.42063200E+03, 0.32773200E+03, -.53289000E+03, -.73285200E+03, 0.56737500E+03, -.24312600E+03, -.28207700E+03, -.21841800E+04, -.27720600E+03, 0.14022900E+03, 0.62277200E+03, 0.10373400E+04, -.63256800E+03, 0.30830700E+03, -.13712300E+03, -.21792500E+03, 0.82124500E+03, 0.14531300E+04, -.20470000E+04, -.34614000E+04, -.11730300E+03, 0.10690000E+04, -.26487500E+04, 0.13138800E+04, 0.11791300E+04, -.58334600E+03, -.13462400E+04, 0.23683000E+04, 0.40620100E+04, 0.31966600E+04, -.13658700E+04, -.25726900E+03, 0.14446900E+03, 0.12913500E+03, 0.17826200E+03, -.17403300E+03, 0.10185000E+03, -.31479700E+03, 0.40003100E+02, -.41711700E+02, -.68528800E+04, 0.33925800E+04, 0.34656200E+04, 0.17616400E+04, 0.17434800E+04, 0.16407000E+04, -.28309300E+04, -.57873700E+03, 0.20503900E+04, -.45041600E+04, 0.22307500E+04, 0.22241600E+04, 0.75593100E+03, -.10316600E+04, 0.23832700E+04, 0.20805300E+04, 0.20257100E+04, -.30843700E+03, -.11015100E+03, -.10700900E+03, -.16611100E+03, 0.11988600E+03, -.78572900E+01, -.51649700E+02, 0.58002600E+02, 0.17102300E+03, 0.93633300E+03, -.15272600E+04, -.28218600E+03, -.19396100E+04, 0.45586300E+04, 0.91691400E+03, -.11305300E+03, 0.29880900E+03, 0.99585600E+03, 0.27421700E+04, -.42321400E+03, -.14579400E+02, -.86199600E+03, -.38362700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.94157600E+00, 0.69519400E+00, -.67545500E+00, 0.12372400E+02, -.88838400E+00, -.20234000E+00, 0.98637100E+00, 0.16922000E+00, -.27904100E+01, 0.43084200E+00, -.15184600E+01, 0.13490900E+00, 0.28417700E+01, 0.42466800E+00, 0.14290800E+00, 0.85622400E+00, 0.10822000E+01, 0.14131300E+00, 0.13266000E+00, -.14475300E+00, 0.15255000E+00, 0.12698600E+01, 0.63830600E+00, -.30813600E+00, 0.17455500E+00, -.64621100E-01, 0.23567300E+01, -.59797500E+00, -.38222800E+01, 0.45467500E+00, -.13628400E+00, -.72235900E-01, 0.48058300E+00, -.13119200E+01, -.20715700E+00, 0.35568800E+00, 0.54254000E+00, 0.26752400E-01, -.23838900E+00, 0.14136600E+00, 0.44077300E+00, -.41597600E+00, 0.51236000E-01, -.65440100E+00, -.87647900E+00, 0.89607300E-01, 0.38025500E+01, 0.80263900E-02, -.17148600E+00, -.38566900E+00, 0.15302700E+00, -.13286100E+00, -.25439000E+00, 0.94577100E+00, -.54494200E+00, 0.30368300E+00, 0.23065600E+00, 0.13899700E+01, 0.63312800E-01, -.41997800E+03, -.61552700E+03, -.21540100E+02, 0.17564800E+03, 0.22992700E+04, -.11112000E+04, -.93971000E+03, 0.57744200E+03, 0.45549500E+02, -.94894000E+03, -.11951500E+04, -.14538000E+04, -.94820700E+02, 0.65645100E+03, -.37690900E+03, -.33861900E+03, 0.10344300E+04, 0.48896000E+03, -.17427100E+04, -.35851500E+04, -.96837400E+03, 0.86284300E+03, -.15524200E+04, 0.76207600E+03, 0.73350100E+03, -.25128000E+03, 0.35779600E+03, 0.80383600E+03, 0.75973000E+03, 0.44890400E+03, 0.19111100E+03, 0.40078100E+04, -.19745000E+04, -.18783400E+04, -.16159700E+04, -.19216700E+04, 0.12800300E+03, 0.25847900E+04, -.34344000E+03, -.20794000E+04, -.54199800E+03, 0.23534300E+03, 0.15944600E+03, -.15665200E+04, -.86677000E+03, 0.10335700E+04, 0.18745600E+04, 0.14718800E+04, -.61637400E+03, 0.31228500E+04, -.14827900E+04, -.12546400E+04, 0.26079800E+03, 0.74350700E+02, -.24239600E+04, -.37205500E+04, -.31769100E+04, -.20334000E+03, -.12964900E+04, 0.68356400E+03, 0.70496000E+03, -.37580800E+02, 0.48348800E+03, -.62828600E+01, -.56550100E+03, 0.71291700E+02, 0.28911400E+03, 0.12066100E+04, -.59448400E+03, -.53554900E+03, 0.43700800E+03, -.65385400E+02, -.27777600E+03, -.35843500E+03, -.82205500E+03, -.41458200E+03, 0.18235400E+03, -.96185600E+02, -.12956400E+03, -.93949700E+03, -.30502900E+03, 0.44018700E+03, 0.11754600E+04, 0.88896600E+03, -.88695600E+02, 0.28297500E+04, -.14273200E+04, -.13422100E+04, -.41371900E+03, -.79245600E+03, -.10150300E+03, 0.64941900E+03, -.57785400E+03, -.76425200E+03, 0.65933700E+02, -.18127200E+02, 0.20106100E+03, -.45088900E+03, -.33510800E+03, 0.68441100E+03, 0.87374700E+03, 0.65199800E+03, -.40269700E+03, -.82089900E+02, 0.23493400E+02, 0.11283000E+03, 0.20002200E+03, 0.47317700E+02, -.18640600E+03, -.55946400E+03, -.13201700E+03, 0.12421500E+03, 0.13174600E+04, -.60836900E+03, -.54202800E+03, 0.50237000E+03, -.87411700E+01, -.11042100E+04, -.21017000E+04, -.19079400E+04, 0.76427400E+02, -.96525700E+03, 0.51345700E+03, 0.47277500E+03, 0.56327300E+03, 0.48716900E+03, 0.10231800E+02, -.26119300E+03, 0.36705400E+03, 0.40694500E+03, -.10034100E+03, -.34022700E+01, 0.45465100E+02, 0.79101000E+02, 0.27105500E+02, 0.26759600E+02, 0.53046600E+02, 0.15290900E+03, 0.33805700E+03, -.26302800E+04, 0.14901100E+03, -.17869900E+04, 0.19553800E+04, -.85489200E+03, 0.26580100E+03, -.48127200E+02, 0.72059300E+03, -.67238800E+03, -.72149200E+02, -.82365100E+01, 0.13704800E+04, 0.99178300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21590600E+01, 0.11441400E+01, 0.26070900E+01, 0.15078700E+02, -.40513700E+00, -.52206400E+00, 0.21266500E+00, 0.14029100E+01, -.45201500E+01, 0.85023700E+00, -.26539500E+01, 0.11690500E+01, 0.19795300E+01, 0.20797600E+01, 0.19507800E+00, 0.27645300E+00, 0.19651600E+01, -.27406700E+00, 0.68292000E+00, -.75773600E+00, 0.39469800E+00, 0.29834300E+01, -.24194800E-01, -.10174900E+01, 0.63913000E+00, 0.62227200E+00, 0.82285700E+01, -.24864700E+01, -.14528600E+02, 0.10598400E+01, -.53873900E+00, -.78065400E+00, 0.76901600E+00, -.61437000E+00, -.13933300E+01, 0.99842500E+00, 0.14556000E+00, 0.14674100E+00, -.22341900E+01, -.25029500E-01, 0.12254000E+01, -.67576900E+00, 0.40282000E+00, 0.56233100E+00, -.82356500E-01, -.22681500E+00, 0.10850200E+01, -.12917400E+01, 0.48040300E+00, 0.28944200E+00, 0.12912900E+00, 0.59007100E+00, -.19687700E+00, 0.22006000E+01, -.36248700E+00, -.29055400E+00, -.96980300E+00, 0.20063700E+01, -.33335100E+00, -.14362600E+01, 0.53012800E+03, 0.28996900E+03, -.28482500E+02, 0.11719400E+04, -.61302000E+03, -.45348300E+03, 0.15637200E+03, -.45194300E+03, -.43737200E+03, -.71439700E+03, -.77521000E+03, -.81924100E+03, -.34924700E+04, 0.17997400E+04, 0.17832900E+04, 0.64562900E+03, -.71216900E+03, 0.50834500E+03, 0.65389700E+03, -.90649100E+03, -.13862400E+04, 0.20809500E+04, -.10468100E+04, -.11253500E+04, 0.66326500E+03, 0.39510000E+03, -.66070900E+03, -.43100900E+03, -.72002300E+02, 0.33544100E+03, 0.19644400E+04, -.99799600E+03, -.88511800E+03, -.67373600E+03, 0.42121500E+03, -.39307700E+02, -.12312300E+04, 0.11549800E+04, 0.59420600E+03, 0.17943200E+04, -.89898200E+03, -.12602100E+04, -.47673900E+03, 0.50149500E+03, -.52406400E+03, -.66453700E+03, -.21361000E+03, 0.79685500E+03, -.69992100E+04, 0.34705800E+04, 0.39047600E+04, 0.36413400E+03, -.35078400E+03, 0.27627700E+04, -.28684000E+03, 0.11717900E+04, -.70049400E+03, -.35555000E+04, 0.17649500E+04, 0.18984700E+04, -.25958400E+03, 0.27022400E+03, 0.14739500E+04, 0.40023900E+03, 0.15496700E+04, 0.39148200E+03, 0.13585800E+04, -.67186400E+03, -.52802100E+03, 0.90540100E+02, -.61774100E+03, -.28848900E+03, -.38859700E+03, -.14120100E+04, -.11168600E+04, 0.66474500E+03, -.28912600E+03, -.45578600E+03, -.49893800E+03, 0.11373400E+03, 0.13649500E+03, 0.19954800E+03, 0.82923400E+03, 0.50269000E+03, 0.58201500E+04, -.28628000E+04, -.27314500E+04, -.27660000E+03, -.86057400E+03, -.16290300E+04, -.92031700E+03, -.13567900E+04, -.43684900E+03, 0.13004200E+04, -.65321300E+03, -.46658900E+03, -.77342600E+02, -.40540300E+03, -.13762400E+03, 0.45656100E+03, -.21949300E+03, 0.13981600E+03, 0.20992900E+03, -.97478300E+02, -.84804700E+02, -.37758300E+02, 0.47987900E+02, -.85942400E+02, 0.11221400E+03, -.16611400E+03, -.14979300E+03, -.23376000E+04, 0.11241000E+04, 0.11799000E+04, 0.16861600E+03, -.36381200E+03, 0.11009600E+04, 0.15667500E+03, 0.61394200E+03, -.83055800E+03, -.14001900E+04, 0.76699700E+03, 0.61840300E+03, 0.60174000E+03, 0.35875400E+03, 0.53053400E+03, 0.10163400E+04, 0.37352400E+03, -.26616400E+03, 0.78278500E+02, 0.36477400E+02, -.15944300E+03, -.51245100E+01, 0.74707900E+01, -.57597100E+02, -.41583100E+02, 0.17051600E+03, 0.15715300E+03, 0.71030300E+03, 0.15762800E+03, 0.38343100E+03, 0.97987100E+03, 0.22681200E+03, 0.77365800E+02, 0.18017300E+03, 0.55243400E+03, 0.81107100E+03, 0.56557600E+02, 0.51771500E+02, -.10796500E+04, -.31455600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.96643200E+00, -.11733500E+00, 0.23102000E+00, -.23249800E+01, 0.95098400E+00, -.79076200E-01, -.13820200E+00, -.72667800E+00, 0.11421500E+01, -.33042500E+00, 0.42766300E+00, 0.40409500E+00, 0.46386500E+00, -.74940100E+00, -.11610900E+01, -.25953500E+01, -.18768400E+00, 0.71482000E+00, -.40379300E+00, -.61730400E+00, 0.21545000E+00, 0.54075000E+00, -.11271200E+00, 0.40469900E+00, 0.96895200E-01, 0.47734400E+00, -.13609200E+01, 0.16478000E+00, 0.72319200E+00, 0.41803700E+00, -.67683200E+00, 0.88622700E+00, 0.29056400E+00, 0.29441700E+00, -.62856900E+00, 0.15086900E+01, -.75838300E-01, -.39833100E-01, -.57912100E+00, 0.10928000E+00, -.15105600E+00, 0.64542000E-01, -.50391700E-01, 0.17207100E+00, -.13514700E+00, -.13604300E+00, 0.22751000E+01, -.35377900E+00, 0.48680300E+00, -.45627400E-01, -.64978500E-01, 0.17885200E+00, 0.12938600E+00, 0.80048100E+00, 0.16878200E-01, 0.59081900E-01, -.84119500E-01, 0.65753000E+00, -.15248600E+00, -.65635500E-01, 0.17935100E+00, 0.12279900E+03, 0.26233900E+02, 0.45479000E+03, -.21613100E+03, -.22508500E+03, 0.46331300E+03, 0.98523400E+02, -.41192700E+03, -.61665000E+03, -.64255200E+03, -.97655900E+01, 0.37818600E+04, -.19049800E+04, -.19079500E+04, 0.22111600E+03, 0.33280100E+03, -.14015500E+04, -.16762600E+04, -.16961500E+04, -.23080200E+02, 0.12390800E+04, -.61267000E+03, -.62955300E+03, 0.39492100E+02, 0.18821400E+03, -.59249200E+03, -.35240700E+03, -.69054000E+03, -.55723100E+02, -.25892400E+04, 0.12968200E+04, 0.13070500E+04, -.54564700E+03, -.87162200E+03, 0.11824400E+04, 0.17874000E+04, 0.16735300E+04, -.39837900E+03, 0.73472300E+03, -.37246100E+03, -.37880600E+03, -.69058400E+03, -.31578700E+03, -.85776200E+02, 0.35159000E+03, 0.23501400E+03, -.21278600E+03, 0.20034700E+04, -.98510400E+03, -.10223600E+04, -.21456600E+03, -.87404800E+02, -.28370600E+03, -.41440400E+03, -.10329800E+04, -.47635200E+03, 0.36669300E+03, -.17466700E+03, -.16929300E+03, 0.51243500E+01, 0.48572800E+02, -.17037700E+03, 0.95119500E+02, -.22205900E+03, 0.32038900E+02, 0.72683600E+03, -.36140100E+03, -.34492500E+03, -.80083300E+01, -.17994800E+03, -.11076100E+03, -.19380700E+03, -.10761500E+03, -.20650500E+03, 0.40689700E+03, -.21098600E+03, -.21920700E+03, -.41173300E+03, -.18123900E+03, -.76383200E+02, 0.25468300E+03, 0.20752900E+03, -.14746400E+03, 0.10989900E+04, -.54302900E+03, -.53573400E+03, -.65998200E+02, -.26245800E+03, -.48734400E+03, -.18926300E+03, -.12355400E+03, -.29213500E+03, -.44979500E+03, 0.22764300E+03, 0.22150300E+03, -.72670900E+02, -.47042000E+02, 0.38687700E+03, 0.70245500E+03, 0.62338200E+03, -.98801800E+02, -.23383400E+02, 0.72161100E+01, 0.14287600E+02, 0.69694800E+02, -.24612900E+02, -.13563200E+02, -.14914000E+03, -.50498200E+02, 0.83468200E+01, -.28765500E+03, 0.15891500E+03, 0.15495700E+03, 0.11532100E+03, 0.93448600E+02, 0.82609300E+02, -.59242500E+03, -.29622300E+03, 0.31888000E+02, -.20433800E+03, 0.96972800E+02, 0.89340400E+02, 0.22716500E+03, 0.21682900E+03, 0.11601100E+03, 0.75449600E+02, 0.68354700E+02, 0.18291900E+03, -.30717400E+02, 0.24878900E+02, 0.30522700E+02, 0.27905800E+02, 0.19506700E+02, -.10428800E+02, 0.13946400E+02, 0.17513800E+02, 0.18887500E+03, -.10763000E+04, 0.89001300E+01, -.82490300E+03, 0.91317600E+03, 0.46132900E+02, 0.13524700E+02, 0.13930800E+02, 0.31020900E+03, 0.24777300E+03, -.48315600E+02, 0.18827900E+01, -.54447000E+02, 0.17591400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.83380300E+00, -.65265500E+00, 0.14516600E+00, -.68287400E+01, 0.90947500E+00, 0.33519300E-01, -.53357300E+00, -.32384900E+00, -.15723600E+00, -.28039500E+00, 0.24159400E+00, -.65054300E-01, -.99955700E+00, -.21212700E+00, 0.17425400E+00, -.30046600E+00, -.70261700E+00, -.71286300E+00, 0.13020800E+00, 0.25041000E+00, -.86345600E-01, -.53794900E+00, -.12050800E+01, 0.18773800E+00, -.31470400E+00, 0.29021400E-02, -.67503000E-01, -.42103300E-01, 0.22384600E+00, 0.24022500E+00, -.59054400E+00, 0.34957100E+00, 0.22600500E+00, 0.95205600E+00, -.51306600E+00, 0.12206700E+00, -.19717000E+00, 0.96826400E-01, -.21658600E+00, 0.26246400E-01, 0.80985400E-01, -.48416500E+00, 0.24402200E-01, -.30679300E+00, 0.42263300E+00, -.38504100E+00, -.17677100E+01, -.22207700E+00, 0.18234200E+00, -.41655300E+00, 0.28893700E+00, -.11461500E+01, -.99999800E-01, 0.33538300E+00, -.55311500E-01, 0.20721000E+00, -.78187400E-02, 0.98663400E+00, -.56018300E-01, 0.64586700E+00, 0.14773100E+00, 0.29626300E+00, 0.65239000E+02, -.31552400E+03, 0.15525500E+03, 0.16139600E+03, -.74178200E+02, 0.72105200E+02, 0.14546000E+03, 0.18865700E+03, 0.26283100E+03, 0.32844500E+03, 0.20012100E+04, -.10170700E+04, -.95910500E+03, -.18505300E+03, 0.40464700E+03, -.46058000E+03, -.23327900E+03, -.13427700E+03, 0.57919900E+03, 0.52270000E+03, -.26035000E+03, -.23440400E+03, -.14916000E+03, -.23110200E+02, -.19739800E+03, 0.12194600E+03, -.43287600E+03, -.10059500E+03, -.24212500E+04, 0.12168500E+04, 0.11745900E+04, -.47357000E+02, -.26618400E+03, 0.72418000E+03, 0.62424500E+03, 0.43085800E+03, -.20790700E+03, -.42215300E+03, 0.20792900E+03, 0.24935400E+03, 0.16840600E+03, -.17503300E+03, 0.10289500E+03, 0.25890800E+02, -.88364000E+02, -.31655700E+03, 0.48172500E+03, -.23129000E+03, -.17544800E+03, -.34164200E+03, 0.15836900E+03, -.59637500E+01, 0.56703600E+03, -.93563800E+02, 0.27540800E+03, 0.13365400E+04, -.66622500E+03, -.70199600E+03, 0.71893800E+01, -.28752000E+03, -.43586600E+03, 0.13361800E+03, -.47701700E+03, -.25908000E+03, -.32910000E+02, 0.13356700E+02, -.32424300E+02, -.10563600E+03, -.25160100E+01, 0.83582100E+02, 0.19524700E+03, 0.36401900E+03, 0.15033700E+03, -.54016400E+03, 0.27137200E+03, 0.31237300E+03, 0.10256200E+03, -.43238700E+02, 0.59866200E+02, -.13409900E+03, -.12093900E+03, -.12260700E+03, -.44704200E+03, 0.21099700E+03, 0.18428100E+03, 0.83953400E+02, 0.52587400E+02, 0.74468400E+02, 0.14109000E+03, -.13560300E+02, -.41610400E+02, -.31522200E+03, 0.15943100E+03, 0.17078800E+03, -.28320000E+02, 0.96593800E+02, 0.15441800E+02, -.17821500E+03, 0.14025000E+03, -.25186800E+03, -.58422400E+01, 0.10340000E+01, 0.19078100E+01, -.28096600E+02, -.28817000E+02, 0.36663000E+02, 0.72518100E+02, 0.11221100E+03, 0.45221700E+02, -.10761900E+03, 0.64170200E+02, 0.52197600E+02, 0.37941600E+02, 0.22024500E+03, -.27545500E+02, 0.21567100E+02, -.22313100E+03, 0.42974400E+03, 0.56247900E+03, -.27816300E+03, -.23159900E+03, -.14493600E+03, 0.72535300E+02, -.19256800E+03, -.12067000E+03, -.22469700E+03, 0.15635700E+03, -.91392400E+01, -.12339800E+02, 0.60625600E+02, -.49673000E+01, -.77121300E+01, 0.18871400E+02, 0.28749100E+01, -.15199000E+02, -.41223400E+02, -.19908200E+02, -.20162800E+02, -.37593800E+02, -.36360700E+03, 0.14736900E+03, -.92143100E+02, -.29413700E+02, -.20033800E+03, -.10067300E+03, -.17414000E+02, -.18976000E+02, 0.49876800E+02, 0.45621200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25409800E+01, -.19602800E+01, -.10179700E+01, -.13235700E+02, 0.12979100E+01, -.29590400E+00, -.11084400E+01, -.17041100E+01, 0.48461900E+01, -.13203600E+01, 0.16453400E+01, -.79822300E+00, -.22522900E+00, -.15027800E+01, -.48461800E+00, -.46062100E+01, -.22020400E+01, -.88750800E+00, -.13615400E+01, 0.86042800E+00, -.23721700E+00, -.19407300E+01, -.33166000E+01, 0.46668200E+00, -.20980300E+00, -.33902200E+00, -.53503200E+01, 0.79479800E+00, 0.47023100E+01, 0.17659200E+00, -.81301300E+00, 0.70071600E+00, 0.36160000E-01, 0.22736600E+01, -.31823900E+00, 0.22345000E+01, 0.56938400E+00, -.10116400E+00, -.68660500E+00, 0.57739600E-01, 0.38318600E-01, 0.12496700E+01, -.57301800E+00, 0.42278500E+00, -.12786600E+01, 0.17962700E+00, 0.81073900E+01, -.38856100E+00, 0.59747400E+00, 0.61975200E+00, -.22010600E+00, 0.40217000E+00, 0.51367200E+00, 0.17690300E+01, 0.58963500E-01, 0.48654600E-01, 0.31680700E+00, 0.46905800E+00, -.97385300E-01, -.58469300E+00, 0.18466600E+00, 0.23445200E+00, 0.41645100E+00, 0.82732200E+03, -.43570800E+03, -.39747800E+03, 0.36592500E+03, 0.15422500E+02, -.35724400E+03, -.39380200E+03, -.57589900E+03, -.17912000E+03, -.54373100E+03, 0.31860000E+03, 0.18484100E+03, 0.11269000E+03, -.17713700E+03, 0.23053000E+03, 0.64791900E+02, 0.83724900E+02, -.38363300E+03, 0.40411000E+03, -.25001300E+03, -.26431800E+03, 0.25315700E+03, 0.12125600E+03, -.26917900E+03, -.31930200E+03, -.23119600E+03, 0.35737100E+02, -.68620500E+03, 0.32541100E+03, 0.42230900E+03, -.21322500E+03, -.10303600E+01, 0.23886600E+03, 0.54654900E+02, 0.36417000E+03, 0.21771500E+03, 0.76582800E+03, -.38079300E+03, -.50772900E+03, -.40972900E+03, 0.22783200E+03, -.50903600E+03, -.38417700E+03, -.20815500E+03, 0.28792400E+03, -.79657800E+03, 0.37196100E+03, 0.32622500E+03, 0.13395200E+03, 0.77191500E+02, 0.58138100E+03, 0.43764900E+03, 0.42477200E+03, -.24878300E+03, -.67654500E+03, 0.33116800E+03, 0.42159500E+03, 0.33087900E+02, 0.19319100E+03, 0.21809300E+03, -.58839000E+02, 0.42145600E+03, 0.12729900E+03, 0.10429600E+02, -.55492900E+00, 0.10390600E+03, 0.62378700E+02, 0.65894500E+01, 0.50712000E+02, -.13181700E+03, -.37343100E+02, -.11984200E+03, 0.49011000E+03, -.22049800E+03, -.34023600E+03, -.33491900E+03, 0.41345800E+02, -.14664300E+03, 0.10158600E+03, 0.12879400E+03, 0.44984900E+02, 0.34839900E+03, -.21222500E+03, -.82433600E+02, 0.66500400E+02, 0.61164300E+02, -.32723500E+03, -.56217700E+03, -.33448300E+03, 0.17411000E+03, 0.49841200E+01, -.69102400E+01, 0.41199700E+01, -.54736400E+02, -.10231800E+03, 0.15915600E+03, 0.44635500E+03, 0.13848700E+03, -.11712900E+02, 0.67523900E+01, 0.37169500E+01, 0.64213400E+01, 0.30128900E+02, -.64144000E+01, 0.78175100E+01, -.69170900E+02, -.66633400E+02, -.31080600E+02, -.21154600E+03, 0.70266600E+02, 0.14892400E+03, 0.14516600E+03, 0.80368200E+01, 0.14394300E+03, 0.11528700E+03, 0.14978100E+03, -.12211600E+03, -.79577600E+03, 0.42986500E+03, 0.30967200E+03, 0.23999800E+03, -.46535500E+02, 0.40995700E+03, 0.35032900E+03, 0.54561100E+03, -.17361500E+03, -.17845200E+01, 0.32176200E+02, -.28213000E+02, 0.20090700E+02, 0.19095200E+01, -.73033100E-01, 0.94461300E+00, -.15536600E+02, 0.18283000E+03, -.42276600E+02, 0.27979200E+02, -.34920800E+02, 0.81039300E+03, 0.89071200E+02, 0.12281400E+03, -.20430900E+02, 0.29009400E+03, 0.30575500E+03, -.15230800E+02, 0.11152700E+02, -.27822100E+03, -.76341000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19353600E+01, -.11393300E+01, 0.69219800E+00, -.21773200E+02, 0.28081800E+01, 0.51288200E+00, -.16650700E+01, -.71962000E+00, 0.44660600E+01, -.10603700E+01, 0.16808600E+01, -.19607500E+00, -.26424700E+01, -.10990600E-01, 0.58567600E+00, -.26114700E+01, -.21452700E+01, -.11790100E+01, -.29057100E+00, 0.54603800E+00, -.23845800E+00, -.14307100E+01, -.56400700E+01, 0.82779300E+00, -.14469900E+00, 0.13433000E+00, -.80619500E+01, 0.59229300E+00, 0.16844200E+01, -.20841100E+01, -.80712300E+00, -.60147400E+00, -.10817500E+01, 0.25300600E+01, -.49743300E+00, -.80288800E+00, -.16995000E+01, -.35821500E-01, -.30206500E+00, -.46142700E+00, -.54828300E+00, 0.28456900E+00, -.30744700E+00, 0.93615300E+00, 0.48520900E+00, -.44995900E+00, -.56391200E+01, -.36583100E+00, 0.21321200E+00, 0.10625300E+00, -.33809600E+00, 0.70241300E-01, 0.84648200E+00, -.17855900E+01, 0.14670500E+01, 0.35938600E+00, -.11679300E+01, -.63113300E+00, 0.64627400E-01, -.30720400E+00, -.40826400E+00, -.17408500E+01, -.58875200E+00, -.49738000E+00, 0.48151500E+02, -.30817500E+02, -.82889800E+03, -.10282000E+03, 0.23154200E+03, 0.15867100E+03, 0.68760000E+02, -.33787300E+03, -.63594200E+03, 0.27924200E+03, 0.34959600E+03, -.16437900E+03, -.16791500E+03, 0.48746400E+03, 0.38432300E+03, 0.51930300E+03, -.35290000E+03, -.11702000E+03, 0.10774800E+03, 0.35374800E+02, -.95176100E+02, -.44201000E+02, 0.24086800E+03, 0.56566600E+03, 0.18781400E+03, -.12903700E+03, 0.21101200E+03, -.93479200E+02, -.11939400E+03, 0.17479200E+03, 0.24129400E+03, -.36424000E+03, -.35929200E+03, -.16738100E+03, 0.41153900E+03, -.21953000E+04, 0.10891500E+04, 0.93078400E+03, 0.12852200E+04, 0.32643300E+03, 0.58668000E+03, 0.55082300E+03, 0.48294900E+03, 0.59653000E+03, 0.12335600E+04, -.57935800E+03, -.51176200E+03, -.50065800E+03, -.42290700E+02, -.30114700E+03, 0.74651000E+02, 0.36636000E+03, -.22182100E+02, -.17757400E+02, 0.29976100E+02, 0.50514700E+02, 0.42146800E+01, -.31754700E+01, -.71749300E+02, -.26241400E+03, -.10948200E+03, 0.58060300E+02, -.10751100E+03, 0.54758500E+02, 0.10233200E+03, -.27400700E+02, 0.52544600E+02, 0.29049800E+02, -.48851700E+02, -.14625300E+02, -.69909500E+02, -.87404600E+02, -.90039300E+01, -.55765800E+01, 0.51369600E+03, 0.66298300E+01, -.99037300E+02, 0.41159400E+02, -.10543100E+03, 0.14346600E+03, 0.60976000E+03, -.23933400E+03, -.23442300E+03, -.32520000E+03, -.34694500E+03, 0.24976800E+03, 0.12461600E+04, 0.21023200E+03, -.44569600E+03, 0.69365800E+03, -.34147100E+03, -.35841700E+03, 0.46421100E+02, 0.11481600E+03, -.32234600E+03, -.24166600E+03, -.62088900E+02, 0.27377000E+03, 0.36811000E+02, -.29144200E+02, -.42369700E+02, -.18335000E+02, 0.47823100E+02, -.16981000E+02, -.55634900E+02, -.67181800E+02, 0.18945500E+01, 0.22664700E+03, -.78768800E+02, -.14713800E+03, -.30858000E+03, 0.15132500E+03, 0.68214800E+01, 0.25272800E+03, 0.22675100E+03, -.23222800E+02, 0.19625900E+04, -.10195800E+04, -.10192200E+04, -.14361300E+03, 0.15867300E+03, -.88714600E+03, -.95594400E+03, -.86028800E+03, 0.11455800E+02, 0.33002400E+01, 0.29845300E+02, 0.22361700E+02, -.21863700E+02, 0.33608800E+02, -.79059600E+01, -.61505800E+00, 0.11666100E+02, -.25810500E+03, 0.12367100E+03, 0.90898700E+02, 0.18239200E+03, -.11896900E+04, -.17221400E+03, -.30358600E+01, -.18358000E+02, -.13098600E+03, -.53407500E+03, 0.44976800E+02, 0.54986000E+01, 0.18477700E+03, 0.10205100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.95945300E+00, -.24871000E+00, 0.79759700E+00, 0.19521700E+01, -.16776600E+01, -.31417400E+00, -.10644100E-01, 0.87084200E+00, -.11474700E+01, 0.35338200E-01, -.73097800E+00, 0.14863500E+00, 0.11185500E+01, 0.49870800E+00, 0.14215800E+01, 0.16315800E+01, -.18770600E+00, 0.87094800E-01, 0.34193900E+00, 0.40022800E+00, -.23042000E+00, -.51776300E+00, -.11870400E+01, -.50715400E-01, -.35145400E-01, 0.21634400E+00, 0.44509100E+00, 0.84739500E-01, 0.14449900E+01, 0.23355500E+00, -.27699700E+00, 0.37677400E+00, 0.92711700E-01, 0.15729300E+01, -.26423600E+00, -.53912700E+00, -.62567000E+00, -.81043500E-01, 0.12293000E+00, 0.34074800E-01, 0.10621500E+00, -.80129100E-01, -.21638100E+00, 0.81753000E+00, -.14535500E+00, 0.84971000E-02, 0.14281000E+01, -.31236600E+00, 0.93807900E-01, 0.79016100E-01, -.72346700E-01, 0.13485900E+01, 0.23646700E+00, 0.63413800E+00, 0.79119100E-01, 0.20602300E+00, -.36100300E-01, 0.83502200E+00, -.14559000E+00, -.27559800E+00, 0.28214300E+00, 0.90495800E+00, -.69342600E-01, 0.11643100E+00, 0.20126500E+00, 0.47750300E+02, -.46144100E+01, -.46956300E+01, 0.47186300E+02, 0.14207100E+03, 0.77210200E+02, 0.12956100E+03, 0.80947600E+03, -.39541200E+03, -.45339100E+03, 0.42462400E+02, 0.23928200E+03, -.32953000E+03, -.20613800E+03, -.29078700E+03, 0.26478700E+03, 0.15386100E+03, -.61457600E+02, -.86845100E+02, -.11747400E+03, 0.32532300E+02, -.46160600E+02, -.16208400E+02, -.44734500E+02, 0.44852900E+02, -.90958600E+03, 0.44826100E+03, 0.49882200E+03, -.93220800E+02, -.25864000E+03, 0.46090100E+03, 0.37283500E+03, 0.22543800E+03, -.21152500E+03, -.10581200E+03, 0.62589600E+02, 0.98985000E+02, -.15487700E+03, -.22880300E+03, 0.10056100E+03, 0.85413300E+02, 0.15389000E+03, -.25264000E+03, 0.18616300E+04, -.94490100E+03, -.97983400E+03, -.36424400E+03, -.29881700E+03, -.24301300E+03, 0.47420400E+03, -.35742500E+03, -.40192400E+03, 0.88669600E+03, -.44965800E+03, -.43494400E+03, -.68391800E+02, -.19272000E+03, -.20955400E+03, 0.47721100E+02, -.39455800E+03, -.22523200E+03, -.21968100E+03, 0.10903300E+03, 0.12053000E+03, 0.12649600E+02, 0.13854800E+02, 0.77911600E+02, -.80714000E+01, 0.28390100E+02, 0.70700900E+02, -.38029300E+03, 0.18576200E+03, 0.18634700E+03, -.84357900E+02, -.50308900E+02, 0.14306100E+03, 0.48325500E+02, 0.11806900E+03, -.49022100E+02, -.15095300E+04, 0.77131900E+03, 0.74766800E+03, -.39029000E+02, 0.97572100E+02, 0.46910700E+03, -.21583600E+02, 0.53171800E+03, 0.19782200E+03, -.78994900E+02, 0.37103100E+02, 0.76483100E+02, -.58020400E+02, -.14933100E+02, 0.52141500E+02, 0.51534500E+02, 0.38652400E+02, -.16857400E+03, -.26661300E+02, 0.17513300E+02, 0.39740800E+02, -.11270200E+02, -.79231700E+01, 0.24491200E+02, 0.43986600E+02, 0.52655600E+02, 0.20533700E+02, 0.10428600E+04, -.52543700E+03, -.46237400E+03, -.13754600E+03, -.18066200E+03, -.21768100E+03, 0.10905800E+03, -.16899700E+03, -.16070800E+03, 0.16259500E+03, -.10448500E+03, -.85847000E+02, 0.47025000E+02, 0.11549600E+02, -.80174800E+02, -.45671100E+02, -.52495300E+02, 0.24736000E+02, -.17973700E+01, -.50886800E+01, 0.35364900E+02, 0.14351000E+01, 0.36796700E+01, 0.82217800E+01, 0.36252900E+00, -.72601700E+01, 0.67875900E+01, -.20165900E+03, -.20507300E+02, -.18587700E+03, 0.18785100E+02, 0.31153000E+02, -.30529300E+02, 0.60184200E+01, -.40077500E+02, -.12998600E+02, 0.32192300E+01, -.66514400E+01, 0.38695500E+02, 0.14101500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23381500E+01, -.20549700E+01, -.25404600E+01, -.12058100E+02, 0.16946300E+01, -.22787300E+00, -.14508600E+01, -.15234000E+01, 0.42340200E+01, -.12589200E+01, 0.14340000E+01, -.66851100E+00, 0.25827500E-01, -.44397400E+00, 0.50479700E+00, -.17082300E+01, -.10404100E+01, -.10707200E+01, -.68590600E+00, 0.56030700E+00, 0.26309500E-01, -.15446000E+01, -.62441200E+01, 0.24688300E+00, -.38342900E+00, -.23042500E+00, -.22819800E+01, 0.34149000E+00, 0.54681300E+00, 0.22147000E+00, -.28304000E-01, 0.20257100E-01, -.30986900E+00, 0.12042600E+01, 0.54625600E-01, 0.15333100E+01, 0.79031600E+00, -.12480200E+00, -.66167800E+00, 0.42754300E-01, 0.28154400E+00, 0.73863500E+00, 0.20945100E+00, -.31740800E-01, -.13829200E+01, 0.15088400E+00, 0.74221700E+01, 0.45224700E+00, 0.96562200E-01, 0.57262500E+00, -.26006100E+00, 0.90213100E+00, 0.49038000E+00, 0.22544900E+01, -.58816500E+00, -.36949600E+00, 0.10600100E+01, 0.57555400E+00, 0.13379100E-01, -.30950300E+00, 0.57751100E+00, -.69448900E+00, 0.27541700E+00, 0.54388900E+00, -.41636800E+00, 0.20198500E+01, 0.75873800E+03, 0.15720700E+03, -.42560700E+03, -.10009800E+04, -.66246800E+03, -.29690400E+03, 0.51765600E+04, -.26034700E+04, -.24343200E+04, 0.93796700E+02, -.93582700E+01, -.18712500E+04, -.22820700E+04, -.25066000E+04, -.77246600E+03, 0.15488100E+04, -.78733200E+03, -.73970900E+03, 0.23536100E+03, 0.12622800E+03, -.73913400E+03, -.54357300E+03, -.91192500E+03, -.16318800E+03, -.20299600E+04, 0.10209400E+04, 0.94112600E+03, -.60642700E+03, -.85722300E+03, 0.95617300E+03, 0.21500900E+04, 0.22400600E+04, -.36415500E+02, 0.26592800E+04, -.13428500E+04, -.14007900E+04, -.80014300E+03, 0.21391400E+03, -.87905800E+03, -.32784300E+03, -.84243000E+03, 0.28702900E+03, 0.33881100E+04, -.16604100E+04, -.14039600E+04, 0.18092500E+03, -.39256100E+03, -.96322300E+03, -.14472200E+04, -.12942400E+04, -.70479100E+03, -.34497300E+03, 0.18744800E+03, 0.13124000E+03, 0.20495700E+03, 0.15449800E+03, -.57503500E+02, 0.67895200E+02, -.25785700E+03, 0.25302200E+03, 0.91465600E+03, -.45561400E+03, -.50825700E+03, 0.44517700E+02, -.22447200E+03, -.25699100E+03, -.28239800E+03, -.16513800E+03, -.32399800E+03, 0.76939200E+03, -.37822800E+03, -.33957800E+03, -.41624200E+03, -.64572900E+02, -.17753400E+03, 0.23136000E+03, 0.11157800E+03, -.13499900E+03, 0.39705700E+04, -.19901500E+04, -.19970600E+04, 0.10234500E+03, -.40339100E+03, -.14242900E+04, -.15345600E+03, -.13101200E+04, -.87456000E+03, -.16355600E+03, 0.87076500E+02, 0.11827500E+03, 0.23275900E+03, 0.23908200E+03, 0.74275200E+02, 0.23227600E+03, 0.43124100E+03, 0.40693600E+03, -.40475900E+02, 0.11077800E+02, -.54529800E+01, 0.84856800E+02, 0.16945600E+02, -.42236000E+02, -.18153900E+03, -.11123400E+03, -.44513500E+01, -.88013300E+03, 0.45373900E+03, 0.32375700E+03, 0.36812700E+03, 0.18220400E+03, 0.17691800E+03, -.99759600E+03, -.21934600E+03, -.10157400E+03, -.16459800E+03, 0.12059200E+03, 0.13936000E+03, 0.21549400E+03, 0.31721400E+03, 0.71560500E+02, 0.49444900E+02, -.20044400E+03, 0.29973000E+03, -.30089700E+02, 0.47570600E+02, -.17791400E+02, 0.25647900E+02, 0.22732400E+02, -.40054200E+02, 0.13603700E+02, 0.48244200E+02, 0.24250400E+03, -.14056700E+04, 0.27921600E+02, -.10727000E+04, 0.12804500E+04, -.68528900E+02, -.62453900E+02, 0.23544300E+02, 0.37610500E+03, 0.12708300E+03, -.41551700E+02, 0.11558800E+02, -.16236400E+02, -.11294200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.30129000E+01, -.16342700E+01, -.14462300E+01, -.36089900E+02, 0.46705600E+01, -.44010200E-01, -.30122400E+01, -.57958000E-01, 0.10078500E+02, -.22137100E+01, 0.24868700E+01, -.16533100E+00, -.31463900E+01, -.81742800E+00, 0.11752900E+01, -.23725400E+01, -.32801600E+01, -.13233400E+01, -.82555500E+00, 0.95003700E+00, -.33841800E+00, -.20921900E+01, -.63559600E+01, 0.17693200E+01, -.62696100E+00, -.91557800E+00, -.12138100E+02, 0.15617000E+01, 0.51553200E+01, -.22628100E+01, 0.33220200E-01, -.17866100E+01, -.19742300E+01, -.18936900E+00, 0.42740800E+00, -.47142500E+00, -.69229200E+00, -.13831100E-01, -.58935700E-01, -.50170400E+00, -.53550600E+00, -.86170000E+00, 0.11394700E+01, -.10947200E+01, 0.18195600E+01, 0.16279200E+00, -.83441800E+01, 0.21602800E+01, -.47184500E+00, -.55087000E+00, 0.77553200E+00, -.34810000E+01, -.76060100E+00, -.29348200E+01, 0.33850000E+00, -.83488200E-01, 0.67303100E+00, 0.59767700E+00, -.11414200E-01, 0.11537200E+01, -.20544400E+00, 0.27396200E+01, -.25199400E+00, 0.17868900E+00, -.77899400E+00, -.33429700E+01, -.13183300E+01, 0.62612200E+03, -.36264300E+03, -.52733000E+03, -.17393900E+03, 0.89974900E+03, 0.12396800E+05, -.62096000E+04, -.62116100E+04, 0.61212600E+03, -.36615700E+03, -.41181900E+04, -.26006600E+04, -.41547800E+04, -.64631000E+03, -.13804600E+04, 0.69427200E+03, 0.79514500E+03, -.10744500E+04, -.55661400E+03, 0.58840700E+03, 0.51260700E+03, 0.17988500E+03, -.20000600E+03, -.98906300E+04, 0.49398300E+04, 0.48986100E+04, -.10666400E+04, -.73326700E+03, 0.39205500E+04, 0.33714000E+04, 0.42517200E+04, 0.16649800E+03, -.29546800E+04, 0.14847600E+04, 0.19246800E+04, -.71055100E+03, -.10893300E+04, 0.17642000E+04, 0.16835000E+04, 0.14145400E+04, -.10046300E+04, 0.18081500E+05, -.90327700E+04, -.93052600E+04, -.17832900E+04, -.37032200E+04, -.38233800E+04, 0.26433000E+04, -.39431500E+04, -.39518000E+04, 0.40320100E+04, -.20220700E+04, -.21757900E+04, 0.14201500E+02, -.10613700E+04, -.98778300E+03, 0.10576500E+04, -.21391900E+04, -.93073800E+03, 0.35074800E+02, -.24885500E+02, -.21215700E+03, 0.19967400E+03, -.29021200E+03, 0.26301000E+02, -.20567800E+02, 0.19934600E+03, 0.14154300E+03, -.23525500E+04, 0.11653700E+04, 0.13558500E+04, -.50449900E+03, -.25320400E+03, 0.10415100E+04, 0.88243800E+03, 0.93962600E+03, -.32166100E+03, -.35392200E+04, 0.17310700E+04, 0.15332500E+04, -.34965700E+03, 0.10232900E+04, 0.10848600E+04, 0.84805000E+03, 0.15954300E+04, 0.63884500E+03, -.64819900E+03, 0.32336000E+03, 0.28354700E+03, 0.10216000E+02, 0.15252300E+03, 0.19261300E+03, -.21053400E+02, 0.74744800E+03, -.55773200E+03, -.19984200E+03, 0.10162400E+03, 0.12791600E+03, 0.66769100E+01, -.50566700E+02, 0.53747200E+02, 0.50568200E+02, 0.24652100E+03, 0.15431100E+03, 0.82815400E+04, -.41175400E+04, -.41305800E+04, -.53786000E+03, -.12724800E+04, -.21693700E+04, 0.16181500E+03, -.24347600E+04, -.14187000E+04, 0.15216200E+04, -.80623000E+03, -.63145500E+03, 0.10048900E+03, -.82741300E+03, -.77980600E+03, -.12701600E+04, -.86368300E+03, -.28932700E+03, -.53621900E+02, -.53776800E+02, 0.18487800E+03, 0.20127400E+02, 0.12850400E+02, -.22506300E+02, 0.24858800E+02, 0.41195700E+02, -.13561400E+03, -.39165300E+03, -.20137000E+03, -.12592300E+04, 0.23133600E+03, 0.73970000E+03, -.44582200E+03, 0.82231300E+02, -.77475100E+02, 0.54664100E+03, -.49754600E+02, -.36537700E+02, -.12065100E+03, -.40675100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10270600E+01, 0.22302200E+00, -.86136600E-01, 0.80823200E+00, -.83213400E+00, -.27203500E+00, -.23464900E+00, -.16503300E+00, 0.74030600E+00, -.23356100E+00, 0.30945500E-01, -.12644200E+00, -.50962000E-02, -.92781100E+00, -.29612000E+00, -.27982400E-01, 0.59368200E-01, 0.34004100E+00, 0.17229100E+00, -.14566300E+00, -.81869400E-01, 0.64436800E+00, 0.20546900E+01, 0.37208900E+00, 0.29596500E+00, -.32482400E+00, -.54465200E+01, 0.22177100E+00, 0.34816100E+01, -.60347300E+00, 0.15119900E+00, -.39964300E+00, -.43091200E+00, -.34286900E-01, 0.95297800E-01, -.12282100E+00, -.19286900E+00, 0.33628800E-01, 0.52239400E+00, 0.16907500E+00, -.29526400E+00, -.13130500E+00, 0.10220800E+00, 0.26668300E+00, 0.93693400E+00, -.65770000E+00, -.40724200E+01, -.18400500E+00, -.59975800E-01, -.15388500E+00, -.32261800E-02, 0.47030600E+00, 0.12247900E+00, -.18090700E-01, 0.21965300E+00, 0.24625000E+00, 0.17831500E-01, 0.44260300E+00, -.10337100E+00, 0.29021100E+00, -.16964200E+00, 0.62297500E+00, 0.32240000E-02, -.27653000E+00, -.14163200E+00, 0.12665300E+00, -.36362600E+00, 0.42244700E-01, -.93882200E+02, -.33143500E+03, -.14852600E+03, -.20901300E+03, 0.81680600E+03, -.40152900E+03, -.34934200E+03, 0.86785300E+02, -.13173100E+03, -.37939500E+03, -.53925000E+03, -.68294700E+03, -.47057200E+03, 0.38601200E+03, -.19482700E+03, -.19985900E+03, 0.84831700E+02, 0.94550700E+02, -.10276000E+03, 0.19126300E+02, -.99915200E+02, 0.96471600E+01, -.44415900E+02, 0.20200100E+02, 0.41435900E+01, -.19996500E+03, -.15560300E+03, 0.10764400E+03, 0.36083000E+03, 0.59784000E+03, 0.14040700E+03, 0.35317600E+03, -.18021100E+03, -.28176500E+03, 0.13776300E+02, 0.21228600E+03, -.10396300E+03, -.19406000E+02, -.19653300E+03, 0.31080700E+03, 0.22232800E+03, -.10624100E+03, 0.41340300E+02, 0.48779900E+02, -.12734000E+03, -.36906100E+02, -.55187200E+03, 0.11304600E+02, -.19172500E+03, -.71082200E+03, 0.35834000E+03, 0.36893400E+03, 0.29934400E+01, 0.96608600E+02, 0.19382400E+03, -.30008300E+01, 0.14000400E+03, 0.16403200E+03, 0.23606400E+03, -.11667100E+03, -.10122700E+03, 0.28532000E+02, -.10573900E+03, -.95945600E+02, -.75506600E+02, -.18546100E+03, -.22428500E+03, 0.16316600E+03, -.80801400E+02, -.97831300E+02, -.31414700E+02, 0.32458000E+02, -.61573800E+01, 0.81230300E+02, 0.10097300E+03, 0.11198200E+03, 0.13624100E+04, -.66851300E+03, -.64203200E+03, -.17918000E+03, -.28168100E+03, -.30205300E+03, 0.27303300E+03, -.30572600E+03, -.31422200E+03, 0.26555400E+03, -.13222800E+03, -.11140300E+03, 0.11131100E+03, 0.84112900E+02, -.96244600E+02, -.18886800E+02, 0.29560400E+01, 0.23542600E+03, 0.77952700E+01, -.54292100E+01, -.18790600E+02, 0.96427600E+01, 0.31443000E+02, -.26955700E+02, -.42647400E+02, -.95845600E+01, -.13429100E+02, -.69202000E+03, 0.34128100E+03, 0.29858400E+03, 0.60708700E+02, 0.47887400E+02, 0.23675300E+03, -.24108100E+03, 0.20762300E+03, -.10044900E+03, 0.76084600E+03, -.36320400E+03, -.38481900E+03, 0.18531500E+03, 0.22933600E+03, -.36611100E+03, -.27219800E+03, -.47540100E+03, 0.33331900E+02, 0.24152900E+01, 0.17694100E+02, -.19627100E+02, 0.74399100E+01, 0.44942200E+01, -.24311500E+02, -.13680300E+01, 0.34007100E+02, -.23070000E+02, -.31247700E+03, 0.46087900E+02, -.21891500E+03, 0.14980500E+03, -.61456800E+02, 0.61829200E+01, 0.18823100E+02, 0.10415700E+03, 0.55493500E+01, 0.54788500E+01, 0.99307900E+01, -.64123400E+02, -.21958200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12433700E+01, -.40879100E+00, 0.21593500E+01, 0.36931700E+01, -.14036000E+01, -.32372900E+00, 0.43217900E+00, 0.94844800E+00, -.27777200E+01, 0.87830300E-01, -.16942000E+01, 0.89355500E+00, 0.17202100E+01, 0.25388800E+00, 0.14907800E+01, 0.17225000E+01, 0.37884100E-01, 0.38934400E+00, 0.83742800E+00, 0.31353800E+00, -.17090000E+00, 0.53580800E+00, -.20480000E+01, 0.16593900E-01, -.30946200E+00, 0.10361900E-01, 0.79447400E+00, 0.41808700E+00, 0.17834200E+01, 0.13409800E-01, 0.62297400E-01, 0.28283000E+00, -.17539000E+00, 0.81639700E-01, 0.17413000E+00, -.23165700E-01, 0.90542500E-01, -.80210700E-01, -.36257900E+00, -.10692900E+00, 0.27969500E+00, -.13415500E+00, 0.28152500E+00, -.32001900E+00, 0.48500100E+00, 0.13825400E+00, -.24423400E+01, 0.92971100E+00, -.10903600E+00, -.64651400E-01, 0.28445300E+00, -.45675600E+00, -.86185000E+00, -.80729600E+00, -.85888900E+00, -.57609600E-01, -.15750400E+00, -.38113800E+00, 0.35781400E+00, 0.15828000E+00, 0.23858400E+00, -.56536400E+00, 0.42808700E+00, -.16030300E+00, 0.10448000E-01, 0.19071300E+00, -.32546500E+00, -.40362300E-01, -.90366500E+00, -.16228600E+03, -.28368300E+01, -.35267400E+03, 0.49930100E+02, -.28753400E+02, 0.69630400E+02, -.21013800E+03, -.37103300E+03, 0.22300500E+03, 0.44142500E+02, -.66188500E+01, -.71688300E+03, 0.33269500E+03, -.19587800E+03, -.16016500E+03, 0.28704300E+03, 0.22950900E+02, -.23103200E+03, -.22705000E+03, -.42880600E+03, -.71176700E+02, -.62871000E+02, 0.35255700E+02, 0.30224200E+01, 0.23840800E+02, 0.13088100E+03, -.18935200E+03, -.19352300E+02, 0.45473500E+03, 0.44285900E+03, 0.50313700E+03, -.26434400E+03, -.36935400E+03, 0.26050800E+03, 0.53935800E+03, -.51484300E+03, -.52318600E+03, -.74546200E+03, 0.61773700E+03, 0.12558600E+04, -.60683100E+03, -.44204000E+03, 0.20833200E+03, -.18092200E+03, -.36204700E+03, -.31861100E+03, -.66123800E+02, -.31322200E+03, -.33291600E+03, 0.17892300E+03, 0.16198400E+03, 0.14893000E+03, 0.60550500E+02, 0.49336400E+02, 0.67023000E+01, 0.28996700E+03, 0.13118300E+03, 0.48387800E+03, -.24049000E+03, -.24236000E+03, -.58456500E+02, -.10441200E+03, -.95799600E+02, -.41148400E+01, 0.80282300E+02, -.21365600E+03, 0.42569000E+03, -.21176600E+03, -.21197600E+03, 0.95960400E+02, 0.88664800E+02, -.23346600E+03, -.92633700E+02, -.18499300E+03, 0.60434500E+02, 0.15456600E+04, -.79943600E+03, -.75322900E+03, 0.11685600E+03, -.25766600E+01, -.58411900E+03, 0.36777100E+02, -.83748600E+03, -.27635200E+03, 0.34552600E+03, -.16944900E+03, -.15128600E+03, 0.22475300E+03, 0.19743700E+03, -.24111100E+03, -.21180700E+03, -.11170200E+03, 0.40181500E+03, 0.11482900E+02, -.11947500E+02, -.25651800E+02, -.68359200E+01, 0.16858200E+02, -.10540700E+01, -.34487700E+02, 0.13103900E+02, -.28283000E+02, -.68079000E+02, 0.37108600E+02, -.59450800E+02, 0.81358000E+02, 0.94764500E+02, 0.33361100E+02, -.48589100E+02, 0.23793500E+01, -.15544100E+03, 0.28890600E+03, -.11334400E+03, -.14050400E+03, 0.26780600E+01, 0.54879300E+02, -.89739800E+02, -.14799700E+03, -.12148600E+03, 0.15347000E+02, 0.58831200E+00, 0.27334100E+02, -.49168300E+02, 0.84060500E+01, 0.88781200E+00, -.31418400E+02, -.25685800E+00, 0.29765000E+02, -.24984100E+02, -.57852700E+02, 0.33421300E+02, -.63935700E+01, 0.37920900E+02, -.44228300E+02, -.32395600E+01, -.10646800E+02, 0.60341300E+02, -.32788500E+02, 0.38685500E+01, 0.77710100E+01, -.46384800E+02, -.22422500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.41819300E+01, 0.14231100E+01, 0.54301900E+01, 0.24675700E+02, -.35482700E+01, -.50034000E+00, 0.94607500E+00, 0.22151000E+01, -.80758900E+01, 0.18160600E+01, -.19349400E+01, 0.98488000E+00, 0.43102000E+01, 0.28991200E+01, 0.67953500E+00, 0.26223200E+01, 0.43376900E+01, 0.72930300E+00, 0.11123700E+01, -.15013700E+01, 0.64499200E+00, 0.36783600E+01, 0.28377000E+01, -.18757000E+01, 0.81620900E+00, 0.13308700E+01, 0.17036600E+02, -.38611100E+01, -.19015400E+02, 0.49724200E+00, -.67758400E-01, -.78468500E+00, 0.90462100E+00, -.32904300E+01, -.77806800E+00, -.16529700E+01, -.47812500E+00, 0.52047700E-01, -.13590000E+01, -.66088900E-01, 0.12060400E+01, -.33036700E+01, 0.13689800E+01, -.10161000E+01, 0.13832300E+00, 0.93120500E+00, 0.34459300E+01, -.77834500E+00, 0.10528200E+01, 0.69572800E+00, -.34640400E+00, -.17172000E+01, -.10074300E+01, 0.13307300E+01, -.29224400E+00, 0.45108200E+00, -.23939300E+01, 0.16769000E+01, -.62986200E+00, -.37044000E+00, 0.32528700E+00, 0.53980000E+00, 0.15906300E+01, -.33290100E+00, -.71727400E+00, -.29728000E+01, 0.21538000E+00, 0.17120000E-01, 0.50480400E+00, 0.21299700E+00, -.52925700E+03, 0.20635700E+03, -.49801900E+04, 0.25258400E+04, 0.23280700E+04, 0.14148100E+03, 0.29668400E+02, 0.12491100E+04, 0.15644500E+04, 0.10850600E+04, 0.57513300E+03, -.25595900E+04, 0.13099400E+04, 0.11663200E+04, 0.20832200E+02, 0.42303000E+02, 0.95852500E+03, -.12070800E+03, 0.14523100E+04, 0.52106600E+03, 0.48528300E+04, -.24390600E+04, -.23125100E+04, 0.70463000E+03, 0.79329700E+03, -.16176700E+04, -.23553200E+04, -.24059400E+04, -.36807300E+03, -.29772700E+03, 0.17215800E+03, 0.40132000E+02, -.30417500E+03, -.54512500E+03, 0.59220000E+03, 0.67251700E+03, 0.13180800E+04, -.52416800E+03, -.81299500E+04, 0.40111900E+04, 0.39495000E+04, 0.18076600E+03, 0.10058100E+04, 0.22340900E+04, 0.88502600E+02, 0.14436800E+04, 0.14285300E+04, -.23900700E+04, 0.11712600E+04, 0.13643500E+04, -.15122100E+03, 0.69102300E+03, 0.71581200E+03, -.39664800E+03, -.92544400E+02, 0.70622900E+03, -.76299800E+03, 0.38361300E+03, 0.58608800E+03, 0.22049700E+03, 0.22601000E+03, 0.31593800E+02, -.60802000E+02, -.81508000E+03, 0.15566600E+03, 0.25230000E+03, -.12396200E+03, -.31145000E+03, 0.60703400E+02, 0.45457000E+02, 0.65365600E+02, 0.43994700E+02, 0.15004600E+03, 0.25129500E+03, -.43039400E+03, 0.26117100E+03, 0.44568900E+03, -.20515800E+03, -.10958500E+03, 0.40614500E+03, -.35108200E+03, 0.10625200E+04, 0.17237100E+03, 0.20853100E+03, -.11338200E+03, -.13139800E+03, -.38899200E+03, -.54864500E+03, 0.44470400E+03, 0.81608600E+03, 0.26588600E+03, -.32995400E+03, -.37892700E+02, 0.31550400E+02, 0.38901600E+02, 0.79520800E+02, -.39693700E+00, -.45995100E+02, -.74872700E+02, -.27443000E+03, 0.24318600E+02, -.22400400E+04, 0.10951800E+04, 0.13034900E+04, -.26328500E+03, -.24429500E+02, 0.76326300E+03, 0.40470500E+03, 0.11632100E+04, 0.28390100E+03, -.15304200E+04, 0.70541700E+03, 0.58470100E+03, 0.42101900E+01, -.12519500E+03, 0.47058300E+03, 0.47161600E+03, 0.43081200E+03, 0.98392700E+02, 0.11609800E+02, -.22606000E+02, -.93226900E+00, -.13761300E+02, 0.28202900E+02, -.96381200E+01, -.23618400E+01, 0.93985900E+00, 0.76909000E+02, 0.11463600E+04, 0.20508500E+02, 0.89809300E+03, 0.80842100E+02, -.50703700E+02, 0.10996200E+03, 0.56776000E+02, 0.16668800E+02, 0.24784300E+03, 0.30681400E+01, 0.11843600E+02, -.15255700E+03, -.62284200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20077700E+01, 0.72511300E+00, 0.35101800E+01, 0.12186700E+02, -.17818000E+01, -.44466700E+00, 0.10422700E+00, 0.74903700E+00, -.37553600E+01, 0.78426600E+00, -.68659800E+00, 0.51909200E+00, 0.17129900E+01, 0.14043900E+01, 0.35873400E+00, 0.51446000E+00, 0.17170500E+01, -.32764200E+00, 0.56619800E+00, -.68463700E+00, 0.22232300E+00, 0.30962800E+01, 0.17139900E+01, -.66310800E+00, 0.67713100E+00, 0.26994900E+00, 0.53347400E+01, -.24080100E+01, -.15333900E+02, -.60559200E+00, -.99458400E-01, -.17887000E+01, 0.19258200E+00, -.27287900E+01, -.74361400E+00, -.10984800E+01, -.24752700E+00, 0.19948500E+00, -.12472600E+01, 0.43226100E-01, 0.99046400E+00, -.12834700E+01, 0.60210900E+00, -.37747200E+00, 0.11131800E+01, -.10802300E+00, -.27090500E+01, -.17344000E+00, -.57311700E-01, 0.10791800E+00, 0.19125800E+00, -.98094900E+00, 0.25176100E+00, -.20116200E+00, 0.52165500E+00, -.45704600E+00, -.28143100E+00, -.30986100E+00, -.15194100E+00, -.76671400E+00, 0.64570800E-01, -.50498900E+00, 0.93386400E-01, 0.79215100E+00, 0.40295400E+00, 0.60716700E+00, 0.78367000E+00, 0.25418100E+00, -.75884700E+00, -.10321700E+01, -.34186800E-01, -.24416900E+03, -.46987500E+04, 0.23388800E+04, 0.24788200E+04, -.16672800E+03, -.66020300E+03, 0.17555600E+04, 0.16748400E+04, 0.16139400E+04, -.59880600E+03, -.90968700E+03, 0.42937900E+03, 0.42954600E+03, 0.41955300E+03, -.75333400E+02, 0.20025200E+03, -.36770200E+03, 0.20224500E+03, 0.13453400E+03, 0.32600600E+04, -.16181200E+04, -.16638900E+04, 0.53265200E+03, 0.10361600E+04, -.15179600E+04, -.19989400E+04, -.12204400E+04, 0.58475900E+03, 0.27207700E+03, -.15270800E+03, -.36137100E+03, 0.89154500E+02, 0.22450400E+03, -.21767100E+03, -.59141700E+03, -.34974700E+03, 0.33043900E+03, -.60685000E+04, 0.30525000E+04, 0.33916300E+04, 0.91520500E+03, 0.52226900E+03, 0.15699400E+04, -.26310300E+03, 0.20388400E+04, 0.74139000E+03, -.24932700E+04, 0.12547000E+04, 0.12970500E+04, 0.11221300E+02, 0.40535200E+03, 0.79885100E+03, 0.38859800E+01, 0.11098400E+04, 0.55332600E+03, 0.18136900E+03, -.87897200E+02, -.30262700E+02, -.45591000E+02, -.40256400E+02, -.57274200E+02, 0.26439900E+03, -.74131200E+02, -.16738300E+03, 0.85150400E+03, -.41090400E+03, -.48195800E+03, 0.20368800E+03, 0.12749300E+03, -.34851400E+03, -.40133700E+03, -.33002800E+03, 0.23755400E+03, 0.21795100E+04, -.11147600E+04, -.95610100E+03, 0.17447500E+03, 0.60307300E+02, -.83982800E+03, -.69754100E+03, -.13448500E+04, 0.10180100E+02, 0.18627600E+03, -.89776500E+02, -.53217400E+02, 0.16648100E+03, 0.35588200E+02, -.15780100E+03, -.10521400E+03, -.20479100E+03, 0.38505300E+03, 0.82481000E+02, -.47455900E+02, -.71408800E+02, 0.73047800E+00, 0.18141400E+02, -.46526700E+02, -.12956600E+02, -.49600100E+02, -.55706200E+02, -.24591300E+04, 0.12323900E+04, 0.11626400E+04, 0.21778700E+03, 0.15741900E+03, 0.77039900E+03, 0.31862000E+03, 0.10353300E+04, 0.12509900E+03, -.16116100E+04, 0.83805300E+03, 0.76896800E+03, -.12805500E+02, -.68668200E+02, 0.64706700E+03, 0.68237800E+03, 0.56336900E+03, -.14768700E+02, 0.24466400E+02, 0.43704000E+01, -.10253300E+03, 0.67997000E+00, -.21172600E+02, -.38050200E+02, -.11042000E+02, 0.32290200E+02, -.53820300E+02, 0.11081900E+04, 0.21408200E+02, 0.90294900E+03, 0.19636400E+02, 0.84201100E+02, 0.64381000E+02, 0.31359900E+01, 0.29497200E+02, 0.30361600E+03, 0.16002000E+02, 0.15522500E+02, -.43998600E+03, -.11406800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.26400400E+01, 0.16766800E+01, 0.21048300E+01, 0.12815000E+02, -.99539200E+00, 0.44317800E+00, 0.99954300E+00, 0.20097600E+01, -.53949600E+01, 0.15111600E+01, -.18799000E+01, 0.96624200E+00, 0.12592000E+01, 0.16109800E+01, -.63558100E+00, 0.36399900E+01, 0.32692900E+01, 0.27656800E+01, 0.11764500E+01, -.23710800E+01, 0.55382200E+00, 0.40932700E+01, 0.54222600E+01, -.38191000E+00, 0.20339600E+01, 0.16842200E+01, 0.49738300E+01, -.22036800E+00, -.45557000E+01, 0.19364600E+00, 0.94487000E+00, -.15009600E+01, 0.14139500E+00, -.97322600E+00, 0.26858800E+00, -.28281500E+01, -.74242700E+00, 0.14865300E-01, 0.10153200E+01, -.22548500E+00, -.61862600E-01, -.10302800E+01, 0.46396000E+00, 0.22423900E+01, 0.22298500E-01, -.68622800E+00, -.10021900E+01, -.73096200E+00, 0.14060800E+01, -.33893300E+00, 0.24566100E+00, 0.67540500E+00, -.22612600E+00, 0.52171600E+00, -.66660900E+00, -.22849300E+00, 0.89126400E+00, -.89838100E+00, 0.16797800E+00, -.10596600E+00, 0.28282600E+00, 0.78278000E-01, 0.67839600E+00, 0.26302000E+00, -.35540600E-01, 0.12018900E+01, 0.69381500E+00, -.30854100E-01, -.15232400E+01, 0.36021800E+00, -.34837500E+00, -.61689200E+00, -.64850700E+04, 0.32520200E+04, 0.33054000E+04, -.90920300E+02, -.78275200E+03, 0.22237100E+04, 0.20828200E+04, 0.23442400E+04, -.56246900E+02, -.24308700E+04, 0.12117400E+04, 0.11496800E+04, 0.41887900E+03, 0.18147700E+02, 0.82793000E+03, -.10574000E+03, 0.87826500E+03, 0.35605000E+03, 0.48223800E+04, -.24084200E+04, -.24039900E+04, 0.89170500E+03, 0.14549400E+04, -.21577800E+04, -.28557300E+04, -.24714300E+04, 0.35978300E+03, 0.21406000E+03, -.11306800E+03, -.37274400E+03, 0.61861800E+01, 0.10074300E+03, -.40635000E+02, -.49020200E+03, -.19871100E+03, 0.85110200E+01, -.10109400E+05, 0.50455900E+04, 0.53606000E+04, 0.10339800E+04, 0.85129700E+03, 0.26578700E+04, -.21372000E+03, 0.30163300E+04, 0.16460200E+04, -.37319000E+04, 0.18627400E+04, 0.19748900E+04, 0.17081700E+02, 0.63914900E+03, 0.11285100E+04, -.51451500E+02, 0.11841700E+04, 0.72440600E+03, -.93331300E+02, 0.50556100E+02, 0.17605100E+03, 0.44928500E+02, 0.10129500E+02, -.62134800E+02, 0.41240600E+03, -.23319200E+03, -.14153800E+03, 0.75276600E+03, -.36631700E+03, -.49593600E+03, 0.23873900E+03, 0.23938400E+03, -.28490600E+03, -.41434000E+03, -.33607200E+03, 0.37902500E+03, 0.21276000E+04, -.10467400E+04, -.85912000E+03, 0.10978700E+03, 0.53606000E+02, -.71610800E+03, -.74480100E+03, -.11713500E+04, 0.16816000E+03, -.33443300E+02, 0.15709100E+02, 0.52921700E+02, 0.26327700E+02, -.13746400E+03, 0.12498700E+03, 0.16602800E+03, 0.48733200E+02, 0.27461100E+03, 0.22302800E+02, -.11663200E+02, -.33721800E+02, 0.21069900E+02, 0.19109200E+02, -.53189900E+02, -.32553200E+02, -.36384200E+02, -.27303800E+02, -.33004700E+04, 0.16365100E+04, 0.16500600E+04, 0.14418100E+03, 0.11743300E+03, 0.10434100E+04, 0.50805800E+03, 0.14483600E+04, 0.40079300E+03, -.19215900E+04, 0.97468400E+03, 0.86558900E+03, 0.53975600E+02, -.51906900E+02, 0.72272000E+03, 0.84996400E+03, 0.63853200E+03, 0.20440300E+02, 0.19165100E+02, -.27112600E+02, -.11506300E+03, 0.89782900E+01, -.44366100E+02, -.31596200E+02, -.68637200E+01, 0.34318200E+02, -.40087900E+02, 0.17560100E+04, 0.45646900E+02, 0.13658600E+04, -.45908000E+02, 0.20349800E+03, 0.67109200E+02, 0.57488900E+01, -.27787800E+02, 0.37335300E+03, -.22949800E+02, 0.13196300E+02, -.55032900E+03, -.15182900E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.53245400E+01, -.23756700E+01, -.40472800E+01, -.27178700E+02, 0.28404100E+01, -.62848500E+00, -.19204800E+01, -.39498800E+01, 0.10833200E+02, -.27860200E+01, 0.34369500E+01, -.17122100E+01, -.42047600E+01, -.28287500E+01, 0.68038000E+00, -.62633800E+01, -.62577400E+01, -.47296200E+01, -.20645800E+01, 0.35056000E+01, -.44953700E+00, -.68388600E+01, -.13255800E+02, 0.10805700E+01, -.34842300E+01, -.29011600E+01, -.91565500E+01, 0.73900300E+00, 0.80748700E+01, 0.47036300E+00, -.16043600E+01, 0.28854800E+01, -.45935900E+00, 0.59199500E+00, -.59384800E+00, 0.60552500E+01, 0.14475000E+01, -.18295300E+00, -.22059400E+01, 0.76736800E+00, 0.87629800E+00, 0.16141100E+01, -.62107300E+00, -.47104100E+01, -.44762000E+00, 0.21239200E+01, -.12165100E-01, 0.12814100E+01, -.22224400E+01, 0.79970300E+00, -.51099100E+00, 0.19132700E+00, -.72693900E+00, 0.75412700E-01, 0.61780700E-01, 0.50117000E+00, -.11687600E+01, 0.60935100E+00, -.34970100E+00, -.24675600E+00, -.28438600E+00, -.10145300E+01, 0.14200900E+00, 0.14226200E+01, 0.18104100E+01, 0.11064600E+01, 0.17851500E+01, 0.17201500E+00, -.15264900E+01, -.25731800E+01, -.95192500E+00, 0.70175100E+00, 0.11990900E+01, 0.54199800E+02, -.21697400E+03, 0.22101200E+03, 0.34192200E+03, -.66223000E+03, -.10427200E+03, -.12065700E+04, -.35084000E+03, 0.10024700E+04, -.41372600E+03, -.53980800E+03, -.57377300E+02, 0.19735000E+03, -.37770500E+03, -.30534000E+03, 0.26928300E+03, 0.31401300E+03, 0.76226600E+03, -.42112000E+03, -.26574700E+03, -.48227400E+03, -.52147800E+03, 0.56821300E+03, 0.12448800E+03, 0.55179200E+03, -.21965600E+03, 0.89317500E+02, -.16827300E+01, 0.10582600E+03, -.39208400E+03, 0.44264200E+02, 0.10643900E+03, 0.40556400E+03, 0.54878500E+03, 0.16389700E+03, 0.25768800E+04, -.13853000E+04, -.17898700E+04, -.22966100E+03, -.13736000E+03, -.97083100E+03, -.21298400E+03, -.21767500E+04, -.83597500E+03, 0.99534900E+03, -.53140800E+03, -.46692400E+03, -.34047500E+03, -.16284300E+03, -.88374900E+01, 0.15113700E+03, -.19926500E+03, -.16437600E+03, -.24496600E+03, 0.13159900E+03, 0.17891600E+03, 0.10280900E+03, -.36320400E+02, -.41339800E+02, -.52223300E+03, -.82531700E+03, -.29317500E+02, -.77642400E+03, 0.37891900E+03, 0.34412500E+03, -.31116700E+03, 0.27413600E+02, 0.54095900E+03, 0.39068200E+03, 0.65878400E+03, 0.12881100E+03, -.27466800E+04, 0.14994600E+04, 0.13457600E+04, -.47458800E+03, 0.22512000E+02, 0.11175400E+04, 0.20768300E+03, 0.21118400E+04, 0.42570300E+03, 0.93892700E+03, -.48134800E+03, -.54968500E+03, -.14120200E+03, -.34490900E+03, -.19914500E+03, -.72086300E+02, -.78473400E+03, -.40921000E+03, -.12661900E+02, 0.23868300E+02, 0.41860200E+02, -.40530900E+02, -.27527000E+01, 0.38027900E+02, 0.13837100E+03, 0.47985600E+01, -.24652300E+02, 0.14006200E+04, -.73992000E+03, -.59787500E+03, -.20991400E+03, -.29258000E+03, -.51162000E+03, -.23476900E+03, -.62474700E+03, -.57247200E+03, 0.13403500E+04, -.75269700E+03, -.75032900E+03, 0.35062500E+03, -.60352700E+02, -.64222600E+03, -.65178800E+03, -.56012500E+03, -.38243000E+03, 0.35686800E+02, -.12508200E+02, 0.96788700E+01, -.11402800E+01, 0.94547900E+01, -.89495200E+01, -.18509600E+02, 0.79875400E+00, -.34566500E+02, -.48094200E+03, -.58890000E+02, -.41724600E+03, 0.32305500E+03, -.35270100E+03, 0.85434100E+02, 0.12112900E+03, 0.80721800E+02, 0.34052300E+03, 0.76428000E+02, 0.11123200E+02, 0.34114100E+03, -.37294400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20056100E+01, 0.10182900E+01, 0.96806200E+00, 0.24216200E+02, -.29634000E+01, 0.31164800E+00, 0.20200000E+01, -.23937700E+00, -.62929100E+01, 0.15679100E+01, -.11789600E+01, -.57733600E+00, 0.49529300E+01, 0.17774300E+01, 0.84860200E+00, 0.27085700E+01, 0.28311700E+01, 0.11328800E+00, 0.42275500E+00, -.16508000E+00, 0.39894000E+00, 0.25105400E+01, -.31978300E+00, -.14926600E+01, -.25758500E+00, 0.32805800E+00, 0.98676100E+01, -.21887200E+01, -.13493200E+02, 0.11193700E+01, -.61102800E+00, -.91868700E-02, 0.18381400E+01, 0.19378000E+01, -.10477500E+01, 0.12796900E+01, 0.70151500E+00, -.29018300E+00, -.24201300E+01, -.25839700E+00, 0.13725700E+01, 0.29395600E+00, 0.10119400E+00, 0.15360400E+01, -.19376800E+01, 0.10573800E+00, 0.15132000E+02, -.15062700E+01, -.37111000E-01, 0.61746900E+00, -.26687100E-01, 0.38863000E+01, 0.80610700E+00, 0.33770700E+01, -.89227500E-01, -.10592700E+01, 0.41129000E+00, 0.25731300E+01, -.49352900E+00, -.22548100E+01, 0.99866000E+00, 0.11288500E+01, -.11579900E+01, 0.48893400E-02, -.69903100E+00, 0.14270800E+01, 0.58575900E+00, -.44368000E+00, 0.17123900E+01, -.31504600E+00, 0.42892200E+00, -.43501800E+00, 0.67364600E+00, -.33687800E+00, -.18944500E+03, 0.17987500E+03, 0.79817800E+03, 0.12974100E+03, 0.55273400E+03, -.24429400E+03, -.18723900E+03, 0.40924600E+04, -.20174800E+04, -.20110300E+04, -.20656100E+03, -.58313700E+02, -.14871100E+04, -.31521600E+03, -.95008100E+03, -.28143200E+03, -.14390900E+04, 0.70937400E+03, 0.78128600E+03, -.92637000E+03, -.70294000E+03, 0.80849800E+03, 0.67542500E+03, 0.13124800E+04, 0.30685500E+03, -.61265000E+03, 0.32453600E+03, 0.63002600E+03, -.21400900E+03, -.41292200E+03, 0.24602000E+03, 0.10592000E+04, 0.10830600E+04, 0.18489100E+02, 0.54449500E+04, -.27528300E+04, -.33097100E+04, 0.41168800E+03, 0.55859300E+03, -.16991600E+04, 0.39863300E+03, -.10325000E+04, -.83339800E+03, 0.40507500E+04, -.20315700E+04, -.21029100E+04, 0.13599300E+03, -.32189400E+03, -.13791200E+04, -.90257700E+03, -.53889000E+03, -.50572900E+03, -.44630800E+03, 0.22520800E+03, 0.14284100E+03, -.16388400E+02, 0.17462700E+03, 0.20350000E+03, -.55038700E+03, 0.20489100E+03, 0.25396200E+03, -.86367300E+03, 0.42383600E+03, 0.51171800E+03, -.49351700E+03, -.48524400E+03, 0.49534500E+03, 0.69545100E+03, 0.75387800E+03, -.38263000E+03, -.35687300E+04, 0.18017400E+04, 0.15793900E+04, -.26164000E+03, 0.10840300E+03, 0.95906400E+03, -.11150700E+02, 0.15176000E+04, 0.34292000E+03, 0.42273000E+03, -.21325100E+03, -.29432100E+03, 0.78050500E+01, -.37469200E+02, -.25792800E+03, -.20383400E+03, -.59172600E+03, -.50696000E+03, 0.10386600E+03, -.44961900E+02, -.10171200E+02, -.57613900E+02, 0.18454700E+02, 0.47892800E+02, 0.94056800E+02, -.57786200E+02, -.11313700E+02, 0.19498000E+04, -.97729700E+03, -.91302900E+03, 0.38643300E+03, 0.28547300E+03, -.78001000E+03, -.20132700E+03, -.56430300E+03, -.22078800E+03, 0.96099300E+03, -.52547200E+03, -.44696200E+03, 0.62489600E+02, -.22664600E+03, -.17844600E+03, -.27501800E+03, 0.14539900E+03, -.44308300E+03, 0.26455100E+02, 0.54759300E+02, 0.81037200E+02, -.18101000E+02, 0.71371900E+02, 0.61787700E+02, -.14007900E+02, -.95429400E+02, -.13310700E+01, -.89556400E+03, -.60655600E+02, -.52949600E+03, 0.22872300E+03, -.48546500E+03, 0.29050500E+03, -.42711000E+02, 0.19335800E+03, 0.25961400E+03, 0.53198800E+02, -.76289000E+00, 0.49991700E+03, -.69829800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23638700E+01, -.49366000E+00, -.35763600E+01, -.13607100E+02, 0.24352300E+01, 0.37047600E+00, -.11049300E+01, -.13098900E+01, 0.44623800E+01, -.81222300E+00, 0.13203500E+01, -.70639600E+00, -.19529400E+01, 0.10939100E+00, 0.12453600E+00, -.94712000E+00, -.92677300E+00, -.10292400E+01, -.43887200E+00, 0.99142000E+00, -.18946000E-01, -.27457800E+01, -.78182800E+01, 0.11516600E+00, -.10305100E+01, -.19251900E+00, -.31317200E+01, 0.30871200E+00, 0.39425400E+01, 0.76135400E+00, -.59389700E+00, 0.93484800E+00, -.10435400E+00, 0.17937300E+01, -.16702000E+00, 0.24969200E+01, 0.10259800E+01, -.17633600E+00, -.10343500E+01, 0.92268900E-02, 0.52871200E+00, 0.92706900E+00, -.15274900E-01, -.74507100E+00, -.18682600E+01, 0.24055200E+00, 0.25203500E+01, 0.62807100E+00, 0.22823400E+00, 0.29699000E+00, -.46002700E-01, -.53182900E-02, -.45661000E+00, 0.56230500E+00, -.60835000E+00, 0.33510000E+00, 0.70200000E-01, -.11801700E-01, -.61991600E-01, -.34872000E+00, 0.12124300E+00, 0.24953300E+00, 0.13035700E+00, -.20471200E+00, -.38961700E+00, -.21164700E+00, 0.11368800E+00, 0.15770200E+00, 0.24068000E+00, 0.41892700E+00, -.92348200E-02, -.45660500E+00, 0.66832200E+00, -.74763800E-01, 0.49562500E+00, 0.19649800E+03, 0.10300600E+03, -.36792500E+03, -.89508800E+03, -.35186800E+03, 0.29371700E+03, -.82350300E+03, 0.40835800E+03, 0.37929600E+03, 0.69364500E+01, 0.16748800E+03, 0.32568800E+03, 0.93964800E+02, 0.26331700E+03, 0.17300700E+03, 0.98529800E+03, -.48704700E+03, -.47845300E+03, -.86661000E+02, -.33103800E+03, -.93214600E+02, 0.36757800E+03, -.23877800E+03, -.55117900E+03, 0.13012200E+03, -.72229000E+02, -.19215700E+03, 0.43909300E+01, 0.16887000E+03, -.83726500E+02, -.39893800E+03, -.30796400E+03, 0.74913200E+02, -.25027100E+04, 0.12650600E+04, 0.13572700E+04, -.15350700E+03, 0.13153000E+03, 0.60571700E+03, -.81210800E+03, 0.11531100E+03, 0.46799000E+03, -.18343400E+04, 0.91880700E+03, 0.97126200E+03, -.19813000E+03, 0.21113500E+03, 0.60743300E+03, 0.21773200E+03, 0.31855300E+03, 0.27072000E+03, 0.15014400E+03, -.74679200E+02, -.14441500E+02, -.30807300E+01, -.23146900E+02, -.11592700E+03, -.47555900E+02, -.27995300E+03, -.80438500E+02, 0.46785900E+02, -.14100000E+02, -.77465800E+02, 0.11217300E+03, 0.19482400E+03, -.59253500E+02, -.20804600E+03, -.14818800E+03, 0.19474200E+03, 0.14157800E+04, -.70577200E+03, -.62313600E+03, -.13415400E+03, -.31018600E+03, -.24427000E+03, 0.14623200E+03, -.29111200E+03, -.25725400E+03, 0.58810100E+02, -.28109100E+02, -.95150500E+01, -.80310800E+02, -.11356500E+03, 0.93336400E+02, 0.15565300E+03, 0.12227800E+03, 0.40318000E+02, -.44736000E+02, 0.20233400E+02, 0.17033000E+02, 0.19653500E+02, 0.73369400E+00, -.32751000E+01, -.17687400E+02, -.25045700E+02, -.43423300E+01, -.12519300E+04, 0.62717800E+03, 0.65046900E+03, -.61307800E+02, -.21480400E+02, 0.36632000E+03, -.30288100E+03, 0.24204900E+03, 0.16618200E+03, -.49293000E+03, 0.27313800E+03, 0.20811300E+03, 0.17573400E+03, 0.23360900E+03, 0.46109000E+02, -.23309000E+00, -.82117400E+02, 0.21084700E+03, -.68277500E+01, -.12457900E+02, -.21632300E+02, -.81444300E+00, -.86667300E+01, -.10609100E+02, 0.25250400E+01, 0.22333300E+02, -.11137000E+02, -.41311600E+03, 0.38563100E+02, -.22773300E+03, -.13334200E+02, -.42093100E+02, -.27045900E+02, 0.32726200E+02, -.64310100E+02, -.11410300E+03, 0.14485400E+01, 0.22221800E+01, 0.14723600E+02, 0.19507300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.26033800E+01, 0.11626200E+01, 0.45718200E+01, 0.12075600E+02, -.37840300E+00, 0.21002600E+00, 0.11502500E+01, 0.17263500E+01, -.66756500E+01, 0.13059400E+01, -.22472400E+01, 0.12539900E+01, 0.20186300E+01, 0.16065900E+01, -.16363100E+00, 0.27544900E+01, 0.32098500E+01, 0.23564400E+01, 0.14510900E+01, -.17106300E+01, 0.38040200E+00, 0.47523200E+01, 0.43901600E+01, -.49964900E+00, 0.16584200E+01, 0.98500900E+00, 0.24785200E+01, -.63465700E+00, -.51468900E+01, -.28368600E+00, 0.28864800E+00, -.16889500E+01, 0.31685000E+00, 0.30175200E+00, -.79477700E-02, -.25581400E+01, -.70174000E+00, 0.16867600E+00, 0.12790400E+01, -.12924700E+00, 0.24499000E-01, -.60937100E+00, -.33840200E-01, 0.27746100E+01, -.29526500E+00, -.10419700E+01, 0.11408400E+01, -.68823100E+00, 0.12584100E+01, -.40978200E+00, 0.15820100E+00, 0.12393900E+01, -.78847400E-01, 0.28689500E+00, -.57941200E+00, -.25966900E+00, -.10926100E+00, 0.72096900E+00, 0.67255000E-01, -.24964400E+00, 0.64574900E+00, 0.50086200E+00, 0.11281100E+01, -.76335400E+00, -.45144300E+00, 0.27578200E+00, -.62253600E+00, -.30080000E+00, -.23852400E+00, 0.13372500E+01, 0.29363900E+00, 0.26202000E+00, -.15474300E+00, 0.11418500E+00, 0.73941100E+00, -.14497100E+00, -.85964200E+03, -.18997000E+03, -.83623900E+03, 0.15860100E+03, 0.20071500E+03, -.38768800E+04, 0.19158000E+04, 0.18675400E+04, 0.30689800E+02, 0.72241600E+02, 0.15532400E+04, 0.63432700E+03, 0.10667000E+04, 0.22811700E+03, 0.16625400E+04, -.82268300E+03, -.80473400E+03, 0.61383800E+03, 0.56659100E+03, -.81133300E+03, -.35450600E+03, -.11639100E+04, -.27974600E+03, -.42238000E+03, 0.19916000E+03, -.74924100E+02, 0.35885500E+03, 0.54633900E+03, -.65073800E+01, -.75108900E+03, -.64757700E+03, 0.21710700E+03, -.33506100E+04, 0.16991900E+04, 0.18587200E+04, -.27722700E+03, -.77180600E+03, 0.11324600E+04, -.57065500E+03, 0.16247700E+04, 0.58488000E+03, -.35272800E+04, 0.17686700E+04, 0.18672900E+04, 0.18269800E+03, 0.58077400E+03, 0.89783600E+03, 0.27657600E+03, 0.44067500E+03, 0.61746500E+03, 0.32149400E+03, -.16323200E+03, -.36872800E+02, 0.14835700E+03, 0.88605000E+00, -.29872100E+03, 0.18448600E+03, -.16496200E+03, -.15190600E+03, 0.18373400E+03, -.93173200E+02, -.20495500E+03, 0.30138600E+03, 0.36477500E+03, -.13948700E+03, -.21475600E+03, -.32169700E+03, 0.26597300E+03, 0.22348500E+04, -.11245600E+04, -.96815400E+03, 0.21051400E+03, 0.89695200E+02, -.50406200E+03, 0.38221700E+03, -.10434800E+04, -.23097200E+03, -.28421700E+03, 0.14358300E+03, 0.18221300E+03, -.14862000E+02, -.10721200E+03, 0.40279000E+03, 0.34455500E+03, 0.66843900E+03, 0.30774300E+03, -.14958400E+03, 0.71046100E+02, 0.54948700E+02, 0.71141100E+02, 0.45729300E+01, -.31805400E+02, -.13023800E+03, -.11010400E+02, 0.46879200E+02, -.80156700E+03, 0.40141200E+03, 0.39788100E+03, -.34003400E+03, -.48186800E+03, 0.48338000E+03, 0.11059700E+03, 0.88520300E+03, 0.19138400E+01, -.73434200E+03, 0.39971800E+03, 0.29002200E+03, -.56677400E+02, -.39203000E+02, 0.12786000E+03, 0.66860100E+02, -.17354100E+02, 0.28159000E+03, -.39488900E+02, -.39383800E+02, -.76026300E+02, 0.14828700E+02, -.43470900E+02, -.28621900E+02, 0.21072500E+02, 0.50113400E+02, 0.17231700E+02, 0.53881900E+03, 0.84628000E+02, 0.24778500E+03, -.21423300E+03, 0.36216400E+03, -.12230100E+03, -.22817600E+02, -.12772000E+03, -.39598300E+03, -.10462600E+03, -.33034400E+01, -.38893700E+03, 0.27010400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17561600E+01, -.11230100E+01, -.36478600E+00, -.20573000E+02, 0.15950700E+01, 0.64536100E+00, -.11056400E+01, -.72492200E+00, 0.44566800E+01, -.77964600E+00, 0.25238400E+01, -.58272300E+00, -.36079600E+01, -.98892500E+00, 0.15149600E+00, -.12855800E+01, -.25721400E+01, -.10933500E+01, -.69333600E-01, 0.92572800E-01, -.27252700E+00, -.72398900E+00, -.22067100E+01, 0.96842100E+00, -.25010200E+00, 0.45930700E+00, -.78020400E+01, 0.62733100E+00, 0.26458900E+01, -.12254200E+01, -.29348900E+00, -.32228400E+00, -.13327500E+01, 0.12101500E+01, -.54014700E+00, -.67663500E-01, -.12228000E+01, 0.68687600E-01, 0.30589200E+00, -.56791400E-01, -.28569400E+00, -.10730300E-01, -.13843400E+00, 0.54189600E+00, 0.21069600E+00, -.27938700E+00, -.53370000E+01, 0.57115800E+00, 0.11191800E+01, -.10821800E+00, 0.35873900E-01, -.57030400E+00, -.73927900E+00, -.19386700E+01, -.10595700E+00, 0.12310700E+01, -.86544800E+00, 0.20240700E-01, 0.18203600E+00, 0.79157000E+00, -.38113000E-01, -.51943600E+00, 0.17865000E+01, -.62038000E-01, 0.84220200E+00, 0.57832400E+00, 0.29279400E-01, -.27548500E-01, -.13415400E+01, -.30428100E+00, -.37386900E+00, 0.18873400E+00, 0.37520700E+00, 0.84705300E-02, 0.21273900E+00, -.85776700E+00, 0.65344200E+00, -.53120600E+03, -.88831400E+03, -.69736200E+03, 0.68612900E+02, -.14100500E+03, 0.68394200E+02, 0.71465500E+02, -.23963300E+00, 0.77056000E+02, 0.27777000E+01, -.30215900E+03, 0.12050900E+03, 0.22398800E+03, 0.16392800E+04, -.81507000E+03, -.81325300E+03, -.10208700E+03, -.43635500E+03, -.54240100E+02, 0.46659000E+03, 0.10455300E+03, -.65903400E+03, 0.48930000E+03, -.24546300E+03, -.21054800E+03, -.27201000E+03, 0.11955800E+03, -.83802700E+02, -.16247700E+03, -.22958900E+03, 0.22509700E+02, 0.96762000E+03, -.47530000E+03, -.48219100E+03, -.24881400E+03, -.12534800E+03, -.79321900E+03, -.12056400E+04, -.15032200E+04, -.10910500E+03, -.57522300E+03, 0.28799700E+03, 0.29246200E+03, -.24467900E+03, -.35697300E+02, 0.32694800E+03, 0.21786400E+03, -.15172200E+03, 0.39450100E+00, 0.10637100E+03, -.53796800E+02, -.47636400E+02, 0.14487400E+03, -.18947100E+02, -.17486200E+03, -.34437300E+03, -.54936800E+03, -.40934200E+02, -.33346600E+03, 0.17196600E+03, 0.16282800E+03, -.74693500E+02, 0.15213300E+03, 0.19906100E+03, 0.71366900E+02, 0.11434600E+03, 0.16479000E+03, 0.11653700E+04, -.59042400E+03, -.56032400E+03, -.26224300E+03, -.39016700E+03, -.93419900E+02, 0.14105000E+03, 0.27004900E+03, -.26725500E+03, 0.29158600E+03, -.14493900E+03, -.15486300E+03, -.61673400E+02, -.12440300E+03, -.48245600E+02, -.52574300E+02, -.17619400E+03, -.53888800E+01, -.84543700E+02, 0.40622300E+02, 0.47922500E+02, -.75439400E+01, -.13972700E+00, 0.15513200E+02, 0.28638400E+02, 0.66040400E+01, -.15792700E+00, 0.24856900E+03, -.11960300E+03, -.10323500E+03, -.17737200E+03, -.12350100E+03, -.25422100E+03, -.58989100E+03, -.48264600E+03, -.10493900E+03, -.40940500E+03, 0.21161700E+03, 0.19393600E+03, 0.23240900E+03, 0.19743400E+03, -.52855900E+02, -.26473300E+03, -.15900800E+03, 0.13081100E+03, 0.50272300E+00, -.23992600E+02, -.22507200E+02, 0.39192900E+01, -.69249300E+01, -.22904800E+02, -.84390100E+00, 0.32838700E+02, -.43784200E+02, -.63513100E+03, -.35911300E+02, -.47378000E+03, 0.12536000E+03, -.29049400E+03, -.89885900E+02, 0.89746200E+02, -.19344200E+02, -.20231200E+02, 0.31864600E+02, 0.25039200E+01, 0.44081500E+03, 0.42109900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.78052400E+00, 0.23231600E+00, 0.11069100E+01, 0.42682400E+01, -.49006800E+00, -.23678200E+00, 0.55565600E-02, 0.53342900E+00, -.12350100E+01, 0.24862700E+00, -.56711600E+00, 0.35613100E+00, 0.57358800E+00, 0.53898200E+00, -.65479800E-01, 0.11825300E+00, 0.74435300E+00, 0.21097700E+00, 0.14010800E+00, -.35897400E+00, 0.91960500E-01, 0.79425300E+00, 0.15484600E+01, -.26579100E+00, 0.27330900E+00, 0.20180900E+00, 0.29278900E+01, -.43949200E+00, -.32436900E+01, 0.82056500E-01, 0.22376600E-01, -.20592100E+00, 0.22046600E+00, -.30762500E+00, -.16459800E+00, -.42780000E+00, -.21082900E+00, 0.50092200E-01, -.18867000E+00, -.44613300E-01, 0.50685200E-01, -.15073400E+00, 0.30344700E-01, 0.28644200E+00, 0.46242900E-01, 0.61526800E-01, 0.90780900E+00, -.33476000E+00, 0.56465600E-01, 0.17336100E+00, 0.20945800E-01, 0.29806500E+00, 0.79826300E-01, 0.31954100E+00, 0.13658800E+00, -.18373300E+00, 0.21655100E+00, 0.20998300E-01, -.15666200E-01, -.25862300E+00, 0.94798600E-01, 0.81916000E-01, -.22238400E+00, 0.17274100E+00, 0.21408400E+00, 0.83780500E+00, 0.21994700E+00, -.14465900E-01, -.21001300E+00, -.16951700E+00, -.11204300E+00, -.86701400E-01, 0.14402200E+00, -.49072700E-01, -.99169300E-01, -.90304200E-01, -.50413000E-01, 0.24156800E-01, 0.18185000E+03, -.20880600E+02, -.10863300E+03, 0.69947500E+01, -.11003500E+01, 0.62441400E+01, -.10666600E+01, -.36374200E+02, 0.25559100E+01, -.17545200E+02, 0.45235500E+02, -.76384700E+01, -.48610300E+02, 0.23723400E+02, 0.20896700E+02, -.14676100E+02, 0.62805700E+02, 0.25049500E+02, -.12929700E+03, 0.34741800E+02, 0.10140900E+03, -.42326200E+02, 0.22451000E+02, 0.56794900E+02, 0.12035700E+01, 0.11506100E+02, 0.17819500E+02, 0.66854900E+02, 0.73542000E+02, 0.12838100E+02, 0.24617100E+03, -.12529500E+03, -.15196500E+03, 0.75186400E+02, -.44468200E+01, -.11389900E+03, 0.13930300E+03, -.59770800E+02, -.11993100E+03, 0.90579700E+02, -.46133200E+02, -.61482500E+02, 0.17425700E+02, 0.12366400E+02, -.24962900E+02, -.37132500E+02, 0.45271000E+02, 0.60482600E+01, -.25614300E+02, 0.12978200E+02, -.52848100E+01, 0.86785900E+01, 0.16436900E+02, -.66643200E+01, -.20704400E+02, -.16650700E+02, 0.27313200E+02, -.13089400E+02, 0.66756500E+01, 0.23802000E+02, -.16831400E+01, -.59512800E+01, 0.19289800E+02, 0.19234600E+02, 0.14898600E+02, -.48505600E+01, -.38448800E+03, 0.19362400E+03, 0.16640400E+03, 0.36534300E+02, 0.95840000E+02, 0.84707800E+02, -.74746800E+02, 0.99764700E+02, 0.11944000E+03, 0.48368200E+02, -.24324000E+02, -.28800600E+02, 0.12781100E+02, -.68364900E+01, -.44594100E+02, -.44956100E+02, -.12496200E+03, -.18086600E+02, 0.13867100E+02, -.65387400E+01, -.53269900E+01, -.77579500E+01, 0.27423000E-01, 0.45939900E+00, 0.94885800E+01, -.12716900E+02, -.47185500E+01, 0.24277100E+03, -.12142900E+03, -.12973800E+03, 0.22033300E+02, -.21241200E+02, -.85893200E+02, 0.65554900E+02, -.58242000E+02, -.75723700E+02, 0.13174300E+03, -.68343200E+02, -.54569100E+02, -.35090900E+02, -.68694400E+02, -.22087500E+02, 0.32330100E+01, 0.11347700E+02, -.84178100E+02, 0.45174900E+01, -.41375000E+00, -.37349300E+01, -.38590300E+01, 0.68692300E+01, 0.22078400E+01, -.19039700E+01, -.47064300E+01, -.12945200E+01, 0.10458600E+03, -.43101600E+01, 0.56548200E+02, -.23793800E+01, -.52863600E+01, 0.24430500E+02, -.12359600E+01, 0.20232300E+01, 0.37945100E+02, 0.83981700E+01, 0.56316700E+00, -.89678200E+01, -.11501500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37286300E+01, -.14757300E+01, -.55934100E+01, -.20598900E+02, 0.23729400E+01, 0.10553700E+01, -.92827700E-01, -.22328500E+01, 0.60928100E+01, -.10136600E+01, 0.30959600E+01, -.15897100E+01, -.38748100E+01, -.17727400E+01, 0.48496300E+00, -.11833900E+01, -.34025200E+01, -.13701500E+01, -.78026400E+00, 0.16862700E+01, -.26793500E+00, -.48060400E+01, -.10887400E+02, 0.55029700E+00, -.15854900E+01, 0.11800400E-01, -.63352700E+01, 0.15807700E+01, 0.11276500E+02, 0.12115100E+01, -.49824800E+00, 0.19140000E+01, -.51207200E+00, 0.15440800E+01, 0.34391700E+00, 0.30886500E+01, 0.10995400E+01, -.25790000E+00, -.71352300E+00, 0.17183500E+00, 0.45628200E+00, 0.15557500E+01, -.29117900E+00, -.42104100E+00, -.94450300E+00, 0.83664300E+00, 0.67800600E+00, 0.60081700E+00, 0.51888300E-01, -.59700000E+00, 0.11362000E+00, -.80792800E+00, -.22367600E+00, 0.25251200E+00, -.46238800E+00, -.17471400E+00, 0.67745600E+00, 0.26091600E+00, 0.50580800E-02, 0.23273400E-02, 0.18522900E+00, 0.11966700E+01, 0.13577700E+01, 0.93254100E-01, -.69347800E+00, 0.96049200E+00, -.35470700E+00, -.51407100E-01, 0.76802900E+00, 0.39801500E+00, 0.22260200E-01, 0.61477800E+00, 0.25545700E+00, -.36571100E+00, 0.89195800E+00, -.87697200E+00, 0.62064900E+00, 0.15343200E+01, -.26710800E+01, 0.42407000E+03, 0.21017000E+03, -.17978600E+04, 0.92602900E+03, 0.88835300E+03, -.53790100E+02, -.21715900E+02, 0.79431000E+03, 0.64027400E+03, 0.89172500E+03, -.10889100E+03, 0.10477500E+04, -.52585300E+03, -.52639400E+03, 0.35726100E+03, 0.36417800E+03, -.61720800E+03, -.54853600E+03, -.12665700E+04, 0.14651600E+03, -.36532600E+03, 0.18244300E+03, 0.99309400E+02, 0.40845100E+03, 0.25677300E+03, 0.26343800E+02, -.22155700E+02, 0.50412000E+02, 0.10800800E+03, -.46996200E+04, 0.23358700E+04, 0.24154100E+04, 0.14524000E+03, 0.46325300E+03, 0.11843900E+04, -.28150700E+03, 0.12026600E+04, 0.10530000E+04, -.16562100E+04, 0.82161300E+03, 0.84548600E+03, 0.11870100E+03, 0.45253500E+03, 0.31132900E+03, -.92863100E+02, 0.47234800E+03, 0.40272000E+03, -.98436300E+01, 0.79583600E+01, 0.19877000E+02, -.10890400E+03, 0.33634500E+02, -.34579300E+02, 0.18945400E+03, -.69760700E+02, 0.57299100E+02, 0.77287400E+03, -.37984400E+03, -.40241800E+03, 0.38647400E+03, 0.20696500E+03, -.40395500E+03, -.32553500E+03, -.45643500E+03, 0.60305200E+02, 0.78221400E+03, -.34062800E+03, -.37318000E+03, 0.18480700E+03, 0.64580300E+02, -.15180100E+03, 0.35603500E+03, -.33191400E+03, -.12674600E+03, -.31061700E+03, 0.15360100E+03, 0.17506700E+03, -.73007500E+02, -.56561400E+02, 0.20398000E+03, 0.18863600E+03, 0.19327100E+03, 0.13022200E+03, 0.56995900E+02, -.26823100E+02, -.33747400E+02, 0.62863800E+02, -.21432800E+01, -.49670000E+02, -.11063900E+03, -.13571200E+03, -.14893600E+01, -.15650700E+04, 0.77569100E+03, 0.79165800E+03, 0.20662700E+02, 0.11766700E+03, 0.45389200E+03, 0.14231000E+03, 0.45927400E+03, 0.37907400E+03, 0.28412000E+03, -.13053300E+03, -.14121200E+03, -.26980700E+03, -.10396600E+03, -.58899500E+02, 0.45673800E+02, -.39256500E+01, -.10936500E+02, -.14242000E+02, -.17861000E+02, -.14728500E+02, -.12526800E+02, -.13664100E+02, 0.25123300E+02, 0.83827300E+01, -.17331500E+02, 0.61428800E+02, 0.44762200E+03, 0.48164800E+02, 0.41591400E+03, -.21031700E+03, 0.13389700E+03, 0.79898400E+02, -.18851100E+02, -.91809900E+02, -.30506400E+03, -.35943300E+02, 0.12424100E+01, -.17890700E+03, 0.27451800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12445600E+02, 0.56369200E+01, 0.12583600E+02, 0.96907500E+02, -.13152800E+02, -.11798800E+01, 0.64975000E+01, 0.36837200E+01, -.27363500E+02, 0.61374800E+01, -.88839600E+01, 0.34006800E+01, 0.20362200E+02, 0.46029700E+01, -.11288900E+01, 0.33274500E+01, 0.10109200E+02, 0.37251300E+01, 0.16168300E+01, -.37896100E+01, 0.20413100E-01, 0.19152200E+02, 0.38509700E+02, -.26704800E+01, 0.53164200E+01, -.16147300E+01, 0.96262500E+01, -.87496300E+01, -.44579800E+02, -.45922900E+01, 0.34443000E+01, -.93841300E+01, 0.30733900E+00, -.14643400E+02, 0.26620100E+01, -.79487800E+01, 0.38694500E+01, 0.21882500E+01, 0.29674700E+01, -.22673900E+00, -.21654800E+01, 0.45688300E+00, -.19907000E+01, 0.30197100E+01, -.33855800E+01, -.19102600E+01, 0.90618500E-01, -.40760800E+01, -.81824500E+00, 0.76669700E-01, -.16295100E+01, 0.94983900E+01, -.89828500E+00, -.33387500E+00, -.97002400E+00, 0.10264000E+01, -.24815700E+01, -.22592400E+01, -.23339900E+01, -.67778400E+00, -.70029700E+00, 0.30036500E+01, -.43936600E+01, 0.27107600E+00, -.11594300E+01, 0.10116300E+02, -.75848500E+00, 0.27893100E+00, 0.49160600E+01, 0.29296500E+01, 0.90283700E+00, -.11842700E+01, 0.25997300E+00, -.10785000E+01, 0.84876500E-01, 0.37473500E+01, 0.43930000E+00, -.30445900E+01, 0.19812500E+01, 0.18380600E+00, -.10538200E+04, 0.63145500E+04, -.30939700E+04, -.29810500E+04, -.30461700E+03, -.60387700E+03, -.23387700E+04, -.10503000E+04, -.16671100E+04, -.43572700E+03, -.14388300E+03, 0.56069700E+02, -.82609100E+01, -.15002400E+04, -.62674300E+03, 0.82769000E+03, 0.18000500E+04, 0.21866300E+04, 0.43814100E+03, -.25623100E+04, 0.13058200E+04, 0.19159400E+04, -.72745600E+03, -.96550400E+03, 0.13889400E+04, 0.24016600E+04, 0.21236700E+04, -.13533000E+03, 0.23149600E+05, -.11614600E+05, -.12049900E+05, 0.50261900E+02, -.26939900E+04, -.74991400E+04, 0.44384100E+03, -.48635100E+04, -.46038000E+04, 0.74357400E+04, -.37226300E+04, -.39819300E+04, 0.76469400E+01, -.15774700E+04, -.19999800E+04, -.44523700E+03, -.20970100E+04, -.16629700E+04, -.44002000E+03, 0.23739200E+03, -.94422900E+02, 0.65166800E+03, 0.18580100E+03, -.15762400E+03, -.15487600E+04, -.10083300E+04, 0.40502300E+03, -.24535600E+04, 0.12441300E+04, 0.15093100E+04, -.10984400E+04, -.77879300E+03, 0.14469200E+04, 0.18907100E+04, 0.18449900E+04, -.59413200E+03, -.61254000E+03, 0.35050600E+03, -.65733700E+02, 0.26731900E+03, 0.23812600E+03, -.33685600E+03, -.13781100E+04, 0.22827200E+03, 0.20159800E+03, 0.79877600E+03, -.39755400E+03, -.51896400E+03, 0.43576100E+03, 0.31120300E+03, -.10413200E+04, -.18180600E+04, -.19826200E+04, -.30834800E+03, 0.35135200E+02, -.11579000E+02, 0.19822700E+02, -.69382900E+02, 0.14197600E+03, -.11272700E+02, 0.21039400E+02, -.25157200E+03, 0.75909200E+02, 0.12140200E+05, -.60553200E+04, -.60603500E+04, -.13657300E+03, -.13893000E+04, -.38751100E+04, -.19239900E+02, -.26047600E+04, -.23542700E+04, -.23402100E+04, 0.10958800E+04, 0.13873300E+04, -.43760700E+03, -.49444200E+03, 0.11834800E+04, 0.43706600E+03, 0.15298700E+04, -.41556500E+03, 0.99368500E+01, 0.52053400E+02, 0.19362300E+02, -.34145200E+02, 0.12283200E+03, 0.85632200E+02, -.47689500E+01, -.87510100E+02, -.12208800E+03, -.19036700E+04, -.18612700E+03, -.16149000E+04, 0.57583000E+03, -.93901000E+03, -.19894700E+03, 0.15114000E+03, 0.46177500E+03, 0.41883200E+03, 0.11176900E+03, -.44564600E+01, 0.16287200E+04, 0.92022700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.15502000E+01, -.10529900E+01, -.68181900E+00, -.14249900E+02, 0.19643600E+01, 0.41521200E+00, -.10698800E+01, -.48168500E+00, 0.31092200E+01, -.83561200E+00, 0.46385100E+00, -.45247000E+00, -.16478800E+01, -.55481600E+00, 0.34494100E+00, -.45481200E+00, -.15255200E+01, -.60176600E+00, -.31799600E+00, 0.70403200E+00, -.32355600E+00, -.32081000E+01, -.48838600E+01, 0.69925600E+00, -.85428200E+00, 0.28543700E+00, -.13571500E+01, 0.15398500E+01, 0.63085800E+01, 0.12626500E+00, -.20364000E+00, 0.10856900E+01, -.25856500E+00, 0.17580100E+01, 0.32487200E+00, 0.17175900E+00, -.58867700E+00, -.22616700E+00, 0.79906700E-01, -.26287100E+00, -.52011800E+00, -.20346600E+00, -.25412600E+00, 0.38174700E+00, 0.11347800E+00, 0.14967300E+00, -.95478800E+00, -.19800200E+00, 0.65093100E+00, -.18071900E+00, -.81537500E-01, -.22989700E+01, 0.23639800E+00, -.81892200E+00, 0.37617100E+00, -.67516100E+00, 0.11055100E+00, -.97061400E-01, 0.41815000E-01, 0.48501500E+00, -.23308400E+00, -.71130700E+00, 0.84296100E+00, 0.59297900E-01, -.27890600E+00, -.95654900E+00, -.33169900E+00, 0.18336200E+00, 0.13890300E+01, -.44811600E+00, 0.47336400E-02, 0.48865600E+00, 0.73654600E-01, -.93089700E-01, 0.36234800E+00, -.53143300E+00, 0.59267500E-01, 0.15728800E+00, -.18469300E+01, 0.23572600E-01, 0.21558000E-01, -.88435600E+03, 0.40779000E+03, 0.45398300E+03, 0.93850600E+02, 0.32914000E+02, 0.28469900E+03, 0.34318300E+01, 0.30811400E+03, -.16886300E+02, 0.17606400E+03, -.87818700E+02, -.89106800E+02, 0.14553500E+03, -.24442300E+02, -.10951900E+03, -.20869300E+03, -.30440700E+03, -.11646000E+03, 0.54765000E+03, -.28127900E+03, -.25169600E+03, 0.17287100E+03, 0.27957600E+03, -.34341300E+03, -.34972600E+03, -.34265400E+03, 0.79954000E+02, -.27282200E+04, 0.13688100E+04, 0.13325100E+04, 0.30511800E+03, 0.69234500E+03, 0.56968400E+03, -.32664600E+03, -.41801400E+03, 0.62452000E+03, -.95214800E+03, 0.47853400E+03, 0.45598600E+03, 0.82406300E+01, 0.25833400E+03, 0.26327500E+03, 0.75001400E+02, 0.22726700E+03, 0.24405500E+03, 0.11715000E+03, -.58853500E+02, -.81081300E+02, -.94821600E+02, 0.89952500E+00, -.83993200E+01, 0.12811100E+03, 0.89253600E+02, 0.47382400E+02, 0.50431100E+03, -.25090600E+03, -.23009300E+03, 0.21905600E+03, 0.20863800E+03, -.29348500E+03, -.31415200E+03, -.41460200E+03, 0.70308000E+02, -.17163100E+03, 0.38155100E+02, 0.37567600E+02, 0.38388200E+02, 0.11688200E+03, 0.19157000E+02, 0.29886900E+02, 0.23809700E+03, 0.12249000E+03, -.13259700E+01, 0.14345600E+01, 0.51525200E+01, -.74251300E+02, -.10879400E+03, 0.93312200E+02, 0.31506400E+03, 0.72540700E+02, -.14714200E+02, 0.29669900E+00, -.22398300E+01, 0.16851300E+01, -.10658500E+02, -.41137000E+02, 0.19200300E+02, 0.41527300E+01, -.49854200E+02, -.30774400E+02, -.13970400E+04, 0.69785900E+03, 0.66840400E+03, 0.19532200E+03, 0.38449700E+03, 0.26663500E+03, -.20155900E+03, -.22542400E+03, 0.39774100E+03, 0.15888700E+03, -.64762500E+02, -.59219600E+02, 0.31277300E+02, -.70609100E+02, -.50769000E+02, -.88146000E+02, -.51181700E+02, -.70326300E+02, -.83968100E+00, -.11186300E+02, -.14226800E+02, -.11517300E+02, 0.48240700E+01, -.50412200E+01, 0.45475400E+00, 0.29818300E+01, 0.20495900E+02, 0.16194700E+03, 0.15060900E+02, 0.17642000E+03, -.14439700E+03, 0.36009100E+02, 0.26468200E+02, -.13965200E+02, -.96955300E+02, 0.68632300E+02, 0.12855400E+02, -.94570200E+00, -.58375700E+02, -.84964800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22638500E+01, 0.16797100E+01, 0.21982000E+01, 0.19295700E+02, -.33390500E+01, -.35678900E+00, 0.20749700E+01, 0.49824700E+00, -.53390400E+01, 0.12417600E+01, -.15265300E+01, 0.18085300E+00, 0.19787800E+01, 0.96078500E+00, -.28691400E+00, 0.16531700E+01, 0.19933800E+01, 0.84194400E+00, 0.73255000E+00, -.11976300E+01, 0.23463400E+00, 0.25449100E+01, 0.43138000E+01, -.47691200E+00, 0.79095500E+00, 0.70575000E+00, 0.61295400E+01, -.12104300E+01, -.70249600E+01, -.31086900E+00, 0.43094600E+00, -.83306800E+00, 0.16588500E+00, -.25041700E+01, 0.29129100E+00, -.19485000E+01, -.74065400E-01, 0.17317200E+00, -.40465600E+00, -.26216200E+00, 0.12348700E+00, -.16668100E+01, 0.58249200E+00, 0.21818400E+00, -.20148100E+00, -.36846200E+00, -.12784000E+01, -.80173800E+00, 0.54267000E+00, -.31472700E+00, -.56291100E-01, -.21280100E+01, 0.35142300E+00, 0.11397500E+00, 0.63841700E+00, 0.50429300E-01, -.15057800E+01, 0.12437100E+01, -.39927200E+00, -.29903400E+00, 0.72456700E-01, -.12280200E+00, 0.14727800E+00, -.36224100E+00, -.80133000E-01, -.11318200E+01, -.20130500E+00, 0.79634000E-01, 0.17593900E+00, 0.20295200E+00, 0.34495200E+00, 0.31994800E+00, -.16604300E+00, -.14240700E+00, 0.13141100E+00, 0.91867000E-01, -.13645400E+00, 0.20247300E+00, 0.50068100E+00, -.11624900E+00, -.10480700E+00, -.13483800E+00, 0.32914300E+02, -.30995700E+00, 0.11908800E+02, 0.10713300E+02, 0.31295200E+02, 0.64761700E+02, 0.21988900E+02, -.36824300E+02, -.69817100E+02, 0.33552400E+02, 0.31794600E+02, 0.71340600E+01, -.31218300E+02, 0.22950900E+02, -.11877200E+02, -.44678700E+02, 0.14096700E+02, 0.46640300E+02, -.26380900E+02, -.42704300E+02, 0.58162700E+02, 0.40088000E+02, -.35569700E+02, -.53814900E+02, -.56001900E+02, 0.32345000E+02, -.76743600E+01, 0.12486800E+00, 0.20873800E+02, 0.45942000E+02, -.37444700E+02, 0.11797400E+03, 0.73121100E+02, -.63143500E+02, -.47322700E+02, 0.10874700E+03, -.55728700E+02, -.52879900E+02, -.91654300E+01, -.22952700E+02, -.24462700E+02, 0.40554400E+02, -.10620200E+03, -.27375700E+02, -.25687400E+02, 0.18145300E+02, 0.12127200E+02, -.16688500E+02, -.68309700E+01, 0.23587100E+02, 0.76542700E+02, 0.90942100E+01, 0.32707900E+01, 0.13369800E+03, -.53062400E+02, -.67628700E+02, 0.47981200E+02, 0.21829000E+02, -.52081600E+02, -.52701000E+02, -.46199700E+02, -.96207600E+01, 0.18826800E+03, -.35125200E+02, -.10420500E+03, 0.13035700E+03, 0.12723600E+03, -.13660000E+03, -.85383900E+02, -.14416100E+03, 0.87391100E+02, 0.76005800E+02, -.37808700E+02, -.29410200E+02, -.48834200E+02, -.47223700E+02, 0.24006200E+02, 0.63182800E+02, 0.69102400E+02, -.46962600E+02, 0.23785400E+02, -.11822900E+02, -.12525900E+02, 0.16888500E+01, 0.14884700E+01, -.11969400E+02, -.43851600E+01, -.32979600E+02, -.51913400E+01, -.36403800E+02, 0.16284700E+02, 0.16189000E+02, 0.55643400E+02, 0.22661300E+02, 0.63822200E+02, 0.35368300E+02, -.10233800E+01, 0.82579700E+01, 0.19622600E+02, 0.12920700E+02, 0.71234800E+00, -.21016800E+02, 0.21729900E+02, 0.12106800E+00, 0.34752400E+02, -.22372100E+02, -.35527000E+01, 0.15874300E+01, 0.24285900E+01, 0.70905100E+01, -.61120700E+01, 0.50071400E+00, 0.18929200E+01, -.11585000E+01, 0.19351000E+01, 0.56057600E+01, -.19907700E+01, 0.12229300E+02, 0.54132600E+01, -.25393700E+02, 0.46205000E+02, -.16342400E+02, -.61898700E+01, -.11234200E+02, -.15253300E+02, -.90014000E+00, 0.78489000E+00, -.71020000E+02, -.78890000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23702500E+01, 0.11388500E+01, 0.14135400E+01, 0.30126300E+02, -.38875700E+01, 0.26355800E-01, 0.21001800E+01, -.22831300E+00, -.75016900E+01, 0.17784200E+01, -.16377200E+01, -.28115900E+00, 0.42533100E+01, 0.12319400E+01, 0.13089700E+00, 0.46651300E+01, 0.35150800E+01, 0.25038700E+01, 0.10393000E+01, -.90537500E+00, 0.39519300E+00, 0.22149800E+01, 0.16725900E+01, -.70011700E+00, 0.10998500E+00, 0.62094600E+00, 0.79677300E+01, -.55379000E+00, -.42451300E+01, 0.14750600E+01, 0.58083100E+00, -.38956800E+00, 0.81763400E+00, -.36092900E+00, 0.43570900E+00, -.66828200E+00, 0.84098600E+00, -.54747000E-01, 0.25831200E+00, -.12740500E+00, 0.30078700E+00, -.44107000E+00, 0.34837200E+00, 0.12546400E+01, -.16083900E+00, -.55565000E+00, 0.55737100E+01, -.71615000E+00, 0.57452300E-01, -.12702200E+00, 0.36889400E+00, 0.15783500E+01, -.16020300E+00, 0.20952000E+01, -.16099000E+01, -.93362400E+00, 0.15025400E+01, 0.13217500E+01, 0.18619300E+00, 0.30109000E+00, 0.63638700E+00, 0.15679300E+01, 0.84482400E-01, -.74132500E-01, -.79668300E+00, 0.14350100E+01, -.60284400E+00, -.26656500E+00, 0.58226800E+00, 0.52709200E+00, 0.53682100E-01, 0.56636200E+00, -.33587100E+00, 0.96286200E-01, 0.23939200E+00, 0.59003600E+00, 0.23135300E+00, -.46986300E+00, 0.74444800E+00, 0.84221000E-01, -.71712300E-01, -.99324800E+00, -.11301800E+01, 0.80909200E+02, -.51412000E+02, -.18025800E+03, 0.10563800E+03, 0.11834800E+03, 0.15878700E+03, -.22399200E+03, 0.92539800E+03, -.46562900E+03, -.49713200E+03, -.68963800E+02, -.15598900E+03, -.35188700E+03, -.14727600E+03, -.27095500E+03, -.22718900E+02, 0.96038500E+03, -.48155200E+03, -.20763400E+03, -.11672100E+02, 0.22562000E+03, -.36812200E+03, -.29767600E+03, -.43076100E+03, 0.39169300E+02, 0.10658600E+04, -.53581000E+03, -.70478800E+03, 0.36162000E+03, 0.34001700E+03, -.71764400E+03, -.72035000E+03, -.11140200E+04, 0.27702100E+03, 0.10635000E+04, -.52837500E+03, -.65436700E+03, 0.25484800E+03, -.41673300E+02, -.48790900E+03, -.33839500E+03, -.81393500E+03, -.17044200E+03, -.17832400E+03, 0.92191700E+02, -.59750700E+02, 0.88419400E+02, 0.27703800E+02, 0.25076700E+02, 0.12115400E+02, 0.26648000E+02, 0.99204800E+02, -.12341100E+03, 0.60830600E+02, 0.19615800E+03, 0.12462400E+02, 0.12208000E+03, 0.35361100E+02, -.44635000E+02, -.56128700E+02, -.72897500E+02, 0.31262700E+03, -.14403200E+03, -.36471400E+03, 0.95386600E+02, 0.18653200E+03, -.10865200E+03, 0.19367100E+03, 0.16340800E+03, -.86516300E+02, 0.16275800E+03, -.80437700E+02, -.94176800E+02, -.22794900E+01, 0.40505400E+02, -.31541000E+02, -.95995700E+02, 0.31708300E+02, 0.47111100E+02, 0.97654500E+01, -.61236500E+01, 0.12844500E+02, -.47385600E+02, -.10206700E+02, 0.41269300E+01, 0.73016400E+02, -.53400200E+02, -.22344200E+01, 0.65704000E+03, -.33057000E+03, -.36966600E+03, 0.20163900E+03, 0.27307900E+03, -.35920900E+03, -.36117200E+03, -.74662000E+03, 0.14477400E+03, 0.14830600E+03, -.53682500E+02, 0.43708200E+02, -.10995600E+02, -.10115300E+03, -.88934900E+02, -.25834000E+03, -.54456900E+02, -.58152600E+02, 0.33237700E+01, -.12824700E+02, 0.22172000E+02, -.21860500E+02, 0.13825800E+02, 0.82572300E+01, -.21134500E+01, 0.10647300E+02, 0.92580900E+01, -.78151700E+02, -.23011800E+02, 0.20747400E+02, -.99251100E+02, -.18782400E+03, -.51914700E+02, -.50759300E+01, -.83327900E+02, -.10112700E+03, 0.12445300E+02, -.74491400E+01, 0.34320400E+03, 0.18010400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24872900E+01, -.75939800E+00, -.49311400E+01, -.12493600E+02, 0.70114800E+00, 0.14630400E+00, -.13549000E+01, -.11994500E+01, 0.69204100E+01, -.91133100E+00, 0.31650700E+01, -.16680600E+01, -.20027800E+01, -.99570700E+00, -.80176700E+00, -.31638700E+01, -.19239000E+01, -.66372500E+00, -.18125700E+01, 0.54058400E+00, -.22332900E+00, -.36449900E+01, -.11227100E-01, 0.39276300E+00, -.21958300E-01, 0.13932300E+00, -.29559500E+01, 0.74837500E+00, 0.46770400E+01, 0.22813200E+00, -.34987600E+00, 0.93155700E+00, 0.11364300E+00, 0.11343400E+01, -.26662100E+00, 0.14858100E+01, 0.12600300E+00, -.79480100E-01, 0.52991500E-01, 0.90527800E-01, -.59578000E+00, 0.63965800E+00, 0.60634700E-01, -.98459000E+00, -.70576400E+00, 0.18488000E+00, 0.23845300E+01, -.28810700E+00, 0.25038300E-01, 0.47464900E+00, -.15831900E+00, 0.79690700E+00, 0.37358600E+00, 0.58075700E+00, 0.67185000E+00, 0.97530400E+00, -.12709200E+00, 0.46089600E+00, -.34222400E+00, -.10894700E+00, -.24484200E+00, 0.10152400E+01, -.11473600E+00, 0.72511600E+00, 0.45160700E+00, 0.14105100E+00, 0.56756500E+00, 0.88866800E-01, 0.17946500E+00, -.18551700E+01, -.22429100E+00, 0.26643500E+00, -.27919500E-01, -.50871900E-01, -.36640200E+00, -.16923200E+00, -.20195300E+00, 0.12904100E+00, -.83923600E+00, -.17518800E+00, 0.24916700E-01, 0.21491000E+00, 0.16018800E+00, 0.36622800E+00, -.12698500E+03, 0.40054500E+02, -.50519800E+00, 0.51251200E+02, 0.70275600E+02, 0.61632100E+02, -.48508900E+03, 0.24122400E+03, 0.25066900E+03, 0.26780700E+01, 0.74289500E+02, 0.17330200E+03, 0.98277700E+02, 0.15299700E+03, 0.58061900E+02, -.28038800E+03, 0.14408000E+03, 0.16809300E+03, -.15578600E+03, -.18449100E+03, 0.21688000E+03, 0.32933600E+03, 0.31347400E+03, -.96712400E+02, 0.86114600E+03, -.43633600E+03, -.46051300E+03, -.40294500E+03, -.43763500E+03, -.19480200E+02, 0.56696100E+03, 0.17598400E+03, -.40802800E+03, -.92551800E+02, 0.42611700E+02, 0.41601800E+02, -.64324400E+02, -.68312200E+02, 0.93764800E+02, 0.69991800E+02, 0.14704200E+03, -.49240600E+01, -.15676900E+02, 0.61834300E+01, 0.84770900E+01, -.27139800E+02, -.98345200E+01, -.42113800E+00, -.12552600E+03, -.60688600E+02, -.17380200E+01, -.17448500E+03, 0.83591800E+02, 0.89386200E+02, -.69067000E+02, -.98147500E+02, 0.10481300E+03, 0.15431700E+03, 0.13514300E+03, -.12696400E+02, -.10481000E+04, 0.51356100E+03, 0.53028200E+03, -.15720700E+03, -.39509700E+02, 0.41597800E+03, 0.18256600E+03, 0.50616900E+03, 0.30292200E+02, -.70325200E+02, 0.34065900E+02, 0.21411700E+02, 0.16425100E+02, 0.33124400E+02, -.17753800E+02, -.41260700E+02, -.41350400E+02, -.35257800E+01, -.13240500E+02, 0.81091900E+01, 0.63670900E+01, 0.15277800E+02, 0.12633200E+01, 0.28261500E+01, -.17778800E+02, 0.49545400E+02, 0.54728200E+01, 0.66234800E+03, -.33100000E+03, -.33731800E+03, -.23810100E+03, -.29917000E+03, -.77290800E+02, 0.26066600E+03, 0.36570400E+02, -.26522100E+03, 0.34067200E+03, -.18755200E+03, -.18209600E+03, 0.10783500E+02, -.46410800E+02, -.13774700E+03, -.11631600E+03, -.10738400E+03, -.21360900E+02, -.20191700E+01, -.44521600E+00, 0.80538300E+00, 0.10235200E+02, 0.34511700E+01, -.18274200E+01, 0.16132300E+01, -.14134800E+01, 0.40225500E+01, -.14317400E+02, -.12662900E+02, -.59653600E+02, 0.11675300E+03, 0.41422600E+02, 0.97165400E+01, 0.21321300E+02, 0.36534500E+02, -.75057000E+01, 0.56919900E+00, 0.15124300E+01, -.61505700E+02, 0.50642000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.38980600E+00, -.18590500E+00, -.39331100E-01, -.51752500E+01, 0.75261800E+00, -.43353300E-01, -.42202700E+00, 0.95327400E-01, 0.11653900E+01, -.31110600E+00, 0.18161700E+00, 0.10868200E+00, -.65869000E+00, -.78081100E-01, -.25734500E-01, -.89099600E+00, -.47003500E+00, -.36083300E+00, -.19336300E+00, 0.10654700E+00, -.44823700E-01, -.39623000E+00, -.52140600E+00, 0.12897900E+00, 0.29480100E-01, -.80553400E-01, -.88860300E+00, 0.16424600E+00, 0.56494400E+00, -.17120300E+00, -.64370400E-01, 0.11380800E-01, -.12607600E+00, 0.11118500E+00, 0.20169100E-01, 0.26517000E-01, -.17394800E+00, 0.64239000E-02, -.31860100E-01, -.90025200E-02, -.89403600E-01, 0.10186500E+00, -.64733600E-01, 0.10967500E-01, 0.42218900E-01, 0.12869000E+00, -.27944500E+00, 0.39427700E-01, 0.43351400E-01, 0.20681000E+00, -.10624600E+00, -.43628100E-01, -.72655200E-01, -.14567300E+00, 0.10954100E+00, 0.18819300E-01, -.34694900E-01, -.25044700E+00, -.84164300E-02, -.68011500E-01, -.63410700E-01, -.22394100E+00, -.23559900E+00, 0.73380100E-01, 0.14715000E+00, 0.33883500E+00, 0.14088500E+00, 0.70771600E-01, -.30482000E-01, -.57769700E-01, -.59605600E-01, -.42407000E-01, 0.37620200E-01, -.36935300E-01, -.23530100E-01, -.96110900E-01, -.43099300E-02, 0.54623000E-01, 0.99591300E-01, 0.69877500E-01, 0.91156300E-02, -.15089000E-02, -.12530300E-01, -.73817500E-01, -.19742300E+00, 0.26258100E+02, -.97457600E+01, -.14717200E+02, 0.62198600E+01, 0.16338700E+02, -.22735100E+03, 0.11323800E+03, 0.11550300E+03, 0.33451000E+01, 0.11640000E+02, 0.89425000E+02, 0.29562500E+02, 0.46254200E+02, 0.24464300E+01, 0.88497200E+02, -.43879900E+02, -.38390100E+02, -.30224900E+02, -.21754100E+02, -.23042100E+02, -.45606400E+01, -.46427900E+01, -.20526200E+02, 0.20548400E+02, -.11896100E+02, -.15008100E+02, -.10729200E+03, -.77682500E+02, 0.70387100E+02, 0.18602000E+03, -.63690200E+02, -.88479700E+02, -.11015600E+03, 0.53782500E+02, 0.54452100E+02, -.51081200E+02, -.30876200E+02, 0.85812800E+02, 0.83220300E+02, 0.54030400E+02, -.81133900E+01, -.12406500E+02, 0.61639600E+01, 0.63042300E+01, -.16836900E+02, -.91109600E+01, 0.13000500E+02, -.40158300E+01, -.14645300E+02, -.76015900E-01, 0.39600500E+02, -.19072400E+02, -.19413900E+02, 0.13633900E+01, 0.61466600E+01, -.21193900E+02, -.24597900E+02, -.25482700E+02, 0.15761800E+02, -.28917600E+03, 0.14188800E+03, 0.14449600E+03, -.41048400E+02, 0.67760200E+01, 0.96485500E+02, 0.43671900E+01, 0.15777500E+03, 0.39247600E+02, -.35734600E+01, 0.15846000E+01, 0.37568300E+00, 0.84445900E+00, 0.16695500E+01, -.18830100E+02, 0.43220600E+01, -.31720900E+02, -.13252600E+01, 0.54915500E+00, 0.11242900E-01, 0.76793800E-01, -.15563100E+01, -.36285600E+01, 0.20750400E+01, 0.26173700E+01, 0.12622100E+02, -.50681800E+01, 0.65804100E+02, -.32805800E+02, -.33982800E+02, -.47222500E+02, -.48815300E+02, 0.56152900E+01, 0.68461800E+02, -.47352600E+02, -.40887700E+02, 0.73508000E+02, -.38804300E+02, -.37945800E+02, 0.35644600E+02, 0.31955100E+01, -.30463400E+02, -.19937900E+02, -.33975500E+02, -.98338800E+01, 0.10163500E+01, -.14732200E+01, -.15292200E+01, 0.17482800E+01, -.48377200E+00, -.17608400E+01, -.69095500E+00, 0.10544700E+01, -.13593000E+01, 0.12338400E+02, -.49329200E+00, -.37769200E+01, 0.14577500E+02, 0.25506700E+02, -.81731800E+01, 0.84052900E+01, 0.13134000E+01, 0.36176000E+02, 0.80039400E+01, 0.60768500E+00, -.34102200E+02, -.60815800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.55869800E+01, -.31033900E+01, -.45005600E+01, -.48454700E+02, 0.88205900E+01, 0.11833900E+01, -.46762600E+01, -.16476200E+01, 0.94490900E+01, -.28626900E+01, 0.15455000E+01, -.67265500E+00, -.34228000E+01, -.18015400E+01, 0.13222600E+01, -.35576100E+01, -.53005900E+01, -.39970900E+01, -.15377700E+01, 0.35833800E+01, -.87117800E+00, -.59135400E+01, -.12338600E+02, 0.10807500E+01, -.18185900E+01, -.20502100E+01, -.15807400E+02, 0.14844800E+01, 0.12596000E+02, -.74684400E-01, -.22825600E+01, 0.20172400E+01, 0.32783200E+00, 0.74938700E+01, -.97000700E+00, 0.83286900E+00, -.21843600E+01, -.27764900E+00, 0.40329800E+00, -.41498600E+00, -.22295600E+01, 0.17123000E+01, -.17758200E+01, 0.40654300E+00, -.26806200E+01, -.83564400E+00, -.61544600E+01, -.18675200E+01, -.74312800E-01, -.21950800E+01, -.74768300E+00, 0.34200300E+01, 0.83235500E+00, -.71852600E+00, 0.22161400E+01, 0.35797200E+01, -.48266400E+01, 0.63074100E+01, -.15579100E+01, 0.14104100E+01, -.57429700E-01, 0.82068300E+00, 0.94172200E+00, -.27456200E+00, 0.10431500E+01, 0.46194000E+00, -.53918900E+00, -.34226300E+00, 0.28405000E+01, -.35187800E+01, -.52813800E+00, 0.27741000E+01, -.17484500E+01, 0.24116900E+00, 0.44106300E+00, -.19173200E+01, 0.67152800E+00, 0.80357500E+00, -.49685600E+01, -.11856900E+00, -.28988400E+00, 0.10688100E+01, 0.13258200E+01, 0.24796800E+00, 0.22065000E+00, 0.56949600E+01, -.23075700E+03, -.22201600E+03, -.16714500E+03, 0.14033000E+03, 0.12803000E+04, -.63859000E+03, -.63937500E+03, -.22321500E+03, 0.53361000E+02, -.44436100E+03, 0.85312300E+02, 0.11975000E+02, -.23076000E+03, -.30483900E+04, 0.15328900E+04, 0.15287100E+04, 0.85328100E+02, -.15435400E+03, 0.11007300E+04, 0.13043500E+04, 0.13605400E+04, 0.11828300E+03, -.20015000E+03, 0.90558300E+02, 0.12925900E+03, 0.46428200E+03, 0.65796500E+03, -.94170500E+03, -.98881200E+03, -.67547700E+03, 0.61752200E+03, -.17088400E+03, 0.84443200E+02, 0.10762500E+03, 0.84056100E+02, 0.32523600E+03, -.20946300E+03, -.24005800E+03, 0.44859300E+03, 0.30021600E+03, 0.72053600E+03, -.36258200E+03, -.33790200E+03, 0.66331400E+02, 0.10495100E+03, -.32279300E+03, -.43336800E+03, -.28045500E+03, 0.39962800E+02, -.39854900E+03, 0.18898500E+03, 0.17911800E+03, 0.59509200E+01, -.23388100E+03, 0.19244800E+03, 0.53532600E+03, 0.35138800E+03, -.14831300E+03, 0.20313200E+04, -.10313000E+04, -.92881200E+03, 0.18570600E+03, -.26622400E+03, -.72338700E+03, -.28413900E+03, -.75309400E+03, -.36341000E+03, -.14044600E+03, 0.68505300E+02, 0.30409500E+02, 0.50297800E+02, 0.82681300E+01, 0.55492000E+02, -.95210400E+02, -.27751900E+03, 0.36082000E+02, 0.20329100E+01, -.16988500E+00, 0.60244700E+01, 0.77032600E+02, -.11516600E+02, -.77825500E+01, -.15324500E+03, -.17760500E+03, 0.12145300E+02, -.25685100E+03, 0.13027900E+03, 0.21532100E+03, 0.43295900E+00, 0.21737800E+03, -.31872700E+03, -.39007300E+03, -.23037200E+03, 0.27445300E+03, -.12490900E+04, 0.58336300E+03, 0.57405800E+03, -.57618400E+03, -.15242000E+03, 0.61677500E+03, 0.27916300E+03, 0.79737600E+03, 0.10580400E+03, -.26120800E+02, -.48623900E-01, -.83952500E+00, -.15784100E+01, 0.33344800E+02, 0.69290000E+01, 0.15965700E+02, -.34713400E+02, 0.26308300E+02, -.90782300E+02, -.25057400E+02, -.81893100E+02, 0.15276100E+03, -.27811200E+03, 0.12613100E+03, 0.40013900E+01, 0.10611700E+03, 0.23413500E+02, -.27305800E+02, 0.21582300E+01, 0.52559700E+03, 0.10860600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.61013600E+01, -.28993600E+01, -.76526500E+01, -.40665100E+02, 0.45235800E+01, 0.89017800E+00, -.74759500E+00, -.23872900E+01, 0.11707300E+02, -.24235600E+01, 0.51281200E+01, -.21731300E+01, -.70087500E+01, -.26825800E+01, 0.16703200E+00, -.40090500E+01, -.45223300E+01, -.57772200E+00, -.17614700E+01, 0.17462400E+01, -.16488700E+00, -.70435000E+01, -.10501600E+02, 0.13505100E+01, -.99772100E+00, -.72559800E+00, -.15880600E+02, 0.51388600E+01, 0.25773100E+02, -.48862500E+00, 0.23885500E+00, 0.16824100E+01, -.95744600E+00, 0.40974000E+01, 0.10910500E+01, 0.14695000E+01, -.38108100E+00, -.68251600E+00, 0.14220200E+01, 0.23242800E+00, -.63540500E+00, 0.27869300E+01, 0.41338000E+00, -.15115900E+01, -.23958400E+00, 0.14669100E+01, 0.51835300E+01, 0.37846800E+01, -.15037100E+01, 0.52709500E+00, 0.56650900E+00, -.86076200E+00, 0.12553500E+01, -.19422200E+01, 0.17854000E+01, -.11309600E+01, 0.48818700E+01, -.82904700E+00, 0.12592400E+01, 0.11371500E+01, -.85539000E+00, 0.15281800E+01, -.20063900E+01, -.18031000E+00, 0.27462300E+00, 0.16595800E+01, -.13318300E+01, 0.35509800E+00, 0.19372200E+01, 0.69040400E+00, -.14289500E+00, -.86468600E+00, 0.13446300E+00, -.51111000E+00, 0.72798400E-01, -.55948700E+00, -.85391300E+00, 0.80065900E+00, 0.28949700E+01, 0.87253100E+00, -.88409000E-01, 0.16814200E+01, 0.14945400E+01, -.11257100E+01, -.68448800E+00, -.23081100E+01, 0.34912600E+00, -.27886300E+03, -.44495600E+03, 0.24573300E+03, -.55444500E+03, 0.27581800E+03, 0.28597100E+03, -.75552700E+02, 0.41429100E+02, 0.14064500E+03, 0.12068600E+02, 0.38666300E+03, 0.91354100E+02, 0.10196400E+04, -.50149900E+03, -.43675800E+03, -.77614000E+03, -.55344800E+03, 0.47007200E+02, -.51451300E+03, -.53764600E+03, -.42688900E+03, 0.34436200E+04, -.17219700E+04, -.17689600E+04, -.93235100E+03, -.15722800E+04, 0.19214900E+01, 0.87915800E+03, 0.10808300E+04, -.13285200E+04, 0.60633800E+03, -.30310800E+03, -.31866300E+03, -.49403700E+02, -.53650000E+03, 0.50605500E+02, 0.11307400E+03, -.97640800E+03, -.40791800E+03, -.38493100E+03, 0.18931700E+03, 0.18442600E+03, 0.27656600E+03, -.17490700E+03, 0.13425500E+03, 0.12211300E+03, -.14874400E+03, -.16852600E+03, -.10744300E+04, 0.52113700E+03, 0.54791200E+03, -.42503500E+03, -.13565900E+03, 0.51027500E+03, 0.11838900E+03, 0.47795400E+03, 0.97468300E+02, 0.20033000E+03, -.98331000E+02, -.10165000E+03, -.25287000E+03, -.17243000E+03, 0.11227000E+03, -.82401600E+02, -.39974700E+03, -.20935100E+03, 0.25280900E+03, -.12588000E+03, -.13412500E+03, 0.26768700E+03, 0.32257800E+03, -.26899500E+03, -.56099400E+03, -.11483800E+02, 0.23389300E+03, -.78931600E+02, 0.39880000E+02, 0.36734700E+02, -.45638600E+02, 0.55119200E+02, -.21985900E+02, 0.11986600E+03, 0.19648700E+03, 0.43543300E+02, 0.25059300E+04, -.12515600E+04, -.12757200E+04, -.57959700E+03, -.96768400E+03, -.11836100E+03, 0.63288200E+03, 0.52456800E+03, -.99664500E+03, -.48311900E+03, 0.21599000E+03, 0.24144300E+03, 0.45229700E+03, 0.33839300E+03, -.35049300E+02, 0.11882000E+03, -.21238900E+03, 0.31644200E+03, 0.86337900E+01, -.37978300E+01, 0.11158100E+02, 0.19885800E+02, -.54217400E+01, -.43985700E+02, -.68896000E+01, 0.81792900E+02, -.90112800E+02, -.57240500E+02, -.11265900E+02, -.84596000E+02, 0.29590300E+03, 0.10267700E+03, -.27301200E+03, 0.79559700E+02, 0.39755100E+02, -.26496300E+02, 0.16901800E+02, -.45773000E+01, -.27573900E+03, -.78714600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21149500E+01, 0.17409700E+01, 0.15463500E+01, 0.17571300E+02, -.34947000E+01, -.24626600E+00, 0.15889800E+01, 0.12907500E+00, -.45080000E+01, 0.10136200E+01, -.11319600E+01, -.98746600E-01, 0.39126900E+01, 0.41810100E+00, 0.49770800E-01, 0.19281500E+01, 0.17885100E+01, 0.12797000E+01, 0.20029600E+00, -.88297700E+00, 0.16423800E+00, 0.35715600E+01, 0.62783600E+01, 0.26122300E-01, 0.12935800E+01, -.72200900E+00, -.15001700E+01, -.29291000E+00, -.41064200E+01, -.10542300E+01, 0.11943400E+01, -.20060100E+01, -.11721100E+00, -.29733800E+01, 0.11377500E+01, -.99088100E+00, 0.16123900E+01, 0.16718600E+00, 0.63231900E+00, 0.16293100E-01, -.20996100E+00, -.48654400E+00, 0.16711700E+00, -.42342400E+00, -.88576200E+00, -.18146000E+00, 0.89757300E+00, -.46687500E-01, -.62450100E+00, -.54122800E+00, 0.56989400E-01, 0.77031800E+00, -.21240400E+00, 0.47655600E+00, -.74491100E+00, 0.19804800E+00, 0.12499700E+00, 0.24152300E+00, -.36859100E-01, 0.77063900E+00, -.22157300E+00, -.84708500E-01, -.49280400E+00, 0.50987800E-01, -.21495500E+00, -.82278100E-01, 0.84821600E-01, 0.12693900E+00, 0.62843100E+00, -.14288400E+00, -.73162700E-01, -.21401900E+00, 0.19503800E+00, -.37588100E-01, 0.10363100E+00, 0.24782700E+00, -.49012300E-01, -.89390300E-01, 0.14137100E+01, -.14531800E+00, -.10710200E+00, -.66148800E-01, 0.36528200E+00, 0.83974000E-01, 0.95749400E-01, -.17783300E+01, 0.12151700E+00, 0.20146600E+00, 0.15738600E+03, -.42768300E+02, -.31073900E+03, 0.15394600E+03, 0.15594600E+03, -.11784400E+02, 0.30074200E+02, 0.16405700E+03, 0.87911900E+02, 0.19869600E+02, 0.18001200E+02, 0.70558400E+01, -.28327300E+01, -.12311400E+02, 0.72830200E+02, -.90369200E+01, -.29302900E+02, 0.83492100E+02, 0.10258300E+03, 0.12490300E+02, 0.13245900E+03, -.71801600E+02, -.76750400E+02, -.28037500E+02, 0.16745400E+02, -.45100400E+02, 0.24753200E+03, -.42337400E+03, -.92595800E+02, -.20048300E+02, 0.68122700E+01, 0.98489100E+01, -.69587400E+02, -.40064300E+02, 0.75450400E+02, 0.79105800E+02, 0.32282200E+02, -.33963700E+02, -.10514300E+03, 0.53488600E+02, 0.51878400E+02, -.16568700E+02, -.78614500E+01, 0.36074800E+02, -.52632600E+02, -.10494000E+03, 0.38926000E+02, 0.16601700E+03, -.78977600E+02, -.83569700E+02, 0.28145400E+02, 0.43219600E+02, -.70259500E+02, -.12261000E+02, -.50928400E+02, 0.98251900E+01, -.47126100E+03, 0.22630200E+03, 0.23278300E+03, 0.77443200E+01, 0.71062000E+02, 0.10745200E+03, -.94039000E+02, 0.30310800E+03, 0.86747800E+02, -.26841500E+02, 0.13210000E+02, 0.10797100E+02, -.38602000E+02, -.77790100E+02, -.31157500E+00, 0.98535300E+02, -.68582500E+02, -.69675500E+02, 0.13359400E+02, -.55112600E+01, -.67667100E+01, 0.42140500E+01, -.25337000E+00, -.27316800E+00, -.21138700E+02, -.32397300E+02, -.67890300E+01, 0.99756300E+02, -.47876600E+02, -.47614800E+02, 0.30085900E+02, 0.22438800E+02, -.80822400E+02, 0.37424700E+02, -.21336500E+03, 0.13024000E+02, -.49898700E+02, 0.16147800E+02, 0.28976300E+02, -.36029400E+02, -.10402800E+03, 0.81061400E+02, 0.64092000E+02, 0.10123100E+03, -.75205400E+02, -.11024600E-01, 0.48614100E-01, -.15084400E+02, -.31916500E+01, 0.80694600E+01, 0.88189200E+01, 0.32330500E+00, -.11855500E+02, 0.43433000E+01, 0.37360600E+01, 0.24181400E+01, -.25082300E+02, -.29538500E+02, 0.85226100E+01, 0.30902700E+00, 0.19647600E+02, 0.12294500E+02, 0.88860500E+02, 0.11132900E+02, 0.12094500E+01, 0.14694500E+02, -.62108100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12525700E+01, -.11764000E+00, -.18864600E+01, -.49597800E+01, 0.11950500E+01, 0.32609300E+00, -.12414300E+00, -.99296800E+00, 0.13112300E+01, -.25392500E+00, 0.49799700E+00, -.45111100E+00, -.16951000E+00, 0.34101500E+00, 0.59257200E-01, -.89531400E-01, 0.20062400E+00, -.20177900E+00, -.18275500E+00, 0.43095000E+00, -.74940900E-01, -.12415900E+01, -.25775700E+01, 0.13509900E+00, -.38052200E+00, -.31507800E+00, -.16988400E+01, 0.36964500E+00, 0.28883500E+01, 0.35497600E+00, 0.43050500E-01, 0.20763300E+00, -.93420100E-01, 0.14474300E+00, 0.51570300E+00, 0.96601600E+00, 0.88637000E+00, -.19466400E-01, -.17791200E+00, -.53847900E-01, -.10556000E+00, 0.40093700E+00, -.75669800E-02, -.49952300E+00, -.10726600E+01, -.52657900E-01, 0.44480400E+00, 0.82894900E-01, 0.20931000E-01, 0.10739900E+00, -.68960900E-01, -.49105300E+00, -.33791000E+00, 0.31580900E+00, -.35956600E+00, 0.12395000E+00, -.20628400E+00, 0.92374300E-01, -.10468600E+00, -.88343600E-01, -.16712000E-01, -.26614500E-02, 0.71354200E-01, -.30490800E+00, -.28870100E+00, -.42031300E+00, -.63202000E-02, 0.80889600E-01, 0.41501900E+00, -.81047600E-01, -.10328200E+00, 0.14499500E+00, 0.20558600E+00, 0.12128900E+00, 0.34051900E+00, 0.26897200E+00, 0.17403200E+00, 0.10430000E+00, -.69734100E+00, 0.69328300E-01, -.22377100E-01, 0.37745300E+00, 0.87489500E-01, 0.38078400E-01, 0.19368200E+00, -.59396600E+00, -.12705200E+00, -.22853000E-01, -.38569200E+00, 0.38154300E+02, -.10947000E+03, 0.56777700E+02, 0.55230200E+02, -.78612200E+02, 0.58812500E+02, 0.57056600E+02, 0.75264400E+02, 0.98112200E+02, 0.41175300E+02, -.47871900E+03, 0.24010900E+03, 0.24101200E+03, 0.81780600E+01, -.57900200E+02, 0.18425800E+03, 0.21906900E+03, 0.21360400E+03, 0.14595000E+02, 0.82835800E+03, -.41109600E+03, -.41129200E+03, -.96586800E+02, -.21192800E+03, -.20733400E+03, 0.24636200E+03, 0.17308800E+03, -.22817300E+03, 0.32287700E+02, -.15604200E+02, -.11994700E+02, 0.23529400E+02, 0.14292600E+02, -.37795100E+02, -.10596300E+03, 0.62337800E+02, -.28558300E+00, -.14855900E+02, 0.72570100E+01, 0.10508200E+02, 0.61787200E+02, 0.35755200E+02, -.41162200E+02, -.12792600E+03, -.96226700E+02, 0.19280500E+02, -.15000600E+03, 0.76081900E+02, 0.69911100E+02, -.44351700E+02, -.52046400E+02, 0.87147800E+02, 0.14155000E+03, 0.11331200E+03, -.15325700E+02, -.26468400E+02, 0.83930700E+01, 0.32739500E+02, 0.56794800E+02, 0.23793800E+02, -.27116300E+02, -.12792500E+03, -.11022100E+03, 0.13056200E+02, -.10175900E+02, 0.54809400E+01, -.17234500E+01, 0.42134900E+02, 0.82284300E+01, -.34255600E+02, -.60617300E+02, -.12757700E+03, -.20246500E+01, 0.25692200E+01, -.89720500E+00, 0.25929400E+00, 0.91871700E+01, 0.14926200E+02, -.87126700E+01, -.27647500E+02, -.26422200E+02, 0.72923300E+01, 0.65777400E+03, -.32534900E+03, -.30663900E+03, -.82402200E+02, -.16624100E+03, -.15812200E+03, 0.14088700E+03, 0.32665900E+02, -.16440300E+03, -.17766800E+03, 0.84369300E+02, 0.82916700E+02, -.99638100E+02, -.59401800E+02, 0.12563600E+03, 0.10069500E+03, 0.18563400E+03, -.14979900E+02, -.32475000E+01, 0.45473200E+01, -.86528700E+01, -.38805900E+00, 0.12622800E+02, 0.71471600E+01, 0.23048200E+01, -.10634600E+02, -.54440900E+01, -.25434100E+02, 0.11651400E+02, -.50687200E+02, 0.21440500E+02, -.21576300E+02, 0.35227200E+02, 0.19403600E+01, 0.41028300E+02, -.10421600E+02, -.19979800E+01, 0.41663600E+00, 0.38397300E+02, 0.92737600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18298900E+01, -.98938700E+00, -.13762200E+01, -.16822500E+02, 0.32713600E+01, 0.13093500E+00, -.13043700E+01, -.23282200E+00, 0.36124200E+01, -.10744900E+01, 0.38632600E+00, 0.18285800E+00, -.19962700E+01, -.45837500E+00, 0.32342200E+00, -.37910000E+01, -.26079500E+01, -.18362500E+01, -.77836000E+00, 0.11076200E+01, -.32608300E+00, -.20536600E+01, -.70725300E+01, 0.58458200E+00, -.52259600E+00, -.39305100E+00, -.54042600E+01, 0.34038100E+00, 0.81069500E-01, -.17531800E+00, -.29137800E+00, -.19468200E-01, -.93498200E+00, 0.62248800E+00, -.94264100E-01, 0.14618200E+01, -.37690400E-02, 0.85121000E-01, -.41882200E+00, 0.72470800E-01, -.24694900E+00, 0.12630800E+01, -.97422000E+00, -.32904400E-02, 0.63531700E+00, 0.23306900E+00, -.54728600E+01, 0.25278100E+00, -.94379000E-01, -.13308500E+00, -.28610600E+00, -.12413400E+01, 0.26170600E+00, -.19182400E+01, 0.99605600E+00, -.37393500E-01, -.68973800E+00, -.18237300E+01, -.18968400E-01, -.38397700E+00, -.60925500E+00, -.10881700E+01, -.40183000E+00, -.27470900E+00, 0.31588000E+00, -.79736200E+00, 0.26696300E-01, 0.20278900E+00, 0.55440900E+00, 0.14658100E+00, -.12459000E-01, -.90884300E+00, 0.78644100E+00, -.20101000E+00, 0.72867300E-01, -.79528800E-02, -.15073700E+00, -.59873900E-01, -.99468200E-01, -.19539200E+00, 0.61725200E-01, 0.90859800E+00, 0.52931300E+00, -.41459300E+00, 0.30166400E+00, -.19182000E+01, 0.10585300E+00, 0.40108300E-01, 0.39271400E+00, -.41516500E+00, -.45571900E+03, 0.22873700E+03, 0.23018100E+03, -.75195100E+02, 0.95296200E+01, 0.20699900E+03, 0.10641100E+03, 0.11626800E+03, -.43024300E+01, 0.41174900E+01, -.41057400E+01, 0.47728300E+00, 0.25667400E+02, -.65784600E+02, 0.21315000E+02, 0.12998800E+03, 0.40030200E+02, -.27656300E+02, 0.31553000E+03, -.15384300E+03, -.16073200E+03, -.22362500E+03, -.28188600E+03, 0.70325400E+02, 0.45569100E+03, -.24814000E+03, -.34799400E+03, -.25277100E+02, 0.13357400E+02, 0.10800400E+02, -.12916400E+03, -.10673700E+03, 0.12519400E+03, 0.18422400E+03, 0.95408600E+02, -.80666300E+02, -.16432900E+02, 0.10038100E+02, 0.69396100E+01, -.14829500E+02, -.33049000E+02, 0.45283900E+02, 0.64707200E+02, -.43305700E+02, -.70897000E+01, 0.16104900E+03, -.73177700E+02, -.80109300E+02, 0.26487600E+02, -.51737300E+01, -.65109400E+02, -.40858900E+02, -.41682400E+02, 0.22356200E+02, 0.33712800E+02, -.18141100E+02, -.13907600E+02, 0.86473600E+02, 0.51616500E+02, -.58235000E+02, -.18718400E+03, -.45260000E+02, 0.60368100E+02, 0.63711400E+00, 0.46376300E+00, 0.14660600E-01, -.10138800E+02, -.91988300E+01, -.52815900E+02, -.26203700E+02, -.15437600E+03, -.30245600E+02, 0.38660200E+02, -.19752900E+02, -.19858800E+02, 0.36449300E+01, -.16116300E+01, -.19520700E+02, -.20129900E+02, 0.17035300E+01, -.13125600E+02, 0.45970500E+03, -.22811400E+03, -.23069800E+03, -.10209700E+03, -.20030700E+03, -.58799800E+02, 0.20100100E+03, -.18832000E+03, -.18632500E+03, -.29826900E+03, 0.15872700E+03, 0.15155300E+03, -.66408000E+02, -.43566600E+02, 0.16871000E+03, 0.16664000E+03, 0.17537000E+03, -.23529200E+02, -.40791600E-01, -.35501000E+01, -.43345200E+01, 0.14489300E+01, 0.91265200E+00, -.15361700E+01, -.13298900E+00, 0.11799400E+01, -.55450200E+01, 0.24662500E+01, 0.23711500E+01, -.33482100E+02, -.13978200E+02, 0.63942900E+02, -.15483600E+02, 0.16529000E+02, 0.22566000E+02, 0.24683700E+02, 0.17829100E+02, 0.74004900E+00, -.83887800E+02, -.33753400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.51704500E+01, 0.16026500E+01, 0.16506200E+01, 0.29935600E+02, -.46881800E+01, 0.17392600E-01, 0.20523200E+01, 0.32009800E+01, -.97426800E+01, 0.20751300E+01, -.47001100E+01, 0.15462600E+01, 0.45778000E+01, 0.16706500E+01, 0.15813700E+01, 0.81407900E+01, 0.33381600E+01, 0.53534200E+00, 0.22236400E+01, -.58780500E+00, -.42109500E+00, 0.32573000E+01, 0.93904600E+01, -.91144700E+00, 0.32123800E+00, 0.44117500E+00, 0.92278900E+01, -.12726700E+01, -.67915100E+01, -.80875400E+00, 0.19090600E+01, -.15169300E+01, -.17984400E+00, -.45459500E+01, 0.12514600E+01, -.48782500E+01, -.73975500E+00, 0.14901700E+00, 0.19025200E+01, -.24532200E+00, -.61210900E+00, -.18118900E+01, 0.59826100E+00, -.64337500E+00, 0.18287000E+01, -.23585200E+00, -.66822600E+01, 0.81375000E+00, -.10141300E+01, -.72051500E+00, 0.30590200E+00, -.22680000E+01, 0.14414800E+00, -.23157800E+01, 0.70474100E-01, -.17139600E+01, 0.12619300E+01, -.16070000E+01, 0.48463600E+00, 0.97589900E+00, -.41679500E+00, -.18432300E+01, -.11134700E+01, -.66180600E+00, -.72325600E+00, -.89057500E-01, -.45883200E+00, 0.18168400E+00, 0.15343400E+01, 0.27074100E+00, 0.40906000E-01, -.47583500E-02, -.17549400E+00, -.71584600E-01, -.32932800E+00, -.37412000E+00, -.54843700E+00, -.52610000E+00, -.26433900E+01, 0.25667500E+00, 0.16602200E+00, 0.91469600E+00, -.55933100E+00, 0.12182500E+00, 0.15438800E+00, -.17379900E+01, -.68704700E-01, 0.18812500E+00, -.25413600E+00, -.91210000E+00, 0.43640800E+00, 0.12826300E+02, 0.93729500E-02, -.80698200E+02, 0.44643400E+02, 0.26433200E+02, 0.61727200E+02, 0.13057300E+03, 0.54106700E+01, -.78131000E+03, 0.38564200E+03, 0.37813300E+03, 0.12894100E+03, -.72645700E+01, 0.22365500E+03, 0.31704100E+03, 0.36293900E+03, 0.54928700E+02, -.64017500E+02, 0.48429800E+02, 0.46734500E+02, 0.13061100E+03, 0.89760100E+02, -.12257000E+03, 0.14168400E+02, 0.50463800E+03, 0.25118000E+02, -.40088100E+03, 0.20535600E+03, 0.20716800E+03, 0.70717000E+02, 0.22265200E+03, -.90275100E+01, -.26486800E+03, 0.36298800E+03, 0.18011500E+03, 0.59008500E+02, -.28877700E+02, -.26606800E+02, 0.49434000E+02, 0.11157900E+03, -.10903700E+03, -.20583000E+03, -.31205100E+02, 0.71175300E+02, -.51998200E+01, 0.10277400E+02, 0.11386800E+01, 0.32155100E+02, -.51936700E+02, 0.14046200E+02, 0.13987700E+03, 0.25647900E+02, -.46370300E+02, 0.18884100E+03, -.94224900E+02, -.80389700E+02, 0.15012100E+03, 0.20280000E+02, -.15305300E+03, -.23114300E+03, -.35163000E+03, 0.42502600E+02, -.81179100E+02, 0.42390500E+02, 0.36577100E+02, 0.19908300E+02, -.59114600E+02, 0.20088700E+02, 0.90152800E+02, -.48212300E+02, -.38497100E+02, 0.92217000E+01, -.61312400E+01, -.28900200E+01, 0.20019200E+02, 0.12446200E+02, -.44550000E+01, -.64220100E+02, -.76920400E+02, 0.28643400E+01, -.79242500E+02, 0.44429100E+02, 0.73018300E+02, 0.38474900E+02, 0.68137500E+01, -.36678900E+02, 0.11872700E+02, 0.21914400E+03, 0.16395500E+02, -.20017900E+03, 0.11897600E+03, 0.98282000E+02, -.18767700E+03, -.69412500E+02, 0.18357200E+03, 0.18102900E+03, 0.28054200E+03, -.36060300E+02, -.77401800E+01, 0.75160100E+01, -.15001500E+02, -.53438400E+01, 0.24210600E+02, 0.12974600E+02, 0.51020200E+01, -.27904800E+02, 0.28243800E+01, -.17063800E+02, 0.19802600E+02, -.40696100E+02, -.38332900E+02, -.37977300E+02, 0.11888400E+03, -.26329300E+02, 0.27946100E+02, -.35524900E+02, -.11496200E+02, 0.87984700E+00, 0.35936100E+02, 0.19976300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11424000E+02, 0.61602000E+01, 0.18802400E+02, 0.79966300E+02, -.11355500E+02, -.24366500E+01, 0.64610300E+01, 0.40642300E+01, -.24681600E+02, 0.54673100E+01, -.58162000E+01, 0.18439100E+01, 0.13138900E+02, 0.71162200E+01, -.58291600E+00, 0.78036200E+01, 0.12637900E+02, 0.78490400E+01, 0.23997000E+01, -.59672300E+01, 0.80865200E+00, 0.18119400E+02, 0.40773000E+02, -.10655000E+01, 0.52059800E+01, -.20425800E+01, 0.18731000E+02, -.52209900E+01, -.43205600E+02, -.69707600E+01, 0.63784400E+01, -.11009600E+02, -.10840500E+01, -.22614900E+02, 0.44795900E+01, -.13675200E+02, 0.22419200E+01, 0.16539000E+01, 0.19517800E+01, -.44101700E+00, -.10882900E+01, -.50791000E+01, 0.24442000E+01, -.45244500E+01, 0.58125400E+01, -.67580100E+00, -.25860200E+02, 0.44392500E+01, -.29060200E+01, -.24882900E+01, 0.16306100E+01, -.10860400E+02, -.18765400E+01, -.58142500E+01, -.27600300E+01, -.22505500E+01, 0.32503600E+01, -.83858800E+01, 0.24248900E+01, 0.54866500E+01, -.19755000E+01, -.65839100E+01, -.25623000E+01, -.21792800E+01, -.10691500E+01, -.56323500E+01, 0.38801900E+00, 0.13108300E+01, -.44143500E+01, 0.37396300E+01, 0.21453200E+00, -.17256400E+01, -.33920900E+00, 0.11839400E+01, -.27713300E+01, 0.29253200E+01, -.16519600E+01, -.45375100E+01, -.49111200E+01, -.21253500E+01, 0.15089800E+00, 0.96487200E+00, -.70740200E+00, 0.11635100E+01, 0.14741500E+01, -.63014100E+00, -.12698400E+01, -.93442800E+00, -.19388100E+01, 0.25613700E+01, 0.25234100E+01, 0.70636100E-01, -.51007800E+02, -.39902900E+03, -.74194100E+02, -.33404700E+01, 0.23618100E+03, 0.58363000E+03, 0.20384500E+01, -.30144400E+04, 0.15114500E+04, 0.14862100E+04, -.30770400E+02, -.40793800E+03, 0.11402100E+04, 0.74714500E+03, 0.12751800E+04, -.28935300E+02, 0.96367700E+03, -.48659300E+03, -.41441500E+03, 0.69070400E+03, 0.61219800E+03, -.11687300E+04, -.56746000E+03, 0.30204600E+03, 0.35474000E+03, -.53467000E+02, 0.27113500E+02, 0.39874000E+02, 0.40450700E+03, 0.32503600E+03, -.37481200E+03, -.86063300E+03, -.30409300E+02, 0.21542600E+03, 0.28717800E+03, -.13752600E+03, -.15259500E+03, 0.29200300E+03, 0.11473000E+03, -.28972700E+03, -.33738700E+03, -.21109500E+03, 0.28525100E+02, -.88111500E+03, 0.45400100E+03, 0.44662200E+03, -.19219900E+03, -.26109800E+03, 0.41533700E+03, 0.49439100E+03, 0.53629600E+03, -.87556400E+02, 0.88671600E+03, -.45224200E+03, -.41504700E+03, 0.15362800E+03, -.11046500E+03, -.44960000E+03, -.61474000E+03, -.79115700E+03, -.20753900E+03, -.55537200E+03, 0.27834800E+03, 0.27301900E+03, 0.30827300E+03, 0.19586200E+03, 0.59992100E+02, -.21613500E+03, -.29167600E+03, 0.19598200E+03, -.14220000E+02, 0.82699700E+01, 0.48874500E+01, 0.35220500E+02, 0.61111200E+02, 0.67884300E+01, -.11336200E+03, -.13267300E+03, 0.16767100E+02, 0.72842900E+03, -.36156800E+03, -.24870800E+03, 0.24400100E+03, 0.22586400E+03, -.64228000E+03, -.26070200E+03, 0.10222800E+03, 0.11178600E+03, -.71546800E+03, 0.33026200E+03, 0.38946100E+03, -.29958100E+03, 0.99735300E+01, 0.42959100E+03, 0.56020700E+03, 0.43115300E+03, 0.14332600E+03, -.20976100E+02, 0.36542100E+02, -.32252600E+02, -.84747300E+01, 0.69753600E+02, 0.31722800E+02, 0.14703400E+02, -.36160300E+02, -.14787700E+02, -.11481400E+03, 0.66820600E+02, -.11210400E+03, 0.12276300E+03, -.27873800E+03, 0.16743300E+03, -.40223300E+02, 0.11529000E+03, 0.12243600E+03, -.57708000E+02, -.47976200E+00, 0.47670500E+03, -.26876300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.56180000E+01, 0.30618700E+01, 0.36807100E+01, 0.48436400E+02, -.92037500E+01, -.96200700E+00, 0.48354400E+01, 0.16157100E+01, -.10262100E+02, 0.29958500E+01, -.15584000E+01, -.92840600E-02, 0.44062900E+01, 0.15594300E+01, -.11289600E+01, 0.41440100E+01, 0.50282800E+01, 0.24364800E+01, 0.13467500E+01, -.29125300E+01, 0.58268800E+00, 0.44009000E+01, 0.14126300E+02, -.12331800E+01, 0.10373000E+01, 0.17118700E+01, 0.22480600E+02, -.26228400E+01, -.13047700E+02, 0.31305100E+01, 0.13585600E+01, 0.14310800E+00, 0.76011400E+00, -.71769300E+01, -.10550800E+00, 0.18267200E+01, 0.29803500E+01, 0.57670100E+00, 0.29095000E+00, 0.12358500E+01, 0.23656500E+01, -.20036000E+01, 0.45378700E+00, -.80698400E+00, -.10554900E+00, 0.61805700E+00, 0.13900300E+02, -.41529800E+00, 0.16944200E+01, 0.18767700E+01, -.46614000E-01, -.33964500E+01, -.14929100E+01, 0.44807900E+01, -.30133000E+01, -.11592800E+01, 0.10749900E+01, -.11325200E+01, 0.51023900E+00, -.34244700E+00, 0.78036400E+00, -.20468800E+01, 0.11962900E+01, 0.34857900E+00, -.23569500E+00, 0.78199100E+00, 0.17947200E+01, -.20333100E+00, -.31746700E+01, 0.11779900E+01, 0.12542600E+00, -.18685100E+00, 0.70147800E-01, 0.33259000E+00, -.46116800E+00, 0.51467600E+00, -.13762700E+00, -.35943000E+00, 0.10933700E+01, 0.16382900E+00, 0.86361900E-01, -.43589300E+00, -.31467200E+00, -.13000400E+00, -.50117400E+00, -.29214700E+01, -.35213100E+00, 0.19421000E-01, 0.15698200E+00, 0.18810700E+01, 0.58059300E+00, -.13886800E+00, 0.57260200E-01, 0.41384000E+03, 0.82150800E+02, -.83639300E+02, -.18829900E+03, -.30493100E+03, -.13916600E+01, 0.18930400E+04, -.94160200E+03, -.92063500E+03, 0.12888700E+02, 0.34258200E+03, -.84392600E+03, -.78462100E+03, -.83181300E+03, 0.50778200E+02, -.24087700E+04, 0.12012100E+04, 0.12069400E+04, 0.22513800E+03, 0.51070700E+03, 0.63515800E+03, -.26971000E+03, 0.51916200E+00, 0.64863400E+03, -.64519300E+03, 0.31723600E+03, 0.31708900E+03, -.84379100E+01, 0.21986000E+02, 0.29179500E+03, 0.32830800E+03, 0.29440700E+03, 0.55141600E+02, 0.45405500E+02, -.29307200E+02, -.29209100E+02, -.14461200E+03, 0.38087200E+02, 0.21374300E+02, 0.19450800E+03, 0.35505100E+03, 0.16320000E+02, 0.50284600E+03, -.26453600E+03, -.24186300E+03, 0.75546700E+02, 0.15809100E+03, -.29062300E+03, -.38885300E+03, -.40765000E+03, 0.10294700E+03, -.13582100E+04, 0.67558000E+03, 0.65129400E+03, -.30521500E+03, 0.37175600E+02, 0.51389400E+03, 0.49211800E+03, 0.92791300E+03, 0.23695700E+03, -.32416800E+03, 0.15948900E+03, 0.17881400E+03, 0.30254500E+02, 0.12040000E+03, 0.44490800E+02, 0.15413000E+02, 0.18631400E+03, 0.15950000E+03, -.36077700E+02, 0.18517000E+02, 0.18672800E+02, -.43038000E+02, -.51557400E+02, 0.55000800E+02, 0.11782200E+03, 0.17031500E+03, -.32247600E+02, -.15310700E+04, 0.75885000E+03, 0.74117000E+03, 0.12807600E+03, 0.32394100E+03, 0.35033000E+03, -.18670600E+03, 0.55952700E+01, 0.40976300E+03, 0.11927800E+04, -.59333000E+03, -.58813100E+03, 0.37707700E+03, 0.51439900E+01, -.57215200E+03, -.51834000E+03, -.68915200E+03, -.18181600E+03, 0.16109800E+02, -.12651600E+02, -.13542400E+02, 0.11905900E+02, -.50751200E+02, -.10348400E+02, -.92444400E+01, 0.31338200E+01, 0.33235700E+01, 0.16255000E+03, -.44835200E+02, 0.17330300E+03, -.88028600E+02, 0.99879900E+02, -.47570700E+02, -.39089700E+02, -.84822500E+02, 0.12915800E+03, 0.63191000E+01, 0.43552400E+00, -.12004100E+03, -.44092800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.35414700E+01, -.13795800E+01, -.26758500E+01, -.25808300E+02, 0.41827500E+01, 0.37114500E+00, -.21810900E+01, -.16535800E+01, 0.75187000E+01, -.16479800E+01, 0.23126100E+01, -.71293000E+00, -.47812600E+01, -.13789600E+01, 0.34944600E-02, -.21294800E+01, -.34322400E+01, -.12770400E+01, -.74353600E+00, 0.15960800E+01, -.37440300E+00, -.41458400E+01, -.67707600E+01, 0.95242700E+00, -.11317700E+01, -.88042700E+00, -.11123500E+02, 0.15173400E+01, 0.12416600E+02, -.48221000E+00, -.79063800E+00, 0.12796100E+01, -.68801300E+00, 0.28670500E+01, -.19215500E+00, 0.13657200E+01, -.42115600E+00, -.18684900E+00, 0.16663400E+00, 0.19251200E+00, -.10138900E+00, 0.10444400E+01, -.52723400E+00, -.75070600E+00, 0.10416100E+01, -.15713200E+00, -.38341600E+01, 0.10842200E+01, -.28169700E+00, 0.32633300E+00, -.17719600E+00, -.10960600E+01, 0.36648500E+00, -.10256100E+01, 0.61694900E+00, 0.32757200E+00, -.58908200E+00, -.36258300E+00, 0.57897700E-02, -.19886800E+00, -.12762400E+00, -.68039100E+00, 0.23763100E+00, 0.18155500E+00, 0.35758300E+00, -.11046600E+01, -.68567000E-01, 0.19322000E-01, -.43890700E+00, -.49181700E+00, -.69087900E-01, 0.78148400E+00, -.86452400E+00, 0.56499600E+00, -.46680500E+00, -.62317100E+00, 0.11969100E+00, 0.46535800E-01, -.28784300E+01, -.61278600E-01, 0.28731300E-01, 0.56927800E-01, -.87714300E+00, 0.22713400E+00, -.84320600E-01, 0.10684300E+01, -.12067100E+00, -.93486700E-01, -.57703400E+00, -.39004400E+00, 0.19092800E+00, -.48288300E+00, -.18332200E+00, -.18648200E+00, 0.93949000E+02, -.32048000E+01, 0.82119900E+02, 0.16358800E+03, 0.95570500E+02, -.15537900E+04, 0.74631400E+03, 0.67227600E+03, 0.18555400E+03, -.11901600E+03, 0.48226700E+03, 0.48074300E+03, 0.69203900E+03, 0.48874300E+02, -.45587800E+02, 0.37843900E+02, 0.14479800E+03, 0.38306900E+03, 0.21935900E+03, -.18834400E+03, -.80923300E+02, 0.78790200E+03, 0.21805200E+03, -.60128900E+03, 0.30180400E+03, 0.35608300E+03, 0.15544200E+03, 0.33692100E+03, -.38602600E+02, -.40597000E+03, 0.54876800E+03, 0.27910700E+03, 0.20375400E+03, -.90552800E+02, -.76293500E+02, 0.54011600E+02, 0.15919300E+03, -.20257100E+03, -.26297500E+03, -.26148500E+02, 0.78556400E+02, 0.33221300E+02, -.22451600E+02, -.52157200E+02, 0.22380700E+02, -.12518500E+03, -.35955800E+01, 0.17263800E+03, 0.61313500E+02, -.60263700E+02, 0.12522500E+03, -.74290000E+02, 0.10923400E+02, 0.17379000E+03, 0.36404600E+02, -.21933800E+03, -.35077300E+03, -.46552600E+03, 0.83133200E+02, -.44792000E+03, 0.22884400E+03, 0.24927100E+03, 0.44020300E+02, -.46511500E+02, 0.17300300E+03, 0.18801000E+03, 0.13547600E+03, 0.19734300E+02, 0.37755500E+02, -.65134100E+01, -.12908800E+02, 0.47667700E+02, 0.28113100E+02, -.26183500E+01, -.12012700E+03, -.99309900E+02, 0.71481200E+01, -.17403000E+03, 0.88618500E+02, 0.16281400E+03, 0.18549600E+03, 0.10928700E+03, -.83141200E+02, -.55900600E+02, 0.33413800E+03, 0.15389500E+03, -.48639000E+03, 0.28431400E+03, 0.21219000E+03, -.21596300E+03, -.94163200E+02, 0.31904400E+03, 0.35042900E+03, 0.38691300E+03, -.21437200E+02, 0.27930000E+00, 0.22649700E+02, -.37202100E+02, -.29181100E+01, 0.26080800E+02, 0.32189900E+02, 0.80149700E+01, -.53808100E+02, 0.96115000E+01, -.46079800E+02, 0.30956000E+02, -.69169100E+02, -.32600300E+02, -.42671000E+02, 0.17247900E+03, -.57296200E+02, 0.65506300E+02, 0.23455900E+02, -.51522000E+02, 0.28546600E+01, 0.91182600E+02, 0.15951500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.36013600E+00, 0.41334800E-01, 0.16479800E+00, 0.10470500E+01, -.35053200E+00, -.13453700E+00, -.23322300E-01, 0.42703800E+00, -.12430000E+00, 0.95555300E-01, -.24282500E+00, 0.27586900E-01, 0.31696800E+00, 0.16571700E+00, 0.16395100E+00, 0.99089500E+00, 0.23636400E+00, 0.40644600E+00, 0.80692100E-01, -.19079800E+00, 0.15375800E-01, 0.11231400E+00, 0.13552000E+01, -.96355200E-02, 0.13449500E+00, 0.10748500E+00, 0.31928600E+00, 0.15366100E+00, 0.15816300E+01, 0.63460300E-01, 0.68930700E-01, 0.16148800E+00, 0.33933900E-01, 0.20161000E+00, 0.73993400E-01, -.32745100E+00, -.20783200E+00, -.59092100E-02, 0.25827900E+00, -.10803400E-01, -.24142900E+00, -.27457900E-01, -.50414500E-01, 0.10886700E+00, 0.21625000E-01, -.14099900E-01, 0.10784300E+00, -.10530100E+00, 0.15957500E-01, 0.57597000E-02, 0.35509700E-02, 0.26406300E+00, 0.65803500E-01, 0.24672400E+00, -.52085800E-02, 0.49225300E-01, -.19755900E-01, 0.26654300E+00, -.37657900E-01, -.76214600E-01, 0.10412300E+00, 0.25653700E+00, 0.11231800E-01, -.14171100E-01, 0.45819100E-01, 0.19232200E+00, 0.96278600E-02, -.11430800E-01, -.10044500E+00, 0.63385000E-01, -.16828900E-01, -.79672700E-01, 0.42363900E-01, 0.11770500E-01, -.17129400E-01, 0.53601200E-02, 0.12351900E-01, 0.47171500E-02, 0.20389700E+00, -.10690100E-01, -.92053500E-02, -.87943400E-01, -.50677300E-01, 0.23015700E-01, -.13328600E-01, -.21808200E-01, 0.15913300E-01, 0.13626200E-01, 0.39173400E-01, -.15435600E+00, 0.10202700E+00, 0.83645000E-02, 0.12092200E-01, 0.33596100E-01, -.86912100E-02, 0.54332200E+01, 0.72672500E+01, -.84839400E+01, 0.50690800E+01, -.62045400E+02, 0.30160000E+02, 0.27467200E+02, 0.28092800E+02, 0.22590600E+02, 0.55803500E+01, 0.15819400E+02, 0.14328800E+02, 0.20717700E+02, 0.13908200E+03, -.68855700E+02, -.66038600E+02, 0.10063400E+02, -.26434700E+01, -.44384700E+02, 0.25347700E+02, -.19279300E+02, -.94517400E+01, 0.35260600E+02, -.17379500E+02, -.16243000E+02, 0.97495300E+00, 0.58358000E+01, -.17404000E+02, -.15654100E+02, 0.22102600E+01, 0.63979500E+00, -.33102100E+01, 0.20197300E+01, 0.24071400E+01, -.49632400E+00, 0.10164100E+02, -.51363800E+01, -.20379800E+02, -.29358400E+01, 0.11718300E+02, 0.35130000E+01, -.84494700E+00, -.30620500E+01, 0.73416000E+01, 0.43846000E+01, 0.14125000E+00, 0.12105100E+02, -.24792900E+01, -.63745900E+01, -.73282500E+02, 0.36780600E+02, 0.38456900E+02, 0.18254800E+02, 0.25551100E+02, 0.68480500E+01, -.12347400E+02, 0.37757400E+01, 0.25270600E+02, 0.11134200E+02, -.54640200E+01, -.49196400E+01, -.12066700E+02, -.16983800E+02, 0.50752900E+01, 0.15688700E+02, 0.32915500E+00, -.16390300E+02, 0.90590200E-01, 0.96424700E-01, 0.27835100E+00, 0.13525600E+01, 0.16701800E+00, 0.28920800E+00, -.45419600E+01, -.84569200E+01, 0.28056800E+00, 0.66412800E+02, -.32788700E+02, -.30377000E+02, 0.10030800E+02, 0.54423100E+01, -.25053500E+02, 0.59715300E+01, -.12233800E+02, 0.24136900E+01, 0.50477000E+01, 0.24904000E+00, -.15589500E+01, -.16682500E+02, -.19209700E+02, 0.11838400E+02, -.78699800E+00, 0.19516800E+02, -.13333000E+02, -.35477200E+00, 0.57376900E+00, -.49533700E+00, -.11950300E+01, 0.16420600E+01, 0.22784600E+01, 0.35288200E+00, -.33703100E+01, 0.16960200E+01, -.94483400E+01, 0.13573300E+01, -.94728500E+01, -.98522100E+01, -.39670400E+01, 0.72116200E+01, -.20670700E+01, -.72500800E+00, -.48028400E+01, -.79250800E+00, 0.27812400E-01, 0.13124000E+02, 0.33599900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.26718500E+01, -.13429600E+01, -.24287400E+01, -.29319100E+02, 0.29113900E+01, 0.41808800E+00, -.18044900E+01, -.56335800E+00, 0.71315800E+01, -.14836000E+01, 0.26890600E+01, -.56834200E+00, -.35173800E+01, -.64859500E+00, 0.25701400E+00, -.24476600E+01, -.25273000E+01, -.15461800E+01, -.95216500E+00, 0.10158800E+01, -.36678900E+00, -.34537100E+01, -.33136200E+01, 0.62654800E+00, -.42927600E+00, -.27174700E+00, -.76715500E+01, 0.11957600E+01, 0.92918200E+01, -.13880900E+01, -.10027700E+00, 0.63499600E+00, -.14895400E+01, 0.35108600E+01, 0.49263500E+00, -.53077100E+00, -.17143100E+01, -.18659900E+00, 0.13836100E+01, -.22141200E+00, -.12611300E+01, 0.21629400E+01, -.18419700E+01, 0.45522100E+01, 0.25362000E+00, -.11095500E+00, 0.58675700E+01, -.11408800E+00, 0.10941600E+01, 0.14902600E+00, -.11637200E+01, 0.12846300E+01, 0.17992000E+01, -.99865800E-01, 0.11956400E+01, -.66895800E+00, 0.36474900E+00, 0.46134100E+00, 0.12347200E-01, 0.11731700E+00, 0.32965500E-01, -.11171600E+01, -.12545500E+01, -.31776200E+00, 0.31842200E+00, 0.15255800E+01, 0.22542000E+00, 0.16507800E+00, 0.89646200E+00, 0.22271100E-01, -.61277800E-01, -.22500300E-01, -.26755900E-01, 0.65526400E-01, 0.94160400E-01, 0.28538900E+00, -.20621700E+00, -.55017900E+00, -.13158300E+01, 0.20773200E-01, -.75945000E-01, -.17980400E+00, -.67182700E+00, 0.14925100E+00, -.11453400E+01, 0.52622900E+01, -.10716000E+00, -.51050500E+00, -.13876300E+01, 0.88073300E+00, 0.74062000E+00, -.27284700E+00, 0.16114000E-01, -.15042900E+00, -.71204700E-01, -.16473700E+01, 0.10825400E+03, 0.19697200E+03, -.21934600E+02, -.38173000E+03, 0.19090900E+03, 0.17185700E+03, -.17036100E+01, -.10666900E+03, 0.14952700E+03, 0.15710700E+03, 0.22525900E+03, -.22148400E+02, 0.16611900E+04, -.83259600E+03, -.85186500E+03, 0.25891200E+03, -.23298300E+02, -.69813800E+03, -.89801100E+02, -.10660200E+03, -.22348800E+03, 0.41955800E+03, -.20968400E+03, -.20990100E+03, 0.12652600E+03, -.12776200E+02, -.21429900E+03, -.20785800E+03, -.19061900E+03, -.33186700E+02, 0.15753300E+03, -.76418500E+02, -.78914100E+02, 0.95795100E+02, 0.33303400E+02, -.13464800E+03, -.23768400E+03, -.10388600E+03, 0.38536600E+02, -.28710900E+03, 0.14225600E+03, 0.14481100E+03, -.14392300E+03, -.10307800E+03, 0.19060500E+03, 0.30222600E+03, 0.22467900E+03, -.11256500E+03, -.26702800E+03, 0.12787600E+03, 0.12824400E+03, 0.55405600E+02, 0.93195100E+02, 0.88364700E+01, -.11650500E+03, 0.11210900E+02, 0.49680600E+02, -.55744100E+02, 0.28584600E+02, 0.16479500E+02, 0.38141100E+02, -.30487900E+02, 0.52279500E+02, 0.94886300E+01, 0.18200500E+02, -.64561500E+02, -.56328900E+02, 0.29640900E+02, 0.25277100E+02, 0.68407500E+01, 0.13786100E+02, 0.21472300E+02, -.25980200E+02, -.38826100E+02, 0.19877700E+02, 0.70701500E+03, -.35213800E+03, -.35520200E+03, 0.90758400E+02, -.13026100E+02, -.30379300E+03, -.64158600E+02, 0.79436900E+02, -.98365000E+02, -.77852800E+02, 0.33647900E+02, 0.47382100E+02, -.55030000E+02, -.95377400E+02, 0.81259300E+02, 0.72341000E+02, 0.91596800E+02, -.75791800E+01, -.52779900E+01, 0.15640300E+02, -.16464900E+02, -.15459700E+01, 0.21452500E+02, 0.65598800E+01, 0.45892700E+01, -.10250600E+02, -.13408600E+01, -.11460100E+03, 0.17100000E+02, -.11713000E+03, 0.26799700E+02, -.69913200E+02, -.36603600E+01, -.57809200E+01, 0.53659500E+02, 0.57463400E+02, -.28684600E+02, -.14664100E+00, 0.11998500E+03, 0.19661400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.60329400E+01, 0.25963800E+01, 0.97683400E+01, 0.37171900E+02, -.31321700E+01, -.43751800E+00, 0.30105800E+01, 0.26979800E+01, -.14695500E+02, 0.28392700E+01, -.48000700E+01, 0.28576800E+01, 0.67425400E+01, 0.34083300E+01, -.14502600E+01, 0.52654600E+01, 0.81257700E+01, 0.68842400E+01, 0.19660000E+01, -.40910600E+01, 0.58918300E+00, 0.96054600E+01, 0.26217500E+02, -.88658500E+00, 0.41759500E+01, 0.95686100E-01, 0.71923300E+01, 0.21195300E+00, -.41206200E+01, -.33820100E+01, 0.33483200E+01, -.47847700E+01, 0.39633500E+00, -.49275900E+01, 0.37112600E+01, -.10989000E+02, -.14066100E+01, 0.39225200E+00, 0.36908000E+01, -.11149300E+01, -.29613500E+01, -.21406500E+01, 0.10318600E+01, 0.28061300E+01, 0.17243000E+01, -.11832000E+01, -.41846700E+01, -.49788600E+00, -.31426000E+00, -.39755300E+00, 0.23733500E+00, -.19491500E+01, 0.13206600E+01, -.18552300E+01, 0.15698500E+01, -.18275600E+01, 0.24869000E+01, -.13302800E+01, 0.42597500E+00, 0.16595000E+01, -.10654700E+01, 0.11603400E+01, -.33593800E+01, -.97350200E+00, -.16494100E+00, 0.11554600E+01, -.15083800E+01, 0.54768400E+00, 0.25260700E+01, 0.88980600E+00, -.26507300E+00, -.34255000E+00, 0.11551300E+00, 0.72183000E-01, -.83025700E+00, 0.34657500E+00, -.11524900E+01, -.11333700E+01, 0.18822700E+01, 0.20982300E+00, 0.89827600E-01, 0.18785800E+01, 0.61366300E+00, 0.16683000E+00, 0.82233200E+00, -.39747500E+01, -.33542200E+00, 0.28724100E+00, -.15509100E+01, 0.16305300E+01, -.26080400E+00, 0.31999500E+00, 0.10633800E+00, -.37501500E+00, 0.68335900E+00, 0.32669800E+01, -.47994900E-01, -.33335600E+03, -.90514600E+02, 0.16532200E+04, -.79683900E+03, -.74772900E+03, -.84515800E+02, 0.10773700E+03, -.53893700E+03, -.42959500E+03, -.74416200E+03, -.64221900E+02, -.12497800E+04, 0.61190700E+03, 0.53562200E+03, -.43898500E+03, -.58766100E+02, 0.52889200E+03, 0.32198800E+03, -.16889400E+03, -.92299000E+02, 0.27048800E+03, -.14084900E+03, -.18088200E+03, -.22182500E+03, -.23749300E+03, 0.12028600E+03, 0.32781300E+03, -.34734300E+03, -.19523200E+03, -.32603700E+03, 0.15157800E+03, 0.14028500E+03, -.47971400E+02, -.65371600E+02, 0.21084400E+03, 0.17601200E+03, 0.39704400E+02, 0.13110400E+02, 0.11923300E+03, -.59241700E+02, -.23243400E+02, 0.14262200E+02, 0.11332600E+03, -.85438600E+02, -.21252900E+03, -.16155800E+03, 0.24616300E+02, -.12037000E+03, 0.54410100E+02, -.30341600E+00, -.76410200E+02, -.48094100E+02, 0.20938700E+03, 0.23985800E+03, 0.29914500E+03, -.59379600E+02, 0.27155600E+03, -.14012600E+03, -.14948000E+03, -.41477200E+02, 0.56872300E+02, -.18233300E+03, -.15175900E+03, -.17776700E+03, -.22355800E+02, -.29468400E+02, 0.81884100E+01, 0.84714700E+01, -.38006700E+02, -.21936800E+02, -.66928600E+01, 0.94437200E+02, 0.95739500E+02, -.39081600E+01, -.68115400E+03, 0.33851000E+03, 0.26246300E+03, -.14939400E+03, -.72443400E+02, 0.32932900E+03, 0.14633300E+03, 0.81357200E+02, -.49377200E+02, 0.26206800E+03, -.18025600E+03, -.10594100E+03, 0.99488200E+02, -.38362700E+02, -.17692300E+03, -.21308000E+03, -.22994800E+03, -.61436700E+02, 0.30573200E+01, -.21767800E+02, 0.32711000E+02, 0.31998200E+00, -.18974200E+02, -.24210800E+02, -.77727300E+01, 0.35665400E+02, -.88731300E+01, 0.62651500E+02, -.21758700E+02, 0.68725300E+02, -.37856700E+02, 0.50202000E+02, -.10513500E+03, 0.52591700E+02, -.69818400E+02, -.12970600E+03, 0.65699700E+02, -.26198700E+01, -.17620200E+03, -.12110200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13177700E+01, 0.11751600E+01, 0.18275200E+01, 0.62849700E+01, -.19593300E+01, 0.38949200E+00, 0.13911900E+01, 0.12756500E+00, -.30379500E+01, 0.87518300E+00, -.10167200E+00, -.22741500E+00, 0.11451700E+01, 0.23155600E+00, 0.80679700E-01, 0.13876500E+01, 0.76529700E+00, 0.71740600E+00, 0.23976100E+00, -.53112000E+00, -.15001800E-01, 0.18762700E+01, 0.37018800E+01, 0.23014700E+00, 0.73434600E+00, -.31997000E+00, -.23029200E+01, 0.23284500E+00, -.11507800E+01, -.10454400E+01, 0.82393000E+00, -.14724300E+01, -.29093400E+00, -.17851800E+01, 0.97301300E+00, -.14353700E+01, 0.43340300E+00, 0.12224700E+00, 0.66807800E+00, -.15285900E+00, -.43713300E+00, -.36597900E+00, 0.22136200E+00, 0.14718500E+00, -.49661100E-02, -.22917700E+00, -.26507000E+01, 0.12691600E+00, -.37022500E+00, -.64421000E+00, 0.58000600E-01, -.31498600E+00, 0.55023700E-02, -.93184400E+00, -.57633400E-01, -.19759800E+00, 0.83554700E-01, -.52175400E+00, 0.14681700E-01, 0.48946800E+00, -.34491600E+00, -.69958900E-01, -.23778700E+00, -.29993400E+00, -.36501700E+00, -.85324500E+00, -.31114500E+00, 0.18718900E+00, 0.10189200E+01, 0.24247000E+00, 0.69729400E-01, -.47138400E+00, 0.45016300E+00, -.12892300E+00, 0.25758300E+00, 0.52966600E+00, -.12476900E+00, -.19970500E+00, 0.22805700E+00, -.12628900E+00, 0.40253900E-02, 0.51455700E+00, 0.37302300E+00, -.26897500E-01, 0.42956500E+00, -.18086400E+01, -.41841700E-01, 0.55327400E-01, 0.22726300E+00, 0.36245400E+00, -.63990300E-01, -.78010700E-01, 0.36286900E-01, -.12482200E+00, -.14421000E-02, 0.71296800E+00, -.75134400E-01, -.28502700E-01, -.41105100E+02, 0.28783000E+03, -.14193000E+03, -.12810300E+03, -.44309000E+02, -.38481500E+02, -.72269700E+02, -.69166700E+02, -.81767700E+02, -.55212300E+02, -.54770900E+03, 0.27130600E+03, 0.26348100E+03, -.44647000E+02, 0.40424500E+02, 0.17258000E+03, -.29794600E+02, 0.10567000E+03, 0.18174300E+02, -.38306600E+02, 0.18479800E+02, 0.15298800E+02, -.24682200E+02, -.16472000E+02, 0.38263900E+02, 0.59703600E+02, -.19415700E+02, 0.69914100E+00, -.17395800E+02, 0.77931000E+01, 0.63078200E+01, -.59113300E+01, -.15072800E+02, 0.22976000E+02, 0.55798700E+02, 0.26530800E+02, -.11656700E+02, 0.45065200E+02, -.25081200E+02, -.18754100E+02, -.14359300E+02, -.12929300E+02, -.18804000E+02, -.38804000E+02, -.19992800E+02, -.56938500E+01, 0.72847100E+02, -.36490700E+02, -.42890000E+02, -.47718300E+02, -.40965500E+02, 0.28050400E+02, 0.78459500E+02, 0.21416900E+02, -.48795100E+02, 0.30730100E+02, -.15645400E+02, -.16189100E+02, 0.17906900E+02, 0.31972900E+02, -.31433500E+02, -.32308700E+02, -.26067800E+02, 0.64751800E+01, -.75979800E+01, 0.36332600E+01, 0.33675200E+01, -.55506500E+01, -.66887200E+01, 0.31348300E+01, 0.21412700E+02, 0.20906100E+02, 0.73602900E+00, -.32827600E+03, 0.16345000E+03, 0.15782500E+03, -.27739700E+02, -.48752800E+01, 0.11715500E+03, -.27530400E+01, 0.10798700E+03, -.38269500E+01, 0.12683000E+03, -.69807800E+02, -.61732700E+02, 0.41448100E+02, 0.24604600E+02, -.80165300E+02, -.60184500E+02, -.10185000E+03, 0.19420000E+02, 0.22447100E+01, -.17316300E+01, 0.82940700E+01, 0.18318500E+01, -.43934300E+01, -.85526500E+01, -.18108600E+01, 0.96372500E+01, 0.27111900E+00, 0.25059700E+02, -.47068800E+01, 0.20777000E+02, 0.23015700E+01, 0.20218400E+02, -.18017000E+02, 0.42622700E+01, -.26229400E+01, 0.90165500E+00, 0.91839000E+01, -.13415500E+00, -.66849500E+02, -.58525600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.16254300E+01, -.83409200E+00, -.12836500E+01, -.16321800E+02, 0.17222400E+01, 0.14165500E+00, -.14461800E+01, -.52204300E+00, 0.43669400E+01, -.96550600E+00, 0.14017300E+01, -.10426100E+00, -.23058000E+01, -.40438100E+00, 0.39366000E-01, -.15423200E+01, -.14128100E+01, -.10774000E+01, -.39027300E+00, 0.57354500E+00, -.20162100E+00, -.18362400E+01, -.19829200E+01, 0.40852200E+00, -.40065800E+00, -.44030600E+00, -.59944400E+01, 0.69488500E+00, 0.49923200E+01, -.11061200E+01, -.15813500E+00, 0.10857800E+00, -.75387700E+00, 0.16054000E+01, 0.28322000E+00, -.79350000E+00, -.10599100E+01, -.64606900E-01, 0.88247100E+00, -.84833400E-01, -.77378700E+00, 0.10416400E+01, -.64125500E+00, 0.13444400E+01, 0.34501200E+00, 0.18429900E+00, 0.21258300E+01, 0.50875200E-01, -.19419000E+00, 0.47471700E+00, -.38719600E+00, 0.17085000E+01, 0.55693300E+00, 0.16248400E+00, 0.52055700E+00, -.20292900E+00, 0.90999500E+00, -.33387200E+00, 0.46184200E-01, -.16138500E-01, -.51581300E-01, 0.28052000E-01, -.11541200E+01, 0.94471800E-01, 0.53841400E+00, 0.18680600E+01, 0.60174300E+00, 0.64603300E-01, 0.16755400E+00, -.95634100E+00, -.34852900E+00, 0.91498600E-01, -.81432300E-02, 0.65680800E-01, -.63643000E-02, -.53499100E+00, 0.66208100E-01, -.16391800E-01, 0.18239400E+00, 0.12433100E+00, -.65075600E-01, -.53873900E-01, -.28653200E+00, -.65409300E-01, -.35740700E+00, 0.26502400E+01, 0.36466600E-01, -.15583900E+00, -.75350400E+00, -.27145600E+00, 0.87397000E+00, 0.87158800E-01, 0.40334000E-02, -.12742200E+00, -.25211800E-01, -.62991500E+00, 0.31974800E+00, -.52236100E-01, -.55039500E+00, 0.46746000E+03, -.23231100E+03, -.21744800E+03, -.43751900E+02, 0.49958000E+02, -.19380500E+03, -.30421800E+03, -.26459600E+03, 0.35378000E+00, -.22760800E+03, 0.11327200E+03, 0.10285700E+03, -.22900400E+02, 0.16097200E+03, -.36271500E+01, -.15129300E+03, 0.10432600E+01, 0.15619600E+03, 0.14592300E+03, -.73191300E+02, -.74455400E+02, 0.45028200E+02, -.41359200E+02, -.53158700E+02, -.26409500E+02, -.20587000E+03, -.50416400E+02, -.77133200E+02, 0.37057300E+02, 0.37873300E+02, 0.27931600E+02, -.22713100E+02, 0.20021900E+02, 0.34880100E-02, -.31039900E+02, -.20758400E+02, -.14243100E+03, 0.69538800E+02, 0.72404300E+02, -.57052600E+02, 0.59785700E+02, 0.46691000E+02, -.32804700E+02, 0.14275500E+02, 0.22293000E+02, -.34262900E+01, 0.99345200E+00, 0.51650300E+01, -.18834800E+03, -.64737200E+02, 0.10970200E+03, 0.25707000E+03, 0.17121300E+03, -.11656300E+03, 0.56746700E+02, -.28587800E+02, -.32578000E+02, 0.18171000E+02, 0.33994900E+02, -.27261300E+02, -.62870600E+02, 0.13842400E+02, 0.34210900E+02, -.35154100E+02, 0.17215200E+02, 0.18776200E+02, -.22175100E+02, -.36283600E+01, 0.18511300E+02, 0.51528200E+02, 0.30053400E+02, 0.64540700E+01, -.12280700E+03, 0.63102500E+02, 0.67308600E+02, 0.17424700E+02, 0.10041300E+03, -.11132700E+02, -.93958400E+02, 0.37776000E+01, 0.77604300E+02, 0.14733700E+03, -.79626800E+02, -.74579300E+02, 0.12416900E+03, 0.19196000E+02, -.94648600E+02, -.10444600E+03, -.10661600E+03, 0.88086500E+01, 0.42289200E+01, -.18671700E+01, -.17518600E+01, -.62674800E+00, -.62415400E+01, -.50628900E+01, -.28824200E+01, 0.10506700E+02, -.32196900E+01, 0.22935100E+02, -.62201200E+01, 0.28335900E+02, -.82451500E+01, -.38841000E+02, -.38915300E+02, 0.12190600E+02, -.19174400E+02, 0.24042600E+02, 0.62256200E+01, -.14435800E+01, 0.54189000E+02, -.15272500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.71956900E+01, -.41040300E+01, -.54000700E+01, -.60926700E+02, 0.94695700E+01, 0.11376600E+01, -.51009800E+01, -.18400800E+01, 0.13408500E+02, -.37464100E+01, 0.28544400E+01, -.10956800E+01, -.72857500E+01, -.28511600E+01, 0.16262600E+01, -.35876600E+01, -.66847600E+01, -.38757500E+01, -.11149000E+01, 0.30881600E+01, -.71556900E+00, -.69640100E+01, -.18216900E+02, 0.18462900E+01, -.18966400E+01, -.94894700E+00, -.19795700E+02, 0.37936600E+01, 0.16630500E+02, -.39249100E+00, -.22910100E+01, 0.17484500E+01, 0.29480800E-01, 0.80986700E+01, -.13191900E+01, 0.26968600E+01, -.11029300E+01, -.59127900E+00, -.16101300E+01, -.17507400E+00, 0.76132100E-01, 0.15877700E+01, -.58025100E+00, 0.41079900E+00, -.74163300E+00, -.53011700E+00, 0.46690400E+01, -.15453700E+00, 0.26177100E+00, -.77812400E+00, 0.53412000E+00, -.39856700E+01, 0.30978300E+01, 0.99548700E+00, 0.33264700E+01, -.14016700E+01, 0.27326100E+01, 0.30880600E+01, 0.21669700E+00, 0.76954500E+00, -.27747000E+00, 0.32173000E+00, -.20939600E+00, -.40982500E+00, 0.29870500E+00, -.18190500E+01, -.77368700E+00, 0.17974700E+00, 0.28824500E+01, -.19789500E+01, -.36870300E+00, 0.77176400E+00, -.14253000E+00, 0.19575800E+00, 0.17062200E+00, -.11510800E+01, -.34573300E+00, 0.37585000E+00, -.14097300E+01, 0.53220000E-01, -.29242800E+00, 0.69516200E+00, -.69319300E+00, 0.88605400E-01, 0.68282300E-01, 0.39936700E+00, -.11812600E+00, -.41984200E+00, -.19931300E+01, -.80381200E+00, 0.31862600E+00, 0.13732000E+00, -.11508400E+00, -.98735400E+00, -.10666200E+01, 0.16793900E+01, 0.11366900E+01, 0.45659800E+00, -.72410800E+00, -.28139200E+01, -.42540800E+02, -.57700300E+02, 0.13153700E+03, 0.24823200E+03, -.28402700E+03, -.64588200E+03, -.22663900E+03, 0.16876100E+03, -.31690400E+04, 0.16017800E+04, 0.17090100E+04, 0.45687400E+03, 0.13777700E+04, 0.25494800E+03, -.84165800E+03, 0.25589900E+03, 0.14879400E+04, -.91033100E+03, 0.45490800E+03, 0.52286400E+03, 0.21701900E+03, 0.33382500E+03, 0.78120800E+02, -.26682500E+03, 0.20486000E+03, 0.24644500E+03, 0.11767900E+03, -.46968300E+02, -.30909800E+02, 0.86999000E+02, 0.14564500E+03, -.15925600E+03, -.68190400E+02, -.49935400E+02, 0.36409900E+02, -.14342400E+03, 0.71052500E+02, 0.29822500E+02, -.23026700E+02, 0.22258200E+03, -.57006800E+02, -.20254500E+03, -.15208300E+03, 0.17528300E+03, 0.41878000E+03, -.22588400E+03, -.10925000E+03, -.48451700E+03, -.23946100E+03, 0.23607500E+01, 0.43215700E+03, 0.23393900E+03, -.20743800E+03, -.39532100E+03, 0.20363600E+03, 0.22736300E+03, 0.83814800E+02, 0.11111900E+03, 0.86129900E+02, 0.53866500E+01, 0.55075600E+02, 0.23061700E+03, -.41266500E+02, 0.33646400E+02, 0.35852700E+02, -.41533000E+02, -.26903700E+02, 0.72132500E+02, 0.65694700E+02, 0.51937100E+01, -.15108500E+02, -.14297200E+04, 0.72496900E+03, 0.84868200E+03, 0.32158700E+03, 0.71854100E+03, -.23281600E+02, -.51716600E+03, -.32211700E+02, 0.78199000E+03, -.84480400E+02, 0.89082200E+02, -.64892300E+01, 0.26739400E+03, -.21584100E+02, 0.36300100E+02, -.14171200E+01, -.96431000E+01, -.10691800E+03, 0.20347000E+02, 0.10464500E+02, -.38164800E+02, -.94441700E+01, -.10966900E+02, 0.18869200E+02, -.41569500E+01, -.27198800E+02, 0.54540300E+01, 0.12958900E+03, 0.26823100E+01, 0.14606100E+03, -.10619900E+03, -.16916300E+03, 0.73158000E+02, -.42353300E+02, -.38451000E+02, 0.23771700E+03, -.43273100E+01, -.17812700E+01, 0.35792800E+03, -.51256800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.17320000E+01, 0.67320600E+00, 0.29300700E+01, 0.11914400E+02, -.13743700E+01, -.35823500E+00, 0.96571500E+00, 0.69917800E+00, -.42036900E+01, 0.74034300E+00, -.13886200E+01, 0.62176700E+00, 0.20141000E+01, 0.93022200E+00, -.16754300E+00, 0.14085800E+01, 0.20030200E+01, 0.12471100E+01, 0.56648700E+00, -.10212100E+01, 0.13392800E+00, 0.26940000E+01, 0.63174700E+01, -.25046300E+00, 0.93333200E+00, 0.87413500E-01, 0.38578900E+01, -.42513400E+00, -.45425000E+01, -.58783800E+00, 0.68800600E+00, -.11908100E+01, 0.23490200E+00, -.16974300E+01, 0.58241600E+00, -.22287900E+01, -.32634300E+00, 0.14298500E+00, 0.57502300E+00, -.16469200E+00, -.46082200E+00, -.74252900E+00, 0.25337000E+00, 0.51683700E+00, 0.16946100E+00, -.11405100E+00, -.51220000E+00, -.66868800E+00, -.55455400E-01, -.11002300E+00, -.53164100E-01, -.21462800E+00, 0.37623300E+00, -.36838500E-01, 0.53313200E+00, -.24446700E+00, 0.73446800E-01, 0.27319200E+00, -.83929700E-01, 0.18717300E+00, -.17052700E+00, 0.14712400E+00, -.54084100E+00, 0.69133000E-01, 0.25624600E+00, 0.41867800E+00, 0.40486400E-01, 0.12030300E+00, 0.29066100E+00, -.31556700E+00, -.15053000E+00, -.18946900E+00, 0.36659100E+00, -.11050700E+00, -.91797300E-01, -.96647800E-01, -.27728000E+00, 0.15004800E+00, 0.14611600E+01, 0.51766900E-01, -.60771600E-01, 0.20680100E+00, 0.17558000E+00, 0.19466500E+00, 0.30514500E+00, -.46434400E+00, -.37829200E-01, 0.48579300E-01, -.84580400E-01, 0.54820500E+00, -.21329200E+00, -.12437000E-01, -.99913700E-01, -.18752300E+00, 0.88266200E-01, -.12426200E+00, 0.14677200E+00, 0.15402800E+00, 0.19851300E+00, -.56884700E+00, 0.36811900E-02, -.40955600E+02, 0.20054100E+02, 0.39983600E+02, -.37547600E+02, -.15111900E+03, -.74887700E+02, 0.29767600E+02, -.50874000E+03, 0.25453500E+03, 0.29346000E+03, 0.82675300E+02, 0.17104500E+03, 0.78920500E+02, -.14865600E+03, 0.98003300E+02, 0.17378000E+03, -.27966000E+02, 0.14035700E+02, 0.35081400E+02, 0.23418500E+02, 0.68279700E+01, 0.33174900E+01, -.19651400E+02, -.18542200E+02, 0.14750300E+01, -.28908800E+02, 0.14087100E+02, 0.22620700E+02, 0.10620900E+02, -.11392200E+02, 0.12338500E+02, 0.38349400E+02, 0.22680400E+02, -.15216600E+02, -.74348800E+02, 0.37923800E+02, 0.22642300E+02, -.17417200E+02, 0.27447400E+02, 0.17893600E+02, -.35513300E+02, 0.34700400E+01, 0.20910300E+02, -.51401600E+02, 0.25996500E+02, 0.49561200E+02, -.83117700E+02, -.31703800E+02, 0.54500900E+02, 0.90801200E+02, 0.40356800E+02, -.34763400E+02, -.23080800E+02, 0.11531200E+02, 0.27217500E+02, 0.30663900E+02, 0.27990500E+02, -.10749900E+02, -.36241200E+02, -.15284100E+02, 0.31952000E+02, -.17995100E+02, 0.87296500E+01, 0.10053500E+02, -.59396000E+01, 0.29860200E+01, 0.74935100E+01, 0.22605400E+02, 0.17767100E+02, 0.19390600E+01, -.31024200E+03, 0.15557100E+03, 0.16992200E+03, 0.55770800E+02, 0.90893100E+02, 0.48808400E+02, -.78807500E+02, 0.73945200E+02, 0.92208000E+02, 0.15380800E+03, -.78562300E+02, -.89564700E+02, 0.61152300E+02, 0.20976600E+02, -.64985700E+02, -.22269900E+02, -.92469800E+02, -.25321000E+00, 0.25407100E+01, -.17516300E+00, -.66618900E+01, -.20237600E+00, -.61752700E+01, -.64171600E+00, -.88363200E+00, 0.24784200E+01, -.47524000E+01, 0.28693400E+02, -.19465800E+01, 0.31737100E+02, -.11434000E+02, -.15108000E+02, -.40547200E+01, -.17282100E+01, -.12098200E+02, 0.26966000E+02, -.24259900E+00, -.86344500E+00, 0.15833700E+02, -.15061400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24592300E+01, -.18320800E+01, -.42533600E-01, -.27497600E+02, 0.30312400E+01, 0.92564900E+00, -.18068800E+01, -.84483300E+00, 0.52264900E+01, -.12811700E+01, 0.16544900E+01, -.51324600E+00, -.17048100E+01, -.67085300E+00, 0.41317500E+00, -.23560000E+01, -.21583900E+01, -.10650000E+01, -.11181800E+01, 0.82096600E+00, 0.48921000E-01, -.28102000E+01, -.85286200E+01, 0.85792400E+00, -.23786300E+00, 0.13102300E+00, -.32901400E+01, 0.22381000E+01, 0.77068800E+01, 0.12889700E+00, 0.38221400E+00, 0.63591800E+00, -.83245100E+00, 0.14026500E+01, 0.13024900E+01, 0.56119500E+00, -.45479900E+00, -.40234800E+00, 0.85000200E-02, -.45242900E+00, -.42603600E+00, 0.63793200E+00, -.46094900E+00, 0.19728200E+01, -.12149000E+01, 0.13470900E+01, 0.43768600E+01, 0.42155100E+00, 0.14416800E+01, 0.21561400E+00, -.96612000E+00, -.24074800E+01, -.30343900E+00, -.97905700E+00, 0.10489000E-01, -.25497100E+00, -.47962000E+00, -.90114700E+00, 0.10972300E+00, 0.71266600E+00, -.38276400E+00, -.17310000E+01, -.62418200E+00, -.17764200E-01, 0.10963500E+00, -.27814000E+00, 0.48924200E-01, 0.27255600E+00, 0.75466800E-04, 0.93731400E+00, 0.94182400E-01, -.43137500E+00, 0.12274500E+00, -.35393400E+00, -.12064300E+00, 0.98817100E-01, -.73806200E+00, 0.79715100E-01, -.11706000E+01, 0.11505100E+00, -.81137700E-01, 0.63067500E+00, 0.10649100E+01, -.21415000E+00, -.12238500E+01, 0.42947100E+01, 0.35840800E+00, 0.12733000E+00, 0.48188100E+00, 0.16596100E+01, -.11338400E+01, -.31114900E+00, 0.10514600E+00, 0.27144700E+00, -.25477800E+00, 0.25687200E+01, 0.22702700E+00, 0.40254900E-01, -.77706000E+00, 0.17439100E+00, 0.10140500E+00, -.45907400E+00, -.13868900E+03, -.41754500E+03, 0.26991600E+03, 0.35577900E+03, 0.26663600E+03, -.31255800E+03, -.76737000E+03, 0.38320600E+03, 0.38799600E+03, -.28576700E+03, -.35211300E+03, 0.47981300E+03, 0.12246000E+03, 0.32621100E+03, -.26239800E+03, -.47160000E+02, 0.23458400E+02, 0.18739000E+02, -.19446300E+03, -.12365600E+03, 0.15409700E+03, 0.23471800E+03, 0.20527300E+03, -.46359500E+02, 0.34074500E+02, -.15222800E+02, -.25329000E+02, -.82671900E+02, -.12734100E+03, 0.97615100E+02, 0.24798200E+03, 0.57312700E+02, -.97578700E+02, 0.33677900E+03, -.17053300E+03, -.16087900E+03, 0.50477900E+02, -.12169800E+03, -.11990800E+03, -.13044900E+03, -.48418400E+02, -.24229300E+02, 0.78809800E+03, -.39118100E+03, -.40106400E+03, 0.86407200E+02, -.20744700E+03, -.15485000E+03, -.11856200E+03, -.43828800E+03, -.19742700E+03, -.11056300E+03, 0.55805200E+02, 0.70780600E+02, 0.66886200E+01, 0.65305400E+02, -.18463800E+02, -.41775200E+02, -.17581900E+02, 0.13489900E+02, 0.54449200E+02, -.26260400E+02, -.34953700E+02, 0.32738800E+02, 0.84278200E+01, -.41139400E+02, -.39853700E+02, 0.65906400E+02, -.11640800E+01, -.45404200E+03, 0.22119200E+03, 0.19413600E+03, -.17185900E+03, -.26596100E+03, 0.31910500E+03, 0.13526600E+03, 0.19344900E+03, -.20189000E+03, -.37221000E+03, 0.18761700E+03, 0.18856400E+03, -.94891200E+02, 0.10104300E+03, 0.11973400E+03, 0.26826000E+03, 0.53259500E+02, 0.12944200E+03, -.85141500E+00, -.91020600E+01, 0.20931900E+02, 0.15643900E+02, -.19178500E+02, -.12834000E+02, 0.14889900E+01, 0.19834900E+02, -.77547700E-01, 0.99095700E+01, -.13395500E+02, 0.25121400E+01, 0.39506100E+02, 0.10233300E+03, -.17819000E+02, 0.26821600E+02, 0.14469700E+02, -.13709200E+03, 0.53921300E+01, 0.10513500E+01, -.23963200E+03, -.26508200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.30469800E+01, 0.14936100E+01, 0.20884300E+01, 0.35212000E+02, -.38522600E+01, -.26887200E+00, 0.23095700E+01, 0.28745000E+00, -.84736500E+01, 0.19253000E+01, -.26310800E+01, 0.34513400E+00, 0.36255200E+01, 0.69095900E+00, -.28623600E+00, 0.32845300E+01, 0.26679500E+01, 0.74309000E+00, 0.14562900E+01, -.12926100E+01, 0.39114000E+00, 0.49120300E+01, 0.38230100E+01, -.88676800E+00, 0.14917900E+00, 0.42092400E+00, 0.66390700E+01, -.24650400E+01, -.15941600E+02, 0.10703500E+01, -.40482300E+00, -.13552600E+01, 0.14991700E+01, -.41587300E+01, -.13923600E+01, 0.11747000E+01, 0.18624500E+01, 0.27894500E+00, -.14012000E+01, 0.52486900E+00, 0.17222800E+01, -.18268000E+01, 0.14820100E+01, -.43936700E+01, -.69912900E-01, -.71718400E+00, -.13808300E+00, 0.13397900E+00, -.78720700E+00, 0.87080800E+00, 0.14366800E+01, -.32217700E+00, -.15463900E+01, 0.13528400E+01, -.12019600E+01, 0.55544700E+00, 0.41392100E+00, -.87102500E+00, 0.14752300E+00, -.15139100E+01, 0.21048600E+00, 0.15036200E+01, 0.12548000E+01, 0.60134200E+00, -.43686100E+00, -.18522700E+01, 0.44459400E-01, -.26411000E+00, -.14949000E+01, -.45168200E+00, 0.18799400E+00, 0.51571500E+00, 0.20014000E+00, 0.87650300E-01, 0.48975100E+00, 0.63900000E+00, 0.92208800E+00, 0.20616000E-01, 0.20071200E+00, -.65924800E-01, 0.13951800E+00, -.12383900E+01, -.10333000E+01, 0.45950600E+00, 0.97348700E+00, -.16956000E+01, -.56779000E+00, -.60482400E+00, -.13120400E+01, 0.11775400E+01, -.89865200E-01, -.29666300E+00, -.24490900E+00, -.14111000E+00, 0.40214400E+00, 0.97704300E+00, -.74978100E+00, -.32608500E+00, 0.18356700E+01, 0.86060300E+00, -.38231800E+00, 0.36323700E+00, 0.24213800E+00, 0.29429400E+03, -.20068000E+03, -.37014200E+03, -.22970500E+03, 0.24181600E+03, 0.20830700E+03, -.11124900E+03, -.14654700E+03, 0.39864000E+03, 0.44634700E+03, -.52713400E+03, -.28995200E+03, -.76280200E+03, 0.40503600E+03, -.13389000E+03, 0.63970000E+02, 0.58472400E+02, 0.11931300E+03, -.12396400E+02, 0.20198100E+02, -.76960500E+02, -.38737500E+03, -.46803300E+02, -.26673900E+02, 0.14831300E+02, 0.10255200E+02, 0.14467500E+03, 0.71866100E+02, -.90568100E+02, -.18227700E+03, -.21692700E+03, 0.66845800E+02, -.53900700E+03, 0.27934800E+03, 0.27803300E+03, -.98032400E+02, 0.16563700E+03, 0.17436200E+03, 0.98502000E+02, 0.12078200E+03, 0.13190200E+03, -.55751400E+03, 0.26763300E+03, 0.25350900E+03, -.85394100E+02, 0.14089600E+03, 0.68051900E+02, -.28662900E+02, 0.46049800E+03, 0.16015900E+03, -.24866100E+03, 0.12405500E+03, 0.10796400E+03, 0.13799300E+03, 0.13632700E+03, -.42119300E+02, -.18263500E+03, -.13191900E+03, 0.20483900E+03, -.53838000E+02, 0.25894100E+02, 0.28837900E+02, -.44188200E+02, -.84284100E+01, 0.41032500E+02, 0.55013700E+02, -.86482700E+01, -.50381600E+01, 0.48646800E+03, -.23883500E+03, -.24045300E+03, 0.18782900E+03, 0.22148400E+03, -.43894700E+03, -.18349000E+03, -.36559300E+03, 0.19048100E+03, 0.93459500E+02, -.56380500E+02, -.40776300E+02, 0.15130800E+03, -.78758000E+02, -.17664400E+02, -.10005000E+03, -.56012100E+02, -.12080300E+03, 0.11299400E+01, 0.72066000E+01, -.25526300E+02, -.95654800E+01, 0.90773200E+01, 0.54967500E+01, -.16061200E+01, -.53611000E+01, -.22468600E+02, 0.19995700E+02, 0.75509900E+01, 0.30428800E+02, 0.22419400E+02, -.12235300E+03, -.61982700E+02, 0.12671900E+02, -.15214500E+02, 0.20514300E+03, 0.10018100E+02, -.25176800E+01, 0.29547200E+03, -.32257900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.25003400E+01, 0.13918600E+01, 0.20628700E+01, 0.22471300E+02, -.44753500E+01, -.74632600E+00, 0.19836800E+01, 0.42592600E+00, -.50168600E+01, 0.12221000E+01, -.74553200E+00, 0.21129200E+00, 0.28789300E+01, 0.43590900E+00, -.64012500E+00, 0.29813800E+01, 0.30290700E+01, 0.27407500E+01, 0.59099100E+00, -.17350100E+01, 0.27476100E+00, 0.38391100E+01, 0.95874500E+01, -.18262200E+00, 0.17695700E+01, 0.28504000E+00, 0.20459200E+01, 0.53469600E+00, -.11335300E+01, -.50620800E+00, 0.18965800E+01, -.20204400E+01, 0.40114400E-01, -.27871100E+01, 0.19600600E+01, -.25679300E+01, 0.39127400E+00, -.17877400E-01, 0.11102700E+01, -.33022500E+00, -.70813600E+00, -.42581800E+00, 0.97693200E+00, 0.10466700E+01, -.30796100E+00, 0.24540600E-01, 0.25025300E+01, 0.84862900E-01, -.46620300E+00, -.70508100E+00, 0.72421400E-01, -.27798500E+00, 0.11168200E+01, -.51629300E+00, 0.62553300E+00, -.95466200E+00, 0.75752900E+00, 0.72105700E+00, 0.11650700E+00, 0.13050700E+00, -.21153300E+00, 0.48807300E-01, -.90879600E+00, 0.34628500E+00, -.27251500E+00, 0.14725400E+00, -.44064200E+00, 0.12191900E+00, 0.18537300E+01, -.70671200E+00, -.17447700E+00, 0.45235900E+00, 0.11549800E+00, -.31864800E+00, 0.42387000E+00, -.69064600E+00, -.14160400E+00, 0.57744500E+00, -.85614200E+00, 0.45110000E+00, -.96516800E-01, 0.78457400E+00, 0.36316100E+00, 0.25924800E+00, 0.85497400E+00, -.29169300E+01, 0.25438400E+00, 0.40724000E+00, 0.28708000E+00, 0.22547300E+00, 0.35643400E+00, -.17572100E-01, 0.92047500E-01, 0.61303000E-01, -.10045200E+00, 0.76818100E+01, -.45841200E+00, -.28409700E+00, 0.19721700E+01, -.23923500E-01, -.10206500E+00, 0.36745100E+00, -.10980200E-01, 0.43882000E+00, 0.63705400E+02, 0.11671200E+03, 0.62070300E+02, -.55440000E+01, 0.24582500E+03, -.11949200E+03, -.13035700E+03, -.17788600E+03, -.28266400E+03, 0.15533100E+03, 0.20150700E+03, 0.28636800E+03, -.26002100E+03, 0.78560600E+01, -.36569600E+01, -.10651900E+02, -.86781100E+02, -.56330700E+01, 0.30824200E+02, 0.64256100E+02, 0.18732100E+03, 0.16831700E+02, 0.24037400E+02, -.12622300E+02, -.15276600E+02, -.77593900E+02, -.11841000E+02, 0.32730600E+02, 0.54941400E+02, 0.83125800E+02, -.94015100E+01, 0.20076300E+03, -.10530600E+03, -.92578900E+02, 0.56479100E+02, -.32915500E+02, -.79856600E+02, -.64266500E+02, -.74588100E+02, -.16652800E+02, 0.33881100E+03, -.16798900E+03, -.18044300E+03, 0.10014700E+03, -.36192400E+02, -.88691100E+02, -.77202200E+02, -.23881400E+03, -.36197700E+02, 0.11789900E+03, -.58560900E+02, -.57938300E+02, -.69349600E+02, -.72232300E+02, 0.93383200E+01, 0.87457500E+02, 0.62482500E+02, -.87436300E+02, 0.20094100E+02, -.91783000E+01, -.13229000E+02, 0.13597200E+02, 0.43826100E+01, -.14719000E+02, -.25603300E+02, -.53894100E+01, -.26130100E+01, -.38226200E+00, -.20028800E+01, -.24968500E+02, -.67872400E+02, -.13259100E+03, 0.13627600E+03, 0.11300900E+03, 0.14187000E+03, -.12610200E+03, -.17820300E+03, 0.85429500E+02, 0.83484200E+02, -.79506900E+02, 0.46974700E+02, 0.28929900E+02, 0.61450100E+02, 0.44105100E+02, 0.59499900E+02, -.78929500E+00, -.82227200E+00, 0.10245500E+02, 0.15223600E+01, 0.24910800E+01, 0.92819900E+00, 0.88004800E+00, -.20504600E+01, 0.53540100E+01, -.24899100E+02, 0.12165200E+01, -.28682300E+02, 0.51514800E+01, 0.52893500E+02, 0.24651600E+02, -.56244400E+01, -.16417700E+00, -.10118200E+03, 0.78233000E+00, 0.10253800E+01, -.12809500E+03, 0.18279400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.54028800E+01, 0.29013100E+01, 0.88748900E+01, 0.41394200E+02, -.31881200E+01, -.10724600E+01, 0.33157600E+01, 0.20267100E+01, -.14414500E+02, 0.24795900E+01, -.56677400E+01, 0.21052200E+01, 0.66121500E+01, 0.37414600E+01, 0.43803200E-01, 0.47972800E+01, 0.62464500E+01, 0.26811600E+01, 0.22927500E+01, -.30064600E+01, 0.75888300E+00, 0.98730500E+01, 0.13175000E+02, -.11533500E+01, 0.25671900E+01, 0.37669600E+00, 0.12545500E+02, -.32970300E+01, -.23577800E+02, -.17866600E+01, 0.14810500E+01, -.45673800E+01, 0.62972300E+00, -.65780700E+01, 0.65978600E+00, -.55330900E+01, -.36836300E+00, 0.44302600E+00, -.17379200E+00, -.51359900E+00, 0.37858900E-01, -.39101900E+01, 0.26797600E+01, -.11300600E+01, 0.74952700E+00, -.10717200E+01, -.94035100E+01, 0.27080100E+00, -.32115200E+00, -.95041100E+00, 0.51535900E+00, -.30696000E+01, -.21373200E+00, -.13945800E+01, 0.27818000E+00, -.18727500E+00, -.56760200E+00, 0.20757000E+01, -.72253400E-01, 0.13312400E+01, -.40495400E+00, 0.14216400E+01, -.22219900E+00, -.54494200E+00, -.85519000E+00, -.35442100E+01, -.18231300E+01, 0.10588800E+01, 0.30556700E+01, 0.10410400E+01, 0.48378500E+00, -.65869000E+00, 0.72039300E+00, -.17607700E+00, 0.57948000E+00, 0.19827800E+01, -.15659600E+00, -.36264900E+00, 0.22957200E+01, 0.36935000E+00, 0.72239000E-01, -.17119200E-01, -.96223600E-01, 0.13351200E+00, 0.13315400E+00, -.90736000E+00, -.15260400E+00, 0.23457000E+00, 0.18622700E+00, 0.16775100E+00, -.92975800E+00, 0.93007500E-01, -.17014200E-01, -.36021500E+00, 0.62759800E+00, 0.15546000E+01, -.41418500E+00, 0.14632900E+00, 0.25212100E+01, -.21492300E+00, -.29798000E+00, -.18948800E+01, -.59096900E+00, 0.99060700E-01, -.26145100E+00, -.28857500E+03, -.17321400E+03, 0.19270400E+01, -.76294800E+03, 0.38574000E+03, 0.42690200E+03, 0.45007500E+02, 0.11424000E+03, 0.15170200E+03, -.23829200E+03, 0.18326000E+03, 0.11068200E+03, 0.26342900E+03, -.12990900E+03, -.10124200E+03, -.32905500E+02, -.14164400E+03, 0.83751300E+00, 0.80761900E+02, -.19501700E+03, -.13878200E+03, -.11603000E+03, 0.57315300E+02, 0.64505800E+02, 0.36420000E+01, -.11333100E+03, 0.10095900E+03, 0.21614600E+03, 0.29911400E+02, -.79937900E+02, -.11744900E+03, 0.62814000E+02, 0.37730500E+02, -.31038500E+02, 0.28736300E+02, 0.35791700E+02, -.12944900E+03, 0.45568400E+02, 0.37450600E+02, 0.11154900E+03, -.52275900E+02, -.21315700E+02, -.12349600E+03, -.11956400E+03, 0.98511200E+02, 0.19907400E+03, -.63634500E+01, -.15446900E+03, -.11095700E+03, 0.55930200E+02, 0.92562600E+02, 0.91715700E+02, 0.12519400E+03, -.54857500E+02, -.18720200E+03, -.12917700E+03, 0.10811400E+03, -.64878300E+01, 0.17263100E+01, 0.49600700E+01, -.10679900E+02, 0.11425500E+02, -.48476100E+01, 0.49683100E+02, 0.80932200E+02, 0.12719200E+01, -.29389700E+03, 0.14941500E+03, 0.15764800E+03, 0.20185600E+02, 0.14707400E+02, 0.63250100E+02, -.74282800E+02, 0.15585000E+03, 0.11179000E+02, 0.31212800E+03, -.16257000E+03, -.18181100E+03, 0.11250400E+03, 0.11113500E+03, -.15167700E+03, 0.43910400E+02, -.26999200E+03, 0.55811600E+02, 0.63885800E+01, -.55044700E+01, -.92065100E+01, 0.53068400E+01, -.24853400E+02, -.86557300E+01, -.23083100E+01, 0.21112000E+02, -.18139100E+02, 0.62163600E+02, -.13772300E+02, 0.69645900E+02, -.29426800E+02, 0.27681000E+01, -.63927700E+02, 0.24247800E+02, -.27119100E+02, -.37087200E+02, 0.50792700E+01, -.26499500E+01, -.36041200E+02, -.37522400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37946100E+01, -.23210200E+01, -.26451500E+01, -.31752200E+02, 0.52670300E+01, 0.33739600E+00, -.32222000E+01, -.10473400E+01, 0.67569700E+01, -.18086500E+01, 0.20448100E+01, 0.14571100E+00, -.51879800E+01, -.14693900E+01, -.55280000E+00, -.14794700E+01, -.25844600E+01, 0.39708200E+00, -.37220000E+00, 0.87578700E+00, -.66054300E+00, -.40278100E+01, 0.86982300E+00, 0.11211100E+01, -.56126800E+00, -.41653100E+00, -.10503300E+02, 0.27207800E+01, 0.18783400E+02, -.92517100E+00, 0.24907900E+00, 0.10862300E+01, -.87492100E+00, 0.27580600E+01, 0.11998700E+01, -.26005500E+01, -.22164900E+01, -.54616400E-01, 0.24951800E+01, -.93489900E-01, -.23147100E+01, 0.15217100E+01, -.47854400E+00, 0.37637200E+00, 0.17760700E+01, 0.78226700E-01, -.12524400E+02, 0.60597000E+00, -.50619000E+00, -.13379800E+01, -.83899300E-01, -.16070700E+01, 0.19496900E+01, -.32702600E+01, 0.26434800E+01, 0.38143400E+00, 0.74824000E-01, 0.35893700E+00, -.29490000E-01, 0.15945100E+01, -.75478900E+00, 0.15500800E+01, -.13307500E+00, -.70506400E+00, 0.48913100E+00, -.57064900E+00, -.12846400E+01, 0.23154800E+00, 0.26229600E+00, -.15338600E+00, -.55174100E+00, -.10569600E+00, -.18734500E+00, 0.11226700E+00, -.87882200E+00, -.97186200E+00, -.42529700E+00, 0.48200000E+00, 0.81265400E+00, -.69486300E-01, -.71342600E-01, 0.12482900E+01, 0.13120000E+01, -.23823200E+00, 0.39372500E+00, -.27121000E+01, 0.14720100E+00, 0.30958600E+00, -.53662200E+00, -.86136500E+00, 0.66533800E+00, 0.22630600E+00, 0.68862800E-01, -.22192600E+00, 0.32553400E+00, 0.83109600E+00, 0.16293700E+00, 0.54646300E+00, -.26958500E+01, 0.56632900E+00, -.12836200E+00, -.43182300E+00, 0.34071500E+00, 0.17094800E+00, -.57183900E+00, 0.22986400E+00, 0.12331000E+03, -.28596200E+02, -.51705200E+03, 0.25602500E+03, 0.27823500E+03, -.99274700E+02, 0.45745600E+02, 0.40046100E+03, 0.33380000E+02, 0.69099000E+03, 0.34361600E+02, -.20969400E+03, 0.10195500E+03, 0.11325100E+03, 0.12513200E+03, 0.24741600E+03, -.71749200E+02, -.19202200E+03, 0.33068300E+03, 0.22131100E+03, -.34196100E+02, 0.13543300E+02, 0.22208500E+02, -.10663200E+03, 0.74095800E+02, 0.49264600E+02, 0.61435400E+02, 0.33013100E+03, 0.46079300E+02, 0.30887700E+03, -.17125100E+03, -.15890800E+03, 0.41394700E+02, -.10804200E+03, -.12359700E+03, -.93167100E+02, -.15151800E+03, -.89620800E+02, -.59041000E+03, 0.29022200E+03, 0.31577300E+03, -.15390300E+03, -.13136200E+02, 0.29139500E+03, 0.26299700E+03, 0.20534000E+03, 0.36334700E+02, 0.28235300E+03, -.14172500E+03, -.14152400E+03, -.12284100E+03, -.19668100E+03, 0.71797400E+02, 0.25419000E+03, 0.22665000E+03, -.23280200E+03, 0.17246900E+02, -.49315700E+01, -.60288400E+01, 0.15245900E+02, -.40237200E+01, 0.17669900E+01, -.69851100E+01, -.38818600E+02, -.22505200E+01, -.75653600E+03, 0.37795100E+03, 0.41018200E+03, -.21183200E+02, 0.88627200E+02, 0.35298900E+03, -.28042700E+02, 0.34050300E+03, 0.10502100E+03, 0.54522200E+03, -.29021800E+03, -.29117700E+03, 0.86158100E+02, -.18836300E+02, -.29490400E+03, -.29167400E+03, -.23239000E+03, -.41249200E+02, 0.37347100E+01, 0.39394000E+01, 0.40881800E+01, -.51529800E+01, 0.12842300E+02, 0.93768100E+01, -.17488500E+01, -.17722600E+02, 0.21475200E+02, -.65344400E+01, 0.97750500E+01, -.87956200E+01, 0.58287000E+01, 0.35334800E+02, 0.10968900E+03, -.59735900E+02, -.14458300E+01, -.21572700E+01, -.18613400E+02, 0.15976300E+01, -.12574700E+03, 0.31147300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17115900E+01, -.11173400E+01, 0.16508000E+00, -.19312800E+02, 0.21598300E+01, 0.34666400E+00, -.17960900E+01, -.42763300E+00, 0.43612100E+01, -.90877000E+00, 0.16479200E+01, 0.11344200E+00, -.40490700E+01, -.11687800E+01, -.55066200E+00, -.13007000E+01, -.20388600E+01, 0.25142100E+00, -.75859400E-02, -.61490600E-01, -.31256700E+00, -.21046900E+01, 0.22623100E+01, 0.85968600E+00, -.32645500E+00, -.18744700E-01, -.57973800E+01, 0.12932100E+01, 0.11416300E+02, -.11059700E+01, 0.25487900E+00, 0.60337500E+00, -.13131800E+01, 0.90722100E+00, 0.29519900E+00, -.12220600E+01, -.11372100E+01, 0.14953400E+00, 0.13196800E+01, 0.11415600E+00, -.64349000E+00, -.48612300E-01, -.31690700E-01, 0.23491400E+00, 0.17771400E+01, -.99710600E-01, -.77534400E+01, 0.70523100E+00, 0.88141100E+00, 0.47017300E+00, -.14037900E+00, -.16118100E+01, -.69706500E+00, -.19766800E+01, 0.17207400E+00, 0.75827000E+00, -.91589500E+00, 0.47407900E+00, -.75244100E-01, 0.77463000E+00, 0.48774200E-01, 0.10125200E+01, 0.11541600E+01, -.29483000E+00, 0.55103700E+00, 0.25265800E+00, -.62661100E+00, 0.14402800E+00, -.76940600E+00, -.84918500E-01, -.38614700E+00, 0.27761800E+00, -.11169600E+00, 0.16638200E+00, -.28151800E+00, -.67920500E+00, 0.30193300E+00, 0.55271600E+00, 0.19817500E+01, 0.12484500E+00, -.46858000E-01, -.30842300E+00, -.28622800E+00, 0.16878000E+00, -.21973400E+00, 0.12218200E+01, 0.14491700E+00, 0.20306600E+00, -.27597100E+00, -.15369900E+01, -.92727900E-02, 0.33772600E+00, 0.26379100E-01, -.77477700E-01, -.15455800E+00, 0.60856500E+01, 0.13947000E+00, 0.16191300E+00, -.22618700E-01, 0.56907300E-02, 0.79860300E-01, 0.30794500E+00, 0.25011800E-01, -.26282000E+00, 0.12627200E+00, -.19312500E+00, -.13878400E+00, 0.22693200E+02, 0.50680700E+02, -.25717000E+02, -.13910600E+02, -.40794100E+02, 0.10435100E+02, 0.17452300E+02, -.28511600E+02, -.78841400E+02, 0.76239300E+01, -.38955400E+02, 0.17266000E+02, 0.26874000E+02, 0.40235100E+02, 0.23893900E+02, -.58547200E+01, -.33719300E+02, 0.28877200E+01, -.28145900E+01, 0.13913800E+02, -.78792800E+01, -.38015300E+01, -.25454700E+02, -.13036400E+02, 0.19784200E+02, 0.22795500E+02, 0.24133800E+02, -.17639500E+02, 0.89010800E+01, -.77962800E+01, -.10842300E+02, -.21980500E+02, -.51478300E+01, -.66886700E+00, 0.13579700E+02, 0.13887500E+02, 0.15947400E+02, 0.17109200E+03, -.95366400E+02, -.67823700E+02, -.44581000E+02, -.48839600E+02, -.18047000E+02, 0.26813800E+02, 0.66934100E+02, -.45586200E+02, -.79498400E+02, 0.39747200E+02, 0.40458300E+02, -.19384600E+02, -.22151800E+02, 0.52941600E+02, 0.54916000E+02, 0.54913300E+02, -.11714600E+01, 0.80692700E+01, -.21281600E+01, -.14417500E+01, 0.10973800E+01, 0.14740900E+01, -.25832300E+01, -.11882900E+02, 0.95478200E+01, -.72117400E+00, 0.80463000E+02, -.37675600E+02, -.15562000E+02, -.55828800E+01, 0.13089200E+02, -.23812800E+02, -.46444500E+02, -.10962800E+03, 0.27343800E+02, -.26738000E+03, 0.11847700E+03, 0.11740900E+03, 0.15152100E+02, -.49798900E+02, 0.75658500E+02, 0.40152400E+02, 0.82360600E+02, -.32797000E+02, 0.16090000E+00, -.92263800E+00, -.14554800E+02, 0.25558700E+01, -.66085600E+00, 0.36167500E+01, 0.53317800E+00, -.22992000E+01, -.11115900E+01, -.10936600E+02, 0.52239200E+00, -.72547800E+01, 0.97382800E+01, -.15564000E+02, 0.51960300E+01, -.62750500E+00, 0.18815700E+02, 0.11287100E+02, -.89340400E+01, -.22642400E+00, 0.40019700E+02, -.49688700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.16646500E+01, -.11589800E+01, -.27237500E-01, -.17279200E+02, 0.25944000E+01, 0.47278100E+00, -.14419800E+01, -.50638600E+00, 0.35024900E+01, -.87046200E+00, 0.74887800E+00, -.16938600E+00, -.19459800E+01, -.81854800E+00, 0.16510600E+00, -.19621100E+01, -.23268500E+01, -.10253100E+01, -.71664800E+00, 0.12005600E+01, -.43227200E+00, -.26502800E+01, -.30896200E+01, 0.61128600E+00, -.37200200E+00, -.66589400E+00, -.68122500E+01, 0.12357000E+01, 0.74278400E+01, -.45464400E+00, -.40494600E+00, 0.60081700E+00, -.39899400E+00, 0.16725200E+01, 0.30598300E+00, 0.46973700E+00, -.29461100E+00, 0.26349300E-01, 0.49249000E+00, -.96159300E-01, -.85697000E+00, 0.95056800E+00, -.96105800E+00, 0.23315900E+00, 0.81577600E-01, -.11020800E+00, -.46996900E+01, -.11815700E+00, -.22114900E+00, -.46337600E+00, -.18289200E+00, -.68054000E+00, 0.22153400E+00, -.18172600E+01, 0.12104900E+01, 0.33447100E+00, -.11502000E+01, 0.73896500E+00, -.27126800E+00, 0.28985700E+00, -.47525100E+00, 0.88487100E-01, 0.90616500E-01, -.97148900E-01, 0.36631300E+00, -.28089600E+00, -.66794900E+00, 0.10577800E+00, 0.17533200E+01, -.46623500E+00, -.58148600E-01, 0.42739100E+00, -.43131800E-01, -.10462100E+00, 0.51485100E+00, -.69553800E+00, 0.23148800E+00, 0.76910600E+00, -.77539500E-01, 0.44958200E+00, -.37546900E-01, 0.46295800E+00, 0.20745000E+00, -.31598500E+00, -.48465100E+00, 0.11243300E+01, 0.15357900E+00, 0.23844200E+00, 0.18237600E+00, -.66838700E+00, -.64224200E+00, 0.22429200E+00, -.27422200E-01, -.49731000E-01, 0.21001900E+00, 0.39118100E+01, -.18741900E+00, 0.10002800E+00, 0.10249100E+01, -.49226900E+00, -.75244500E-01, -.11762900E+00, 0.61696700E-02, 0.39893600E-01, -.12527300E-01, 0.19489800E+00, -.21301200E+00, -.27695700E+00, 0.86570200E+03, -.43046100E+03, -.43555400E+03, -.16933100E+03, -.16721000E+03, -.16552800E+03, 0.66037300E+02, -.35156400E+03, -.16632600E+03, 0.99840300E+02, -.50266100E+02, -.49768100E+02, 0.28109200E+02, -.16002400E+02, -.42368800E+02, 0.18925300E+02, -.47191400E+02, -.35700100E+02, 0.44960700E+02, -.23921300E+02, -.20635500E+02, -.15932600E+02, -.19020400E+02, -.55007000E-01, -.73456500E+01, -.52337900E+02, -.19422000E+02, 0.91040400E+02, -.47222600E+02, -.47810500E+02, 0.34458800E+01, 0.14123400E+02, -.41864700E+02, -.23872500E+02, -.45501600E+02, 0.16509800E+02, 0.51818900E+02, -.30106800E+02, -.10215700E+02, -.90613100E+02, -.38651800E+02, 0.36608800E+02, 0.76573000E+02, 0.11278400E+03, -.52168800E+02, 0.69510500E+02, -.34964700E+02, -.45834000E+02, -.55444900E+02, -.61706400E+02, 0.45385400E+02, 0.52049100E+02, 0.63049000E+02, -.40601300E+02, 0.23969300E+01, -.95836100E+00, 0.66851800E+00, 0.51594900E+01, 0.20394800E+00, -.51758500E+01, -.17881100E+02, -.19987900E+02, 0.13560700E+01, 0.59757100E+03, -.29577500E+03, -.27223600E+03, -.10184300E+03, -.77742600E+02, -.13030300E+03, 0.17642100E+02, -.26891100E+03, -.84966800E+02, -.20991700E+03, 0.98879200E+02, 0.97849300E+02, 0.26220700E+02, -.20167500E+02, 0.56072400E+02, 0.42960900E+01, 0.10168700E+03, -.24479200E+01, -.26604600E+01, -.23105700E+01, -.64672000E+01, 0.19591000E+00, 0.39250900E+01, 0.29538600E+01, 0.11958200E+01, -.17675800E+00, 0.36808100E+01, -.27011600E+02, 0.19799000E+01, -.26597600E+02, 0.98803800E+01, -.22200600E+02, -.11700700E+02, 0.75196300E+01, 0.13770100E+02, 0.25739700E+02, -.66586600E+01, 0.19829400E-01, 0.76203100E+02, 0.27078600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23880700E+01, 0.12714200E+01, 0.10675400E+01, 0.27204000E+02, -.30046200E+01, 0.16599700E+00, 0.20625300E+01, 0.31706500E+00, -.75067300E+01, 0.17783000E+01, -.19917000E+01, 0.77007100E-01, 0.33608000E+01, 0.91302300E+00, -.10104800E+01, 0.26791000E+01, 0.36518500E+01, 0.13895400E+01, 0.54061800E+00, -.94899800E+00, 0.57899700E+00, 0.18101400E+01, 0.43720100E+01, -.16988600E+01, 0.30306600E+00, 0.68902400E+00, 0.13790700E+02, -.99604400E+00, -.39006900E+01, 0.23641100E+01, 0.23868600E+00, 0.12689700E+01, 0.19101400E+01, 0.86710000E+00, 0.25542900E+00, 0.70477000E+00, 0.10334500E+01, -.25507700E+00, -.49453800E+00, -.17080400E-01, 0.59239100E+00, 0.26116700E+00, -.16771000E+00, 0.17678700E+01, -.23341900E+01, 0.62432200E+00, 0.16843000E+02, -.12787000E+01, 0.88291300E+00, 0.93764100E+00, -.40288600E+00, 0.28501700E+01, -.34443900E+00, 0.42415200E+01, -.15349500E+01, -.60898400E+00, 0.12336900E+01, 0.22143200E+01, -.36013400E+00, -.50185900E+00, 0.10429200E+01, 0.17038200E+01, 0.15314100E-01, -.12515600E-01, -.10812400E+01, 0.17922600E+01, 0.21523300E+00, -.52047400E+00, 0.43064700E+00, 0.18883900E+00, 0.19829100E+00, 0.24832700E+00, -.59320700E+00, 0.30666800E+00, -.89954100E-01, -.25464800E-01, 0.39114900E+00, -.94833400E+00, -.11152600E+01, -.56405700E+00, 0.80302700E-01, 0.99502400E-02, 0.13924600E+00, 0.50051000E+00, 0.23352300E+00, -.86313700E+00, 0.21008500E+00, 0.17609500E+00, 0.84396400E+00, 0.52256400E+00, 0.92743300E-01, 0.91195300E-01, 0.20001300E-01, 0.50854900E+00, -.26542900E+00, 0.16865800E+01, 0.80906900E-01, -.44318300E-01, -.17236200E+01, 0.79580100E+00, 0.66574000E-01, -.23520200E+00, 0.68849000E+00, 0.12013800E+00, -.34928400E+00, -.11016500E+00, 0.11967100E+00, -.54115900E+00, -.69186500E+00, 0.61155200E+01, 0.52951600E+02, -.22610500E+03, -.13435500E+03, 0.24282100E+03, 0.68305500E+02, 0.29241400E+03, -.10655800E+03, -.14665600E+03, 0.72272500E+02, 0.91602700E+02, 0.43832400E+02, 0.11210700E+03, -.16368800E+02, -.35450800E+02, 0.13075300E+03, 0.99481300E+02, -.10877600E+02, 0.17850000E+01, 0.17502100E+02, -.93370700E+02, -.69867500E+01, 0.46361500E+02, 0.77411800E+02, 0.97901200E+02, -.20057900E+02, 0.26427500E+03, -.14090700E+03, -.14428500E+03, 0.36444300E+02, -.50653700E+02, -.11524300E+03, -.71476100E+02, -.11563000E+03, 0.40525000E+01, 0.11382300E+03, -.62340900E+02, -.16808400E+02, -.12858900E+03, -.88484500E+02, 0.57459200E+02, 0.13473100E+03, 0.12118300E+02, -.58277900E+02, 0.10814300E+03, -.54443800E+02, -.48882200E+02, -.94514700E+02, -.11186600E+03, 0.70314700E+02, 0.15384100E+03, 0.15941400E+03, -.10129800E+03, 0.29324100E+02, -.12547000E+02, -.73534100E+01, 0.19300200E+02, 0.32133000E+01, -.12415400E+02, -.39879700E+02, -.45344200E+02, 0.44872700E+01, -.19782900E+03, 0.99762300E+02, 0.14475500E+03, -.87848800E+02, -.16367600E+02, 0.16612600E+03, 0.14329300E+02, 0.10542200E+03, 0.90893100E+01, -.22205500E+03, 0.98827900E+02, 0.79096900E+02, 0.72523800E+02, 0.23558300E+02, -.51971200E+01, -.37085900E+02, 0.49537400E+02, 0.30677800E+02, -.10847300E+01, 0.40782800E+01, -.28105200E+01, -.52765900E+00, 0.69698600E+01, 0.48092500E+01, 0.79728300E+00, -.49909100E+01, 0.13448300E+02, -.24004600E+02, 0.80226400E+01, -.24327700E+02, 0.19540200E+02, 0.23802200E+02, 0.35975700E+02, -.16864200E+02, 0.23783900E+02, -.16857700E+01, -.11928200E+02, 0.10071900E+01, -.55635500E+02, 0.24967200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.47885800E+01, 0.10133600E+01, 0.46089400E+01, 0.28795600E+02, -.60777000E+01, -.34588300E+00, 0.26655200E+01, 0.27876300E+01, -.85753800E+01, 0.17581900E+01, -.24108300E+01, 0.76911600E+00, 0.51144600E+01, -.61433200E+00, 0.68122600E+00, 0.60334300E+00, 0.81049900E+00, -.30449500E+00, 0.56655700E+00, -.11822500E+01, 0.33274300E+00, 0.46544200E+01, 0.30106700E+01, -.78380700E+00, 0.68964600E+00, 0.11817300E+01, 0.10602900E+02, -.22422400E+01, -.18226900E+02, 0.57837100E+00, -.14756600E+00, -.70654800E+00, 0.48266200E+00, -.31931900E+01, -.16718300E+01, -.12922100E+00, -.41484700E+00, 0.22033200E+00, -.94276400E+00, 0.16258100E+00, 0.10666900E+01, -.15555200E+01, 0.21442500E+00, 0.40813800E+00, 0.22714500E+01, -.19720700E+00, 0.18551500E+01, -.76535500E+00, -.37164800E-01, -.78384400E+00, 0.45148900E+00, 0.28202800E+00, -.62178600E-02, 0.60561900E+00, -.74007300E+00, -.55820700E+00, 0.27243400E+00, 0.14815500E+00, 0.32141700E+00, 0.50562600E+00, 0.28425600E+00, -.39015200E+00, 0.36105500E+00, 0.33929900E+00, -.49664600E+00, -.28224700E+01, -.31158800E+00, -.53270000E+00, -.11015300E+01, -.26097900E+00, 0.33788700E+00, -.77187200E-01, -.12872100E+01, 0.27964200E+00, -.13467000E+01, -.69348400E+00, -.33456600E+00, -.11258200E+01, -.26941000E+01, -.60801700E+00, 0.14412700E+00, -.31081800E+00, -.61540300E+00, 0.63491200E+00, 0.11011600E+01, -.16977100E+01, -.17972800E+00, -.16794700E+00, -.86415600E-01, -.80245700E+00, 0.50627000E+00, 0.12938400E+00, 0.31072600E-03, -.13652300E+00, 0.34127900E+00, -.19245900E+00, -.45953200E+00, -.23333300E+00, 0.14509100E+01, 0.54300900E+00, -.33413900E+00, 0.90996200E-01, 0.56845700E-01, 0.17307100E+00, -.57346300E+00, 0.91447600E-01, 0.79544000E+00, 0.15947600E+01, -.10752600E+00, 0.88549900E+00, -.90706500E+02, 0.40572300E+03, 0.19427600E+03, -.45905400E+03, -.98172800E+02, -.51018200E+03, 0.19222000E+03, 0.32633400E+03, -.15703000E+03, -.20086500E+03, -.17179900E+03, -.29991700E+03, 0.56618400E+02, 0.22151700E+03, -.33203600E+03, -.22566000E+03, 0.71101900E+02, -.30165600E+02, -.53811000E+02, 0.19409200E+03, -.55630800E+01, -.14325100E+03, -.14028200E+03, -.37069900E+03, 0.84254900E+01, -.43148000E+03, 0.24323100E+03, 0.25501000E+03, -.19082500E+02, 0.15282000E+03, 0.17449700E+03, 0.89726900E+02, 0.18252200E+03, 0.72417600E+02, 0.23411000E+03, -.96677600E+02, -.20814100E+03, 0.27322400E+03, 0.13221900E+03, -.29117500E+03, -.35940300E+03, -.33986200E+03, 0.86786700E+02, -.18459300E+03, 0.93061900E+02, 0.81051200E+02, 0.16819300E+03, 0.26247800E+03, -.16606500E+03, -.36612600E+03, -.30677100E+03, 0.25595700E+03, -.45269000E+02, 0.15223400E+02, 0.11520500E+02, -.36446200E+02, -.99768300E+01, 0.25189200E+02, 0.62740100E+02, 0.57340600E+02, -.70628900E+01, 0.42243100E+03, -.21389400E+03, -.31751300E+03, 0.17178900E+03, 0.32724800E+02, -.34521600E+03, 0.42841500E+02, -.12387700E+03, -.32074000E+02, 0.47034700E+02, 0.13990100E+02, 0.27892200E+02, -.14070500E+03, 0.98922800E+02, 0.13700100E+03, 0.21328800E+03, 0.32497300E+02, 0.64390300E+02, -.93564400E+00, -.15130000E+01, 0.23934900E+02, -.30574700E+00, -.13313500E+02, -.14754600E+02, -.97685100E+00, 0.17536300E+02, -.19699600E+02, 0.55474100E+02, -.15865600E+02, 0.53337600E+02, -.31469200E+02, -.17870000E+02, -.11710500E+03, 0.49506700E+02, -.45705700E+02, 0.11030500E+02, 0.34925100E+02, -.10925700E+01, 0.72068900E+02, 0.33938500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.46982200E+01, -.20318500E+01, -.61233800E+01, -.24598700E+02, 0.27071100E+01, 0.48615300E+00, -.93903700E+00, -.32684800E+01, 0.86651600E+01, -.17582600E+01, 0.37148700E+01, -.18118800E+01, -.46895500E+01, -.23365900E+01, 0.49119900E+00, -.17971300E+01, -.46456300E+01, -.11824000E+01, -.15292500E+01, 0.27051600E+01, -.58074300E+00, -.78632100E+01, -.95060900E+01, 0.12221200E+01, -.30391700E+01, -.13944400E+01, -.83569100E+01, 0.27532200E+01, 0.19249800E+02, 0.58646900E+00, -.46755800E+00, 0.32282400E+01, -.29187100E+00, 0.17664600E+01, 0.26454200E+00, 0.20988500E+01, 0.10795600E+01, -.19397700E+00, 0.62995000E-01, 0.55687300E+00, 0.18477000E+00, 0.19216300E+01, -.62020900E+00, -.16644500E+01, 0.21092100E+01, -.84180100E-01, -.31699800E+01, 0.17033900E+01, -.14346300E+01, 0.17687600E+00, 0.69257800E+00, -.68634200E+00, 0.14938100E-01, -.25099100E-01, -.72561100E+00, -.15631400E+01, 0.33423100E+01, -.21069300E+01, 0.39039000E+00, -.14316200E+00, 0.19280300E+00, 0.20257800E+01, -.93270800E-01, 0.51577400E+00, -.98319700E+00, 0.15795900E+01, -.23140700E+00, 0.20474500E+00, -.68127100E+00, 0.60494400E+00, -.17061100E+00, 0.81748500E+00, -.54820700E+00, 0.23445900E+00, 0.40006500E-01, 0.45415000E+00, 0.64753400E+00, -.36193200E+00, -.99256400E+00, 0.44461800E+00, 0.18441200E+00, -.48442900E+00, -.79601000E+00, 0.24497300E+00, 0.37327800E+00, -.31795000E+01, -.29728400E+00, 0.78662400E-01, 0.52548000E+00, -.40994400E+00, 0.82726500E+00, 0.21685800E+00, -.97067000E-02, 0.14127900E+00, 0.28655200E+00, -.81931200E+01, -.52244100E+00, -.60709000E-01, -.87287500E+00, 0.28441000E-01, -.11984500E+00, 0.29681100E-01, -.49760200E+00, -.18096000E+00, -.90438400E+00, 0.21242700E+00, 0.32297000E+00, 0.22706000E-01, -.37446300E+00, 0.39686400E+00, 0.40386300E+00, -.26083600E+03, -.11025800E+03, 0.18860300E+03, 0.14345400E+03, 0.30180000E+03, -.10387600E+03, -.12764100E+03, 0.62760300E+02, 0.63013400E+02, 0.69602700E+00, 0.96168700E+02, 0.12331600E+02, -.11628900E+03, 0.71773500E+02, 0.72076300E+02, -.10706700E+03, 0.52394100E+02, 0.54749200E+02, -.40165500E+02, 0.16698500E+02, 0.73030900E+02, -.45700600E+02, 0.69497100E+02, 0.23016700E+02, 0.80953200E+02, -.47817800E+02, -.43532300E+02, -.19530900E+02, -.46824200E+02, -.27512600E+02, 0.23600900E+02, -.40618700E+02, -.62770300E+02, 0.18045000E+03, -.92702000E+02, -.86142900E+02, -.67554900E+02, -.50615200E+02, 0.14921300E+02, 0.13723100E+03, 0.68040000E+02, -.10527600E+03, 0.88458600E+02, -.44424900E+02, -.52083500E+02, -.63058900E+02, -.83064700E+02, 0.51951900E+02, 0.17886300E+03, 0.12993600E+03, -.89961300E+02, -.20823100E+02, 0.12275200E+02, 0.12261700E+02, 0.10645500E+02, -.14903200E+01, 0.50156900E+01, -.20445600E+02, -.14360500E+02, 0.51850900E+01, -.82160900E+02, 0.41941200E+02, 0.55831700E+02, -.95207300E+02, -.61446400E+02, 0.11709600E+03, 0.33005400E+02, 0.87425300E+02, -.41843900E+02, -.24672300E+03, 0.11628500E+03, 0.12546300E+03, 0.10271200E+02, -.70376400E+02, 0.54500700E+02, -.46977100E+02, 0.99342000E+02, 0.15411300E+02, -.35172700E+01, 0.34572000E+01, 0.10234000E+02, 0.22781000E+01, 0.69721200E+01, 0.33392700E+01, 0.23530700E+01, -.56694800E+01, 0.12322600E+02, -.40324700E+02, 0.38488800E+01, -.41971700E+02, 0.15082700E+02, 0.53693800E+00, 0.52191600E+02, -.54519000E+01, 0.13963000E+02, -.42095000E+02, -.34353700E+01, 0.26934700E+00, -.39682500E+02, 0.11555600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.53658900E+01, -.34925200E+01, -.42449100E+01, -.44964800E+02, 0.74264300E+01, 0.98619600E+00, -.36785400E+01, -.17130800E+01, 0.85607200E+01, -.27253100E+01, 0.18496900E+01, -.23901700E+00, -.30750300E+01, -.21871700E+01, 0.53421700E+00, -.29995100E+01, -.44098800E+01, -.11935700E+01, -.14327800E+01, 0.20811500E+01, -.61717800E+00, -.40523900E+01, -.39960200E+01, 0.15321400E+01, -.12207200E+00, -.11518800E+01, -.15132400E+02, 0.40769300E+01, 0.20109200E+02, -.17843300E+01, 0.10284000E+01, -.40612400E-01, -.14654200E+01, 0.31916700E+01, 0.26803900E+01, -.22887600E-01, -.73707000E-01, -.44537000E+00, 0.14320000E+01, -.73589900E+00, -.21308400E+01, 0.24487300E+01, -.11911000E+01, 0.24304000E+01, -.20078900E+01, 0.75195700E+00, 0.37752000E+01, 0.47144600E+00, 0.10250500E+01, -.32404400E+00, -.13504300E+01, -.36789300E+01, 0.15285800E+01, -.23217000E+01, 0.19897000E+01, -.47078900E+00, -.32267800E+00, 0.27894500E+00, 0.30072400E+00, 0.20021100E+01, -.12400600E+01, -.34542400E+01, -.21009000E+01, -.38687200E+00, 0.10937200E+01, 0.43597900E+00, -.51451100E+00, 0.34693800E+00, 0.19870000E+01, 0.39584100E+00, -.51188500E+00, -.90368500E+00, 0.52936500E+00, -.47794800E+00, -.21728700E+00, -.95857400E+00, -.16031900E+01, 0.93189200E+00, -.17539600E+01, 0.60768500E+00, -.26448200E+00, 0.20374400E+01, 0.15689100E+01, -.51821500E+00, -.66773800E+00, 0.26554900E+01, 0.46534600E+00, 0.57545700E+00, -.39892200E-01, 0.18774400E+01, -.14490900E+01, -.28569700E-01, 0.27400800E+00, 0.10825500E+00, -.82196400E+00, 0.14767700E+02, 0.70000700E+00, 0.73892600E-01, 0.20321400E+01, -.12944800E+01, 0.45203800E+00, 0.33875700E+00, 0.10596800E+01, -.83789500E-01, 0.98909600E+00, -.51592800E+00, -.84217100E+00, 0.74895300E+00, 0.92016300E+00, 0.47730600E+00, 0.13032800E+00, -.99522900E+00, -.14970500E+03, 0.21829900E+03, 0.12875300E+03, 0.49685500E+03, -.25894200E+03, -.29016300E+02, 0.13925100E+02, 0.14256700E+02, 0.34476600E+02, 0.99574800E+02, -.16099900E+02, -.12965600E+03, 0.10931400E+03, 0.62945200E+02, -.18657400E+03, 0.92904500E+02, 0.91860000E+02, -.45224700E+02, 0.37691500E+02, 0.11210100E+03, 0.26657700E+02, 0.20317600E+03, 0.44396900E+02, 0.10832400E+03, -.61830600E+02, -.58571600E+02, 0.27554500E+01, -.92751500E+02, -.24576500E+02, 0.95422200E+01, -.14590400E+02, -.10515900E+03, -.41739500E+03, 0.21040900E+03, 0.20709300E+03, -.89036800E+01, 0.10620500E+03, 0.14124200E+03, 0.84960300E+02, 0.11482800E+03, 0.99291200E+02, 0.16200800E+03, -.80821300E+02, -.75240400E+02, -.38555500E+02, -.11271300E+03, 0.48791800E+01, 0.15300300E+03, 0.79970000E+02, -.14788000E+03, 0.23173600E+02, -.99886300E+01, -.13684800E+02, 0.10474200E+02, 0.73289200E+01, -.16910200E+02, -.64933800E+01, -.25868700E+02, 0.10257400E+01, -.26058800E+03, 0.12947700E+03, 0.11799600E+03, 0.16519700E+02, -.64912700E+02, 0.20901900E+03, 0.58844600E+02, 0.28033000E+03, -.83481100E+02, 0.30726200E+03, -.15389700E+03, -.15009400E+03, 0.25897500E+02, -.32101400E+02, -.14498000E+03, -.14026200E+03, -.13188100E+03, -.33151700E+02, 0.33160400E+01, 0.44026400E+01, 0.19807100E+01, -.43875100E+01, 0.73904000E+01, 0.23485900E+01, -.16401400E+01, -.60105400E+01, 0.16764200E+01, -.26933200E+02, 0.74173400E+01, -.26914900E+02, 0.74919600E+01, 0.63149900E+02, 0.56271500E+02, -.25521300E+02, 0.35839300E+01, 0.18756300E+01, -.60430600E+01, 0.10158500E+01, -.18080100E+03, 0.32656200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.40098800E+01, 0.32137900E+01, 0.42235500E+01, 0.33432600E+02, -.58268100E+01, -.99318700E+00, 0.24713400E+01, 0.11021800E+01, -.79978100E+01, 0.20499800E+01, -.23319600E+01, 0.39034600E+00, 0.29348600E+01, 0.18853400E+01, -.83990000E+00, 0.19123100E+01, 0.41456200E+01, 0.19793400E+01, 0.79622400E+00, -.18094100E+01, 0.45589400E+00, 0.35008700E+01, 0.67381400E+01, -.10357500E+01, 0.12504400E+01, -.31844900E-01, 0.10497900E+02, -.21285300E+01, -.12028600E+02, 0.15588200E+00, 0.47280600E+00, -.91688200E+00, 0.89809600E+00, -.60257000E+01, -.20360800E+00, -.10465600E+01, 0.16635100E+01, 0.37934400E+00, -.16717500E+01, 0.35066000E+00, 0.17178200E+01, -.18559100E+01, 0.90546800E+00, -.21804800E+01, 0.13070800E+01, -.27046200E+00, -.17401600E+01, -.17694500E+00, -.12625100E+01, -.34835100E-01, 0.79441600E+00, -.24355300E+01, 0.22584900E+00, 0.12576000E+01, 0.37750400E-01, -.11621200E+01, 0.72200700E+00, -.11469100E+01, -.11656400E+00, -.13624700E+01, 0.54108000E-01, 0.20837000E+00, -.96936300E+00, 0.54645700E+00, -.21850200E+00, -.77281800E+00, 0.84492600E+00, 0.45865600E+00, -.54195000E+00, -.58970500E+00, 0.34184200E+00, 0.52159400E+00, 0.22601900E+00, -.30250500E+00, 0.46114300E+00, 0.67789600E+00, 0.16966000E+00, -.30211000E-01, 0.86668400E+00, 0.13851700E+00, -.11016200E+00, -.12230800E+01, -.28780400E+00, 0.32348800E+00, -.57831300E+00, 0.59845100E+01, -.20843000E+00, -.49992900E+00, -.10870500E+01, 0.31536000E+00, -.23703800E+00, -.21647300E+00, -.69341100E-01, -.43411500E+00, -.17415600E+00, 0.22984200E+01, 0.20115000E+00, -.12436500E+00, 0.12682900E+01, -.10937000E+00, 0.92022000E-01, 0.53264700E+00, -.56363300E+00, -.56919600E+00, 0.30362600E+00, -.13595900E+00, -.18505200E+00, 0.14440600E+01, -.53166200E+00, -.93505300E+00, 0.39168200E+00, 0.65022700E+00, 0.43349700E+00, -.13697100E+03, -.19051600E+03, -.56933300E+03, 0.81448500E+02, -.27841500E+03, 0.13748600E+03, 0.14130500E+03, 0.50069900E+02, -.68026500E+01, 0.86188800E+02, 0.13338700E+03, 0.87448000E+02, 0.57129300E+01, 0.21529300E+03, -.10830500E+03, -.10662200E+03, -.21416600E+02, -.59132600E+02, -.63140300E+02, 0.10743800E+03, -.65966500E+02, -.62758500E+02, 0.79744500E+02, -.39081800E+02, -.38083600E+02, 0.27885600E+02, 0.49257000E+02, -.73431300E+02, -.10361200E+03, -.76121500E+02, 0.14836400E+03, 0.29175500E+03, -.15684900E+03, -.13458500E+03, -.58162900E+02, -.12393500E+03, -.49954100E+02, -.49758000E+02, 0.15166800E+02, -.70295300E+02, -.28350400E+03, 0.14148600E+03, 0.13743000E+03, 0.54576400E+02, 0.67261900E+02, 0.38589900E+02, -.12951600E+03, -.81737100E+02, 0.12117400E+03, 0.28843700E+02, -.14781700E+02, -.12819600E+02, 0.31446600E+01, 0.20862500E+01, -.68331600E+01, -.25414800E+02, 0.66003800E+01, -.58052600E+01, 0.30246100E+03, -.15147900E+03, -.13157000E+03, -.46404000E+02, -.46533900E+02, -.17204800E+03, -.81875900E+02, -.34242700E+03, 0.63441400E+01, -.31585100E+03, 0.14834800E+03, 0.13788900E+03, 0.50863200E+02, -.13839900E+02, 0.10088900E+03, 0.13971100E+03, 0.10707800E+03, -.17524600E+02, -.31436200E+01, -.55956400E+01, -.36310700E+02, 0.36923100E+01, -.70824100E+00, 0.51167500E+01, 0.19416600E+01, -.73277200E+00, -.94713900E+01, 0.13902900E+02, 0.10056900E+01, 0.15545600E+02, -.78557500E+01, -.41735200E+02, -.33391200E+02, 0.70568000E+01, 0.15775100E+02, 0.40086000E+02, -.12286000E+02, -.10695700E+01, 0.13435500E+03, -.22092700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11754000E+01, 0.74047000E+00, 0.58962900E+00, 0.12496900E+02, -.15190900E+01, -.30848600E+00, 0.13209600E+01, 0.28325300E+00, -.30693500E+01, 0.63941800E+00, -.10491800E+01, 0.13147900E+00, 0.14233000E+01, 0.11795000E+00, -.90905700E-01, 0.15872600E+01, 0.93438000E+00, 0.78799300E+00, 0.51508900E+00, -.34323600E+00, 0.30042800E-02, 0.12562900E+01, 0.30643500E+01, -.30165700E+00, 0.27075300E+00, 0.28099300E+00, 0.28172600E+01, -.63242200E+00, -.20045400E+01, 0.87870400E-01, 0.23084700E+00, -.26495600E+00, 0.20820400E+00, -.84173400E+00, 0.12328500E+00, -.27957800E+00, 0.46789100E+00, 0.51515900E-01, -.37269800E+00, -.12603700E+00, 0.70204300E-01, -.75083700E+00, 0.36271200E+00, -.32119500E+00, -.15481600E+00, -.39656000E+00, -.32942900E+01, -.42947000E+00, -.39755400E-01, -.76712000E+00, 0.16137300E+00, -.75707300E+00, 0.66405000E-01, -.14377900E+00, 0.14123600E-01, 0.25844600E+00, -.93718000E+00, 0.88873000E+00, -.13848900E+00, 0.33546600E+00, 0.56914300E-02, -.96466900E-01, 0.53635300E+00, -.35562600E+00, -.34223700E+00, -.10351000E+01, -.46480500E+00, -.64773700E-01, 0.47600000E+00, 0.53430000E+00, 0.24174300E+00, -.36127000E-01, -.14184800E+00, -.13640900E-01, -.32005900E-01, 0.12885500E-02, -.11300700E+00, 0.74794500E-01, -.75280000E+00, -.31664300E-01, -.21807200E-01, -.13534100E-01, 0.72242500E-01, 0.10970200E+00, 0.72910500E-01, -.83325800E+00, -.75851500E-02, 0.12116500E-01, 0.68755400E-01, -.86200500E-01, 0.21144500E-01, -.22696700E-01, -.49768100E-02, 0.46631300E-01, 0.63038100E-01, 0.42920500E+00, 0.79597500E-01, 0.61664800E-01, -.40613700E-01, -.49989400E+00, -.46867300E-01, -.23534600E-01, 0.31593700E-01, 0.15450000E+00, 0.12136000E+00, 0.16567100E+00, 0.14099100E+00, 0.27216600E-01, -.17867800E+00, -.13754200E-02, 0.15922400E-01, 0.23863400E+00, -.22196200E+00, -.27955400E+00, -.57007200E+02, -.15225000E+03, 0.14941300E+02, -.61097400E+02, 0.30171900E+02, 0.29273000E+02, 0.22280900E+02, 0.12289700E+02, 0.51364500E+01, 0.38471700E+02, -.11961100E+02, 0.16224300E+02, 0.45271600E+02, -.22898400E+02, -.22491800E+02, -.40548000E+01, -.31083100E+01, -.18882300E+02, 0.27341200E+02, -.26355800E+02, -.41654100E+01, 0.47940300E+02, -.24203200E+02, -.23052200E+02, 0.27301200E+02, 0.18483900E+02, -.30935800E+02, -.36829500E+02, -.34032400E+02, 0.33839000E+02, 0.10334700E+03, -.52954000E+02, -.50308300E+02, 0.30727200E+01, -.14198000E+02, -.25280300E+02, 0.14512600E+02, -.11227100E+02, 0.94630400E+00, 0.45426500E+01, -.23256400E+01, -.39566500E+01, -.12326400E+02, -.10369100E+02, 0.69776000E+01, -.16433600E+02, 0.97389100E+01, 0.77709000E-01, 0.19632700E+02, -.10104800E+02, -.92179000E+01, 0.31927200E+01, -.21324100E+01, -.63154800E+01, -.61339900E+01, -.25667200E+02, -.11789400E+01, 0.24917000E+02, -.12529800E+02, -.61965100E+01, -.88639400E+01, 0.59827000E+01, -.86092600E+01, -.25720500E+02, -.83521500E+02, 0.14692100E+02, -.48128900E+02, 0.23642700E+02, 0.20451800E+02, 0.14913800E+02, 0.63864400E+01, 0.72081300E+01, 0.44004000E+01, 0.17975000E+02, -.92634900E+01, 0.18998000E+00, -.97815700E+00, -.48324100E+01, -.30486600E+01, 0.19355400E+01, 0.74443400E+00, -.66406300E+00, 0.51170000E+00, 0.15097800E+01, 0.28100000E+01, 0.12955500E+01, 0.35933800E+01, 0.12598400E+01, -.12137400E+01, -.15901700E+02, 0.35047800E+00, -.19470400E+01, -.14579100E+01, -.96317900E+00, 0.32724000E+00, 0.18187600E+02, -.24856100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.27027200E+01, 0.14788300E+01, 0.19463400E+01, 0.23938900E+02, -.42098700E+01, -.62322400E+00, 0.21438200E+01, 0.67429200E+00, -.50807000E+01, 0.12941100E+01, -.12425800E+01, 0.42771600E+00, 0.21887100E+01, 0.32703700E+00, -.90351400E+00, 0.31623700E+01, 0.28631000E+01, 0.23578300E+01, 0.85628700E+00, -.17183400E+01, 0.36090600E+00, 0.28088100E+01, 0.82806200E+01, -.40337400E+00, 0.10503000E+01, 0.90594200E+00, 0.72113500E+01, 0.58368200E-01, -.15713000E+00, 0.58730100E+00, 0.12592400E+01, -.49390100E+00, 0.31794600E+00, -.21947900E+01, 0.11338700E+01, -.28123700E+01, -.73264400E+00, -.36582600E-01, 0.14747000E+01, -.25862500E+00, -.76865700E+00, -.15333500E+01, 0.14836500E+01, 0.22712800E-01, -.14561400E+00, -.14588200E+00, -.39136700E+01, 0.73063900E-01, -.70012600E-01, -.76624600E+00, 0.31840600E+00, -.25098100E+00, 0.90767300E-01, -.70426200E+00, 0.15444200E+00, 0.25033800E+00, 0.29200200E-02, 0.70908100E+00, 0.87376500E-01, 0.57786100E+00, 0.21449700E-01, 0.66041300E+00, 0.49511800E+00, 0.29935400E+00, -.10970300E+00, -.97664300E-01, -.39219500E+00, -.72062500E-01, 0.76286100E-01, -.47106100E+00, -.10839300E+00, 0.10479300E+01, -.62804000E+00, -.29105200E-01, 0.14112100E+00, -.60702100E+00, 0.39692700E+00, 0.37812300E+00, -.18283100E+01, 0.24500400E+00, -.51569200E-01, -.28254900E+00, 0.19848200E+00, 0.41323700E+00, -.21106800E-01, 0.21815500E+01, 0.33348700E+00, 0.17871500E+00, 0.23702600E+00, 0.54640500E+00, -.67471600E-01, -.56443700E-01, 0.50191700E-01, 0.35973900E+00, -.25432000E+00, 0.48574400E+01, -.26317800E+00, -.41287600E+00, -.28925700E+00, 0.51586700E+00, -.10212900E+00, -.10782600E+00, 0.50954300E+00, 0.47615900E+00, 0.56741500E+00, 0.12635600E+00, 0.10352100E+00, 0.63900600E+00, -.58752600E+00, 0.44675500E+00, 0.28533900E+00, 0.20732100E+00, -.26731400E+00, -.40283900E+00, 0.66777800E+00, 0.17511600E+03, -.26255000E+02, -.27846500E+02, 0.14139100E+02, 0.15926200E+02, 0.44359800E+02, 0.56192900E+02, -.26931200E+02, -.72450600E+02, 0.46401600E+02, 0.32460800E+02, -.42521900E+02, 0.20174500E+02, 0.22484100E+02, -.15139700E+02, 0.10037700E+02, 0.19501300E+02, 0.66186300E+01, 0.68930100E+02, 0.18613400E+02, -.64092000E+01, -.20944200E+01, -.96411800E+00, 0.46229600E+01, -.16266400E+02, 0.34231200E+01, 0.38918500E+01, -.91354400E+01, -.35259100E+02, -.19681700E+03, 0.97861500E+02, 0.10464200E+03, -.29923100E+02, -.10581300E+02, 0.80764400E+02, 0.25413700E+02, 0.31830100E+02, 0.15170500E+02, 0.15309700E+02, -.78706800E+01, -.96521200E+01, -.10553000E+02, -.32629400E+02, 0.84150700E+01, 0.25552200E+02, 0.21462300E+02, -.39377900E+02, 0.62346800E+01, -.27467000E+01, -.26340500E+01, 0.25478500E+01, 0.27925600E+01, -.32408900E+01, -.38067100E+01, -.20103200E+02, 0.43266300E+00, -.64953900E+02, 0.32174500E+02, 0.36994100E+02, -.95928600E+01, -.72991700E+00, 0.20647600E+02, 0.43620700E+00, 0.10810700E+03, 0.22260400E+01, 0.19441900E+03, -.10055600E+03, -.99323700E+02, 0.19504600E+02, -.96212000E+01, -.80792200E+02, -.54429200E+02, -.56018800E+02, -.28113400E+02, 0.75790300E-01, 0.19359900E+01, -.27766300E+01, -.35514600E+01, 0.53369100E+01, 0.32520400E+01, 0.24640700E-01, -.41876800E+01, 0.12980000E+01, -.12308200E+01, 0.47556900E+01, -.13108000E+01, -.31777800E+01, -.33404300E+01, 0.26170100E+02, -.90878100E+01, -.82141500E+01, -.35058500E+01, -.40202200E+01, -.53044000E+00, -.87647100E+01, -.35036400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10002800E+01, -.47996500E+00, -.49970100E-01, -.15720100E+02, 0.16097000E+01, -.39404300E+00, -.12026500E+01, 0.73450900E+00, 0.41075700E+01, -.88274400E+00, 0.10174100E+01, 0.26318000E+00, -.31278300E+01, -.27574000E-01, -.41539700E+00, -.33555900E+01, -.98706600E+00, -.64213500E+00, -.74646100E+00, 0.42050200E-01, 0.32836500E-01, -.15300400E+01, -.26986500E+01, 0.85505900E-01, 0.69824200E+00, 0.15792800E+00, -.12073500E+01, 0.61183000E+00, 0.22322500E+01, -.15897600E+00, -.19997100E-01, 0.14105900E+00, -.59884800E+00, 0.78555700E+00, 0.28270800E+00, 0.36754900E-01, -.55662600E+00, -.38605500E-01, -.18866900E+00, -.20827400E+00, -.25181400E+00, 0.27516500E+00, -.67554900E-01, 0.79224000E+00, 0.33929600E+00, 0.25142300E+00, -.26328900E+01, -.41344600E-01, 0.35588700E+00, 0.44040900E+00, -.24286900E+00, -.42998200E+00, -.12036200E+00, -.70043100E+00, 0.24000800E+00, -.26605300E+00, 0.42944700E-01, -.20647000E+01, 0.24834000E+00, -.57388100E+00, -.26374700E+00, -.14039400E+01, -.27533900E+00, 0.17399300E+00, 0.23037500E+00, 0.25756600E+00, 0.37145900E+00, -.34910800E-02, -.44259600E+00, 0.10547400E+00, -.86746000E-01, 0.16215700E+00, -.64113600E-01, -.30306400E-01, -.35834500E-01, -.14952200E+00, 0.38924500E-01, 0.84717000E-01, -.24110500E+00, 0.61505500E-01, -.14864800E-01, -.19487500E+00, -.10323400E+00, -.28511400E-01, -.14018200E+00, 0.11901600E+01, -.17414800E+00, -.16411800E+00, 0.10854700E+00, 0.96277200E+00, -.99736700E-01, -.17890100E+00, 0.16595000E-01, 0.47257500E-01, -.11804900E-01, -.26278400E+01, -.42395200E+00, -.25952100E+00, 0.80719800E+00, -.23442700E+00, -.66241000E-01, 0.16842000E+00, -.40299200E-01, 0.38611900E-01, 0.21601400E-01, 0.14886600E+00, -.79572700E-01, 0.36162400E+00, 0.35284800E+00, -.30057000E+00, 0.33594400E-02, 0.17622100E+00, 0.19680200E-01, 0.32757400E-01, -.11916800E+01, 0.23698900E+00, 0.41068300E+02, -.35988200E+02, 0.18118100E+02, 0.10873200E+02, -.17908200E+02, -.14551900E+02, 0.48684200E+01, 0.80568700E+02, -.10428600E+03, 0.20966400E+02, 0.55708600E+02, -.26858600E+02, -.28640600E+02, 0.27662000E+02, 0.17187600E+02, -.63742700E+02, -.29424000E+02, -.12682000E+03, 0.20692100E+02, -.17886700E+02, 0.12004200E+02, 0.18785300E+02, 0.36183900E+02, 0.42992300E+02, 0.33325100E+01, 0.79309900E+01, -.54999200E+01, 0.20027100E+02, 0.38698300E+03, -.19073600E+03, -.20420600E+03, 0.53627300E+02, -.17495100E+02, -.15181600E+03, -.35263400E+02, -.17930000E+03, -.92247400E+01, 0.11587300E+03, -.57817300E+02, -.62933400E+02, -.37122600E+02, -.12157800E+02, -.27797500E+02, -.38753400E+02, 0.25285000E+02, -.76944100E+01, 0.12148300E+02, -.66436700E+01, -.61035700E+01, 0.24248100E+01, -.72266300E+01, -.14707100E+01, -.27299900E+01, -.70747900E+02, -.86283100E+00, 0.17934800E+02, -.10572700E+02, -.13296200E+02, 0.30342200E+01, 0.25361900E+02, -.56286300E+01, 0.32705300E+02, 0.63823300E+02, 0.22464800E+02, -.14917900E+03, 0.83256800E+02, 0.81374700E+02, -.13363500E+02, 0.53760500E+02, 0.60053400E+02, 0.37332400E+02, 0.52554100E+02, 0.29223800E+02, 0.23773800E+00, 0.38005300E+01, 0.11967000E+02, -.10169500E+02, 0.59117400E+01, -.15844500E+01, -.10645300E+01, 0.30457600E+01, 0.92407700E+01, 0.24187300E+01, 0.33137500E+01, 0.12442700E+01, 0.51553500E+01, 0.13984600E+02, -.43318300E+02, 0.82798800E+01, -.13084900E+02, -.10398000E+02, 0.10417900E+02, 0.14908200E+01, -.57515500E+01, 0.67731100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20086700E+01, -.15598500E+01, -.37937700E+00, -.23237400E+02, 0.24189900E+01, 0.63588600E+00, -.19466000E+01, -.65995400E+00, 0.52968200E+01, -.11001400E+01, 0.16985300E+01, -.66882700E+00, -.23144100E+01, -.66507600E+00, 0.51531800E+00, -.22391000E+01, -.27930300E+01, -.21853200E+01, -.93360200E+00, 0.10475600E+01, -.25901000E+00, -.14213800E+01, -.51260200E+01, 0.69084000E+00, -.16515800E+00, -.45696500E+00, -.87994900E+01, 0.59833900E+00, 0.74829400E+00, -.64095200E+00, -.74164200E+00, -.33045600E-02, -.48935200E+00, 0.11765200E+01, -.52541800E+00, 0.10190000E+01, -.55472800E+00, -.13252700E-01, -.19742000E+00, 0.89406900E-01, -.10042000E+00, 0.81183100E+00, -.86777900E+00, -.11182300E-01, 0.59020500E+00, 0.12774100E+00, -.32985600E+01, 0.31940200E+00, -.38710200E+00, -.66399000E+00, -.63644800E-02, 0.56568900E-01, 0.18667400E+00, -.14097400E+01, 0.75201600E+00, 0.54649900E+00, -.58096600E+00, -.29874100E+00, 0.24235000E-01, 0.33589600E+00, -.32109300E+00, -.76950400E+00, 0.93236300E-01, -.21866100E+00, 0.31295000E+00, -.59118800E+00, -.75318200E-01, 0.34941500E-02, 0.48496500E-01, 0.82781100E-02, -.35980000E-01, -.29551100E+00, 0.11223200E+00, 0.11310900E-02, -.39673100E-01, -.10454200E+00, -.16569200E+00, 0.36929300E-01, -.11927800E+01, -.14558500E+00, 0.50981700E-01, 0.83358600E+00, 0.67639900E+00, -.46093800E+00, 0.65256400E-01, -.17580800E+00, 0.69971500E-02, 0.26189900E-01, -.22950800E+00, 0.22603000E+00, -.11676000E+00, -.32817500E-01, 0.79679500E-01, 0.39513400E-02, 0.76504200E-01, -.39483500E+00, -.27771600E-01, 0.49182300E-01, 0.21883500E+00, -.44438500E-01, -.29951000E-01, 0.19523000E+00, 0.17006800E-02, -.84191800E-01, -.21716400E+00, -.36478000E-01, -.66568000E-01, 0.73102200E-01, 0.30946300E+00, -.47356700E-01, 0.96074100E-01, 0.59955100E-01, 0.29905600E+00, 0.65440000E-01, 0.57487000E-01, 0.38459600E+00, 0.10996200E+01, 0.10944400E+03, -.55084500E+02, -.47675800E+02, -.69657300E+01, -.21349900E+02, -.24240600E+02, -.46640400E+02, 0.56913300E+02, -.33276900E+02, -.61157600E+02, 0.29639800E+02, 0.31483300E+02, -.40308200E+02, -.26361500E+02, 0.62430900E+02, 0.43899900E+02, 0.95848900E+02, -.33370100E+02, 0.84941400E+02, -.44869500E+02, -.50888500E+02, -.46797800E+02, -.52591900E+02, -.33467400E+02, -.44971300E+02, -.23068000E+02, -.28293100E+01, -.34065300E+03, 0.16665100E+03, 0.17834200E+03, -.18899100E+02, 0.12308200E+02, 0.11953100E+03, -.86719700E+01, 0.10751400E+03, 0.11361500E+02, -.10562500E+03, 0.52788300E+02, 0.57981100E+02, 0.25443700E+02, 0.11491900E+02, 0.43701600E+02, 0.46046200E+02, 0.80094400E+01, 0.40055800E+01, -.15800300E+02, 0.88877400E+01, 0.78902100E+01, -.35360600E+01, 0.65028500E+01, 0.55340700E+01, 0.22577700E+01, 0.70783200E+02, 0.11464100E+01, -.74006600E+02, 0.38619700E+02, 0.39507300E+02, 0.79873800E+01, 0.43874500E+01, 0.15155100E+02, -.35756900E+02, -.41683100E+02, 0.10810600E+02, 0.11337600E+03, -.67378700E+02, -.64346400E+02, -.54461200E+01, -.19923700E+02, -.44516600E+02, 0.26820500E+01, -.44995900E+02, -.16517800E+00, -.59404900E+00, -.26882600E+01, -.68751100E+01, 0.10861500E+02, -.46890300E+01, 0.89478100E+00, 0.13389600E+01, -.15779300E+01, -.90492900E+01, 0.50714600E+01, -.24171700E+01, 0.47550200E+01, 0.25891400E+00, -.11261600E+02, 0.26777800E+02, -.51662000E+01, 0.27271200E+02, -.56037100E+01, -.11804500E+02, -.16436300E+01, 0.10763100E+02, -.46005400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12281800E+02, -.52851900E+01, -.10764000E+02, -.79816600E+02, 0.10106500E+02, -.14885600E+00, -.68527200E+01, -.60538300E+01, 0.27202500E+02, -.60509900E+01, 0.85895200E+01, -.27541500E+01, -.17094400E+02, -.62054500E+01, -.48082000E-01, -.93055800E+01, -.13316400E+02, -.69403400E+01, -.25704800E+01, 0.53196400E+01, -.97534600E+00, -.16092400E+02, -.30563400E+02, 0.30698300E+01, -.58907500E+01, -.14553900E+01, -.21851500E+02, 0.40883400E+01, 0.32625000E+02, 0.16257700E+01, -.31774100E+01, 0.69111300E+01, -.25999500E+01, 0.76275200E+01, -.21558900E+01, 0.10725000E+02, -.27168200E+00, -.65858200E+00, -.22482700E+01, 0.10240700E+01, 0.13521000E+01, 0.29832100E+01, -.95143100E+00, -.51951500E+01, 0.17325300E+01, 0.17243400E+01, -.16910300E+02, 0.36928300E+01, -.67593100E+00, 0.58997700E+00, -.31469100E+00, -.24082800E+01, -.17715400E+01, -.45141000E+01, 0.32516800E+00, 0.32769600E+01, -.48773400E+01, -.76010900E+00, 0.55576700E-01, -.90356200E+00, -.12055500E+00, -.27327200E+01, 0.38401200E+01, 0.11108200E+01, 0.17430700E+01, -.26407400E+01, 0.37703500E+00, 0.91129600E-01, -.39103000E+01, 0.31744000E+00, 0.90536100E-01, 0.23392200E+00, -.35564700E+00, -.17257700E+01, 0.24380500E+01, -.19144700E+01, 0.15520400E+01, 0.53562900E+01, 0.72077400E+01, 0.98249300E+00, -.73557500E+00, -.28002700E+01, 0.31377000E+01, -.22285100E+01, -.44528700E+01, 0.12256900E+02, 0.12287600E+01, 0.71858100E+00, 0.39509500E+01, -.22299300E+00, -.27329800E+01, -.68521600E+00, -.56542200E+00, 0.71013100E+00, -.24880300E+01, 0.32066400E+01, 0.58119200E+00, -.16596600E+01, -.11334300E+01, -.14362100E+01, 0.29112100E+00, 0.35511600E+00, 0.13260000E+01, -.43939400E-01, -.87274200E-01, 0.36109800E+00, -.25368600E+00, 0.57893600E-01, 0.10245200E+01, -.27562000E+01, -.18643500E+01, -.13101800E+01, -.62251200E+00, 0.96639000E+00, -.69361900E+01, 0.14773400E+01, 0.19200400E+01, -.14155300E+01, -.76497100E+01, -.49517300E+01, -.21865600E+02, 0.28479300E+02, -.48683500E+02, -.30390100E+02, -.60113400E+02, 0.43590500E+01, -.16618800E+03, 0.76963500E+02, 0.91618800E+02, -.38593600E+02, -.46598400E+01, 0.61757800E+02, 0.77006300E+01, -.99189900E+02, -.90181600E+02, 0.36976400E+03, -.22147600E+03, -.16725000E+03, 0.19337600E+01, -.60524700E+02, -.20165000E+03, -.19678600E+03, -.12312700E+03, 0.70569300E+02, 0.51483500E+03, -.26800100E+03, -.27274800E+03, 0.10178700E+03, 0.22779500E+02, -.20383000E+03, -.61670500E+02, -.21807500E+03, -.82373300E+02, -.27891800E+03, 0.13881400E+03, 0.11955800E+03, 0.54902600E+02, 0.77255100E+02, 0.96670700E+02, 0.10919000E+03, 0.17079600E+03, 0.12275900E+03, 0.39724200E+02, -.63746900E+01, -.12587100E+02, 0.74781300E+01, 0.83130500E+01, 0.32993800E+01, -.27306400E+02, 0.32880800E+02, 0.10747100E+02, -.18677300E+03, 0.90813600E+02, 0.64266100E+02, 0.66611200E+02, 0.92414400E+02, 0.12430700E+02, -.40063400E+02, -.48544800E+02, 0.56310200E+02, -.45990700E+03, 0.18885700E+03, 0.22150000E+03, -.10716800E+03, 0.98802000E+02, 0.11495200E+03, 0.85732100E+02, 0.16470600E+03, 0.17638900E+03, 0.31145400E+01, 0.10213800E+02, 0.70197900E+01, 0.12972900E+02, 0.75624400E+01, -.31916700E+01, 0.69514700E+00, -.60955300E-02, 0.55585300E+01, 0.48734100E+01, 0.24984700E+01, 0.59935500E-01, 0.11355300E+02, 0.25905500E+02, 0.16575900E+02, -.45436700E+00, 0.68415500E+02, -.37368400E+02, -.19531400E+02, 0.15997200E+01, -.33756300E+02, 0.32541100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.42208400E+01, -.23791900E+01, -.24808500E+01, -.35568800E+02, 0.62802600E+01, 0.56025700E+00, -.31619700E+01, -.14629900E+01, 0.74497400E+01, -.21337200E+01, 0.17892300E+01, -.16995200E-01, -.44904000E+01, -.13120800E+01, 0.45138500E+00, -.25009700E+01, -.40780800E+01, -.95242400E+00, -.62431500E+00, 0.13814500E+01, -.58804200E+00, -.19800300E+01, -.60948200E+01, 0.14656100E+01, 0.40561700E+00, -.49020900E+00, -.21748200E+02, 0.26046800E+01, 0.12130500E+02, -.30762600E+01, -.61634900E+00, -.11399400E+01, -.10314400E+01, 0.50019400E+01, 0.36740000E+00, -.27502200E+01, -.28849200E+01, -.28076100E+00, 0.10883900E+01, -.64628100E+00, -.20243600E+01, 0.16577200E+01, -.48833000E+00, 0.15617700E+01, 0.55774400E+00, -.73708500E+00, -.11807000E+02, -.25389600E+00, -.10467100E+01, -.13371400E+01, -.11913400E+00, 0.88605500E+00, 0.33734700E+01, -.38341300E+01, 0.45650800E+01, 0.94793300E-01, -.68358200E+00, -.34776900E+00, -.20942700E+00, -.70128400E+00, -.92714100E+00, -.25238200E+00, -.13397800E+01, -.61845000E+00, 0.10221700E+01, -.15355500E+01, -.87450200E+00, 0.14113700E+00, 0.16917400E+01, -.10627000E+01, -.65037100E-01, 0.22162100E+00, 0.13275400E+00, -.16851100E+00, 0.24798900E+00, -.70368200E+00, -.55639800E-01, 0.51432700E+00, -.36598700E+00, -.21953100E+00, -.12396500E+00, 0.82967200E+00, 0.65008700E+00, -.14881100E+00, 0.74926600E+00, -.17631600E-01, -.26418400E-01, -.12768000E+00, -.54357000E+00, -.86386700E+00, -.71889300E+00, 0.11784200E+00, -.37210600E-01, -.73888800E+00, -.14647300E+00, 0.30712600E+01, 0.62165300E-01, 0.18316300E+00, -.36189600E+00, -.62440800E+00, 0.17117000E+00, -.26116100E+00, 0.68607600E+00, 0.52554200E+00, 0.18790400E-01, 0.10009700E-01, -.20715500E+00, -.10225200E+01, 0.36966400E+00, 0.19754100E+00, -.38939200E+00, -.13108800E+00, -.20074800E+00, -.28481600E+00, 0.47311800E+00, 0.64358900E+00, 0.65610000E+00, -.13417400E+01, -.12526400E-01, 0.16749000E+02, -.38368600E+02, -.62981500E+01, 0.32426300E+02, -.11438200E+03, 0.15767600E+03, -.22575300E+02, -.15675000E+03, 0.77073700E+02, 0.81530700E+02, -.44362200E+02, -.26336400E+02, 0.12247000E+03, 0.27044300E+02, 0.19917700E+03, -.42241600E+02, 0.96846200E+02, -.50106500E+02, -.65259800E+02, -.11630100E+03, -.95736700E+02, -.26266900E+02, -.37155300E+02, 0.67693700E+01, -.30118300E+02, -.46535100E+03, 0.22743100E+03, 0.25531900E+03, -.23497400E+02, 0.15371200E+02, 0.16749600E+03, -.10903400E+02, 0.21033700E+03, -.11152600E+02, -.23983900E+03, 0.12014300E+03, 0.13004300E+03, 0.84436300E+02, 0.39660600E+02, 0.77303300E+02, 0.10912800E+03, -.27534400E+02, 0.34402800E+02, -.54410100E+02, 0.28314700E+02, 0.27830900E+02, -.85687600E+01, 0.15200300E+02, 0.14127500E+02, 0.11511400E+02, 0.16075600E+03, 0.21771100E+01, -.30842400E+02, 0.20313100E+02, 0.25910500E+02, 0.15391700E+02, -.38069900E+02, 0.12484700E+02, -.68506500E+02, -.91128500E+02, -.27916900E+02, 0.15114900E+03, -.96382300E+02, -.96430400E+02, -.44235000E+02, -.74809200E+02, -.33748700E+02, 0.26673700E+02, -.42751100E+02, -.21516900E+02, -.15089700E+01, -.87486200E+01, -.15099800E+02, 0.23795800E+02, -.13929500E+02, 0.10417100E+01, 0.30079700E+01, -.27971300E+01, -.22664600E+02, -.14617500E+01, -.98107800E+01, -.15479100E+01, -.29096300E+01, -.29918700E+02, 0.64040500E+02, -.11119500E+02, 0.53541400E+02, -.15785600E+02, -.20579800E+02, -.28100500E+01, 0.23590500E+02, -.42129000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.51418500E+01, -.15874700E+01, -.61387200E+01, -.30275500E+02, 0.45086300E+01, 0.92165600E+00, -.85263800E+00, -.28860500E+01, 0.87983000E+01, -.20715400E+01, 0.27882900E+01, -.12705200E+01, -.51324200E+01, -.31615900E+01, -.15971500E+00, -.44447900E+01, -.52286500E+01, -.28385500E+01, -.10161300E+01, 0.21364900E+01, -.59953800E+00, -.34008800E+01, -.71255200E+01, 0.15102300E+01, -.11842400E+01, -.15386200E+01, -.22069000E+02, 0.27236400E+01, 0.14482200E+02, -.22775900E+01, -.43795300E+00, -.35831300E+00, -.15262400E+01, 0.33209100E+01, 0.43577400E+00, 0.17207600E+01, 0.47104000E+00, -.10808200E+00, -.15943000E+00, -.32728200E+00, -.80725500E+00, 0.32018500E+01, -.78442700E+00, 0.29686200E+00, 0.19052100E+00, -.93091600E+00, -.43896200E+01, 0.13049900E+01, -.70353800E+00, 0.14916800E+00, 0.33160100E+00, 0.33571400E-01, 0.89167600E+00, -.25908600E+01, 0.13649800E+01, -.62468200E+00, 0.17076400E+01, -.14872000E+01, 0.62403100E+00, -.43731300E-02, -.74869500E+00, -.20121500E+01, -.24035900E+01, 0.38911800E+00, 0.11636800E+01, 0.24828200E+01, -.30944600E+00, 0.19872800E+00, 0.94747200E+00, -.50782300E+00, -.79458700E+00, -.17654700E+00, 0.48904400E+00, -.50096400E+00, 0.33953100E+00, -.26934500E+00, -.70013500E+00, 0.35489200E+00, -.20271600E+01, 0.23090600E+00, -.84709200E-01, 0.67160700E+00, 0.53477200E+00, -.16229200E+00, -.99737500E+00, 0.62112000E+01, 0.18978400E+00, 0.13266200E-01, -.17619200E+01, 0.27007500E+00, -.19901800E+00, -.18659800E+00, 0.11335800E+00, -.27054400E+00, -.29137600E-01, 0.96787400E+01, 0.15455700E+00, -.20118300E+00, 0.23284900E+01, -.17828100E+00, -.17816400E+00, 0.49958400E+00, 0.56172700E+00, 0.31114700E+00, 0.26288100E+00, -.25011900E+00, 0.10999600E+00, 0.16874700E+01, 0.60369300E+00, 0.17976900E+00, 0.63122800E+00, -.20973500E+00, -.74364400E-01, 0.75094100E+00, -.12202000E+01, 0.16028600E+01, -.57745800E-01, 0.86574300E+00, -.79632300E-02, -.58360100E+00, -.11609100E+03, -.59062900E+02, 0.61308300E+02, 0.75645100E+02, -.35927600E+02, -.29129100E+02, -.44213900E+02, 0.23615700E+02, 0.21357900E+02, 0.19492000E+02, -.72439700E+01, 0.17134600E+01, -.84959600E+02, -.13005800E+03, -.81018900E+01, 0.65118000E+02, -.28648700E+02, -.37713200E+02, 0.75529500E+01, 0.27871300E+02, -.18730000E+02, -.40871800E+01, 0.16122500E+02, -.62987300E+01, 0.51089000E+03, -.24937800E+03, -.25540700E+03, 0.82755100E+02, -.27587000E+01, -.17862300E+03, 0.24925000E+02, -.10641600E+03, -.37582500E+02, 0.86923600E+02, -.42998300E+02, -.39354600E+02, -.56587500E+01, -.10956400E+02, -.26175700E+02, 0.42500500E+02, 0.18872500E+01, -.40066700E+01, -.63830200E+01, 0.33394100E+01, 0.15446300E+01, 0.24583500E+01, -.13750700E+01, -.41008300E+01, 0.47175000E+01, 0.13680100E+01, -.99018400E+00, -.61114100E+02, 0.33291900E+02, 0.22171400E+02, 0.37179600E+02, 0.36849100E+02, 0.21481200E+02, -.15903800E+02, -.26606400E+02, 0.10651600E+02, -.17325500E+03, 0.87706500E+02, 0.90642600E+02, -.85229300E+02, 0.33774800E+02, 0.11005000E+03, 0.75574200E+02, 0.85025700E+02, 0.15715200E+02, 0.12825800E+01, -.48942800E+01, 0.91759800E+01, 0.82323200E+00, -.12028600E+02, -.73447300E+01, -.92067000E+00, 0.87987900E+01, -.15123800E+01, -.51169900E+01, -.11091900E+02, -.53422800E+01, 0.89634100E+01, 0.21220900E+02, -.28960100E+02, 0.26209400E+02, 0.59250400E+01, -.49682700E+02, 0.98004900E+01, 0.20830500E+01, -.30811700E+02, 0.17869100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.59214700E+00, 0.10308400E+01, 0.42038100E+00, 0.10403000E+02, -.27203200E+01, -.31224900E-01, 0.13249600E+01, -.68751200E+00, -.20452000E+01, 0.71155100E+00, 0.57417400E+00, -.58811800E+00, 0.35207900E+00, 0.54186500E-01, -.39637900E+00, 0.40561500E+00, 0.75910200E+00, 0.89693700E+00, 0.11672900E+00, -.51997500E+00, 0.21095600E+00, 0.47576300E+00, 0.15194600E+01, -.14126800E+00, 0.24524600E-01, 0.15032200E+00, 0.15823700E+01, 0.15914600E+00, 0.78210900E+00, -.57051900E-01, 0.37109900E+00, 0.66148100E-01, 0.46728800E-01, -.21217900E+00, 0.35530100E+00, -.31677800E+00, 0.35405100E+00, -.51249700E-01, 0.51393400E-01, -.87908400E-01, 0.22277600E-01, 0.29962800E-01, 0.18127900E+00, 0.16500500E+00, -.44292100E+00, 0.91264200E-01, 0.20796100E+01, 0.11085300E+00, 0.21288400E+00, 0.14255500E+00, -.54733000E-01, 0.27805800E+00, -.16478400E+00, 0.14067100E+00, -.37380500E+00, 0.47148500E-02, -.22981100E-01, -.12404500E+00, 0.55124500E-01, -.61128800E-01, 0.54379100E-01, 0.47280500E-01, 0.19001400E+00, -.14463800E+00, -.29613800E+00, -.37277300E+00, -.22012100E+00, -.98432100E-01, 0.85802800E-01, 0.43622100E+00, 0.15024900E+00, -.16220800E+00, 0.44443000E-01, -.52412300E-02, 0.79462000E-01, 0.19498700E+00, 0.15434700E-02, -.16212900E+00, -.32161600E+00, -.55305000E-01, 0.30380700E-01, 0.86967100E-01, -.64182800E-01, 0.68655300E-01, 0.14879100E+00, -.66143100E+00, -.31010700E-01, 0.85781900E-02, -.20603600E+00, 0.10931000E+00, 0.63879800E-01, -.54224900E-01, 0.80761200E-02, 0.16668900E-01, 0.53931500E-02, 0.16479700E+01, -.36841300E-01, -.37671600E-01, 0.19826700E+00, 0.24072000E+00, -.45416800E-01, -.28042900E-01, 0.15470500E+00, 0.11461100E+00, 0.30385800E-01, -.35735200E-01, -.15430600E-01, 0.17372500E-01, -.43882900E-01, 0.60576500E-01, -.55500100E-01, -.61088800E-01, 0.91661000E-02, 0.41410900E-01, -.33293500E+00, -.10130500E+00, 0.12491900E+00, -.35429100E-01, -.22292900E-01, 0.44053400E-01, -.92529300E-01, 0.91678500E+01, -.65265900E+01, -.19575200E+01, -.20920500E+01, 0.50829500E+01, -.35672700E+01, 0.16772900E+01, 0.21366000E+01, 0.97988000E+00, 0.48337300E+01, -.27761200E+01, -.10674400E+02, -.15241900E+02, -.54197700E+00, 0.13562500E+02, -.76427800E+01, -.72973700E+01, 0.83990200E+01, 0.12026500E+01, -.61903000E+01, -.35875700E+01, -.27524200E+01, -.34951300E+01, 0.47355600E+02, -.22533300E+02, -.22182800E+02, 0.17068200E+02, 0.55844600E+00, -.15260900E+02, 0.32056800E+01, -.17738800E+02, 0.37749400E+01, -.33462500E+01, 0.16211200E+01, 0.95690500E+00, -.29176200E+01, -.39266300E+01, 0.46714700E+01, 0.10661600E+02, 0.98891100E+01, -.18439400E+01, 0.45753500E+01, -.21396600E+01, -.23435100E+01, 0.20875100E+01, 0.37155600E+00, -.14536900E+01, -.20358600E+01, -.55115700E+01, 0.14612400E+01, -.40613200E+02, 0.20323600E+02, 0.19888200E+02, 0.10653700E+01, 0.11716200E+02, 0.11495900E+02, -.38378000E+01, 0.16469500E+01, 0.10340800E+02, 0.92107500E+01, -.61166200E+01, -.56927500E+01, -.10063500E+02, 0.96098000E+01, -.31314000E+01, -.12446400E+01, 0.26226300E+01, -.92997600E+00, 0.69909400E-01, 0.98596300E+00, 0.18607900E+01, -.52528500E+00, 0.13981900E+00, -.38607900E+00, -.20707600E+00, -.63992700E-01, 0.95430800E+00, 0.58451500E+00, -.26037300E-01, -.19684600E+00, 0.57308100E+00, 0.64225100E+01, 0.15479700E+01, 0.62776100E+00, -.21956200E+01, -.12299000E+02, -.70828400E+00, 0.23096200E+00, -.66174700E+01, 0.28941800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22403500E+01, 0.11566900E+01, 0.19456700E+01, 0.18853400E+02, -.25992500E+01, -.21063500E+00, 0.12411600E+01, 0.72773800E+00, -.51878600E+01, 0.12520500E+01, -.13928800E+01, 0.34720100E+00, 0.34964000E+01, 0.10673700E+01, -.14874500E+00, 0.80092700E+00, 0.20531900E+01, 0.73004600E+00, 0.27389400E+00, -.62311100E+00, 0.17078800E+00, 0.34514400E+01, 0.60511300E+01, -.82551500E+00, 0.90773800E+00, -.10880600E+00, 0.32077300E+01, -.16001300E+01, -.81240400E+01, -.41485600E-01, 0.16310400E+00, -.12710400E+01, 0.74764700E+00, -.13811500E+01, -.13557800E+00, -.81720300E+00, 0.62139800E+00, 0.25674900E+00, 0.23018700E+00, -.36035900E-01, -.22935700E+00, 0.12230000E+00, 0.32706300E-02, -.46827800E+00, -.13880800E+01, -.18813400E+00, 0.25371800E+01, -.56861200E+00, -.16100300E-01, 0.29578200E+00, 0.12295200E+00, 0.19473400E+01, -.24842300E+00, 0.31826100E+00, 0.19630100E+00, 0.76573200E+00, -.35477600E+00, 0.16142700E+00, -.45168900E+00, -.65870700E+00, 0.12687500E-01, 0.15162300E+01, -.90456600E-01, 0.51527300E+00, 0.84069500E-01, 0.16070800E+01, -.18623000E+00, -.15118300E+00, 0.31174400E-01, 0.17566500E+00, 0.49113200E-01, -.10111800E+00, 0.18780900E+00, -.34188000E+00, 0.23573800E+00, 0.45196000E+00, 0.27004800E+00, -.55649000E-01, 0.17486700E+01, -.32854900E-01, 0.10341200E+00, -.56240300E-01, 0.84167000E+00, -.86587500E-01, 0.32466400E+00, -.23667700E+00, 0.28243000E+00, 0.19151500E+00, 0.40130900E+00, 0.31064500E+00, -.53175800E+00, -.12047100E+00, -.22487500E-01, 0.20378800E+00, -.10422200E+00, 0.35427500E+01, -.27738300E+00, 0.41393700E-02, 0.14509000E+00, -.50498300E-01, 0.46654600E-01, 0.33518000E-01, 0.56917700E+00, 0.40541000E+00, 0.95621600E-01, -.27077500E-01, -.19264500E+00, -.26818000E+00, 0.41074100E+00, -.57911100E-01, -.22551900E+00, -.23669700E+00, 0.12731600E+00, -.19680500E+00, -.10184300E+01, -.26881400E+00, 0.21775200E+00, 0.15357200E+00, 0.16911300E-01, 0.25715500E-01, -.39434100E+00, 0.34514000E+00, -.69273800E+01, 0.43507300E+02, -.19497700E+02, 0.12362900E+02, 0.51362400E+02, -.26016800E+02, -.23355600E+02, 0.11893900E+01, -.71820600E+01, -.30063000E+02, -.98102700E+01, -.48652300E+02, -.64798900E+01, 0.17020600E+02, -.88196300E+01, -.10663400E+02, 0.19676800E+02, 0.16431800E+02, -.35623900E+01, 0.14722600E+01, -.16837500E+00, 0.78932900E+01, 0.21504700E+03, -.10667900E+03, -.10373900E+03, 0.19062600E+02, -.17753300E+02, -.65285100E+02, 0.19651700E+02, -.63865400E+02, -.83397500E+01, 0.94453100E+02, -.47186800E+02, -.51011800E+02, -.27313700E+02, -.34365700E+02, -.85918600E+01, -.48053800E+01, 0.11805700E+02, -.31686900E+02, 0.10723400E+02, -.58592500E+01, -.44606200E+01, 0.27405100E+01, -.28536500E+01, -.27348500E+01, -.24222100E+01, -.35084800E+02, -.10063600E+01, -.54763100E+02, 0.27022500E+02, 0.30912800E+02, 0.42929200E+01, 0.26694200E+02, 0.16244900E+02, 0.14251300E+02, 0.31818500E+02, 0.17118500E+02, -.69733200E+01, 0.30400600E+01, -.19831600E+01, -.43272600E+01, 0.30253900E+02, 0.80792200E+00, -.25901800E+01, 0.14885500E+02, 0.42605600E+01, 0.47323200E+00, 0.64926300E-01, 0.70987100E+00, -.42664100E+01, 0.95125400E+00, -.10732100E+01, -.81708100E+00, 0.26926300E+01, 0.45627400E+01, -.16449600E+01, -.45047000E+00, -.12386200E+01, 0.35292000E+01, 0.12723600E+02, -.18922600E+02, 0.46375300E+01, -.22898600E+01, -.88631800E+01, 0.13205600E+01, 0.10751600E+01, -.15196900E+02, 0.46125000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36514600E+01, -.22024800E+01, -.40455500E+00, -.36068400E+02, 0.49451500E+01, 0.10182800E+01, -.27753900E+01, -.11593900E+01, 0.69530300E+01, -.19849800E+01, 0.16472600E+01, -.83824800E+00, -.47289200E+01, -.13423300E+01, 0.14484100E+01, -.40770100E+01, -.49623000E+01, -.38360600E+01, -.71324100E+00, 0.25131900E+01, -.60754600E+00, -.61845500E+01, -.18229400E+02, 0.11297600E+01, -.23395900E+01, 0.60136700E-01, -.68184500E+01, 0.13447000E+01, 0.42493200E+01, 0.31485500E+00, -.21914600E+01, 0.20578100E+01, -.41582300E+00, 0.52976000E+01, -.15758300E+01, 0.27224100E+01, -.72021000E+00, -.22148900E+00, -.19112300E+01, -.24099100E+00, 0.65272800E+00, 0.72979100E+00, -.12661200E+01, 0.16321000E+01, 0.26750000E-01, -.31678400E+00, 0.13825400E+01, -.92417600E+00, 0.99974900E+00, 0.57240300E-01, -.74588200E-01, -.15752300E+01, 0.58725500E+00, -.40338900E+00, 0.64642900E+00, -.14020300E+01, 0.10726800E+01, -.84440600E+00, 0.48143600E-01, -.89423900E-01, -.24365700E+00, -.60382000E+00, 0.33973400E+00, 0.24970400E+00, -.22068600E+00, 0.91507900E+00, -.12655700E+00, 0.24365200E+00, 0.19360300E+01, -.29111400E+00, 0.99110600E-01, 0.70723900E+00, 0.11961800E+00, -.75244800E-01, 0.70172000E+00, 0.16065800E+00, 0.36050100E+00, -.44855300E+00, -.12990100E+01, 0.26330600E+00, 0.66256600E-01, 0.82607300E-01, -.14791900E+01, -.42546000E-01, -.15630200E+01, 0.27093800E+01, 0.87700500E-01, -.32016800E+00, -.77578600E+00, -.10468200E+01, 0.11274300E+01, -.12418100E+00, -.19793600E+00, -.31380900E+00, 0.95701700E-01, -.96586100E+01, 0.45545200E+00, 0.85906900E-01, -.70709500E+00, -.16576700E+01, 0.12638600E+00, -.59454000E+00, -.12174200E+01, -.28166300E+00, -.25141900E+00, 0.70681900E+00, 0.47419200E+00, 0.25276500E+00, -.24711400E+00, -.66799800E+00, 0.23535100E+00, 0.36139900E+00, -.34584600E+00, 0.37277600E+00, -.11910300E+00, 0.39427000E+00, -.11704500E+01, -.46986300E+00, 0.41387000E-01, -.70202100E+00, 0.43773100E+00, 0.48926300E+00, 0.14352400E+01, -.10278500E+03, 0.63889600E+02, 0.50174200E+01, -.12040400E+03, 0.60079100E+02, 0.53577900E+02, -.50834500E+02, -.73869200E+00, 0.84044600E+02, 0.18981400E+02, 0.15018000E+03, -.73081000E+01, 0.10064800E+03, -.48818300E+02, -.46397300E+02, -.76111100E+02, -.71303900E+02, -.37942200E+02, -.19025300E+02, -.52454100E+02, 0.51589700E+01, -.57800600E+03, 0.28617900E+03, 0.29181100E+03, -.91836200E+02, 0.53078700E+02, 0.19265000E+03, -.47047600E+01, 0.18132600E+03, 0.34536400E+02, -.13466300E+03, 0.67051100E+02, 0.72460200E+02, 0.33968900E+02, 0.21277100E+02, 0.47611700E+02, 0.80418300E+02, 0.30942300E+02, 0.64550200E+01, -.38654800E+02, 0.20365200E+02, 0.17278300E+02, -.70017800E+01, 0.33245200E+01, 0.10935300E+02, -.16292700E+01, 0.10164900E+03, 0.54259400E+01, 0.60495900E+01, -.19970100E+01, 0.56521100E+01, -.34814300E+01, -.25599100E+02, -.91659500E+00, -.45972800E+02, -.10074400E+03, -.24087400E+02, -.63893600E+02, 0.28445000E+02, 0.44350600E+02, 0.14463200E+02, -.81445300E+02, 0.24018000E+02, 0.21471000E+00, 0.19639500E+02, 0.57577400E+01, -.23485600E+01, -.35114900E+01, -.53583400E+01, 0.15801200E+02, -.71921100E+00, -.55496200E+00, 0.24103900E+01, -.29037800E+01, -.93687800E+01, -.11191900E+01, 0.18508900E+01, -.41696900E+01, 0.51569200E+01, -.28371200E+02, 0.41749100E+02, -.12890200E+02, 0.44709500E+02, 0.43577900E+02, -.10780100E+02, -.22512500E+01, 0.28050200E+02, -.64128200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.79388600E+00, 0.52236000E+00, 0.37505800E+00, 0.68319000E+01, -.12495300E+01, -.76275800E-01, 0.73345700E+00, 0.22451500E+00, -.12924100E+01, 0.41069500E+00, -.28134100E+00, 0.17671500E-01, 0.68686500E+00, 0.12978100E+00, -.14168500E+00, 0.73795800E+00, 0.70976700E+00, 0.49763000E+00, 0.19038400E+00, -.38724900E+00, 0.12902900E+00, 0.65832900E+00, 0.88196500E+00, -.15161800E+00, 0.18891000E+00, 0.29264700E+00, 0.18508700E+01, -.90169700E-01, -.58141300E+00, 0.34946600E+00, 0.17891300E+00, -.38220300E-02, 0.10133300E+00, -.48271000E+00, 0.13357600E+00, 0.14463200E+00, 0.26968900E+00, -.24078900E-01, -.16361800E-01, 0.55465900E-02, 0.18666800E+00, -.20044300E+00, 0.16553400E+00, 0.14772200E+00, -.52029600E+00, 0.11880100E+00, 0.24218900E+01, -.34715000E-01, 0.35249800E+00, 0.12329600E+00, -.21831900E-01, 0.23775900E-01, -.32158800E+00, 0.64658500E+00, -.62176900E+00, -.44867700E-02, 0.21532000E+00, -.72587000E-01, 0.56234900E-01, 0.39482900E-01, 0.11350600E+00, 0.13254800E+00, 0.18308700E+00, -.86315100E-01, -.29844600E+00, -.14942400E+00, -.17489300E-01, -.40774100E-01, -.19418900E+00, 0.44657600E+00, 0.61480300E-01, -.27215900E+00, 0.19499500E+00, -.37612000E-01, 0.53434300E-01, 0.25795000E+00, 0.27927200E-01, -.49392900E-01, -.15729800E-01, 0.51798400E-02, 0.16320600E-01, -.17059200E+00, -.14872400E+00, 0.96821900E-01, 0.32735900E-01, 0.89780700E-01, -.87867900E-01, -.10126600E+00, -.19103500E+00, 0.32488900E+00, -.26096600E-01, -.96561200E-01, 0.67760700E-02, -.87867800E-02, 0.30864100E-01, 0.75346200E+00, -.63220400E-01, -.55673700E-01, 0.15096200E+00, 0.41061400E+00, -.73114300E-01, 0.23133100E-01, 0.12277300E+00, 0.70556400E-01, 0.35152400E-01, -.72483000E-01, 0.46001100E-01, 0.16328300E+00, -.23942500E+00, -.14148300E-01, 0.14361800E-01, -.10788500E-01, 0.29299700E-02, -.33204000E-02, 0.14061900E+00, -.12568500E+00, -.16666300E+00, -.43534900E-01, 0.40649400E-02, 0.42330900E-01, -.33345700E-01, -.72156400E+00, 0.21464500E+00, -.52266300E-01, -.32204600E+02, -.36665500E+01, -.19149800E+02, 0.96189700E+01, 0.90925100E+01, 0.49950300E+01, 0.69027300E+01, 0.19082500E+01, -.96617200E+01, -.21441600E+02, 0.83862600E+01, -.22144100E+01, 0.42333400E+00, 0.15893600E+01, 0.11604100E+01, 0.28402100E+01, 0.15134000E+01, 0.75492500E+01, 0.15962600E+01, -.70685200E+01, 0.13440100E+02, -.62029300E+01, -.58752000E+01, 0.39212000E+01, 0.41266600E+01, -.57991800E+01, -.44727100E+01, -.10511800E+02, 0.80717400E+01, 0.76878800E+00, -.41743200E+00, -.82130700E+00, -.15976100E+01, 0.36270300E+01, -.51159700E+01, -.17418600E+01, 0.20149800E+01, 0.62711700E+01, -.10383800E+01, 0.72241100E+00, 0.25313300E+00, 0.43885000E+00, -.23699500E+00, -.13239400E-01, -.46988100E+00, -.74916300E+01, 0.28107700E+01, -.72370400E+00, 0.54151200E+00, 0.20560400E+01, -.53366400E+01, 0.50134000E+00, 0.25519000E+01, 0.25717300E+01, 0.10734300E+02, -.34241400E+00, -.26265600E+02, 0.12548600E+02, 0.15518100E+02, -.12619900E+01, -.18011500E+00, 0.93675800E+01, 0.56648500E+01, 0.78622000E+01, -.52712400E+01, 0.15952500E+00, 0.20995700E+01, 0.29272000E+01, -.16377200E+01, 0.49485100E+00, 0.18650000E+00, -.65943300E-01, -.34664600E+00, 0.47597600E+00, -.10949700E-01, 0.70216300E+00, -.22894100E+00, 0.11632000E+01, 0.29629000E+01, -.44787200E+01, 0.20248400E+01, -.15966200E+01, 0.11981600E+01, 0.26789600E+01, -.54313800E+00, -.29408500E+01, -.97452800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14500900E+02, 0.64707200E+01, 0.12873800E+02, 0.10951900E+03, -.13977500E+02, -.19197800E+01, 0.82179800E+01, 0.70431200E+01, -.31660900E+02, 0.67807300E+01, -.12426300E+02, 0.41849600E+01, 0.16984200E+02, 0.54023700E+01, -.71824900E+00, 0.11935600E+02, 0.13053800E+02, 0.66735200E+01, 0.42019200E+01, -.71347200E+01, 0.17686800E+01, 0.20568300E+02, 0.28193900E+02, -.31314200E+01, 0.53804400E+01, 0.28465500E+01, 0.34599300E+02, -.59306600E+01, -.48345800E+02, 0.15443100E+01, 0.40794700E+01, -.72245500E+01, 0.23675000E+01, -.12531400E+02, 0.60368500E+00, -.51469300E+01, 0.18807700E+01, 0.82841300E+00, -.57229000E+00, -.28368800E+00, 0.12811700E+01, -.50373800E+01, 0.38249300E+01, 0.91635300E+00, -.20678200E+01, -.10073100E+01, 0.49153000E+01, -.87040000E+00, 0.11895700E+01, -.94282200E+00, 0.12744400E+01, -.10374200E+01, -.16195000E+01, 0.22506100E+01, -.22980600E+01, -.15732700E+01, 0.28830800E+01, 0.14021400E+01, 0.24441800E+00, 0.91945400E+00, 0.94239500E+00, 0.13339400E+01, -.10990100E+01, -.16968800E+00, -.19130000E+01, 0.28925500E+01, -.51528400E+00, 0.50456800E+00, 0.21525700E+01, 0.21869100E+01, 0.25541900E+00, -.23169200E+01, 0.15314500E+01, -.80673800E+00, -.73970100E+00, 0.22188500E+01, -.16076200E+01, -.17110800E+01, 0.14525900E+01, 0.22874700E+00, 0.24942800E+00, -.46423200E+00, -.17000800E+01, 0.96686800E+00, 0.14382200E+01, -.41318600E+01, -.25907200E+00, 0.96254500E-01, 0.50259300E+00, -.10045400E+01, 0.61722400E+00, 0.41555100E+00, 0.31181200E+00, -.92520500E-01, -.27418000E+00, -.20219100E+01, 0.18243400E+00, 0.52693800E-01, 0.51746700E+01, -.20309300E+01, 0.52159400E+00, 0.13345800E+01, -.15402600E+01, -.87872800E+00, 0.15602300E+01, -.70811300E+00, -.74142500E+00, 0.72791900E+00, -.41033300E-01, -.40003000E+00, 0.47099900E+00, -.44480900E+00, 0.96804800E+00, -.43047100E+00, 0.41566700E+01, 0.15049400E+01, -.45413100E+00, 0.24015400E+01, 0.13570600E+00, -.70706800E+00, 0.15556800E+00, -.57078800E+01, -.40535700E+01, -.19430000E+01, 0.81741100E+01, 0.14084100E+03, 0.14799300E+03, -.72125400E+02, -.72719900E+02, -.38869400E+02, -.77577900E+02, -.26300600E+02, -.85551700E+02, 0.73146500E+02, -.52799300E+02, -.94797500E+02, 0.83233700E+02, 0.41645300E+02, -.11824400E+03, -.84538700E+02, 0.13905700E+03, 0.22302000E+03, 0.13416000E+03, 0.17452600E+02, 0.14040800E+03, -.68728300E+02, -.50396000E+02, -.11689600E+03, 0.22266400E+02, 0.13085200E+02, 0.20605700E+03, 0.22050700E+03, -.71599700E+02, 0.41950300E+03, -.20926100E+03, -.21155800E+03, -.47591700E+02, -.18971200E+03, -.17495800E+02, 0.86947200E+02, -.11415100E+03, -.24882800E+03, -.46270000E+02, 0.18216600E+02, 0.21725600E+02, -.39712900E+01, -.72377300E+01, 0.11744100E+02, -.72565800E+01, 0.40812800E+02, -.18248600E+01, -.31556300E+03, 0.15450600E+03, 0.16353700E+03, 0.54523000E+02, 0.72445800E+02, 0.91015600E+02, -.27401100E+02, 0.13915500E+02, 0.34543600E+02, -.21831000E+03, 0.13231500E+03, 0.84417600E+02, 0.55952500E+01, -.85566400E+02, 0.12663600E+03, 0.46020100E+01, 0.13007200E+03, 0.61763000E+02, -.54127700E+01, -.14494600E+02, -.30713200E+02, 0.14288600E+02, -.20730800E+00, -.13021500E+02, 0.16513500E+01, 0.18700200E+02, 0.29779000E+01, -.34429200E+02, 0.35693300E+00, -.39125000E+02, 0.19937400E+02, -.21437200E+01, -.28888400E+02, 0.32047900E+01, 0.75334100E+02, 0.36302000E+02, -.21558300E+02, 0.59784100E+01, -.25332200E+02, 0.10277800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.42657200E+01, -.25617300E+01, -.38775300E+01, -.34096700E+02, 0.52770800E+01, 0.48486300E+00, -.25754800E+01, -.17378900E+01, 0.68130700E+01, -.19966300E+01, 0.23782600E+01, -.27313700E+00, -.49643300E+01, -.16651400E+01, 0.35493200E+00, -.21528300E+01, -.42986600E+01, -.18058500E+01, -.27381000E+00, 0.12892500E+01, -.69592700E+00, -.31263900E+01, -.55087400E+01, 0.14846800E+01, -.10839600E+01, 0.20840600E+00, -.10776100E+02, 0.16701200E+01, 0.81121600E+01, -.10279700E+01, -.87818200E+00, 0.68207800E+00, -.96403300E+00, 0.36706000E+01, -.47781800E+00, -.12548700E+01, -.28522000E+01, -.21801300E-01, 0.10561800E+01, -.32603300E+00, -.17630900E+01, 0.10320100E+01, -.55231700E+00, 0.14918600E+01, 0.19358700E+01, -.13057700E+01, -.15180000E+02, 0.15212000E+00, -.41484000E+00, -.20178300E+01, 0.19552600E+00, -.55200500E+00, 0.24380600E+01, -.38612800E+01, 0.24156700E+01, 0.92940600E-02, -.56006300E+00, -.17561700E+01, 0.20404200E+00, 0.11728000E+00, -.65255600E+00, -.76792100E+00, 0.11096900E+01, 0.15412000E+00, 0.68568000E+00, -.98049200E+00, -.60776500E-01, 0.66518000E-01, -.59793500E+00, -.73354800E+00, -.42235200E+00, 0.11452900E+00, 0.37188800E+00, 0.14616900E-01, -.29247900E-02, -.59330300E+00, -.11613200E-02, 0.86854900E+00, -.10624000E+01, -.59810000E-01, -.14767900E-01, 0.13481400E+01, 0.12578700E+01, -.54277100E+00, 0.70587800E+00, -.33137300E+01, -.26978800E-01, -.55358900E-01, -.46891900E+00, 0.67058600E+00, 0.16651900E+00, -.16204800E+00, -.70909600E-01, -.14382200E+00, 0.79741800E+00, -.34091400E+01, -.21997800E+00, 0.26184800E+00, -.52184100E+00, 0.87787700E+00, -.40677000E+00, -.66841300E+00, -.10794400E+00, 0.27034200E+00, -.21599600E+00, 0.48228100E+00, 0.68468600E+00, -.48072000E+00, 0.39107600E+00, -.27629700E+00, 0.10220700E+00, -.35952300E-01, -.18736000E+00, -.28021200E+00, 0.49959800E+00, -.31099800E+00, 0.81993200E-01, -.74622300E+00, -.18765100E-01, 0.49853500E+00, -.37939300E+00, 0.98602900E+00, -.12651900E+01, -.65051700E+00, -.53683800E+00, 0.12149400E+00, -.10491800E+03, 0.51142200E+02, 0.49808900E+02, -.52801600E+02, 0.10535200E+02, 0.59451900E+02, 0.58052800E+02, 0.62712900E+02, 0.25770600E+02, 0.19118700E+03, -.10480100E+03, -.99013600E+02, 0.97687400E+01, -.34773700E+02, -.88027600E+02, -.71935200E+02, -.87597700E+02, 0.54338100E+01, -.26142300E+03, 0.13038000E+03, 0.13145100E+03, -.42187100E+02, 0.60941500E+01, 0.85528100E+02, -.28202300E+01, 0.84234800E+02, 0.52681300E+02, -.15478500E+02, 0.73759000E+01, 0.91097800E+01, -.20545200E+02, -.11866900E+02, 0.21494900E+02, 0.35493200E+02, 0.46886700E+02, -.18061700E+02, 0.12884400E+02, -.53347900E+01, -.70082400E+01, 0.32969900E+01, -.33300700E+01, -.41585600E+01, -.68464200E+01, 0.85782900E-01, -.38802600E+01, 0.74570300E+02, -.36683600E+02, -.30864700E+02, -.19782200E+02, 0.36361400E+01, -.23150800E+02, 0.82930300E+01, -.33170400E+02, 0.50744400E+01, 0.89212300E+02, -.51648200E+02, -.37443000E+02, 0.32408100E+02, 0.24427500E+02, -.58440500E+02, -.36276900E+02, -.58843600E+02, -.12714000E+00, 0.10349900E+01, 0.20613400E+01, 0.41452300E+01, 0.21666000E+00, 0.23239800E+01, 0.26258400E+01, -.51395900E+00, -.30999000E+01, 0.34224300E+01, 0.97839300E+01, 0.32721700E+01, 0.91949300E+01, 0.12978200E+02, 0.30270000E+01, 0.35125500E+01, -.58255000E+01, 0.21272300E+02, 0.32215200E+02, -.63076000E+00, -.17174600E+00, 0.82171700E+01, -.40493300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.49544400E+01, -.25344200E+01, -.65279600E+01, -.27069200E+02, 0.48588200E+01, 0.11199700E+01, -.69233300E+00, -.29165300E+01, 0.73506000E+01, -.18968100E+01, 0.23124900E+01, -.11313300E+01, -.41244500E+01, -.28303000E+01, -.23920600E-01, -.81041000E+00, -.38874100E+01, -.28253500E+00, -.60979700E+00, 0.15805600E+01, -.39055400E+00, -.53160000E+01, -.82662000E+01, 0.14108700E+01, -.16953700E+01, -.31088500E+00, -.11224800E+02, 0.37527500E+01, 0.20680500E+02, -.49115400E+00, 0.12291100E+00, 0.18255000E+01, -.69322000E+00, 0.47112300E+01, 0.90569000E+00, 0.52931600E+00, -.10145300E+01, -.62746800E+00, 0.19139200E+01, -.11717200E+00, -.10719600E+01, 0.25454000E+00, 0.15823700E+00, -.15866700E+01, -.56532900E+00, -.31373800E+00, -.64993200E+01, 0.15764500E+01, -.59017600E+00, 0.33498500E+00, -.35105300E+00, 0.54554200E-01, -.40195000E+00, -.43901300E+01, 0.13798200E+01, 0.13161100E+01, -.19637000E+01, -.10108900E+01, -.10875000E+00, -.15621600E+00, -.12863400E+01, 0.14040000E+00, 0.35625800E+00, -.16034500E+00, -.35799300E+00, -.37352000E+01, -.15457900E+01, 0.12824900E+00, 0.37338900E+01, -.70925500E+00, 0.60363600E+00, 0.59134900E+00, -.29501900E+00, -.72281900E-01, 0.13534800E+01, 0.90676500E-01, 0.62841600E+00, 0.65901700E+00, -.21509700E+01, 0.53173600E+00, 0.67705100E-01, 0.78430600E+00, 0.29256600E+00, -.45913500E+00, -.30504600E+00, 0.14144400E+01, 0.12956700E+00, 0.47117100E+00, -.57710400E-01, 0.73367900E+00, -.15576900E+01, 0.35269600E-01, -.25789100E+00, -.18046100E+00, 0.36198800E+00, 0.70037500E+01, -.66255000E-01, -.31115900E+00, 0.20294400E+01, 0.10648300E+01, -.40018500E+00, -.18769700E+00, 0.22687300E+00, 0.31186700E+00, 0.30441600E+00, 0.13721500E+00, -.62666100E+00, -.73841500E+00, 0.16834900E+00, 0.41340700E+00, 0.64499900E-01, 0.33770200E-01, -.16707100E+00, 0.25377800E-01, -.17176600E+00, -.82362900E+00, -.71499200E+00, -.29142200E+00, 0.17095000E+00, 0.54058900E-01, -.92696300E+00, 0.30117100E+01, 0.33177200E+00, -.14017800E+00, 0.19598800E+00, 0.10959400E-01, 0.58637300E+00, 0.21993700E+01, -.30520300E+01, -.23060600E+02, 0.35999300E+01, 0.16878700E+02, 0.38524500E+02, 0.41127200E+02, 0.73880000E+01, 0.78947600E+02, -.26215700E+02, -.42655400E+02, 0.14026700E+02, -.10265500E+02, -.33387300E+02, -.45229500E+02, -.15297600E+02, -.22060900E+02, 0.45420100E+02, -.24886000E+02, -.23496700E+02, 0.57678800E+01, -.52033700E+01, -.83468700E+01, 0.43913600E+02, 0.97909900E+02, -.13656800E+02, -.18484200E+03, 0.92723300E+02, 0.10365500E+03, 0.13052900E+02, 0.49379400E+02, 0.68958800E+02, -.39145100E+01, 0.63404400E-01, 0.36470200E+02, 0.15475300E+02, -.95730400E+01, -.92961900E+01, 0.45754800E+01, -.37061700E+01, -.86663300E+01, 0.27980400E+01, 0.57252500E+01, -.77255500E+01, 0.17891600E+03, -.85268400E+02, -.86895100E+02, 0.80430300E+01, -.23869600E+02, -.64249500E+02, -.19926100E+02, -.84054500E+02, -.74608200E+01, 0.35645500E+02, -.17246300E+02, -.30751600E+02, -.11444900E+02, -.41366900E+02, -.91256300E+01, -.15505000E+02, -.59758800E+02, -.54223500E+02, 0.20998000E+00, -.27432400E+01, 0.36088200E+01, -.46353500E+00, -.92363100E+01, 0.42589200E+00, -.40798700E+00, 0.46889200E+00, -.45301400E+00, 0.44709200E+01, -.69499200E+01, 0.66936800E+01, 0.48659800E+01, 0.57817200E+01, 0.65676500E+00, 0.13585300E+01, -.58891000E+01, -.84728700E+01, -.53611900E+01, 0.34936000E+00, 0.12552500E+02, -.30404800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11009900E+02, -.58900000E+01, -.95935900E+01, -.87894600E+02, 0.99417100E+01, 0.15486900E+01, -.66611500E+01, -.48000900E+01, 0.25675900E+02, -.54488100E+01, 0.96964400E+01, -.39084400E+01, -.13156000E+02, -.60071000E+01, 0.17470600E+01, -.10105100E+02, -.13408700E+02, -.76748100E+01, -.36498900E+01, 0.66811400E+01, -.14499000E+01, -.15152000E+02, -.34664200E+02, 0.28998900E+01, -.51547000E+01, -.23165100E+01, -.33079200E+02, 0.40466600E+01, 0.26472900E+02, 0.34707700E+00, -.41718500E+01, 0.54659000E+01, -.19649800E+01, 0.96669600E+01, -.23838200E+01, 0.94140000E+01, 0.19140300E+00, -.56587100E+00, -.15958600E+01, 0.87159500E+00, 0.76312400E+00, 0.61353000E+01, -.48265600E+01, -.53511400E+00, 0.62769800E+00, 0.12338900E+01, 0.22370600E+01, 0.17268000E+01, -.30026900E+00, -.39546400E+00, -.47956700E+00, 0.62678400E+00, 0.48499800E+00, -.10804500E+01, -.48881200E+00, 0.12119500E+01, 0.84919000E-01, -.53352600E+01, 0.63458400E+00, -.18072100E+00, -.54820600E+00, -.26384900E+01, 0.10160000E+01, -.29396200E+00, 0.60160000E+00, -.38501700E+01, 0.22565100E+01, -.11161800E+01, -.67906500E+01, -.82666300E+00, -.34314700E+00, -.41340700E+00, -.68119500E+00, 0.10565100E+01, -.12800100E+01, -.10899400E+01, 0.35305700E+00, -.52004100E+00, -.33950700E+01, -.14133600E+01, -.11854300E+00, -.10906200E+01, -.13050400E+01, 0.13111100E+00, 0.11531300E+01, -.12637200E+01, -.76456900E+00, -.11782700E+01, -.11970400E+01, -.51070600E+00, 0.22848300E+01, -.46654600E-01, -.20265200E-01, -.32483000E+00, -.94113500E+00, -.46572800E+01, 0.73539900E+00, -.29124800E+00, -.32668000E+01, 0.88318400E+00, 0.27158500E+00, 0.68565700E+00, 0.39475400E+00, -.14505400E+00, -.37000200E+00, -.36379600E+00, 0.12692000E+01, 0.27456300E+01, -.10446700E+01, 0.71601500E+00, 0.32355200E+00, -.98488000E+00, -.25676300E+00, -.23837400E+00, -.25567800E+01, -.33786200E+01, 0.73437700E+00, -.34918400E+01, -.20559200E+00, 0.14862000E+01, -.10756300E+01, 0.58052000E+01, 0.12820000E+01, 0.89097800E+00, -.22043100E+01, -.47872400E+00, 0.55852800E+00, 0.13852300E+01, 0.11274800E+02, 0.54590500E+02, -.35355200E+02, -.17457300E+02, -.66349300E+02, -.10609500E+03, -.34756000E+02, -.20178500E+03, 0.85804800E+02, 0.86101300E+02, -.77989800E+01, 0.44408500E+02, 0.56584100E+02, 0.46511300E+02, 0.14570700E+02, 0.38411400E+02, 0.14871800E+03, -.69057800E+02, -.73449900E+02, 0.40105800E+01, 0.26588800E+02, -.92754300E+02, -.77940300E+02, -.22655000E+03, -.56410700E+02, 0.33517400E+03, -.16740000E+03, -.19860400E+03, -.30843500E+02, -.10306000E+03, -.91105500E+02, 0.18339600E+02, 0.52016300E+02, -.79089400E+02, -.19412900E+02, 0.12266100E+02, 0.13614500E+02, -.41130500E+01, 0.78603000E+01, 0.10980200E+02, -.11438000E+02, -.62175200E+02, 0.87225200E+01, -.34695700E+03, 0.16162800E+03, 0.16152800E+03, 0.19256700E+02, 0.46343900E+02, 0.10013700E+03, 0.21250900E+02, 0.15845700E+03, 0.35424800E+02, -.98955000E+02, 0.87229900E+02, 0.85743800E+02, 0.14825100E+02, 0.52806700E+02, 0.54415500E+02, 0.15501800E+02, 0.16292200E+03, 0.13915300E+03, -.25247000E+01, 0.39871600E+01, -.90653400E+01, -.43221400E+01, 0.22392700E+02, -.33828700E+00, 0.22078400E+01, 0.97626500E+00, 0.23147400E+01, -.15135100E+02, 0.15838300E+02, -.17853200E+02, -.18671800E+02, -.26161000E+02, -.15797900E+01, 0.38028500E+01, -.51003700E+01, 0.28116800E+02, 0.34807100E+01, -.17037900E+00, -.22267000E+01, 0.10383700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.83351500E+01, -.37624000E+01, -.13328300E+02, -.57086800E+02, 0.67605500E+01, 0.15439400E+01, -.40898400E+01, -.31842800E+01, 0.19370300E+02, -.33389100E+01, 0.68859900E+01, -.33991200E+01, -.11668600E+02, -.36809500E+01, 0.15859600E+01, -.48546700E+01, -.98070300E+01, -.63650700E+01, -.21720600E+01, 0.51390200E+01, -.69358800E+00, -.14555500E+02, -.36367400E+02, 0.85833000E+00, -.56893100E+01, 0.10300300E+01, -.78060700E+01, 0.13700700E+01, 0.18019200E+02, 0.56288600E+01, -.40273200E+01, 0.76643300E+01, -.33067800E+00, 0.75611100E+01, -.34314100E+01, 0.12099800E+02, 0.11513400E+01, -.65254200E+00, -.22558100E+01, 0.15478900E+01, 0.31428100E+01, 0.42179500E+01, -.13351500E+01, -.21738500E+01, -.44406900E+01, 0.27673600E+01, 0.12111400E+02, 0.19606500E+01, 0.23568900E+01, 0.26141400E+00, -.36286500E+00, 0.13514700E+01, -.19832900E+01, 0.18874400E+01, -.27397600E+01, 0.19748900E+01, 0.49996300E+00, 0.91985900E+00, -.21178300E+00, -.32742900E+00, 0.89999300E+00, 0.47146700E+01, 0.59510800E+01, -.13205900E+00, -.23965000E+01, -.16955200E+01, -.79898500E+00, -.42924900E+00, -.31069000E+00, 0.18864400E+01, 0.94956500E+00, -.88010400E-01, 0.53729700E+00, -.26998100E+00, 0.19327300E+01, 0.73114900E+00, 0.27707600E+01, 0.14823700E+01, 0.55766000E-02, 0.11345700E+01, 0.30008800E+00, -.24461700E+01, -.19971300E+01, -.51500500E+00, -.72610000E+00, 0.28680400E-01, -.94619400E-01, -.18433400E+00, 0.11514900E+01, -.28717800E+01, 0.55568400E+00, -.49457800E-01, -.59343600E+00, -.51573000E+00, -.89066000E+00, -.10188800E+02, 0.84477200E+00, -.77971300E+00, -.11716400E+01, -.69353800E+00, 0.20546800E+00, 0.19892000E+00, -.15219100E+01, -.28717300E+00, -.12161800E+00, 0.40742100E+00, 0.38932000E+00, -.43812100E+00, -.18691800E+01, 0.96967500E-01, -.40202400E+00, 0.59131500E+00, -.55015400E+00, 0.32224800E+00, -.13786600E+01, -.24159700E+01, -.23641300E+01, -.11907300E+01, 0.12601400E+00, -.13905800E+01, -.67434300E+00, 0.36380000E+01, -.23296400E+00, 0.11193800E+01, -.28300700E+01, -.81118100E-02, 0.88399800E+00, 0.43590700E+00, 0.45036200E-01, 0.61400200E+02, 0.26091800E+02, -.18275500E+02, -.10726800E+02, 0.27317300E+02, 0.96959300E+01, -.12001200E+03, 0.60761300E+02, 0.59316600E+02, 0.10713100E+02, 0.17680800E+02, 0.53584000E+02, -.83832800E+01, 0.99654600E+02, -.57636400E+02, 0.33548700E+02, -.15957000E+02, -.11921500E+02, 0.10188800E+03, 0.65612300E+01, 0.75396600E+01, 0.82529900E+02, 0.36535800E+02, -.11670000E+02, -.13672400E+02, 0.74783700E+01, 0.12586800E+02, 0.17981500E+02, 0.29343900E+02, -.29869300E+02, -.54270100E+02, -.88481300E+00, 0.32670900E+02, 0.16842200E+02, -.91898900E+01, -.85237400E+01, -.50051500E+01, 0.29170200E+01, -.33331900E+01, 0.28248200E+02, 0.15584700E+02, -.45885500E+00, -.19583400E+03, 0.96491600E+02, 0.88038400E+02, 0.36464900E+02, 0.37191600E+02, 0.47247800E+02, -.46474500E+02, -.15720600E+02, 0.43940800E+02, 0.31334000E+03, -.15096800E+03, -.15980300E+03, -.48191100E+02, -.90263200E+00, -.86491700E+02, -.25459400E+02, -.11049400E+03, -.74509800E+02, 0.44047600E+01, -.67454400E+01, -.34172600E+00, -.25045100E+01, -.12531600E+02, -.10900600E+01, -.20269300E+01, 0.90463300E+00, -.10517100E+02, 0.23274100E+01, -.13803400E+02, 0.61370500E+01, -.13200600E+02, 0.16432400E+02, -.13831500E+02, -.23497100E+01, -.41055600E+02, -.10708100E+03, 0.47918100E+01, -.22005500E+01, -.20306400E+02, 0.19604100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37884700E+01, -.26859000E+01, -.37539500E+01, -.31148600E+02, 0.57142200E+01, 0.72617800E+00, -.20982200E+01, -.11131300E+01, 0.78810200E+01, -.17910000E+01, 0.24600200E+01, -.16687900E+00, -.54474400E+01, -.14744600E+01, -.18090200E+00, -.21995300E+01, -.35693100E+01, -.11508900E+01, -.27830400E+00, 0.11467200E+01, -.51404000E+00, -.40693800E+01, -.78209100E+01, 0.89413200E+00, -.94008800E+00, 0.12075300E+01, -.76319100E+01, 0.18170200E+01, 0.11289000E+02, 0.20600300E+00, -.12703100E+01, 0.18899400E+01, -.65716100E+00, 0.55853100E+01, -.80492200E+00, 0.14063100E+01, -.20756700E+01, -.26885500E+00, 0.10896600E+00, -.33513800E+00, -.76794000E+00, 0.14520800E+01, -.51470100E+00, 0.19839600E+01, -.49351600E+00, -.55249500E+00, -.28405100E+01, 0.18955900E+00, 0.94973300E+00, -.35615700E+00, -.16170300E+00, -.32927900E+00, 0.14314500E+01, -.22530200E+01, 0.13510100E+01, -.78106100E-01, -.79912700E-01, -.99088900E+00, 0.13391500E+00, -.51735600E+00, -.34039700E+00, -.53373100E+00, 0.58222600E+00, 0.27605400E+00, 0.73670600E+00, 0.35436100E+00, 0.11785600E+00, 0.94864200E-02, -.44792400E+00, -.89181400E+00, -.32739500E+00, 0.70248800E+00, 0.28811900E+00, -.21909400E+00, 0.64026100E+00, -.65999000E+00, 0.65315000E+00, 0.12290400E+01, 0.14229400E+00, 0.17315400E+00, -.81238800E-01, -.71503400E-01, 0.51731200E+00, 0.69824700E-01, 0.45847100E+00, -.25016000E+01, -.86380600E-04, 0.24219500E-02, 0.59216800E+00, 0.74067600E+00, -.27069100E+00, -.19557900E+00, -.93142100E-01, 0.16158300E-01, -.15062300E-01, -.59799700E+00, -.25597600E+00, -.14390800E-01, 0.36485300E+00, -.78997300E+00, 0.32780300E-01, -.14449800E+00, 0.28543200E+00, 0.43543500E+00, -.73559500E-01, 0.23867800E+00, 0.27248600E+00, 0.72956100E+00, 0.54412900E+00, 0.35193900E-01, 0.26421300E+00, -.57441200E-01, 0.21441000E+00, -.31970800E+00, 0.19775600E+00, 0.38185700E+00, 0.75562700E+00, -.21096600E-01, -.18549000E+00, 0.16306500E+00, 0.12462500E-01, 0.13393300E+01, 0.23166600E-01, 0.10454100E+00, -.23923100E+01, -.33885900E-01, 0.58421900E+00, -.14626200E+00, 0.22979000E+00, 0.87164900E-01, 0.20843200E+02, -.30116800E+01, 0.80555100E+01, 0.29805100E+02, -.29306400E+01, -.23513900E+02, 0.13688800E+02, 0.18382500E+02, -.20747400E+02, -.20938900E+02, 0.23373400E+02, 0.36428800E+02, 0.40083900E+02, -.15725800E+02, -.14370100E+02, 0.83693100E+01, 0.43695000E+01, -.17795300E+02, 0.88089500E+01, 0.16763400E+02, 0.46749900E+02, 0.55910000E+02, -.22869400E+02, -.12352700E+03, 0.61624900E+02, 0.63920900E+02, 0.39717100E+02, 0.58861300E+02, 0.24178100E+02, -.20153300E+02, -.49847500E+02, 0.59674100E+02, -.87317800E+01, 0.44727900E+01, 0.44198800E+01, -.79783200E+00, -.88171000E+00, 0.45856800E+01, 0.63245500E+01, 0.30629900E+02, 0.43163500E+01, 0.53130400E+02, -.25999300E+02, -.33417700E+02, -.16184000E+01, -.18999100E+02, -.15220500E+02, -.79812400E+00, -.16294100E+01, -.21013200E+02, -.14314100E+02, 0.37669000E+01, 0.11702300E+01, -.88693900E+01, -.23503900E+02, 0.99483000E+01, 0.52775600E+00, -.10003400E+02, -.16287900E+01, 0.51721300E+00, 0.25427000E+01, 0.99521700E+00, 0.37671300E+01, -.56784500E+01, -.11520800E+01, 0.24090100E+00, -.48448800E+00, 0.47811200E+00, 0.12702900E+01, -.49554200E+01, 0.15922800E+01, 0.26886200E+01, 0.55201600E+01, 0.33017500E+01, -.81024300E+01, 0.65886800E+01, 0.37442800E+01, -.34921600E+01, -.52479900E+00, -.84660000E+01, 0.15347500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25587600E+01, -.14637900E+01, -.39291700E+00, -.29882900E+02, 0.37686100E+01, 0.10184700E+01, -.25188800E+01, -.65074100E+00, 0.62342200E+01, -.14389100E+01, 0.19945100E+01, -.11534900E+01, -.14601400E+01, 0.65233900E-01, 0.14993200E+01, -.37754400E+01, -.26762100E+01, -.43328600E+01, -.13187300E+01, 0.23881000E+01, -.31393000E+00, -.43796700E+01, -.13183300E+02, 0.13048200E+00, -.17003500E+01, -.86589800E+00, -.34954400E+01, -.75137700E+00, -.23882800E+01, 0.58826200E+00, -.28384500E+01, 0.21710800E+01, 0.62660000E+00, 0.48298900E+01, -.21564600E+01, 0.33141900E+01, -.53140300E+00, -.19136800E+00, -.23120500E+01, -.23089500E+00, 0.40777400E+00, 0.76271300E+00, -.14145400E+01, 0.13457000E+01, -.23396300E+01, -.15818200E-01, 0.11461800E+02, -.23153200E+01, 0.85165500E+00, -.11306000E+00, -.89275300E+00, 0.26596000E+01, 0.67530400E+00, 0.34693600E+01, 0.65181800E-01, 0.91473400E+00, -.18323300E+01, 0.31648700E+01, -.96441600E+00, -.30653600E+00, 0.57117000E+00, 0.10747300E+00, 0.96065200E+00, 0.22432200E+00, 0.12415600E+00, 0.60547200E+00, 0.92397900E+00, -.46388200E+00, 0.81191000E+00, -.20476600E+01, -.62297400E-01, 0.13425700E+01, -.83473200E+00, 0.40222000E+00, 0.24048300E-01, -.91036900E+00, 0.31268200E+00, 0.11331900E-01, -.30326800E+01, -.18781400E+00, -.43056000E-01, 0.84746300E+00, 0.11700600E+00, 0.94333600E-02, 0.35632100E+00, 0.76728800E+00, 0.36464400E-01, -.42802500E+00, -.79820200E+00, 0.12229700E+01, -.16831300E+00, -.80716700E-01, -.10100800E+00, -.10171100E+00, 0.25769000E+00, -.73622700E+01, -.36129200E-01, 0.28121200E+00, -.20847000E+00, -.88544900E+00, 0.34376300E-01, -.45653000E+00, -.41935100E+00, 0.33337000E-01, -.30969700E+00, 0.28532700E+00, 0.16239300E+00, -.31587800E+00, 0.54000100E-01, -.17553600E+00, -.18450000E+00, 0.85729000E-03, -.25200900E-01, 0.37024100E+00, -.77445600E+00, -.28298600E+00, 0.31734400E+00, -.23680700E+00, -.14385400E+00, 0.22030600E-01, 0.35342300E+00, 0.89091500E+00, 0.65848700E+00, 0.57757900E+00, -.15318800E+01, -.16911700E+00, 0.13296600E+00, -.10039900E+00, 0.23172900E+00, 0.19718200E+00, 0.41815200E+00, -.88586300E+01, -.11502900E+02, -.68233500E+01, 0.68377800E+01, 0.40751500E+02, -.17736000E+02, -.16848600E+02, 0.49877900E+01, 0.12855300E+02, -.13860000E+02, -.80883400E+01, -.23981500E+02, 0.63286100E+00, -.30694800E+02, 0.16374300E+02, 0.13038700E+02, -.76493900E+01, 0.10518000E+02, 0.17077100E+01, -.58221600E+01, 0.29682700E+01, 0.21240400E+02, 0.70187200E+01, -.35716900E+01, -.18529600E+01, 0.18503400E+02, 0.58816600E+01, -.87561100E+01, -.12224800E+02, -.37028000E+02, 0.16827700E+01, -.14307100E+01, 0.63437300E+00, 0.72267300E+00, 0.32233900E+00, -.71622100E+00, -.36452400E+01, 0.68940400E+00, 0.15109500E+01, -.18443100E+01, 0.44285500E+02, -.20917600E+02, -.18152800E+02, -.12998200E+02, -.15067300E+02, -.66968200E+00, 0.14625200E+02, 0.35040000E+01, -.15034400E+02, -.29413900E+02, 0.13210100E+02, 0.10879000E+02, -.49357700E+01, -.47877200E+01, 0.23990200E+02, 0.16110700E+01, 0.16227400E+02, -.11439400E+02, 0.17832300E+00, -.34666600E+01, -.12874800E+00, 0.53966000E+00, -.27778500E+01, -.97155100E+00, -.53531000E+00, 0.18073100E+01, -.62650700E+00, -.26047800E+01, -.30977200E+01, -.15632500E+01, 0.18460600E+01, 0.20259800E+00, -.20077400E+01, 0.25586200E+01, 0.20147900E+00, 0.14050300E+02, 0.17449000E+01, 0.81113500E+00, -.92999500E+00, 0.14391600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.33686400E+01, -.20663200E+01, -.24156100E+01, -.28872400E+02, 0.49637800E+01, 0.64477900E+00, -.25799800E+01, -.10336300E+01, 0.59290200E+01, -.16103100E+01, 0.14388900E+01, -.25934200E+00, -.25753800E+01, -.62036100E+00, 0.41574000E+00, -.29078300E+01, -.27579700E+01, -.12245000E+01, -.10746000E+01, 0.15341300E+01, -.47980300E+00, -.35852900E+01, -.40616100E+01, 0.73911600E+00, -.54113500E+00, -.10865400E+01, -.81265200E+01, 0.13884400E+01, 0.85128600E+01, -.10548300E+01, -.47492600E+00, 0.66069400E+00, -.45425300E+00, 0.24537000E+01, 0.28122300E+00, 0.35136400E+00, -.30645800E+00, -.78924000E-02, 0.35757300E+00, -.76097000E-01, -.89544800E+00, 0.11647700E+01, -.10987500E+01, 0.48340600E-01, 0.45423500E+00, -.20197000E+00, -.29986200E+01, -.11916300E+00, -.46933300E+00, 0.46968200E-01, -.46173000E+00, -.29842000E+00, 0.56226200E+00, -.10330800E+01, 0.12366000E+01, 0.18172300E+00, -.11192900E+01, 0.62703900E+00, -.34740300E+00, -.13272900E-01, -.39442000E+00, -.30603400E+00, 0.36564400E-01, -.27460500E+00, 0.35288700E+00, -.16512800E+00, -.28539600E+00, 0.24759900E+00, 0.17030600E+01, -.21677600E+00, 0.16263100E-01, -.11549200E+00, 0.43060300E+00, 0.47628300E-01, 0.52338600E+00, -.12477700E+00, 0.15724500E-01, 0.61391700E+00, 0.12484400E+01, 0.34568100E+00, -.14347800E-01, 0.84688400E+00, 0.23062800E+00, -.57639000E+00, -.24936400E+00, -.18371900E+01, -.18087900E+00, 0.15789000E+00, -.11879300E+00, -.31474000E+00, -.67707100E+00, 0.23337400E+00, -.12062200E+00, -.29050900E+00, 0.66019600E+00, -.16250700E+01, -.53764600E-02, 0.48082800E+00, 0.15130800E+01, -.80393600E+00, -.13913700E+00, -.47339600E-01, -.68402600E+00, -.34013400E+00, -.27905100E+00, 0.15275200E+00, -.34983100E+00, -.16352600E+00, 0.14487100E+01, -.46089600E+00, -.18960000E+00, -.46832600E-01, 0.33730900E+00, 0.79734300E+00, -.16978300E+01, -.57980300E+00, 0.59128100E+00, 0.10928000E+01, -.20091700E+00, -.54820600E+00, 0.36138200E+00, 0.29031400E+01, -.53069200E+00, 0.18258200E+00, -.78549600E+00, 0.55044700E-01, 0.45600200E+00, -.48682300E+00, 0.19275000E+00, 0.22936000E+00, 0.41948500E+00, -.24473500E+00, 0.35092600E+02, 0.32413200E+02, 0.45580100E+01, 0.64196200E+02, -.27028000E+02, -.27515800E+02, 0.12978300E+02, -.35765200E+01, -.28389400E+02, -.39758900E+02, -.20520900E+02, -.19279300E+02, -.58069300E+02, 0.28417900E+02, 0.23071400E+02, 0.82384800E+01, 0.67874900E+01, 0.92529400E+01, 0.22120900E+02, 0.28159000E+02, -.85652300E+01, -.90934500E+02, 0.45535800E+02, 0.53211600E+02, 0.35354200E+02, 0.57347100E+02, 0.14792400E+02, -.44761000E+02, -.53078100E+02, 0.49535500E+02, 0.44702300E+01, -.28053700E+01, -.15405500E+01, 0.15609200E+01, -.16023100E+01, -.37748900E+01, 0.89096100E+01, 0.29163700E+01, -.75297900E+01, 0.21723700E+03, -.10485700E+03, -.10731200E+03, -.16124000E+02, -.54875100E+02, -.50017800E+02, 0.25286600E+02, -.27861000E+02, -.51776400E+02, 0.13860400E+03, -.72944600E+02, -.82460600E+02, -.90618800E+01, -.36299400E+01, -.44674300E+02, -.41022900E+02, -.72387600E+02, -.99810300E+01, 0.76703100E+00, -.36782100E+01, 0.47248000E+01, -.33480600E+00, -.53230400E+01, 0.72487600E+00, -.75132300E+00, 0.74508300E+00, 0.21239900E+01, 0.45121600E+01, -.51058100E+01, 0.69983900E+01, 0.17195200E+01, -.32029100E+01, 0.77550500E+00, -.27025600E+01, -.53399500E+01, -.59542500E+01, 0.68578700E+00, 0.10322600E+01, 0.66542300E+01, 0.78122000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21883200E+01, 0.11287100E+01, 0.16791600E+01, 0.27669700E+02, -.29206200E+01, 0.11973000E+00, 0.15460800E+01, -.22463700E+00, -.71772500E+01, 0.15313000E+01, -.21332400E+01, -.47099800E-01, 0.55705600E+01, 0.15118800E+01, 0.86558400E+00, 0.46636500E+01, 0.31706100E+01, 0.18713200E+01, 0.76096300E+00, -.12152100E+00, 0.24086300E+00, 0.16152800E+01, 0.41996200E+01, -.11246400E+01, -.57286000E+00, -.12919900E+00, 0.10768200E+02, -.59825400E+00, -.33358800E+01, 0.92680400E+00, 0.76591400E+00, -.29161600E+00, 0.15266600E+01, 0.14092300E+01, 0.11369700E+01, -.10790100E+01, 0.96641200E+00, -.25416800E+00, -.56660100E-01, -.42175000E+00, 0.18426700E+00, 0.16825500E+00, 0.29041200E+00, 0.24417400E+01, -.11373800E+01, 0.59818500E+00, 0.15885400E+02, -.13744600E+01, 0.30246300E+00, 0.14048500E+01, -.34886300E+00, 0.23121800E+01, 0.42674800E+00, 0.33321700E+01, -.25401400E+00, -.20178800E+01, 0.14822500E+01, 0.24504400E+01, -.44646900E+00, -.14699100E+01, 0.93160700E+00, 0.28049400E+01, -.23459100E+01, -.45821800E+00, -.13354800E+01, 0.14823600E+01, -.59353300E+00, -.29598500E+00, 0.22764500E+01, 0.84018700E+00, 0.39094900E+00, -.75867200E+00, 0.21587800E+00, -.35692200E+00, 0.35442300E+00, 0.12607800E+00, -.45458400E+00, -.55772300E+00, 0.24221700E+01, -.12047500E+00, -.88725400E-01, -.23240400E+00, 0.31183700E-01, 0.39972200E+00, -.87681300E-01, -.17768400E+01, 0.13371000E-01, 0.12566000E+00, 0.22477000E+00, 0.31183800E+00, 0.55820700E+00, -.16440300E+00, 0.54245500E-01, 0.48290600E-01, -.24537100E+00, 0.24655100E+00, -.22561600E+00, -.16842300E-01, -.30211100E+00, -.62324100E+00, 0.35263800E-01, 0.20651200E+00, 0.61718000E+00, 0.40280500E+00, -.47005600E+00, 0.21986900E+00, 0.60400300E+00, 0.84818100E+00, 0.29789800E+00, -.19602800E+00, -.12658700E+00, 0.34384500E+00, -.15717200E+00, 0.23245800E-01, -.12863600E+01, 0.45431200E+00, 0.98397000E+00, 0.63269100E+00, -.45112500E-01, -.62587600E+00, 0.43746800E+00, 0.84062100E+00, -.38113500E+00, 0.12516400E+00, -.24716600E+01, -.30650200E-01, -.38164400E+00, 0.10281700E+00, 0.49740500E-01, 0.94126500E-01, 0.43352300E+00, -.25864100E+00, 0.73140600E+00, -.45986200E+02, -.33980700E+01, -.57392000E+02, 0.23051300E+02, 0.27694700E+02, -.26563800E+02, 0.21150000E+02, 0.24951900E+02, 0.45979800E+02, -.39803700E+01, 0.16364900E+02, -.89657500E+02, 0.44706600E+02, 0.55628200E+02, -.46666000E+02, 0.16665000E+01, 0.36351500E+02, -.35882600E+02, -.55039200E+02, 0.13088000E+02, 0.16706000E+03, -.83649000E+02, -.95338100E+02, -.37250200E+02, -.65111900E+02, -.33115900E+02, 0.57036900E+02, 0.52717700E+02, -.42899000E+02, -.26301900E+02, 0.14311600E+02, 0.12019400E+02, -.45629600E+01, 0.35522500E+01, 0.87997300E+01, -.75662300E+01, -.29977300E+01, 0.11369800E+02, -.23120700E+03, 0.11181000E+03, 0.12059200E+03, -.19220200E+00, 0.50291300E+02, 0.71589500E+02, -.30312600E+01, 0.55064900E+02, 0.30057700E+02, -.15327500E+03, 0.80376700E+02, 0.94681700E+02, 0.94694200E+01, 0.27477200E+02, 0.59072400E+02, 0.56222400E+02, 0.10175400E+03, 0.40987400E+02, -.12110400E+01, 0.46859000E+01, -.38565000E+00, 0.18143700E+00, 0.77051200E+01, -.10732700E+01, 0.12160000E+01, 0.30600100E+00, -.13446400E+01, -.28301100E+01, 0.83537100E+01, -.51721900E+01, 0.22595100E+01, -.48535900E+01, 0.15549200E+01, -.25257700E+01, 0.77565600E+01, 0.29801100E+02, 0.64424500E+01, -.20066000E+01, -.10424200E+02, 0.81941100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.39157300E+01, -.19313200E+01, -.54282300E+01, -.22140900E+02, 0.31457200E+01, 0.10112800E+01, -.48485100E-01, -.21437500E+01, 0.52607400E+01, -.13161300E+01, 0.22916800E+01, -.10386700E+01, -.41074000E+01, -.27034600E+01, -.52262300E+00, -.21294500E+01, -.34042600E+01, -.14172400E+01, -.82966000E+00, 0.14614500E+01, -.13837400E+00, -.55995600E+01, -.10487400E+02, 0.61488800E+00, -.15327500E+01, 0.58130200E+00, -.55774500E+01, 0.24941100E+01, 0.16902600E+02, 0.14127900E+01, -.10121800E+01, 0.35768500E+01, 0.85835800E-01, 0.26462400E+01, -.37622400E+00, 0.21228100E+01, 0.52582600E-01, -.42199000E+00, 0.31022600E+00, 0.40677300E+00, 0.10511400E+00, 0.48091800E+00, 0.77930800E-01, -.19152400E+01, -.44647600E+00, 0.16747700E+00, 0.34542400E+00, 0.16443300E+01, -.43861100E+00, -.37552300E+00, 0.53122700E+00, -.10656500E+01, -.14156800E+00, -.63548100E+00, -.61374600E+00, 0.16930800E-01, 0.20078300E+01, -.13954300E+01, 0.43784100E+00, 0.10430300E+01, -.45552800E+00, 0.14782400E+01, 0.79827800E+00, 0.18018700E+00, -.65677500E+00, -.12426800E+01, -.51714300E+00, 0.30900100E+00, -.21294600E+00, 0.46616100E+00, 0.32592000E+00, 0.31053500E+00, -.36772000E+00, 0.53310100E-01, 0.30338700E-01, 0.12205600E+01, 0.69874700E+00, -.44502500E+00, 0.18078700E+01, -.57655600E-01, 0.19076000E+00, -.45564300E+00, -.10614700E+00, -.94416600E-01, 0.52745100E+00, -.32637500E+01, -.23712600E+00, -.24021400E-01, 0.83646800E+00, -.30822100E+00, 0.17006100E+00, -.11810200E+00, -.10945000E+00, -.14362200E+00, 0.52904100E+00, -.90543500E+01, -.59929900E+00, -.17098400E+00, 0.28103500E+00, 0.29516500E+00, -.30938200E+00, -.12446500E+00, -.79291900E+00, 0.20302200E+00, -.28997400E+00, 0.19623500E+00, 0.27236400E+00, -.25958900E+00, -.93093800E+00, 0.23795100E+00, 0.22458700E+00, 0.78612100E+00, -.34663400E+00, 0.29951300E+00, 0.37327600E+00, 0.50759300E+00, -.82750500E+00, -.91103500E+00, -.98849500E-01, 0.30527900E-01, 0.42022200E+00, -.24165800E+01, -.57836200E+00, -.33466100E-01, -.13791900E-01, -.42868600E-02, 0.73459700E+00, -.23080800E+00, 0.95599700E-01, 0.10384400E+00, -.53479200E+00, -.74745400E-01, -.26906000E+00, -.10727500E+01, -.31214100E+02, -.69356400E+02, 0.34493300E+02, 0.40111400E+02, -.42756900E+02, 0.41683300E+00, 0.53338100E+02, 0.70393100E+02, 0.60102400E+02, -.17837000E+02, -.13737500E+03, 0.72484100E+02, 0.85773700E+02, -.38891400E+02, 0.33394600E+02, 0.82715100E+02, 0.10643700E+03, 0.38354000E+02, 0.15254200E+01, 0.62170000E+02, -.31221800E+02, -.37822100E+02, 0.22018200E+00, -.16875300E+02, -.62362900E+01, 0.44745400E+02, 0.19445700E+02, 0.13639300E+01, -.23183100E+02, 0.12523700E+02, 0.92585500E+01, -.53817200E+01, 0.27739500E+01, 0.83789000E+01, 0.68568300E+01, 0.43877400E+02, 0.14120200E+02, -.25311500E+03, 0.12369900E+03, 0.12616500E+03, 0.32954100E+01, 0.48477500E+02, 0.84857400E+02, -.18921400E+02, 0.23581500E+02, 0.23106400E+02, 0.17094600E+02, -.55170400E+01, -.29025400E+01, -.22173400E+02, -.12048600E+01, 0.14354100E+02, -.42103500E+01, 0.39634300E+02, 0.92826200E+01, 0.96507100E+00, -.34967900E-01, -.36462300E+00, 0.67408700E+01, -.58726600E+01, -.75410200E+01, -.61238700E-01, 0.63552800E+01, -.32931700E+01, -.12337300E+01, -.48816300E+01, -.32743500E+01, 0.51882100E+01, 0.15893400E+02, -.10414800E+01, -.43795100E+01, 0.61771200E+01, -.13769800E+02, -.67546400E+00, -.12714200E+01, -.35575700E+02, 0.89627800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.45902600E+01, -.13823500E+01, -.65157800E+01, -.25043900E+02, 0.33167100E+01, 0.98286800E+00, -.62262400E+00, -.31064400E+01, 0.78273000E+01, -.15921000E+01, 0.33177900E+01, -.18162500E+01, -.35506200E+01, -.21706200E+01, -.54171100E-01, -.11235300E+01, -.29770800E+01, -.23311800E+00, -.11305800E+01, 0.19664300E+01, -.61702000E+00, -.53902800E+01, -.45067900E+01, 0.13789800E+01, -.12947500E+01, -.17706900E+01, -.15895600E+02, 0.33664700E+01, 0.21780900E+02, -.10524600E+01, 0.47165200E+00, 0.10721700E+01, -.10263600E+01, 0.24359800E+01, 0.16579200E+01, 0.12082200E+01, 0.12700700E+01, -.24624400E+00, 0.15571000E+01, 0.42114300E-01, -.99098700E+00, 0.19312800E+01, -.58658000E+00, -.82803000E+00, 0.20338100E+00, -.55915400E+00, -.24292500E+01, 0.14309300E+01, -.11335800E+01, -.23945700E+00, 0.15211000E-01, -.55800000E-01, 0.32620900E+00, -.14086100E+01, -.26585000E+00, -.22141200E+00, 0.77797100E+00, -.99556700E+00, 0.23454600E+00, 0.65420900E+00, -.57925100E+00, -.23878900E+00, -.69274600E+00, -.18148500E+00, -.46753900E+00, -.12130100E+01, -.43829600E+00, 0.38329100E-01, 0.63316100E+00, -.44999500E+00, -.35228300E+00, 0.80579800E+00, -.42558400E+00, 0.32143800E+00, 0.45949500E+00, 0.38358400E+00, 0.25114400E+00, -.35065200E+00, -.28584500E+01, -.24451000E+00, -.96689000E-01, 0.96766000E+00, 0.75660200E+00, 0.42221700E+00, 0.61753600E+00, -.81721400E+00, 0.84002700E-01, 0.24962000E+00, -.24951200E+00, 0.20141900E+01, -.89982300E-01, -.94217700E-01, 0.95834700E-01, 0.27477600E+00, 0.20045800E+00, 0.61769400E+01, -.63138000E+00, -.30504800E+00, 0.12892100E+01, 0.54877800E+00, -.37032100E+00, -.25291300E-01, 0.96342300E+00, 0.46150800E+00, -.54888500E+00, 0.12552200E+00, 0.26425200E+00, 0.10183600E+01, 0.60380200E+00, 0.32854600E+00, 0.42226600E+00, 0.74318100E-01, -.32850600E+00, -.43400100E+00, -.11919600E-01, 0.13372700E+01, 0.68110100E+00, -.35942300E+00, 0.21140800E+00, 0.45171100E+00, -.25484800E-01, -.23546300E+01, 0.30765200E+00, -.31822800E+00, -.15089700E+00, 0.71076900E-01, -.19272600E-01, 0.72232900E+00, -.24781800E-01, 0.11578500E+00, 0.20145000E+00, 0.11876300E+01, -.89356000E+00, 0.44659100E+00, 0.24361900E+00, 0.16200500E+03, -.82421200E+02, -.83531200E+02, 0.35046800E+02, -.34852700E+02, -.88246500E+02, -.63112500E+02, -.65234800E+02, 0.20976400E+02, 0.66541100E+02, -.34271500E+02, -.41942800E+02, 0.27492900E+02, -.12700700E+02, -.39012700E+02, -.53715100E+02, -.16876900E+02, -.52773200E+01, -.74039900E+02, 0.36847400E+02, 0.41478100E+02, 0.11047500E+01, 0.25935200E+02, 0.55892600E+01, -.10706800E+02, 0.31811900E+02, 0.23645100E+02, 0.15726000E+02, -.83540700E+01, -.69043800E+01, 0.10428200E+02, 0.46720300E+00, -.31218300E+01, -.12848000E+02, -.18446900E+02, -.51507700E+01, 0.15954100E+03, -.76839900E+02, -.82931700E+02, -.10656200E+02, -.23721200E+02, -.51180100E+02, 0.17612500E+02, -.25304200E+02, -.18267800E+02, 0.29449700E+02, -.22381700E+02, -.19906000E+02, 0.17439100E+02, 0.38725800E+02, -.48553800E+02, -.14548600E+02, -.53103100E+02, 0.44779200E+02, -.13291900E+01, 0.43655700E+01, 0.15679900E+01, -.13343600E+00, 0.53780000E+01, 0.40697900E+01, 0.20596100E+00, -.57131600E+01, 0.75565000E+01, 0.52744400E+01, 0.52291500E+01, 0.25615300E+01, 0.57083100E+01, 0.18880700E+01, 0.29935600E+01, -.20095100E+01, 0.16360000E+02, 0.12336700E+02, -.36529800E+01, 0.20832800E+01, 0.86282000E+01, -.22573300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.27823200E+01, -.19993400E+01, -.25698400E+01, -.22991400E+02, 0.34481900E+01, 0.47682000E+00, -.18776600E+01, -.70119300E+00, 0.57693200E+01, -.15714700E+01, 0.69745400E+00, -.45370500E+00, -.26206100E+01, -.15437700E+01, 0.36936900E+00, 0.16174300E+00, -.22938900E+01, -.68234300E+00, -.23823100E+00, 0.86135100E+00, -.25695000E+00, -.40590100E+01, -.77940900E+01, 0.93317900E+00, -.11190500E+01, 0.65854000E+00, -.24536800E+01, 0.23833000E+01, 0.12164600E+02, 0.12172000E+01, -.71269200E+00, 0.20835600E+01, -.31894500E-01, 0.39685400E+01, -.21679500E+00, 0.12146500E+01, -.12273500E+01, -.50409500E+00, 0.35124500E-01, -.15712400E+00, -.21516300E+00, -.78995200E+00, 0.57481400E+00, -.29649800E+00, 0.71926800E+00, 0.71688000E-01, -.29008900E+01, 0.20424900E+00, 0.66823100E+00, -.30658300E+00, 0.35684700E+00, -.24471400E+01, 0.14011500E+00, -.50008400E+00, 0.42815100E+00, -.66607900E-01, -.14689700E+00, 0.13637300E+01, 0.12280600E+00, 0.38879000E+00, 0.13258500E+00, 0.60845700E+00, 0.21102100E+01, 0.11572700E+00, -.81640400E-01, -.24782600E+01, -.76912200E+00, 0.16534200E-01, 0.58902500E+00, -.84639200E+00, -.12151200E+00, 0.76346400E+00, -.32936200E-01, 0.39903000E-01, 0.37407400E+00, -.10877100E+01, 0.23947300E+00, 0.98983600E+00, -.85296200E+00, -.12164100E-01, -.14636600E+00, 0.33858500E+00, 0.23700000E+00, 0.14046800E+00, 0.32119300E+00, 0.16348300E+00, 0.46318800E-01, -.97475300E-01, 0.43482200E-01, -.43297200E+00, -.67094800E+00, 0.58590700E-01, -.26276100E-01, -.14211600E+00, -.13323700E+00, 0.18639900E+01, -.14150200E-01, 0.81233900E-01, -.32794000E+00, 0.60052400E+00, 0.73609900E-01, -.15149100E+00, 0.42955700E+00, 0.12783700E+00, 0.90668700E-01, -.11481000E+00, -.10850300E+00, -.22085800E+00, 0.11350700E+00, 0.23103200E-01, -.39271400E+00, -.61412900E+00, -.47804800E+00, -.62541100E+00, 0.27635600E+00, 0.19472200E+00, -.38625600E+00, -.44325300E+00, 0.13092300E+00, 0.11627500E+00, -.91601100E-01, -.27470800E+01, -.43047700E+00, -.31280300E+00, 0.11350700E+01, 0.23342800E-01, -.48877500E-01, 0.33537900E+00, -.76045200E-02, 0.14496500E+00, -.27573200E+00, -.45835800E+00, -.38565100E+00, 0.50724400E+00, 0.18095200E+00, 0.68148900E+00, 0.59783300E+01, 0.57914800E+01, -.10824800E+02, -.45427700E-01, 0.15587200E+02, 0.14262300E+01, 0.99122600E+01, -.28001200E+01, 0.68639600E+02, -.33540600E+02, -.37686400E+02, 0.29967300E+02, -.44677000E+01, -.31895600E+02, -.62666600E+01, -.17910600E+01, 0.64410700E+01, -.54759500E+02, 0.27508000E+02, 0.32261200E+02, 0.36411200E+02, 0.15241700E+02, 0.27105500E+02, -.10042600E+02, -.74354600E+02, -.63915900E+00, 0.58128800E+01, -.33263900E+01, -.27873500E+01, -.19742600E+01, -.29769200E+01, -.40311500E+01, 0.58317300E+01, 0.87195300E+01, -.85331400E+01, 0.84996500E+02, -.40148500E+02, -.37465200E+02, -.13378300E+02, -.16061500E+02, -.19341300E+02, 0.13788400E+02, -.48145900E+01, -.92102800E+01, 0.34208700E+02, -.18850000E+02, -.29034100E+02, -.20543600E+02, -.24201900E+02, 0.20055600E+02, 0.86992600E+01, -.87342000E+01, -.33856500E+02, 0.28068700E-01, -.28971300E+01, -.19318600E+01, 0.93650000E+00, -.48161000E+01, -.21446300E+01, -.52410600E+00, 0.46124600E+01, -.44444700E+01, -.18943900E+01, -.51747900E+01, 0.54823900E+00, -.17465200E+01, 0.61067900E+01, -.23021800E+01, 0.25420000E+01, 0.28003500E+01, -.11789900E+02, -.51522600E+01, 0.13797300E+01, -.24613100E+00, -.31538600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.16942200E+02, 0.76409900E+01, 0.15599300E+02, 0.12109100E+03, -.18458200E+02, -.16526600E+01, 0.95465800E+01, 0.71586000E+01, -.36424300E+02, 0.71122600E+01, -.12771600E+02, 0.26041500E+01, 0.28801500E+02, 0.66701000E+01, 0.21889100E+01, 0.62140100E+01, 0.14306600E+02, 0.62151800E+00, 0.27267300E+01, -.53470100E+01, 0.13087000E+01, 0.26316500E+02, 0.30358900E+02, -.38468800E+01, 0.67727700E+01, -.55503400E+00, 0.23287800E+02, -.11215400E+02, -.83039700E+02, -.46491800E+01, 0.17937500E+01, -.12688000E+02, 0.26308100E+01, -.13626600E+02, -.19306900E+01, -.64158200E+01, 0.26928300E+01, 0.14144300E+01, -.20337700E+01, -.83253700E+00, 0.12545400E+01, -.66147100E+01, 0.20601600E+01, -.96330600E-03, -.78089300E+00, -.43417000E+01, 0.12473600E+02, -.32515300E+01, -.28445800E+01, -.43784800E-01, 0.95783300E+00, 0.57526400E+01, 0.47184400E+00, 0.34703100E+01, -.88687800E+00, -.17426700E+01, 0.28278600E+00, -.90024300E+00, 0.21298500E-01, -.12118100E+01, -.25852000E+00, -.50912000E+01, -.50097900E+01, -.14586700E+00, -.65601100E+00, -.21284400E+01, 0.17756500E+01, -.42126700E+00, 0.43370200E+01, -.25564500E+01, 0.12854600E+01, -.26822500E+00, -.12923300E+01, 0.82959400E+00, -.12640300E+01, 0.38178900E+01, -.13947500E+01, -.63717100E+01, -.57309600E+01, -.35151700E+01, 0.51599300E+00, 0.16631500E+01, 0.22927800E+00, 0.14584200E+01, 0.24570700E+01, 0.27940600E+01, -.61190200E+00, -.16728400E+01, -.27891900E+01, 0.47081800E+01, -.83618400E+00, -.20038100E+00, -.16372200E-01, -.39014500E+00, 0.13454200E+01, -.64257800E+01, -.98339400E+00, 0.69436800E-01, 0.24722400E+01, 0.19198600E+01, -.79874700E+00, -.57282800E+00, 0.37677400E+00, 0.67963400E+00, -.66690600E+00, 0.41482800E+00, 0.29081100E+00, -.91930400E+00, 0.49719700E+00, -.68272700E+00, 0.39105700E-01, -.71672900E+00, -.38091100E+00, 0.13749400E+01, -.43254300E+01, 0.29162500E+00, -.88162300E+00, 0.98054800E-01, 0.50670800E+00, -.66336000E+00, 0.75473600E+00, -.27842200E+01, 0.12244600E+01, 0.29155300E+00, 0.10344100E+02, 0.26896300E+00, 0.71430100E+00, -.32456900E+01, -.41832000E+00, -.75798100E-01, -.22302400E+00, -.28346900E+01, 0.36903300E+01, 0.60038900E+00, -.13141400E+01, -.92975500E+00, 0.35823800E+01, -.42969500E+02, 0.87839100E+02, 0.57894300E+02, -.70237500E+02, -.79353800E+02, -.62265900E+02, 0.65807100E+02, -.99663600E+02, 0.46027200E+02, 0.63154400E+02, -.13617400E+02, 0.19790300E+02, 0.59217200E+02, 0.47476200E+02, 0.81572900E+02, 0.34109300E+02, 0.38725100E+02, -.18683100E+02, -.17556700E+02, -.15961300E+03, -.81988200E+02, 0.13991900E+02, 0.78987900E+02, 0.32511400E+03, -.76555800E+02, 0.30894100E+02, -.20826700E+02, -.19834900E+02, 0.12415000E+02, 0.15521200E+01, -.10349500E+02, -.23454900E+02, -.47675200E+02, 0.12373200E+02, -.24359300E+03, 0.11253400E+03, 0.97010600E+02, 0.10123800E+03, 0.94886100E+02, -.74403000E+01, -.12509900E+03, -.98612500E+02, 0.11202600E+03, -.44551300E+02, 0.47968200E+02, 0.31638400E+02, 0.52753800E+02, 0.23819300E+02, -.65636300E+02, -.40573700E+02, -.38640800E+01, -.13450000E+02, -.18356900E+01, 0.12821900E+01, 0.65175600E+01, -.27353400E+01, 0.36296000E+01, -.15543900E+01, -.66098300E+00, -.49927400E+01, 0.77284100E+01, 0.97879100E+01, 0.50598200E+01, 0.21685100E+01, 0.20734600E+01, 0.45715100E+01, 0.12328100E+01, 0.85317800E+01, -.38352300E+02, -.12882800E+02, 0.16851600E+01, -.11775000E+00, 0.15587300E+02, -.23578600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.24506800E+01, 0.15612300E+01, 0.14338300E+01, 0.19692300E+02, -.31909900E+01, 0.13434700E-01, 0.20391900E+01, 0.60471400E+00, -.39634300E+01, 0.12212500E+01, -.11072800E+01, -.73373200E-01, 0.34937200E+01, 0.54873600E+00, -.28115700E+00, 0.19488900E+01, 0.22399700E+01, 0.12850100E+01, 0.18823000E+00, -.88604900E+00, 0.33882900E+00, 0.26266400E+01, 0.41701000E+01, -.44126600E+00, 0.90911200E+00, 0.29587400E-01, 0.13100000E+01, -.41629900E+00, -.21726000E+01, 0.32512300E+00, 0.59306800E+00, -.73558700E+00, 0.43172700E+00, -.21168100E+01, 0.57246800E+00, -.40214200E+00, 0.95826700E+00, -.20952700E-01, 0.32295800E+00, 0.11708200E+00, 0.14825500E+00, -.27101800E+00, 0.24022800E+00, -.49101300E+00, -.31607000E+01, 0.49994900E+00, 0.90382800E+01, -.42338200E-01, 0.40831700E+00, 0.26126300E+00, -.12860400E+00, 0.21386000E+01, -.12027600E+01, 0.22578000E+01, -.17984400E+01, 0.11680500E+01, 0.31498100E+00, 0.38505100E+00, 0.30531300E-01, 0.63074400E+00, 0.66085700E-01, 0.15114800E-02, -.50446500E+00, -.18474300E+00, -.43319400E+00, 0.86614500E-01, 0.25858300E+00, 0.43626100E-01, -.23394900E+00, 0.59741200E+00, 0.16960100E-01, -.72999700E+00, 0.44709600E+00, -.81015700E-01, 0.29820400E-01, 0.69361100E+00, -.23391700E+00, -.31657900E+00, 0.54353400E+00, -.86178200E-01, -.69425200E-01, -.41225200E+00, -.46739900E-01, 0.56783500E-01, -.23656600E+00, 0.10679900E+01, -.33385500E-01, -.85036600E-01, -.17355200E+00, 0.48552600E+00, 0.33962700E+00, -.24883700E+00, 0.52958900E-01, -.12352200E+00, 0.28430300E-01, 0.33083300E-01, 0.43423000E-01, -.12195300E+00, 0.83286000E+00, 0.15938900E+00, -.88899300E-01, 0.46105600E+00, -.53523400E+00, -.26470800E+00, 0.17924800E+00, -.61800800E-01, 0.13187900E+00, 0.61483900E+00, -.61172900E+00, -.40224300E+00, 0.26347300E+00, 0.39711300E+00, 0.18221400E+00, 0.31300400E+00, 0.96288800E+00, -.97480500E-01, 0.93560500E-01, 0.56830700E+00, 0.50171600E-01, -.24486800E+00, -.24519300E-01, -.65318300E+00, -.28008500E+00, -.19275400E-01, -.85500800E-01, 0.91970200E-01, 0.14634600E+00, -.13174200E+00, -.20394400E+00, 0.23052200E+00, -.45238300E+00, 0.50774700E+00, -.42270400E+00, 0.28395500E+00, 0.20619700E+00, -.13557800E+00, -.33901500E+00, -.60200900E-02, 0.22705800E+02, -.12839700E+02, -.88080700E+01, -.19878800E+02, 0.41348800E+01, -.58224700E+01, 0.49925800E+02, -.24812300E+02, -.34136200E+02, -.40965100E+01, -.79863700E+01, -.21970900E+02, 0.12016400E+02, 0.26728300E+02, -.36894300E+02, -.13260800E+03, 0.66275100E+02, 0.72080700E+02, 0.28515900E+02, 0.48881100E+02, 0.31897100E+02, -.38558500E+02, -.38444500E+02, 0.36013900E+02, 0.16592000E+02, -.83570100E+01, -.79491500E+01, 0.49418200E+01, -.17977900E+01, -.52898600E+01, -.10302100E+01, -.99815800E+01, -.53859500E+01, 0.19934200E+03, -.96890300E+02, -.10431500E+03, -.62276300E+01, -.44951100E+02, -.62837600E+02, 0.12976300E+02, -.24063100E+02, -.28385500E+02, 0.61763200E+02, -.31978300E+02, -.37986500E+02, 0.79626700E+01, -.21353300E+02, -.29976800E+02, -.30015000E+02, -.55250300E+02, 0.15774700E+01, -.84829900E-01, 0.84460100E+00, 0.41787000E+00, -.16378900E+01, -.64363800E+00, 0.20296400E+01, 0.15662900E+00, -.21682900E+01, 0.43322600E+01, 0.46205500E+01, -.37193800E+00, 0.44733000E+01, -.38121100E+01, -.12101700E+01, 0.31904200E+01, 0.25237100E+01, -.80873900E+01, 0.10434700E+02, -.62717000E+01, 0.10002800E+01, 0.12849300E+02, -.34455200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18216700E+02, 0.93226400E+01, 0.15143300E+02, 0.13177000E+03, -.21472000E+02, -.17302200E+01, 0.95876100E+01, 0.78823200E+01, -.35649900E+02, 0.86783600E+01, -.10735100E+02, 0.19915400E+01, 0.26725400E+02, 0.79491800E+01, 0.38211000E+00, 0.13138700E+02, 0.18909400E+02, 0.85700100E+01, 0.28961500E+01, -.67345300E+01, 0.91120200E+00, 0.21927400E+02, 0.53988700E+02, -.40537800E+01, 0.56306900E+01, -.25445500E+01, 0.43131500E+02, -.89885900E+01, -.57719400E+02, -.83274600E+00, 0.73508900E+01, -.10480300E+02, 0.16762900E+01, -.21762900E+02, 0.48042900E+01, -.58043800E+01, 0.77712000E+01, 0.19070300E+01, 0.20614000E+01, 0.31387400E-01, 0.37040900E+00, -.34056500E+01, 0.69585300E+00, 0.15207500E+01, -.16555200E+01, -.25215500E+00, 0.23045500E+02, -.20038200E+01, 0.72981800E-01, 0.35964000E+00, -.70411700E+00, -.18662200E+00, -.28899800E+01, 0.76917700E+01, -.62190600E+01, -.25970900E+01, 0.23876900E+01, 0.88571000E+00, 0.27631100E+00, 0.31763900E+01, 0.95714800E+00, -.37937500E+01, -.30367600E+01, -.18029600E+01, -.27076000E+01, 0.36492700E+01, 0.17905400E+01, -.89720900E+00, 0.10017800E+01, 0.16454000E+01, -.27723800E+00, -.11840300E+01, -.10868600E+01, 0.15259700E+01, -.25840900E+01, 0.90000100E+00, -.21908000E+01, -.49717500E+01, -.13345100E+02, -.18059700E+01, 0.31487300E+00, 0.34050100E+01, 0.27866600E-01, 0.16408600E+01, 0.73726000E+00, 0.32866200E+01, -.28838800E+00, -.41176000E+00, -.38735300E+01, 0.71473900E+01, 0.12654800E+01, 0.28741100E+00, 0.71151900E+00, 0.10558600E+01, -.95987100E+00, 0.15627000E+02, 0.13574600E+01, 0.42294500E+00, -.27160100E+01, 0.98088600E+00, 0.50595900E+00, -.48549900E+00, 0.20621900E+01, -.73829200E+00, -.61587500E+00, -.35238400E+00, 0.80436800E+00, 0.18983200E+01, -.24058100E+00, 0.17483100E+01, 0.14515400E+01, -.94995600E+00, 0.92600500E+00, -.31530500E+00, 0.49164800E+00, 0.18218100E+00, 0.19303800E-01, 0.50029200E+01, -.40397100E+00, -.15962100E+01, -.30811500E+00, 0.47916400E+01, -.19797000E+00, -.57882200E+00, 0.38667900E+01, 0.58713500E+00, -.90105200E+00, -.15469600E+01, -.13518000E+00, -.74592300E+00, 0.23128800E+01, -.21224100E+01, 0.28000500E+01, 0.34070800E+01, -.15636700E+01, 0.22431300E+01, -.14748200E+01, -.35196600E+00, 0.26337600E+01, 0.15350300E+03, -.94465900E+01, -.13527600E+03, 0.37370500E+01, 0.50974200E+02, 0.46861900E+03, -.24655500E+03, -.22232900E+03, 0.17558800E+03, 0.21974900E+02, -.15088400E+03, 0.25551800E+02, 0.11036700E+01, 0.13623800E+03, -.79513600E+02, 0.41443200E+02, 0.39665300E+02, -.61222200E+01, -.48824100E+02, 0.42959000E+02, 0.49975300E+02, 0.14630000E+03, -.32420700E+02, 0.58442300E+02, -.26069000E+02, -.30002200E+02, -.20307000E+02, -.18343600E+01, -.30620600E+02, 0.23700300E+02, 0.27709000E+02, -.12581000E+02, -.63137600E+03, 0.30736400E+03, 0.31905700E+03, 0.13741400E+03, 0.20416400E+03, 0.11250800E+03, -.17216800E+03, -.10673600E+03, 0.21460300E+03, -.46815500E+03, 0.23450500E+03, 0.21953500E+03, -.12997400E+03, -.74330400E+02, 0.25123500E+03, 0.13418100E+03, 0.20740100E+03, -.27099100E+03, 0.10909300E+02, -.28950700E+02, -.92014200E+01, 0.16661600E+01, -.30820100E+02, -.14987000E+02, -.69504400E+01, 0.21281700E+02, -.39715300E+02, -.26664700E+02, -.35408300E+02, -.11114300E+02, -.10008700E+02, 0.36905400E+02, -.38427100E+02, 0.24873300E+02, -.34154300E+02, -.13736200E+03, 0.70127400E+01, 0.37819900E+00, -.22288200E+02, 0.16053400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10093900E+02, -.44445000E+01, -.10751600E+02, -.76311700E+02, 0.12722500E+02, 0.67859400E+00, -.67623000E+01, -.30361900E+01, 0.23780200E+02, -.52066000E+01, 0.44499600E+01, -.74424100E+00, -.13788400E+02, -.42944200E+01, -.11100300E+01, -.66098800E+01, -.95532700E+01, -.22256200E+01, -.24604500E+01, 0.41088800E+01, -.11437200E+01, -.13676500E+02, -.12524800E+02, 0.25165700E+01, -.34036400E+01, -.20391500E+01, -.29754700E+02, 0.77805300E+01, 0.53146400E+02, 0.10735900E-02, -.13681200E+01, 0.61076100E+01, -.16262700E+01, 0.11947900E+02, 0.74397000E+00, 0.44272800E+01, -.15753800E+01, -.68245800E+00, 0.40119700E+01, 0.10285200E+00, -.33943900E+01, 0.65058800E+01, -.29313000E+01, 0.17758400E+00, -.11989800E+01, 0.10305500E+01, 0.33863300E+01, 0.27199000E+01, -.10961500E+00, 0.18941900E+01, -.66802100E+00, 0.27359300E+01, -.86854900E+00, -.25683400E+01, 0.11666200E+00, 0.15758400E+01, 0.22314400E+01, -.43040000E+01, 0.12697100E+01, 0.11018500E+01, -.10060800E+01, -.21695600E+00, -.86049600E+00, -.14340100E+01, 0.11272900E+01, 0.10654200E+01, -.91861300E+00, -.63349000E+00, -.57838900E+00, 0.19117200E+01, -.54766200E+00, -.24237500E+01, 0.19440100E+00, 0.47536500E-01, 0.15727600E-01, -.13102400E+01, 0.80295300E+00, 0.11907100E+01, 0.22053800E+01, 0.80608200E+00, 0.16642300E+00, -.54536600E+00, -.68682900E+00, -.13225700E+01, -.17448200E+01, 0.59274100E+01, -.27809500E+00, -.63460500E+00, -.13361300E+01, 0.10438800E+01, -.99229700E+00, -.69836300E-01, -.26846600E+00, -.24600200E+00, -.42317500E+00, -.55922400E+01, 0.64638800E+00, 0.12774000E+00, -.25934400E+01, 0.95325000E+00, 0.37734400E+00, -.96680000E+00, -.53862800E-02, -.49616800E-01, 0.66090300E+00, 0.13374100E+00, -.57709400E+00, -.13522400E+01, -.30565000E+00, -.91470900E+00, -.11719000E+01, -.40326300E+00, -.70203100E+00, 0.43307100E+00, -.32476000E+01, -.14309200E+01, -.14781600E+01, -.25050500E+01, 0.88152400E-01, 0.10111300E+00, -.46740600E+00, 0.37951100E+01, -.12768800E+01, -.46702100E+00, -.23139100E+01, 0.69619600E-01, 0.15811200E+01, 0.11929800E+01, 0.27192800E+00, 0.33477500E+00, -.24870900E+00, -.12391200E+01, -.93395100E+00, -.61089800E+00, 0.32601400E+00, 0.53178600E+00, 0.20467000E+01, -.27825200E+00, 0.81462200E-01, 0.36036900E+00, -.26740100E+02, 0.54106700E+02, -.87235800E+02, -.47504500E+01, -.58118800E+03, 0.29725300E+03, 0.32001300E+03, -.18030300E+03, 0.51283600E+02, 0.23521800E+03, -.23977800E+02, -.80028600E+01, 0.65545100E+01, 0.42498600E+03, -.21314600E+03, -.22936600E+03, -.12424800E+03, -.10294200E+03, -.14307500E+03, 0.29947100E+02, 0.10635500E+03, -.67969900E+02, -.73670400E+02, 0.35179100E+02, 0.33302500E+02, 0.24916000E+01, 0.74095100E+01, 0.24186800E+02, -.13897300E+02, -.44523200E+02, 0.28704400E+02, -.16532200E+03, 0.78573800E+02, 0.91109300E+02, -.36144100E+02, -.29313000E+02, 0.10567400E+03, 0.42470100E+02, 0.16126600E+03, -.59263300E+02, -.26949700E+02, 0.30742900E+02, 0.54751700E+02, 0.87810600E+02, 0.55470300E+02, -.45799800E+02, -.42672000E+02, 0.59724000E+02, 0.14117500E+03, -.54158700E+01, 0.13105400E+02, 0.86694500E+01, -.51499900E+01, 0.25207200E+02, 0.64669100E+01, 0.36853300E+01, -.12525200E+02, 0.17813000E+02, -.41550400E+00, 0.26048600E+02, -.75378600E+01, 0.97784300E+01, -.44109000E+02, 0.14338500E+02, -.15533500E+02, 0.36047700E+01, 0.12022200E+03, 0.25817800E+02, -.47353400E+01, 0.20005400E+01, -.32448600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.17495000E+01, 0.12161500E+01, 0.14225600E+01, 0.12091500E+02, -.16254000E+01, -.50636400E-01, 0.11282600E+01, 0.87084900E+00, -.37394100E+01, 0.95151800E+00, -.11041200E+01, 0.42533500E+00, 0.14788100E+01, 0.94994100E+00, -.23559800E+00, 0.14740400E+01, 0.19153300E+01, 0.99693400E+00, 0.50856600E+00, -.10064800E+01, 0.29346800E+00, 0.21305400E+01, 0.36390200E+01, -.42032300E+00, 0.62487700E+00, 0.46308700E+00, 0.53398400E+01, -.65647000E+00, -.46993100E+01, 0.29788600E+00, 0.30644200E+00, -.47036800E+00, 0.39963500E+00, -.13737500E+01, 0.48722200E-01, -.95175500E+00, -.12643400E+00, 0.47686100E-01, -.55851000E-01, -.31615500E-01, 0.19462900E+00, -.75183700E+00, 0.35329700E+00, 0.24646800E+00, -.23692900E+00, 0.15683800E+00, 0.23426300E+01, -.38423300E+00, 0.40552100E+00, 0.27364300E+00, -.38795100E-01, -.77030200E-01, -.24607700E+00, 0.84931500E+00, -.31490300E+00, -.10239800E+00, 0.20968400E+00, -.10039100E+00, -.20204200E-01, -.14620300E+00, 0.10656300E+00, 0.16597400E+00, -.14741300E+00, -.87721000E-01, -.13247600E+00, -.55817400E-01, 0.16031100E+00, 0.27783800E-01, -.43866500E+00, 0.39832000E+00, 0.37875600E-01, -.52269500E+00, 0.34132400E+00, 0.64512900E-02, -.19368700E+00, 0.35607800E+00, -.21578500E+00, -.19338400E+00, 0.91927300E+00, -.14013800E-01, 0.45640500E-02, -.32406400E+00, -.47644900E+00, 0.21629500E-01, -.29416800E-01, -.45901700E-01, -.21866700E+00, -.17961400E+00, -.33592400E+00, 0.16318400E+00, 0.33551200E-01, -.17469100E+00, -.66815000E-03, -.18099200E+00, -.23791300E-02, -.12179000E+01, 0.15609400E+00, 0.50319700E-01, 0.17770500E+00, -.21286800E+00, 0.14076400E+00, -.96279600E-01, -.15576400E+00, -.18585600E-01, 0.23024500E+00, -.83180300E-01, -.13346900E+00, -.15688600E+00, -.22497100E+00, -.22657900E+00, -.15148000E+00, 0.56116600E-02, 0.15334000E+00, -.75321500E-01, 0.96398600E+00, 0.23146100E+00, 0.25745400E+00, 0.59759700E+00, -.34090000E-01, -.13717100E+00, 0.14596000E+00, -.15779700E+01, -.62992200E-01, 0.15082000E+00, 0.33320200E+00, -.43007100E-01, -.12536700E+00, -.20977500E+00, 0.50845500E-01, 0.11579600E+00, -.10280600E+00, 0.19383800E+00, -.24844800E+00, -.24604800E+00, 0.11822800E+00, -.74803700E-01, 0.33860800E+00, 0.20185900E-02, 0.40057200E+00, 0.32072100E-03, -.63785700E-01, 0.23139200E+02, -.15397400E+01, -.63818500E+00, -.60534700E+02, 0.30558300E+02, 0.35423600E+02, -.27323400E+02, -.21420000E+01, 0.33717100E+02, 0.13130000E+02, 0.15304500E+02, 0.19266300E+00, 0.38941200E+02, -.19635800E+02, -.22521100E+02, -.19619200E+02, -.56703900E+01, -.16954800E+02, 0.10215100E+02, 0.25212400E+02, 0.12190500E+02, -.17843700E+02, 0.87983900E+01, 0.85087800E+01, 0.11478900E+01, 0.30741100E+01, 0.42041100E+01, -.25713400E+01, 0.75525200E+01, 0.51972800E+01, -.72592700E+02, 0.35353400E+02, 0.35728300E+02, 0.17257000E+01, 0.11679500E+02, 0.27066100E+02, 0.12873100E+01, 0.16651900E+02, 0.69738400E+00, -.19014200E+02, 0.81641300E+01, 0.11887300E+02, 0.76519500E+01, 0.23548800E+02, -.70056200E+01, -.35386100E+01, 0.13095000E+02, 0.22967000E+02, -.22578400E+01, 0.42403500E+00, 0.16742600E+01, 0.15046700E+01, 0.65438100E+00, -.12545000E+00, 0.94443200E+00, -.71016100E+00, 0.22846300E+01, 0.14129100E+01, 0.13691800E+01, 0.24344200E+00, 0.33013600E+01, -.42400100E+01, 0.22150400E+01, -.24583700E+01, 0.10664600E+01, 0.20887200E+01, 0.45678300E+01, -.11392600E+00, -.45983100E+01, 0.26983900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23276600E+02, -.12503900E+02, -.20372300E+02, -.17076700E+03, 0.30434200E+02, 0.30514700E+01, -.14200800E+02, -.95272400E+01, 0.44458600E+02, -.12013600E+02, 0.87558000E+01, -.12889500E+01, -.29098100E+02, -.11151400E+02, 0.14775000E+01, -.14680200E+02, -.23814500E+02, -.13426900E+02, -.29240400E+01, 0.10621400E+02, -.67362600E+00, -.29882300E+02, -.87089600E+02, 0.39906600E+01, -.11569700E+02, 0.19319500E+01, -.40554600E+02, 0.10525600E+02, 0.67356600E+02, 0.41031200E+01, -.10924200E+02, 0.16723700E+02, -.62367500E+00, 0.33737400E+02, -.69879500E+01, 0.14747800E+02, -.79209700E+01, -.35180100E+01, -.93397200E+01, -.16195100E+01, 0.18807300E+01, 0.31331500E+01, 0.80922400E-01, -.14768800E+01, 0.19804600E+01, -.54799800E-01, -.22442100E+02, 0.32911000E+01, 0.17856800E+01, -.19061900E+00, 0.76678000E+00, -.46619400E+00, -.18544700E+01, -.74032600E+01, 0.18389100E+01, 0.38199500E+01, -.47920800E+01, 0.34612800E+01, -.67785000E+00, -.25666400E+01, 0.44532200E+00, 0.78623700E+01, 0.57195000E+01, 0.17501600E+01, 0.85362100E+00, -.51681300E+01, -.31526800E+01, 0.95225500E+00, 0.11157500E+00, -.20441000E+00, 0.74146000E-01, -.80780500E+00, 0.34284600E+01, -.14846700E+01, 0.37227300E+01, 0.26016600E+00, 0.19338200E+01, 0.53067100E+01, 0.97373900E+01, 0.30081300E+01, -.20144200E-01, -.37306600E+01, -.38007500E+01, -.15258500E+01, -.15023400E+01, 0.67983300E+00, 0.44918800E-03, -.44276600E+00, -.91984000E+00, -.70771500E+01, 0.34424000E+00, -.27309200E+00, -.77091400E+00, -.14641800E+01, 0.98781300E+00, -.64349400E+01, -.98625000E+00, -.19067300E+00, 0.51352900E+01, 0.11253100E+00, -.27213800E+00, 0.12596700E+01, -.10730000E+01, 0.10025500E+01, 0.23065300E+01, 0.30441800E+00, -.31943400E+00, 0.44210300E+01, 0.43139800E+01, -.24470500E+01, -.26933800E+00, -.19415600E+01, 0.13643400E+01, -.20516000E+01, -.15020000E+01, -.19430300E+01, 0.38433100E+01, 0.49129700E+01, -.17000900E+01, -.15674500E+01, -.13553200E+01, 0.96590100E+01, 0.11778500E+01, 0.12373900E+01, 0.73748800E+01, 0.14039700E+00, 0.75592600E+00, -.34757800E+01, 0.16840800E+01, -.10752700E+01, -.17807300E+01, -.52041900E+01, 0.55581100E+01, -.40094100E+01, 0.44301500E+01, 0.11025800E+01, 0.15049700E+01, 0.28989600E+00, -.15634300E+01, -.69654600E-01, 0.13153100E+01, -.84204000E+01, 0.20721800E+03, 0.47489500E+02, 0.14309800E+04, -.74212700E+03, -.78829700E+03, 0.22289400E+03, -.18594500E+03, -.50884800E+03, -.78442400E+02, 0.30767500E+03, -.23073700E+03, -.13319200E+04, 0.66870300E+03, 0.67424700E+03, 0.26514400E+03, 0.47192300E+03, 0.28822600E+03, -.41565300E+02, 0.22367400E+02, 0.55834600E+03, -.92867700E+01, 0.82661800E+01, 0.19092800E+02, 0.62666100E+01, 0.18707200E+02, -.52360100E+01, 0.17020700E+02, 0.30375300E+03, -.36801800E+01, 0.13825400E+03, -.61149200E+02, -.11782900E+03, 0.22147500E+03, 0.92909800E+02, -.23109700E+03, -.21090500E+03, -.38780600E+03, 0.93977100E+02, -.72636900E+03, 0.28221800E+03, 0.33026500E+03, -.20248100E+03, -.40356600E+02, 0.19408100E+03, 0.13679300E+03, 0.59814000E+01, -.84258200E+02, -.10623500E+02, -.29887900E+02, -.95056200E+01, 0.41335700E+02, -.71046500E+02, -.63638300E+01, 0.55152300E+01, 0.61696300E+01, -.27522600E+02, 0.14300000E+02, -.72701700E+02, 0.20639700E+02, -.14494600E+02, 0.11569400E+02, 0.29855100E+02, 0.17675300E+02, 0.35695800E+01, -.18032500E+03, -.29446600E+02, 0.17829200E+01, 0.31340500E+02, 0.28641500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.29682200E+01, 0.11243800E+01, 0.42137900E+01, 0.14143700E+02, -.11075600E+01, -.45625400E+00, 0.26648600E+00, 0.21229200E+01, -.50963800E+01, 0.10982700E+01, -.21653300E+01, 0.13354800E+01, 0.19942300E+01, 0.22563400E+01, -.14690200E+00, 0.13570100E+01, 0.31870500E+01, 0.16568100E+01, 0.73198000E+00, -.15253600E+01, 0.36527600E+00, 0.37699000E+01, 0.59721100E+01, -.91508300E+00, 0.17312700E+01, 0.78534900E+00, 0.60215100E+01, -.10686100E+01, -.94290600E+01, -.59395000E+00, 0.27657500E+00, -.17508300E+01, 0.77786900E+00, 0.69479600E+00, -.21253100E+00, -.34552300E+01, -.14897200E+01, 0.39355000E-01, 0.19272700E+00, -.47947300E+00, -.31968600E+00, -.81080300E+00, 0.42836500E-01, 0.25977000E+01, 0.28110700E-01, -.74270500E+00, 0.31788500E+01, -.16246000E+01, 0.60011800E+00, 0.81367600E+00, -.74203700E-01, 0.19726800E+01, 0.67760300E+00, 0.82866700E+00, 0.86039500E+00, -.81871000E+00, 0.55884900E+00, -.35129400E+00, -.18951800E+00, -.15589400E+01, 0.25938600E+00, 0.41216900E+00, -.14526700E+01, 0.15812400E+00, 0.63968800E-01, 0.19409100E+01, 0.89390100E-01, -.34104800E-01, 0.94668200E+00, -.21948700E+00, 0.82628700E-01, 0.33824200E+00, -.13418300E+00, -.41011400E-01, 0.83061500E-01, -.14970400E+00, -.69800300E-01, -.32803500E+00, -.63524100E+00, 0.30718900E+00, 0.16760700E+00, 0.45243700E+00, -.37538100E+00, -.95676400E-01, 0.31083000E+00, -.59821900E+00, -.33131100E+00, -.19894400E+00, -.10520700E+01, 0.87823200E+00, 0.52526700E+00, -.50780300E-01, 0.17057800E-02, 0.56836700E-01, 0.25563700E+00, -.43141100E+01, -.18077100E+00, 0.70261100E-01, 0.99734300E-01, 0.91348800E-01, -.85817000E-01, 0.11557900E+00, -.43202400E+00, -.54692700E-01, -.68429600E-02, 0.14625700E+00, 0.88789600E-02, -.13402400E+00, -.53500900E+00, -.23181800E+00, -.76157500E-01, 0.51766100E+00, -.41464000E+00, -.37714800E+00, 0.60208500E+00, -.27680000E+00, -.25792500E+00, -.16394400E+00, 0.63978100E-01, -.16949200E-01, -.50099400E-01, -.67334200E+00, 0.74088000E+00, 0.10388100E+00, 0.13284800E+01, -.25233500E-01, -.19505600E+00, 0.92752200E-01, -.40510300E-01, -.28800500E-01, -.29014800E+00, -.17804600E+00, 0.39948400E+00, -.14729000E+00, -.13063200E-01, -.39052700E+00, -.51924400E+00, -.64851200E-01, -.88555800E-01, -.70354200E-02, 0.14983200E+00, -.46390100E+00, 0.21018600E-01, 0.25602500E+02, 0.54855800E+02, -.29231300E+02, -.27566800E+02, -.27519100E+01, -.31162000E+02, -.24257600E+02, -.52199600E+02, -.20223900E+02, 0.14148300E+02, -.18397200E+01, 0.89374300E+00, 0.17688100E+01, -.41918800E+01, -.22114700E+02, 0.14741100E+02, 0.23411500E+02, -.33602800E+01, -.28001000E+02, 0.94710100E+01, -.48456800E+01, -.55351000E+01, -.15370100E+00, -.11081700E+01, -.39537900E+01, -.55963500E+01, -.19943700E+01, -.64935600E+01, -.34317100E+02, 0.16243700E+02, 0.16318900E+02, -.81062000E+01, 0.16298200E+02, 0.51807400E+01, 0.31104800E+01, 0.16921400E+02, 0.19756000E+02, -.28355400E+02, 0.12666000E+02, 0.45059900E+01, 0.21349400E+01, 0.22324500E+02, 0.13438700E+02, 0.35650200E+02, 0.12611000E+02, 0.86140500E+00, -.97052100E+00, 0.82971600E+00, -.16587100E+01, 0.62310900E+00, 0.24904300E+01, -.18891000E+01, -.52670300E-01, 0.21130500E+01, -.24680500E+01, 0.28726800E+01, 0.31195700E+01, 0.15462000E+01, -.11226800E+01, 0.71886800E+01, 0.14747100E+00, 0.16200100E+01, 0.78093600E+01, 0.17257400E+02, -.42778600E+01, 0.18793900E+01, -.29286700E+01, -.23827400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.30737500E+01, -.11745600E+01, -.39423600E+01, -.19113900E+02, 0.11612400E+01, 0.74782600E+00, -.35926600E+00, -.21407000E+01, 0.56031400E+01, -.11237200E+01, 0.33115900E+01, -.15797000E+01, -.21562600E+01, -.15856800E+01, 0.48037000E+00, -.18747100E+01, -.24448300E+01, -.14532000E+01, -.79143100E+00, 0.14059600E+01, -.44652500E+00, -.33373600E+01, -.42402700E+01, 0.77688200E+00, -.10196700E+01, -.85286000E+00, -.98702600E+01, 0.11982800E+01, 0.81885900E+01, -.15909900E+01, -.30870600E+00, 0.25722400E+00, -.90095400E+00, 0.11939700E+01, 0.41517300E+00, 0.11051500E+00, 0.23321000E+00, -.10585600E+00, 0.73095200E+00, -.41599800E-02, -.40628500E+00, 0.81809800E+00, -.48538700E+00, -.36946300E+00, 0.78364500E+00, -.21549800E+00, 0.45712400E-01, 0.66790800E+00, -.77460700E+00, 0.24536300E+00, -.12922600E-01, 0.53502200E+00, 0.49233900E+00, -.90093400E+00, 0.24588200E+00, -.28378900E+00, 0.80781300E+00, -.17920600E+01, 0.26001700E+00, 0.60436200E-01, -.50907400E+00, -.24112800E+00, -.12832300E+00, 0.13940300E+00, -.66487200E-02, 0.39174300E-02, 0.70425100E-01, -.52287900E-01, 0.99035800E-01, 0.34430200E-01, 0.24395100E+00, 0.44201900E+00, -.25138300E+00, 0.80248300E-01, 0.32621400E+00, 0.57910800E+00, 0.33264500E+00, -.48273800E+00, -.67293800E+00, -.29875800E+00, 0.10217300E+00, 0.33804900E+00, 0.55788400E+00, -.91764500E-01, -.16539500E+00, 0.42548200E-01, 0.50038000E-01, -.82340300E-01, -.46203500E-01, 0.15638600E+01, -.52598100E+00, -.28845400E+00, -.49888900E-01, 0.20857800E+00, 0.11533400E+00, -.24763800E+01, -.21593000E+00, -.58255800E-01, -.13296100E+01, 0.62998000E+00, -.11657600E+00, -.49606100E+00, 0.66337000E+00, 0.39509500E+00, -.40641900E+00, 0.23231700E+00, 0.68835400E-01, -.55987300E+00, -.34772300E+00, 0.12459100E+00, -.31248300E-01, 0.46176800E+00, -.19132300E+00, -.94464900E-01, -.36677400E-02, 0.33213200E+00, -.69494500E-01, 0.12853200E+00, 0.12353300E-01, -.12276600E-01, 0.86415300E-01, 0.37990700E+00, 0.94944900E+00, 0.13767500E+00, -.17276500E+01, -.13190300E+00, -.17192000E+00, -.14109800E+00, -.15548900E+00, -.17995800E+00, 0.18395000E+00, 0.24578300E+00, -.54206000E-01, -.24088600E+00, -.12632200E+00, -.38792900E-01, -.28034400E+00, -.15020500E-01, -.69032700E+00, -.27516200E-01, 0.44332700E-01, -.46476600E+00, 0.32650200E-01, -.24079200E+00, -.12640600E+03, 0.64308000E+02, 0.66428100E+02, -.35077900E+02, 0.55442500E+01, 0.39307000E+02, 0.12805000E+02, 0.32557500E+02, 0.15737100E+02, -.16929300E+02, 0.82799800E+01, 0.64070300E+01, -.15445100E+00, -.34440000E+01, 0.14304300E+02, 0.13122800E+02, 0.16381100E+02, -.56879600E+01, 0.43500200E+01, -.18707500E+01, -.31994400E+01, 0.18975100E+00, -.20301500E+01, -.23819900E+01, -.34137700E+00, -.38274900E+01, -.15403700E+01, -.22786000E+02, 0.10519200E+02, 0.14166600E+02, -.90496200E+01, 0.38649900E+01, 0.42260000E+01, 0.19548200E-01, 0.87626900E+01, 0.84027600E+01, 0.57396000E+02, -.19702200E+02, -.24004900E+02, 0.23828000E+02, -.41241300E+01, -.14523400E+02, -.17752700E+02, -.89179900E+01, -.59772800E+01, -.44714600E+00, 0.33073900E+00, 0.24977800E+01, -.16395500E+00, 0.24829000E+00, -.19233200E+01, -.85510200E-01, 0.14964400E+01, -.12871100E+01, 0.60636700E+00, 0.43342300E+00, -.59542400E+00, 0.19308200E+00, 0.43004200E+01, 0.99970900E+00, 0.65064000E+00, 0.30556100E+00, 0.29124500E+02, -.15574200E+01, 0.40616800E+00, -.15045900E+01, -.33866300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19387300E+02, -.81428200E+01, -.20837600E+02, -.14014100E+03, 0.20920700E+02, 0.19642400E+01, -.98805000E+01, -.82774400E+01, 0.42406600E+02, -.96815200E+01, 0.10014700E+02, -.33996500E+01, -.22916400E+02, -.10529800E+02, -.11990500E+01, -.12212800E+02, -.20954400E+02, -.71207800E+01, -.46532600E+01, 0.79624800E+01, -.23991600E+01, -.21005900E+02, -.31353500E+02, 0.68213800E+01, -.52443400E+01, -.21395600E+01, -.59269400E+02, 0.14446500E+02, 0.81908400E+02, 0.14602200E+01, -.22966500E+01, 0.76465000E+01, -.45944600E+01, 0.20320800E+02, 0.18917300E+01, 0.10432600E+02, -.25917000E+01, -.13201200E+01, 0.58207100E+01, -.33826300E+00, -.54823900E+01, 0.12036100E+02, -.67088300E+01, 0.74954400E+01, -.78762900E+01, 0.41529900E+00, 0.71685300E+01, 0.27257800E+01, 0.42751500E+01, -.10519800E+01, -.25420900E+01, 0.49882900E+00, 0.15182100E+01, -.58548200E+01, 0.97053900E+00, 0.35142400E+01, -.34853800E+00, -.37699900E+01, 0.17702700E+01, 0.32067900E+01, -.19325200E+01, -.61812900E+01, 0.95792800E+00, 0.18748100E+00, 0.33392600E+01, 0.29443700E+01, -.16942500E+01, -.69267000E+00, -.26323400E+01, 0.14424100E+01, -.23270100E+01, 0.40430200E+00, -.43004600E+00, 0.28197600E-01, 0.60835500E+00, -.15695200E+01, 0.97164300E+00, 0.28439900E+01, -.35995600E+01, 0.66230200E+00, 0.45284100E-01, -.23901900E+00, 0.34198600E+00, -.15511700E+01, -.13282900E+01, 0.46691900E+01, -.48836900E+00, -.14383100E+01, -.32287200E-02, 0.53582500E+01, -.50697500E+01, -.97423100E+00, -.33532600E+00, 0.14721500E+00, -.12043100E+01, 0.47542400E+01, 0.88723500E+00, 0.30074200E-01, -.33698300E+00, -.42119900E+00, 0.62322400E+00, -.90675200E+00, 0.22817900E+01, 0.16878200E+01, 0.17652900E+01, -.13657000E+00, -.18511300E+01, -.43256200E+01, -.56746900E+00, 0.23234700E-01, -.29776300E+01, -.16266400E+01, -.99583800E+00, -.17914000E+01, 0.45108000E+00, -.52975300E+01, -.11800300E+01, -.34076200E+01, -.17424900E-01, 0.11396400E+01, -.15234700E+01, 0.44371900E+01, -.18994300E+01, -.10890900E+01, -.63471400E+01, -.30438900E+00, 0.26557000E+01, 0.20135700E+01, 0.11545400E+01, 0.71104500E-01, 0.10028400E+01, -.11420000E+01, -.12786500E+01, -.13386200E+01, -.39721600E+00, -.38876400E+00, 0.35916000E+01, -.30690100E+00, 0.80623800E+00, 0.50410700E+00, 0.63483400E+00, 0.38040200E+01, -.93601800E-02, -.22921700E+01, 0.16733100E+01, -.19622800E+02, 0.24667100E+02, -.94530300E+02, -.77770000E+02, 0.91095200E+01, -.14098600E+03, -.15837600E+03, 0.21139900E+02, 0.38578200E+03, -.19309500E+03, -.20470100E+03, -.12908700E+03, -.18964400E+03, -.85887300E+02, 0.84974100E+02, 0.10231300E+03, -.20921500E+03, 0.29361000E+02, -.16068600E+02, -.20855500E+02, -.24114900E+01, -.13392900E+01, -.27877700E+01, -.19517200E+02, -.29179200E+02, 0.34741400E+01, -.11949900E+03, 0.55903500E+02, 0.69764200E+02, -.62445900E+02, 0.25491300E+02, 0.63621400E+02, 0.20780600E+02, 0.51951100E+02, 0.21706800E+02, -.21539800E+03, 0.91077400E+02, 0.10881600E+03, -.32415700E+01, 0.92319300E+02, 0.49450300E+02, 0.14795800E+03, 0.57461600E+02, 0.45432600E+02, 0.39403400E+01, 0.98310300E+01, -.18938100E+01, -.58958300E+01, 0.17115800E+02, 0.28865800E+01, -.13647100E+01, -.81230700E+01, 0.17767100E+01, 0.15037500E+02, 0.19989100E+02, 0.53198400E+01, 0.29546500E+01, 0.24303000E+02, -.60129800E+01, 0.10213000E+01, 0.26248700E+01, 0.10797800E+03, 0.68524200E+00, -.23316100E+01, -.24020000E+02, -.82632400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.49940600E+01, 0.21996100E+01, 0.75025400E+01, 0.36792500E+02, -.53125600E+01, -.76965200E+00, 0.27759400E+01, 0.14067400E+01, -.11857000E+02, 0.24673200E+01, -.23236100E+01, 0.10982800E+01, 0.54683100E+01, 0.25146400E+01, -.59392300E+00, 0.46033800E+01, 0.59205000E+01, 0.37818600E+01, 0.14724000E+01, -.30667100E+01, 0.34074100E+00, 0.73619200E+01, 0.19206900E+02, -.65314900E+00, 0.29219700E+01, 0.40486700E+00, 0.11591300E+02, -.19899000E+01, -.16014800E+02, -.27452100E+01, 0.25257600E+01, -.44107500E+01, 0.90356600E-01, -.78571100E+01, 0.21236000E+01, -.81722300E+01, -.93216900E+00, 0.42187600E+00, 0.97397400E+00, -.53193400E+00, -.83962400E+00, -.41420900E+01, 0.20694700E+01, -.77047300E+00, 0.31892200E+01, -.77246100E+00, -.14947800E+02, -.86115800E-01, -.89737100E+00, -.11407300E+01, 0.45541500E+00, -.39480300E+01, 0.73755800E+00, -.26703800E+01, 0.14720700E+01, -.84468300E+00, -.10116300E+01, 0.47921800E+00, -.27898900E+00, 0.74073100E+00, -.56648400E+00, -.39158200E+00, -.44523600E+00, 0.64347500E+00, 0.48568800E+00, 0.61687700E+00, 0.12029700E+00, 0.87250300E+00, 0.54837000E+00, -.13805300E+01, -.16079300E+00, 0.17310800E+01, 0.47422100E-01, -.93199600E-01, -.28447300E+00, -.25869900E-01, -.73857000E+00, -.56766400E-01, 0.68421700E+00, -.13479500E-01, -.15055100E+00, 0.92506000E+00, 0.73219500E+00, 0.39202500E+00, 0.57985800E+00, -.23944000E+01, 0.14732600E+00, 0.49189300E+00, 0.31108100E+00, 0.14004400E+00, 0.83035400E-01, 0.74525600E-01, 0.28838900E+00, 0.15401100E+00, 0.10220400E+00, 0.72032200E+01, -.23347700E+00, 0.13672400E+00, 0.14164300E+01, -.44039800E+00, -.30010100E-01, 0.35194900E+00, 0.35407900E-02, -.51774300E-01, 0.39227400E+00, -.23714400E+00, -.59458200E+00, -.21873700E-02, 0.68510300E+00, -.13571100E+00, -.23521700E+00, -.25952300E+00, 0.63945800E+00, -.10902900E+00, 0.71452400E+00, 0.89140600E+00, 0.13365700E+01, 0.12975200E+01, -.17634600E+00, -.32117500E-01, 0.17141500E+00, -.98189000E+00, 0.27969000E+00, 0.38531400E+00, 0.15569100E+01, -.10958300E-01, -.68837400E+00, -.81849600E+00, -.48111900E-02, -.50739700E-01, 0.74363900E-01, 0.91155900E-01, 0.32023600E+00, 0.21885200E+00, 0.22629100E-01, 0.22264400E+00, 0.36077600E+00, 0.88663300E-01, 0.53663900E+00, -.36087200E-01, -.27392900E+00, 0.46998700E+00, 0.58349600E-01, -.36682800E+00, 0.54509700E+00, -.11819500E+00, 0.16334400E+02, 0.27760200E+01, 0.12812300E+01, 0.25518600E+01, -.30534900E+01, -.31341000E+02, 0.11347600E+01, 0.12774400E+03, -.64032000E+02, -.68081900E+02, -.47504000E+02, -.56171600E+02, -.24056500E+02, 0.28757900E+02, 0.57668300E+02, -.57824500E+02, 0.30334400E+01, -.21206300E+01, -.28435100E+01, 0.21288400E+00, 0.78916100E+00, 0.32380700E+01, -.45287300E+01, -.72332300E+01, 0.57782800E+01, -.22682300E+02, 0.97609500E+01, 0.11755800E+02, -.49953100E+01, 0.16221900E+01, 0.14048300E+02, -.60460200E+00, 0.35243900E+01, -.49943300E+01, -.16847200E+02, 0.45060500E+01, 0.66947400E+01, -.10172100E+01, 0.20282100E+02, -.10852400E+02, 0.10615700E+02, 0.70059100E+01, 0.18717800E+02, 0.22053200E+01, 0.29560400E+01, -.14839800E+01, -.91996700E+00, 0.41389900E+01, 0.12703800E+01, -.62706800E+00, -.32105100E+01, 0.30174500E+01, 0.21741700E+01, 0.53077400E+01, 0.22812800E+00, 0.20967500E+01, 0.13785900E+01, -.15410700E+01, -.16415400E+01, -.64892500E+00, -.26857100E+01, -.19294300E+00, -.10573100E+01, -.53359100E+01, 0.87646900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.19635800E+01, 0.99875100E+00, 0.12104000E+01, 0.21079500E+02, -.37151600E+01, -.41877800E-02, 0.15236200E+01, -.90816000E-01, -.49299600E+01, 0.13066600E+01, -.68739500E+00, -.41440600E+00, 0.30338400E+01, 0.11361900E+01, 0.33116600E+00, 0.36749200E+01, 0.27833800E+01, 0.80937600E+00, 0.97649500E+00, -.88508500E+00, 0.44360800E+00, 0.24864900E+01, 0.16266000E+01, -.86497800E+00, -.95671500E-01, 0.73397000E+00, 0.84826700E+01, -.16820900E+01, -.95467700E+01, 0.83003700E+00, -.28413400E+00, -.21587100E+00, 0.92735700E+00, -.87856900E+00, -.95094000E+00, -.30788600E+00, 0.26301400E+00, -.29968100E-01, -.75154800E+00, 0.25357000E-01, 0.10778100E+01, -.13859200E+01, 0.72347600E+00, 0.12773900E+00, 0.13542200E+00, -.42883700E+00, 0.69101500E+01, -.55083900E+00, 0.26167900E+00, 0.37000700E+00, 0.46285400E+00, 0.10580500E+01, -.30864200E+00, 0.26492400E+01, -.13420100E+01, -.34046100E+00, 0.10547900E+01, 0.11060600E+01, 0.12190700E+00, -.91041000E-01, 0.80577800E+00, 0.10197400E+01, 0.30695100E+00, 0.17654800E+00, -.48731900E+00, 0.72871200E+00, 0.90925400E-01, -.29430800E+00, -.12181800E+01, 0.36165600E-01, 0.14950700E+00, 0.93079900E+00, -.90968200E+00, 0.31871200E+00, -.37960200E+00, 0.45616700E+00, 0.82089100E-01, -.70678300E+00, -.75647700E+00, -.25042900E+00, 0.42960800E-01, -.96738600E+00, -.77795500E+00, 0.58290100E+00, 0.11686900E+00, 0.89301300E+00, -.26362600E+00, -.39029000E+00, -.84008800E+00, 0.10485800E+01, -.74041400E+00, -.76957600E-01, -.32569200E-01, -.11756600E-01, -.19517400E+00, -.38918100E+01, 0.12559700E+00, 0.16586600E-01, -.83862900E+00, -.27604700E-02, 0.17791100E+00, 0.44915500E-01, 0.29939800E-01, -.88797600E-01, -.11571300E+00, -.22578400E+00, -.23365800E+00, -.29561100E+00, -.65045800E+00, 0.14046600E+00, -.12602100E+00, -.10199000E+00, 0.10750000E+00, -.47060300E-01, 0.60440700E+00, -.41526100E-01, -.15860100E+00, 0.11898700E+00, 0.19819200E-01, -.57251400E-01, 0.74740600E-01, -.99134500E+00, -.38159000E+00, -.62441500E-01, 0.75955700E+00, 0.18896000E-01, -.21010000E+00, -.50066800E-01, -.57371900E-01, -.16193600E+00, -.17637800E+00, -.69557400E+00, 0.36136000E+00, 0.80954500E-02, -.15747000E+00, 0.83332900E-01, 0.18542600E-01, -.70739600E-01, -.53387300E+00, 0.36661500E-01, 0.99312800E-02, -.18572700E+00, 0.20353800E-01, -.35604300E+00, 0.17723400E+00, -.10433200E+00, 0.23648200E+00, -.46199800E+02, -.21361000E+02, 0.13111600E+02, 0.10536900E+02, 0.99203200E+01, -.10390900E+02, 0.28110600E+02, -.14078500E+02, -.14057100E+02, -.10104300E+02, -.31170500E+02, 0.94997000E+01, 0.24589200E+02, 0.14169100E+02, -.38308500E+02, 0.43870600E+01, -.27388600E+01, -.36214900E+01, 0.17406800E+01, -.14828400E+01, -.23882900E+01, -.38728000E+01, -.58461100E+01, -.33324100E+01, -.30260300E+02, 0.13696400E+02, 0.14857100E+02, -.68872900E+01, 0.94110600E+01, 0.92710700E+01, 0.44823600E+01, 0.19644400E+02, 0.15209800E+02, 0.29545800E+02, -.12247600E+02, -.16802700E+02, 0.19825400E+02, 0.10084400E+02, -.73052300E+01, 0.13861000E+02, -.13622700E+02, 0.44246500E+01, -.10610100E+01, 0.50809200E+00, -.16229400E+01, -.19419800E+00, 0.14437200E+01, -.90113200E+00, 0.24164200E+00, 0.48026900E+00, -.14638900E+00, 0.13930700E+01, 0.13124500E+01, -.58051300E+00, 0.18752600E+01, 0.91584300E+01, -.24739500E+01, 0.17197000E+01, 0.59842400E+00, 0.39688700E+02, -.45752500E+01, 0.71872100E+00, -.60844900E+01, -.53407600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.44029600E+01, 0.27987300E+01, 0.42849100E+01, 0.36479300E+02, -.57953300E+01, -.81779500E+00, 0.28452900E+01, 0.14784900E+01, -.72078100E+01, 0.22429600E+01, -.18259700E+01, 0.29359800E+00, 0.27370000E+01, 0.21269900E+01, -.75891800E+00, 0.22416400E+01, 0.45388500E+01, 0.19447600E+01, 0.86287800E+00, -.18162100E+01, 0.74646400E+00, 0.25178100E+01, 0.25790500E+01, -.15303000E+01, 0.45238900E+00, 0.95226300E+00, 0.16316000E+02, -.28057700E+01, -.13630400E+02, 0.20981600E+01, -.36950100E+00, 0.77417600E+00, 0.14041500E+01, -.40175500E+01, -.13882700E+01, -.22187100E+00, 0.51843300E+00, 0.18531800E+00, -.23685700E+01, 0.37933900E+00, 0.22122800E+01, -.29811800E+01, 0.16597100E+01, -.32502000E+01, 0.22696200E+01, 0.16575400E+00, -.71346900E+01, -.26280700E+00, -.13440400E+01, -.92428800E-01, 0.11279700E+01, -.32388800E+00, -.16031200E+01, 0.11004100E+01, -.10946000E+01, 0.26666800E+00, -.62912800E+00, 0.20262300E+00, -.36023000E+00, -.10336800E+01, 0.62027000E+00, 0.16453500E+01, 0.10704800E+01, 0.50992600E+00, -.62993700E+00, -.19101200E+01, 0.45464500E+00, 0.11937100E+00, -.13430100E+01, -.52666500E+00, 0.44430400E+00, 0.64421900E+00, -.32041900E+00, 0.38107300E-01, 0.21305600E+00, 0.43619800E-01, 0.52533500E+00, 0.20258200E+00, 0.12142300E+01, -.96569400E-01, 0.83231900E-02, -.80405000E+00, 0.15165700E+00, 0.23099200E-01, 0.17499500E+00, -.66961300E+00, 0.69245000E-02, 0.15851900E+00, 0.77650800E+00, 0.26351400E-01, -.27334500E+00, 0.45342200E-02, -.63035900E-01, 0.26304300E+00, -.61750000E+00, -.41949700E+01, -.35992400E+00, -.32205600E+00, -.12716200E+01, -.54067300E+00, 0.34407200E+00, 0.35823300E+00, -.32560200E+00, -.85768600E+00, -.68782700E+00, 0.51038900E-01, 0.12363500E-01, 0.38398900E+00, -.32993300E+00, -.65499300E+00, 0.25148600E+00, 0.63654600E+00, 0.42898100E+00, 0.29471900E+00, 0.41128300E+00, 0.47195300E+00, 0.16973700E+01, 0.25905600E+00, 0.23725400E+00, 0.48638300E+00, -.17696500E+00, 0.21594100E+00, -.48752800E+00, -.21765300E-01, -.11307500E+01, -.76755900E-01, -.54315100E+00, 0.10134800E+00, -.12965200E+00, -.47285800E+00, -.53980300E+00, -.61884600E-01, 0.29599300E-01, -.45917400E+00, -.30889100E+00, -.40271900E+00, -.29247300E+00, -.16801300E-01, -.40431400E+00, -.15788200E-01, 0.15530500E-01, 0.72232000E+00, 0.54986600E-01, -.90364900E+00, 0.31772200E+00, 0.81811100E-01, -.65958900E-01, -.50359800E+00, -.38150500E+02, 0.33803900E+01, -.62295000E+02, -.31321500E+02, 0.10356100E+02, 0.38646100E+02, -.19340400E+02, -.17908900E+02, -.13587800E+02, -.70466200E+02, 0.23884500E+02, 0.54633100E+02, 0.33685100E+02, -.70952200E+02, 0.16686600E+02, -.93604300E+01, -.10012600E+02, 0.35940100E+01, 0.26401300E+01, -.79245300E+01, -.14656900E+02, -.30141300E+02, -.43942200E+01, -.27264300E+03, 0.13421000E+03, 0.13581800E+03, 0.38410000E+01, 0.71116700E+02, 0.61322100E+02, -.14682700E+02, 0.64753000E+02, 0.82989600E+02, 0.29964300E+01, -.20196000E+00, -.12958700E+02, 0.20165800E+02, 0.31288900E+02, 0.17386800E+02, 0.88965100E+02, 0.17348100E+02, 0.34605600E+01, -.47671100E+00, 0.28693000E+01, -.90544900E+01, -.29311900E+01, 0.74037000E+01, -.19233600E+00, 0.12659000E+00, 0.12555200E-01, -.58704200E+01, -.21687600E+01, 0.65619300E+01, -.43234300E+01, -.21698900E+01, 0.16105100E+02, -.91211800E+01, 0.21413300E+01, 0.13692100E+01, 0.23269400E+02, -.90633200E+01, 0.62742400E+00, -.12888000E+02, -.12157900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.48653900E+01, -.41152800E+01, -.44460300E+01, -.41003400E+02, 0.71824200E+01, 0.11614600E+01, -.32721200E+01, -.12239200E+01, 0.95681300E+01, -.25629000E+01, 0.19472300E+01, -.36286200E+00, -.30496900E+01, -.23182900E+01, 0.53329400E+00, -.28300600E+01, -.43996000E+01, -.20824200E+01, -.13520700E+01, 0.19444000E+01, -.23595400E+00, -.44848200E+01, -.10123500E+02, 0.11268300E+01, -.92127900E+00, 0.13052400E+00, -.77492500E+01, 0.29903200E+01, 0.14611200E+02, 0.96073200E+00, -.39095500E-01, 0.16260000E+01, -.90565500E+00, 0.41335100E+01, 0.90361600E+00, 0.23685400E+01, -.76750300E+00, -.58835100E+00, 0.42433300E+00, -.39626700E+00, -.10198000E+01, 0.12403700E+01, -.35423100E+00, 0.82135500E+00, -.14192000E+01, 0.12961400E+01, -.88701500E+00, 0.50549700E+00, 0.10908300E+01, -.36576100E+00, -.85300900E+00, -.13316000E+01, -.59328200E+00, -.22424300E+01, 0.44458100E+00, 0.14360600E+01, -.22167000E+01, 0.11848300E+01, 0.82152200E-01, 0.15110200E+01, -.54571900E+00, -.15641200E+01, 0.48353600E+00, -.26756400E-01, 0.59522700E+00, -.12464000E+01, -.92509700E+00, 0.16451800E-01, 0.69903000E+00, 0.85020800E+00, -.17309900E+00, -.10965700E+01, 0.22949100E+00, -.44233700E+00, -.18815400E+00, -.12809100E+01, -.12461900E+01, 0.14934200E+01, -.10894200E+01, 0.72207300E+00, -.11511000E+00, 0.18779900E+01, 0.18487900E+01, -.11496400E+01, -.62239500E+00, 0.76323000E-01, 0.51878900E+00, 0.76893500E+00, 0.60459300E+00, 0.77513600E+00, -.14940300E+01, 0.19571500E-01, 0.13894500E+00, 0.43606200E+00, -.97698700E-01, 0.66139000E+01, -.14552900E+00, -.15065800E+00, 0.13516300E+01, 0.46478300E+00, -.10549000E+00, -.58209000E-01, 0.96139300E+00, 0.14865400E+00, 0.42608300E+00, -.15945400E+00, -.43724900E+00, 0.15736000E+00, 0.12237600E+01, 0.50238400E+00, -.47568800E-01, -.12596800E+01, 0.16483800E+00, -.77715800E+00, 0.98391800E-01, -.45262600E+00, 0.55916100E+00, -.10424800E+01, 0.19353600E+00, 0.68211300E+00, -.57289100E+00, -.27268600E+00, -.11430500E+01, -.34242200E+00, -.49422500E+00, 0.18940800E-01, 0.28999500E+00, 0.42274900E+00, -.97253000E-01, 0.11974000E+00, -.84739500E+00, -.10365900E+00, -.10392300E+01, -.48516000E-01, 0.63208900E-01, 0.29547200E+00, 0.43276800E+00, 0.32589100E-01, -.13015100E+00, 0.44746300E-01, -.18547800E+00, 0.15156700E+01, -.11069800E+00, -.84920900E+00, -.13220600E+01, 0.64799700E-01, -.32228500E+00, 0.95337700E+00, -.27232000E+00, -.35714500E+02, -.58432800E+02, 0.95495700E+01, -.94360000E+01, -.11748200E+03, 0.58685600E+02, 0.58890300E+02, 0.37877000E+02, 0.22230800E+02, 0.50540000E+02, 0.11902300E+02, -.17227300E+02, 0.16451100E+02, 0.10903700E+02, -.47782700E+01, -.53540100E+01, 0.24492400E+01, -.16606600E+01, -.65776100E+01, -.41934600E+01, -.13559000E+02, -.41444800E+01, 0.18602800E+02, -.72014900E+01, -.35664200E+01, -.11080200E+02, -.11917400E+02, -.16099200E+02, -.45673800E+01, -.45822100E+01, 0.18069500E+01, -.57761800E+02, 0.34162100E+02, 0.27531000E+02, 0.61613600E+01, -.41260100E+02, 0.49529300E+02, 0.21496000E+02, 0.37214600E+02, -.10492600E+02, -.27183300E+00, 0.11033100E+01, -.26907700E+01, -.13861300E+01, 0.62818400E+00, -.24921400E+00, 0.33120200E+00, 0.11822400E+00, -.30489600E+01, -.47290900E+01, 0.83591000E+00, -.49151900E+01, -.58460400E+01, -.44692500E+00, 0.21464800E+01, 0.20615200E+01, 0.37470500E+01, 0.40502000E+02, -.75343500E+01, 0.40831700E+00, 0.72490900E+01, -.58651300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.35899100E+00, 0.27169900E+00, -.21722800E+00, 0.42752800E+01, -.53903100E+00, -.80251300E-01, 0.40549100E+00, 0.99472800E-01, -.86616700E+00, 0.20674800E+00, -.25165300E+00, 0.58051700E-01, 0.50672800E+00, 0.97604200E-01, -.78973300E-01, 0.46627900E+00, 0.47509900E+00, 0.36091300E+00, 0.12948800E+00, -.18682400E+00, 0.52759400E-01, 0.33333000E+00, 0.79235400E+00, -.11164300E+00, 0.83696700E-01, 0.15901500E+00, 0.13346300E+01, -.35223900E-01, -.24246200E+00, 0.19521000E+00, 0.11361800E+00, 0.94290900E-02, 0.94088300E-01, -.23097500E+00, 0.11603600E+00, -.47815500E-01, 0.96629800E-01, -.17009200E-01, 0.75917200E-01, -.12615700E-01, 0.18688100E-01, -.80843100E-01, 0.46090100E-01, 0.11865700E+00, -.24859100E+00, 0.61542100E-01, 0.16245600E+01, -.28475700E-01, 0.18593400E+00, 0.62788600E-01, -.45473800E-02, -.12257300E+00, -.80597300E-01, 0.28373500E+00, -.22014500E+00, -.42035900E-01, 0.16578600E+00, 0.48620900E-01, 0.53819900E-01, 0.93896200E-01, 0.19710700E-01, 0.10773700E+00, 0.55786700E-01, -.12432700E-01, -.10034500E+00, -.76020300E-01, -.68858400E-01, -.24748500E-01, -.62419400E-01, 0.16408600E+00, 0.27763100E-01, -.25946000E-01, 0.32302900E-01, -.61410100E-02, 0.73855800E-02, 0.97571600E-01, 0.84473300E-02, -.32329000E-01, 0.38454900E-01, 0.17871200E-01, 0.36938400E-02, -.80022400E-01, -.67557400E-01, 0.88470200E-01, 0.12118900E-01, -.64784300E-01, -.18909700E-01, -.28845500E-01, -.70918400E-01, 0.30328000E+00, -.87329700E-01, -.52969600E-01, 0.40801800E-03, 0.23922200E-01, 0.90494000E-02, 0.74172900E+00, -.30154100E-01, -.10739300E-01, 0.47163700E-01, 0.16973000E+00, -.23144500E-01, 0.19425400E-01, 0.10424800E+00, 0.58959600E-01, 0.34128600E-01, -.27433700E-01, -.49610900E-02, 0.66568700E-01, -.80185900E-01, 0.23762400E-01, 0.41206300E-01, 0.39786500E-01, 0.74603800E-01, -.59804600E-02, 0.15193500E+00, -.66638900E-01, -.12437700E-01, 0.83466800E-01, -.80780800E-02, 0.51596900E-02, -.48021600E-01, -.13313700E+00, -.60023500E-01, -.86865800E-01, 0.29041100E-01, 0.21345200E-01, 0.45752400E-01, -.59049200E-01, -.36641200E-01, 0.62067500E-02, -.34347200E-01, 0.28170200E-01, -.86338100E-02, -.74163000E-02, 0.61774800E-01, -.34820500E-01, -.13569900E+00, -.78343000E-02, 0.95488600E-01, 0.41912700E-02, 0.25181700E-01, -.13066700E+00, -.30692900E-02, 0.57358600E-01, -.24202700E-01, -.22222400E-02, -.73225600E-01, -.84791100E-01, 0.44399200E-01, 0.31524400E-01, 0.44122800E+01, 0.43060000E+01, 0.76354100E+00, -.18925400E+01, 0.94106900E+00, 0.66665000E+00, 0.28070400E+00, 0.41173700E+01, -.17698600E+01, -.25389800E+01, 0.21875000E+01, 0.37367200E+01, -.95071600E+00, 0.45420600E+00, 0.55007000E+00, 0.34489100E+00, -.93054500E-01, 0.38005800E+00, 0.10137100E+01, 0.29005700E+01, 0.40730900E-01, 0.16113500E+02, -.81098200E+01, -.78985400E+01, -.15687400E+01, -.39606700E+01, -.35411800E+01, 0.13353400E+01, -.30055600E+01, -.49309800E+01, 0.84225500E+01, -.47194700E+01, -.35952200E+01, 0.97747000E-01, 0.23967000E+01, -.60840000E+01, -.60043600E+01, -.70070200E+01, -.41589500E+00, -.29893500E-02, -.10008300E-01, 0.10863200E+01, 0.54580100E+00, -.93847000E+00, -.20365500E+00, -.12159400E+00, 0.11810600E+00, 0.55628800E+00, 0.75613500E+00, -.92374100E+00, 0.68441500E+00, 0.74195400E+00, 0.67497700E-01, 0.70741900E+00, -.10821100E+00, -.68953400E+00, -.14046300E+01, 0.42267700E+00, 0.25079400E+00, -.85095100E-01, 0.56797300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.41419400E+01, -.36103600E+01, -.38439900E+01, -.34940400E+02, 0.66485900E+01, 0.81610700E+00, -.31738300E+01, -.10428200E+01, 0.87534500E+01, -.21492500E+01, 0.18879900E+01, -.30400500E+00, -.37469300E+01, -.13608200E+01, 0.46146500E+00, -.37644900E+01, -.42949600E+01, -.27792000E+01, -.13099900E+01, 0.20157500E+01, -.29016700E+00, -.42003100E+01, -.10001800E+02, 0.45753300E+00, -.13537000E+01, -.40799300E-01, -.69425700E+01, 0.70940700E+00, 0.53259000E+01, 0.73922000E+00, -.14143400E+01, 0.17512500E+01, -.16575200E+00, 0.36832700E+01, -.13982600E+01, 0.27579700E+01, -.91812200E+00, -.27607600E+00, -.61184900E+00, 0.33034700E+00, 0.18702200E+00, 0.16332500E+01, -.77218200E+00, -.13184100E+01, -.69397400E-02, 0.61536600E+00, -.20333200E+01, 0.91521100E+00, -.10429200E+00, 0.10862700E+00, 0.23081900E-01, 0.12839800E+00, 0.18201500E+00, -.15264500E+01, 0.15629900E+01, 0.13676700E+01, -.12151400E+01, 0.38343300E+00, 0.67136000E-02, -.43759100E+00, -.14671300E+00, -.53813000E+00, 0.52568300E+00, -.17383300E+00, 0.68301300E+00, -.12210100E+01, -.11266000E+00, -.24306900E+00, -.11593900E+01, 0.13479600E+00, 0.14052100E+00, -.10369600E+00, -.35648100E+00, 0.21559100E+00, -.22956600E+00, -.19624300E+00, 0.53988000E-01, -.90170200E-01, -.10420000E+01, -.25155800E+00, 0.60302900E-01, 0.66523000E-02, 0.27541700E+00, -.54502800E+00, -.46020700E+00, 0.17229700E+01, 0.24607600E+00, 0.70985300E-01, 0.62414400E-01, -.10362500E+01, -.37574200E+00, 0.20302600E+00, -.44212700E-01, 0.10414800E+00, -.24409200E-01, 0.13221300E+01, 0.15427100E+00, 0.37637700E-01, -.12266900E+01, 0.55766300E+00, 0.13552800E-01, 0.11179300E-01, 0.29574900E+00, 0.10023700E+00, -.10360400E+00, -.99057300E-01, -.36626800E+00, -.11485400E+01, 0.13113000E+00, 0.38697600E+00, -.12129500E+00, 0.12726400E-01, 0.30444300E+00, -.14128200E+00, 0.56205700E+00, -.47418600E+00, 0.33982000E+00, 0.44322000E+00, 0.12036100E+00, 0.25347400E+00, -.43087100E+00, 0.17039600E+00, 0.93420600E-01, -.21771000E+00, -.18224300E+00, 0.22004400E-01, 0.99508000E-01, 0.35106000E+00, -.16614600E+00, 0.10072900E+00, 0.57773600E-01, 0.10291200E+01, -.36336800E+00, 0.36144000E+00, -.38362200E+00, 0.15641500E-01, -.21339700E+00, 0.51394900E-01, 0.39038000E+00, -.90350400E-01, -.28663900E+00, 0.40310100E+00, -.96223900E-01, 0.18130000E+00, 0.34362600E+00, 0.71569600E-01, 0.22672900E+00, -.19779500E+00, -.27508400E+00, -.41160100E+00, -.36334100E+01, 0.47777400E+02, -.74145900E+01, -.87626400E+02, 0.44057800E+02, 0.39198100E+02, 0.19516900E+02, 0.31501100E+02, 0.13271400E+02, 0.11986000E+01, 0.34057500E+02, 0.38764400E+02, -.41159500E+01, 0.26044600E+01, 0.30719400E+01, 0.34688800E+01, 0.14517900E+01, -.23181300E+00, 0.89249800E+00, 0.23522600E+02, 0.28501800E+01, -.99072000E+02, 0.48158100E+02, 0.50222500E+02, 0.15430100E+02, 0.18074500E+02, 0.11444100E+02, -.27087100E+02, -.59295700E+01, 0.25081100E+02, -.27819200E+02, 0.17956800E+02, 0.27129200E+02, 0.91225500E+01, -.22780000E+02, 0.79049800E+01, -.18041900E+02, 0.36523700E+01, -.15415800E+02, -.14968600E+01, -.26873200E+01, -.69242500E+00, 0.42843000E+01, -.63991500E+01, -.18740100E+01, 0.68287900E+00, 0.96963100E+00, -.29989100E+01, -.60375200E+01, -.77717700E+01, -.55924600E+01, -.14994500E+01, -.23130300E+01, 0.24960700E+01, 0.13528600E+01, -.40371300E+01, 0.20283700E+01, -.86858600E+00, -.32947300E+00, 0.40846000E+01, -.61582500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.24312900E+01, 0.14967300E+01, 0.20921300E+01, 0.20826400E+02, -.34974500E+01, -.25983300E+00, 0.22700800E+01, 0.59106000E+00, -.49157700E+01, 0.13435400E+01, -.10708900E+01, -.69699100E-01, 0.23374700E+01, 0.11802600E+01, -.10324100E+00, 0.17612100E+01, 0.23557600E+01, 0.10301700E+01, 0.54471800E+00, -.10377000E+01, 0.39803100E+00, 0.15828600E+01, 0.47979700E+00, -.71416300E+00, 0.40603000E+00, 0.11549900E+01, 0.10638900E+02, -.14475800E+01, -.81291200E+01, 0.12452300E+01, 0.90698300E-01, 0.18709200E+00, 0.45997700E+00, -.17788000E+01, -.24099200E+00, 0.27740100E+00, 0.52572900E+00, 0.15404500E-01, -.13788500E+01, -.95391700E-01, 0.10863700E+01, -.17381400E+01, 0.65064200E+00, 0.26944900E+00, 0.23360900E+00, -.15457100E-01, 0.12268900E+01, -.77350700E+00, 0.78201500E+00, -.31187100E-02, -.41191500E-01, -.15310100E+01, -.40837900E+00, 0.93461600E+00, -.57425300E+00, -.26547900E+00, -.14552500E+01, 0.10819200E+01, -.38789400E+00, -.72573700E+00, 0.45744600E+00, 0.27029700E+00, 0.86016300E+00, -.27578900E-01, -.64845200E+00, -.16569400E+01, -.21352900E+00, 0.27787900E-02, -.14191900E+00, 0.63319500E+00, 0.45960400E+00, 0.12936500E+00, -.50468900E-01, -.99807900E-01, 0.19917600E+00, 0.29930600E+00, -.10521300E+00, 0.24121900E+00, 0.69802500E+00, 0.27612500E-01, -.15333400E-01, -.11141600E+00, 0.45269600E+00, -.14954000E+00, 0.17760900E+00, -.26789800E+01, -.76665600E-01, 0.14654100E+00, 0.46757200E+00, 0.12533900E-01, -.36471800E+00, -.47679800E-01, -.20530600E-01, 0.19356400E+00, -.17385400E+00, -.59274500E+00, -.21840500E+00, -.73182700E-01, 0.43853200E-01, -.60462700E+00, 0.10053800E+00, 0.10373400E+00, 0.10724000E+00, -.11059900E-01, -.20992600E+00, -.17531200E-01, -.12841400E+00, -.23681700E+00, 0.99798100E-01, -.73038200E-01, -.14203400E+00, -.50437700E-01, 0.11172200E+00, -.38295200E+00, 0.90201300E+00, 0.15876700E-01, 0.53352900E+00, 0.24879500E+00, 0.48903100E-01, 0.21325800E+00, -.70491300E-01, -.97787100E+00, 0.61125300E+00, 0.18873900E+00, 0.82372500E+00, -.71028600E-01, -.46747500E+00, -.85171400E-01, 0.16780800E-01, -.17874900E+00, 0.49975800E-01, 0.42820300E-01, 0.22821800E+00, -.18692300E+00, -.16893700E+00, -.47052300E-01, -.21148400E+00, 0.57580900E-02, -.58315100E+00, -.64729600E-01, -.24336000E-02, -.35923200E+00, 0.70138100E-01, -.58381100E-01, 0.55385600E+00, -.24487600E-01, 0.17116700E+00, 0.18193600E+00, 0.25822500E+00, -.18510300E+00, -.10343700E+01, -.15320600E+00, 0.12713900E+02, -.15537400E+02, 0.76767800E+01, 0.70011900E+01, 0.26402800E+01, 0.11582000E+02, 0.11739800E+01, -.71648000E+01, 0.58611600E+01, 0.13503900E+02, -.16579900E+00, 0.34553000E+00, 0.25013400E+00, 0.14496900E+01, 0.78247700E+00, -.14783700E+01, 0.24392000E-01, 0.22287000E+01, -.15867900E+00, -.28552900E+01, 0.18719600E+01, 0.39595600E+00, 0.19669100E+01, 0.29843100E+01, 0.19952100E+01, 0.37262100E+00, -.10292600E+02, -.16130600E+01, -.17415800E+02, 0.81394300E+01, 0.11946100E+02, -.68907600E+01, 0.59865500E+01, 0.24661700E+01, -.65654700E+01, -.10680800E+01, 0.70992400E+01, 0.27526200E+00, -.62031500E+00, 0.25202500E+01, 0.71177900E+00, -.89206000E+00, -.64059200E+00, -.21985300E+00, 0.70183500E+00, 0.10168500E+01, 0.17539000E+01, -.81057700E+00, 0.13543800E+01, 0.12677100E+01, -.41668200E+00, 0.11123700E+01, -.10207500E+00, -.75821300E+00, -.55882100E+01, 0.99113100E+00, 0.68663500E+00, -.11842400E+01, 0.31004200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.95971000E+01, 0.40300700E+01, 0.14229600E+02, 0.67664600E+02, -.87130900E+01, -.13019300E+01, 0.48290800E+01, 0.37928000E+01, -.22562100E+02, 0.45916700E+01, -.57410000E+01, 0.15156000E+01, 0.11607000E+02, 0.61311900E+01, 0.16203300E+01, 0.66206000E+01, 0.99484000E+01, 0.23286300E+01, 0.26932700E+01, -.36180500E+01, 0.74492600E+00, 0.13417800E+02, 0.19463400E+02, -.29599600E+01, 0.42121000E+01, -.22886700E+00, 0.20604100E+02, -.84636700E+01, -.49396700E+02, -.30823900E+01, 0.93685500E+00, -.72096900E+01, 0.18956400E+01, -.12512000E+02, -.56432800E+00, -.79248000E+01, 0.51407300E+00, 0.10563200E+01, -.14646900E+01, 0.23571600E+00, 0.16234000E+01, -.67719900E+01, 0.27112400E+01, -.38330000E+01, 0.44415100E+01, -.71256200E+00, -.89087900E+01, -.13641900E+01, -.27717300E+01, -.13873400E+01, 0.11304600E+01, -.15504300E+01, 0.66082700E+00, 0.30099800E+01, 0.14514100E+00, -.11381700E+01, -.12854400E+01, 0.27513000E+01, -.84483100E+00, -.28977100E+00, 0.76491000E+00, 0.18251400E+01, 0.91110700E+00, -.84935600E+00, -.12211600E+01, -.31938800E+01, 0.11880200E+01, 0.38099500E+00, 0.80736100E+00, -.96311400E+00, 0.13968000E+01, 0.98365500E+00, -.33262900E+00, 0.63274300E+00, -.48146700E+00, 0.68673100E+00, 0.24193900E+00, -.14149200E+01, 0.12911200E+01, -.58501800E+00, -.81303400E-01, -.80170700E+00, -.11214100E+01, 0.98208100E+00, 0.87827700E+00, 0.89600400E-02, -.22408800E+00, -.32862000E+00, -.68060200E+00, -.15349200E+01, 0.16787200E+01, 0.32367400E+00, 0.15651200E+00, -.51412400E+00, 0.64273600E-01, -.10253600E+01, 0.48608000E+00, 0.43778900E+00, -.11932900E+01, 0.15254600E+00, 0.24795300E+00, 0.10849000E+01, -.12840900E+01, -.10172100E+01, 0.14848300E+00, -.40190800E+00, -.11232000E+00, 0.98916200E+00, -.39650200E+00, -.48674500E+00, 0.68207400E+00, 0.10980700E+01, 0.15991800E+01, 0.10380800E+01, 0.55980600E+00, 0.11223600E+01, 0.25222600E+01, 0.32360500E+01, -.34024900E+00, -.18061800E-01, 0.98723400E-02, -.19836000E+01, 0.57888100E+00, -.12050800E+00, 0.28465700E+01, 0.44839700E-01, -.67059400E+00, -.15855200E+01, -.89336100E-01, -.29028400E+00, 0.70452600E+00, -.24081700E+00, 0.14519400E+01, 0.26111500E+00, 0.59485100E-01, -.67589300E-03, -.49872400E+00, 0.27692600E+00, 0.15990600E+01, 0.42657000E-01, -.86073900E+00, 0.21588200E+01, -.97792100E-01, 0.11041900E+01, 0.22800900E+01, -.39454700E+00, 0.53393900E+00, -.10458500E+01, -.12680000E+00, -.70322600E+00, -.21287900E+02, 0.20862700E+01, 0.92262800E+00, 0.28046000E+03, -.14056000E+03, -.13643800E+03, -.38173800E+02, -.11408600E+02, -.13764000E+03, -.49074900E+02, -.29674300E+02, -.41385300E+02, -.84845700E+01, 0.17610500E+01, 0.27552900E+01, -.19206400E+01, -.22389400E+01, 0.11921500E+02, 0.14208800E+02, 0.38018000E+02, 0.85892300E+01, 0.54196000E+03, -.26842900E+03, -.26634800E+03, -.92807600E+02, -.14595900E+03, -.83584800E+02, 0.88893700E+02, -.12379300E+02, -.17333700E+03, 0.75975000E+02, -.66622300E+02, -.22526600E+02, -.16522000E+02, 0.90607000E+02, -.91397100E+02, -.28410300E+02, -.13266900E+03, 0.46899900E+02, 0.62848700E+01, 0.80641700E+01, 0.13713000E+02, 0.44230500E+01, -.40609800E+01, 0.32403600E+01, -.38173500E+01, -.56695700E+01, 0.14261600E+02, 0.21149500E+02, 0.79460700E+00, 0.18350400E+02, 0.11340800E+02, -.41966200E+01, 0.12546000E+02, -.73368800E+01, -.69774800E+01, 0.18849500E+01, 0.14864500E+02, 0.37047400E+00, -.30371500E+01, 0.60480400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23453100E+02, 0.12286500E+02, 0.22957200E+02, 0.17022200E+03, -.30354300E+02, -.34110200E+01, 0.14213800E+02, 0.97888600E+01, -.47796500E+02, 0.11580900E+02, -.11313300E+02, 0.44587900E+01, 0.25595400E+02, 0.94529500E+01, -.24751800E+01, 0.12588800E+02, 0.22797500E+02, 0.12188900E+02, 0.49185100E+01, -.12431300E+02, 0.17633700E+01, 0.34121500E+02, 0.74704300E+02, -.42887900E+01, 0.11977000E+02, 0.14930400E+01, 0.34121400E+02, -.92795700E+01, -.72402800E+02, -.85300900E+01, 0.98275700E+01, -.18265600E+02, -.46669500E+00, -.33321900E+02, 0.59838000E+01, -.20559100E+02, 0.42323600E+01, 0.29008100E+01, 0.41600500E+01, -.25791800E+00, -.99530600E+00, -.57239400E+01, 0.47120500E+01, 0.43140600E+00, 0.90039100E+01, -.14161400E+01, -.11929800E+02, 0.11073400E+01, -.54436700E+01, -.57348400E+00, 0.38120800E+01, -.28783700E+01, 0.19126900E+01, -.71244700E+00, -.94258100E+00, -.92696600E+01, 0.15846200E+02, -.13506600E+02, 0.34004300E+01, 0.15930500E+01, -.11070700E+01, -.57999400E+00, -.10032400E+02, -.13915500E+01, -.11162700E+01, 0.89944300E+01, 0.14528600E+01, 0.11917000E+01, -.37609500E+01, 0.57098200E+01, -.60047500E+00, -.62647700E+01, 0.31417900E+01, -.43896100E+00, -.44738600E+01, 0.46219500E+01, -.39171500E+01, -.67844500E+01, 0.97739400E+01, -.26695400E+01, 0.51686500E+00, 0.84596500E+00, 0.50341000E+00, 0.15569200E+01, 0.25206100E+01, -.10522100E+02, -.13581500E+01, 0.75509400E-01, -.61232000E+00, 0.28933400E+00, 0.27503400E+01, 0.64136100E+00, 0.10345900E+01, -.47194400E+00, -.34488400E+00, -.56393200E+01, 0.36060300E+00, 0.10674300E+01, -.29714800E+01, -.25774700E+01, 0.75086600E+00, 0.92172300E+00, -.81312500E+00, -.10233500E+01, -.92731500E+00, -.30962700E+00, 0.73119700E+00, -.93394100E+00, -.57305100E+00, 0.22909200E+00, 0.64076100E+00, 0.71327200E+00, -.21086100E+00, 0.41532800E+00, 0.27085900E+01, 0.47724700E+01, 0.11062400E+00, 0.16321200E+01, 0.50264200E+00, -.86958800E+00, 0.22502900E+01, -.12561100E+02, -.65964800E+00, 0.34876500E+00, -.22508200E+01, 0.47607400E-01, -.16563000E+01, -.46653400E+00, -.95450400E+00, 0.25506900E+00, -.36699200E+00, -.33757600E+00, -.28485100E+01, 0.11223700E+01, -.13030200E+01, -.35684200E-01, 0.11353100E+00, -.17109800E+00, 0.15368400E+01, 0.20339400E+00, -.98997600E+00, 0.64165300E+01, -.37843300E+00, -.14831700E+01, 0.61220700E+00, -.22539800E-01, -.72524900E+00, -.70304400E+00, 0.26156400E+00, 0.35439800E-01, -.13070000E+01, 0.24516800E+00, -.14661300E+01, 0.52729800E+00, 0.64269400E+01, 0.12432600E+02, 0.27575200E+02, -.22227000E+02, 0.58637200E+02, 0.50640600E+02, -.53115800E+01, -.37528600E+02, 0.14674900E+02, -.69743500E+01, -.94758800E+01, 0.14962900E+01, -.24611300E+01, -.52289300E+01, -.10211100E+01, -.13445500E+02, -.42602900E+01, -.92501700E+02, 0.45407700E+02, 0.36061500E+02, 0.38543700E+02, 0.42962200E+02, -.85561300E+01, -.41204900E+02, -.41075200E+02, 0.49702100E+02, 0.58031300E+01, 0.20833000E+01, -.31045100E+02, -.10346000E+02, -.47061300E+02, 0.33804300E+02, 0.25202100E+02, 0.35510300E+02, -.16790100E+00, 0.30798600E+01, -.24256200E+00, -.44718200E+01, -.22413800E+01, 0.29600100E+01, -.25033500E+01, -.48979600E+00, 0.44414200E+01, -.44055300E+00, 0.87397900E+00, 0.19460200E+01, -.25351200E+01, -.28480600E+01, 0.14233300E+02, -.34251900E+00, 0.41282100E+01, 0.34430400E+01, 0.13101400E+02, -.12337500E+02, 0.32312600E+00, -.72927200E+01, -.40329300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20680400E+02, 0.80913000E+01, 0.20640300E+02, 0.14683800E+03, -.23223200E+02, -.20830500E+01, 0.11921400E+02, 0.10338400E+02, -.45005200E+02, 0.96301100E+01, -.14150900E+02, 0.49355100E+01, 0.25705400E+02, 0.69380700E+01, -.12303700E+00, 0.12311800E+02, 0.18155200E+02, 0.72324100E+01, 0.50912200E+01, -.96827100E+01, 0.22415600E+01, 0.24746800E+02, 0.36964900E+02, -.48147100E+01, 0.58886700E+01, 0.48715400E+01, 0.62543000E+02, -.98022300E+01, -.74352400E+02, 0.20953800E+01, 0.36944700E+01, -.72875700E+01, 0.36348800E+01, -.17711000E+02, -.15851100E+00, -.89314700E+01, 0.93749900E+00, 0.12721500E+01, -.16591300E+01, -.75000100E+00, 0.12107700E+01, -.85742100E+01, 0.39638500E+01, 0.26153000E+01, -.21323100E+01, -.92817800E+00, 0.17130000E+02, -.55596000E+01, 0.23030600E+01, 0.36403400E+00, 0.79416400E+00, 0.63588800E+00, -.17674900E+01, 0.66315500E+01, -.24649200E+01, -.20722200E+01, 0.21267900E+01, 0.31525300E+01, -.63225400E+00, -.26509600E+00, 0.13900200E+01, 0.47595700E+01, 0.27392000E+00, 0.10462300E+00, -.29109100E+01, 0.24921300E+01, -.13035700E+01, 0.25332800E+00, 0.53034000E+01, 0.16800800E+01, 0.14373300E+01, -.21859400E+01, 0.95360800E+00, -.16075600E+01, -.54736100E-01, 0.13426000E+01, -.62243600E+00, -.70558700E+00, 0.87578800E+01, 0.91110500E+00, 0.34107500E+00, -.12228500E+01, -.17873200E+01, 0.86723300E+00, 0.11061600E+00, -.46984400E+01, -.44206500E+00, 0.27680900E+00, 0.11797000E+01, -.56054900E+00, 0.30774800E+00, -.45856200E+00, -.50265600E+00, -.77454700E+00, 0.56261300E+00, -.19601400E+02, 0.30962000E+00, 0.14898400E+00, 0.38817300E+01, -.26145200E+01, 0.19236100E+00, 0.43146700E+00, -.35302700E+01, -.13988200E+01, 0.11041100E+00, 0.90904600E-01, 0.53594400E+00, -.57598700E+00, -.22079600E+01, -.12213700E+00, 0.88461100E+00, 0.99727800E+00, 0.16408500E+00, 0.21596200E+01, 0.73437600E+00, 0.56510400E+00, -.46419000E+01, 0.80103800E+00, -.27611600E+00, -.27726600E+01, 0.16056600E+01, 0.49554900E+01, -.10750400E+01, 0.14530600E+01, -.13896700E+01, -.49926100E-01, -.14949900E+01, -.22790900E+01, -.60615600E+00, -.62083500E+00, -.29076400E+00, -.43459200E+01, 0.16606100E+01, -.13864800E+01, -.89252200E+00, -.28128900E+01, -.41969600E+01, -.43847200E+00, -.33093500E+01, -.25551500E+00, -.42627100E+00, -.23966800E+01, 0.37022300E-02, -.15781300E+01, -.11327200E+01, -.55234900E-02, 0.52168500E+00, 0.13416800E+01, 0.73583100E+00, -.75405900E-01, 0.91072500E+01, 0.22622400E+01, 0.27474400E+01, 0.39421200E-01, 0.11438800E+00, 0.34680100E+02, 0.46703100E+02, -.25253600E+02, 0.71130200E+02, -.49445800E+02, -.38584500E+03, -.63238000E+02, 0.38822800E+00, -.56609800E+01, -.11901400E+02, -.17313900E+02, -.97045400E+01, -.17837800E+02, 0.81093600E+01, -.77815200E+02, -.37280000E+02, 0.57394700E+03, -.27675400E+03, -.27140200E+03, -.72897400E+02, -.12968000E+03, -.93462000E+02, 0.12025300E+03, 0.56852200E+02, -.10806200E+03, 0.19497100E+03, -.85902100E+02, -.18731800E+03, -.55730000E+02, -.44338800E+02, 0.57010100E+02, 0.75232400E+02, 0.30127200E+01, -.78953300E+02, -.47199600E+01, -.60684300E+01, -.10186700E+02, -.15814900E+02, 0.75976200E+01, 0.81454700E+00, 0.12948300E+00, 0.92165900E+01, -.64619100E+01, 0.10169700E+02, 0.13490400E+02, 0.20337600E+02, -.73199300E+01, 0.78310200E+00, -.13311700E+02, 0.72336200E+01, 0.20826000E+02, 0.21263200E+02, -.75029000E+01, 0.55277700E+01, 0.99870800E+01, -.65754300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.89271400E+01, -.45837500E+01, -.14897400E+02, -.61302300E+02, 0.74810100E+01, 0.16043000E+01, -.43339500E+01, -.33391000E+01, 0.20024400E+02, -.39450000E+01, 0.65062100E+01, -.22210200E+01, -.11893400E+02, -.50386700E+01, 0.23166800E+00, -.73910600E+01, -.10407500E+02, -.62795700E+01, -.23542200E+01, 0.42637400E+01, -.47320200E+00, -.14032700E+02, -.34199400E+02, 0.11243900E+01, -.39377900E+01, 0.25640700E+01, -.15399000E+02, 0.35986900E+01, 0.27261900E+02, 0.41397400E+01, -.47326200E+01, 0.78874800E+01, 0.13415800E-01, 0.13264000E+02, -.41536300E+01, 0.89588400E+01, -.20128700E+01, -.11002600E+01, -.21711400E+01, 0.58494500E+00, 0.14248600E+01, 0.32079800E+01, -.93407400E+00, 0.94519100E-02, -.28659500E+01, 0.84671400E+00, 0.77595300E+01, -.36354000E+00, 0.11230800E+01, 0.99215700E+00, 0.11187500E+00, 0.50537100E+01, 0.63993600E+00, 0.76459900E+00, 0.12471600E+01, 0.14052200E+01, -.77747300E+00, 0.12304700E+01, -.57377300E+00, -.35873800E+01, 0.89022600E+00, 0.28961500E+01, 0.26913700E+01, 0.13451200E+01, 0.34317300E+00, 0.81363100E+00, -.37280200E+00, -.45617000E+00, 0.23992500E+00, -.74555600E+00, 0.57899300E+00, 0.79928900E+00, 0.15693500E+00, -.97762000E+00, 0.19286900E+01, -.49807600E+00, 0.17984500E+01, 0.22543900E+01, 0.43901700E+01, 0.86812700E+00, 0.10599000E-01, -.20123200E+01, -.23457400E+00, -.66473600E+00, -.57498300E+00, -.23812200E+00, 0.50834100E+00, 0.25925600E+00, 0.23399500E+01, -.43639200E+01, -.22548300E+00, -.20149900E+00, -.41119000E+00, -.10022200E+00, 0.45393400E+00, -.96588000E+01, -.94024300E+00, -.69135700E+00, 0.15558200E+01, 0.64587700E-01, -.45244200E+00, 0.19495300E+00, -.10756800E+01, 0.37776200E+00, 0.33467100E-01, 0.14753100E+00, -.19422900E+00, -.10887900E+01, -.40553200E+00, -.40176900E+00, -.41126500E+00, 0.67458900E+00, -.87760800E+00, 0.23200800E+00, 0.33167200E+00, 0.60110600E+00, -.13139400E+01, -.30572400E+01, 0.64819500E-01, 0.94671000E+00, 0.40169700E+00, -.30107800E+01, 0.30103000E+01, 0.11736300E+01, 0.14121200E+01, -.34859600E+00, -.18277000E-01, 0.74536100E+00, 0.21860800E-01, 0.51939300E+00, -.66030200E+00, 0.10319300E+01, -.96648700E+00, -.53558300E+00, 0.31032800E+00, -.84955900E+00, 0.10364000E+00, -.66419100E-01, 0.34031500E+00, -.29684800E+00, -.45759500E-01, 0.17715700E+00, -.10301100E+00, 0.15581200E+01, -.11810700E+00, 0.63666700E-01, -.73505000E+00, -.11082000E+01, -.65429300E+00, -.70300900E+00, -.17709300E+01, 0.41381000E+00, -.64974400E+00, 0.40901600E+00, 0.60206400E-01, -.15665300E+00, -.39488400E+02, -.96325700E+02, 0.84709700E+02, 0.95969700E+02, 0.75691600E+02, -.98669100E+02, 0.22044400E+02, -.11161100E+02, -.14160300E+02, 0.38897700E+01, 0.92003800E+00, -.11765500E+02, -.19842900E+02, -.54266400E+02, -.10546800E+02, -.35511700E+03, 0.17365200E+03, 0.15970100E+03, 0.65233200E+02, 0.11308900E+03, 0.57889600E+02, -.60127000E+02, -.38913100E+01, 0.12750500E+03, -.33888900E+02, 0.38082600E+02, 0.46077400E+01, 0.14857400E+02, -.13478200E+02, 0.56092400E+02, 0.71716700E+02, 0.60279500E+02, 0.80748400E+01, -.26997900E+01, -.15855000E+01, -.13026000E+02, -.47732900E+01, 0.92851000E+01, -.17666000E+01, 0.99265500E+00, 0.15254400E+01, -.46015200E+01, -.70621600E+01, 0.74640300E+01, -.94815900E+01, 0.75194100E+00, 0.17350900E+02, -.13944300E+02, 0.45910700E+01, 0.49500600E+01, 0.13567400E+02, -.17072800E+02, 0.26368200E+01, -.11729600E+02, -.79967400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10039500E+02, -.61656900E+01, -.10843700E+02, -.65275400E+02, 0.76710500E+01, 0.89921000E-01, -.48174000E+01, -.56182000E+01, 0.21951700E+02, -.50261200E+01, 0.81822900E+01, -.29008800E+01, -.11800300E+02, -.51139400E+01, 0.13228000E+01, -.68344200E+01, -.11492200E+02, -.50274000E+01, -.28893400E+01, 0.64984500E+01, -.17345600E+01, -.17628300E+02, -.25055900E+02, 0.22803800E+01, -.64318700E+01, -.92312800E+00, -.17464500E+02, 0.47745200E+01, 0.36576400E+02, 0.13795500E+01, -.31012200E+01, 0.75062400E+01, -.83116900E+00, 0.10121100E+02, -.15002500E+01, 0.54914200E+01, -.10633300E+01, -.47903800E+00, -.20908800E+00, 0.22150300E+00, -.99563700E+00, 0.35867700E+01, -.18436000E+01, -.11484400E+01, 0.14728200E+01, -.74154800E+00, -.46125800E+01, 0.25662600E+01, -.49088500E+00, -.24874500E+00, 0.26321000E+00, -.42812900E+01, 0.15500900E+01, -.37581000E+01, 0.20275200E+01, -.12878700E+01, 0.18711400E+01, -.10839100E+01, 0.21092500E+00, 0.78163600E+00, -.61766900E+00, 0.98823700E+00, 0.59848800E+00, -.95225600E-01, -.17445500E+00, -.37577100E+00, -.12089500E+01, 0.18482400E+00, 0.17746500E+01, -.15126300E+01, 0.10528000E+00, 0.34342000E+01, -.25679800E+01, 0.71276700E+00, -.43950900E-01, -.17953700E+00, 0.12394400E+01, -.48610100E+00, -.51339800E+01, 0.13701000E+00, 0.30324200E+00, 0.61378600E-01, -.87814800E+00, 0.74482800E+00, 0.14715200E+01, -.45357800E+01, -.21144900E+00, -.25057600E-01, 0.11797300E+01, -.13172100E+01, -.98823800E+00, 0.91528600E+00, -.31734300E-01, -.16676900E+00, -.88597100E-01, -.76218000E+01, -.32093500E+00, 0.61067900E+00, -.81288500E+00, -.26852600E+01, 0.62310100E+00, -.23325100E+00, -.45595400E+00, -.21102400E+00, -.85356100E+00, 0.60087300E-01, -.51550200E+00, -.10023500E+01, 0.89271600E+00, 0.12417400E+01, 0.33274100E+00, 0.63008000E+00, 0.88960800E+00, 0.68541900E+00, -.15977700E+01, -.16521700E+00, 0.41615100E+00, 0.15050800E+01, -.42119200E+00, -.49507600E+00, 0.55275500E+00, 0.30048400E+01, 0.13333200E+00, 0.29767300E+00, -.17013500E+01, -.74538600E-01, 0.81377400E+00, 0.64586800E-01, 0.71250200E+00, 0.37956800E+00, 0.17541400E+01, 0.23483800E+01, 0.97870800E+00, -.19459200E+00, -.12030200E+00, -.70585700E+00, -.13939300E+01, -.48949900E-01, 0.38027300E+00, -.17597700E+00, -.20283300E+00, -.12647700E+01, -.21459500E-01, 0.19042300E+01, 0.72985000E+00, 0.10018800E+00, 0.63462000E+00, -.16922600E+01, -.22556000E+00, -.15262300E+01, -.31719500E+01, 0.17268200E+01, -.12780900E+01, -.19664700E+00, -.48558200E-01, 0.20050800E+00, 0.94683600E+00, 0.80365500E+02, -.68454800E+02, -.62486000E+02, 0.28588600E+02, 0.84216400E+02, -.19114000E+02, 0.95574300E+01, 0.14222800E+02, 0.25760700E+01, -.16004800E+01, 0.16945300E+02, 0.15458400E+02, 0.58936500E+02, 0.16402100E+02, 0.39713300E+03, -.19348500E+03, -.18027300E+03, -.56069300E+02, -.10801500E+03, -.84919100E+02, 0.49508600E+02, -.41871000E+02, -.12790000E+03, -.60620300E+02, -.60889600E+00, 0.53673300E+02, 0.72813500E+01, 0.17515300E+02, -.47961200E+02, -.65992900E+02, -.62208800E+02, 0.26927300E+02, 0.24824400E+01, 0.73156400E+01, 0.16511200E+02, 0.73625300E+01, -.87713700E+01, 0.38180000E+01, -.11687000E+01, -.65393900E+01, 0.94657300E+01, 0.72952600E+01, -.74187600E+01, 0.57347100E+01, 0.35870500E+01, -.13243700E+02, 0.16329600E+02, -.76980000E+01, -.87742800E+01, -.83003600E+01, 0.13228700E+02, -.28847000E+01, 0.13197800E+02, 0.52904300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.50649300E+01, 0.26872400E+01, 0.40050100E+01, 0.45662000E+02, -.53337300E+01, -.31593200E+00, 0.33215200E+01, 0.16093100E+01, -.11693500E+02, 0.31147100E+01, -.30149400E+01, 0.81962200E+00, 0.73214400E+01, 0.26283400E+01, -.14738900E+01, 0.43288500E+01, 0.66351800E+01, 0.47781200E+01, 0.88970200E+00, -.27003600E+01, 0.58017000E+00, 0.72485900E+01, 0.19420400E+02, -.15197800E+01, 0.23871200E+01, 0.37177700E+00, 0.12190700E+02, -.19653200E+01, -.10264100E+02, 0.42937200E+00, 0.17350000E+01, -.21576100E+01, 0.15654100E+01, -.50082700E+01, 0.11611400E+01, -.24139600E+01, 0.13627100E+01, 0.38180400E+00, 0.14756600E+01, -.68353300E-01, -.90700600E+00, -.10415100E+01, 0.10522800E+01, -.25317700E+01, -.19437500E+01, -.52850400E-01, 0.16969600E+01, 0.20720000E+00, 0.17230600E+00, 0.43621200E+00, 0.29105900E+00, -.46450900E+00, -.85846200E+00, -.28418100E+00, -.13975400E+00, 0.12926700E+01, -.91226000E+00, -.83729300E+00, -.31094100E+00, -.26960000E+00, -.36759700E+00, 0.46078800E+00, 0.98765900E+00, 0.33426600E+00, -.13890800E+00, -.56274900E+00, -.31965700E+00, -.22956500E+00, -.42596900E+00, 0.30534000E+00, 0.14016600E+00, -.83938800E-01, 0.31076200E+00, -.29846400E+00, 0.37956000E-01, 0.63535700E+00, 0.23667100E+00, -.17698600E+00, -.61455800E+00, -.59488900E+00, 0.16316300E+00, 0.87266800E+00, 0.20901800E+01, 0.38658100E+00, 0.18947300E+01, -.99469700E+00, 0.18496000E+00, 0.30459800E+00, 0.41568700E+00, 0.18582800E+01, -.14121800E+01, -.17278500E+00, 0.18750400E+00, 0.43307000E+00, -.12189100E+00, 0.14533600E+02, -.64694000E+00, 0.27366300E-01, 0.18057300E+01, 0.30184600E+00, -.48843500E-01, 0.41848700E+00, 0.11992100E+01, 0.54402000E+00, 0.33672900E+00, -.48620900E+00, -.57619200E+00, -.40831700E+00, 0.82022600E+00, 0.32384200E+00, -.23923600E+00, -.49657700E+00, 0.49047900E+00, 0.14473500E+00, -.23650000E+01, -.13308300E+00, 0.91840400E+00, 0.26351400E+00, 0.53479000E-01, 0.41229400E+00, -.64306400E+00, 0.74054900E+00, 0.97814400E+00, -.38828700E+00, -.13177700E+01, -.90890100E-03, 0.34872500E+00, 0.15873000E+00, -.15479600E+00, 0.71305200E-01, -.37489200E+00, 0.28736200E+00, -.28810500E+00, 0.21246600E+00, 0.21735300E+00, -.23238500E+00, -.20599700E+00, -.39077600E-01, 0.11353100E+01, 0.22784700E-01, 0.11987300E+00, -.12416300E+00, -.17425900E-01, 0.44731800E+00, -.27686300E+00, -.38444400E-01, -.59587200E-01, -.11998600E+01, 0.14760300E+00, -.56345500E+00, 0.46752600E+01, -.79046000E+00, -.11434400E+01, -.35972400E+00, 0.17990700E-01, -.81136300E-02, -.43703800E+00, -.44442400E+00, -.12546100E+02, 0.16029700E+02, 0.54016400E+02, -.65336100E+01, 0.35414500E+01, -.21491900E+01, -.25515000E+01, 0.87029100E+01, 0.15263200E+01, 0.19267500E+01, -.60290600E+01, 0.15323700E+02, 0.99965000E+01, -.49929500E+02, 0.24658800E+02, 0.22931800E+02, -.11884900E+01, 0.37565900E+01, 0.41021000E+01, -.28175100E+02, -.13836100E+02, 0.90199300E+01, -.83490400E+02, 0.36063200E+02, 0.57686200E+02, 0.10263800E+02, -.15963300E+02, 0.20639600E+02, 0.18858000E+02, -.39797300E+01, 0.91973400E+01, 0.19719200E+00, 0.48501900E+01, -.21803000E+01, 0.39122400E+01, -.32287700E+01, 0.73196800E+00, -.13760600E+00, -.36876100E+01, 0.14269900E+01, -.40015400E+01, -.22007900E+01, -.72303200E+01, 0.19922700E+01, 0.77925700E+01, 0.92200300E+00, -.11288500E+01, -.60308800E+01, 0.41633600E+01, -.29025500E+01, -.94295300E+00, -.48129100E+01, -.41507300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.29439600E+01, 0.15826800E+01, 0.19392400E+01, 0.36320300E+02, -.41499900E+01, -.19454400E+00, 0.27508400E+01, 0.10137200E+00, -.88809900E+01, 0.22687900E+01, -.18495200E+01, 0.27050000E+00, 0.27227300E+01, 0.16081700E+01, -.10335300E+01, 0.29830300E+01, 0.40053600E+01, 0.32709400E+01, 0.10640200E+01, -.16762600E+01, 0.43879500E+00, 0.37760000E+01, 0.85724400E+01, -.11371800E+01, 0.98098700E+00, 0.60966000E+00, 0.91728400E+01, -.12283000E+01, -.85772300E+01, -.63202400E-01, 0.11083700E+01, -.87771600E+00, 0.56548000E+00, -.18510800E+01, 0.12676700E+00, -.24812700E+01, -.30077100E+00, 0.25017100E+00, 0.49011100E+00, 0.15252800E-02, -.92046800E-01, 0.77548300E-01, 0.30802200E+00, -.23541800E+00, 0.23697800E+01, -.87534000E+00, -.10842900E+02, 0.50793400E+00, -.14771300E+01, -.50231000E+00, 0.63153300E+00, 0.75332500E+00, 0.86732000E+00, -.29121700E+01, 0.11583300E+01, -.96995100E+00, 0.11645000E+01, -.27864700E+01, 0.85594000E+00, -.34078100E+00, -.60808800E+00, -.76776500E+00, -.89913900E+00, -.75208400E+00, 0.63674800E+00, 0.25676500E+01, -.91590200E+00, -.32902100E+00, 0.15949000E+01, 0.10842100E+01, 0.88591700E-01, -.52377000E+00, 0.42582000E+00, -.47043200E+00, 0.17595000E-01, 0.14772500E+00, -.53024400E+00, 0.31387200E+00, 0.15746800E+01, 0.62778900E+00, 0.59773000E-01, 0.18354900E+00, -.32735000E+00, -.10052800E-01, 0.41584600E-01, 0.13898500E+00, -.75283200E-01, 0.38760600E+00, -.81224600E+00, -.27835100E+01, -.37546400E-01, 0.46484200E+00, 0.12122700E+00, -.66457200E+00, 0.36578500E+00, 0.42689200E+01, -.50690500E-02, 0.25117400E+00, 0.19784600E+01, -.54017500E+00, -.80249000E-01, 0.42930600E+00, -.10096800E+01, -.56099600E+00, 0.57975100E+00, -.12235700E+00, -.31780900E+00, 0.92345200E+00, 0.74006800E+00, -.45719300E+00, 0.18535100E+00, -.16897400E+00, -.18426500E+00, 0.36855500E+00, -.88084900E+00, 0.75380700E+00, 0.18966200E-01, -.86212000E-01, 0.25469600E-01, -.10650400E+00, 0.25532100E+00, 0.56277900E+00, -.12330800E+01, -.45100300E+00, -.55279200E+00, 0.61690700E-01, 0.32347400E+00, 0.30526000E+00, -.17866700E+00, -.16857300E+00, -.65638400E+00, -.80757000E+00, -.34226000E+00, -.12939400E+00, 0.32291400E+00, 0.59469700E-01, 0.37833800E+00, -.28642300E-01, -.57250500E+00, -.63630100E-01, 0.22921100E+00, -.15415800E+01, 0.38219700E-01, -.12898100E+00, -.48867900E-01, 0.43761300E-01, -.14953000E+00, -.78967900E-01, -.35804900E+00, -.41902400E+00, 0.44740600E+01, -.16859500E+00, -.15177100E+01, -.38073700E+00, -.37563700E-01, 0.18347900E+00, -.21230000E+00, -.19720400E+00, 0.48724800E+00, 0.29147200E+02, 0.34123700E+02, 0.98870600E+01, 0.22314600E+01, -.86813800E-01, 0.26328200E+00, 0.32726600E+01, 0.22335200E+01, 0.22205900E+01, -.31644100E+01, 0.12048400E+02, 0.34973900E+01, -.61079600E+02, 0.29274200E+02, 0.23610200E+02, 0.81637100E+01, 0.15500700E+02, 0.12395700E+02, -.56717600E+01, -.12103800E+02, 0.81862800E+01, -.66578900E+02, 0.26121500E+02, 0.36520400E+02, -.16461800E+00, 0.10008400E+02, 0.71528300E+01, 0.89889500E+01, 0.12491400E+02, 0.29779700E+02, 0.96746600E+00, 0.22790200E+01, -.66583400E+00, 0.25006500E+01, -.83386600E-01, 0.10323900E+01, 0.13444900E-01, -.14015800E+01, 0.19660100E+01, 0.10794500E-01, 0.90136700E+00, -.14237100E+01, 0.95840800E+00, -.12062200E+01, 0.26373600E+01, -.27730900E+01, -.16072800E+01, -.10070500E+02, 0.36570200E+00, -.28300500E+00, -.28196200E+01, 0.22710800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.95964100E+01, 0.63960000E+01, 0.10769600E+02, 0.66404700E+02, -.84515400E+01, -.36511200E+00, 0.51211900E+01, 0.43198200E+01, -.21088300E+02, 0.54047600E+01, -.59992300E+01, 0.22648900E+01, 0.75829800E+01, 0.62454800E+01, -.90106000E+00, 0.86232300E+01, 0.11260600E+02, 0.55765000E+01, 0.29918800E+01, -.47332500E+01, 0.12786800E+01, 0.10497100E+02, 0.20671500E+02, -.29146100E+01, 0.31763100E+01, 0.94022000E+00, 0.25775800E+02, -.58157400E+01, -.30049800E+02, -.80586100E+00, 0.17062400E+01, -.36260400E+01, 0.21417800E+01, -.10945100E+02, 0.28655100E+00, -.68714700E+01, 0.76273100E+00, 0.55894600E+00, -.13490100E+01, 0.22557300E+00, 0.21371700E+01, -.60833000E+01, 0.30153600E+01, -.39544000E+01, 0.35389500E+01, 0.29446300E+00, -.44753400E+01, -.10242700E+01, -.11713800E+01, 0.12943900E+01, 0.10408600E+01, -.29514400E+01, -.12378400E+01, 0.24241700E+01, -.26454000E+00, -.11727700E+01, -.75952300E+00, 0.39938300E+00, -.89010500E+00, -.25211800E+01, 0.63058300E+00, 0.31100900E+01, -.40228900E+00, 0.11362100E+00, -.12161300E+01, -.30923600E+01, 0.42664000E+00, 0.68859500E+00, -.28476200E+00, 0.65219800E+00, 0.10774500E+01, -.10796500E+01, 0.12839400E+01, -.83304500E+00, 0.92196100E+00, 0.11159500E+01, -.13012900E+00, 0.42840200E+00, 0.77566900E+01, 0.25824800E+00, -.28278400E+00, -.10781300E+01, 0.12872800E+01, -.31765200E+00, -.10250700E+01, 0.10215800E+01, 0.26412400E+00, 0.72418400E+00, 0.96402500E+00, -.16593600E+01, 0.12536100E+01, -.73131100E-01, -.40022400E-01, 0.10320600E-01, -.36093100E+00, -.15553000E+01, -.29717400E+00, -.62492900E+00, 0.41916700E-01, 0.68618100E+00, -.12052400E-01, 0.67055900E+00, -.77588500E+00, -.10416900E+01, -.48296500E+00, -.28086100E+00, 0.12322800E+00, 0.13066700E+01, -.13042300E+00, -.14014400E+01, 0.24260000E+00, 0.55751100E+00, 0.20903700E+00, 0.10059700E+01, -.17064600E+01, 0.25866100E+01, 0.82883900E+00, 0.65580300E+00, 0.33790800E+00, -.12193300E+00, 0.36330100E+00, -.27378000E+01, 0.80456200E+00, 0.26052100E+00, 0.18360500E+01, 0.46122200E-01, -.15616400E+01, 0.86803800E+00, -.25194500E+00, 0.27026300E+00, -.14430200E+00, 0.17373000E+01, -.60608700E+00, 0.88388400E+00, -.17392500E-01, 0.52560500E+00, -.35504000E+00, -.23738500E-02, -.33111900E+00, -.29549200E+00, 0.12033300E+00, -.12985100E+01, 0.88737100E-01, 0.14965600E+01, 0.80698800E+00, 0.36173200E+00, -.90207600E+00, -.28530700E+01, 0.26400500E+00, -.13925500E+01, 0.13441900E+02, -.27269700E-01, -.35392700E+01, -.40401200E+00, -.29821100E-01, 0.22578000E+00, -.11200700E-01, -.27737300E+00, -.70260300E+00, 0.11193700E+01, 0.13376700E+03, -.12963000E+02, 0.81569000E+01, -.44668100E+01, -.37363200E+01, 0.14226400E+02, 0.17528600E+01, -.31653500E+01, -.10385100E+02, -.78464800E+01, 0.13664600E+02, -.54062100E+02, 0.29164300E+02, 0.27941700E+02, -.27552100E+01, -.21396700E+01, 0.10135200E+02, -.19548200E+02, -.30410000E+02, -.61665800E+01, -.13282400E+02, 0.65898400E+01, 0.47752100E+02, 0.36267400E+02, -.16111300E+02, -.15007100E+02, -.39436400E+02, -.46999300E+02, 0.44677600E+02, 0.43249100E+01, 0.25230900E+01, 0.76574100E-01, 0.22804200E+01, 0.18201700E+01, 0.51648700E+00, -.11635300E+01, -.55272300E+01, 0.50994600E+01, -.70029200E+01, 0.14277800E+01, -.12384100E+02, 0.33900600E+01, 0.32677600E+01, 0.55444800E-01, 0.47434600E+00, -.50631100E+01, 0.21402500E+02, -.71204200E+01, -.10411300E+01, -.52485500E+01, -.49092000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20215800E+02, 0.95165400E+01, 0.21259100E+02, 0.13512300E+03, -.17802200E+02, -.92893700E+00, 0.94218300E+01, 0.11030900E+02, -.44070200E+02, 0.93746800E+01, -.15407800E+02, 0.51651000E+01, 0.28471700E+02, 0.90915200E+01, -.94211000E+00, 0.10694900E+02, 0.22206000E+02, 0.77624400E+01, 0.49355100E+01, -.96768100E+01, 0.17502800E+01, 0.31765400E+02, 0.55953100E+02, -.54711900E+01, 0.11315200E+02, 0.56041600E+00, 0.33053300E+02, -.10433200E+02, -.73203100E+02, -.50787900E+01, 0.57749300E+01, -.15164900E+02, 0.19513200E+01, -.17065200E+02, 0.33941600E+01, -.11565000E+02, 0.29336300E+01, 0.16614100E+01, 0.12503500E+01, -.14898500E+01, -.70691200E+00, -.58096300E+01, 0.29301200E+01, 0.29634500E+01, -.24573800E+01, -.11730900E+01, 0.13863900E+02, -.43879500E+01, -.87260400E+00, -.48058000E+00, -.30873200E+00, 0.33817900E+01, 0.25786100E+00, 0.32881000E+01, -.13077200E+00, -.52191000E+00, -.14044300E+01, 0.49885300E+01, -.48121800E+00, 0.17667400E+01, 0.34879000E-03, -.13370800E+01, -.56248200E+01, -.32667100E+01, -.27903100E+00, -.70255900E-01, -.30771600E+00, -.45356700E+00, 0.52441000E+01, -.66144700E+00, 0.29247100E+00, -.26977300E+01, 0.61871100E+00, 0.16398200E+00, -.20107400E+01, 0.81307200E+00, -.31054000E+01, -.41099100E+01, -.23193700E+01, -.23928600E+01, -.38904700E-01, 0.46967000E+01, 0.24109400E+01, 0.15768400E+01, 0.21217100E+01, 0.35888700E+01, 0.32944400E+00, -.13333700E+00, -.57353800E+01, 0.34978500E+01, 0.14295400E+01, 0.10356700E+00, 0.65198500E+00, -.31849800E+00, 0.10977500E+01, 0.24186800E+02, 0.20813900E+00, 0.90963900E+00, 0.22402200E+01, 0.24133900E+01, -.70700200E+00, -.16612900E+00, 0.16673800E+01, 0.57548100E+00, 0.28444100E+00, -.30732400E+00, 0.13730000E+01, 0.38123900E+01, 0.11629900E+01, -.89743600E-01, 0.97109100E+00, -.21931200E+01, -.24310200E+00, 0.57407700E+00, -.19719200E+01, 0.28315200E+01, -.99755300E+00, 0.19356700E+01, 0.87130400E-01, -.14757300E+01, 0.15029300E+01, -.49290000E+01, 0.18133900E+00, -.83543500E-02, 0.67991400E+01, 0.55729600E+00, -.11306400E+01, 0.10633900E+01, 0.82604800E+00, -.74356300E+00, 0.19690200E+01, -.32738800E+01, 0.12442300E+01, 0.63666400E+00, -.18069000E+01, 0.13648200E+01, -.37537200E+01, -.92680500E+00, -.38589200E+00, 0.97514700E+00, -.13311700E+01, 0.58797900E+01, -.60530500E+00, 0.18322300E+01, 0.36809300E+01, -.27881400E+00, -.15922600E+01, -.37840700E+01, 0.15469800E+01, -.17721300E+01, -.84667300E+01, 0.22355800E+01, -.66735600E+01, 0.69000400E-01, 0.46276400E-01, 0.72355200E+00, 0.45072200E+00, 0.18713900E+01, -.33823600E+01, 0.43262400E+01, 0.12385300E+01, -.12698000E+03, -.10177800E+02, -.33813000E+01, -.47392700E+01, 0.12614000E+02, -.28633900E+01, -.50598100E+00, 0.27640200E+01, 0.79202400E+02, 0.15109200E+02, 0.29398100E+03, -.13958500E+03, -.15882900E+03, 0.21904800E+02, -.54044500E+02, -.10522400E+03, -.12928500E+03, -.19147400E+03, -.43459300E+02, 0.24286100E+03, -.14596100E+03, -.11677100E+03, -.10767700E+03, -.62162500E+02, -.91597100E+02, -.30845100E+02, -.19369000E+03, -.68257700E+02, -.45565800E+01, 0.69794200E+00, 0.70405700E+01, 0.12997400E+02, -.21572800E+02, -.75174000E+01, -.19708300E+00, 0.16171500E+00, 0.11619500E+02, 0.35533200E+02, -.22239600E+02, 0.17031400E+02, 0.15373200E+02, 0.46621900E+02, 0.19660500E+02, 0.14981200E+02, -.18141500E+02, 0.28640500E+02, -.23139500E+02, 0.12442100E+01, -.25651700E+02, 0.18483300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.71252500E+01, -.31817700E+01, -.11488100E+02, -.51608200E+02, 0.47464300E+01, 0.13986900E+01, -.39444600E+01, -.30817800E+01, 0.17579100E+02, -.31317300E+01, 0.70519100E+01, -.26814900E+01, -.78651500E+01, -.34476900E+01, 0.30824700E+00, -.66084800E+01, -.69153600E+01, -.41257800E+01, -.27069800E+01, 0.39668200E+01, -.71680700E+00, -.12919300E+02, -.20132100E+02, 0.95878600E+00, -.40936800E+01, -.31084200E+00, -.10790000E+02, 0.27834500E+01, 0.24797200E+02, 0.13571600E+01, -.24144800E+01, 0.58921800E+01, -.84413400E+00, 0.71939300E+01, -.13082600E+01, 0.58895900E+01, 0.90440800E-01, -.61503400E+00, -.11446000E+00, 0.49345400E+00, 0.45886300E+00, 0.31424000E+01, -.13792500E+01, -.19567100E+01, -.80355000E+00, 0.12853600E+01, 0.59422400E+01, 0.14993000E+01, -.37857800E+00, 0.16256500E+01, -.43985300E+00, 0.26985500E+01, -.49130400E+00, -.10140300E+01, -.36537200E-01, 0.93297900E+00, 0.23693200E+00, -.21154500E+01, 0.73335900E-01, -.88810200E+00, -.43820900E+00, 0.57148800E+00, 0.11957700E+01, 0.47980400E+00, 0.51327400E-01, 0.13794000E+01, 0.15516500E+00, -.48912200E+00, 0.67051800E+00, -.10125500E+01, 0.25585200E+00, 0.13012600E+01, -.79637300E+00, 0.15901100E-01, 0.86055100E+00, -.98121200E+00, 0.12419100E+01, 0.54213400E+00, -.29570900E+01, 0.32170100E+00, 0.20768900E+00, 0.61763200E+00, 0.23004400E+00, -.49047700E+00, -.11974100E+01, 0.46141000E+01, 0.45159900E+00, 0.20200200E+00, -.75821100E+00, -.66342500E+00, 0.57655800E+00, -.29132400E-01, -.28255100E+00, 0.25078900E+00, 0.42249500E+00, -.31540600E+01, -.12603800E+00, -.34899300E+00, -.27786500E+01, 0.15777300E+01, -.51984200E+00, -.10606300E+01, -.82107900E-01, 0.18244900E+00, -.63903200E+00, 0.65827400E+00, 0.43357600E+00, -.78958300E+00, -.59614400E+00, -.41814800E-01, -.67968300E-01, 0.52558500E+00, -.11163100E+01, 0.48667700E+00, -.18894900E+01, 0.18258400E+00, -.15210600E+01, -.26558800E+01, 0.30914500E+00, 0.41819100E+00, -.26982900E+00, 0.20086700E+01, 0.27651000E+01, 0.95890500E+00, -.30785200E+01, -.25474400E+00, 0.26872300E+00, 0.10605700E+01, -.11450100E-01, 0.28405000E+00, 0.73276600E+00, 0.14606800E+01, -.14069900E+01, 0.10418700E+01, -.65495800E+00, 0.46215100E+00, 0.97865700E+00, 0.64096000E-01, 0.60390800E+00, 0.22960700E-01, -.11366900E+00, 0.73796800E+00, -.10584300E+00, -.48755900E+00, 0.14468500E+01, 0.15335700E+00, 0.10777000E+00, -.20585100E+01, 0.62456600E+00, -.80251700E+00, 0.13474700E+01, -.21719300E+00, -.48339500E+00, -.36619800E-01, 0.90755700E-01, -.37172700E-01, 0.19306300E+00, 0.26158000E+00, -.12363900E+00, -.52227900E-01, -.18694800E-01, 0.47297600E-01, -.13659100E+02, 0.73842400E+01, 0.40657600E+01, 0.48578400E+00, 0.22098900E+01, -.61974600E-01, 0.31394500E+01, 0.54421000E+00, -.13862000E+01, -.74328300E+02, 0.38181300E+02, 0.30574500E+02, 0.10219200E+02, -.18592400E+01, 0.32273800E+02, -.16573000E+02, -.85121200E+01, -.68788800E+01, 0.84670400E+02, -.42467300E+02, -.48394600E+02, -.40102600E+01, -.26945100E+02, -.26153600E+02, -.41819100E+02, -.51634300E+02, -.27548900E+02, -.18394900E+01, -.37083800E+01, -.15534000E+01, -.77741600E+00, -.15215500E+01, 0.11323000E+00, 0.73460900E+00, -.71189700E+00, -.69479900E-01, -.24842000E+01, 0.59210900E-01, -.20552500E+01, -.54078600E+00, -.42724500E+01, -.50785900E+00, 0.36324400E+01, 0.32082800E+00, 0.68026200E+00, 0.13586500E+01, 0.89811900E+00, -.69669300E+01, 0.84622700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18431700E+02, 0.77536400E+01, 0.15770000E+02, 0.13424800E+03, -.20196200E+02, -.17914400E+01, 0.11247200E+02, 0.84440200E+01, -.39982400E+02, 0.87326200E+01, -.12283200E+02, 0.39621400E+01, 0.23277000E+02, 0.76492300E+01, -.14208700E+00, 0.12281600E+02, 0.17995900E+02, 0.74075700E+01, 0.44283400E+01, -.82211400E+01, 0.19498600E+01, 0.21638300E+02, 0.36981800E+02, -.48717500E+01, 0.55633600E+01, 0.41114700E+01, 0.57503600E+02, -.80733200E+01, -.62362900E+02, 0.20155400E+01, 0.36892500E+01, -.63063300E+01, 0.38982500E+01, -.13862900E+02, 0.50570800E+00, -.81852800E+01, 0.13119000E+01, 0.95516400E+00, -.58859600E+00, -.88922500E+00, 0.81688500E+00, -.60219500E+01, 0.27984900E+01, 0.38952900E+01, -.37737600E+01, -.14539000E-01, 0.26598600E+02, -.54307300E+01, 0.18467800E+01, -.13027000E+00, 0.46918100E+00, 0.22142400E+01, 0.10043200E-01, 0.73839400E+01, -.21741500E+01, -.27579200E+01, 0.32864100E+01, 0.23210700E+01, -.99638200E-01, -.11714900E+00, 0.12144400E+01, 0.25765100E+01, -.12080100E+01, 0.53240700E-01, -.17902200E+01, 0.23835900E+01, 0.36157900E+00, -.36761500E+00, 0.13181300E+01, 0.83519400E+00, 0.36285500E+00, -.26662400E+01, 0.20444800E+01, -.52023200E+00, -.10026900E+01, 0.20629600E+01, -.14881500E+01, -.22608000E+01, 0.65337700E+01, -.47062000E+00, 0.14976400E+00, -.13674000E+00, -.14863600E+01, 0.16987400E+01, 0.25838500E+01, -.83205900E+01, -.60151300E+00, -.28958900E+00, -.61269700E+00, 0.10848100E+01, 0.55650500E+00, 0.11900900E-01, 0.45068600E-01, -.74649700E+00, 0.37015600E+00, -.39074400E+01, 0.58048900E-01, 0.44993200E+00, 0.33483600E+01, -.45530900E+00, 0.12615700E+00, 0.78982100E+00, -.90727400E+00, 0.60133600E-01, 0.79753100E+00, -.40265700E+00, -.53732000E-01, 0.98724900E-01, -.80082800E+00, 0.65889700E+00, 0.79745000E+00, 0.72747800E-01, 0.10290100E+01, 0.65695300E-01, 0.40971300E+01, 0.96895000E+00, -.98159000E+00, 0.30211300E+01, -.24369400E+00, -.12194300E+01, 0.77336400E+00, -.50346700E+01, -.16375500E+01, -.23652400E+00, 0.15317700E+01, 0.18010600E+00, -.42665500E+00, -.14189400E+01, -.26761000E+00, 0.32280300E+00, -.45121600E-01, 0.59973700E+00, -.80392400E+00, -.11104400E+01, -.82723400E-01, -.12279800E+01, -.20749000E+01, -.16767000E+00, 0.25038600E+00, -.12575100E+00, -.74665500E+00, 0.27238700E+01, -.24798400E+00, -.19733000E+00, -.81562100E+00, 0.93647900E-01, -.82344600E+00, -.10025000E+01, 0.64240200E+00, 0.38723200E+00, 0.10839600E+02, 0.21735900E+01, -.73724700E-01, 0.71102400E-01, 0.78477100E-01, 0.44912700E+00, 0.59770800E+00, 0.60346900E+00, -.90114600E+00, 0.77298300E+00, 0.33917700E-01, 0.20856700E+00, -.24665600E+01, 0.86337600E+01, -.12057100E+00, -.49655100E+01, 0.19123200E+01, -.20583900E+01, 0.83690100E+01, 0.41173500E+01, -.23424900E+01, -.12642000E+03, 0.66690200E+02, 0.49452900E+02, 0.10282600E+02, -.20499000E+02, 0.67889900E+02, -.23362000E+02, 0.41564700E+00, -.29832700E+02, 0.22998200E+03, -.11499100E+03, -.12637000E+03, 0.27293400E+00, -.71634700E+02, -.71732900E+02, -.12588200E+03, -.12657500E+03, -.62309300E+02, 0.36621700E+01, -.83374100E+01, -.19003700E+01, -.44704000E+01, 0.13349900E+01, -.28033200E-01, -.11353100E+00, -.15739500E+01, -.24030800E+01, -.85763600E+01, 0.52949300E+01, -.70382400E+01, -.57620500E+01, -.14671000E+02, 0.88802600E+00, 0.71607500E+01, 0.63279200E+01, 0.53459400E+01, 0.52358000E+01, -.34920700E+00, -.10737000E+02, 0.53800100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10209200E+02, -.39895700E+01, -.15559400E+02, -.70106400E+02, 0.91703600E+01, 0.16529600E+01, -.54389500E+01, -.47505100E+01, 0.23828800E+02, -.44752800E+01, 0.78801000E+01, -.27988200E+01, -.12010900E+02, -.45878900E+01, -.14691300E+00, -.75340500E+01, -.93862200E+01, -.42669400E+01, -.30645900E+01, 0.51168400E+01, -.61186100E+00, -.15136900E+02, -.29003500E+02, 0.15738400E+01, -.47702500E+01, -.89196100E+00, -.22193500E+02, 0.48124800E+01, 0.38268900E+02, 0.27264600E+01, -.26643500E+01, 0.70921600E+01, -.12150200E+01, 0.11555500E+02, -.14807400E+01, 0.10501600E+02, 0.15098200E+01, -.98711100E+00, -.18470400E+01, 0.57813000E+00, 0.15848400E+01, 0.55336800E+01, -.18980200E+01, -.84374600E+00, -.12842800E+01, 0.11646300E+01, 0.58165300E+01, 0.25385600E+01, 0.32347000E-01, 0.12196300E+01, -.20742300E+00, 0.23863100E+01, -.82353100E+00, -.43977200E+00, -.11515200E+01, 0.64336800E+00, -.11606500E+00, -.12443600E+01, 0.34186200E+00, -.16460000E+01, 0.50889600E+00, -.15969500E+01, 0.77464700E-01, 0.29354400E+00, 0.31538200E-01, -.51080000E+00, 0.24936300E+00, -.70111500E+00, -.26863400E+01, 0.83534100E+00, -.31698000E+00, -.48142900E-02, -.58648300E+00, 0.11984900E+00, 0.61214600E+00, -.20001600E+00, 0.28501500E+00, 0.21852300E+00, -.48391300E+01, -.42389300E+00, -.10401800E+00, 0.47168100E+00, 0.14338800E+01, -.36711000E+00, -.60533300E+00, 0.35450400E+01, 0.67403600E+00, 0.38399100E+00, -.76429900E-01, -.60047700E+00, 0.57773400E+00, -.16453300E+00, 0.13425700E+00, 0.76609300E+00, 0.10161500E+00, 0.91440500E+01, -.94695100E+00, -.81875600E+00, -.15012400E-01, 0.14897800E+01, -.70745900E+00, 0.23599700E+00, 0.18960400E+01, 0.75929000E+00, -.11383500E+01, 0.26535700E+00, 0.86792600E+00, 0.19290700E+01, 0.94286300E+00, 0.41240800E+00, 0.50937400E+00, -.37719700E+00, -.12810200E+01, -.10683800E+01, -.74592400E+00, 0.17357800E+01, 0.71441500E+00, -.23725200E+01, 0.56648200E+00, 0.12018400E+01, -.13200700E+00, -.39321200E+01, 0.21291700E+01, 0.16989100E+00, 0.57133500E+00, -.47864000E-01, -.49339500E-01, 0.17922700E+01, 0.33424700E+00, 0.92336500E-01, 0.79612400E+00, 0.21450300E+01, -.16318900E+01, 0.13402200E+01, -.44789800E+00, 0.18617600E+01, 0.13364600E+01, 0.25519600E+00, -.57103900E+00, -.82033800E-01, -.53189400E+00, 0.11516300E+01, -.13559900E+00, -.72895400E+00, 0.23240300E+00, 0.23138300E+00, 0.39346700E+00, 0.12523800E+00, 0.28737500E+00, -.52436800E+00, -.88602100E+01, 0.12810400E+01, -.25762000E+00, -.32960800E+00, -.54341200E-01, 0.40791000E-01, -.13053000E+00, 0.68844800E+00, -.12953700E+01, 0.44189700E+00, -.29657300E-01, 0.21013600E+00, -.11376700E+00, 0.11180400E+00, -.46590000E+01, 0.54022400E+01, 0.37529700E+01, -.11338800E+01, -.36205800E+01, -.23749500E+02, -.99072600E+00, -.59394600E+02, 0.30132800E+02, 0.19216000E+02, 0.13318700E+02, 0.67927600E+01, 0.17332500E+02, -.18125900E+02, 0.18485600E+01, 0.27590300E+01, -.37836500E+02, 0.18085800E+02, 0.25978100E+02, 0.33022500E+01, 0.10192400E+02, 0.93681400E+01, 0.30970300E+02, -.14539200E+02, 0.16320000E+02, 0.11538100E-01, 0.54625500E+01, 0.24871300E+00, -.19829900E+01, 0.35108500E+01, 0.33416200E+01, -.91465000E+00, -.41834400E+01, 0.43290000E+01, -.17136900E+01, 0.62083900E+01, -.26796200E+01, 0.53008600E+01, -.31802600E+00, -.24353000E+00, -.14295000E+01, -.10249100E+01, -.34571500E+01, 0.58556600E+00, 0.31733700E+01, -.71392000E+01, -.25751700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.38546800E+01, -.23278600E+01, -.27749700E+01, -.33183900E+02, 0.60316800E+01, 0.75771200E+00, -.28196400E+01, -.11615500E+01, 0.80609000E+01, -.19643400E+01, 0.17755100E+01, -.18359500E+00, -.43681500E+01, -.14709900E+01, 0.81894500E-01, -.19920600E+01, -.35901400E+01, -.13474300E+01, -.47644900E+00, 0.11946700E+01, -.44053300E+00, -.26249200E+01, -.75916700E+01, 0.12986000E+01, -.14591100E+00, 0.14905300E+00, -.13621000E+02, 0.20417300E+01, 0.10932600E+02, -.12544700E+01, -.94876300E+00, 0.15112700E+00, -.88511000E+00, 0.50613500E+01, -.24729100E+00, 0.10511200E+00, -.20209900E+01, -.24283400E+00, 0.50386200E+00, -.44197100E+00, -.10735100E+01, 0.59384300E+00, 0.39285700E-01, 0.56846900E+00, 0.91452300E+00, -.58773900E+00, -.12033300E+02, 0.22155300E+00, -.32600900E+00, -.87722800E+00, 0.47608300E-01, -.19579100E+00, 0.14472300E+01, -.35395600E+01, 0.25641900E+01, 0.57860100E+00, -.14204700E+01, 0.31922800E+00, -.23324900E+00, -.27799900E+00, -.44693700E+00, 0.44818000E+00, 0.35859000E+00, -.63475600E+00, 0.58336000E+00, -.14193200E+01, -.11067900E+01, 0.10981600E+00, 0.13992900E+01, -.58548600E+00, 0.81044900E-01, 0.52542900E+00, -.26997200E-02, -.16928700E+00, 0.49128700E+00, -.77743500E+00, 0.39321800E+00, 0.86152600E+00, -.76423000E+00, 0.62640100E-01, -.49710900E-01, 0.31290100E+00, 0.34404900E+00, 0.38162300E-01, 0.73159900E+00, -.84568500E+00, 0.13008200E+00, 0.69606200E-01, 0.21251900E-01, -.19466100E+01, 0.24275900E-02, 0.23442100E+00, 0.83262100E-02, -.37177500E+00, 0.22776300E+00, 0.36254200E+01, -.18813000E+00, 0.11172300E+00, 0.63440300E+00, 0.38532200E+00, -.98919800E-01, 0.51240000E-01, 0.13434600E-01, 0.19706700E+00, 0.31426000E+00, -.66190900E-01, -.14218500E+00, -.36184300E+00, -.16894800E+00, 0.16288700E+00, -.22132100E+00, 0.56909700E-01, -.42876300E+00, -.88086200E-01, 0.71774300E+00, 0.23281600E+00, -.45022500E+00, -.13981900E+01, -.44085800E-01, 0.49119600E+00, 0.72578900E-01, 0.13503200E+01, -.30203000E+00, 0.57050900E-01, 0.95032700E+00, -.43295900E-01, -.70944000E-02, 0.11506500E+00, 0.62999500E-02, -.15871000E+00, -.34392200E+00, -.26903900E+00, 0.38632300E+00, -.56004700E-01, 0.12136900E+00, -.77883500E-01, 0.22768500E+00, 0.64789100E-01, -.10496400E+01, -.18772000E+00, 0.49720600E-01, -.19769700E+01, 0.83341900E-01, 0.50227900E-01, 0.88195400E-01, 0.30750400E-01, 0.48621400E+00, 0.66677400E+00, -.30211200E+00, -.49217100E+00, -.10323700E+01, 0.54483800E+00, -.29694700E+00, -.26827500E-01, -.38030100E-01, 0.12470800E+00, 0.18736500E+00, 0.16138400E+00, -.12209500E-01, -.37929100E+00, 0.67966800E-01, -.13944500E+00, 0.15659300E+00, 0.68543900E-01, -.10134000E+00, 0.47841600E+01, 0.24892700E+01, -.16882900E+01, -.44529700E+01, -.19468400E+01, 0.15886800E+01, -.39641300E+02, 0.20008900E+02, 0.14156000E+02, 0.19452500E+02, 0.17966600E+02, -.14665700E+00, -.19628600E+02, -.26166200E+02, 0.17881700E+02, -.67882500E+02, 0.29538100E+02, 0.34216500E+02, -.22136100E+02, 0.58735600E+01, 0.24740700E+02, 0.35764500E+02, 0.28591400E+02, 0.14240000E+02, -.14732300E+01, 0.72665000E+00, -.33512900E+01, 0.12708200E+01, -.14671500E+01, 0.54508900E+00, 0.52043900E+00, -.16842000E+00, 0.26856700E+01, 0.23207500E+01, -.14749800E+01, 0.16221300E+01, 0.32464100E+01, 0.21748000E+01, -.32219400E+01, 0.82288700E+00, -.23774600E+01, -.11929300E+02, -.19082400E+01, 0.91915900E+00, -.12990600E+01, 0.27063900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.71354600E+00, 0.62134700E+00, 0.45914500E+00, 0.61852800E+01, -.12416800E+01, -.11905400E+00, 0.63549500E+00, 0.11752200E+00, -.14920600E+01, 0.38381600E+00, -.27685000E+00, 0.37754000E-01, 0.66014900E+00, 0.13549900E+00, -.10188500E+00, 0.85121300E+00, 0.67109200E+00, 0.58428100E+00, 0.24126400E+00, -.42396600E+00, 0.78959300E-01, 0.96062600E+00, 0.18092200E+01, -.18980200E-01, 0.33278400E+00, 0.11312900E+00, 0.52437200E+00, 0.15072700E-01, -.32710000E+00, -.10305700E+00, 0.31665300E+00, -.37307800E+00, -.19863000E-01, -.64493000E+00, 0.31009800E+00, -.52907500E+00, 0.92688700E-01, 0.20329200E-01, 0.22947200E+00, -.47496800E-01, -.77497200E-01, -.32203200E+00, 0.20436500E+00, 0.11553300E+00, -.80485200E-01, -.56332400E-01, -.25932200E+00, -.33671800E-01, 0.87176500E-01, -.13658000E+00, 0.31881100E-01, -.90479100E-01, -.15885200E+00, 0.92042600E-01, -.32529800E+00, 0.20918700E-01, 0.61331900E-01, -.15225900E-02, 0.21180600E-01, 0.22691300E+00, -.12204000E-02, 0.14972400E+00, 0.10767300E+00, -.12675000E+00, -.17338400E+00, -.17637200E+00, -.92039400E-01, 0.24985300E-01, 0.20963800E-01, 0.22170900E+00, -.46382600E-02, -.15797300E+00, 0.16124200E+00, -.52227100E-02, 0.22735000E-01, 0.17196800E+00, -.12900200E-01, -.38903400E-01, 0.96303300E-01, -.35721700E-01, -.50431500E-02, 0.16935600E-01, 0.17462500E-01, 0.87748000E-01, 0.17563900E+00, -.57360500E+00, -.49973300E-01, -.33600300E-01, -.49290100E-01, 0.31304400E+00, 0.26048900E-01, -.54772900E-01, 0.21800600E-01, -.22124700E-02, -.41738400E-02, 0.60899600E+00, -.21133000E-01, -.14551900E-01, 0.19914300E+00, 0.17056000E+00, -.18459600E-01, 0.45293900E-01, 0.82540300E-01, 0.31728800E-01, 0.32445000E-01, -.42186600E-01, 0.11204900E-02, 0.15978500E+00, -.82185300E-01, -.61804600E-02, 0.12695000E-03, -.45144100E-01, 0.21796900E-01, -.83330800E-01, 0.20295800E+00, 0.55948600E-01, 0.99378300E-01, 0.34011000E-01, -.29211300E-02, 0.36159000E-01, -.19877400E-01, -.34502400E+00, 0.52729400E-02, 0.31945300E-01, 0.43467700E+00, 0.34186700E-02, -.20354800E-01, -.46702500E-01, 0.26024600E-01, -.59857600E-02, -.26803100E-01, -.18836000E+00, 0.73014500E-01, 0.75663000E-02, 0.33648500E-01, 0.48227100E-01, 0.12512100E+00, 0.79238100E-02, 0.14782600E+00, 0.24298600E-01, -.53321500E-01, 0.43229800E+00, -.11104300E-01, 0.44235600E-01, -.11222700E+00, -.27116300E-01, -.27058500E-02, 0.83280000E-01, -.81804000E-02, 0.77833900E-01, -.13320800E+01, -.58679500E-01, 0.24785700E+00, 0.65723400E-01, 0.62493700E-02, -.37004100E-01, -.15008600E-01, -.45633800E-01, 0.15552900E-01, -.35847700E-01, -.14516800E-01, 0.14153200E-01, -.45884600E-01, -.53482400E-02, -.21646400E-02, -.86077300E-01, 0.42875300E+00, -.15558300E+00, 0.45604100E+00, -.27227500E+01, -.10816800E+00, 0.68221300E+01, -.34355400E+01, -.27599000E+01, 0.37145900E+00, -.17066000E+01, -.18899300E+01, 0.71599100E+00, -.68995900E+00, -.12434100E+01, 0.52966900E+01, -.22471100E+01, -.28594100E+01, 0.15781700E+01, -.16132600E+01, -.17194000E+01, -.20035100E+01, -.80944200E+00, -.31030300E+01, -.49829700E-01, 0.50866700E+00, 0.29022000E+00, -.37768100E+00, 0.10332100E+00, 0.51513600E+00, -.71157200E-01, -.36405700E+00, -.10372100E+00, -.43855000E+00, 0.66794600E-02, -.98375700E-01, -.82564300E-01, -.10301400E+01, -.55879000E-01, -.21810100E+00, 0.18429700E+00, 0.56484700E+00, 0.57081900E+00, 0.10444100E+00, 0.12625900E+01, -.34027300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.40207700E+01, -.13887200E+01, -.57301200E+01, -.22466400E+02, 0.22419500E+01, 0.10564400E+01, -.20665800E+00, -.26858600E+01, 0.66823500E+01, -.13561300E+01, 0.30195400E+01, -.17543900E+01, -.27646100E+01, -.27667800E+01, 0.13085600E-01, -.69164800E+00, -.33905600E+01, -.55406300E+00, -.90182000E+00, 0.15556300E+01, -.49237300E+00, -.42798000E+01, -.53884600E+01, 0.14364100E+01, -.11172300E+01, -.10259900E+01, -.14664400E+02, 0.28348300E+01, 0.19336200E+02, -.48633900E+00, 0.33241700E+00, 0.11016600E+01, -.11512200E+01, 0.13038700E+01, 0.13734300E+01, 0.16103400E+01, 0.10699100E+01, -.23734100E+00, 0.14230600E+01, 0.20632500E+00, -.71142800E+00, 0.93488300E+00, -.11551400E+00, -.15283100E+01, -.88854500E-01, -.18711500E+00, -.52178800E+01, 0.16577200E+01, -.51141900E+00, -.75216400E+00, -.33601400E-01, -.13288900E+01, -.41857000E+00, -.19406600E+01, -.38112500E+00, 0.83738200E+00, -.58041600E+00, -.39871200E-01, 0.59023900E-01, 0.14803500E+01, -.64658000E+00, -.61367900E-01, 0.74184800E+00, -.62223300E+00, -.70612700E+00, -.28026800E+01, -.95495600E+00, 0.12042800E+00, 0.12169200E+01, 0.29948000E+00, 0.14922300E+00, 0.32195800E+00, -.41230400E+00, 0.16460400E+00, 0.40320200E+00, 0.39919800E+00, 0.19467800E+00, -.68325600E-01, -.29503200E+01, -.25993100E+00, -.48685500E-01, 0.67345000E+00, 0.90664800E+00, 0.51723500E-01, 0.23548300E+00, -.78005100E+00, 0.22129500E+00, 0.27294800E+00, 0.55703200E+00, 0.83808500E+00, -.56584400E+00, -.38917600E-01, 0.50242500E-01, 0.22926100E+00, -.15012900E-01, 0.39258400E+01, -.24340600E+00, -.18189400E+00, 0.47869500E+00, 0.30646900E+00, -.13092800E+00, -.10815500E+00, 0.60773600E+00, 0.10663600E+00, -.32777000E+00, 0.62381700E-02, 0.47946000E-01, 0.20397700E+00, 0.26598100E+00, 0.30564000E+00, 0.19377500E+00, 0.42543300E-02, -.56576900E-01, -.24783900E-01, -.25830200E+00, 0.33364800E+00, 0.14267200E+00, -.27862300E+00, 0.11306000E+00, 0.19757000E+00, -.15502700E+00, 0.37145200E+00, -.17042700E+00, -.21373100E+00, -.17792300E+00, 0.82156800E-01, 0.35884700E-02, 0.30357500E+00, -.10991100E+00, -.18691400E-01, 0.11085500E+00, -.10057300E-01, -.65480000E-01, 0.51488100E+00, -.71147500E-01, 0.45280500E+00, -.55328700E-01, 0.19778700E-01, -.28986000E+00, -.23629500E-02, 0.40146500E-02, -.68497600E+00, 0.12911300E-01, -.25677100E+00, 0.10403400E-01, -.44373700E-01, 0.17807400E+00, 0.36683100E+00, -.10061400E+00, -.25838500E-01, -.75262100E+00, -.21531900E+00, 0.81688500E-01, -.45109000E-02, 0.82387400E-02, -.19434300E-01, -.90971000E-01, -.86298400E-01, 0.83789300E-01, -.78452300E-01, -.13441100E-01, -.27827700E-01, 0.35965200E+00, -.36351800E-01, -.19400300E+00, 0.35097200E+00, -.13137400E+01, 0.22687800E+01, 0.14048900E+01, -.11372900E+02, -.13399500E+01, 0.29855500E+02, -.14796100E+02, -.10971200E+02, -.53330600E+01, -.58367300E+01, -.74549900E+01, 0.73157200E+01, 0.74755000E+01, -.45453700E+01, -.65750100E+01, 0.56071700E+01, 0.73908200E+01, 0.91877700E+01, 0.31491200E+01, 0.51145900E+01, 0.68071300E+01, 0.34063900E+01, 0.15951400E+00, -.56891300E+00, 0.25906200E+01, 0.15465300E+01, -.11460500E+01, 0.13605900E+01, 0.14786100E+01, -.25733400E+00, -.13311100E+01, 0.24477000E+00, -.15958300E+01, 0.11296900E+01, -.99689600E+00, 0.47776700E+00, -.37933800E+00, 0.21268900E+00, -.17397700E+01, 0.22319600E+00, 0.38075500E+01, 0.76880400E+00, 0.60686200E+00, 0.21173200E+01, -.18329700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10217300E+02, -.71008400E+01, -.10788400E+02, -.68734100E+02, 0.89013100E+01, 0.26218800E+00, -.61778300E+01, -.54295200E+01, 0.22384600E+02, -.55562600E+01, 0.65466400E+01, -.28122200E+01, -.75924500E+01, -.50577100E+01, 0.13426400E+01, -.83715800E+01, -.10336300E+02, -.56416500E+01, -.32995000E+01, 0.51832200E+01, -.12293700E+01, -.11439400E+02, -.23368300E+02, 0.22648200E+01, -.28795300E+01, -.20836800E+01, -.28262900E+02, 0.42243300E+01, 0.26005300E+02, -.53833100E+00, -.14034400E+01, 0.27328300E+01, -.21580200E+01, 0.77125000E+01, -.19865800E+00, 0.65069600E+01, 0.11109300E+01, -.48190900E+00, 0.83844500E-01, 0.32432000E+00, -.43914300E+00, 0.48108600E+01, -.19009900E+01, -.88669400E+00, -.30609000E+00, 0.30550500E+00, -.32149100E+01, 0.24029200E+01, -.16119300E+01, -.11796600E+01, -.10343800E+00, 0.17079700E+01, 0.13895800E+01, -.22576800E+01, 0.64346200E+00, 0.69767600E+00, -.34099300E+00, -.35579400E+00, 0.41599000E+00, 0.41364900E+00, -.26037000E+00, -.24405700E+01, 0.49464200E+00, 0.70074500E+00, 0.35536500E+00, 0.21072300E+00, 0.37102600E+00, -.45899800E+00, -.41238300E+00, -.73046500E+00, -.26131400E+00, 0.10718200E+01, -.11521300E+01, 0.23162400E+00, 0.47594200E-01, -.14098900E+01, 0.18359900E+00, 0.39790100E+00, -.60251800E+01, -.25126200E+00, -.95266200E-01, 0.11586900E+01, 0.15726800E+01, -.22409300E+00, 0.30267900E+00, 0.33067500E+00, 0.78966900E+00, 0.46908800E+00, 0.68426600E+00, -.62390000E+00, 0.57982500E+00, 0.17782500E-01, 0.19991800E+00, 0.65975700E+00, 0.41482600E+00, 0.98187900E+01, -.75043600E+00, -.52611700E+00, 0.50832100E+00, 0.17719000E+01, -.68137700E+00, 0.16005800E+00, 0.10578300E+01, 0.56711000E+00, -.23441900E+00, 0.24512200E+00, 0.30431100E+00, 0.47839000E+00, 0.62098400E+00, 0.98074700E+00, 0.86157300E+00, 0.53835300E+00, -.74787700E+00, -.12499200E+01, 0.20643500E+01, 0.83628800E+00, 0.26039600E+00, -.17190900E+01, 0.45997700E+00, 0.13778600E+01, -.84019300E+00, -.38349300E+01, 0.37288300E-01, -.10535500E+01, -.18520100E+01, 0.11206700E+00, 0.83052800E+00, 0.11447100E+01, -.54248400E+00, 0.16661800E+00, -.55527200E+00, 0.19128200E+01, -.22831800E+01, 0.85564800E+00, 0.25273000E+00, 0.10036200E+01, -.98196700E+00, -.37947600E-01, 0.10154300E+01, 0.83736900E-01, -.63756500E+00, 0.21751100E+01, -.37188700E+00, 0.16381000E+00, -.11380000E+01, 0.11808200E+00, -.74161900E+00, 0.11401800E+00, -.25483900E-01, 0.76253900E+00, 0.27110200E-01, 0.21570100E+01, -.66075100E+00, 0.19697900E+00, 0.22315100E-01, 0.54565200E-01, 0.42100800E+00, 0.65714400E+00, -.63822700E+00, -.71898300E-01, -.35527900E+00, 0.65247100E-01, 0.54400800E-03, -.97722600E-02, 0.24789000E+00, 0.10093200E+00, 0.51534700E+01, 0.10207700E+01, -.10777700E+02, 0.15870000E+02, 0.10197400E+02, -.94014700E+02, 0.46451500E+02, 0.26439900E+02, 0.21514600E+02, 0.16270800E+02, 0.21917100E+02, -.25200900E+02, 0.18163200E+01, 0.10833900E+02, -.29002900E+02, 0.15216800E+02, 0.17619000E+02, -.28603800E+02, -.49955800E+01, 0.10172400E+02, 0.81550400E+01, -.23251300E+01, 0.34418500E+02, 0.27299800E+01, -.36443000E+01, -.64239700E+01, 0.37738600E-01, 0.39446700E+01, -.14865700E+01, 0.13633900E+01, -.14287500E+00, 0.16587000E+01, 0.33161400E+01, 0.63604500E+01, 0.18695200E+00, -.61662500E+00, 0.57910900E-01, 0.10862100E+01, 0.16565400E+01, 0.19667600E+01, -.15209700E+02, -.45679000E+01, -.42776700E+01, -.85481900E+01, 0.47640800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.99945400E+01, -.47097400E+01, -.15122300E+02, -.64736900E+02, 0.69237500E+01, 0.85170600E+00, -.45686700E+01, -.51248100E+01, 0.23587500E+02, -.44509100E+01, 0.84546100E+01, -.31816800E+01, -.13663800E+02, -.51665200E+01, 0.36774600E+00, -.55500700E+01, -.11290600E+02, -.43352500E+01, -.30434400E+01, 0.52216300E+01, -.77451900E+00, -.18559900E+02, -.32321700E+02, 0.22347400E+01, -.70067500E+01, 0.65158900E+00, -.99323000E+01, 0.52360600E+01, 0.38655100E+02, 0.48447400E+01, -.33219400E+01, 0.10219000E+02, -.26657600E+00, 0.10506700E+02, -.28107300E+01, 0.91719000E+01, -.62783700E+00, -.10598000E+01, -.17512000E+01, 0.10540100E+01, 0.16285300E+01, 0.36828100E+01, -.13804800E+01, -.14797700E+01, -.25410800E+00, 0.10141200E+01, 0.16970000E+01, 0.13640400E+01, 0.10310900E+01, 0.17208900E+01, 0.50974000E-01, 0.11267800E+01, -.10893800E+01, -.10179800E+00, -.66723000E+00, 0.14964800E+00, 0.12102500E+01, -.18398400E+01, -.16784000E+00, -.24402600E+01, 0.60390700E+00, 0.18612800E+01, 0.26016200E+01, 0.22679600E+01, -.41498600E+00, 0.16859400E+01, 0.27280800E+00, -.73938000E-01, -.17895200E+01, -.11516000E+00, -.56627400E-01, 0.10475600E+01, -.20573300E+00, -.50309900E+00, 0.14935400E+01, -.48901600E+00, 0.17082400E+01, 0.20571200E+01, 0.51048000E+00, 0.12643100E+01, 0.13335300E+00, -.20226500E+01, -.92119400E+00, -.74112000E+00, -.84181200E+00, -.28646400E+01, 0.11320700E+00, 0.55027100E+00, 0.35210100E+01, -.26608500E+01, 0.97224500E-02, 0.14540700E-01, -.39105800E+00, 0.48668500E+00, -.37156100E+00, -.15233600E+02, -.68102800E+00, -.10436300E+01, -.10279900E+00, -.12330800E+01, -.25470400E-01, 0.48402300E-01, -.88432800E+00, -.17365300E+00, -.87157000E+00, 0.43781000E+00, -.68087000E-01, -.14776900E+01, -.46027100E+00, 0.49099700E+00, -.18421500E-01, 0.11429500E+01, -.83100500E+00, -.49279000E+00, 0.93198100E+00, -.60243100E+00, -.13698200E+01, -.22747300E+01, 0.25464000E+00, 0.33923000E+00, -.28866500E+00, 0.17109300E+01, 0.35104100E+00, 0.53549200E+00, -.29985900E+01, -.21899100E+00, -.11333300E-01, 0.10432100E+01, 0.25923600E+00, 0.15712700E+00, 0.67496400E+00, 0.22112400E+01, -.11185600E+01, -.10818300E+00, -.66064900E+00, -.60476600E+00, -.32942700E-01, 0.15408500E-01, -.10882500E+01, -.36224400E+00, -.12485000E+00, -.90470300E+00, 0.60835600E-01, -.14636200E+01, -.37383600E+00, 0.35599800E+00, 0.85525300E+00, 0.34665600E-01, 0.83892700E+00, -.92771800E+00, 0.71864500E+01, 0.11200200E+01, 0.55563100E+00, -.31411100E+00, 0.16187600E-01, 0.41011000E+00, 0.62103700E+00, 0.69519900E+00, 0.50210100E+00, -.72741800E-01, -.12518500E+00, -.10700400E+00, -.38233600E-02, 0.31699800E+00, -.63879400E-01, -.70239400E+00, 0.16302600E+01, -.18320700E+01, -.17629200E+00, -.41980000E+02, -.44975000E+01, -.86776000E+02, 0.44726400E+02, 0.43378900E+02, 0.25352200E+02, 0.44860800E+02, 0.68174700E+01, -.29562100E+02, -.44310000E+02, 0.40097100E+02, -.23737000E+02, 0.19367200E+02, 0.30385200E+02, -.27460600E+02, 0.21619800E+02, 0.20960300E+02, 0.42562000E+02, 0.50148400E+02, 0.14765800E+02, -.14315600E+01, 0.17554400E+01, 0.28710200E+01, -.48894500E+01, 0.58235800E+01, 0.65515200E+00, 0.17874800E+00, 0.24141900E+00, 0.35246300E+01, 0.54936600E+01, 0.54194000E+01, 0.42883300E+01, 0.47784300E+01, 0.47509500E+01, -.22380100E+01, 0.77492200E+00, 0.12701300E+01, -.11037400E+02, 0.24046200E+01, 0.18251200E+01, -.12601400E+01, 0.39409400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.51735600E+01, 0.28539700E+01, 0.39913500E+01, 0.46047900E+02, -.89530600E+01, -.12321900E+01, 0.44051100E+01, 0.11788800E+01, -.11274600E+02, 0.27244200E+01, -.18605300E+01, 0.24986400E+00, 0.46751700E+01, 0.17986600E+01, -.33728200E+00, 0.37141700E+01, 0.42529200E+01, 0.29413600E+01, 0.12802800E+01, -.25074700E+01, 0.31654100E+00, 0.52343400E+01, 0.14990100E+02, -.95304500E+00, 0.16024000E+01, 0.92294300E+00, 0.11775600E+02, -.18632800E+01, -.11535200E+02, 0.35272500E+00, 0.18253800E+01, -.18242900E+01, 0.30620400E+00, -.75715900E+01, 0.73720700E+00, -.26751400E+01, 0.13205500E+01, 0.59040100E+00, 0.14445100E+01, 0.83608100E+00, 0.73277600E+00, -.12589900E+01, 0.22092300E+00, -.64156200E+00, 0.10267000E+00, 0.29782000E+00, 0.63354000E+01, -.33670900E+00, 0.21261700E+00, 0.64605800E+00, 0.96890100E-01, -.24666900E+01, 0.15969500E+00, 0.17872200E+01, -.36282500E+00, -.10404900E+01, 0.14123600E+01, -.16066600E+01, 0.61228500E+00, 0.22918100E+00, -.26008500E+00, -.23717300E+01, -.12328800E+01, -.30724100E+00, 0.30413300E+00, 0.14931000E+00, 0.11837600E+01, 0.26409900E-01, -.19065400E+01, 0.84707000E+00, 0.30892800E-01, -.64831200E+00, 0.16150200E+00, 0.30901600E+00, -.84068600E+00, 0.95466200E+00, -.68384900E+00, -.10471100E+01, 0.21660400E+01, -.13311700E+00, 0.30562400E-03, -.33415600E+00, -.48948200E+00, -.11123800E+00, -.51388300E+00, -.94592400E+00, -.48895800E+00, -.19010800E+00, -.53351300E+00, 0.18525100E+01, -.10635000E+00, -.72463200E-01, 0.57758500E-01, 0.20297200E+00, -.34983500E+00, -.16300100E+01, 0.39776200E+00, 0.15258100E+00, -.68390700E+00, -.14685000E+01, 0.34085700E+00, 0.81325700E-02, -.61643000E-01, -.25930100E-01, -.11509600E+00, 0.20225100E-01, -.27730200E+00, -.63664300E+00, 0.45744900E+00, -.29166500E+00, -.12413000E+00, 0.11050200E+00, 0.39944200E+00, 0.33607800E-01, 0.48997500E-01, 0.23682100E+00, 0.56516900E+00, 0.68405900E+00, 0.50503200E-01, -.27347200E-01, 0.50446000E-01, -.81509400E+00, -.37895100E+00, -.29977300E+00, -.17483200E+01, 0.94517100E-02, 0.10767800E+00, 0.41828900E-01, -.17514000E+00, 0.14431100E+00, 0.91354600E-01, 0.65965100E-01, -.37213000E+00, -.31965300E+00, -.30319100E-01, -.31182600E+00, -.38090600E+00, -.12917900E+00, 0.22731400E+00, 0.99248500E-02, 0.33120100E+00, -.79581000E-01, -.42036500E-02, 0.81602100E+00, 0.54056100E+00, 0.45093800E-01, -.59718900E+00, -.10469900E+01, -.25453100E+00, -.27008500E+00, 0.44345800E+01, -.19321000E+00, -.68006000E+00, -.17877900E+00, 0.10445600E-01, 0.21036300E-01, -.10682600E+00, -.38181000E+00, 0.71783000E+00, 0.47149200E-01, 0.19402600E+00, -.62342500E-02, -.33228800E+00, -.30204800E-01, -.43589200E-01, -.65795500E+00, 0.62435200E+01, -.11564000E+00, 0.37995500E+00, -.32877700E+00, -.47851200E+01, -.67614600E+02, 0.35088800E+02, 0.36377800E+02, 0.74522000E+01, 0.30247000E+02, 0.13656900E+02, -.75553300E+01, -.21207300E+02, 0.23553900E+02, -.92133300E+02, 0.33064800E+02, 0.38026700E+02, -.17681000E+02, 0.27716100E+02, 0.24823900E+02, 0.52076700E+02, 0.31323000E+02, 0.15934600E+02, -.74261200E+00, -.95068600E+00, 0.27570400E+01, 0.92124700E+00, -.37691900E+00, -.13467900E+01, -.24738400E+00, 0.19472400E+01, 0.20425700E+01, 0.56237100E+01, -.23261700E+00, 0.43661900E+01, 0.28856900E+01, 0.66631700E+01, -.27656900E+00, 0.95113800E+00, -.23952800E+01, -.11258400E+02, -.26010300E-01, 0.19581500E+01, -.61320700E+01, 0.17055500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21762300E+01, 0.10760800E+01, 0.80299700E+00, 0.26898700E+02, -.39061400E+01, 0.14245800E+00, 0.21351700E+01, -.35444000E+00, -.63624700E+01, 0.16406700E+01, -.10483100E+01, -.48966900E+00, 0.36730900E+01, 0.70915100E+00, 0.84239900E-01, 0.48570500E+01, 0.29707400E+01, 0.20735300E+01, 0.10200100E+01, -.77742500E+00, 0.31070700E+00, 0.22454200E+01, 0.36014700E+01, -.70503000E+00, -.32952400E-01, 0.50479800E+00, 0.60241000E+01, -.70697500E+00, -.26739400E+01, 0.11932000E+01, 0.32464900E+00, 0.40926100E-01, 0.97573600E+00, -.43642300E+00, -.12552000E+00, -.49429600E-01, 0.88636000E+00, -.66014800E-01, 0.17127300E+00, 0.96708300E-01, 0.50180400E+00, -.62443500E+00, 0.49789100E+00, -.18817800E+00, -.49951600E+00, -.44073800E+00, 0.42761200E+01, -.32594000E+00, -.64815500E-01, -.62197300E+00, 0.54090000E+00, 0.71761900E+00, -.28887000E-01, 0.15494200E+01, -.92247200E+00, 0.14007600E-01, 0.52992000E+00, 0.21858000E+01, -.34507900E-01, 0.55342100E+00, 0.51882200E+00, 0.17427600E+01, 0.94162800E+00, -.45451000E+00, -.71916300E+00, -.78374400E+00, -.64312500E+00, -.28997400E+00, 0.29796500E-01, 0.21509100E+00, 0.15644900E+00, 0.19633000E+00, -.16449000E+00, 0.24148700E+00, 0.64144900E-01, 0.50252300E+00, 0.54248600E-01, -.33764100E+00, 0.50459400E-01, -.35322900E+00, -.49498100E-01, -.81254300E-01, -.26690000E-01, 0.47451900E+00, 0.83321200E+00, -.39355000E+01, -.26187600E-01, -.20738100E-02, -.19038100E+00, 0.41958300E+00, -.16607900E+00, -.20231800E-01, -.14548900E-01, 0.72844600E-03, -.39794700E-01, -.52387600E+00, 0.14662400E+00, 0.94190700E-01, -.31618300E+00, 0.66043000E-01, 0.58529300E-01, 0.77257400E-01, -.90286500E-01, -.14968100E+00, -.12032600E+00, -.11847000E+00, -.10436200E-01, -.18589800E+00, -.26250700E+00, 0.38201200E-01, -.23764400E-01, -.11464000E+00, 0.13994200E+00, 0.75311400E-01, 0.56895000E+00, -.14887400E+00, -.13866800E+00, 0.16566400E+00, 0.28502200E-01, -.57838700E-01, 0.89128800E-01, -.20239900E+00, -.55055900E+00, -.76761500E-01, -.57393000E+00, 0.26001500E-01, 0.10694600E+00, -.14917400E+00, -.55555500E-01, -.21729400E-01, 0.89908200E-02, -.50935500E+00, -.17472600E-01, 0.57567300E-01, -.12648200E+00, 0.48543100E-01, 0.25363300E+00, -.22819100E-01, 0.37900100E-01, 0.68351500E-01, 0.20392400E-01, 0.44792800E+00, -.25383900E-01, -.34089800E+00, -.46243000E-01, 0.71241300E-02, -.15038400E+00, 0.18443900E+00, 0.17508200E+00, 0.14616500E+00, 0.12648000E+01, -.80840800E-01, 0.91062200E-01, 0.99582900E-02, 0.14662700E-01, -.51465200E-02, -.72568200E-01, -.22767400E-01, -.13141400E+00, 0.10680100E+00, 0.93700400E-02, 0.29704500E-01, -.13256900E-01, 0.12533300E-01, -.20915900E-01, -.41527000E+00, 0.14229500E+01, 0.61842900E+00, -.18002200E+00, -.24028900E+00, -.29868400E+00, -.98161400E+02, 0.49696400E+02, 0.40485700E+02, 0.24335600E+02, 0.34900600E+02, 0.14473900E+02, -.28208200E+02, -.32538800E+02, 0.29575700E+02, -.91225300E+02, 0.39403100E+02, 0.44210100E+02, -.28997300E+02, 0.10645700E+02, 0.31412700E+02, 0.48368600E+02, 0.41264200E+02, 0.21537600E+02, 0.30630300E+00, -.14298500E+01, -.13265100E+01, -.31469600E+00, 0.10853300E+01, -.63245200E+00, 0.15371600E+00, 0.66856200E+00, 0.22306500E+01, 0.40543900E+01, 0.19691700E+01, 0.20317100E+01, 0.20556700E+01, 0.48849800E+01, -.12537300E+01, 0.17362700E+01, -.82914000E+00, -.16394900E+02, -.94179800E+00, -.14371100E+00, -.64262000E+01, 0.33138600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.61442400E+01, -.27848300E+01, -.94281200E+01, -.46467400E+02, 0.50734500E+01, 0.89873000E+00, -.30511900E+01, -.15629700E+01, 0.14667100E+02, -.28522500E+01, 0.50024600E+01, -.13698800E+01, -.10314900E+02, -.31848000E+01, -.83715700E-01, -.30809000E+01, -.50136200E+01, -.15013700E+01, -.96728100E+00, 0.17380000E+01, 0.46821200E+00, -.11209900E+02, -.25505600E+02, 0.77577700E+00, -.40786100E+01, 0.18557200E+01, 0.49056300E+00, 0.48601300E+01, 0.26764100E+02, 0.39172700E+01, -.17694400E+01, 0.67545900E+01, -.38589100E+00, 0.82069200E+01, -.16351800E+01, 0.66204100E+01, -.90524900E+00, -.12713500E+01, -.13191700E+01, 0.29089300E+00, 0.19297100E+01, 0.56976900E+00, 0.19419000E+01, -.31078800E+01, -.68516200E-01, 0.17808000E+01, 0.57101600E+01, 0.48777700E+01, 0.94321300E+00, 0.14330000E+01, 0.12827800E+01, -.34635100E+01, -.20714300E+01, -.20910100E+01, -.13304800E+01, -.28531500E+00, 0.35415100E+01, -.22097200E+01, 0.19063600E+01, 0.27559400E+00, -.18116300E+00, 0.10157400E+01, 0.31655700E+01, -.32416900E+00, -.10741000E+01, -.44475800E+01, -.12755400E+01, -.13728200E+00, -.36592800E+00, 0.12212100E+01, 0.37180400E+00, -.53133000E+00, 0.45223100E+00, 0.83376300E-01, 0.12471400E+01, -.26205600E+00, 0.50754200E+00, 0.10341400E+01, 0.24534900E+00, 0.72984000E+00, -.14271300E+00, 0.28760100E-01, -.18790500E+00, -.79582600E+00, -.19755000E+01, 0.29829300E+01, 0.36044700E+00, 0.69743100E+00, -.60943100E+00, -.10229300E+01, 0.31832300E+00, 0.56752500E-01, -.21490200E+00, 0.46007000E-01, 0.72448300E+00, -.20470600E+01, -.34767400E+00, -.40757700E+00, 0.14518800E+01, 0.88318500E+00, -.63624200E+00, -.68886800E+00, -.11297100E+01, -.12406200E+00, -.42144200E-02, 0.64710200E+00, 0.22229900E+00, 0.29191100E-01, -.50356600E+00, 0.26061700E-02, 0.21678700E+00, -.34202900E+00, -.11230300E+01, 0.47295600E+00, -.15984900E+01, 0.95095900E+00, -.31531900E+01, -.26576800E+01, 0.43043100E+00, -.68264800E+00, -.13114400E+00, 0.10854700E+01, 0.17895900E+01, 0.12790200E+01, 0.22308100E+01, 0.18755900E+00, 0.47112100E+00, 0.10803700E+01, -.82311700E-01, 0.58573500E+00, -.69820100E+00, 0.30322600E+00, -.87984700E+00, 0.85145200E+00, 0.30542800E+00, 0.73407700E+00, 0.71106900E+00, 0.30085000E-01, -.18225900E+00, -.74665000E-01, 0.30771600E+00, -.23038600E+01, 0.59976200E-01, 0.56419400E-01, -.56504100E+00, 0.13823000E+00, -.17711900E+00, -.12291700E+01, 0.21566800E+00, -.51551600E+00, 0.12289200E+02, -.59452000E+00, -.17263600E+01, -.46021100E+00, -.12791800E-01, 0.16297100E+00, 0.88412000E-01, 0.38084200E-01, 0.17469500E+00, -.24480900E+00, 0.21918400E+00, -.92972500E-01, 0.62361800E+00, -.54857700E-02, -.19121100E+00, 0.64463600E+00, 0.54812500E+01, 0.16505800E+01, 0.45516000E+00, -.56807900E+00, 0.10743100E+01, 0.14060100E+00, 0.39608700E+01, 0.14315700E+02, 0.12834500E+02, -.45178900E+01, 0.50523100E+00, -.14717300E+02, 0.12864900E+02, -.70053800E+01, 0.84793700E+02, -.35193900E+02, -.26332500E+02, -.47147700E-01, -.19496400E+02, -.24517100E+02, -.37817800E+02, -.19549700E+02, -.74593000E+01, 0.72413800E+00, -.12022200E+01, -.20701100E+01, -.38629800E+00, 0.13698300E+01, -.48812700E+00, 0.28422100E+00, 0.92881600E-01, 0.12966100E+01, 0.26371000E+00, -.35889800E+00, -.13763600E+01, 0.12966700E+00, -.17554400E+01, 0.25790100E+01, 0.68378600E+00, 0.13152900E+01, 0.34380600E+01, -.18835100E+01, -.35235900E-01, -.10523500E+01, 0.79669500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.60833800E+01, 0.39758600E+01, 0.55941100E+01, 0.37820600E+02, -.38788800E+01, 0.41840700E+00, 0.35220500E+01, 0.31341800E+01, -.13539200E+02, 0.33478100E+01, -.43397500E+01, 0.15937700E+01, 0.62298100E+01, 0.37246000E+01, -.64110300E+00, 0.57949900E+01, 0.71290400E+01, 0.44449400E+01, 0.16446300E+01, -.36078500E+01, 0.98978800E+00, 0.88040000E+01, 0.14466900E+02, -.12962600E+01, 0.33307000E+01, 0.99166800E+00, 0.10963600E+02, -.17350400E+01, -.14806500E+02, -.31371100E+00, 0.16422700E+01, -.33141900E+01, 0.12711000E+01, -.44422300E+01, 0.10223600E+01, -.55171100E+01, -.30358800E+00, 0.21387800E+00, 0.11314100E+01, -.28440600E+00, -.17757400E+00, -.20187900E+01, 0.75104000E+00, 0.23032400E+01, -.73780500E+00, -.40525600E+00, 0.50903100E+01, -.18032300E+01, 0.85145500E+00, 0.13448800E-01, 0.77941400E-01, 0.16887000E+01, -.12540500E+00, 0.26075600E+01, -.85667100E+00, -.59552600E+00, 0.14423900E+01, -.26706900E+00, -.87853200E-01, -.14853700E+00, 0.21976500E+00, 0.15264000E+01, -.11566500E+01, -.47719000E+00, -.10835200E+01, 0.73390100E+00, -.24136200E+00, 0.30600100E-01, 0.78574800E+00, 0.13401600E+01, 0.21217900E+00, -.10303300E+01, 0.59239800E+00, -.36446200E+00, 0.64304100E-01, 0.97933300E+00, -.10644100E+00, -.57349700E+00, 0.25839600E+01, 0.51932500E-01, 0.10599700E+00, -.22153100E+00, -.21179900E+00, -.40328100E-01, 0.35690200E+00, -.64252200E+00, -.47200100E+00, -.42206600E+00, -.76250200E+00, 0.12739900E+01, 0.17700400E-01, -.27918200E+00, -.40962100E-01, -.20070400E+00, -.12861900E+00, -.85800700E+00, -.56676100E-01, -.38540600E-01, 0.20978800E+00, 0.79351400E+00, -.56065800E-01, 0.31496600E+00, 0.16100800E+00, 0.22527500E+00, 0.10265300E+00, -.46731500E-01, -.24619900E-01, -.13777300E+00, -.75775600E+00, -.96290900E+00, -.84789200E+00, 0.26486200E-02, -.36547800E+00, -.23339900E+00, -.40277000E+00, -.87630200E+00, 0.21077400E+00, -.27829600E+00, 0.16640100E+00, 0.72135600E-02, -.26435800E+00, -.85682100E+00, 0.69733200E+00, 0.25674800E+00, 0.23878100E+01, -.46447100E-01, -.40063900E+00, -.61514800E-01, 0.28736200E-01, 0.46396200E+00, 0.70010400E-01, 0.24022900E+00, 0.20740400E+00, 0.48570100E+00, -.46613900E+00, -.76133500E-01, 0.24139300E+00, 0.15105300E-01, 0.11425200E+00, -.74170700E-01, 0.38212200E-03, 0.13253500E-01, 0.53013200E-02, 0.54316600E+00, 0.14051400E+00, -.23804500E-01, 0.21318400E+00, 0.40304400E+00, -.29417600E+00, 0.23975600E-02, -.32892400E+01, 0.24295700E-01, 0.71609200E+00, 0.56790200E-01, 0.49697400E-02, -.28996300E-02, 0.51789200E+00, 0.46687800E+00, -.56808300E+00, 0.26118400E+00, 0.15349100E+00, 0.51932000E-01, -.61793500E-01, 0.29652500E-01, 0.25330000E+00, -.50283400E+00, 0.21021300E+01, -.14843800E+01, -.10092800E-01, 0.13501900E+00, 0.61650000E+00, -.37594500E+00, -.77683200E+00, 0.14845900E+02, 0.55001500E+01, -.19881700E+01, -.73181800E+01, -.14184100E+02, 0.22319700E+02, 0.35822600E+01, 0.53661800E+02, -.14445400E+02, -.16546700E+02, 0.23119800E+01, -.55013700E+01, -.10398300E+02, -.28049400E+02, -.14269400E+01, -.95579600E+01, -.61469200E+00, -.12025400E+01, -.25359400E+01, 0.39992900E+00, -.90273900E+00, -.16137300E+01, 0.36595300E+00, 0.14420400E+01, -.81702300E+00, -.10801500E+01, -.27187500E+01, -.11608700E+01, -.52533800E-02, -.30084400E+00, 0.56890200E+00, 0.38415700E+00, 0.26326800E+00, 0.14344800E+01, -.22079600E+01, 0.59268800E-01, 0.34073600E+01, 0.21097200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.84030100E+01, -.53259400E+01, -.80389000E+01, -.58134900E+02, 0.79073700E+01, 0.43013800E+00, -.48831100E+01, -.36961000E+01, 0.18132700E+02, -.39210700E+01, 0.67547400E+01, -.16196500E+01, -.11787500E+02, -.39783700E+01, -.21744600E+00, -.46089600E+01, -.76350100E+01, -.15348900E+01, -.17976300E+01, 0.42031400E+01, -.14411500E+01, -.14661100E+02, -.13025400E+02, 0.15138800E+01, -.41009400E+01, -.25252300E+00, -.12220100E+02, 0.51283400E+01, 0.41018100E+02, 0.13580500E+01, -.11756100E+01, 0.63317300E+01, -.11578500E+01, 0.82630800E+01, 0.99565200E+00, 0.30480400E+01, -.10344200E+01, -.45996600E+00, 0.11810800E+01, 0.11508800E-01, -.15825500E+01, 0.39060500E+01, -.13698500E+01, 0.29426400E+00, 0.64755100E+00, 0.11348600E+01, -.19812300E+01, 0.19492000E+01, 0.70274600E+00, -.18781900E+00, -.43938200E+00, -.50123800E+01, 0.13698600E+01, -.28796600E+01, 0.19589300E+01, -.71591200E+00, 0.12416000E+01, 0.15134100E+01, 0.31100200E-01, 0.18740000E+01, -.28291400E+00, 0.24417600E+01, 0.68985800E+00, -.10521000E+01, 0.21097400E+00, 0.79288800E+00, -.15662100E+01, 0.16462400E+00, 0.75307300E+00, -.56098800E+00, -.58960400E+00, 0.18917600E+01, -.10779700E+01, 0.33681500E+00, -.28763600E+00, -.16828000E+01, 0.44346800E+00, 0.10028700E+01, -.19034100E+01, 0.71715700E+00, -.34536000E-01, 0.11979400E+01, 0.54291100E+00, 0.57483700E+00, 0.10427400E+01, -.38436100E+01, 0.21574300E+00, 0.67908700E+00, -.73198500E-01, -.15364900E+01, -.11460500E+00, 0.10328000E+01, 0.18539800E+00, -.14058400E+00, -.54404800E+00, 0.62687500E+01, 0.36412600E+00, 0.86928300E+00, -.14584600E+01, -.23846600E+01, 0.69012600E+00, 0.89123000E-01, 0.39493600E+00, -.21560600E+00, -.52547900E+00, -.21392500E+00, 0.14431400E+00, 0.14353300E+01, 0.11415900E+01, 0.99199600E+00, 0.37355700E+00, -.31580500E+00, 0.85725300E+00, 0.47286000E+00, -.20580800E+01, 0.63332400E+00, 0.72537000E+00, 0.21598000E+01, -.32606100E+00, -.90351100E+00, 0.77395400E+00, 0.16390700E+01, -.52667900E+00, 0.18405400E-01, -.33937400E+01, 0.94918700E-01, -.19705700E-02, -.15338300E+01, 0.22679100E-02, 0.11309200E+00, 0.15409300E+01, -.50190000E+00, 0.37802700E+00, -.44123100E+00, -.59293400E+00, 0.19679600E+00, -.42647800E+00, 0.53278800E-01, -.92505400E+00, 0.97138000E-01, -.57539600E-01, -.19457900E+00, 0.30686800E-03, -.14367500E+01, 0.71004800E+00, -.78147400E-01, 0.33928500E+00, 0.55639700E+00, -.18448200E+00, 0.43975300E+00, 0.10518400E+01, 0.97449000E-01, -.13295800E+00, -.31867700E+00, -.24122700E-01, 0.14321800E+00, -.25336500E+00, 0.59698200E-01, -.82096100E+00, 0.14261100E+01, 0.99954700E-01, 0.21995500E+00, -.27226400E+00, 0.28321200E-01, 0.43853000E+00, -.25549900E+00, -.74179500E+01, 0.62130400E-01, -.25269900E+00, -.18608400E+00, -.72196900E+00, 0.27391600E+00, -.10286000E-01, 0.92891400E+00, -.26342600E+02, 0.12323000E+02, 0.90753200E+01, 0.28382600E+02, -.10985900E+02, 0.12995100E+02, -.95734900E+02, 0.38678200E+02, 0.37060800E+02, -.55226100E+01, 0.26043200E+02, 0.38958100E+02, 0.48340600E+02, 0.36617000E+02, 0.77300100E+01, -.94940100E+00, 0.44326600E+01, 0.56217100E+01, 0.32943400E+00, -.33718500E+00, 0.31582600E+00, -.38920800E+00, 0.57991800E+00, -.19904800E+01, -.20847900E+00, 0.10610800E+01, 0.17627700E+01, -.11618300E+01, 0.64730500E+01, -.40641900E+01, -.28539400E+01, -.10436000E+01, -.12994500E+01, 0.27461600E+01, 0.43855200E+00, -.84310400E+00, 0.17831200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23633700E+02, 0.94336400E+01, 0.21672600E+02, 0.17269000E+03, -.27167400E+02, -.29577100E+01, 0.12026400E+02, 0.10138400E+02, -.48633800E+02, 0.11362100E+02, -.13134900E+02, 0.36322600E+01, 0.28602800E+02, 0.11205400E+02, 0.19560900E+01, 0.16745100E+02, 0.21678000E+02, 0.81411500E+01, 0.54036500E+01, -.96303800E+01, 0.20874200E+01, 0.27570200E+02, 0.36162600E+02, -.60346900E+01, 0.65575900E+01, 0.27844100E+01, 0.61099600E+02, -.15864100E+02, -.10401300E+03, 0.43541200E+00, 0.20867100E+01, -.10290400E+02, 0.55428800E+01, -.21263000E+02, -.41912100E+01, -.87145400E+01, 0.30946400E+01, 0.20651000E+01, -.25937200E+01, 0.15124100E+01, 0.50582800E+01, -.10727500E+02, 0.44752700E+01, -.38848300E+01, 0.58112600E+01, -.32531900E+01, -.10296400E+01, -.50013500E+01, -.51145400E+01, -.65485400E+00, 0.33519300E+01, 0.11409500E+02, -.82070900E+00, 0.97251200E+01, -.43065500E+01, -.31251000E+01, 0.32574900E+01, 0.67232600E+00, -.16717200E+01, -.61978900E+01, 0.35129500E+01, 0.12282200E+02, 0.28119400E+01, 0.30570400E+00, -.57921300E+01, -.30785300E+00, 0.13704300E+01, -.48804100E+00, 0.20677400E+01, -.96061300E+00, 0.28127300E+01, 0.90209700E+00, -.25850000E+00, 0.11513600E+01, 0.65047400E+00, 0.48526100E+01, 0.32855700E+01, -.49895100E+01, 0.65625400E+01, -.11426400E+01, 0.80362000E+00, -.46110800E+01, -.57928300E+01, 0.31870900E+01, 0.47302000E+01, -.22591800E+02, -.13595300E+01, -.12740600E+00, 0.36005600E+01, -.46576500E+01, 0.56066700E+01, 0.12841700E+01, -.68565700E+00, -.39224300E-01, 0.17057400E+01, -.44751800E+02, -.77073000E+00, 0.87280600E-01, -.87121900E+00, -.20827700E+01, -.33027900E+00, 0.48175000E+00, -.54654700E+01, -.13277200E+01, -.20024300E+01, 0.13556300E+01, 0.10025400E+01, -.31422700E+01, -.26432800E+01, 0.54342700E+00, 0.15119400E+01, 0.42546500E+01, -.89763700E+00, -.12528800E+01, 0.85374700E+01, 0.33229300E+00, -.42399100E+01, 0.70874800E+00, 0.35940500E+00, -.79540300E+00, -.11614000E+01, -.50286300E+01, 0.24108000E+01, 0.33405600E+00, 0.15887700E+01, 0.47770300E+00, -.17105500E+01, 0.51183200E+00, -.82948700E+00, -.41885000E+00, 0.46980900E+00, 0.14117500E+01, -.36324600E+00, -.29769800E+00, -.34709300E+00, -.18659200E+01, -.66050500E+01, -.38965500E+00, -.76650900E+00, -.25386900E+00, -.45927900E+00, -.14298400E+01, -.81836900E-01, 0.86579500E+00, -.94977400E+00, -.72122700E-01, -.32265900E+00, -.16588700E+01, 0.14671500E+01, -.90319900E+00, 0.32115700E+02, -.68770100E+00, -.46608500E+01, -.12819700E+01, 0.11815000E+00, 0.59529800E+00, -.12032800E+01, -.44834900E+00, -.10638700E+01, 0.37578900E+01, 0.10196300E+01, 0.42421900E+00, -.61287000E+00, 0.47916700E+00, 0.10217800E+01, -.25812700E+01, -.19228300E+02, -.28817100E+01, -.13937900E+01, 0.16076400E+01, -.18047500E+01, -.29050000E+01, 0.18916500E+01, -.31878200E+01, -.24241200E+01, 0.12876900E+03, -.60515600E+02, 0.17327700E+02, -.86208200E+02, 0.14710500E+03, -.69231000E+03, 0.32288600E+03, 0.30689300E+03, -.13080800E+03, 0.11186300E+03, 0.32324800E+03, 0.33490500E+03, 0.33451400E+03, 0.86547900E+02, -.74764200E+01, 0.10802100E+02, 0.48454200E+01, 0.22555300E+01, -.57471000E+01, -.46646700E+01, 0.72133000E+00, 0.10967400E+02, -.43742600E+01, 0.10613200E+02, -.32932400E+01, 0.16696200E+02, 0.68622500E+00, 0.42687800E+02, -.27899800E+02, -.78070900E+01, -.72565400E+01, -.66319000E+02, -.74794800E+00, 0.39403000E+00, 0.52947200E+01, 0.18255600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.61735600E+01, -.39143800E+01, -.64611700E+01, -.46760400E+02, 0.55589100E+01, 0.32240800E+00, -.33166200E+01, -.19450700E+01, 0.13642400E+02, -.33319200E+01, 0.34006300E+01, -.16351000E+01, -.81811700E+01, -.29985900E+01, 0.70286800E+00, -.19655100E+01, -.55907600E+01, -.23020000E+01, -.10228100E+01, 0.23469200E+01, -.46674400E+00, -.97431800E+01, -.17286200E+02, 0.14315200E+01, -.25452600E+01, 0.68318800E+00, -.61562000E+01, 0.47896000E+01, 0.25113800E+02, 0.21127800E+01, -.14023300E+01, 0.45725700E+01, -.27157300E+00, 0.70365400E+01, -.76605400E+00, 0.35131600E+01, -.17893000E+01, -.97800000E+00, -.70408600E+00, -.76082000E-02, 0.41243600E+00, -.10115000E+00, 0.86059400E+00, -.15732200E+01, 0.12787300E+01, 0.73500700E+00, 0.90684800E+00, 0.23446200E+01, 0.60925700E+00, 0.82160800E-01, 0.77727600E+00, -.65659100E+01, 0.61427900E+00, -.42778700E+00, 0.90001400E+00, -.12534200E+01, 0.21339700E+01, 0.76223700E+00, 0.11667000E+01, 0.83597000E+00, 0.57656800E-01, -.18914000E+01, 0.17997200E+01, -.38809000E-01, 0.30633700E+00, -.44891400E+01, 0.20758400E-01, 0.56425100E-01, -.69640200E+00, -.17710400E+01, -.55836600E+00, 0.10025900E+01, -.31756400E+00, 0.52452000E+00, -.82383700E-01, -.19391600E+01, -.28305900E+00, 0.10531100E+01, -.30388700E+01, -.83081600E-01, -.37539500E+00, 0.77295700E+00, 0.52141700E-01, 0.22608200E+00, 0.13250900E+00, 0.17851600E+01, 0.25686700E-01, 0.14888100E-01, -.48081500E+00, -.85588800E-01, -.48021900E+00, 0.30483400E+00, 0.81303400E-01, -.95525600E-01, -.13711900E+00, 0.47992600E+01, -.11902500E+00, 0.48967000E-01, 0.98420600E+00, -.51686700E+00, 0.14215400E+00, -.54066300E-01, 0.32448000E+00, 0.46611500E-01, 0.40042200E-03, -.15968500E+00, -.26976500E+00, 0.26241600E+00, 0.51153900E+00, 0.63737600E+00, 0.33799500E+00, -.26235000E+00, -.61791900E-01, -.25393000E-01, 0.18877300E+00, 0.16516600E+01, -.12137400E+00, 0.24062600E+00, 0.54413300E-01, 0.10041600E-01, 0.25867700E+00, -.21342900E+01, -.55211000E+00, -.20337500E+00, 0.16442200E+01, 0.12714700E+00, -.18807500E+00, 0.12005800E-01, -.48618400E-01, 0.19851300E+00, 0.11243600E+00, 0.36586600E+00, -.62823300E+00, 0.22685800E+00, -.22394400E-01, 0.60595400E+00, 0.13628600E+00, -.72291300E-02, -.44830900E+00, -.46558000E-01, -.12938100E+00, -.24639800E+00, -.67793400E-02, -.41114100E+00, -.27926500E+00, -.88694600E-02, 0.31273000E+00, 0.22402700E+00, -.20527700E+00, -.20727600E-02, 0.81645300E+00, 0.48214300E+00, 0.36790900E-01, -.28132700E-01, 0.98059300E-02, 0.15529600E+00, 0.23748700E+00, 0.15439500E+00, -.15670100E+00, -.43069000E-02, 0.10455300E+00, -.15528000E-01, -.77374500E-01, 0.74316700E-01, 0.78062800E-01, 0.41074400E+00, -.15634600E+01, -.36678400E+00, -.21967700E+00, 0.73529400E-01, -.11430400E+00, -.10058100E+00, 0.90515700E+00, -.55214700E+00, 0.76760500E+00, -.10614300E+00, -.96077700E+01, -.57628100E+01, 0.30298300E+02, 0.98019400E+01, -.24813400E+02, 0.14217000E+02, 0.54858200E+01, -.14867900E+02, 0.70702300E+01, 0.12721000E+02, 0.71257500E+01, 0.15595800E+02, 0.13449600E+01, -.49052300E+00, -.19463000E+01, -.23461200E+01, 0.85081900E-01, -.96287200E+00, -.16843500E+01, 0.29283600E+00, 0.17832800E+01, -.51849800E+00, 0.43282400E+00, -.13012500E+01, 0.11933400E+01, 0.60343400E+00, 0.45895400E+00, -.91995400E+00, 0.73523200E+00, -.21043900E+00, -.61965700E+01, -.16916200E+01, -.38556200E+00, 0.35966900E+01, 0.37697600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11609300E+02, 0.63461000E+01, 0.10221500E+02, 0.85028400E+02, -.15069200E+02, -.15014800E+01, 0.70882700E+01, 0.47608000E+01, -.22193300E+02, 0.60167300E+01, -.42487200E+01, 0.63599900E+00, 0.14317400E+02, 0.56403500E+01, -.72525000E+00, 0.73225300E+01, 0.11914700E+02, 0.67031800E+01, 0.14845900E+01, -.54602500E+01, 0.46760500E+00, 0.15146400E+02, 0.42524500E+02, -.19850000E+01, 0.58004100E+01, -.87974900E+00, 0.20653900E+02, -.53653300E+01, -.35524800E+02, -.19524100E+01, 0.54897500E+01, -.84910800E+01, 0.25174300E+00, -.17063700E+02, 0.33951800E+01, -.70090200E+01, 0.41895100E+01, 0.16703700E+01, 0.43055900E+01, 0.85994700E+00, -.61422100E+00, -.13870200E+01, -.12748400E+00, 0.93415300E+00, -.11798300E+01, 0.27422200E+00, 0.14707200E+02, -.17886200E+01, -.87355400E+00, 0.11554200E+00, -.38415700E+00, 0.85547700E+00, 0.12188100E+01, 0.47245200E+01, -.12575300E+01, -.20107200E+01, 0.25152100E+01, -.17387700E+01, 0.45742400E+00, 0.78010700E+00, 0.39669400E-01, -.42833800E+01, -.25847800E+01, -.23457100E+00, 0.40418600E+00, 0.28864100E+01, 0.28279100E+01, -.59301900E+00, -.28651300E+01, -.47850300E+00, -.51420700E+00, 0.52046500E-01, -.65763700E+00, 0.91299300E+00, -.16463200E+01, 0.45558700E-01, -.91157000E+00, -.23339500E+01, -.21645600E+01, -.17757200E+01, -.11410800E+00, 0.17900100E+01, 0.13738900E+01, 0.60030100E+00, 0.11840100E+01, -.32793000E+01, -.23762700E+00, 0.13046800E-01, 0.41025100E+00, 0.41741600E+01, 0.10689700E+00, 0.18833600E-01, 0.39905300E+00, 0.73105400E+00, -.66754200E+00, 0.14859700E+01, 0.35880500E+00, 0.18852600E+00, -.36395100E+01, -.56267600E-01, 0.51625800E+00, -.92868900E+00, 0.19101900E+01, 0.53084100E+00, -.65948300E+00, -.13887000E+00, -.17634000E+00, -.17923400E+01, -.16785200E+00, 0.15901100E+01, -.88782300E-01, -.42181200E+00, 0.29944000E+00, -.47017300E+00, 0.86282400E+00, 0.57896300E+00, 0.67741100E+00, 0.39469900E-01, -.15917300E+00, 0.58343700E+00, -.52761600E-01, -.34199800E+00, 0.42532100E+00, 0.86671300E-01, -.13979200E+01, -.89434500E-01, -.50728000E+00, -.41386400E+00, 0.17513400E+00, -.46649200E+00, 0.68985000E+00, -.93454400E+00, -.26412800E+00, -.60364100E+00, -.32072100E+00, 0.50208200E+00, 0.19003000E+00, -.10266200E+00, -.13093500E+01, 0.72528700E-01, -.94006900E-01, 0.62586100E+00, 0.99080600E-01, -.25174800E+01, 0.39095700E+00, -.10818300E-02, 0.46180300E+00, 0.11465000E+01, 0.58416800E+00, 0.58065000E+00, -.17736000E+01, 0.29303500E+00, 0.22075900E+01, 0.31764200E+00, 0.13056400E+00, 0.15705700E+00, -.21186000E+00, -.13291000E+00, 0.38276700E-01, -.61696100E-01, -.60484100E-01, 0.62435500E-01, 0.18116000E-01, 0.19534900E+00, -.27771300E+00, -.12990800E+00, -.46373700E+01, -.10172800E+01, -.59119600E+00, 0.10274500E+01, -.73872600E+00, 0.58503000E+00, -.61181400E+00, 0.41385400E+00, 0.90966100E+00, -.28567500E+00, 0.21265900E+00, 0.17028900E+02, 0.77189900E+02, 0.63134200E+01, -.62244100E+02, 0.25204200E+02, 0.10508000E+02, 0.60252000E+01, 0.94282100E+01, 0.19189300E+02, 0.15203700E+02, 0.19291700E+02, 0.20496900E+02, 0.35913100E+00, 0.28260600E+01, 0.37033900E+01, 0.11178800E+00, 0.14747500E+01, -.41054400E+00, -.32941900E+00, 0.17142800E+01, 0.37617300E+00, -.15554500E+01, 0.13376500E+01, -.11461900E+01, -.11119900E+01, 0.26698500E+01, -.24076600E+01, -.27401900E+01, 0.83672900E+00, 0.13440800E+01, 0.55852800E+00, 0.72202400E-01, -.32205200E+01, -.17759900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14879200E+02, -.75128500E+01, -.23977000E+02, -.10912500E+03, 0.11450600E+02, 0.19590500E+01, -.79388600E+01, -.39097600E+01, 0.37250800E+02, -.69317300E+01, 0.12466600E+02, -.40310500E+01, -.21421800E+02, -.72362100E+01, -.12514100E+00, -.11688400E+02, -.13353200E+02, -.51921400E+01, -.46064200E+01, 0.57565000E+01, -.16902200E+00, -.26917100E+02, -.46124000E+02, 0.16554900E+01, -.69698800E+01, 0.18568500E+01, -.14171100E+02, 0.10761700E+02, 0.66037900E+02, 0.76077900E+01, -.38717600E+01, 0.13759000E+02, -.39723000E+00, 0.19344600E+02, -.25901000E+01, 0.14516400E+02, -.14815700E+01, -.23555300E+01, -.67980200E+00, 0.89815100E+00, 0.13302000E+01, 0.65954700E+01, 0.12465400E+00, -.31345000E+01, -.52477900E+01, 0.47528800E+01, 0.32860300E+02, 0.51844600E+01, 0.10151900E+01, 0.42048700E+01, 0.37859800E+00, 0.30682800E+01, -.46635800E+00, 0.17200900E+01, 0.84284000E+00, 0.40757800E+00, 0.43096300E+01, 0.20322600E+01, 0.16166200E+01, -.24065400E+01, 0.94913800E+00, 0.14918000E+01, 0.15701900E+01, 0.10674200E+01, 0.11922500E+01, 0.19021000E+01, -.81080200E+00, -.11026800E+01, -.83345700E+00, -.13177500E+01, -.67642900E+00, 0.53297200E+00, -.23099900E+00, -.66931400E+00, 0.12705100E+01, -.42437500E+01, -.27867800E+00, 0.43184500E+01, 0.42062700E+01, 0.20654500E+01, -.58491800E+00, 0.72142300E+00, 0.89123200E+00, -.19832600E+01, -.23725900E+01, 0.19112600E+01, 0.11866900E+01, 0.15264700E+01, -.22230700E+00, -.34380900E+01, 0.11900700E+00, -.78817500E-01, -.43416000E+00, 0.63715600E-02, 0.29727100E+00, -.33559500E+01, -.82389700E-01, -.41691600E+00, 0.43759000E+00, 0.71232400E+00, -.26735700E+00, 0.16360900E+00, -.12370700E+01, -.15779600E+00, 0.25394700E+00, 0.30273800E-01, -.43627400E+00, -.98481000E+00, -.85146400E+00, -.21561500E+00, -.25701100E+00, 0.52973800E-02, -.59836800E+00, 0.12461600E+01, -.24675700E+01, 0.37313700E+00, -.28204600E+01, -.17064500E+01, 0.14000300E+00, -.11353400E+01, 0.47596100E+00, 0.75349100E+00, 0.31652800E+01, 0.21377000E+01, 0.43652200E+01, 0.17310900E-01, 0.16574500E+00, 0.10834300E+00, 0.37351100E+00, 0.44417900E+00, 0.11050300E+01, -.14374900E+01, -.16861300E-01, 0.41919600E+00, -.15973400E+01, 0.20610400E+00, 0.19394900E+01, 0.39074000E-01, -.50460200E+00, 0.14745400E+00, -.51437800E+00, 0.22778700E+01, -.15889000E+00, -.12677800E+01, 0.22883400E+01, 0.15849900E+00, 0.72750900E-01, -.77444700E+00, 0.33384300E+00, -.11035200E+01, -.87594800E+01, 0.24816900E+01, -.59441900E+00, 0.83374100E+00, 0.62663200E-01, 0.33453200E+00, 0.11433600E+01, 0.90078800E+00, -.12614400E+01, 0.68057900E+00, 0.18571200E+00, 0.93417600E-01, 0.79771100E+00, 0.14505900E+00, -.26370200E+00, 0.10459600E+01, 0.25136100E+01, 0.99787200E+00, 0.15560200E+00, 0.12936100E+00, -.80995300E-01, -.55704900E+00, 0.16970900E+01, -.22901200E+01, 0.69210200E+00, -.19318700E+00, 0.49015900E+00, -.94601000E+00, 0.15521700E+03, 0.18252700E+02, -.21415300E+03, 0.10100100E+03, 0.60989400E+02, -.19890300E+02, 0.45264500E+02, 0.67571100E+02, 0.66627200E+02, 0.12120800E+03, 0.48819000E+02, 0.56602700E+00, 0.23360700E+01, 0.17442100E+01, 0.16677800E+01, 0.57835000E+00, -.51786800E+01, -.66136500E+00, 0.67459900E+01, 0.17198700E+01, 0.56274900E+01, -.29701400E+00, 0.43734100E+01, 0.12918800E+01, 0.11091700E+02, -.22615600E+01, -.32859900E+01, -.23162400E+01, -.14755000E+02, -.43223300E+01, 0.11154000E+01, -.10527600E+02, 0.82173900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.30416000E+01, -.22580800E+01, -.25390800E+01, -.26550900E+02, 0.50787200E+01, 0.77784200E+00, -.23037600E+01, -.63129100E+00, 0.60836300E+01, -.15413100E+01, 0.73765500E+00, -.33379000E-01, -.31834700E+01, -.11260700E+01, 0.10558000E+00, -.28406300E+01, -.32990100E+01, -.19467300E+01, -.90057400E+00, 0.15377000E+01, -.28585500E+00, -.41382700E+01, -.75154000E+01, 0.48726100E+00, -.11348900E+01, -.24783000E+00, -.50133100E+01, 0.98753200E+00, 0.86718100E+01, 0.61811700E+00, -.12624000E+01, 0.21525500E+01, -.61293400E-01, 0.28952600E+01, -.78069100E+00, 0.16813100E+01, -.83063900E+00, -.85823300E-01, 0.31993800E-01, 0.15271300E+00, -.42018300E+00, 0.46886900E+00, -.62708600E+00, -.13332500E+01, 0.14454900E+00, -.65739700E-01, -.63679400E+01, 0.10901000E+00, 0.77733700E-01, 0.20519200E+00, -.13441200E+00, -.44256300E+00, -.81346400E+00, -.12360700E+01, 0.72460100E+00, 0.14576400E+01, -.18184900E+01, 0.85128100E+00, -.42000400E+00, 0.13903800E+00, -.28673000E+00, 0.52191600E+00, 0.10908000E+01, -.26713600E+00, 0.41966300E+00, -.27167800E+00, -.37636300E+00, 0.81602600E-01, 0.66184500E+00, -.10083300E+00, 0.65100600E-01, 0.43661500E+00, -.15521800E+00, 0.18205700E+00, 0.37757100E+00, -.14845800E+00, 0.43333500E+00, 0.63761200E+00, 0.11609200E-01, 0.43038500E+00, -.96633600E-02, -.49344900E+00, -.45336200E+00, -.34840900E+00, -.12473600E+01, 0.42654300E+01, -.69485400E-01, -.76456800E-01, -.36733700E+00, -.47022900E+00, -.10941000E+01, 0.27252500E+00, -.15063600E+00, -.76168800E-01, 0.31586100E+00, -.13824000E+01, 0.25768900E+00, 0.31654100E+00, 0.18163900E+00, -.10811900E+01, -.63729400E-03, -.24429800E+00, -.35939800E+00, -.27564800E+00, -.22162000E+00, 0.22199700E+00, -.45570900E+00, -.42535400E+00, 0.12337600E+01, -.37358900E+00, -.16176000E+00, -.24337800E+00, 0.45776900E-01, 0.15437700E+00, 0.24662500E+00, 0.50404300E+00, 0.15523100E+00, 0.54932200E+00, 0.37645700E-01, -.26837800E+00, 0.14340700E+00, -.49936400E+00, -.35506800E+00, 0.19111500E+00, 0.20139700E+01, 0.85302400E-01, -.29247500E-02, 0.68531500E-01, 0.21351500E+00, 0.10106100E+00, 0.19720000E+00, -.43648700E+00, 0.40793900E+00, 0.23565300E+00, -.12521500E-01, 0.37581800E+00, 0.84792300E+00, 0.56804200E-01, 0.40625100E-01, 0.17373600E-01, -.22008400E+00, 0.12042600E+01, 0.33531700E-02, -.16997700E+00, 0.15074900E+00, -.29129300E-01, 0.17885100E+00, 0.39768400E+00, -.75938300E-01, -.47556500E-01, -.43731000E+01, -.62031900E-02, 0.29522800E+00, 0.23705800E+00, 0.23015800E-01, -.29253300E-01, 0.13995800E+00, 0.42971700E-01, 0.20331500E+00, -.40650100E+00, -.53629400E-01, -.51149400E-01, -.84225800E-01, 0.13617700E-01, -.15158100E+00, 0.39039100E+00, 0.61599800E+00, 0.11079100E+00, -.60384000E-01, 0.19233800E+00, -.37910300E-01, 0.31673300E-01, 0.97137700E-01, -.21877000E+00, -.24093200E+00, -.37093100E-01, -.18702800E+00, 0.22089300E+00, -.41223500E-01, 0.29680600E+01, -.28654700E+02, 0.13164000E+02, 0.83107300E+01, -.46590000E+01, 0.32229900E+00, 0.16571000E+02, 0.86290400E+01, 0.15487500E+02, -.78884800E+01, 0.55760200E+00, -.58366700E+00, -.82784000E+00, -.23063700E+00, -.61322600E+00, 0.35593000E-01, -.20226800E-01, 0.35699400E+00, 0.47738100E+00, -.18612400E+01, -.43388300E+00, -.14684000E+00, -.71592000E-01, -.21417300E+01, -.57484800E+00, -.14032200E+00, 0.60134300E-01, -.37965000E+01, 0.30572500E+00, -.22122800E+00, 0.31431200E+01, 0.11088100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11558000E+02, -.60710800E+01, -.18273400E+02, -.80856900E+02, 0.12069300E+02, 0.22638200E+01, -.69386400E+01, -.42743000E+01, 0.26365500E+02, -.53356300E+01, 0.70318000E+01, -.17225400E+01, -.13251700E+02, -.63953800E+01, -.86747700E+00, -.71999500E+01, -.10377100E+02, -.34718300E+01, -.30491900E+01, 0.51612200E+01, -.27176000E+00, -.21214300E+02, -.37713100E+02, 0.14380500E+01, -.72157600E+01, 0.13141000E+01, -.58925400E+01, 0.72487700E+01, 0.54139600E+02, 0.73412300E+01, -.36995600E+01, 0.13184600E+02, 0.12489300E+00, 0.18682600E+02, -.20310200E+01, 0.12641400E+02, -.89469200E+00, -.19409300E+01, -.18333200E+01, -.12723700E+00, 0.51842000E+00, 0.39329800E+01, -.13608400E+01, -.49571300E+00, -.54601500E+01, 0.18822800E+01, 0.14373300E+02, 0.11736800E+01, 0.32283800E+01, 0.22134200E+01, -.14282100E+01, 0.29645100E+01, -.30290100E+01, -.12165800E+00, -.12526600E+01, 0.38521000E+01, -.54925300E+01, 0.45090600E+01, -.98843200E+00, -.15711300E+01, 0.97997100E+00, 0.65548800E+00, 0.42994000E+01, 0.13282900E+01, 0.17908600E+00, 0.69478300E+00, -.13066400E+01, -.95059500E+00, 0.20755600E+01, -.13421300E+01, 0.61451800E-02, 0.26342100E+01, -.15221600E+01, -.58245300E+00, 0.23463600E+01, -.31452600E+01, 0.11797600E+01, 0.37246700E+01, -.62857400E+01, 0.21335300E+01, -.14507500E+00, 0.99543600E+00, 0.96064600E+00, -.96161200E+00, -.25185300E+01, 0.79926100E+01, 0.16342000E+01, 0.12595800E+01, 0.29662100E+00, -.14612800E+01, -.67843900E+00, -.68617200E-01, -.35711500E+00, 0.11479000E+01, 0.74336900E+00, 0.75722300E+01, -.86502000E+00, -.75301500E+00, 0.21640700E+01, 0.20555700E+01, -.86693000E+00, -.80534000E+00, 0.50382600E+00, 0.21287500E+00, 0.20606800E+00, 0.18517100E+00, -.14863000E-01, 0.12215900E+01, 0.40463700E+00, 0.39883600E+00, 0.62660600E+00, -.50478100E+00, -.72357100E+00, -.70985700E-01, -.73838400E+00, 0.93802400E+00, -.16052000E+01, -.27380000E+01, 0.23830700E+00, 0.94487300E+00, -.61996300E+00, 0.34293500E+01, 0.17955900E+01, -.36927300E-01, 0.26156900E+01, 0.15525100E+00, 0.31252400E-01, 0.15187400E+01, 0.11012800E+00, -.27278600E+00, 0.27961200E+00, 0.17430400E+01, -.90407100E+00, 0.60568700E+00, 0.16415400E+00, 0.65158200E+00, -.46700500E+00, 0.38866700E-01, -.14875300E+01, -.25799000E+00, 0.29735100E+00, -.41617900E+01, 0.86836900E-01, -.66826000E-01, -.65899600E+00, 0.23875400E+00, 0.43643700E-01, -.64732600E+00, 0.31442500E+00, -.57452100E+00, 0.93050200E+01, -.89764900E-01, -.59634100E+00, -.58773000E+00, -.39135900E-01, 0.31968300E+00, 0.44919100E+00, 0.81542000E+00, 0.98209100E+00, -.97742900E+00, -.14975600E+00, -.20270200E+00, 0.11061600E+01, 0.93365000E-01, -.44868900E+00, 0.70567700E+00, 0.10739200E+02, -.70214600E+00, 0.68266500E+00, 0.42868300E-01, 0.20386400E+01, -.47709800E+00, -.49997200E+00, -.35621600E+00, 0.23451800E+00, -.25009900E+00, -.26208700E+00, 0.21469000E+00, 0.49739700E+00, -.14821600E+01, 0.15917900E+03, -.47218100E+02, -.18426800E+02, -.21363800E+02, 0.61659900E+01, -.15628100E+02, -.55404600E+02, -.26343400E+02, -.53083800E+01, -.81301900E-02, -.34257800E+01, -.64164100E+01, 0.11806700E+00, 0.40139000E+00, -.13110300E+01, 0.62877200E+00, 0.57736000E+00, -.57980000E-01, -.46941300E+01, -.12460400E+01, -.24523100E+01, 0.11390200E+01, -.68064000E+01, 0.88628400E+00, -.16170200E+01, 0.30808400E+01, -.36713200E+01, -.26719100E+01, -.15361700E+00, 0.67495500E+01, 0.96807100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.50029000E+01, 0.32334200E+01, 0.55288900E+01, 0.36524800E+02, -.54966900E+01, -.67044900E-01, 0.34576700E+01, 0.15933300E+01, -.11824800E+02, 0.28474400E+01, -.30283100E+01, 0.70261600E+00, 0.52366400E+01, 0.25196600E+01, -.24644200E+00, 0.46148600E+01, 0.50894900E+01, 0.21351700E+01, 0.15386200E+01, -.22857900E+01, 0.45642600E+00, 0.67036600E+01, 0.99006200E+01, -.97548100E+00, 0.20288000E+01, 0.84860600E+00, 0.12098100E+02, -.29605400E+01, -.20018900E+02, -.20385600E+00, 0.12198900E+01, -.31409800E+01, 0.63031800E+00, -.65537800E+01, 0.63921200E+00, -.32176900E+01, 0.76507800E+00, 0.43987600E+00, -.69526000E+00, -.15508100E+00, 0.85572800E+00, -.31549700E+01, 0.12195900E+01, -.96484300E-01, 0.11553700E+00, -.63052600E+00, 0.68513400E+00, -.73130600E+00, 0.71516500E+00, -.41873100E+00, 0.16879600E+00, -.48942800E+01, 0.66088400E+00, 0.65224300E+00, 0.59434600E+00, -.73065300E+00, -.15662100E+01, 0.17760900E+01, -.64824800E+00, -.78369100E+00, 0.22264900E+00, 0.30536800E+00, -.23041000E+00, 0.13365800E+00, -.31347800E+00, -.21388700E+01, -.10337600E+00, 0.46107900E+00, -.31510100E-01, -.58504500E+00, 0.37436100E+00, 0.12731800E+01, -.29495700E+00, -.20765200E+00, 0.31354400E+00, 0.99686500E+00, -.25794300E+00, -.19297200E+00, 0.12419200E+01, -.45669300E+00, -.19821000E+00, -.10940300E+00, 0.19968100E+01, 0.42861900E+00, 0.67627200E+00, -.20330000E+01, 0.14481600E+00, 0.28166600E+00, 0.92465300E+00, 0.30150000E+00, -.50129600E+00, -.25835600E-01, 0.53395400E-01, 0.61058800E-01, -.27139500E+00, 0.33342300E+01, -.26709500E+00, -.12842200E+00, 0.10408800E+01, -.22746900E+00, 0.15589400E+00, 0.28986100E+00, 0.11776400E+00, -.32222000E+00, -.33699500E+00, -.40703100E+00, -.18860700E+00, 0.18254400E+00, 0.18991600E-02, 0.50692700E+00, 0.43098800E+00, 0.65629900E-01, 0.37918200E+00, 0.26646600E+00, 0.12870800E+00, 0.71783300E+00, -.18193400E+00, 0.44150400E+00, 0.21151500E-01, 0.48712500E-01, 0.14652600E+00, -.13293400E+01, 0.24967500E+00, 0.12273800E-01, -.65978600E+00, -.36758800E-01, -.46994400E+00, -.22138300E+00, -.25866600E+00, 0.92813400E-02, 0.12057400E+00, 0.48275300E+00, -.24984300E-02, 0.33805600E+00, -.22880400E+00, -.10924700E+00, -.94785000E+00, -.26524100E-02, -.24180100E+00, -.14387200E+00, -.16072600E+00, -.81992200E+00, 0.12683800E-02, 0.82813500E-01, 0.28678400E+00, -.20470800E+00, 0.40557000E+00, -.54692900E-01, 0.74260100E+00, -.13138200E+00, 0.36897800E+01, 0.21916000E+00, -.21145900E-02, -.80720400E-01, 0.21109400E-01, 0.44302600E-01, 0.70139000E-01, 0.38035200E+00, 0.16576200E+00, -.52223900E+00, -.23609200E+00, -.18558000E-02, -.17350000E+00, 0.17392400E+00, 0.30627100E+00, -.91889300E-01, -.34723800E+00, -.11338700E+01, 0.98166100E-01, 0.21814100E+00, 0.54767700E-01, -.61737400E+00, -.22887200E+00, -.14144500E+00, -.33797700E+00, 0.68187700E-01, -.58887200E+00, 0.34327200E-01, -.77107300E-02, 0.15577700E+01, -.34703800E+00, 0.18523800E+02, 0.36961000E+02, -.26388400E+02, 0.94956900E+00, 0.10119800E+02, -.23684700E+02, 0.14508700E+02, 0.24282500E+02, -.11902600E+01, -.32796800E+01, -.29391600E+01, 0.53803300E+00, 0.14417000E+01, -.97585200E+00, 0.60527300E+00, 0.12845900E+00, -.58250800E+00, 0.95559700E+00, 0.12938900E+00, -.37846500E+00, 0.24841000E+01, 0.79737200E+00, 0.26006300E+00, 0.15104300E+00, 0.10843700E+01, -.44927300E+01, -.25688100E+01, -.69403800E-01, -.56272600E+00, 0.94047800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.30118700E+01, -.18276200E+01, -.25413400E+01, -.24908300E+02, 0.38182500E+01, 0.48435800E+00, -.19436800E+01, -.76254800E+00, 0.59334200E+01, -.15865300E+01, 0.11554100E+01, -.49103300E+00, -.31561700E+01, -.13030300E+01, 0.31043700E+00, 0.39278100E-01, -.20957400E+01, -.66402900E-01, -.34236100E+00, 0.70993000E+00, -.25182700E+00, -.36078600E+01, -.51186000E+01, 0.10182100E+01, -.67159900E+00, 0.59909900E-01, -.58437700E+01, 0.28179200E+01, 0.12997600E+02, -.85660400E-01, -.14647300E+00, 0.11734900E+01, -.11944600E+00, 0.34135100E+01, 0.47594300E+00, 0.68277800E-01, -.86001100E+00, -.50642400E+00, 0.83981100E-01, -.23683200E+00, -.34488200E+00, -.13291800E+00, 0.26240400E+00, 0.39632400E+00, 0.52377500E+00, 0.11347000E+00, 0.12650000E+01, 0.25556200E+00, 0.42700800E+00, -.30761000E+00, 0.10445800E+00, -.32861400E+01, 0.14029500E+01, 0.18666400E+00, 0.11197600E+01, -.10628600E+01, 0.86281500E+00, 0.11551500E+01, 0.30132900E+00, 0.46720400E+00, -.37279800E-01, -.60151700E+00, 0.91090400E+00, -.13163000E+00, -.13194200E+00, -.30363100E+01, -.51612200E+00, 0.42444800E-01, 0.99224800E+00, -.98516700E+00, -.10226700E+00, 0.62495900E+00, -.21895200E+00, 0.27163300E+00, -.67613000E-01, -.98342600E+00, -.20142200E+00, 0.31666000E+00, -.21720900E+01, -.31916900E+00, -.14608900E+00, 0.95219100E+00, 0.18823200E+00, 0.32734400E+00, 0.85951900E+00, -.18401800E+01, -.15588200E+00, -.17875200E+00, -.35729400E+00, 0.28059700E+00, -.46675300E+00, 0.94295200E-01, 0.36348600E-01, -.19731900E+00, -.20389800E+00, 0.40053200E+01, 0.86328300E-01, 0.22371500E+00, -.45560000E+00, 0.24670300E+00, 0.16957700E+00, -.21484800E+00, 0.83646400E+00, 0.32068500E+00, -.10941800E+00, -.20519200E+00, -.32463800E-01, -.39594200E-01, 0.18124800E+00, 0.48338000E+00, -.13076900E+00, -.24982000E+00, -.50228800E-01, -.38288700E+00, 0.11243100E+00, -.10157300E+00, 0.56428300E+00, 0.37459300E+00, -.65081400E-01, 0.36543700E+00, -.11164500E+00, -.64251100E+00, -.10340600E+01, -.72656200E+00, -.13333000E+00, -.12707500E-01, -.13329200E-01, -.48393900E-02, -.20317200E-01, 0.55550800E-01, 0.10789200E+00, 0.60804200E-02, -.16119600E+00, 0.17073700E+00, -.37812000E-01, 0.29559700E+00, 0.12837500E+00, -.27902500E-01, -.10839700E+00, -.13215000E-01, -.12959500E+00, 0.52985700E+00, -.53930000E-01, 0.92624900E-01, -.28012300E+00, -.55988800E-01, 0.16309000E+00, 0.55656600E+00, -.34483100E+00, 0.22187600E+00, -.27758900E+01, 0.29492700E+00, 0.62231100E+00, 0.30590800E-01, 0.11793300E-01, -.24696300E-01, -.37589300E-01, -.89288900E-01, 0.10914500E+00, -.73562700E-01, -.72913000E-01, 0.12285600E-01, -.35438700E+00, 0.25260200E-01, 0.15042400E+00, -.41765700E-01, -.22848900E+01, -.84804500E+00, -.25493700E+00, 0.21169600E+00, -.27083300E+00, -.27958800E+00, 0.41770800E-01, -.96302900E-01, 0.23586000E+00, -.67741300E-02, 0.20852000E+00, 0.72653700E-02, -.37020100E-01, 0.86914000E+00, 0.16486100E+00, -.33866000E+00, 0.62594100E+01, -.27328400E+01, -.94074000E-01, -.11040600E+02, -.82594800E+01, -.12460900E+02, 0.18149000E+02, -.70794300E+00, -.46709900E+00, 0.32098700E+00, 0.70349900E-01, 0.11707600E+01, 0.13550500E+00, 0.17058300E+00, -.74749500E+00, -.47608600E+00, 0.22277200E+01, 0.11780400E+01, -.21017700E-01, 0.79652700E+00, 0.30211300E+01, 0.34648100E+00, 0.62817800E+00, 0.16917300E+00, 0.15930500E+01, -.74241100E+00, -.17848600E+00, -.35003300E+01, 0.87963300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.34453400E+01, -.25402100E+01, -.28935200E+01, -.29046100E+02, 0.52503700E+01, 0.48212200E+00, -.28701300E+01, -.65647200E+00, 0.77681600E+01, -.17511800E+01, 0.20707900E+01, -.26670800E-01, -.48814400E+01, -.15370700E+01, -.62775300E+00, -.20048200E+01, -.24383000E+01, -.16803000E-02, -.50769200E+00, 0.11385400E+01, -.56105000E+00, -.48602100E+01, -.28777900E+01, 0.69735400E+00, -.90250900E+00, 0.11382800E+00, -.59081500E+01, 0.21425100E+01, 0.16720800E+02, 0.48602300E+00, -.38786200E+00, 0.22340700E+01, -.60491700E+00, 0.39271000E+01, 0.37936300E+00, 0.12972600E+01, -.90838800E+00, -.18732600E+00, 0.93440800E+00, 0.32184100E-01, -.90226100E+00, 0.17635600E+01, -.63567000E+00, 0.83026700E+00, 0.35508100E+00, 0.36853600E+00, -.18077100E+01, 0.63669800E+00, 0.48526400E+00, -.23309000E+00, -.24479800E+00, -.11727500E+01, 0.86937600E+00, -.10476600E+01, 0.50753500E+00, -.44138200E-01, 0.71689700E+00, 0.33369400E+00, 0.18367400E+00, 0.10325800E+01, -.12565100E+00, 0.10398400E+01, 0.35032200E+00, -.52495000E+00, 0.20931700E+00, 0.43148700E+00, -.61759900E+00, 0.12006600E-01, -.64797800E+00, 0.81104000E-01, -.44848400E+00, 0.36679100E+00, -.22850200E+00, 0.21977900E+00, -.37602300E+00, -.48165600E+00, 0.33398700E+00, 0.27375700E+00, 0.46526300E+00, 0.31517800E-01, 0.29572300E-02, 0.45301500E+00, 0.40622200E+00, 0.31844700E+00, 0.78146800E+00, -.36124200E+01, 0.74903200E-01, 0.25628800E+00, 0.46008100E-01, -.28132300E+00, 0.92258900E+00, 0.17710100E+00, 0.93818500E-01, 0.12277800E+00, -.30809400E-01, 0.21453600E+01, -.97638400E-01, 0.14664000E+00, -.14873700E+01, 0.52869400E+00, -.41293600E-01, -.71832600E-01, 0.38691100E+00, 0.14571100E+00, -.42436400E+00, -.25210900E-01, 0.67548500E+00, 0.12711500E+01, -.18526900E+00, 0.46107400E+00, 0.30652400E+00, -.37993300E-02, 0.21853300E+00, -.49077100E-01, -.77007600E+00, 0.92469100E-01, 0.41269900E+00, 0.68661100E+00, -.16893000E+00, -.22079200E+00, 0.19214400E+00, 0.19896200E+00, -.14756900E+00, -.71742200E-01, -.62358500E+00, 0.97833600E-01, 0.37914100E+00, -.56118500E+00, 0.11036200E+00, 0.89925900E-01, 0.31203100E+00, -.38258800E+00, 0.41217100E+00, -.44861800E+00, 0.99911200E-01, -.31921900E-01, -.65633900E+00, -.89295200E-01, 0.24273800E+00, 0.12514500E+00, 0.79827800E-01, 0.39997600E+00, -.26446600E-01, 0.42230200E+00, -.29305500E+00, -.71690700E-01, -.25863200E+00, -.35574300E+00, 0.58627700E-01, 0.26917000E+00, 0.10173900E+01, -.27588200E+00, 0.33027100E+00, -.93454900E-01, -.37715100E-02, -.42410800E-01, -.99226800E-01, -.13649700E+00, 0.14056500E+00, 0.19034100E+00, 0.19327800E-01, 0.10748800E+00, -.16320400E+00, -.31838400E-01, 0.71929300E-02, -.68667800E+00, -.20620700E+01, 0.14935500E+00, -.12002100E+00, -.83379700E-02, -.36755700E+00, -.12256200E+00, 0.11838000E+00, -.13694500E+00, 0.53587900E-02, 0.61813600E-01, -.10041400E+00, -.12781300E+00, 0.12296000E-01, -.47647300E+00, -.67589200E-01, -.22397700E+00, 0.75848800E+00, -.11870200E+02, 0.10951300E+02, 0.17341100E+01, 0.11430600E+01, 0.84908600E+01, -.96484600E+01, 0.64016500E+00, -.89423600E+00, -.15281500E+01, -.96253600E-02, -.62919500E+00, -.15409300E+00, -.69479200E-01, 0.64155100E+00, 0.18316900E+01, -.25553200E+00, -.73631000E+00, 0.16952200E+01, 0.17921300E+01, -.23984600E+01, -.16167900E+01, 0.30575000E+00, -.10758100E+00, -.58891400E+01, -.13564600E+00, 0.17768100E+00, 0.26346100E+01, 0.34965700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.91237600E+01, -.60588400E+01, -.82328100E+01, -.63709700E+02, 0.81718600E+01, 0.33166400E+00, -.57800600E+01, -.43998700E+01, 0.19895600E+02, -.48936200E+01, 0.61756500E+01, -.23213200E+01, -.78710800E+01, -.48607200E+01, 0.11355500E+01, -.79851100E+01, -.97850700E+01, -.52734400E+01, -.27972500E+01, 0.51442400E+01, -.14682000E+01, -.11303600E+02, -.19394300E+02, 0.21235400E+01, -.31746700E+01, -.22161600E+01, -.27702300E+02, 0.34674400E+01, 0.24700500E+02, -.13733200E+01, -.16165800E+01, 0.25288700E+01, -.21104700E+01, 0.70385800E+01, -.17472800E+00, 0.52087000E+01, 0.69993900E+00, -.31440900E+00, 0.21755100E-01, 0.16163100E+00, -.94313900E+00, 0.40568600E+01, -.18355700E+01, -.13317500E+01, 0.86134200E+00, -.43995300E+00, -.75960500E+01, 0.22453600E+01, -.18329200E+01, -.95748600E+00, 0.47248000E-01, -.75510800E-01, 0.13770800E+01, -.37818300E+01, 0.16271800E+01, 0.37210000E+00, -.64140800E+00, 0.77135400E-01, 0.18354400E+00, 0.57174700E+00, -.63580900E+00, -.12394300E+01, 0.20181100E+00, 0.34863100E+00, 0.47017200E+00, -.24408500E+00, -.72934000E+00, -.57582000E-01, 0.19075700E+01, -.13161200E+01, -.30573700E-01, 0.19638900E+01, -.16305700E+01, 0.19633800E+00, 0.36047300E+00, -.14485600E+01, 0.43673000E+00, 0.41454100E+00, -.58010100E+01, 0.36803500E-01, 0.33359400E-01, 0.16766600E+01, 0.15832400E+01, -.25104100E+00, 0.77937700E-01, -.11919200E+01, 0.75795500E+00, 0.71240900E+00, 0.97579800E+00, -.97519300E+00, 0.45350100E+00, 0.35009800E+00, 0.94584100E-01, 0.59775100E+00, 0.56045600E+00, 0.18456200E+01, -.65766900E+00, -.75269100E-01, -.36281500E+00, 0.36226500E+00, -.41256000E+00, -.34499300E+00, 0.12860300E+00, -.23521900E-02, -.68540000E+00, 0.39263700E+00, 0.45440900E+00, 0.16286700E+00, 0.92927500E+00, 0.72944100E+00, 0.76251200E+00, 0.49753000E+00, -.40601800E+00, 0.10533400E+00, -.15239400E+01, 0.40871600E-01, -.66760900E+00, -.10416600E+01, 0.16213200E+00, 0.23638200E+00, -.19245500E+00, 0.28835100E+01, 0.16902000E+00, -.50305100E+00, -.30213400E+01, 0.13202400E+00, 0.52376700E+00, 0.54403400E+00, -.39118200E+00, -.19836900E+00, 0.36987200E-01, 0.32169800E-01, -.12214400E+00, 0.41777300E+00, -.24830700E+00, -.70870000E-01, -.16988700E+01, -.11588600E+00, -.60164400E+00, 0.55431600E-01, 0.76894000E-01, -.14003800E+01, -.12656800E+00, 0.46309600E+00, -.29327300E+00, 0.20582400E-01, -.55036300E+00, -.39996800E+00, 0.17326300E+00, 0.26400900E+00, 0.62198500E+01, 0.16268800E+00, -.13850600E+01, -.16614400E+00, 0.26123500E-01, 0.26746500E-01, -.12600300E-01, 0.16883200E+00, -.38466700E+00, 0.32802400E+00, -.47822300E-01, 0.72128700E-01, 0.80149800E+00, 0.50088600E-01, -.20882100E+00, 0.60024400E+00, -.48384600E+01, 0.15800000E+01, 0.45590800E+00, 0.18584600E+00, -.74310300E+00, -.77236500E+00, 0.16673200E+00, 0.47467800E-01, -.56721800E-01, 0.20508200E+00, -.85139900E-01, 0.12752700E+00, -.11917400E+00, -.13482700E+01, -.61845100E+00, 0.56002300E+00, 0.14738200E+01, -.75678800E+00, 0.28271500E+02, 0.22606000E+02, 0.34544200E+02, 0.37107800E+02, -.47864400E+02, 0.31443700E+01, -.63792000E-01, -.30621100E+01, -.43050800E-01, -.26368200E+01, 0.72299700E+00, -.74649400E+00, 0.73342700E+00, 0.44052900E+01, -.58529400E+01, -.30200600E+01, 0.15815700E+01, 0.12576100E+01, -.13626400E+02, 0.14162800E+01, -.27289400E+01, -.82439000E+00, -.12842300E+02, 0.13606900E+01, 0.37027600E+00, 0.14169100E+02, 0.43597700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.30263000E+02, 0.15241700E+02, 0.27673600E+02, 0.23092700E+03, -.31913400E+02, -.23392100E+01, 0.16164600E+02, 0.96580000E+01, -.66909200E+02, 0.15054200E+02, -.21037600E+02, 0.75043500E+01, 0.42943200E+02, 0.10610500E+02, -.34106300E+01, 0.22148000E+02, 0.27766000E+02, 0.13696300E+02, 0.71379900E+01, -.12564100E+02, 0.70517800E+00, 0.43528300E+02, 0.97622100E+02, -.51869700E+01, 0.11907800E+02, 0.26518200E+00, 0.47191300E+02, -.17168300E+02, -.94305200E+02, -.86270900E+01, 0.10117100E+02, -.19775900E+02, 0.72824500E+00, -.35735800E+02, 0.72227200E+01, -.23769300E+02, 0.56916600E+01, 0.41241100E+01, 0.79432400E+01, -.99555500E+00, -.41859500E+01, -.10062900E+02, 0.13704300E+01, 0.28619000E+01, 0.44244600E+01, -.63286400E+01, -.35942300E+02, -.65319900E+01, -.18125200E+01, -.36209000E+01, -.56255200E+00, 0.43494900E+01, -.33445600E+01, -.33100100E+01, -.52610600E+01, 0.15380100E+00, -.61887500E+01, -.44689900E+01, -.25026100E+01, 0.24474000E+01, -.54313200E+00, -.53187800E+00, -.12626200E+01, -.41734000E+00, -.29511200E+01, 0.83640600E+01, 0.11438300E+00, 0.45761300E+00, 0.58684000E+01, 0.22524700E+01, 0.12912600E+01, 0.12557800E+01, -.66802700E+00, -.22854100E+00, -.11030700E+01, 0.54013800E+01, 0.11432600E+01, -.68320700E+01, -.13263700E+02, -.24763900E+01, 0.17984600E+01, 0.21137700E+01, 0.70938100E+00, 0.39594600E+01, 0.54789100E+01, -.16701700E+01, -.63286400E+00, -.57695300E+00, 0.20050900E+01, 0.56331800E+01, -.24812500E+01, 0.63761300E+00, 0.92222400E+00, 0.17854300E+01, 0.36984400E+00, 0.26371100E+02, -.18358600E+01, -.25372900E+00, 0.43518200E+01, 0.22419500E+01, -.68635900E+00, 0.68655600E+00, 0.28282500E+01, 0.18370600E+00, 0.62462900E-01, -.13403400E+01, -.89854100E+00, 0.30171900E+00, 0.11982700E+01, 0.38576100E+01, 0.14249900E+01, -.78813100E+00, 0.21758100E+00, -.19679300E+01, 0.67396300E+01, 0.51380200E+01, 0.23567800E+01, 0.11860400E+01, 0.53337800E+00, 0.20873300E+01, 0.67347000E-01, -.92955800E+01, -.94456200E+01, -.42481300E+01, -.50381400E+01, 0.47092000E+00, -.14951700E+01, 0.13150400E+01, -.13464800E+01, -.15847300E+00, -.19384600E+01, 0.37898700E+01, -.59640000E+01, 0.95400700E-01, 0.11805400E+01, 0.12074300E+01, -.37531300E+01, -.41114600E+00, -.15156600E+01, -.28434300E+00, -.67114100E+00, 0.77812100E-01, -.15359400E+00, -.29424800E+01, -.38586100E+01, -.16451700E-01, 0.26852800E+00, 0.15432000E+01, 0.10080800E+01, 0.19161900E+01, 0.34116900E+02, -.73726900E+00, -.23823200E+01, -.12856500E+01, 0.95634000E-01, 0.47343100E+00, -.93909600E+00, -.23521000E+00, -.15711400E+01, 0.10867500E+01, 0.47855700E+00, 0.14359300E+00, -.98291600E+00, 0.30059500E+00, 0.95515300E+00, 0.22333100E-01, -.19639200E+02, -.82861500E+00, -.10988900E+01, 0.68891800E+00, -.35728400E+01, 0.80410100E+00, -.15802600E+01, 0.27320600E+01, 0.13217300E+01, -.11662200E+00, 0.18036400E+01, 0.16221700E+01, -.14627400E+01, -.42418100E+01, -.24391700E+01, 0.16565500E+01, 0.62639300E+01, 0.64430600E+01, -.26061600E+01, 0.22631400E+03, 0.19556000E+03, 0.22845300E+03, -.24248800E+03, 0.14867200E+02, 0.38478800E+01, -.11999600E+02, -.30608400E+01, -.99545800E+01, 0.12071500E+00, -.24129200E+01, 0.67535400E+01, 0.11880100E+02, -.33155100E+02, -.11700800E+02, -.21575900E+01, -.16333500E+02, -.59876200E+02, 0.12807300E+02, -.16492200E+02, 0.70985600E+00, -.51078700E+02, 0.70305600E+01, 0.10574000E+00, 0.59791900E+02, -.11886300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11682400E+02, -.80231700E+01, -.11352500E+02, -.81246200E+02, 0.10652000E+02, 0.63096900E+00, -.62544500E+01, -.53489500E+01, 0.24195200E+02, -.64832200E+01, 0.62079900E+01, -.22387300E+01, -.86420800E+01, -.72958600E+01, 0.49774500E+00, -.10885800E+02, -.12204500E+02, -.63547500E+01, -.35262900E+01, 0.49728600E+01, -.97478400E+00, -.12444000E+02, -.24907800E+02, 0.28470400E+01, -.31796100E+01, -.86702200E+00, -.26389300E+02, 0.69733300E+01, 0.38912000E+02, 0.59218600E+00, -.86020600E+00, 0.43631400E+01, -.30104200E+01, 0.95510900E+01, 0.13069000E+01, 0.66804500E+01, -.29214400E+00, -.92878400E+00, 0.38674700E-01, -.65783300E+00, -.17860400E+01, 0.54771500E+01, -.18316000E+01, 0.22174000E+01, -.37594900E+01, 0.16056900E+01, 0.13700700E+01, 0.19872200E+01, 0.20070000E+01, -.80428200E+00, -.13368200E+01, -.21397600E+01, 0.21478000E+00, -.38961700E+01, 0.11541900E+01, 0.20138100E+01, -.17068800E+01, 0.10465800E+01, 0.81705100E+00, 0.32608800E+01, -.11673400E+01, -.56905100E+01, -.34138700E+00, 0.37119500E+00, 0.24707600E+01, 0.21356200E+01, -.11211400E+00, -.19856300E+00, -.60522600E+00, 0.65037300E-01, -.12524200E+01, -.56148300E+00, 0.51760400E-01, -.42059400E+00, -.76032500E+00, -.30267500E+01, -.18304400E+01, 0.21862000E+01, -.59123100E+01, 0.64200200E+00, -.32101400E+00, 0.24691100E+01, 0.28735600E+01, -.12156700E+01, -.17225400E+01, 0.76206300E+01, 0.11436400E+01, 0.60302200E+00, -.71062900E+00, 0.92338500E+00, -.14068600E+01, 0.14705000E-01, 0.35232700E+00, 0.44420600E+00, -.19073000E+00, 0.16926600E+02, 0.37756900E+00, 0.87187500E-02, 0.11283300E-01, 0.14315900E+01, -.18911800E+00, -.13249300E-02, 0.19122500E+01, 0.55413700E+00, 0.11485300E+01, -.29594100E+00, 0.65799800E-01, 0.11716200E+01, 0.83318500E+00, 0.13483300E+01, 0.79828300E+00, -.96783200E+00, 0.29515300E+00, -.14419200E+00, 0.10171900E+00, -.97019900E+00, -.24008300E+00, -.11122200E+01, 0.89251900E-01, 0.69425500E+00, -.22190800E+00, 0.17185600E+01, -.21404700E+01, -.13810500E+01, -.26918900E+01, 0.12513600E+00, 0.15244900E+01, -.37020300E-01, -.48874400E+00, -.43156500E-01, -.11812400E+01, -.97850300E-01, -.84171300E+00, -.67595000E-01, 0.10233300E+00, -.56352000E+00, -.90625000E+00, 0.30586900E-01, 0.32021400E+00, 0.41941200E-01, -.16000900E+00, 0.93697000E-01, -.24859900E+00, -.40629900E+00, -.91539800E+00, 0.19471700E+00, -.10589700E+01, -.24102100E+00, 0.51070200E-01, 0.10471200E+01, 0.67953800E+01, 0.12634400E+01, -.50536800E+00, 0.18380800E+00, -.26445400E-02, 0.53448800E-01, 0.17593300E+00, 0.13365000E+00, -.86736800E-01, -.73034200E+00, -.37987400E+00, -.65916300E-01, 0.18622800E+00, 0.97898400E-01, -.28489700E+00, 0.13267400E+01, 0.47953400E+01, 0.18582100E+01, 0.11572400E+01, -.21619600E+00, 0.45175400E-01, 0.47272500E+00, 0.50215100E+00, 0.34475000E+00, 0.96287200E+00, -.13726300E+00, 0.56859400E+00, 0.42873400E+00, -.29310600E+00, -.40154400E+00, -.45857700E+00, 0.30467600E+00, 0.31959700E+01, -.25625900E+01, 0.94081300E+00, 0.99693700E-01, -.42985200E+02, 0.44620700E+01, -.18742000E+02, -.34455600E+00, -.15169000E+01, -.26430000E+01, 0.92084500E+00, -.28162900E+01, -.12196200E+01, 0.75210300E-01, 0.21016700E+01, 0.64263000E+00, -.40148000E+01, -.40158600E+01, -.10811700E+01, 0.52740300E+00, -.19909700E+01, -.49315700E+01, 0.73226200E+00, 0.18360400E+00, -.62120500E+01, -.51149200E+00, 0.68121100E+00, 0.37529800E+01, 0.60907300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.90471600E+01, -.38046200E+01, -.14675900E+02, -.62857900E+02, 0.70330400E+01, 0.16547000E+01, -.50338100E+01, -.36838800E+01, 0.21802800E+02, -.39959500E+01, 0.71043000E+01, -.31726000E+01, -.99599000E+01, -.48427000E+01, 0.78666000E+00, -.74332700E+01, -.10130500E+02, -.62443000E+01, -.30401700E+01, 0.51906800E+01, -.75434500E+00, -.13772600E+02, -.31314900E+02, 0.14371800E+01, -.46670700E+01, -.63181600E+00, -.20819600E+02, 0.26444500E+01, 0.25452100E+02, 0.30428700E+01, -.33798700E+01, 0.62000700E+01, -.10678600E+01, 0.91692400E+01, -.27350500E+01, 0.11378500E+02, 0.15903700E+01, -.70443800E+00, -.22472200E+01, 0.10449800E+01, 0.21625700E+01, 0.42762100E+01, -.16268600E+01, -.21975600E+01, -.15946600E+01, 0.80080700E+00, 0.43416100E+01, 0.22089700E+01, 0.14254100E+00, 0.10643600E+01, -.14229900E+00, 0.31068200E+01, -.16104100E+01, 0.32880200E+00, -.16918500E+01, 0.15229600E+01, -.11470300E+01, 0.32950700E-01, -.14144000E+00, -.17155800E+01, 0.85085500E+00, -.38515200E+00, 0.21028800E+01, 0.23412100E+00, -.66824000E+00, -.25837200E+00, -.78301000E-02, -.62865400E+00, -.40485700E+00, 0.36735000E+00, 0.44087100E+00, 0.10783500E+01, -.13261900E+01, 0.47899800E-01, 0.11904500E+01, -.54880400E+00, 0.14699100E+01, 0.54643000E+00, -.64711600E+01, 0.82990400E-01, 0.15225400E+00, -.37414400E+00, 0.14315800E+00, -.46871600E+00, -.11732700E+01, 0.54993400E+01, 0.55373600E+00, 0.17295400E+00, 0.51633700E+00, -.20117200E+01, 0.83029000E+00, -.67289300E-02, -.35730400E-01, 0.75553300E+00, -.13943500E-01, -.66278900E+00, -.53579400E+00, -.91711200E+00, -.60003200E+00, 0.97867100E+00, -.48487900E+00, -.41687200E+00, 0.25442400E+00, 0.52641800E-02, -.86771200E+00, 0.34601500E+00, 0.64434300E+00, 0.72845900E+00, -.10873600E+00, 0.29521000E+00, 0.34252400E+00, 0.15404100E+00, -.11862600E+01, -.14827100E+00, -.12931100E+01, 0.39012400E+00, -.98517300E+00, -.26479900E+01, 0.37669700E+00, 0.74494500E+00, -.24101100E+00, 0.71630500E+00, 0.21074600E+01, 0.37391500E+00, 0.84880100E+00, -.11530200E-01, -.21701200E+00, 0.13557300E+01, 0.60201400E-01, 0.88405400E-02, 0.54945500E+00, 0.62397900E+00, -.48840800E+00, 0.13943400E+01, -.77149200E+00, 0.69080500E+00, 0.21503600E+00, 0.51427400E-01, -.59314100E+00, -.35296500E-01, -.11841900E-01, -.12432800E+01, -.26877000E-01, -.65748500E-01, 0.34812400E+00, 0.51063000E-01, 0.31762600E+00, -.33821700E-01, 0.16687400E-01, -.56208600E+00, -.32606100E+01, -.30767200E+00, -.27332600E+00, -.15760000E+00, 0.19262700E-01, -.37381600E-01, 0.75541600E-01, 0.25950200E+00, -.31798300E+00, 0.49368200E-01, 0.28866900E-01, 0.31745300E-01, 0.10238200E+01, -.68877200E-01, -.85596800E+00, 0.15788400E+01, 0.13343100E+00, 0.48116600E+00, -.35350700E-01, 0.48520500E+00, 0.32255100E+00, -.45676400E+00, -.28065900E+00, -.18519000E+00, 0.61786100E+00, -.25863200E+00, 0.49271500E+00, -.14851300E+00, 0.31552900E+00, -.20666200E+01, -.29889700E+00, 0.87733100E+00, -.53219100E-01, -.19049200E+01, 0.54920700E+00, 0.94870000E-01, 0.26983700E+00, -.54313400E+02, 0.55671600E+01, 0.92296700E+00, 0.20036800E+01, -.45046800E+00, -.17488900E+01, 0.21996200E+01, 0.15641600E+01, -.50123800E+00, -.23188200E+01, 0.99286000E+00, -.33843000E+01, 0.58699600E+01, -.28947400E+01, 0.24632800E+01, 0.41338500E+01, -.40251000E+01, 0.11033400E+00, 0.12104500E+01, 0.16758500E+01, 0.25884200E+00, 0.41102200E-01, -.50823400E+01, -.14382500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11687300E+02, -.65523900E+01, -.11550400E+02, -.84305200E+02, 0.14752700E+02, 0.16008400E+01, -.71204900E+01, -.49213200E+01, 0.23854200E+02, -.58790700E+01, 0.53354200E+01, -.22173500E+01, -.12024500E+02, -.49753500E+01, 0.13018600E+01, -.64400900E+01, -.11552700E+02, -.62469200E+01, -.25471300E+01, 0.64048900E+01, -.10569000E+01, -.17171000E+02, -.36501400E+02, 0.21496800E+01, -.59661700E+01, -.80947500E+00, -.17438300E+02, 0.47743300E+01, 0.37278400E+02, 0.41697900E+01, -.47954700E+01, 0.91002100E+01, 0.20366400E+00, 0.16603900E+02, -.27762200E+01, 0.10068900E+02, -.20832000E+01, -.13552100E+01, -.16990900E+01, 0.52247400E-01, 0.11209700E+00, 0.28462900E+01, -.23379900E+01, -.32208800E+00, -.45972800E+01, 0.49699300E+00, 0.37132400E+01, -.45552900E+00, 0.26602100E+01, 0.13947100E+00, -.18595200E+01, 0.91040500E+00, -.11028200E+01, -.53841800E+00, 0.76353800E+00, 0.45639000E+01, -.78231800E+01, 0.67439200E+01, -.17674600E+01, -.34632600E+00, 0.31626100E+00, 0.50795700E+00, 0.48144000E+01, 0.37214300E+00, -.44369600E-01, -.43852200E+01, -.16433100E+01, -.49870900E+00, 0.42116700E+01, -.25562200E+01, 0.58381800E+00, 0.34084700E+01, -.22063200E+01, 0.48069400E-01, 0.21645200E+01, -.24845200E+01, 0.19021600E+01, 0.31522100E+01, -.70671300E+01, 0.15617500E+01, -.15069000E+00, -.96922500E-01, -.42582700E-01, -.63970400E+00, -.14665000E+01, 0.70049400E+01, 0.87403300E+00, 0.15786100E+00, 0.32166400E+00, -.69210500E+00, -.14618800E+01, -.15131000E+00, -.48889000E+00, 0.27121700E+00, 0.32313800E+00, 0.47921800E+01, -.17114200E+00, -.58304600E+00, 0.23928700E+01, 0.11996500E+01, -.55530700E+00, -.31914800E+00, -.27326900E+00, 0.19673400E-01, 0.34762600E+00, 0.12560800E+00, -.29720800E+00, 0.22099900E+00, -.54708400E+00, -.14932500E-01, 0.32657600E-02, 0.36679100E+00, -.39961300E+00, 0.37231500E+00, -.64257700E+00, -.16562800E+01, -.15737000E+01, -.19194600E+01, 0.15592600E+00, 0.48807500E+00, -.73185600E+00, 0.37643100E+01, -.89950500E-01, -.44629700E+00, 0.78544100E+00, 0.21834300E-01, 0.85026400E+00, 0.12900500E+01, 0.45207300E-01, 0.25715700E+00, 0.28054100E+00, 0.16284700E+01, 0.23842100E+00, 0.65520500E+00, -.11356000E+00, -.28587900E+00, -.65995700E+00, 0.18876100E-02, 0.22297000E+00, -.90342300E-01, 0.15846400E+00, -.16227500E+01, -.88904500E-01, 0.18855200E+01, -.44396600E+00, 0.87830100E-01, 0.10196200E+00, -.42807500E+00, -.38599900E+00, -.55247300E+00, 0.16866800E+01, 0.26566400E+00, -.64219600E+00, -.33576200E+00, 0.11051000E+00, -.13123800E+00, 0.47173200E+00, 0.54612700E+00, 0.12433700E+01, -.19413100E+01, -.59723400E+00, -.21749700E+00, 0.22310000E+00, -.75147400E-01, -.21408000E+00, 0.95278400E+00, 0.95550000E+01, -.49085300E+00, 0.83634100E+00, -.14194800E+00, 0.18889600E+01, -.22778100E+01, 0.57386800E+00, -.16802100E+01, -.31569200E+00, -.18260100E-01, -.43710500E+00, -.53670900E+00, 0.31533000E+00, -.20615200E+01, -.82654600E-01, 0.88685500E+00, -.64697500E+00, 0.10397500E+01, 0.60191300E+00, -.18292600E-01, 0.34091700E+00, 0.62061200E+00, 0.55504600E+02, -.63116000E+00, -.22951900E+01, -.10424000E+01, 0.15972400E+00, 0.18738100E+01, -.10311400E+01, 0.61882700E+00, -.20974100E+00, -.26023600E+01, 0.28245700E+01, 0.30405300E+01, -.16491800E+01, -.40864900E+01, 0.39867900E+00, 0.41694800E+01, -.37553500E+00, 0.19619800E+01, -.23806400E+01, -.19830500E+01, -.16725800E+01, -.24173400E+01, 0.43784700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.90707600E+01, -.51876100E+01, -.76713600E+01, -.64947300E+02, 0.10220700E+02, 0.73368100E+00, -.48194200E+01, -.39807200E+01, 0.17788600E+02, -.44595800E+01, 0.50357600E+01, -.10090500E+01, -.12383300E+02, -.42808600E+01, -.63840600E-01, -.68003900E+01, -.96622300E+01, -.45340200E+01, -.15704400E+01, 0.37731900E+01, -.75872200E+00, -.11332900E+02, -.25526300E+02, 0.19969100E+01, -.28816900E+01, 0.11057800E+01, -.22293400E+02, 0.46322200E+01, 0.31090100E+02, 0.17370700E+00, -.36501700E+01, 0.53132100E+01, -.80390600E+00, 0.11118300E+02, -.21813600E+01, 0.24253000E+01, -.40493900E+01, -.75909400E+00, -.45285300E+00, -.16810400E+00, -.82859000E+00, 0.15085700E+01, -.23602000E+00, -.99479500E+00, 0.10331400E+01, -.43791800E+00, -.14158600E+02, 0.14924100E+01, -.28679200E-01, -.14974300E+00, 0.33861300E+00, -.18808600E+01, 0.13690000E+01, -.52428200E+01, 0.37579900E+01, 0.83581200E+00, -.69174300E+00, -.35335300E+00, -.25833800E+00, -.55964400E+00, -.86208600E+00, 0.19818200E+01, 0.75131100E+00, -.31371400E-01, 0.82976400E+00, -.16571900E+01, -.17387300E+01, 0.60696900E+00, 0.23870900E+01, -.12401300E+01, 0.30898400E+00, 0.15108800E+01, -.60126200E+00, -.40431000E+00, 0.68525200E+00, -.41884900E+00, 0.99010200E+00, 0.12347800E+01, 0.20248500E+01, 0.70061700E+00, 0.67766000E-01, -.86260400E+00, -.36050500E+00, -.15631300E+00, 0.11990800E+00, 0.10107500E+01, 0.10065500E+00, 0.96996300E-01, 0.77363500E+00, -.39618200E+01, -.95761400E+00, 0.40539400E+00, -.21580800E+00, -.73620500E+00, 0.57721300E+00, -.34035800E+01, -.53081700E+00, 0.17094400E+00, 0.19339200E+01, -.13561100E+01, -.12966500E+00, 0.17453100E+00, -.12530000E+01, 0.58771000E-01, 0.10075500E+00, 0.34225800E-01, -.46878500E+00, -.73249500E+00, 0.33406000E-01, 0.95602000E-01, -.74748800E-01, 0.62941400E+00, -.63022300E+00, 0.59326700E+00, 0.34790900E+00, 0.13587500E+01, -.10958100E+01, -.26527600E+01, -.13046700E+00, 0.65848400E+00, 0.85137100E+00, -.30607300E+01, 0.13153500E+01, 0.11236200E+01, 0.11484200E+01, -.35667500E+00, 0.43174000E+00, 0.12718700E+00, 0.24331300E+00, 0.15142600E+00, -.47142900E+00, -.34529100E+00, -.32223300E+00, -.89271400E+00, 0.59962700E+00, -.27279800E+00, 0.11550500E+01, 0.10390800E+00, -.20321500E+00, -.19647500E+00, -.33352700E+00, 0.33790600E+00, -.51686200E-01, 0.27424500E+00, 0.47480700E+00, 0.93717100E-01, 0.31103900E+00, -.60572200E-01, -.80778800E+00, -.11991500E+01, -.98174800E+01, 0.18392500E+01, -.69372800E+00, 0.37045300E+00, -.20339900E-02, 0.22580000E+00, 0.54899400E+00, 0.40167900E-01, 0.65166500E+00, -.36383300E+00, -.66242100E-02, -.15947300E+00, -.27038500E+00, 0.21592700E+00, -.20691600E+00, 0.15985900E+01, 0.39715700E+01, 0.94770300E+00, 0.23312800E+00, -.27168500E+00, 0.61080000E+00, 0.18413700E+00, -.34527200E-02, -.24423700E+00, 0.54206400E-01, -.69008700E-01, -.29645000E-01, 0.29022400E-01, 0.13872800E+00, -.11306900E+01, 0.32391300E+00, -.49442400E+00, -.15104300E+01, 0.91819100E+00, -.31650900E+00, -.74136400E-01, 0.25014800E+00, -.66095900E-01, 0.20764500E+00, 0.22621500E+01, 0.46502400E+00, 0.79172400E+00, -.66068800E+00, 0.15691200E+01, 0.39780000E+00, -.36239600E+00, -.11068500E+01, 0.13823200E+01, 0.34610000E+00, 0.18176400E+01, -.42037600E+00, 0.42884800E+00, -.12759500E+01, 0.78360000E+01, -.16965200E+01, 0.42133700E+00, 0.33058700E+01, -.64912700E+00, -.15789600E+00, 0.58716600E+00, -.48899200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19117100E+01, -.13421400E+01, 0.46667800E+00, -.21952700E+02, 0.27661000E+01, 0.49032800E+00, -.20348800E+01, -.50343900E+00, 0.46687900E+01, -.10522200E+01, 0.14943800E+01, -.32731700E+00, -.28174200E+01, -.66717500E+00, 0.43622400E+00, -.25662700E+01, -.27133600E+01, -.18612700E+01, -.71463600E+00, 0.10664700E+01, -.29563400E+00, -.19418500E+01, -.46823600E+01, 0.59531100E+00, -.44902000E+00, -.75515700E+00, -.75215400E+01, 0.30432400E+00, 0.16427600E+01, -.10258100E+01, -.59350700E+00, -.64850400E-01, -.61470900E+00, 0.13349200E+01, -.52201800E+00, 0.46516200E+00, -.44795300E+00, 0.49888900E-01, -.46403200E+00, 0.96636000E-02, -.96403000E-01, 0.57043600E+00, -.40175400E+00, -.27451000E+00, 0.13581000E+01, -.27851500E+00, -.63147400E+01, 0.38143500E+00, -.69562000E+00, -.18864000E+00, -.16637300E-01, 0.16255100E+00, 0.32380000E+00, -.12610400E+01, 0.74768300E+00, 0.22357300E-01, -.57267200E+00, -.58078400E+00, -.93462500E-01, -.36627800E+00, -.92617000E-01, -.77719200E+00, -.22098800E+00, 0.45272300E-01, 0.38495700E+00, 0.91351900E-01, 0.25343100E+00, 0.10812200E+00, 0.13262100E+00, -.43182500E+00, -.44008600E-01, 0.15563200E+00, -.25299000E+00, 0.10258900E+00, -.66239200E-01, -.24732100E+00, 0.14273000E-01, -.31268300E-01, -.54089500E+00, -.66274100E-01, 0.99748100E-02, 0.14136000E+00, -.12018900E-01, -.29250500E+00, -.19003100E+00, 0.56387900E+00, 0.50255500E-01, 0.58430600E-01, 0.26789700E+00, -.11699800E+01, 0.27824600E+00, 0.21733500E+00, 0.17809600E-01, -.70405000E-01, -.42228300E-01, -.21208200E+01, 0.13206200E+00, 0.75035900E-01, -.17568200E+00, -.63888600E+00, 0.11664700E+00, -.99244100E-01, -.35395600E+00, -.24544700E+00, -.13125200E+00, 0.75235100E-01, -.48714500E-01, -.97114600E-01, 0.37141700E+00, -.74611000E-01, -.10563300E+00, -.10201900E+00, -.33828300E-01, 0.15849500E+00, -.89657200E+00, -.58848300E-01, 0.32832200E+00, -.64195900E-01, -.34659300E-01, 0.19138100E-01, 0.90510700E-01, 0.16314800E+01, 0.18635400E+00, 0.20391900E+00, -.32942300E+00, -.55593000E-01, -.52070600E-01, 0.73520800E-01, 0.11078700E+00, -.48531600E-01, 0.10746500E+00, 0.90656200E-01, 0.33215000E+00, -.43082300E-02, -.12918400E+00, -.29075300E-01, 0.15710000E+00, 0.42209500E-01, -.29041900E+00, -.42214100E-01, 0.30115000E-01, -.39591500E+00, 0.37855500E-01, 0.99427400E-01, 0.12459600E+00, -.64801800E-02, 0.24059600E+00, 0.15600200E+00, -.19053700E+00, -.16233800E+00, -.22614200E+01, -.98259700E-01, -.10209500E+00, -.61439500E-01, -.21144800E-01, -.21361100E-01, 0.21243900E-02, 0.28889200E-02, 0.87098100E-01, -.54922800E-01, 0.13356900E-01, -.30665900E-01, 0.85033200E-01, -.40900000E-01, 0.45374900E-02, 0.48199200E+00, -.15667100E+01, -.16966700E+00, -.96343700E-01, 0.27926400E-01, -.21667300E+00, 0.47760100E-02, -.28538700E-01, 0.21874100E+00, 0.25703400E+00, -.34960300E-01, -.35762900E-01, 0.10888800E+00, -.20351100E-01, -.16690600E+00, -.80686200E-02, 0.19155700E-01, -.91532000E-01, 0.51607700E-01, -.43561900E-02, 0.14509400E-02, -.13781400E-01, 0.37242300E-01, -.48498200E-01, 0.12176900E-01, -.11207900E+01, -.53171900E-01, -.14383600E+00, 0.12797800E+00, -.11701600E+00, 0.99078500E-01, 0.59589400E-02, -.44196100E+00, 0.26756000E+00, 0.16706700E+00, 0.20313900E+00, -.38432900E+00, -.93832600E+00, 0.12660400E+01, 0.99279700E-01, 0.21624900E+00, -.93423300E+00, 0.98529000E-02, -.36485400E+00, 0.78926300E+00, -.38835300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.51846600E+01, -.30020300E+01, -.45923600E+01, -.46008100E+02, 0.90937100E+01, 0.14698300E+01, -.42396400E+01, -.11381600E+01, 0.11291000E+02, -.25926800E+01, 0.19721900E+01, -.80655900E+00, -.40744900E+01, -.15519600E+01, 0.59004900E+00, -.36145000E+01, -.44512400E+01, -.34717800E+01, -.17486300E+01, 0.33722900E+01, -.59618800E+00, -.69282100E+01, -.14395800E+02, 0.65077200E+00, -.20399200E+01, -.14351100E+01, -.10502500E+02, 0.13340600E+01, 0.13936200E+02, 0.20858200E+01, -.25588900E+01, 0.36070900E+01, 0.68012500E+00, 0.82355700E+01, -.12669700E+01, 0.55042000E+01, -.49268100E+00, -.52991400E+00, -.10276200E+01, -.92164600E-01, -.55589700E+00, 0.26188800E+01, -.18295900E+01, 0.78501300E+00, -.38912900E+01, 0.20320000E+00, 0.78135800E+01, -.12900300E+01, 0.13422400E+01, -.83225100E-01, -.13485800E+01, 0.30143600E+01, 0.22299800E-01, 0.18058800E+01, 0.44756200E+00, 0.27177600E+01, -.40911100E+01, 0.45536700E+01, -.13517000E+01, -.31554000E+00, 0.37189000E+00, -.11675900E+00, 0.16214200E+01, 0.26599000E+00, 0.28518100E+00, -.22424200E+00, 0.11480900E+00, -.49169000E+00, 0.20995000E+01, -.24649900E+01, -.20818200E+00, 0.21441700E+01, -.12783700E+01, 0.10579500E+00, 0.95666100E+00, -.16434200E+01, 0.78685000E+00, 0.12323400E+01, -.54120400E+01, 0.21112500E+00, -.21433500E+00, 0.94161800E+00, 0.11589200E+01, -.12241700E+00, -.41152500E+00, 0.41598100E+01, 0.80154900E+00, 0.33490500E-01, 0.32680800E+00, 0.15404200E+01, -.56662700E+00, -.31341100E+00, -.17022100E+00, 0.46673100E+00, -.59726100E-02, -.29630800E+00, -.26716700E+00, -.23501500E+00, 0.24643600E+00, 0.91021300E-01, -.11170000E+00, -.49686400E+00, 0.62665200E+00, 0.26651100E+00, -.34690300E+00, 0.12392100E+00, 0.18031600E+00, 0.27397000E+00, 0.24428000E+00, 0.54865400E-01, 0.71633600E-01, -.17724400E+00, 0.80722900E-02, 0.60290300E-01, -.94053200E+00, 0.16770100E+00, 0.13104500E+00, -.88692800E+00, 0.10301900E-01, 0.42409300E+00, 0.15057900E-01, 0.51494900E+00, 0.14196000E+01, 0.31749000E+00, 0.49502100E+00, -.64667800E-01, -.88068300E-01, 0.45026300E+00, 0.21211000E+00, -.10483500E-01, 0.56289400E+00, 0.72477500E+00, 0.23311700E+00, 0.43630000E+00, -.87397800E-01, 0.19354700E+00, -.53927900E-01, 0.67529000E-02, -.62105200E-01, -.57639500E-01, 0.16151400E+00, -.11445400E+01, 0.32264800E-01, 0.81148800E+00, 0.38642400E+00, 0.14254400E-01, -.74190800E-01, -.91125300E+00, -.20758000E-02, -.58648900E+00, -.74913000E+00, -.14166000E+00, -.15710800E+00, -.28390900E-01, -.45042600E-02, -.30051000E-01, 0.93545400E-01, 0.44885700E-02, 0.45923900E+00, -.48120500E+00, 0.10040100E-01, -.41597500E-01, 0.25639600E+00, -.29070900E-01, -.16835000E+00, 0.46276900E+00, 0.38701500E+01, -.16547200E+00, 0.27849000E+00, 0.23748000E-01, 0.70357400E+00, -.26281600E+00, -.23468200E+00, 0.59774600E-01, 0.30163800E+00, -.14440900E+00, 0.54809100E-01, 0.23269500E+00, 0.53032800E-01, 0.13563300E+00, 0.12272600E+00, 0.15369100E+00, 0.30792100E+00, -.51340700E+00, 0.14492800E+00, 0.14501200E-01, -.38861000E-01, 0.34229000E-01, -.38873500E-01, -.35114400E+00, 0.38951200E+00, -.17157700E+01, 0.10598700E+00, -.19547100E+00, -.17736300E+00, 0.60464700E-01, -.84957800E-01, -.59462600E-01, 0.14945600E+00, -.97136900E-01, -.23945100E+00, 0.19921100E+00, 0.18204700E+01, 0.65436100E+00, -.37807400E+00, -.10205900E+00, 0.87310700E+00, -.14033600E+01, 0.32181900E-01, -.17536600E+01, 0.35708700E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17348000E+01, -.84055900E+00, -.37903900E+00, -.14420200E+02, 0.16018800E+01, 0.21475500E+00, -.12154700E+01, -.51996700E+00, 0.39475100E+01, -.86013700E+00, 0.11256900E+01, -.38903800E+00, -.19553400E+01, -.79181500E+00, 0.92791100E-01, -.17234300E+01, -.17284200E+01, -.10580200E+01, -.53577700E+00, 0.74211400E+00, -.21190000E+00, -.14631700E+01, -.26926400E+01, 0.50344500E+00, -.22915900E+00, -.49446400E+00, -.65655000E+01, 0.58862000E+00, 0.40133200E+01, -.57601200E+00, -.30572300E+00, 0.18522600E+00, -.48717900E+00, 0.98853100E+00, -.14624100E+00, 0.68891200E+00, -.21269600E+00, -.31862600E-01, -.37598700E-01, 0.97316500E-01, -.82857800E-01, 0.57599600E+00, -.33815200E+00, -.14595700E+00, 0.62044700E+00, -.72693700E-01, -.34325900E+01, 0.26817900E+00, -.29559300E+00, -.12852100E+00, -.86517200E-01, 0.26066600E+00, 0.16832400E+00, -.73210000E+00, 0.36650300E+00, 0.23010800E+00, -.38333000E+00, -.37371000E+00, -.52148600E-01, -.97405300E-01, -.15379000E+00, -.39204800E+00, -.14482500E-01, -.35374100E-01, 0.11353900E+00, -.24065800E+00, 0.12067100E-01, 0.45268300E-01, 0.19225600E+00, -.80256300E-01, -.24351300E-02, 0.71200900E-02, -.84765200E-01, -.31071200E-02, 0.54560400E-01, -.15034400E+00, 0.47893900E-01, 0.94026400E-01, -.62076800E+00, -.15538300E-01, 0.13289400E-01, 0.18375400E+00, 0.19249600E+00, -.23228000E+00, -.16636400E+00, 0.55727100E+00, 0.32972400E-01, 0.34873400E-01, 0.12724200E+00, -.25893000E+00, 0.63235400E-01, 0.23149100E-01, 0.95129900E-02, 0.39560700E-01, -.48185500E-02, -.45440900E+00, -.43857900E-01, -.57517000E-01, 0.49700200E-02, -.11054000E+00, -.21072700E-01, -.42831700E-01, 0.23456100E-01, -.83532100E-02, -.13689200E+00, 0.55939200E-01, 0.26844100E-01, 0.40419600E-01, 0.17429000E+00, -.18999600E-01, -.19285500E-01, 0.87529400E-02, -.89310700E-01, -.11585100E-01, -.34521000E+00, 0.12974100E+00, 0.21926800E+00, -.91169600E-01, 0.17439200E-01, 0.61660100E-01, -.20628400E-02, 0.36011700E+00, 0.22008800E+00, 0.89801800E-01, -.21728900E-01, -.21453400E-01, -.81270900E-01, 0.15305000E+00, 0.41064400E-01, -.20404400E-02, 0.73841300E-01, 0.10634600E+00, 0.24243000E-01, 0.10082500E+00, -.50320100E-01, 0.81365000E-01, 0.68017600E-01, 0.10634400E-01, -.16723200E+00, -.19269600E-01, 0.19722800E-01, -.25035900E+00, 0.16698300E-01, 0.78088200E-02, -.63568700E-02, -.35663000E-02, 0.10887200E+00, 0.90421000E-01, -.66388900E-01, -.67553300E-01, -.71909800E+00, -.10777200E+00, -.14713800E-01, -.31712500E-01, -.31427500E-02, -.95611600E-02, 0.39696100E-02, 0.77220800E-02, 0.19101000E-01, -.14095600E-01, 0.94280600E-02, -.82098100E-02, 0.83843800E-01, -.13500500E-01, -.11330700E-01, 0.14896400E+00, -.77437100E+00, -.13699300E+00, -.40295200E-01, 0.81928700E-01, -.40119300E-01, -.13901300E+00, -.27969500E-01, 0.41713500E-01, 0.60315400E-01, -.10187900E-01, 0.48240400E-02, 0.27568600E-01, 0.27054300E-02, -.10590400E+00, -.24575900E-01, 0.36554000E-01, -.24181200E-01, 0.20886700E-01, 0.13140700E-01, 0.32439600E-02, -.21649900E-01, 0.41308800E-01, -.81047000E-02, -.52667400E-01, 0.25209000E+00, 0.45348900E-01, 0.25996900E+00, -.15448900E+00, -.48447900E-01, -.50322800E-02, 0.17180900E-01, 0.62118100E-01, 0.73047000E-01, -.16901300E+00, 0.96580800E-02, 0.37812500E-01, -.18399700E-01, 0.29763300E+00, -.85601200E-01, -.13597400E+00, 0.44422100E-01, -.10041900E+00, 0.59691800E-02, 0.17532500E-01, 0.63806100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11630100E+02, -.46368500E+01, -.18481900E+02, -.81620700E+02, 0.10233100E+02, 0.20270400E+01, -.60217000E+01, -.43684400E+01, 0.27337300E+02, -.52911600E+01, 0.80039500E+01, -.24737700E+01, -.14027300E+02, -.68073700E+01, -.15354500E+01, -.90437000E+01, -.11313500E+02, -.44511300E+01, -.35276000E+01, 0.50495400E+01, -.12651800E+01, -.16920100E+02, -.16438400E+02, 0.23539600E+01, -.38311700E+01, -.33688800E+00, -.27784500E+02, 0.83208300E+01, 0.59493500E+02, 0.13282700E+01, -.63042000E+00, 0.66587500E+01, -.30250400E+01, 0.10911400E+02, 0.24524800E+01, 0.63167000E+01, -.61641300E+00, -.97183300E+00, 0.47154400E+01, -.20022400E+00, -.33666000E+01, 0.68114100E+01, -.16112300E+01, -.55604600E-01, -.63772900E+01, 0.24266900E+01, 0.12418500E+02, 0.38432200E+01, 0.28160200E+01, 0.24407900E+01, -.20565300E+01, -.17441700E+01, -.42601100E+00, -.61983900E+01, 0.24640100E+01, 0.28047100E+01, -.10344000E+01, 0.60241600E-01, 0.58945800E+00, 0.22492100E+01, -.25535300E+01, -.19017100E+01, -.14493300E+01, 0.36538000E+00, 0.18995900E+01, -.24860900E+01, -.27274200E+01, 0.72430800E-01, 0.32097700E+01, -.41006300E+00, -.10651300E+01, -.13501000E+01, 0.74840500E+00, -.10234300E+01, 0.87857100E+00, -.16099700E+01, -.14741100E+01, 0.30285500E+01, -.16407300E+01, 0.12138500E+01, -.10837100E+00, 0.37540100E+01, 0.43415400E+01, -.20555900E+01, -.11969900E+01, 0.48202100E+01, 0.94081900E+00, 0.16986500E+01, -.19721200E+00, 0.22495300E+01, -.50566600E+01, -.20740600E-01, 0.26465500E-01, 0.13840100E+00, 0.18724300E+00, 0.28637000E+02, -.10446100E+01, -.43967200E+00, 0.41477700E+01, 0.27936900E+01, -.70257300E+00, 0.58371300E+00, 0.32267700E+01, 0.12214000E+01, 0.74887500E+00, -.90487000E+00, -.44814800E+00, 0.23901700E+01, 0.17677000E+01, 0.19758200E+01, 0.13204100E+01, -.15742900E+01, 0.63133700E+00, -.13477300E+00, 0.36314300E+00, 0.24922100E+01, 0.24005800E+01, 0.14502500E+01, 0.26166500E+00, 0.10885900E+01, -.18683700E+00, -.35192300E+01, -.27951600E+01, -.18468500E+01, -.96811200E+00, 0.97120600E-01, 0.53972200E+00, 0.71404400E+00, -.45727000E+00, 0.65326700E+00, -.12795800E+01, 0.18599200E+01, -.30343000E+01, 0.31597200E+00, 0.84170600E+00, 0.10713100E+01, 0.15928500E+00, 0.17583600E+00, 0.14849800E+01, -.10247300E-01, -.68939600E+00, 0.37405800E+01, -.24498200E+00, -.96728300E+00, -.10626500E+01, -.54799400E-01, -.43657700E+00, 0.97234800E+00, -.11677700E+01, 0.17904500E+01, -.81893600E+01, 0.12697600E+01, 0.20464300E+01, 0.86535200E+00, 0.38913800E-01, -.29428100E-01, -.36278600E-01, -.64741800E+00, 0.11583200E+01, -.12078500E+01, -.17105200E-01, -.26417700E+00, -.10335600E+00, -.28288900E-01, -.63740200E+00, 0.25940800E-01, 0.26186000E+01, 0.26296900E+00, 0.16063300E+00, -.32333000E-01, 0.12989400E+01, -.10823400E+01, 0.15474000E+00, -.67190900E+00, -.58050500E+00, -.17023600E-02, -.24455200E-01, -.47032800E+00, 0.73313900E-01, 0.93658800E+00, -.12834900E-01, -.23865600E+00, -.76419800E-01, 0.11986500E+01, -.51184700E+00, 0.56679100E-01, 0.13336800E+00, 0.25239200E+00, 0.49008400E+00, -.13140100E+00, -.14998800E+01, -.58428200E+00, -.27980200E+01, 0.39474800E+01, 0.74695700E-01, 0.17179900E+00, -.33390700E+00, 0.10963000E+00, 0.24517200E+01, -.10303000E+01, 0.13981300E+01, 0.82412100E+00, 0.43389700E+01, 0.12568900E+01, -.22912700E+00, 0.34456600E+00, 0.90092400E+01, -.15473400E+01, -.78775100E-01, -.37638900E+01, -.34389200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.29595100E+01, -.21501100E+01, -.22532000E+01, -.24010300E+02, 0.40028600E+01, 0.51019400E+00, -.20158700E+01, -.11540900E+01, 0.51400500E+01, -.14003900E+01, 0.15940900E+01, -.42948300E+00, -.30174500E+01, -.96075700E+00, 0.47907400E+00, -.21073300E+01, -.28328000E+01, -.16187700E+01, -.63286700E+00, 0.15099800E+01, -.46174400E+00, -.34650600E+01, -.50524600E+01, 0.54301100E+00, -.11662900E+01, -.62068500E+00, -.51297300E+01, 0.78285000E+00, 0.53655300E+01, -.45312000E+00, -.54353000E+00, 0.80892700E+00, -.40841100E+00, 0.20924700E+01, -.27621200E+00, 0.63101700E+00, -.42466800E+00, -.18010100E-01, 0.29002300E-01, 0.10080000E-01, -.36083100E+00, 0.90103900E+00, -.46079100E+00, -.50664600E+00, 0.14761800E+01, -.13472500E+00, -.61438100E+01, 0.44856300E+00, -.73904000E+00, -.37520500E+00, 0.44067200E-01, -.10221400E+01, 0.88209400E+00, -.19774000E+01, 0.15286700E+01, -.23522400E+00, -.49854000E+00, 0.12408600E+00, -.10577500E+00, -.54329000E-01, -.24532300E+00, -.76114000E-01, 0.18554600E+00, 0.81542300E-01, 0.38555600E+00, -.35718900E+00, -.30998800E+00, 0.29152200E-01, 0.72364000E+00, -.79468400E+00, 0.34514400E-02, 0.68430800E+00, -.55989100E+00, 0.87064800E-01, -.19250700E-01, -.52254900E+00, 0.95883400E-01, 0.14476200E+00, -.70571300E+00, -.14984100E-01, 0.13649500E-01, 0.48170100E+00, 0.32123600E+00, -.13541100E+00, 0.21939000E-01, -.46136200E+00, 0.20914000E+00, 0.22657100E+00, 0.39784400E+00, -.88528400E+00, -.25487100E+00, 0.27602200E+00, -.47540200E-01, 0.80004200E-02, 0.55187500E-02, -.37373600E+00, 0.96040000E-01, 0.15868400E+00, -.66631800E+00, -.46171900E+00, 0.96466000E-01, -.28470100E+00, 0.34730000E-01, -.35274700E-01, -.17628200E+00, 0.93644900E-01, -.46564400E-01, -.58833100E+00, 0.48997400E+00, 0.23348900E+00, -.77789000E-01, -.11562100E+00, -.13722500E-01, 0.13728600E+00, -.83483000E+00, -.97445800E-01, -.18731100E+00, -.15303900E+00, -.20496200E-01, -.31861900E-01, 0.37814400E-01, 0.15664600E+01, -.28982500E+00, -.87525300E-01, -.11888000E+01, -.88048900E-02, 0.76840200E-01, 0.98827100E-01, 0.35766100E-01, -.71326500E-01, 0.29757300E+00, 0.12629000E+00, 0.96829700E-01, -.37571800E-01, -.19703500E+00, 0.23749500E-01, -.26743500E-01, 0.46197600E-02, -.61103800E+00, -.35196700E-01, 0.30006500E-01, -.60636800E+00, 0.10694100E-01, -.27732000E+00, 0.15079100E+00, 0.44641100E-01, 0.95825400E-01, -.64393600E-01, 0.30277200E-01, -.14037300E+00, 0.16567200E+01, 0.67591300E-01, -.38032500E+00, -.12592400E+00, -.60288900E-02, 0.53426300E-01, 0.11291600E-01, 0.93253700E-01, -.40572600E-01, 0.67888100E-01, 0.51704200E-02, -.11992200E-01, 0.11082200E+00, 0.10533900E-01, -.26025300E-01, 0.20225000E+00, -.41284900E+00, 0.18371600E+00, 0.12978500E-01, -.71674900E-01, -.19493000E-01, 0.12308800E+00, -.86366800E-02, 0.84963700E-01, 0.12693800E+00, -.14461700E-01, 0.42773500E-01, 0.53141000E-02, -.40795700E-02, -.11050600E+00, 0.36390400E-02, 0.62625200E-01, -.89649700E-01, -.12893900E+00, 0.47961500E-01, -.48696300E-02, 0.12466800E-01, -.13054100E-01, 0.29061600E-01, 0.11259700E-01, 0.60745800E-01, -.84081500E-01, -.28349200E+00, 0.25423200E-01, 0.48487500E+00, -.14797900E-02, -.34290300E+00, 0.20748800E+00, 0.12821100E-01, 0.28035900E+00, -.59984100E-01, 0.73485500E-01, 0.25789900E+00, 0.61561500E-01, -.10992900E+00, 0.11587200E+00, -.11762200E+00, -.33831700E-01, 0.24244000E-01, -.29844300E+00, -.11451500E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.41665300E+01, -.26409900E+01, -.25723800E+01, -.35602300E+02, 0.63550800E+01, 0.50198000E+00, -.36658700E+01, -.11470800E+01, 0.71421600E+01, -.21146400E+01, 0.16758100E+01, -.14528200E+00, -.37112300E+01, -.83032400E+00, 0.76052900E+00, -.39628300E+01, -.38996500E+01, -.26020300E+01, -.10291700E+01, 0.20790500E+01, -.66669500E+00, -.35209700E+01, -.53764100E+01, 0.78833000E+00, -.10015400E+01, -.14706200E+01, -.10467700E+02, 0.56090300E+00, 0.33487000E+01, -.18994600E+01, -.88770300E+00, -.55731600E-01, -.66939900E+00, 0.25932600E+01, -.55311500E+00, -.38384700E+00, -.10642700E+01, 0.90503800E-01, -.75719900E-01, -.99848700E-01, -.85045700E+00, 0.11802500E+01, -.93117100E+00, -.45857800E+00, 0.21327500E+01, -.60496300E+00, -.96621300E+01, 0.40204800E+00, -.14532100E+01, -.40570300E+00, -.15178600E-01, -.57956000E+00, 0.15701700E+01, -.28511100E+01, 0.27619800E+01, -.22350200E+00, -.74069700E+00, -.19645700E+00, -.17093000E+00, -.27613800E+00, -.52127300E+00, -.88423400E+00, -.89324000E+00, 0.28981500E+00, 0.10912500E+01, 0.42789600E+00, -.47942400E-01, 0.21968400E+00, 0.11133500E+01, -.13850300E+01, -.91442700E-01, 0.87718400E+00, -.76707200E+00, 0.11446900E+00, -.22195400E+00, -.87364700E+00, -.17730000E+00, 0.13732600E+00, -.70693200E-01, 0.92446300E-01, 0.16085200E-01, 0.70150300E+00, 0.32850100E+00, -.55354800E+00, -.26600100E+00, -.31610300E+00, 0.18310700E+00, 0.28741000E+00, 0.48631000E+00, -.17706900E+01, -.21246300E+00, 0.47848300E+00, -.44620700E-01, -.15761300E+00, 0.58847500E-01, -.32471300E+01, 0.23694700E+00, 0.39951200E+00, -.62871300E+00, -.14091100E+01, 0.26346100E+00, -.22902900E+00, -.53655300E+00, -.30790500E+00, -.13495700E+00, 0.15842700E+00, -.28032400E+00, -.10386600E+01, 0.89257400E+00, 0.44649700E-01, -.22667900E+00, -.33141600E-01, -.30265400E-01, 0.23673500E+00, -.11086500E+01, -.27564900E+00, -.75277900E-01, 0.25505600E-01, -.68946600E-01, -.15469800E+00, 0.14027900E+00, 0.24844600E+01, -.13448600E+00, 0.78964500E-01, -.19846200E+01, -.71982900E-01, 0.13385400E-01, 0.95613600E-01, 0.40883700E-01, -.10191000E+00, 0.20201800E+00, 0.48263800E+00, 0.16136700E+00, -.27587200E+00, -.11061600E+00, -.20376900E+00, -.34394500E+00, -.25675700E-02, -.68702300E+00, -.74874500E-01, 0.62197700E-01, -.10130300E+01, 0.37799300E-01, -.19467300E+00, 0.25159600E+00, 0.60215300E-01, 0.27627300E+00, 0.27333000E-01, 0.45877600E-02, -.15528800E+00, 0.13599200E+01, 0.34334800E+00, -.58650400E+00, -.14536000E+00, -.24009300E-01, 0.87846000E-01, 0.83132800E-01, 0.20138300E+00, -.11274800E+00, 0.10769300E+00, -.12345400E-01, -.32543300E-01, 0.18303300E+00, 0.13177800E-01, 0.27852600E-01, 0.35226300E+00, -.13279000E+01, 0.23464000E+00, 0.19211300E+00, -.76669200E-01, -.45852500E+00, 0.24828200E+00, 0.29587800E-02, 0.44517400E+00, 0.34101800E+00, 0.35249600E-01, -.44028700E-01, 0.13848200E+00, -.89072500E-01, -.65400400E+00, -.14747500E+00, 0.12504300E+00, -.16137200E+00, -.18161100E+00, 0.28677500E+00, -.23914200E-01, 0.26105000E-01, -.70277500E-01, 0.28634100E-01, -.44967700E-01, 0.13363300E+01, -.18763400E+00, 0.19310000E+01, 0.49443000E-01, -.93220300E+00, -.25188100E+00, 0.11628600E+00, 0.87930900E+00, 0.33556400E+00, 0.42931800E+00, 0.77452500E-01, 0.89405500E+00, 0.17618300E+01, -.48781900E+00, 0.19387800E+00, -.38948600E+00, 0.16900000E+01, -.31887200E+00, 0.12592500E+01, -.20124600E+01, -.26474700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.42591800E+01, 0.30041800E+01, 0.37136200E+01, 0.33587100E+02, -.50481000E+01, -.54417100E+00, 0.29246300E+01, 0.14515500E+01, -.83594800E+01, 0.20297400E+01, -.27088000E+01, 0.71573000E+00, 0.51280600E+01, 0.14584100E+01, -.48305800E+00, 0.30773700E+01, 0.42323100E+01, 0.25878200E+01, 0.93217600E+00, -.20936900E+01, 0.59056100E+00, 0.59135700E+01, 0.88710800E+01, -.69897400E+00, 0.20573800E+01, 0.69381200E-01, 0.40204300E+01, -.10154000E+01, -.79601000E+01, -.29418600E+00, 0.12673600E+01, -.22897400E+01, 0.34284100E+00, -.37815900E+01, 0.10358700E+01, -.15734500E+01, 0.13328800E+01, 0.17938500E+00, 0.37612300E+00, -.15830500E-01, 0.26517600E+00, -.78779400E+00, 0.49063800E+00, 0.57424800E+00, -.14710400E+01, 0.11431100E+00, 0.59669600E+01, -.42863300E+00, 0.38087300E+00, 0.44721300E-03, 0.10378300E+00, 0.13105700E+01, -.86033200E+00, 0.22989500E+01, -.18705200E+01, 0.78656500E-01, 0.87328100E+00, 0.11996200E+00, 0.18500600E+00, 0.46363600E+00, 0.32371400E+00, 0.25327700E+00, -.24801400E+00, -.32682900E+00, -.53058800E+00, 0.76308900E+00, 0.11724300E+00, -.49785100E-01, -.64755700E+00, 0.11907500E+01, -.38635600E-01, -.67880100E+00, 0.56564300E+00, -.54972100E-01, 0.66619800E-01, 0.54303000E+00, 0.36033900E-01, -.28172000E+00, 0.11712000E+01, -.52410000E-01, -.42692300E-01, -.39807600E+00, -.17347700E+00, 0.24882300E+00, 0.45287000E-01, 0.24996000E-01, -.17446100E+00, -.19098400E+00, -.31326100E+00, 0.94655000E+00, 0.24953600E+00, -.24254800E+00, 0.70992400E-01, -.19611700E-01, 0.16478500E-01, 0.12769900E+01, -.68141500E-01, -.44907300E-01, 0.41673000E+00, 0.50252400E+00, -.75685100E-01, 0.24966500E+00, 0.12670400E+00, 0.81089600E-01, 0.13582900E+00, -.12759600E+00, 0.83523300E-01, 0.63888000E+00, -.42015400E+00, -.21461400E+00, 0.45842700E-01, 0.20520900E-01, 0.44824900E-01, -.97996700E-01, 0.60633400E+00, 0.16680500E+00, 0.22940600E+00, 0.13685700E+00, -.40901700E-02, 0.72674200E-01, 0.36447600E-01, -.16648000E+01, 0.44421200E+00, 0.10230800E+00, 0.13518700E+01, -.22338500E-02, -.13618600E+00, -.14588200E+00, 0.19769800E-01, 0.66393500E-02, -.13880800E+00, -.34212800E+00, -.11512300E-01, 0.39327100E-01, 0.90650600E-01, 0.49492700E-01, 0.20424100E+00, -.10485300E-02, 0.50696900E+00, 0.60831900E-01, -.61431700E-01, 0.82887100E+00, -.18359400E-01, 0.14863200E+00, 0.84848100E-01, -.51180800E-01, -.12114500E+00, 0.33232200E-01, -.42362600E-01, 0.10286300E+00, -.30946300E+01, -.68345800E-01, 0.38443900E+00, 0.15882000E+00, 0.75030600E-02, -.57025200E-01, -.25818000E-01, -.82696400E-01, -.57267500E-01, 0.50532800E-01, 0.20234600E-01, 0.39856100E-01, -.13380800E+00, -.12555200E-01, 0.33677800E-01, -.16270600E+00, 0.41259800E+00, -.19527400E+00, -.29521500E-01, 0.68105400E-01, 0.58341500E-01, -.74002600E-01, -.84763700E-01, 0.51458000E-02, -.86633400E-01, -.62973600E-02, -.45482300E-01, 0.29743500E-01, 0.14640200E-01, 0.12202800E+00, 0.33902700E-01, -.79664200E-01, -.71144400E-02, 0.45200700E-01, -.60073600E-01, 0.57466300E-04, -.48504300E-02, 0.30328100E-01, -.53963200E-01, -.29143300E-01, -.90165500E-01, 0.10123200E+00, 0.10678100E+00, -.30598600E-01, -.63565200E+00, -.71530900E-01, 0.49427600E+00, 0.46522200E-01, -.48236400E-01, -.34401500E-01, -.93954400E-01, 0.65096100E-01, -.75327300E-01, 0.36407800E+00, 0.50560600E-01, 0.11804100E-01, 0.62777800E-01, -.29321200E-01, 0.19601000E-01, 0.79774600E-02, 0.18941000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.46142500E+01, -.30404200E+01, -.37839800E+01, -.38416500E+02, 0.66223200E+01, 0.62134900E+00, -.36875800E+01, -.16363700E+01, 0.78688300E+01, -.23253800E+01, 0.19430400E+01, -.34545600E+00, -.36910100E+01, -.12645100E+01, 0.77483900E+00, -.36067300E+01, -.45072500E+01, -.27420000E+01, -.11322200E+01, 0.21178600E+01, -.67198900E+00, -.28989400E+01, -.48063900E+01, 0.10385100E+01, -.72363700E+00, -.13320300E+01, -.12727800E+02, 0.98945200E+00, 0.46777700E+01, -.18550900E+01, -.70478500E+00, -.23720900E+00, -.76678700E+00, 0.29441400E+01, -.34676900E+00, -.69932200E+00, -.15509700E+01, 0.14940100E-01, 0.68537500E+00, -.96924200E-01, -.13313700E+01, 0.14157800E+01, -.95932400E+00, -.44917200E+00, 0.11843100E+01, -.56345200E+00, -.12109200E+02, 0.51325400E+00, -.13952100E+01, -.13649700E+01, 0.56797200E-01, 0.36033200E+00, 0.16134700E+01, -.31690300E+01, 0.26198200E+01, 0.95832300E+00, -.13538500E+01, -.17596300E+00, 0.84966600E-02, 0.28458400E+00, -.48157400E+00, -.13907300E+01, -.12068000E+00, -.18656600E+00, 0.11628900E+01, -.45615400E+00, 0.16424900E+00, -.27989100E-01, -.65737000E+00, -.77644000E+00, -.27612800E+00, 0.15616200E+00, -.20311400E+00, 0.28659600E+00, -.34217100E+00, -.51020800E+00, -.25877100E+00, 0.40359000E-01, -.12603700E+01, -.25583400E+00, -.27846300E-01, 0.10560700E+01, 0.91672600E+00, -.52214200E+00, 0.33108400E+00, 0.82230800E-01, 0.19514600E+00, 0.11088600E+00, -.37196800E+00, -.60298400E+00, 0.80992100E-02, 0.26869400E+00, 0.85542900E-01, -.95956600E-01, 0.15618300E+00, 0.20086900E+01, 0.26604200E+00, 0.20983800E+00, -.23913600E+00, 0.39460400E+00, -.34906600E-01, 0.16335800E+00, -.11223100E+00, -.23126800E+00, 0.29483900E-01, -.65940900E-01, -.28705700E+00, -.60264000E+00, 0.32485800E+00, 0.14949000E+00, -.17366400E-01, -.50439100E-01, 0.28168600E-01, -.34827100E+00, 0.87827900E+00, -.21378200E+00, 0.35160100E+00, 0.27979000E+00, 0.18037000E+00, 0.31724700E+00, -.35488600E+00, -.15628800E+01, -.11857300E+01, -.76628000E+00, -.74386400E+00, 0.83663700E-01, 0.43715600E+00, 0.28942500E+00, -.22699800E+00, 0.22899400E-01, -.38509200E+00, 0.73516500E+00, -.10254100E+01, -.18854200E+00, 0.45521100E-04, 0.24350900E+00, 0.57982900E-01, 0.16758200E-01, 0.39231100E+00, 0.33775200E-01, -.30104300E+00, 0.17376700E+01, -.13125400E+00, -.73783800E+00, -.19546100E+00, 0.12921200E+00, -.12630000E+00, 0.18618000E+00, 0.10776900E+00, 0.41496000E+00, -.17900700E+00, 0.90017800E+00, 0.10806400E+00, 0.44685200E-01, 0.76023300E-02, 0.29962100E-01, 0.24476400E-01, 0.12734500E+00, -.17028400E+00, 0.13141000E+00, -.15701600E+00, 0.69685800E-01, -.24950500E+00, 0.80971500E-01, -.46974600E-01, -.35831500E+00, 0.26134700E+00, 0.93142000E+00, 0.26276000E+00, -.12374300E+00, 0.87794000E-01, 0.13981600E+00, -.85807400E-01, -.12393400E-01, -.36699200E+00, 0.64356900E-01, -.11979800E+00, 0.16147500E+00, -.12782800E+00, 0.53752700E+00, 0.34725900E-01, 0.93442900E-02, -.49327600E+00, -.50855100E+00, 0.33710800E+00, -.99210200E-01, 0.50942800E-01, -.41421600E+00, 0.12083600E+00, 0.44623400E+00, -.17844200E+01, 0.32963500E+00, -.22036300E+01, 0.37787000E+00, 0.58209700E+00, 0.69616500E+00, 0.43266000E+00, -.11921000E+01, -.23559300E+01, 0.28214600E+01, -.85303000E+00, -.15752500E+01, -.55704300E+01, -.28045500E+01, 0.14292500E+00, 0.62549200E+00, -.90664100E+01, 0.18734500E+01, -.72085900E+00, 0.50619200E+01, 0.20836500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.71899300E+01, -.45923400E+01, -.66541700E+01, -.52664800E+02, 0.57366600E+01, 0.62666000E+00, -.41939100E+01, -.36445500E+01, 0.15784600E+02, -.37163000E+01, 0.50999500E+01, -.20559300E+01, -.60734900E+01, -.35536700E+01, 0.59630800E+00, -.64219000E+01, -.71887300E+01, -.39276900E+01, -.23796000E+01, 0.33533500E+01, -.89678300E+00, -.93391100E+01, -.15668100E+02, 0.17414500E+01, -.22414200E+01, -.11696600E+01, -.16866700E+02, 0.32213100E+01, 0.21437700E+02, -.30259900E+00, -.13802200E+01, 0.30122800E+01, -.15293200E+01, 0.48060800E+01, 0.99311500E-01, 0.31784200E+01, -.18997800E+00, -.17920100E+00, 0.78667900E+00, 0.94100000E-01, -.10767900E+01, 0.24123200E+01, -.16661700E+01, -.58473200E+00, 0.29711000E-01, 0.25476700E+00, -.54351300E+01, 0.64187200E+00, -.47874700E+00, -.16774400E+00, -.44809900E+00, 0.65682900E-01, 0.18069200E+00, -.21029500E+01, 0.99843700E+00, 0.95872100E+00, -.13647500E+01, -.49539500E+00, -.24897200E+00, 0.23503500E+00, -.58731100E+00, -.37233700E+00, 0.90019100E+00, 0.18688500E-01, 0.47252200E+00, 0.18415000E+00, -.76464000E-01, -.23461200E+00, 0.11684300E+01, -.12191800E+01, -.69843500E-01, 0.13652800E+01, -.88839000E+00, 0.22909200E+00, 0.43022900E+00, -.14403300E+01, 0.85694700E+00, 0.68895100E+00, -.34159000E+01, 0.14394700E+00, 0.62543600E-02, 0.75705300E+00, 0.61164000E+00, -.29558600E+00, -.76173500E+00, 0.38783200E+01, 0.43817100E+00, 0.20639200E+00, -.10572400E+00, -.41827600E+00, -.96205300E-01, 0.28858500E+00, -.59672100E-01, 0.25664800E+00, 0.19652800E+00, 0.39336800E+01, -.13191500E+00, -.66872800E-01, -.19191700E+01, 0.73341900E+00, -.21823300E+00, -.55369600E+00, 0.88658800E+00, 0.59647900E+00, -.26565100E+00, 0.36044200E+00, 0.99985200E-01, -.47802000E+00, 0.51537700E+00, 0.67823600E+00, 0.18551700E+00, 0.30561500E+00, -.42849600E+00, -.29902600E+00, 0.69631800E-01, 0.53272500E+00, -.15901900E+00, -.43608500E+00, 0.14199600E-01, 0.20997200E+00, -.13861800E+00, 0.64639900E+00, 0.13575900E+01, 0.39456400E+00, -.11651500E+01, -.14805300E+00, 0.22475100E-01, 0.89928500E-01, 0.17475600E-01, -.45752900E-01, 0.27682900E+00, 0.43035600E+00, -.13973800E+00, 0.13232800E+00, -.96927600E-01, 0.13616800E+00, 0.42211600E+00, 0.12070900E+00, -.11220200E+00, -.37780000E-01, -.33448300E-01, -.19197600E+00, 0.47934100E-01, -.39835800E+00, 0.59961300E+00, -.90589900E-01, 0.39448000E+00, -.40838500E+00, 0.30116900E+00, -.22410000E+00, -.15326600E+01, -.79474400E+00, 0.67046200E-01, -.99801700E-01, 0.13295300E-02, -.10805400E+00, -.31014500E+00, -.92445900E-01, -.10835200E+00, 0.84057000E-01, 0.27797500E-02, 0.74230800E-01, 0.25711900E+00, 0.23005000E-01, 0.18478300E+00, 0.83377100E-01, -.52616100E+01, -.68238800E+00, -.52209500E+00, 0.34203700E+00, -.62900400E+00, -.21564100E-01, -.41144000E+00, 0.44284600E+00, 0.41772700E-03, -.25487600E-01, -.37170600E+00, 0.39588800E+00, -.81781700E-01, 0.96193200E+00, -.52964100E-01, 0.35381400E+00, -.53494400E+00, -.22879400E+00, -.23729600E+00, -.10476900E-01, -.28170300E+00, 0.13151200E-01, -.29075800E+00, 0.56162900E-01, 0.91164200E+00, 0.79001700E+00, 0.66455900E+00, -.17231500E+00, 0.27691100E+00, -.22711000E+00, 0.98584300E+00, -.98861300E+00, -.26094200E+01, 0.19800800E+01, -.59825700E+00, -.66602600E+00, -.78999600E+01, -.45278800E+01, 0.45234000E+00, 0.80451400E+00, -.14820000E+02, 0.25139800E+01, -.68081400E+00, 0.76223500E+01, 0.50234300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.45420800E+01, -.28473700E+01, -.35626600E+01, -.38708900E+02, 0.58110800E+01, 0.15599200E+00, -.30282700E+01, -.85671800E+00, 0.11269500E+02, -.25624400E+01, 0.30846500E+01, -.61491000E+00, -.55645100E+01, -.13848400E+01, 0.13999800E+00, -.59747300E+01, -.42269800E+01, -.26151700E+01, -.17463900E+01, 0.18589200E+01, -.23245000E+00, -.60541800E+01, -.10050400E+02, 0.62523000E+00, -.13346700E+01, -.55227700E+00, -.80532000E+01, 0.17370200E+01, 0.11103400E+02, 0.34111300E+00, -.11071700E+01, 0.20424000E+01, -.36978800E+00, 0.37747100E+01, -.49692900E+00, 0.29507000E+01, -.25800900E+00, -.29973400E+00, -.54602100E+00, 0.13957400E+00, 0.34081300E-01, 0.22347100E+01, -.87854400E+00, -.16307200E+00, -.90943200E+00, 0.84022300E+00, 0.58165100E+01, 0.80476000E+00, 0.21172600E+00, 0.10330900E+01, -.40743800E+00, 0.86495300E-01, 0.37421000E+00, 0.15336200E+00, 0.65503800E+00, -.21050400E+00, 0.70639900E+00, -.44737000E+00, 0.14003200E+00, -.53952400E+00, -.22757600E-01, -.84342700E+00, -.41930500E+00, 0.45992600E+00, 0.48023400E+00, 0.74955100E+00, 0.39305500E+00, -.21943100E-01, -.48716700E+00, -.36696600E+00, -.15565100E+00, 0.21823500E+00, -.24936100E+00, -.18262500E-02, 0.47752800E-01, -.58793700E+00, 0.10281100E+00, 0.35825800E+00, -.17559400E+00, 0.18481300E+00, -.31369800E-01, -.14385800E-01, 0.61561900E-01, -.30322500E+00, -.74440300E+00, 0.21704700E+01, 0.17832800E+00, 0.12293600E+00, 0.23081000E+00, -.29887900E+00, 0.25226800E+00, -.64290500E-01, -.37516200E-01, 0.12622700E+00, 0.22128600E-01, -.24572200E+01, -.81387500E-02, -.92418400E-01, -.72632400E+00, 0.31634500E-02, -.44689200E-01, -.12889700E+00, -.89222100E-01, -.58526500E-01, -.21078900E+00, 0.17400600E+00, 0.21350100E+00, -.60049600E-01, 0.80844300E-01, 0.24981400E-01, 0.14820900E+00, 0.15116600E+00, -.69028400E-01, 0.75619200E-01, -.48643200E+00, -.90219600E-01, -.10538800E+00, -.84472400E-01, 0.24872900E-01, -.90685000E-01, -.92623200E-01, 0.56198800E+00, 0.46440400E+00, 0.11188600E+00, -.15625900E+00, 0.19474800E-01, 0.10328800E+00, 0.71810800E-01, 0.83713900E-02, -.17388500E-01, 0.18836000E+00, 0.25915500E-01, -.45081700E-01, 0.70223900E-01, -.67111300E-01, -.11255000E+00, -.23526300E+00, 0.43765100E-02, 0.25005700E+00, 0.31018900E-01, -.50299900E-01, 0.22427400E+00, -.24600000E-01, 0.36748200E-01, 0.30924300E+00, 0.13612800E-01, -.20487900E+00, -.45378500E+00, 0.23360600E+00, -.25652700E-02, -.40643000E+00, 0.24212300E+00, 0.60541300E-01, 0.19215900E+00, 0.10877500E-01, 0.85390300E-02, 0.75245900E-01, 0.60282100E-01, -.13410300E+00, 0.73949400E-01, -.46624600E-01, 0.20638600E-01, 0.19476100E+00, 0.70283600E-02, -.14432100E+00, -.26407100E-01, 0.62117900E-01, 0.23463700E+00, 0.21123900E+00, 0.11983300E+00, 0.84100800E-01, -.35651900E+00, 0.12962800E+00, -.24981000E+00, -.13301800E+00, 0.19884100E-01, 0.57026800E-01, -.75774000E-01, 0.37758900E-01, -.14150200E+00, -.20692000E+00, 0.30216300E+00, 0.25506100E-01, -.73112300E+00, 0.26088100E+00, 0.31310700E-02, 0.75270800E-01, 0.96221700E-02, -.11272800E-01, -.50552900E-01, -.29720000E+00, 0.33751200E-01, -.17802200E+00, 0.62866100E-01, -.14448000E-01, -.11622200E+00, -.72744200E-01, -.25317500E+00, -.58338300E+00, 0.21347900E+01, 0.11027300E+01, -.65979400E+00, -.57479200E+01, -.39251900E+01, 0.64288800E+00, 0.66441900E+00, -.10943000E+02, 0.19226700E+01, -.45102000E+00, 0.51736600E+01, 0.18203600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.66730900E+01, -.41341300E+01, -.57078800E+01, -.56572200E+02, 0.92798700E+01, 0.13510600E+01, -.47918100E+01, -.15486400E+01, 0.14157000E+02, -.35182400E+01, 0.25181500E+01, -.11982200E+01, -.70423700E+01, -.27316900E+01, 0.14670300E+01, -.25284500E+01, -.62888000E+01, -.33739300E+01, -.10713500E+01, 0.34107800E+01, -.72850300E+00, -.90022100E+01, -.22164500E+02, 0.16274300E+01, -.27245400E+01, 0.60188200E-01, -.12639300E+02, 0.35936300E+01, 0.19857400E+02, 0.23549900E+01, -.29343900E+01, 0.40453000E+01, 0.22990900E+00, 0.92410600E+01, -.21419000E+01, 0.57125300E+01, -.14535900E+01, -.77227900E+00, -.15226600E+01, 0.12318100E+00, 0.67954000E+00, 0.10812600E+01, -.17592000E+00, -.53166000E+00, -.44164300E+00, 0.36568600E-01, 0.24636500E+01, 0.37335300E+00, 0.74147600E+00, 0.66094800E-01, 0.50007800E+00, -.25745900E+01, 0.10812700E+01, 0.30246300E+00, 0.16110200E+01, -.44419400E+00, 0.14859500E+01, 0.17647300E+01, 0.17800000E+00, -.56910200E-01, -.75858000E-01, 0.13955300E+01, 0.14691900E+01, 0.10164800E+00, 0.37844600E-01, -.21857600E+01, -.11009500E+01, 0.12469000E+00, 0.19450100E+01, -.13716200E+01, -.21860500E+00, 0.78873600E+00, 0.14256700E+00, -.49356900E-01, 0.77371700E+00, -.10314800E+01, 0.33105400E+00, 0.13298800E+01, 0.10355900E+01, 0.52370800E+00, -.27027300E+00, -.33036500E+00, -.86142800E+00, -.19134500E+00, -.72346600E+00, 0.14032300E+01, 0.12797700E+00, -.26548000E+00, -.10782900E+01, -.25407800E+01, 0.38725300E+00, 0.97689200E-01, -.26434900E+00, -.90375300E+00, -.15749100E+00, -.37463100E+01, 0.66272700E+00, 0.28797200E+00, -.19663100E+00, -.76975500E+00, 0.34286100E+00, -.25593600E+00, -.91500800E+00, -.20723900E+00, 0.16758100E+00, 0.18900600E+00, 0.18160900E+00, 0.19100300E+00, -.23751600E+00, -.58056500E+00, -.23874500E+00, -.42675000E+00, -.87646300E+00, -.12091700E-01, -.82133800E+00, -.35075900E+00, -.28202000E+01, -.17618900E+01, 0.12909000E+00, -.63679700E+00, 0.29524200E+00, -.24358900E+01, 0.16556500E+01, 0.73898200E+00, 0.20458900E+01, 0.30864500E-02, 0.41294300E+00, 0.56438200E+00, 0.16901400E+00, 0.42052900E+00, -.34366700E-01, -.48758300E+00, 0.30475500E+00, 0.92063200E+00, -.34817400E-01, 0.60883500E+00, 0.11641300E+01, -.47991300E-02, -.56931800E-01, -.11311100E+00, 0.20506200E+00, -.20231500E+01, 0.20535900E-01, 0.82777300E+00, 0.44186700E+00, 0.49342900E-01, -.49083100E-01, -.12953300E+01, 0.12494500E-01, -.10421900E+01, 0.17653900E+01, 0.40651300E+00, -.53497900E+00, -.12969900E+00, -.30231300E-01, 0.10020500E+00, 0.39741800E+00, 0.24796300E+00, 0.62057800E+00, -.35778000E+00, 0.49286400E-02, -.61329000E-01, 0.30159200E+00, 0.33234100E-01, -.92294900E-01, 0.19370600E+00, 0.56286200E+01, 0.57254400E-01, 0.39158200E+00, -.25183700E+00, 0.95505600E+00, -.39478400E+00, -.28830500E+00, -.10432400E+00, -.18161900E+00, -.58434400E-01, -.39422300E+00, -.29893000E+00, 0.28647900E+00, 0.13487600E+01, 0.42955800E+00, -.40761800E+00, 0.11972000E+01, 0.63800400E+00, 0.32969900E-01, -.26229100E-01, -.29980100E+00, -.24262100E+00, 0.97651200E-01, -.64485900E+00, -.13893600E+01, -.53872600E+00, -.11137700E+01, 0.22969100E+00, -.74088800E+00, -.48650400E-01, -.84482100E+00, -.23715900E-01, -.66611900E+00, 0.13399300E+01, -.19535300E+01, 0.77009100E+00, 0.77494500E+01, 0.63782400E+01, -.15082800E+01, -.48679700E+00, 0.65816800E+01, -.28750300E+01, 0.32576600E+00, -.60071600E+01, -.13348700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.54904500E+01, 0.30172600E+01, 0.48180800E+01, 0.43737000E+02, -.48771500E+01, -.75715100E+00, 0.33271000E+01, 0.24023100E+01, -.12818500E+02, 0.27359300E+01, -.46191300E+01, 0.19144000E+01, 0.64005400E+01, 0.30630100E+01, -.81396000E+00, 0.49730200E+01, 0.67170900E+01, 0.37857400E+01, 0.18345800E+01, -.34707300E+01, 0.85974000E+00, 0.77528200E+01, 0.16231900E+02, -.14677200E+01, 0.25605000E+01, 0.12475300E+01, 0.17132200E+02, -.22090800E+01, -.14659500E+02, -.47100400E-01, 0.19547700E+01, -.27062700E+01, 0.10127000E+01, -.47935800E+01, 0.91318200E+00, -.44743400E+01, -.15601800E+00, 0.23119700E+00, 0.42722600E+00, -.36063000E+00, -.60441400E-02, -.31644600E+01, 0.25062300E+01, 0.32030300E+00, -.14686000E+00, -.53657600E+00, 0.32998700E+01, -.67263400E+00, 0.39639600E+00, 0.64228000E+00, 0.11740700E+00, -.64952000E+00, 0.40632200E-01, 0.18177100E+01, -.65488500E-01, -.76477800E+00, 0.19079600E+00, 0.27756000E+01, -.22987700E+00, -.20955300E+00, 0.59160300E+00, 0.93008200E+00, -.51480700E+00, 0.22760500E+00, -.18924400E+00, 0.13654900E+01, -.52144900E+00, 0.45220900E+00, 0.18031300E+01, 0.34874600E+00, 0.15773500E+00, 0.11968000E+00, 0.17758100E+00, -.13298300E+00, 0.12565300E+00, 0.66977500E+00, -.30915600E+00, -.13366600E+00, 0.17816800E+01, 0.39627800E+00, 0.47247700E-01, 0.14802800E+00, 0.27778100E-01, 0.80348000E-01, -.26190000E+00, -.54323900E+00, 0.90672700E-01, 0.32304200E+00, 0.14535100E+00, 0.27917100E+00, -.89756300E+00, 0.14638500E+00, 0.98354100E-02, 0.38697100E-01, 0.49640400E+00, -.80082200E-01, -.20381400E+00, 0.34259600E+00, 0.58818200E+00, -.33822300E+00, -.12003000E+00, -.40572400E+00, -.13832800E+00, 0.12298000E+00, -.38578500E-01, 0.22667900E+00, -.37723200E+00, -.96741200E+00, 0.40796600E+00, 0.24898400E+00, 0.95096500E-01, 0.29233400E+00, 0.24267600E+00, -.12023000E+00, 0.13631500E+01, 0.63928600E+00, -.11487100E+00, 0.11709800E+01, 0.25153900E-01, -.26864200E+00, 0.13799200E+00, -.16615400E+01, -.10330800E+01, -.62772700E+00, -.26240300E+00, 0.18921100E+00, -.95819900E-01, -.73563500E-01, -.36202900E+00, 0.19066900E-01, -.32859400E+00, 0.71955500E+00, -.45316700E+00, -.22397100E+00, 0.29297300E+00, -.97269300E-01, -.16483000E+01, -.16111700E+00, -.42504300E+00, -.79041400E-01, -.10544300E+00, -.80919800E+00, -.46184900E-01, 0.24307700E+00, -.62339000E+00, 0.65910300E-02, -.23980200E+00, -.56154900E-01, -.84851100E-01, 0.15670300E+00, 0.60744100E+01, 0.37818700E+00, -.96707800E+00, -.18357800E+00, 0.23016700E-01, 0.12619600E+00, 0.52087100E-01, 0.97640500E-01, -.29773000E+00, 0.27162800E+00, 0.13140300E+00, 0.25039700E-01, -.11737600E+00, 0.74394300E-01, 0.16456800E+00, -.67939900E-01, -.14664900E+01, -.18805300E+00, -.11021900E-01, 0.10558400E+00, -.26009300E+00, -.24433900E+00, -.17991700E-01, 0.12623600E+00, 0.33899600E-01, 0.50030800E-01, 0.64441200E-01, 0.58509300E-01, -.25946200E-01, -.58255600E+00, -.61923000E-01, 0.44847300E-01, 0.35215400E+00, 0.54498300E+00, -.21877800E+00, 0.47913600E-01, -.21779200E+00, 0.14195800E-01, -.99670100E-01, 0.20950900E+00, 0.60995800E+00, 0.37556600E+00, 0.15660400E+01, -.18749100E+00, 0.32104500E+00, -.96162700E-01, 0.79122800E+00, -.38074900E+00, 0.18146900E+00, -.34168400E+00, -.37087500E+00, -.27781600E+01, -.54333000E-01, -.19053200E+01, 0.10676600E+00, -.61625700E-01, -.42564400E+01, 0.29951500E+00, -.26446900E-01, 0.11608400E+01, 0.12149600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37505600E+01, -.30070200E+01, -.28464800E+01, -.32478000E+02, 0.64500000E+01, 0.72327300E+00, -.31929700E+01, -.61103600E+00, 0.78389700E+01, -.19427700E+01, 0.16259500E+01, -.16989400E+00, -.38456200E+01, -.79692800E+00, 0.53544300E+00, -.42460000E+01, -.36443900E+01, -.29497200E+01, -.11565200E+01, 0.22607500E+01, -.42572900E+00, -.52624700E+01, -.97159700E+01, 0.15274400E+00, -.18902600E+01, -.48887400E+00, -.35175800E+01, 0.46337300E-01, 0.34683800E+01, 0.37492300E+00, -.17013600E+01, 0.20158300E+01, -.41265800E-01, 0.34990800E+01, -.15847800E+01, 0.24816500E+01, -.62107700E+00, -.11161800E+00, -.10996000E+01, 0.19350800E+00, 0.37514400E+00, 0.14069800E+01, -.97143300E+00, -.72423600E+00, 0.60163500E+00, 0.19731800E+00, 0.11146900E+01, 0.53100100E+00, -.19052500E+00, 0.83820600E+00, -.10632700E+00, -.29861100E+00, 0.38752500E+00, -.67473500E+00, 0.13175300E+01, -.43475700E-01, -.24846400E+00, -.53883900E-02, -.47735500E-01, -.83592500E+00, 0.36887500E-01, -.58462500E+00, -.28567800E+00, 0.34881200E+00, 0.74284800E+00, 0.63942400E+00, 0.20965800E+00, -.93385500E-01, -.20309500E+00, -.70118700E+00, 0.12758800E+00, 0.86756300E+00, -.94243200E+00, 0.16562400E+00, -.18633700E+00, -.47412700E+00, 0.18032900E+00, -.17446700E+00, -.91314300E+00, 0.53985200E-01, 0.10318000E+00, -.19244000E+00, -.37830100E+00, -.28709400E+00, -.78505800E+00, 0.30724700E+01, 0.14684200E+00, 0.25507300E-01, 0.38742000E-02, -.14717600E+01, -.30197800E+00, 0.32078400E+00, -.82108100E-01, -.31130100E-01, -.27138200E-01, -.28307500E+01, 0.17005000E+00, 0.16863300E+00, -.10539300E+01, -.82797500E+00, 0.16889200E+00, -.21993000E+00, -.35870300E+00, -.21700700E+00, -.18658700E+00, 0.88616600E-01, -.17872100E+00, -.79242900E+00, 0.30918800E+00, 0.14560800E+00, -.80471200E-01, 0.14641200E+00, 0.15107800E-01, 0.49596500E+00, -.11615100E+01, -.34720900E+00, -.33528300E+00, -.13854000E-02, -.32182900E-01, -.17463900E+00, 0.14232300E+00, 0.18780200E+01, 0.13076600E+00, 0.62660100E-01, -.19191300E+01, -.52824900E-01, 0.39232900E-01, 0.76438000E-01, -.44211300E-01, 0.40585300E-01, 0.32090400E+00, 0.92315600E+00, -.10401600E+00, 0.81108100E-01, -.23417100E+00, -.17347400E+00, -.39988400E+00, 0.24008100E-01, -.30294600E+00, -.91886700E-01, 0.25802500E-01, -.11263100E+01, 0.13189100E-01, -.22419700E+00, 0.49140800E+00, 0.66910700E-01, 0.30063200E+00, -.20702200E+00, -.70225900E-01, -.36975500E+00, 0.11711000E+01, 0.39698700E+00, -.47137100E+00, -.17320200E+00, -.15863400E-01, 0.86957900E-01, 0.31317800E-01, 0.12543600E+00, -.32980300E-01, 0.75503500E-01, 0.67908000E-02, -.47901100E-01, 0.19241000E+00, -.41254800E-03, 0.85705600E-02, 0.34977300E+00, 0.72008500E+00, 0.11826900E+00, 0.13637600E+00, -.23032800E+00, 0.26732600E+00, 0.60118500E-01, 0.85774500E-02, 0.17671200E+00, 0.28631000E+00, -.17213400E-01, 0.20293500E+00, -.17311100E+00, 0.55092200E-01, -.65695200E+00, 0.85279300E-01, 0.49872800E-01, -.22726400E+00, -.38959900E+00, -.15502900E-01, 0.12415000E-01, 0.10022200E+00, 0.63946100E-02, 0.29893900E-01, 0.11809500E+00, 0.55583200E+00, -.17144800E+00, 0.43513400E-01, 0.63286600E-01, -.15315900E+00, 0.32656300E+00, 0.65032000E-01, -.46656800E+00, 0.40166900E+00, 0.35370000E+00, 0.22930700E+00, 0.54604100E-01, 0.17990400E+01, -.85542400E+00, 0.34285100E+00, -.15660200E+00, 0.53006700E+01, -.15338600E+00, -.13656100E+00, -.20266900E+01, -.23306300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.40309100E+01, -.28149600E+01, -.36011400E+01, -.35378000E+02, 0.47308600E+01, -.59392100E-02, -.30353100E+01, -.70843700E+00, 0.10150700E+02, -.24899800E+01, 0.24724600E+01, -.61013300E+00, -.44293800E+01, -.15413600E+01, 0.47187500E+00, -.51862700E+01, -.42647000E+01, -.29320100E+01, -.16139600E+01, 0.20235500E+01, -.43068000E+00, -.59594000E+01, -.94591700E+01, 0.57939500E+00, -.13098100E+01, -.43990200E+00, -.66046700E+01, 0.15685600E+01, 0.10218400E+02, 0.40218200E+00, -.10679000E+01, 0.20199900E+01, -.36564800E+00, 0.38442800E+01, -.55877700E+00, 0.25961200E+01, -.38447000E+00, -.28144700E+00, -.41661500E+00, 0.14274500E+00, 0.12697200E-01, 0.18853400E+01, -.85678100E+00, -.11836400E+00, -.82983700E+00, 0.74143000E+00, 0.53245300E+01, 0.64288800E+00, 0.15499200E+00, 0.92700000E+00, -.34513000E+00, 0.40302600E+00, 0.34247300E+00, 0.21024700E+00, 0.59153000E+00, -.52309400E-01, 0.55976500E+00, -.69528900E-01, 0.83399800E-01, -.47849800E+00, 0.24445500E-01, -.54560900E+00, -.35904400E+00, 0.59390800E+00, 0.50556200E+00, 0.10888500E+01, 0.35712600E+00, 0.12034000E-01, -.24441000E+00, -.50865400E+00, -.17494900E+00, 0.27520300E+00, -.27533800E+00, -.62213200E-02, -.84703100E-02, -.63219200E+00, 0.56811000E-01, 0.30419300E+00, -.41064300E+00, 0.18875700E+00, -.15213200E-01, 0.57121600E-01, 0.40572000E-01, -.25655400E+00, -.69855600E+00, 0.21658300E+01, 0.19155300E+00, 0.13860500E+00, 0.20349200E+00, -.47490200E+00, 0.30323200E+00, 0.15990900E-01, -.28476100E-01, 0.11077000E+00, 0.82095500E-01, -.25193000E+01, -.20288400E-01, -.59171000E-01, -.66196600E+00, 0.32742700E-01, -.59508400E-01, -.12381400E+00, -.17047900E+00, -.86121200E-01, -.18689800E+00, 0.16535400E+00, 0.22411900E+00, -.22615400E-02, 0.48567900E-01, 0.12492400E+00, 0.24606200E+00, 0.19624200E+00, -.84833800E-01, 0.69219700E-01, -.23119500E+00, -.35459300E-01, -.30408200E+00, -.75307600E-01, 0.29848200E-01, -.11318500E+00, -.70631200E-01, 0.30723600E+00, 0.36693500E+00, 0.38667100E-01, -.25895600E+00, 0.27424000E-01, 0.11734800E+00, 0.10311000E+00, -.53218100E-01, 0.10780200E-01, 0.11137800E+00, 0.83605000E-01, -.14198800E+00, 0.13719700E+00, -.47444900E-01, -.11099100E+00, -.32559700E+00, -.14123900E-02, 0.15779500E+00, 0.46078900E-03, -.42258600E-01, -.60492800E-01, -.29702400E-01, 0.73283900E-01, 0.18196200E+00, 0.17973400E-01, -.19200500E+00, -.39175500E+00, 0.14472300E+00, -.11184700E-05, 0.11349800E+01, 0.29898000E+00, -.66985200E-01, 0.14725200E+00, 0.13160000E-01, 0.34296400E-01, 0.56354500E-01, 0.10771800E-01, -.65263600E-01, 0.30505600E-01, -.30492300E-01, -.42044300E-02, 0.17892800E+00, 0.14618700E-01, -.14791900E+00, 0.69249900E-01, -.50876200E-01, 0.20935500E+00, 0.21061800E+00, 0.12256800E+00, 0.75119600E-01, -.40808100E+00, 0.20060000E+00, -.30475200E+00, -.10477300E+00, 0.23691700E-01, 0.76710100E-01, -.91945400E-01, 0.41144100E-01, -.38995800E-01, -.18222200E+00, 0.24393300E+00, 0.33022300E+00, -.61189400E+00, 0.20631000E+00, 0.21596200E-01, 0.77354400E-01, 0.25543400E-01, -.10075300E-01, -.95920700E-01, -.24145000E+00, 0.17026000E-01, -.22903600E+00, 0.69358100E-01, -.40855200E-01, -.13430900E+00, -.12995700E+00, -.22760100E+00, -.43806900E+00, 0.79643000E+00, -.14990000E+00, -.59174800E-01, 0.81055600E+00, 0.16206400E+01, -.50536400E+00, 0.63370000E-02, -.28747800E+01, -.33047800E+00, 0.20938800E+00, 0.62118100E+00, 0.14644100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18848100E+01, 0.16271600E+01, 0.47744400E+00, 0.16723000E+02, -.35571300E+01, -.66470100E+00, 0.15661100E+01, 0.21496300E+00, -.29062100E+01, 0.78769500E+00, -.58161500E+00, -.10141200E+00, 0.17376800E+01, 0.25523900E+00, -.27063400E+00, 0.12623400E+01, 0.15016800E+01, 0.10596400E+01, 0.15023900E+00, -.66415600E+00, 0.19846700E+00, 0.11387200E+01, 0.28788500E+01, -.20264400E+00, 0.43313100E+00, -.25031700E+00, 0.27635100E+01, -.65136300E-01, -.71601900E+00, 0.33200800E+00, 0.69418500E+00, -.25998100E+00, 0.17011000E+00, -.23659200E+01, 0.69057700E+00, -.30115900E-01, 0.12258200E+01, 0.56774800E-01, 0.11128700E+00, 0.13222900E+00, 0.23428200E+00, -.42232900E+00, 0.27379100E+00, -.76934900E+00, -.31520700E+00, 0.20742500E+00, 0.18293900E+01, 0.24434400E+00, -.27221700E+00, -.20765900E+00, 0.16279500E+00, -.37950400E+00, -.61071500E+00, 0.10677700E+01, -.12417200E+01, -.12846300E+00, 0.71327300E+00, -.21112900E+00, 0.17315800E+00, 0.66390500E+00, 0.18030900E-01, -.15802900E-01, -.30441600E-01, 0.27648600E-03, -.44845700E+00, -.51231300E-01, 0.15316900E+00, 0.68508900E-01, -.33847700E+00, 0.46330100E+00, -.44266400E-01, -.21722000E+00, 0.13611800E+00, 0.59987800E-01, -.10430600E+00, 0.42726200E+00, -.93293200E-01, -.23716000E+00, -.37212100E+00, 0.28238500E-01, 0.50013600E-02, -.50420200E-01, -.92034600E-01, 0.13950800E+00, 0.16613400E+00, -.31973000E+00, -.11406000E+00, -.59115800E-01, -.11229100E+00, 0.54388100E+00, 0.21532000E+00, -.74533000E-01, 0.64655000E-01, 0.34858500E-01, 0.15352500E+00, -.18864600E-01, -.14375700E+00, -.57913800E-01, 0.43110200E+00, 0.49306700E+00, -.12937700E+00, 0.99025400E-01, -.91192100E-01, -.66964600E-01, -.10612800E-01, -.67211500E-01, 0.65825800E-01, 0.31211400E+00, -.27155000E+00, 0.24920500E-01, 0.18941000E+00, 0.11464100E+00, 0.22836000E-02, 0.18412800E-01, 0.40376900E+00, 0.10336400E+00, -.62980200E-01, 0.88072900E-01, 0.19427700E-01, 0.53538800E-01, -.58156500E-03, -.10488800E+01, -.14161700E+00, -.14741900E+00, 0.90706300E+00, 0.45681600E-01, 0.40145500E-01, -.90771600E-01, -.59814000E-01, -.90689500E-02, -.32716400E+00, -.83318400E-01, -.13691600E+00, -.16037500E+00, 0.17861100E+00, 0.26979300E-01, -.13111200E+00, -.16021200E-01, 0.24008800E+00, 0.32145800E-01, -.25452800E-01, 0.38023800E+00, -.17495600E-01, 0.11166900E+00, -.24780700E+00, -.32851200E-01, -.11616700E+00, 0.10280300E+00, -.24902500E-01, 0.18085600E+00, -.37062200E+00, -.37910400E-01, 0.18134000E+00, 0.57138100E-01, 0.44601800E-02, -.23592900E-01, -.13512700E-01, -.55143600E-01, 0.52465000E-01, -.10496800E+00, -.58382900E-02, 0.73804500E-02, -.10026800E+00, 0.25426900E-02, 0.84500000E-02, -.98089000E-01, 0.22940400E-01, -.41021700E-02, 0.46327900E-02, 0.33804800E-01, -.19370400E-03, -.14072800E+00, 0.56328100E-01, -.14171700E+00, -.11622400E+00, 0.22224200E-01, -.22073300E-01, -.29939700E-01, -.29673600E-02, 0.43902500E-01, -.33783100E-01, -.15209800E-01, 0.12206500E+00, 0.16710900E+00, -.49405300E-02, -.13428400E-03, 0.54965600E-02, 0.83024200E-02, 0.28314400E-02, 0.25051100E-01, -.21918500E+00, -.59903800E-01, -.29773000E+00, -.11518200E-01, -.11002600E+00, -.15309600E+00, 0.26697600E+00, -.56529300E-01, -.44756200E-01, 0.10330600E+00, -.55102500E-03, 0.13057800E-01, 0.38857800E-01, -.12261200E-01, 0.51452000E+00, -.44537300E-01, -.19222400E+00, -.28788900E-01, 0.49469100E-01, -.31501300E-01, 0.70871800E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.42641900E+01, 0.23986200E+01, 0.32020600E+01, 0.34580400E+02, -.38356900E+01, -.47986500E+00, 0.26711800E+01, 0.17794700E+01, -.10748700E+02, 0.21997400E+01, -.33624800E+01, 0.12403500E+01, 0.48286200E+01, 0.20500200E+01, -.15653700E+00, 0.36679000E+01, 0.43665700E+01, 0.23806700E+01, 0.14372200E+01, -.17579700E+01, 0.34200700E+00, 0.46346000E+01, 0.99724200E+01, -.10933400E+01, 0.10276500E+01, 0.82869100E+00, 0.13934900E+02, -.17954900E+01, -.11961700E+02, 0.20250700E+00, 0.91250000E+00, -.14207100E+01, 0.88617100E+00, -.27363300E+01, 0.32070200E+00, -.36376200E+01, -.60653400E+00, 0.23746000E+00, 0.73260300E+00, -.32234900E+00, -.48014600E+00, -.17365400E+01, 0.78968700E+00, 0.55656200E+00, 0.17396000E+00, -.41021800E+00, -.12787700E+01, -.97545500E+00, 0.94069500E-01, -.40500300E+00, 0.26161700E+00, -.33269600E+00, 0.29389900E+00, 0.16300300E+00, 0.22486800E+00, -.38418600E+00, 0.18501900E+00, 0.46129900E+00, 0.59230000E-01, 0.34190800E+00, 0.10844000E+00, 0.70819600E+00, -.56842800E-01, -.61094000E-01, 0.11212400E+00, 0.38533700E-01, -.25036300E+00, -.40323000E-01, -.30377400E+00, -.16737200E-01, 0.22777200E-01, 0.25194800E-01, 0.63247400E-02, 0.37855500E-01, -.32223000E+00, 0.98431600E-01, -.10409900E+00, -.27196700E+00, 0.15833700E+01, -.20817400E-01, -.72926700E-02, -.46113700E+00, -.51774100E+00, 0.41958700E+00, 0.22768600E+00, -.23239400E+00, -.93681100E-01, -.12070400E+00, -.22487300E+00, 0.72781200E-01, -.16718500E+00, 0.46393000E-01, -.26558400E-01, -.17978200E+00, 0.11247700E-01, -.16692500E+00, 0.18209100E+00, 0.17491800E+00, -.10950000E+00, 0.10512800E+00, 0.93012300E-01, -.25665900E-01, -.19138900E+00, -.84272600E-01, 0.26323600E+00, -.92727800E-01, -.13125100E+00, -.19556600E+00, -.31127800E+00, -.34013100E-02, -.58264800E-01, -.98353100E-01, 0.22302900E+00, 0.12992400E+00, 0.25456800E+00, -.36298700E+00, -.41090300E+00, 0.29635100E+00, -.62210700E-01, -.22257100E+00, 0.37217300E-01, -.99699900E-01, -.68206000E+00, -.18409000E+00, 0.24071500E+00, 0.41185100E-01, 0.88457700E-01, -.35655500E+00, -.39928800E-01, -.50305500E-01, -.10605500E+00, -.38771200E+00, 0.11881900E+00, -.34769200E+00, 0.44660800E-02, -.21723600E+00, 0.14260500E-01, -.16214900E-01, 0.36115300E-01, 0.29719600E-01, -.10265500E-01, 0.31075100E+00, -.10326000E-01, -.19390400E+00, 0.15629700E+00, 0.17445300E-01, -.10268700E+00, -.91155600E-01, 0.99321500E-01, 0.10109600E+00, 0.83238200E+00, 0.18104500E+00, 0.14936800E+00, 0.49745000E-01, 0.30155700E-02, 0.30681500E-01, 0.31586800E-01, 0.14604000E-01, -.25113000E-01, 0.29370100E-01, -.26855800E-01, 0.19144500E-01, -.14057300E+00, 0.27922400E-01, -.66205000E-01, -.19525300E+00, 0.92148600E+00, 0.31800500E+00, 0.66079100E-01, -.17004800E+00, 0.12912800E+00, 0.24377900E+00, 0.12566100E-01, 0.12021000E-01, -.32451600E-01, -.90191900E-02, 0.33222200E-01, 0.33006300E-01, -.39189800E-01, 0.23558600E+00, 0.43591900E-01, -.57995900E-01, 0.85982800E-01, -.19457600E+00, 0.90800600E-01, -.20068400E-01, 0.45198300E-01, -.16277200E+00, 0.33114700E-01, 0.65523300E-01, -.72706500E+00, 0.88093000E-01, -.11338800E+01, 0.11524900E+00, 0.44132300E+00, 0.70668900E-02, 0.11383500E+00, 0.25780100E+00, -.15583800E-01, 0.97528800E-01, 0.59061800E-01, -.41367900E-01, 0.36452000E-01, 0.26654500E-01, -.40307700E-01, 0.73081900E+00, 0.51187900E+00, -.52471900E-02, 0.19573700E+00, -.82684500E-01, 0.25864600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.56782200E+01, 0.22767400E+01, 0.45719500E+01, 0.41433000E+02, -.64502500E+01, -.54237600E+00, 0.34590700E+01, 0.26150100E+01, -.12197500E+02, 0.26893100E+01, -.37573500E+01, 0.11735300E+01, 0.74282100E+01, 0.23310800E+01, -.34850300E-01, 0.37303700E+01, 0.55939600E+01, 0.21943500E+01, 0.12823200E+01, -.25739300E+01, 0.62796300E+00, 0.66240900E+01, 0.10861800E+02, -.15298000E+01, 0.17569600E+01, 0.14201600E+01, 0.17920400E+02, -.24137700E+01, -.19395000E+02, 0.84098900E+00, 0.11894300E+01, -.19561400E+01, 0.11904400E+01, -.44577800E+01, 0.23047400E+00, -.23305900E+01, 0.52228100E+00, 0.28043800E+00, -.23406600E+00, -.29523100E+00, 0.18223800E+00, -.17878500E+01, 0.88570000E+00, 0.10639400E+01, -.14795600E+01, 0.15559300E+00, 0.88025400E+01, -.15657000E+01, 0.63895300E+00, -.74101300E-01, 0.21229000E+00, 0.67832600E+00, -.23490000E+00, 0.21979200E+01, -.77675700E+00, -.76168800E+00, 0.12116900E+01, 0.60648800E+00, 0.25564300E-03, 0.10135000E+00, 0.27552900E+00, 0.95912500E+00, -.42306100E+00, -.11920800E-01, -.63919700E+00, 0.97236000E+00, 0.40988700E-01, -.58120200E-01, 0.60128700E+00, 0.54398500E+00, 0.12594000E+00, -.11260700E+01, 0.88539900E+00, -.27646000E+00, -.26672400E+00, 0.86928600E+00, -.58382800E+00, -.73072900E+00, 0.23890400E+01, -.11731600E+00, 0.59741200E-01, 0.18131400E-01, -.33968100E+00, 0.39403100E+00, 0.61913400E+00, -.23449800E+01, -.15510300E+00, -.88937800E-01, -.20908900E+00, 0.49015800E+00, 0.92357400E-01, -.82489100E-01, 0.30013200E-01, -.23659900E+00, 0.10402100E+00, -.16043600E+01, 0.27123800E-01, 0.15466000E+00, 0.11490600E+01, -.25425200E+00, 0.65665700E-01, 0.31123600E+00, -.33975500E+00, 0.15762800E-01, 0.33044100E+00, -.12237500E+00, -.76435800E-01, -.16526100E+00, -.22054100E+00, 0.47045900E-01, 0.22348500E+00, 0.11484400E+00, 0.39184000E+00, 0.78210900E-02, 0.17492200E+01, 0.50370800E+00, -.16997100E+00, 0.13006700E+01, -.66825300E-01, -.44166000E+00, 0.24557800E+00, -.20820000E+01, -.38299400E+00, -.32239600E-01, 0.64756800E+00, 0.83762400E-01, -.91708400E-01, -.43308900E+00, -.99424200E-01, 0.17222500E+00, -.26358200E-01, 0.39634500E+00, -.33596200E+00, -.25690800E+00, 0.65796400E-01, -.36209400E+00, -.68492100E+00, -.62951100E-01, 0.47285800E+00, -.22773200E-01, -.24644500E+00, 0.10667800E+01, -.86412700E-01, 0.18543200E+00, -.22094500E+00, 0.22645200E-01, -.29053300E+00, -.51934200E+00, 0.20446700E+00, 0.49180200E-01, 0.33086300E+01, 0.61218000E+00, -.17496600E+00, 0.34983400E-01, 0.31191600E-01, 0.10008700E+00, 0.16135400E+00, 0.15502000E+00, -.34606500E+00, 0.23361000E+00, 0.41790400E-01, 0.65206300E-01, -.45611600E+00, 0.96029200E-01, 0.22585500E+00, -.48413300E+00, 0.64866400E+00, -.30468800E+00, -.15620600E-02, -.55166600E-01, -.11956200E+00, 0.18738000E+00, 0.14949000E+00, -.63375900E-01, -.84405500E-01, 0.32865800E-01, -.69705600E-02, -.24943300E-01, -.26174700E-01, 0.48434700E+00, 0.40552200E-01, -.79372700E-01, 0.35794800E+00, 0.70411700E-01, -.17954000E+00, 0.30202300E-01, 0.11411500E-01, -.47380900E-01, -.75553700E-01, 0.22056200E+00, 0.20280700E+00, 0.73222600E-01, 0.10645800E+01, -.15085500E+00, -.27778100E+00, 0.13110400E-01, 0.44450300E+00, 0.32104500E+00, -.30841800E+00, -.55288200E+00, -.52809800E+00, -.11052500E+00, 0.51722000E+00, -.11688000E+01, -.10238200E+01, 0.19737300E+00, -.10853200E+02, -.21870900E+00, 0.34706400E+00, 0.20514200E+01, 0.39944900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.19436700E+01, 0.30051600E+00, 0.23279900E+01, 0.12611700E+02, -.19790900E+00, -.38301100E+00, -.14102700E+00, 0.11578700E+01, -.35966000E+01, 0.75817800E+00, -.18236600E+01, 0.86466700E+00, 0.17365600E+01, 0.15954600E+01, -.13255300E+00, 0.11508700E+01, 0.19733600E+01, 0.61258500E+00, 0.42803200E+00, -.54246600E+00, 0.20657400E+00, 0.18828800E+01, 0.29602800E+01, -.90246100E+00, 0.45616400E+00, 0.43833300E+00, 0.78518500E+01, -.15201900E+01, -.84506200E+01, 0.10492800E+01, -.37957500E+00, -.36665000E-01, 0.10209800E+01, -.48441400E-01, -.80934600E+00, -.22184300E+00, -.40497900E+00, 0.10162500E+00, -.71004000E+00, 0.62007200E-02, 0.29690600E+00, 0.15773500E+00, -.21814300E+00, 0.59375600E+00, -.12509300E-01, 0.95087900E-01, 0.22773100E+01, -.84998200E+00, 0.19670800E+00, 0.92865500E-01, 0.12136400E+00, 0.67840300E+00, 0.42630500E+00, 0.10905800E+01, 0.47436000E+00, -.18967800E+00, 0.19133300E+00, 0.98980900E+00, -.83235400E-01, -.50484300E+00, 0.41567000E+00, 0.20935600E+00, -.27775000E+00, 0.17709900E+00, 0.57746200E+00, 0.18779300E+01, 0.33113300E+00, -.16009600E+00, -.73932500E+00, -.22443100E+00, -.21588300E+00, 0.97526600E-01, 0.24129700E-01, -.89711600E-01, -.24387300E+00, -.38914900E+00, -.16187800E+00, 0.20605700E+00, 0.14105100E+01, 0.11951700E+00, -.53450800E-01, -.37640300E+00, -.14889400E+00, 0.23124900E-01, -.25307100E+00, 0.75658900E+00, 0.99577300E-01, -.22080200E-01, -.75247200E-01, -.76159400E+00, 0.17025300E+00, 0.64420900E-01, 0.80829500E-02, -.91928800E-02, -.91553700E-01, -.11892800E+01, 0.14769000E+00, 0.14944400E+00, -.56805500E+00, -.47253100E+00, 0.14640200E+00, 0.13387900E+00, -.24357900E+00, -.17382400E+00, 0.73023100E-01, -.65676700E-01, -.20703900E-01, -.17577000E-01, 0.67935900E-01, -.23354500E+00, -.53304400E-01, 0.41309000E-01, 0.11346100E+00, 0.58808600E-01, 0.18861800E+00, 0.17235400E+00, 0.98128500E-01, 0.27975600E+00, -.26309700E-01, -.66689300E-01, 0.22587100E+00, -.67192400E+00, -.17870800E+00, -.87732000E-01, -.33236900E+00, 0.62843800E-02, -.63688800E-01, -.18802600E+00, -.66275600E-01, -.11988800E-01, -.47645200E-01, -.68967900E-01, -.43376100E-01, -.71003800E-01, -.51816100E-01, -.17537000E+00, -.62791600E-01, -.32834900E-01, 0.16054700E-01, -.15131000E-01, 0.86272100E-01, -.21364800E+00, -.55239600E-02, 0.22473400E+00, 0.12658200E+00, 0.29675900E-01, -.11882100E+00, -.24942900E+00, -.69065600E-01, -.16832700E+00, 0.15851900E+01, 0.47131200E-01, -.37593700E+00, -.11034300E+00, -.36398000E-02, 0.28794600E-01, -.22513800E-01, -.36607700E-01, 0.11468800E+00, 0.12872800E+00, 0.33094400E-01, 0.17399000E-02, -.90971900E-01, 0.17233700E-02, 0.53970800E-01, -.16450700E+00, 0.13805800E+01, -.20033100E+00, 0.44834300E-01, -.83486700E-01, 0.14030100E+00, 0.78180400E-01, 0.34807200E-01, -.54644600E-01, 0.34872800E-01, -.16218100E-02, 0.10846900E-02, -.59316300E-01, 0.39726300E-01, -.84571000E-01, 0.37889700E-01, -.21287300E-01, 0.69660400E-01, 0.25273200E-01, -.18048200E-01, 0.58726300E-02, 0.82917300E-02, 0.41457300E-01, -.26852500E-02, 0.46157900E-02, 0.11990900E+00, -.46878100E-01, 0.10330500E+00, -.54462100E-01, 0.41796900E-01, 0.76675100E-02, 0.40083800E-01, 0.13696400E-01, -.29690700E-01, -.13849900E+00, -.10386000E+00, -.63077100E-02, 0.38685000E-01, 0.29131600E-01, -.12339100E+00, 0.15805600E-01, 0.66041200E-01, 0.29964900E+00, -.66596800E-01, 0.68367000E-01, -.77525100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19118500E+01, -.86556100E+00, -.20027800E+01, -.14088900E+02, 0.17767000E+01, 0.10883500E+00, -.11198400E+01, -.81297300E+00, 0.42957900E+01, -.98528900E+00, 0.13109800E+01, -.43264100E+00, -.20934900E+01, -.99159900E+00, 0.10868400E+00, -.17032400E+01, -.20752200E+01, -.10205900E+01, -.56194900E+00, 0.92838200E+00, -.25495900E+00, -.22657300E+01, -.39982800E+01, 0.52357100E+00, -.55955000E+00, -.43894500E+00, -.60573300E+01, 0.81454700E+00, 0.58084200E+01, -.29981700E+00, -.31602700E+00, 0.54617300E+00, -.50739700E+00, 0.13058200E+01, 0.82197700E-02, 0.10465500E+01, 0.58429100E-01, -.71620000E-01, 0.25292500E-01, 0.61065400E-01, -.12057700E+00, 0.69662900E+00, -.30101200E+00, -.29635900E+00, 0.21090600E+00, -.21273500E-01, -.21690300E+01, 0.52635200E+00, -.21714900E+00, -.53447400E-01, -.67540000E-01, -.11581000E+00, 0.32719300E-01, -.72961700E+00, 0.11778500E+00, 0.18470600E+00, -.26691700E+00, -.26187600E+00, 0.31172300E-01, 0.63525000E-01, -.11443800E+00, -.38861500E+00, 0.10730900E+00, 0.34842800E-01, 0.84511700E-01, -.16529500E+00, -.41811500E-01, 0.17254800E-01, 0.12373400E+00, -.14661200E+00, -.23665600E-01, 0.31589100E+00, -.26409700E+00, 0.42365500E-01, 0.10426900E+00, -.25545700E+00, 0.16761800E+00, 0.14412900E+00, -.11831100E+01, 0.29717100E-01, 0.39007500E-02, 0.16371200E+00, 0.20106900E+00, -.66888500E-01, -.11460700E+00, 0.61405900E+00, 0.10253500E+00, 0.78354400E-01, 0.15713300E+00, -.11373700E+00, 0.77443200E-01, 0.33586300E-01, 0.12915100E-01, 0.11839800E+00, 0.46866200E-01, 0.73896100E+00, -.11324600E+00, -.77686900E-01, -.82410300E-01, 0.17498200E+00, -.82279300E-01, -.83753800E-01, 0.11025200E+00, 0.21037300E-01, -.12428200E+00, 0.58956400E-01, 0.89308800E-01, 0.16323600E+00, 0.10546000E+00, 0.10604300E+00, 0.92076600E-01, 0.35644400E-01, -.11756800E+00, -.36912200E-02, -.45029000E+00, -.12934100E-01, -.47699500E-01, -.34109100E+00, 0.30410600E-01, 0.10383200E+00, -.68512300E-01, 0.54022200E+00, 0.12113000E+00, -.46737900E-01, -.14790800E+00, 0.10375100E-01, 0.56105400E-01, 0.13864000E+00, -.18474800E-01, -.44470500E-01, 0.11957400E-01, -.74839400E-01, 0.55326600E-01, 0.11234400E+00, -.35013800E-01, 0.65796500E-01, -.88883600E-01, 0.44743700E-03, -.12798700E+00, 0.75447500E-02, 0.30627700E-01, -.30632000E+00, -.15775800E-02, 0.64576400E-01, -.88260700E-02, -.62438600E-02, -.12657500E-01, 0.19686200E-01, -.30605000E-01, 0.59362000E-02, -.21361700E+00, -.70647700E-01, -.79548000E-01, -.92662000E-02, -.88064500E-03, -.12584300E-01, -.17126100E-01, -.92963200E-02, 0.31900000E-01, -.25717600E-01, -.12026800E-01, -.24255000E-02, 0.15349500E+00, -.18533900E-01, -.73536200E-01, 0.18597300E+00, -.63748600E+00, 0.16788500E+00, 0.48006200E-01, 0.56448700E-01, -.10482600E-01, -.19492000E+00, 0.24242100E-02, -.23124000E-01, 0.93183500E-02, 0.40493000E-02, 0.43769200E-02, 0.21513200E-01, -.28225800E-02, -.16185400E+00, -.61167300E-01, 0.65708100E-01, 0.11624500E+00, -.74865100E-01, 0.10820300E+00, -.71040900E-03, 0.59218900E-02, 0.22180500E-01, 0.12476000E-01, -.51308100E-01, -.96195800E-01, 0.45723700E-02, -.30542600E+00, 0.29113500E-01, 0.11056700E+00, -.38248900E+00, -.86365400E-02, -.26612600E+00, 0.19078400E+00, 0.32497700E+00, 0.24061300E+00, -.12766800E-01, 0.24006200E+00, 0.26131800E+00, 0.21032000E+00, -.16992100E+00, -.22279100E+00, -.23668500E-01, 0.50205800E+00, -.12216800E+00, 0.41751900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.15061100E+02, -.87616400E+01, -.14031800E+02, -.11353600E+03, 0.14852700E+02, 0.89127400E+00, -.81424200E+01, -.49295800E+01, 0.33387800E+02, -.77920200E+01, 0.93041100E+01, -.36585800E+01, -.19323200E+02, -.60398700E+01, 0.17913100E+01, -.11295800E+02, -.14404300E+02, -.72321600E+01, -.37904200E+01, 0.71212400E+01, -.11048600E+01, -.22508800E+02, -.44569500E+02, 0.26614200E+01, -.59578600E+01, -.48541900E+00, -.26044900E+02, 0.92043600E+01, 0.52767200E+02, 0.37408700E+01, -.46538500E+01, 0.98165300E+01, -.47476500E+00, 0.17855700E+02, -.26682700E+01, 0.10872200E+02, -.27132400E+01, -.18519800E+01, -.26054200E+01, 0.22068600E+00, 0.77479200E+00, 0.53122700E+01, -.98429500E+00, -.15820900E+01, -.26909900E+01, 0.26420000E+01, 0.19135500E+02, 0.37749500E+01, 0.10455200E+01, 0.19990700E+01, 0.22479900E+00, -.53971900E+01, 0.21388500E+01, 0.28089100E+00, 0.35996100E+01, -.16353200E+01, 0.49030500E+01, 0.16379100E+01, 0.12600400E+01, -.94296800E-01, -.36500800E+00, -.46409900E+00, -.32047000E+00, 0.22746500E+00, 0.70408400E+00, -.33249900E+01, -.11563100E+01, 0.15511600E+00, 0.13651900E+01, -.16849500E+01, -.69951800E+00, 0.37016200E+00, -.45876700E+00, 0.28776500E+00, 0.10918800E+00, -.28948000E+01, -.88840600E+00, 0.20248400E+01, 0.63713100E+00, 0.12719500E+01, -.57082600E+00, 0.70904500E+00, -.75491200E+00, -.12991900E+01, -.22678600E+01, 0.35588000E+01, 0.34241700E+00, 0.36163000E+00, -.22537000E+01, -.35367800E+01, 0.80250600E+00, 0.53453100E+00, -.23509900E+00, -.10674500E+01, -.10452300E+00, -.47313700E+01, 0.76704700E+00, 0.39983600E+00, -.37461600E+00, -.20682000E+01, 0.47492100E+00, -.37798600E+00, -.13390800E+01, -.26899200E+00, -.81418700E-01, 0.37479300E+00, 0.77558400E-01, 0.22406400E+00, -.98228000E-01, 0.40307900E+00, 0.69119500E+00, 0.31958000E+00, -.45857400E+00, 0.80418900E+00, -.11415300E+01, 0.51270100E+00, -.25900500E+01, -.12618800E+01, 0.12851400E+00, -.60361100E+00, 0.25721300E+00, -.10460100E+01, 0.17249800E+01, 0.88009600E+00, 0.37628900E+01, 0.15444200E+00, 0.63595100E+00, 0.43992200E+00, 0.81367800E-01, 0.74402500E+00, 0.43047900E+00, 0.57474500E+00, -.23759300E+00, 0.61696800E+00, -.74349100E+00, 0.12872400E+00, -.27464900E+00, 0.86466200E-02, -.52445000E+00, -.94876600E-01, -.33193700E+00, -.30857300E+00, -.19917800E+00, 0.74640800E+00, -.15973300E+00, 0.33549900E-01, -.91654000E-02, -.40199900E+00, -.81762500E+00, -.47074800E+00, -.17092700E+01, 0.18623700E+01, -.73890500E+00, 0.19232400E+00, 0.11520100E-01, 0.23728600E+00, 0.89712500E+00, 0.54586500E+00, -.44939500E+00, -.15861800E-01, 0.11610200E+00, -.27465900E-01, 0.29411300E+00, 0.61792500E-01, 0.97981400E-01, 0.11556500E+01, 0.22946700E+01, -.96247200E-01, 0.12950000E+00, -.11345200E+00, 0.47838000E+00, -.10691900E+01, 0.13506600E+01, -.11415900E+01, 0.73969800E+00, -.86986200E-01, 0.11257700E+00, -.64921800E+00, 0.71454400E+00, 0.80800400E+00, 0.64725100E+00, -.11259600E+01, 0.36706600E+01, 0.75010900E+00, -.58164100E+00, 0.14757300E+00, 0.14064100E+00, 0.78729800E-01, -.24948300E+00, -.59036400E-01, 0.19240400E+01, 0.19358300E+00, 0.91071300E+00, -.12659900E+00, 0.34263200E+00, -.18643500E+00, 0.57444600E-01, -.12450000E+00, 0.32538200E+00, -.59610000E+00, -.30383000E+00, -.20983600E+00, -.43788500E+00, 0.12286000E+00, -.71835500E-01, -.17795700E+00, -.39513700E+00, -.61348300E+00, 0.41202400E+00, 0.43516100E+01, 0.42568300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.47534000E+01, 0.31041800E+01, 0.45598400E+01, 0.36110400E+02, -.62325200E+01, 0.79168400E-01, 0.32077000E+01, 0.10310000E+01, -.10696600E+02, 0.28236800E+01, -.22213100E+01, 0.34321200E+00, 0.47531700E+01, 0.20853000E+01, -.20363800E+00, 0.64928500E+01, 0.50403200E+01, 0.28937300E+01, 0.17847700E+01, -.19879300E+01, 0.34405900E+00, 0.58179600E+01, 0.11033700E+02, -.83289700E+00, 0.12466100E+01, 0.49116300E+00, 0.94082500E+01, -.20035000E+01, -.12171100E+02, -.46420700E+00, 0.12016000E+01, -.21797200E+01, 0.44787900E+00, -.37289900E+01, 0.68730900E+00, -.31983700E+01, 0.25800000E+00, 0.25237200E+00, 0.46450600E+00, -.19543000E+00, -.80569600E-01, -.21647800E+01, 0.10374200E+01, 0.16427100E+00, 0.68797300E+00, -.63386300E+00, -.44085200E+01, -.86735400E+00, -.26350300E+00, -.79436100E+00, 0.32045700E+00, 0.63116100E+00, -.45711000E+00, 0.42357500E+00, -.95841800E+00, 0.11526600E+00, -.45506900E+00, 0.16862100E+00, -.10039000E+00, 0.34717600E+00, 0.11051300E+00, 0.60888900E+00, 0.15450800E+00, -.47897600E+00, -.57317700E+00, -.75264300E+00, -.21400700E+00, 0.77458700E-02, 0.23497300E+00, 0.18106400E+00, 0.89846800E-01, -.55739200E-01, 0.14607100E+00, -.11198400E-01, -.78318700E-03, 0.65819100E+00, -.51974000E-01, -.31164900E+00, 0.33382100E+00, -.17554200E+00, -.40169100E-01, -.32366100E+00, -.63149000E-01, 0.46953400E+00, 0.72763900E+00, -.81843100E+00, -.20103900E+00, -.12024500E+00, -.23118200E+00, 0.40674300E+00, -.47076900E+00, 0.38237200E-02, 0.57164300E-01, -.23715700E+00, -.16522000E+00, 0.37905800E+01, -.49171100E-02, -.21420600E-01, 0.15576900E+01, 0.58563500E-01, 0.10672900E+00, 0.36346800E+00, -.12916600E+00, -.16608900E+00, 0.22826500E+00, -.42297000E+00, -.36290900E+00, 0.60496700E-01, -.23950800E+00, -.49502500E-02, -.10849500E+00, -.24083800E+00, 0.30010100E+00, 0.39935500E+00, -.42097900E+00, -.22518600E+00, 0.65530700E-01, 0.12726900E+00, -.19079600E-02, 0.76054900E-01, 0.32075500E-01, -.22034400E+00, -.58792100E+00, -.22635400E+00, 0.50164100E+00, 0.20367700E-01, -.81906400E-01, -.13583700E+00, -.14193200E+00, -.59661100E-01, -.33516100E+00, -.50711100E+00, 0.10370800E+00, -.98748100E-01, -.17869700E+00, -.17297500E+00, -.42793300E-01, -.48483500E-01, -.13833400E+00, 0.98769100E-02, 0.19366900E-01, 0.27910700E-01, 0.49465700E-02, -.33393100E+00, -.17246900E+00, -.10266500E+00, 0.25672100E+00, 0.76104000E+00, -.17598500E+00, -.67461000E-01, 0.77739600E+00, -.43259600E+00, -.20339100E+00, -.18733700E+00, 0.63276700E-02, -.19735400E-01, -.18824100E+00, -.20983400E+00, 0.25023300E+00, 0.19561300E+00, -.31362100E-02, 0.23056500E-01, -.16537200E+00, -.11915400E-02, 0.68426600E-01, 0.53875800E-01, -.21085400E+01, -.26578200E+00, -.15934700E+00, 0.84105100E-01, 0.11115400E-01, -.46287300E+00, 0.12582700E+00, -.13161800E+00, -.22924000E-01, 0.34215600E-01, -.10889500E+00, -.71418600E-01, 0.74254900E-02, 0.12271200E-01, -.43841500E-01, 0.56674900E-02, -.29362800E-01, 0.23731800E+00, 0.45095100E-01, -.14435000E-01, 0.96551900E-01, 0.13231000E+00, 0.12876400E+00, 0.72827100E-01, -.21007600E+00, 0.10130100E+00, -.49294600E+00, 0.69943400E-02, 0.25943400E+00, -.15269800E+00, 0.22412800E+00, 0.25480800E+00, 0.50845000E+00, -.80838000E+00, -.48079200E-02, -.60624200E-01, -.45398400E+00, -.98317100E-01, 0.99554200E-01, 0.29479100E+00, -.15922500E+00, -.11927600E+00, 0.24893700E+00, 0.37205500E-01, 0.50907600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
        },
        {
            { -.17195200E+06, 0.85610000E+05, 0.84423300E+05, 0.10341600E+05, 0.20779500E+05, 0.43829400E+05, -.19879400E+05, 0.45163600E+05, 0.28598600E+05, -.11314000E+06, 0.56389100E+05, 0.49440000E+05, 0.10640100E+05, 0.15148000E+05, 0.28055800E+05, -.88255400E+04, 0.57365100E+05, 0.20605700E+05, 0.53232800E+05, -.27066000E+05, -.27584600E+05, -.16252800E+05, -.28799700E+05, -.16121700E+04, 0.24274200E+05, 0.50535000E+05, -.25864900E+05, 0.97885200E+05, -.47820000E+05, -.33875800E+05, 0.20599600E+04, 0.11287300E+05, -.38942600E+05, -.18159500E+05, -.14707900E+06, 0.11525600E+04, 0.16444800E+06, -.81184200E+05, -.73680900E+05, 0.11100000E+05, 0.11916100E+05, -.62583600E+05, -.27251800E+05, -.19355000E+06, -.23816400E+04, -.13864000E+05, 0.68458600E+04, 0.68604500E+04, -.12537900E+04, -.29813800E+04, 0.60193100E+04, 0.36227900E+04, 0.23812400E+05, -.11667200E+04, -.53805800E+05, 0.26343700E+05, 0.20698900E+05, -.94442600E+04, -.12986100E+05, 0.27652400E+05, 0.23571800E+05, 0.74159500E+05, -.71701000E+04, -.98122000E+05, 0.48245500E+05, 0.44696300E+05, -.38728300E+04, -.52502300E+04, 0.35563700E+05, 0.83293200E+04, 0.93620400E+05, 0.29351400E+04, -.22325600E+05, 0.10506000E+05, 0.11151300E+05, -.15187100E+04, 0.21484800E+03, 0.87097900E+04, 0.48005700E+04, 0.89539400E+04, 0.10616200E+04, -.36794200E+05, 0.17235600E+05, 0.15569900E+04, -.13775200E+05, -.34780700E+05, 0.30460100E+05, 0.37014500E+05, 0.16954100E+06, -.22115100E+05, 0.16853700E+06, -.83308200E+05, -.79130300E+05, 0.96988900E+04, 0.87691100E+04, -.62223400E+05, -.25006900E+05, -.17505600E+06, -.52028400E+04, -.13587300E+05, 0.62685200E+04, 0.67914500E+04, -.12326900E+04, -.14870500E+03, 0.57763800E+04, 0.40222200E+04, 0.58318300E+04, 0.33466700E+03, -.29351100E+05, 0.14091900E+05, 0.82985700E+04, -.69312100E+04, -.16124900E+05, 0.18881600E+05, 0.15550400E+05, 0.66051900E+05, -.10163600E+05, 0.10767200E+06, -.53633600E+05, -.50261600E+05, -.20470600E+04, -.20472200E+04, -.33265000E+05, -.98296700E+03, -.86823100E+05, -.10234400E+05, 0.94170400E+05, -.46173300E+05, -.36338400E+05, 0.90967400E+04, 0.15677800E+05, -.41179000E+05, -.24771900E+05, -.12238900E+06, 0.46276500E+04, -.74367400E+05, 0.35847500E+05, 0.22814300E+05, -.78477000E+04, -.19637300E+05, 0.36788400E+05, 0.24975300E+05, 0.10768400E+06, -.98898100E+04, 0.14435800E+06, -.71419600E+05, -.63377900E+05, -.12067600E+05, -.18567400E+05, -.36108400E+05, 0.17524000E+05, -.37645800E+05, -.25324000E+05, 0.17339300E+06, -.85737500E+05, -.72152200E+05, -.12049600E+03, 0.42900200E+04, -.58632800E+05, -.91183000E+04, -.15852300E+06, -.10201200E+05, 0.63722300E+05, -.31829500E+05, -.32956200E+05, -.12608300E+05, -.23282900E+05, -.84881100E+04, 0.21943500E+05, 0.44840200E+05, -.22315900E+05, -.13086600E+06, 0.64911800E+05, 0.61845500E+05, 0.22530900E+04, 0.50445900E+04, 0.40182000E+05, -.31917000E+04, 0.68722900E+05, 0.13150500E+05, 0.51353000E+05, -.27069400E+04, 0.89830600E+05, 0.73908800E+05, 0.64117500E+05, 0.43792300E+05, 0.31587300E+05, -.41587500E+05, 0.78110200E+04, 0.38114400E+05, -.62128400E+05, -.36551100E+05, -.38917000E+05, -.39336800E+05, 0.73302600E+04, -.37069500E+05, 0.37934600E+05, -.74092900E+04, 0.35641800E+04, 0.82198400E+05, -.20796200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.22486400E-01, 0.13855800E+04, 0.34534500E+02, 0.21375500E+03, 0.10902700E+04, -.22222900E+03, 0.21606700E+02, -.94305900E+03, 0.91383400E+03, -.24965700E+04, 0.15097100E+04, 0.14068700E+04, 0.16262600E+03, 0.67371800E+03, 0.53912400E+03, -.15591800E+03, -.95526900E+03, 0.10261000E+04, 0.49974100E+04, 0.21202300E+04, -.24789200E+04, 0.17431200E+04, 0.69876700E+04, -.33775300E+04, -.26551000E+04, -.54799100E+04, 0.46769900E+04, -.41636600E+04, -.67499700E+04, 0.17494600E+04, -.29318000E+04, -.57925700E+04, 0.34899400E+04, 0.29365600E+04, 0.77001100E+04, -.83183500E+04, 0.10375100E+05, -.12334900E+05, -.53715700E+04, -.24521200E+04, -.70636900E+04, -.24104100E+04, -.28273700E+04, 0.31519600E+04, -.14080300E+05, -.10357800E+04, 0.11256000E+04, 0.51931000E+03, 0.31572000E+03, 0.94843200E+03, 0.24487800E+03, 0.44163700E+03, -.45660000E+03, 0.98730200E+03, -.65456500E+04, 0.76469300E+04, 0.34088500E+04, 0.52195900E+03, 0.68383600E+04, 0.24411500E+04, 0.50071400E+04, 0.36663000E+03, 0.15089900E+05, 0.13192800E+05, 0.11794700E+02, -.65006200E+04, 0.27738100E+04, 0.71352500E+04, -.68447800E+04, -.52232000E+04, -.93311800E+04, 0.83995800E+04, 0.88442900E+04, 0.28272200E+04, -.44218900E+04, 0.14546400E+04, 0.88584800E+04, -.34472300E+04, 0.88671200E+03, -.36290000E+04, 0.11935600E+05, 0.36931200E+04, 0.79099700E+04, -.14778500E+04, 0.27922400E+04, 0.14391200E+05, -.39886700E+04, -.24245200E+04, -.95716300E+04, 0.10514900E+05, 0.13796100E+05, -.13525500E+05, -.70077700E+04, -.85898000E+03, -.96554500E+04, -.45706800E+04, -.57987800E+04, 0.34825700E+03, -.16120900E+05, 0.75826600E+04, 0.21631500E+04, -.37912800E+04, 0.10459600E+04, 0.74591700E+04, -.28610300E+04, 0.57901200E+03, -.29394900E+04, 0.95634500E+04, -.25743200E+04, 0.60529000E+04, 0.14255800E+04, 0.16856900E+04, 0.47735800E+04, 0.72265100E+03, 0.30060100E+04, -.13005700E+04, 0.64124300E+04, -.80220900E+04, 0.34168000E+04, 0.39342500E+04, -.94906300E+03, -.69592800E+04, 0.47187600E+04, 0.51628800E+04, 0.70613600E+04, -.49613300E+04, 0.79092700E+04, -.11007200E+05, -.41900900E+04, -.36895800E+03, -.11643300E+05, -.27551500E+04, -.51609700E+04, 0.77452400E+03, -.13269000E+05, 0.13940700E+03, 0.11276100E+05, 0.24427700E+03, 0.29041300E+04, 0.10872100E+05, -.50672900E+03, 0.51976000E+04, -.36516700E+04, 0.16917500E+05, -.46482500E+04, -.28920400E+04, 0.21278900E+04, -.74136200E+03, -.25242900E+04, 0.17051100E+04, -.45157600E+03, 0.21465100E+04, -.11818000E+04, -.20488400E+05, 0.36713500E+04, 0.99242100E+04, -.31278300E+04, -.13540700E+05, 0.11199100E+05, 0.10456800E+05, 0.15480500E+05, -.12434900E+05, -.33831400E+04, 0.19608900E+04, 0.17129600E+04, 0.56025400E+03, 0.11380700E+04, 0.54530800E+03, -.87695300E+03, -.11500500E+04, 0.10879300E+04, 0.15999100E+04, 0.24626800E+04, -.72079000E+03, 0.13483300E+04, 0.30879400E+04, -.17327500E+04, -.12878000E+04, -.35669000E+04, 0.56973700E+04, -.13835900E+04, 0.49364400E+04, -.52878300E+04, -.24718900E+03, -.15944500E+04, -.37679500E+04, 0.90650700E+04, -.36803500E+04, 0.50671600E+04, -.29645800E+04, 0.13664200E+04, 0.20721100E+04, 0.22721200E+04, -.11852900E+05, -.96319600E+04, 0.20926500E+04, 0.93983100E+04, 0.40370600E+04, 0.80403500E+04, -.26423400E+04, -.34579400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19176800E+01, -.21579100E+01, 0.21265700E+04, -.10282500E+05, -.20201600E+05, 0.82467100E+04, 0.11311400E+05, 0.31705900E+04, -.13367700E+05, 0.80714000E+05, -.39966900E+05, -.29928900E+05, -.17800300E+05, -.22550700E+05, -.12456800E+05, 0.13396400E+05, -.43346600E+05, -.24150400E+05, -.68725400E+05, 0.38113100E+05, 0.36374600E+05, 0.71916700E+04, 0.14334600E+05, 0.16017700E+05, -.11948800E+05, -.18668600E+05, 0.17278300E+05, -.55646200E+05, 0.20846400E+05, 0.50821400E+04, 0.20081400E+05, 0.19163800E+05, 0.15595300E+04, -.15274800E+05, 0.89965000E+05, 0.16595400E+05, 0.42587400E+05, -.29792400E+05, -.35740200E+05, 0.28551100E+05, 0.26725700E+05, -.42031200E+05, -.45331300E+05, 0.64121800E+05, 0.94715200E+04, -.12391400E+05, 0.60910500E+04, 0.63279000E+04, -.25183200E+04, -.42251800E+04, 0.72553800E+04, 0.45732000E+04, -.68941000E+04, -.18917800E+04, -.19030900E+06, 0.97688800E+05, 0.10492800E+06, -.13628300E+05, -.72781900E+04, 0.83108000E+05, 0.58359300E+05, 0.50951000E+05, 0.21078700E+05, -.21867400E+05, 0.16740100E+05, 0.17580400E+05, -.89665100E+04, -.12935500E+05, 0.14312100E+05, 0.61351300E+04, -.29599100E+05, -.23242100E+04, -.80384700E+05, 0.48218900E+05, 0.40208500E+05, -.44747900E+04, 0.11923800E+05, 0.36340700E+05, 0.34595600E+05, 0.36883500E+05, 0.22024700E+05, -.50679200E+05, 0.32355700E+05, 0.51940500E+05, -.16454200E+05, -.99640900E+04, 0.28627300E+05, 0.85903000E+04, -.79247400E+05, -.18716300E+04, 0.11733200E+06, -.66086300E+05, -.67506400E+05, 0.29791000E+05, 0.22106700E+05, -.72731600E+05, -.67641900E+05, 0.17872000E+05, 0.30311800E+03, -.56686600E+05, 0.35648400E+05, 0.28346500E+05, -.33403300E+04, 0.11353400E+05, 0.26662300E+05, 0.27025100E+05, 0.26990500E+05, 0.17973700E+05, -.11126900E+06, 0.62172300E+05, 0.65623400E+05, -.37591900E+04, -.16930800E+04, 0.42920900E+05, 0.23177900E+05, 0.88166300E+04, 0.11437600E+05, -.10505100E+05, 0.45854800E+04, -.65331900E+03, 0.14717800E+05, 0.17151800E+05, -.71230000E+04, -.50439000E+04, 0.37147900E+05, 0.12570400E+05, 0.14893200E+06, -.80010100E+05, -.91343700E+05, 0.20597300E+05, 0.90862400E+04, -.71514900E+05, -.51627300E+05, -.10521400E+05, -.98378200E+04, -.20568900E+06, 0.11638300E+06, 0.12503100E+06, -.14013100E+05, -.69962600E+04, 0.87430500E+05, 0.60817200E+05, 0.35768800E+05, 0.22471400E+05, -.29706200E+05, 0.11163100E+05, 0.21773700E+04, 0.12477700E+05, 0.16770800E+05, 0.17884000E+04, -.10961900E+05, 0.76917200E+04, 0.14264800E+05, -.58161300E+04, -.22019300E+04, -.19419200E+05, 0.23442400E+05, 0.22562200E+05, -.12844200E+05, -.74118700E+04, 0.66006700E+05, 0.11791700E+05, -.13915000E+05, 0.71664900E+04, 0.95763300E+04, 0.12175900E+04, 0.43410900E+04, 0.42459500E+04, -.83188800E+04, -.35246400E+05, 0.35199100E+04, -.69455200E+05, 0.36031700E+05, 0.40033700E+05, -.81988500E+04, -.15398500E+05, 0.30929700E+05, 0.17656100E+05, 0.99630800E+04, -.12524000E+04, 0.28122100E+05, -.80319800E+05, 0.17104700E+05, 0.77860100E+04, 0.24762000E+05, 0.19867600E+05, 0.19331900E+05, 0.69441800E+04, 0.12676000E+05, -.97080600E+04, -.16630800E+05, -.18179100E+04, 0.64639900E+04, -.10519000E+05, -.42170800E+05, 0.20134800E+05, 0.10616100E+05, -.75552300E+05, 0.19548500E+05, 0.18416700E+05, 0.66580600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.52380700E+00, 0.23186200E+00, 0.21992800E+00, 0.83795600E+04, 0.11088600E+05, -.45787300E+04, -.53325100E+04, -.13732700E+05, 0.71385100E+04, -.98743000E+05, 0.49223400E+05, 0.49530700E+05, 0.17035600E+05, 0.26998200E+05, 0.17195600E+05, -.21677800E+05, -.99519900E+04, 0.27193200E+05, -.11969000E+06, 0.58913000E+05, 0.59508700E+05, 0.22333000E+05, 0.36100000E+05, 0.18466800E+05, -.28652400E+05, -.21152100E+05, 0.35501600E+05, 0.27936200E+06, -.13791400E+06, -.13945500E+06, -.49339100E+05, -.80353500E+05, -.44854600E+05, 0.67332900E+05, 0.39053800E+05, -.79487100E+05, 0.27711600E+06, -.13659600E+06, -.13754800E+06, -.65776800E+05, -.98665300E+05, -.31471100E+05, 0.90836500E+05, 0.70145100E+05, -.91074500E+05, -.45013200E+05, 0.22496600E+05, 0.22480900E+05, 0.90935900E+04, 0.14867900E+05, 0.63413000E+04, -.12375500E+05, -.80687000E+04, 0.14256600E+05, -.60601300E+05, 0.29603900E+05, 0.30024900E+05, 0.28199800E+05, 0.38125400E+05, -.72967700E+04, -.49243400E+05, -.45961600E+05, 0.28663700E+05, -.13365900E+06, 0.65426900E+05, 0.66631400E+05, 0.29528000E+05, 0.46329600E+05, 0.17763000E+05, -.37882200E+05, -.31141600E+05, 0.42108000E+05, 0.30332900E+05, -.16958100E+05, -.15166600E+05, 0.27105700E+04, -.28257900E+04, -.13268600E+05, -.10479100E+05, -.13973000E+05, -.71321100E+04, -.32096700E+06, 0.15861100E+06, 0.15966200E+06, 0.62164600E+05, 0.99440500E+05, 0.47884800E+05, -.81149200E+05, -.55844700E+05, 0.97166700E+05, 0.22193600E+06, -.10923800E+06, -.11016500E+06, -.60612700E+05, -.86769400E+05, -.17583800E+05, 0.88739100E+05, 0.72591000E+05, -.77877500E+05, 0.21062500E+05, -.12182300E+05, -.10531400E+05, 0.18615600E+04, -.30216600E+04, -.95214600E+04, -.83010000E+04, -.97867000E+04, -.58993300E+04, -.10523800E+06, 0.51140600E+05, 0.52038800E+05, 0.25831600E+05, 0.40882500E+05, 0.10359500E+05, -.38546800E+05, -.30347400E+05, 0.36552000E+05, 0.12407700E+06, -.61783600E+05, -.61505500E+05, -.27220300E+05, -.41038500E+05, -.17797200E+05, 0.31169700E+05, 0.25383700E+05, -.38947500E+05, 0.14843800E+06, -.72826800E+05, -.73735500E+05, -.44063200E+05, -.62400700E+05, -.81773000E+04, 0.66072900E+05, 0.56882900E+05, -.55163800E+05, -.13019600E+06, 0.62093100E+05, 0.64192500E+05, 0.39285200E+05, 0.59031200E+05, 0.50548300E+04, -.63625800E+05, -.54488700E+05, 0.49021600E+05, -.38532500E+04, 0.26782300E+04, 0.16453200E+04, -.52704500E+04, -.65378100E+04, 0.37781600E+04, 0.25398800E+04, 0.87581400E+04, -.37140000E+04, 0.22935200E+06, -.11330700E+06, -.11427800E+06, -.48803700E+05, -.74739200E+05, -.32827300E+05, 0.59360100E+05, 0.47829000E+05, -.69984300E+05, -.11191400E+06, 0.55798500E+05, 0.55420200E+05, 0.18932800E+05, 0.32042500E+05, 0.18329500E+05, -.25275600E+05, -.15378400E+05, 0.32900400E+05, -.66070000E+05, 0.32646700E+05, 0.32971600E+05, 0.20505100E+05, 0.32029700E+05, 0.42519500E+04, -.26288100E+05, -.28273500E+05, 0.26440000E+05, 0.52631500E+05, 0.94841400E+05, -.58359800E+05, 0.17913200E+05, -.21837900E+05, -.89426400E+04, 0.55983500E+03, -.42649300E+05, 0.14670100E+05, 0.69689000E+05, -.13459500E+04, 0.82013300E+04, -.68443500E+05, -.26234600E+05, -.16280500E+05, -.16758400E+05, 0.33828500E+05, 0.95257200E+05, 0.12527900E+05, 0.14897600E+05, -.73130600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11480900E+01, -.10911400E+01, -.23636900E-01, -.71535200E+00, -.11754700E+05, 0.46679400E+04, 0.82343900E+04, 0.64269300E+03, -.79119700E+04, 0.29091700E+05, -.14733200E+05, -.12203400E+05, -.72038500E+04, -.14000800E+05, -.73431700E+03, 0.10322200E+05, -.89945000E+04, -.13819200E+05, 0.18186100E+05, -.11970800E+05, -.56329400E+04, -.23309000E+05, -.39196200E+05, 0.15219000E+05, 0.31325400E+05, 0.44205600E+05, -.30478300E+05, -.90915900E+05, 0.50467900E+05, 0.36374900E+05, 0.39835300E+05, 0.65094300E+05, -.11786800E+05, -.57975900E+05, -.35751100E+05, 0.59200900E+05, -.57528300E+05, 0.37185300E+05, 0.15181500E+05, 0.61938400E+05, 0.10218500E+06, -.47189900E+05, -.11132500E+06, -.83758000E+05, 0.78949100E+05, -.11890300E+05, 0.61937100E+04, 0.61328300E+04, -.85967900E+04, -.15809200E+05, 0.14280100E+05, 0.18604400E+05, 0.21821300E+05, -.10948100E+05, -.21892100E+06, 0.10722100E+06, 0.11515600E+06, -.35858800E+05, -.57243000E+05, 0.12146500E+06, 0.12279800E+06, 0.14584000E+06, -.18031300E+05, -.10152600E+05, 0.84486800E+03, 0.82256700E+04, -.23694500E+05, -.48765000E+05, 0.28442600E+05, 0.39136900E+05, 0.41808700E+05, -.33003800E+05, -.17024100E+06, 0.81825600E+05, 0.85122700E+05, -.12931000E+05, -.13877400E+05, 0.79269900E+05, 0.73581700E+05, 0.79646600E+05, 0.79218000E+04, 0.46127200E+05, -.27891800E+05, -.66695900E+04, -.62705200E+05, -.10461700E+06, 0.46656600E+05, 0.96088600E+05, 0.97807200E+05, -.81700800E+05, 0.81210000E+05, -.33219500E+05, -.49614900E+05, 0.60890600E+05, 0.96565800E+05, -.99321800E+05, -.14566100E+06, -.13155300E+06, 0.63688000E+05, -.13707900E+06, 0.65020700E+05, 0.68540600E+05, -.10849200E+05, -.10886100E+05, 0.64207400E+05, 0.59639200E+05, 0.64419000E+05, 0.64403100E+04, -.13351200E+06, 0.59822400E+05, 0.73202000E+05, -.29736500E+05, -.53059700E+05, 0.79673700E+05, 0.78850200E+05, 0.10723600E+06, -.26309800E+05, -.12279700E+05, 0.68076800E+04, 0.73581300E+03, 0.24677700E+05, 0.47607500E+05, -.22053300E+05, -.38574000E+05, -.34753300E+05, 0.36065700E+05, 0.14117200E+06, -.65969000E+05, -.80338500E+05, 0.48282500E+05, 0.77538600E+05, -.10464500E+06, -.12455800E+06, -.13711800E+06, 0.43164600E+05, -.28031600E+06, 0.12826000E+06, 0.15231900E+06, -.51297800E+05, -.86778200E+05, 0.15676500E+06, 0.15393200E+06, 0.19555600E+06, -.35135600E+05, -.43367500E+04, 0.43097500E+04, 0.25205500E+03, 0.17502500E+04, 0.10241000E+05, -.23681800E+04, -.60672800E+04, 0.11939700E+04, 0.71505100E+04, -.11967900E+05, 0.10157700E+05, -.46218500E+04, 0.43168400E+05, 0.81939200E+05, -.41259800E+05, -.69864900E+05, -.65886100E+05, 0.59786800E+05, 0.91271600E+05, -.45664900E+05, -.39931800E+05, -.23853700E+05, -.35464900E+05, -.86746300E+04, 0.24658300E+05, 0.18324600E+05, -.36107800E+05, -.58913400E+05, 0.28502600E+05, 0.31203100E+05, -.73295600E+04, -.22790100E+05, 0.33319900E+05, 0.30383200E+05, 0.35507700E+05, -.11887400E+05, 0.37060000E+05, -.12361400E+06, 0.10619900E+06, 0.51958600E+05, 0.82584900E+05, 0.69434000E+05, 0.11082800E+05, 0.26433500E+05, 0.23555600E+05, -.31592300E+05, -.62650200E+05, -.42207600E+05, 0.29727600E+05, 0.11743200E+05, -.25249400E+05, 0.15677500E+05, -.12889000E+05, -.12347300E+06, 0.19780600E+05, 0.83594800E+05, 0.10937300E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.88495500E-02, 0.35933300E+01, -.65405300E-01, 0.73270400E-01, -.18504100E-03, 0.26332900E+03, 0.42379800E+03, 0.17931200E+04, -.10616500E+04, 0.96031200E+04, -.48937600E+04, -.47711000E+04, -.14789400E+04, -.22596900E+04, -.15843000E+04, 0.20531900E+04, 0.20475200E+04, -.41048100E+04, 0.20372500E+05, -.11590200E+05, -.10124900E+05, -.16326000E+04, -.76677400E+04, -.41151800E+04, 0.25539300E+04, 0.22325300E+04, -.91209800E+04, -.99873300E+04, 0.75472500E+04, 0.48397500E+04, 0.85310600E+04, 0.60800000E+04, -.58226600E+04, -.17319100E+05, -.17940000E+05, 0.26075400E+05, -.62170400E+05, 0.34607100E+05, 0.30828900E+05, 0.42719800E+04, 0.34666900E+04, 0.16310100E+05, 0.24064100E+04, 0.12564900E+04, 0.44240800E+05, 0.13367900E+05, -.64911500E+04, -.66808800E+04, -.26885900E+03, -.36909000E+03, -.45892100E+04, -.24678500E+04, -.25761600E+04, -.28248200E+04, 0.70593400E+05, -.36233600E+05, -.35201700E+05, 0.38819300E+04, 0.52989200E+04, -.27753800E+05, -.23255700E+05, -.22099500E+05, -.44861200E+05, 0.38259500E+03, -.23411200E+04, -.13618900E+03, -.48685100E+04, -.39262600E+04, 0.61065300E+04, 0.13105900E+05, 0.13223000E+05, -.22726400E+05, 0.28560600E+05, -.16722500E+05, -.14280300E+05, 0.25829100E+04, 0.20022400E+04, -.12544300E+05, -.13350000E+05, -.12409800E+05, -.29952800E+05, 0.70770800E+05, -.37858400E+05, -.35090600E+05, -.23009500E+04, -.16250100E+05, -.20059700E+05, -.41176900E+04, -.43979600E+04, -.23341200E+05, -.92255400E+05, 0.49149900E+05, 0.45961200E+05, -.29629600E+04, 0.33521800E+04, 0.32429000E+05, 0.20964400E+05, 0.19154200E+05, 0.47205700E+05, 0.24377700E+05, -.14685100E+05, -.12188800E+05, 0.26076700E+04, 0.81792400E+03, -.10950200E+05, -.11890300E+05, -.10934700E+05, -.23889300E+05, 0.50898100E+05, -.28439800E+05, -.25323800E+05, 0.46341500E+03, 0.70570200E+03, -.19313900E+05, -.14843200E+05, -.13479100E+05, -.17705800E+05, -.15792100E+05, 0.81670000E+04, 0.77888900E+04, 0.79416800E+03, 0.87439500E+04, 0.21755300E+04, -.46743700E+04, -.40564400E+04, 0.11053500E+05, -.97155200E+05, 0.50640200E+05, 0.48410000E+05, -.60559400E+04, 0.60632700E+04, 0.37941300E+05, 0.29162500E+05, 0.28164300E+05, 0.33939100E+05, 0.82069700E+05, -.46513600E+05, -.40809700E+05, 0.17226300E+04, 0.33098600E+04, -.31300700E+05, -.25914100E+05, -.22644900E+05, -.46944600E+05, 0.55152200E+03, 0.93119500E+03, -.29642000E+03, 0.14101700E+03, 0.25897600E+03, -.16138600E+03, 0.31123300E+03, -.10506600E+04, 0.49218600E+03, -.11740800E+05, 0.78819400E+04, 0.56903700E+04, 0.50278300E+04, 0.13490300E+05, -.46738400E+04, -.16721100E+05, -.16483300E+05, 0.30775400E+05, 0.14560100E+05, -.73412200E+04, -.71730100E+04, -.24609700E+04, -.43398400E+04, -.22816100E+04, 0.34721100E+04, 0.28678900E+04, -.44430700E+04, -.90583900E+03, -.35701800E+02, 0.48313900E+03, -.29067300E+04, -.26040700E+02, 0.44183100E+04, 0.85345700E+04, 0.93750200E+04, -.15976900E+05, -.20292000E+05, 0.45473900E+04, -.61886200E+04, -.14603700E+05, -.14828900E+05, -.93346900E+04, -.21011300E+05, 0.14231500E+05, -.20481400E+05, 0.35579400E+04, 0.10446000E+05, 0.16006800E+05, -.52169500E+03, 0.20654100E+05, 0.18718100E+05, -.11017900E+05, -.19066100E+05, 0.40547900E+04, -.18461500E+05, -.15029200E+05, -.90960300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.75422200E-01, 0.14296800E+01, 0.30959100E-01, 0.31981200E-01, -.43609900E-01, -.83634900E-01, 0.63291800E+03, -.32793100E+03, -.68055600E+02, 0.35000100E+02, -.90679500E+02, 0.59840100E+02, -.13419900E+03, -.96026900E+02, 0.21134700E+02, 0.46233100E+03, -.46001000E+03, -.22666300E+03, -.27983600E+04, 0.38458400E+03, 0.15281600E+04, -.87610500E+03, -.23763000E+04, 0.16226800E+04, 0.21864000E+04, 0.23661600E+04, -.16606600E+04, 0.53578600E+03, 0.15582700E+04, -.60919600E+03, 0.17485100E+04, 0.20081100E+04, -.13333400E+04, -.23816100E+04, -.18440600E+04, 0.33500000E+04, -.31341500E+04, 0.41169900E+04, 0.10225300E+04, 0.88626800E+03, 0.26338700E+04, 0.79062900E+03, -.12498800E+04, 0.24123600E+03, 0.44260500E+04, 0.37535400E+03, -.83733900E+02, -.18139000E+03, -.19788000E+03, -.29253100E+03, 0.33532400E+02, 0.55389700E+03, 0.28441400E+03, -.42103800E+03, 0.59191100E+03, -.10160000E+04, -.88574300E+02, 0.51796500E+03, -.16942000E+04, -.48144100E+03, 0.18361000E+03, 0.82300900E+02, -.46133500E+04, -.27493600E+04, -.15694300E+03, 0.14936400E+04, -.10626200E+04, -.26679000E+04, 0.18830000E+04, 0.18959000E+04, 0.21623800E+04, -.29368400E+04, -.56513300E+04, 0.10425400E+04, 0.28257300E+04, -.45672700E+02, -.24357700E+04, 0.21041600E+04, 0.14380000E+04, 0.19596600E+04, -.41661400E+04, -.32150000E+04, -.20094700E+03, 0.22484600E+04, -.17726800E+04, -.48495600E+04, 0.23564700E+04, 0.45936800E+04, 0.35111100E+04, -.38502000E+04, -.15216100E+04, 0.29867700E+04, 0.41282000E+03, 0.37780500E+03, 0.33112700E+04, 0.30009500E+03, -.13918500E+04, -.24135400E+03, 0.58414500E+04, -.43315400E+04, 0.39138500E+03, 0.21658100E+04, -.19309400E+03, -.24508800E+04, 0.17666500E+04, 0.89871500E+03, 0.17071900E+04, -.38233500E+04, -.21012400E+04, -.10725100E+04, 0.13114300E+04, -.88820300E+03, -.17573700E+04, 0.10279400E+04, 0.14049800E+04, 0.18230000E+04, -.25535900E+04, 0.22566800E+04, -.92455400E+03, -.13523800E+04, 0.86232200E+03, 0.33266800E+04, -.19593400E+04, -.27777100E+04, -.23414800E+04, 0.26172900E+04, -.94817300E+03, 0.20116400E+04, 0.11015600E+03, 0.19761600E+03, 0.38785400E+04, 0.20245700E+03, -.82229300E+03, -.55833100E+03, 0.47928800E+04, -.56032200E+04, -.11325100E+04, 0.32767100E+04, -.94050200E+03, -.31797500E+04, 0.21455400E+04, 0.24938000E+04, 0.30434700E+04, -.57082300E+04, 0.50293000E+03, 0.61855100E+03, -.31067100E+03, 0.29149700E+03, 0.43072800E+03, -.20311200E+03, -.47371400E+03, 0.54119700E+02, 0.21651100E+03, 0.54269500E+04, -.12818400E+04, -.31086300E+04, 0.16703200E+04, 0.57015900E+04, -.38574100E+04, -.47215400E+04, -.44850100E+04, 0.50690700E+04, 0.25629200E+04, -.13332100E+04, -.10583100E+04, -.82491000E+03, -.10889800E+04, -.24098000E+03, 0.75044400E+03, 0.68904800E+03, -.11036900E+04, -.39737500E+04, 0.16344500E+04, 0.20531700E+04, -.12527800E+03, 0.61696400E+02, 0.14847500E+04, 0.19856000E+04, 0.11492500E+04, -.11779500E+04, 0.84566700E+03, -.34172900E+04, 0.25036100E+04, 0.43496300E+03, 0.18266800E+04, 0.16342600E+04, -.29082900E+04, 0.32825800E+04, -.81350600E+03, 0.21427500E+04, -.10518600E+04, -.34350700E+03, -.20254800E+04, 0.43129600E+04, 0.17745800E+04, 0.37199800E+03, -.39898400E+04, -.31901800E+04, -.17428000E+04, 0.23346700E+04, 0.26925700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36776600E+00, -.56003000E+00, 0.26507500E+00, 0.21771700E+00, 0.71155800E-01, 0.12502100E+00, 0.22808400E+00, 0.47815200E+04, 0.33906900E+03, 0.23171200E+05, -.11488400E+05, -.11933100E+05, -.33382100E+04, -.67747100E+04, -.41930300E+04, 0.68531700E+04, 0.16326300E+05, -.61407000E+04, 0.92772000E+05, -.45305400E+05, -.46791600E+05, -.17250700E+05, -.27323600E+05, -.14101000E+05, 0.22832400E+05, 0.23480800E+05, -.27882600E+05, -.14658300E+06, 0.71344700E+05, 0.74249200E+05, 0.23594100E+05, 0.43749400E+05, 0.24694500E+05, -.34165100E+05, -.50236000E+05, 0.39724200E+05, -.17529700E+06, 0.84802600E+05, 0.88850200E+05, 0.28985100E+05, 0.54876200E+05, 0.28592300E+05, -.43000700E+05, -.64054300E+05, 0.46664200E+05, 0.21457800E+05, -.10893900E+05, -.10757000E+05, -.51397800E+04, -.89025400E+04, -.19616300E+04, 0.83490600E+04, 0.12054600E+05, -.80204400E+04, 0.74521400E+05, -.36488700E+05, -.37981500E+05, -.13210200E+05, -.24397600E+05, -.11741900E+05, 0.19419500E+05, 0.22522900E+05, -.14406800E+05, 0.86888000E+05, -.41881000E+05, -.43786800E+05, -.13140600E+05, -.23784800E+05, -.15767600E+05, 0.17238300E+05, 0.25177800E+05, -.20291000E+05, -.92694400E+03, 0.20597100E+04, 0.46312400E+03, 0.29172700E+03, -.94270100E+03, 0.41049700E+03, 0.85430500E+03, 0.60771100E+03, 0.63596800E+04, 0.19436800E+06, -.95247100E+05, -.98759600E+05, -.36520600E+05, -.58467900E+05, -.28929300E+05, 0.52943400E+05, 0.68151600E+05, -.58624500E+05, -.14924200E+06, 0.72164900E+05, 0.75542300E+05, 0.26346900E+05, 0.47902400E+05, 0.23253900E+05, -.39881300E+05, -.58036300E+05, 0.39077500E+05, -.12041800E+04, 0.22798400E+04, 0.60202900E+03, 0.18058600E+03, -.37695600E+03, 0.52385000E+03, 0.10478600E+04, 0.57261400E+03, 0.52320500E+04, 0.71191300E+05, -.33275500E+05, -.36109000E+05, -.15700200E+05, -.26563300E+05, -.74451400E+04, 0.25164200E+05, 0.28482300E+05, -.22511500E+05, -.64550800E+05, 0.31995100E+05, 0.32679300E+05, 0.11967400E+05, 0.18207200E+05, 0.10334400E+05, -.16693800E+05, -.27766900E+05, 0.17975000E+05, -.11256500E+06, 0.54650000E+05, 0.57409300E+05, 0.22131600E+05, 0.36285300E+05, 0.15496800E+05, -.33740300E+05, -.42784000E+05, 0.31327500E+05, 0.10935700E+06, -.50567400E+05, -.55813000E+05, -.20904900E+05, -.36426200E+05, -.14802100E+05, 0.32977600E+05, 0.37048200E+05, -.26530600E+05, 0.51812100E+04, -.33963100E+04, -.22748600E+04, -.10724500E+04, -.14876500E+04, -.10182300E+04, 0.87350300E+03, -.37817500E+04, -.16552800E+04, -.13611500E+06, 0.66472400E+05, 0.69276900E+05, 0.22127900E+05, 0.36596800E+05, 0.23802500E+05, -.29863500E+05, -.45610800E+05, 0.33811400E+05, 0.76936300E+05, -.38336100E+05, -.39042600E+05, -.14403200E+05, -.24505900E+05, -.11620500E+05, 0.20482600E+05, 0.24965700E+05, -.24807000E+05, 0.50288000E+05, -.24758100E+05, -.25324200E+05, -.70549900E+04, -.13395900E+05, -.98642200E+04, 0.83815200E+04, 0.12038300E+05, -.10217800E+05, -.36883100E+05, -.32739700E+05, 0.33930600E+05, -.74402200E+04, 0.11809700E+05, 0.49372000E+04, -.41750800E+04, 0.22037000E+05, -.91540300E+04, -.35838900E+05, 0.85437800E+03, -.10431800E+05, 0.35204700E+05, 0.15363500E+05, 0.17166900E+05, 0.73550000E+04, -.19792500E+05, -.33759200E+05, -.96452600E+04, -.45118600E+04, 0.26347600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13551200E+01, 0.22722900E+00, -.74865200E+00, -.19849500E+01, 0.83958500E+00, 0.16089700E+02, 0.12207500E+02, 0.75515600E+00, 0.17087600E+05, -.22560200E+04, 0.38764200E+04, 0.17493500E+04, -.94196600E+04, -.12520200E+05, 0.14115800E+05, 0.19734000E+05, 0.17214000E+05, 0.17449700E+05, -.47748800E+05, 0.61700600E+05, 0.34933800E+05, -.20329600E+05, 0.61047400E+05, 0.38481600E+05, 0.38306600E+05, -.22561200E+04, 0.77540400E+05, -.27028800E+06, 0.67004200E+05, 0.13246000E+06, -.36241400E+05, 0.39808500E+05, 0.11170900E+06, 0.86591300E+05, 0.13913300E+06, -.27818600E+06, 0.10240100E+07, -.60691500E+06, -.51542900E+06, 0.18687200E+06, 0.10065200E+06, -.50660700E+06, -.54133500E+06, -.46298400E+06, -.57171700E+06, -.13739600E+06, 0.64354700E+05, 0.69792200E+05, -.10740800E+05, -.17229900E+05, 0.68082900E+05, 0.66229100E+05, 0.57653800E+05, 0.22977200E+05, -.15824700E+07, 0.81612400E+06, 0.80296100E+06, -.24697000E+06, -.14880400E+06, 0.77488000E+06, 0.80710400E+06, 0.73544100E+06, 0.69778400E+06, 0.11106200E+06, 0.13946300E+04, -.50994800E+05, -.95968700E+04, 0.73021300E+04, -.50341000E+05, -.37367600E+05, -.69008600E+05, 0.30088900E+06, -.70715400E+06, 0.41720900E+06, 0.35359000E+06, -.74571300E+05, -.14413000E+04, 0.33151100E+06, 0.36433800E+06, 0.33055100E+06, 0.52833600E+06, -.54816500E+06, 0.34071500E+06, 0.27551600E+06, -.86517000E+05, 0.92784600E+05, 0.28287200E+06, 0.29266800E+06, 0.22435800E+06, 0.20942800E+06, 0.16694000E+07, -.91642500E+06, -.85143900E+06, 0.30114100E+06, 0.84576200E+05, -.83544100E+06, -.88073900E+06, -.78397100E+06, -.66624600E+06, -.58504200E+06, 0.35696800E+06, 0.29252100E+06, -.64962600E+05, 0.15370500E+05, 0.27628600E+06, 0.30979100E+06, 0.27645800E+06, 0.42725100E+06, -.67342900E+06, 0.41632600E+06, 0.34015800E+06, -.52280400E+05, -.54470000E+05, 0.33136900E+06, 0.37032500E+06, 0.29748800E+06, 0.24633700E+06, 0.11719700E+05, -.13494800E+05, -.63836700E+04, 0.32069200E+05, -.88192500E+05, -.78568800E+04, -.33653300E+03, 0.64799400E+04, -.12221600E+06, 0.17261000E+07, -.91848200E+06, -.87665000E+06, 0.28425400E+06, -.13921400E+04, -.85880500E+06, -.88873200E+06, -.80780900E+06, -.48683200E+06, -.13764200E+07, 0.83392700E+06, 0.70087700E+06, -.15098500E+06, -.11913300E+06, 0.68267900E+06, 0.76332900E+06, 0.62913300E+06, 0.71303900E+06, -.23209300E+04, -.30873000E+05, 0.30195200E+04, -.89849800E+04, -.15069300E+05, 0.90313400E+03, -.53087300E+04, 0.73621800E+03, -.15191100E+05, -.14806200E+06, 0.20629500E+05, 0.63538400E+05, 0.38216000E+05, -.11452900E+06, 0.55876100E+05, 0.54453400E+05, 0.93208200E+05, -.38197600E+06, 0.11254400E+05, -.34997500E+04, 0.38304100E+04, -.46664500E+04, -.35144700E+04, 0.12258800E+05, 0.22668700E+04, -.19587800E+05, -.41205800E+04, 0.11831800E+06, -.46265100E+05, -.58548000E+05, 0.11730900E+05, -.38923000E+05, -.56812400E+05, -.47000900E+05, -.65739900E+05, 0.21945800E+06, 0.38188400E+06, -.39781000E+06, 0.38737200E+06, 0.37434500E+06, 0.41640200E+06, 0.26362400E+06, 0.51265800E+06, -.18305800E+06, 0.46614200E+06, -.34983200E+06, -.33407100E+06, -.28365900E+06, 0.30359600E+06, -.44283800E+06, -.48590600E+06, 0.17872200E+06, 0.36884400E+06, -.39890500E+06, 0.47952100E+06, 0.37969500E+06, 0.42482700E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.49867700E+00, -.17406800E-01, -.49378300E+00, 0.14909500E+01, 0.52853300E+00, 0.30751000E+01, 0.15154600E+02, 0.63402000E+00, 0.43532900E+00, -.19725100E+06, 0.99101500E+05, 0.92814000E+05, 0.54540700E+05, 0.82615500E+05, 0.13129500E+05, -.50570100E+05, -.39794200E+05, 0.77371600E+05, -.44674300E+06, 0.23262600E+06, 0.19756000E+06, 0.13275400E+06, 0.19361000E+06, 0.20295300E+05, -.14470000E+06, -.11417800E+06, 0.18371800E+06, 0.96526300E+06, -.49901600E+06, -.45097700E+06, -.22519800E+06, -.36646100E+06, -.11491200E+06, 0.19072400E+06, 0.14871100E+06, -.31065200E+06, 0.10875400E+07, -.56696500E+06, -.49123500E+06, -.28917500E+06, -.47168700E+06, -.97485300E+05, 0.29298400E+06, 0.23059100E+06, -.35350500E+06, -.14731200E+06, 0.72945900E+05, 0.71681700E+05, 0.45751600E+05, 0.71419600E+05, 0.27649800E+04, -.57948400E+05, -.47554700E+05, 0.64059700E+05, -.33442700E+06, 0.17362400E+06, 0.13479100E+06, 0.13393400E+06, 0.22695900E+06, -.21618800E+05, -.17777800E+06, -.13578600E+06, 0.86974900E+05, -.45296300E+06, 0.24059200E+06, 0.21052300E+06, 0.10722200E+06, 0.18769100E+06, 0.54400100E+05, -.88672400E+05, -.80856800E+05, 0.12881700E+06, 0.12463400E+06, -.44965000E+05, -.62340100E+05, 0.11622500E+05, 0.47362600E+05, -.50326500E+05, -.43036400E+05, -.48757200E+05, -.53220700E+05, -.11287200E+07, 0.58039500E+06, 0.50814800E+06, 0.33940400E+06, 0.49420000E+06, 0.62254000E+05, -.38060700E+06, -.29998800E+06, 0.46352700E+06, 0.85734900E+06, -.44899500E+06, -.37576000E+06, -.27588200E+06, -.43208700E+06, -.23625300E+05, 0.31475400E+06, 0.24881400E+06, -.30855300E+06, 0.11026500E+06, -.38653700E+05, -.55135700E+05, 0.12703600E+05, 0.40600600E+05, -.46169300E+05, -.36654700E+05, -.45602800E+05, -.38399700E+05, -.31493800E+06, 0.17621800E+06, 0.12914800E+06, 0.13227700E+06, 0.20570700E+06, -.16360000E+05, -.17540400E+06, -.15757900E+06, 0.14875500E+06, 0.41913000E+06, -.21092400E+06, -.18863700E+06, -.12494600E+06, -.18360800E+06, -.25435600E+05, 0.12675000E+06, 0.10778300E+06, -.16978800E+06, 0.55516400E+06, -.29155300E+06, -.22917400E+06, -.22167300E+06, -.32375100E+06, 0.28272400E+05, 0.28320800E+06, 0.22993000E+06, -.24108800E+06, -.46251400E+06, 0.26725600E+06, 0.17245500E+06, 0.20251800E+06, 0.32694500E+06, -.32671500E+05, -.26720900E+06, -.22681400E+06, 0.17841600E+06, -.25041900E+05, 0.39006000E+04, 0.13020200E+05, -.84560600E+03, -.13299900E+04, 0.73004600E+04, -.54071100E+03, 0.61542400E+04, 0.84401000E+03, 0.78597000E+06, -.40532600E+06, -.34668300E+06, -.21059500E+06, -.32856100E+06, -.63825400E+05, 0.19885200E+06, 0.16572000E+06, -.26905000E+06, -.55703800E+06, 0.27831000E+06, 0.24585100E+06, 0.13687600E+06, 0.20237100E+06, 0.49776500E+05, -.13573700E+06, -.94100600E+05, 0.20560100E+06, -.21659400E+06, 0.11137400E+06, 0.10199200E+06, 0.39310400E+05, 0.76082700E+05, 0.40526800E+05, -.27238800E+05, -.14564500E+05, 0.37687800E+05, 0.20810600E+06, 0.28978400E+06, -.24635500E+06, 0.60621200E+05, -.96653900E+05, -.67746600E+05, -.28931000E+05, -.17230500E+06, 0.99109800E+05, 0.27180000E+06, 0.32864700E+05, 0.82810500E+05, -.26391700E+06, -.13343300E+06, -.74638700E+05, -.10187900E+06, 0.15202700E+06, 0.28881000E+06, 0.82257700E+05, -.29197800E+05, -.27376800E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18822400E-01, 0.76089200E+00, -.26347200E-01, 0.57860600E-01, 0.41296500E-01, -.44854300E-01, -.34981100E+00, 0.18977800E+00, -.16679300E-01, -.18989900E-01, 0.11555900E+03, -.94005800E+02, 0.97075400E+03, 0.12432600E+04, -.89805100E+03, -.15827800E+04, -.32568800E+04, 0.10322400E+04, -.12859300E+05, 0.79108700E+04, 0.61431400E+04, 0.59276400E+04, 0.69841000E+04, -.25660400E+02, -.55382300E+04, -.74336400E+04, 0.60754500E+04, 0.11940800E+05, -.86195300E+04, -.54152400E+04, -.88316200E+04, -.10975200E+05, 0.36415500E+04, 0.12174500E+05, 0.16445800E+05, -.96792900E+04, -.18342900E+05, 0.51704000E+04, 0.10113200E+05, -.16844400E+05, -.16179100E+05, 0.20708900E+05, 0.31013400E+05, 0.37079200E+05, -.10846900E+05, -.15352000E+04, 0.62243400E+03, 0.75064600E+03, 0.16997500E+04, 0.25796400E+04, -.11434700E+04, -.28381300E+04, -.38941500E+04, 0.19395500E+04, 0.46737900E+05, -.22310700E+05, -.23761400E+05, 0.13245300E+05, 0.69190800E+04, -.27678400E+05, -.32250700E+05, -.34167300E+05, 0.73260800E+03, 0.16521800E+04, 0.13644700E+04, -.10454800E+04, 0.65228300E+04, 0.62807000E+04, -.52661200E+04, -.86766900E+04, -.11872900E+05, 0.44850000E+04, 0.40992700E+05, -.18139200E+05, -.20496600E+05, 0.58832500E+04, 0.13404200E+04, -.19102000E+05, -.17036400E+05, -.19103200E+05, -.31815600E+04, -.22432100E+05, 0.13782000E+05, 0.10171700E+05, 0.13802600E+05, 0.15303500E+05, -.30779400E+04, -.16087900E+05, -.21313000E+05, 0.12795300E+05, -.39217300E+05, 0.16122800E+05, 0.20309100E+05, -.18113400E+05, -.13802100E+05, 0.29159400E+05, 0.37948900E+05, 0.43378700E+05, -.68157900E+04, 0.33499100E+05, -.14369600E+05, -.16749600E+05, 0.47903000E+04, 0.11278800E+04, -.15545000E+05, -.13699700E+05, -.15537200E+05, -.27081300E+04, 0.12533200E+05, -.30022100E+04, -.67528700E+04, 0.78391700E+04, 0.97349400E+04, -.11030900E+05, -.14411800E+05, -.18268500E+05, 0.52505700E+04, 0.79999200E+04, -.43001600E+04, -.36048700E+04, -.47398300E+04, -.43783100E+04, 0.42542500E+03, 0.40382300E+04, 0.69452800E+04, -.35799900E+04, -.30522200E+05, 0.12994100E+05, 0.15923300E+05, -.14760300E+05, -.10067300E+05, 0.22744400E+05, 0.29680300E+05, 0.33425900E+05, -.42756000E+04, 0.42485100E+05, -.15358800E+05, -.22141000E+05, 0.15468800E+05, 0.13508100E+05, -.27663300E+05, -.32638700E+05, -.37845400E+05, 0.50893200E+04, -.20379900E+04, -.25627600E+03, 0.10567500E+04, -.34662400E+03, -.54627300E+03, 0.63444700E+03, -.17891700E+03, 0.58328900E+03, -.12011600E+03, 0.89879500E+04, -.65304600E+04, -.38154500E+04, -.97835800E+04, -.84589200E+04, 0.37269900E+04, 0.10650100E+05, 0.15282800E+05, -.67132600E+04, -.17848600E+05, 0.89888600E+04, 0.84780000E+04, 0.43073700E+04, 0.66274000E+04, 0.20321300E+04, -.48876700E+04, -.57423100E+04, 0.66671700E+04, 0.40348700E+04, -.15343000E+04, -.21264100E+04, 0.29791800E+04, 0.21526600E+04, -.38238400E+04, -.53221700E+04, -.63568400E+04, 0.14260200E+04, -.10300100E+05, 0.23955700E+05, -.24382000E+05, -.15304100E+05, -.18624300E+05, -.12085300E+05, -.20386200E+05, 0.11848700E+04, -.73168400E+04, 0.17751200E+05, 0.16944300E+05, 0.53294700E+04, -.17601900E+05, 0.12630200E+05, 0.10339400E+05, 0.23490600E+04, -.84559500E+04, 0.23726300E+05, -.90633600E+04, -.18865100E+05, -.21917400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.16512600E+01, 0.28754800E-01, -.67178000E+00, -.14883000E-01, -.23378100E+00, 0.18409100E+01, 0.19514400E-01, -.24569000E+01, 0.14635000E+00, -.10166700E+00, 0.14569100E+01, -.21045400E+04, 0.21621400E+04, 0.86352600E+03, -.20453100E+04, 0.28636400E+04, 0.11090800E+05, 0.99408300E+03, 0.79257100E+05, -.39215400E+05, -.46970900E+05, -.71922200E+04, -.90317700E+03, -.25707100E+05, 0.83828500E+03, 0.79330300E+04, -.71646700E+04, -.51744500E+05, 0.25071800E+05, 0.35390300E+05, 0.75428800E+04, 0.14221900E+05, 0.81795200E+04, -.27998600E+05, -.46751200E+05, 0.16361600E+05, -.94291900E+05, 0.47117700E+05, 0.62715600E+05, -.47807300E+04, 0.14333200E+05, 0.24446900E+05, -.21389300E+05, -.42276400E+05, 0.19328100E+05, 0.22695800E+04, -.11607500E+04, -.16686700E+04, -.22548000E+04, -.42235900E+04, 0.18014400E+04, 0.83426700E+04, 0.14646000E+05, -.33585100E+04, 0.40418400E+05, -.19805600E+05, -.29784400E+05, 0.53063600E+04, 0.17661300E+05, -.14214100E+05, 0.10818400E+05, 0.16464200E+05, 0.67583700E+04, 0.87536600E+05, -.42964600E+05, -.48433900E+05, -.13549600E+04, 0.14690500E+04, -.28304600E+05, -.27112400E+04, 0.55298700E+03, -.64310700E+04, -.10977500E+05, 0.77846500E+04, 0.54823700E+04, -.43336500E+03, 0.23465000E+05, 0.59705400E+04, 0.90220100E+04, 0.54085200E+04, 0.15723100E+05, 0.14269100E+06, -.70344000E+05, -.88379800E+05, -.10770200E+05, 0.52194100E+04, -.45190200E+05, 0.74411300E+04, 0.28992400E+05, -.86154200E+04, -.71899900E+05, 0.35826600E+05, 0.51010000E+05, -.47177000E+04, -.38730000E+04, 0.21387700E+05, -.21205200E+05, -.40708000E+05, 0.62553800E+04, -.75058300E+04, 0.55587600E+04, 0.37519600E+04, -.76762100E+03, 0.20058300E+05, 0.42944700E+04, 0.63678300E+04, 0.37853100E+04, 0.13299600E+05, 0.51915200E+04, -.28187800E+04, -.10550700E+05, -.78304600E+04, -.97207700E+04, 0.94328500E+04, 0.29598300E+05, 0.40286000E+05, -.88384400E+04, -.75715000E+05, 0.37811300E+05, 0.43890500E+05, 0.17013700E+04, -.14674200E+05, 0.29402600E+05, 0.11245500E+05, 0.43247500E+04, -.48418500E+04, -.80903900E+05, 0.39828300E+05, 0.54727400E+05, -.25720700E+04, -.16432500E+05, 0.29118900E+05, -.46133600E+04, -.17727400E+05, -.36107200E+04, 0.19573000E+05, -.89676300E+04, -.26477900E+05, -.51776000E+04, 0.78078700E+04, 0.31026700E+04, 0.36401700E+05, 0.46476400E+05, 0.59742600E+03, 0.28738800E+04, -.19987400E+04, -.64654200E+03, -.77987400E+03, -.39644100E+03, -.62291200E+03, 0.54939700E+03, 0.24285300E+03, -.67323000E+03, -.15195400E+06, 0.75340400E+05, 0.89914300E+05, 0.10715300E+04, -.21412200E+05, 0.58298800E+05, 0.19072700E+05, 0.91700800E+04, -.39666500E+04, 0.34283500E+05, -.17136100E+05, -.26383900E+05, -.35006400E+04, -.95215600E+04, -.10098900E+05, 0.10604300E+05, 0.21326200E+05, -.93318700E+04, 0.15815900E+05, -.76351100E+04, -.98188600E+04, -.44349200E+04, -.12815300E+04, -.45808500E+03, 0.11975300E+05, 0.13263900E+05, -.40582900E+04, -.29510600E+05, 0.11021900E+04, 0.24634000E+04, -.53083100E+04, -.51584900E+04, -.97072600E+04, 0.19179400E+05, -.23054000E+04, -.25046400E+04, -.17493300E+05, 0.92758100E+04, 0.63859500E+04, 0.16014700E+05, -.18164000E+05, 0.47453000E+04, -.99380300E+04, 0.71880100E+04, 0.97060400E+03, 0.96251600E+03, -.14107100E+05, -.59774700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12540800E+01, -.25839200E+01, 0.27753000E+00, -.64311500E+00, 0.87038400E+00, 0.17742100E+01, 0.46851300E+01, 0.31745100E-01, 0.13085000E+00, 0.23947300E+00, 0.28784500E+01, 0.24109000E+00, -.11986900E+05, -.11693200E+05, 0.99479500E+04, 0.14960500E+05, 0.25191200E+05, -.96240500E+04, 0.62549300E+05, -.31198300E+05, -.26692700E+05, -.41335500E+05, -.53843400E+05, 0.16619300E+05, 0.53832500E+05, 0.58461300E+05, -.43415100E+05, -.89908900E+05, 0.44817600E+05, 0.39976000E+05, 0.68771600E+05, 0.78665200E+05, -.33030500E+05, -.97755200E+05, -.11120800E+06, 0.64906300E+05, 0.39071600E+06, -.19485700E+06, -.20726800E+06, 0.20573800E+06, 0.11463700E+06, -.28463500E+06, -.36848100E+06, -.38212100E+06, 0.53822500E+05, 0.18662200E+05, -.93117500E+04, -.90645800E+04, -.12311600E+05, -.18692500E+05, 0.66181300E+04, 0.19969100E+05, 0.21789700E+05, -.14254600E+05, -.60742100E+06, 0.30298500E+06, 0.30896000E+06, -.15996900E+06, -.75326500E+05, 0.33548800E+06, 0.36860100E+06, 0.37170600E+06, 0.10619500E+05, -.11183700E+06, 0.55911100E+05, 0.58690800E+05, -.70132800E+05, -.48913200E+05, 0.87678900E+05, 0.11424500E+06, 0.12663400E+06, -.25344900E+05, -.32269300E+06, 0.16121100E+06, 0.16135000E+06, -.43607700E+05, -.11372700E+05, 0.15478500E+06, 0.15160000E+06, 0.15507100E+06, 0.35149000E+05, 0.86432400E+05, -.43070600E+05, -.31963300E+05, -.10541200E+06, -.12959100E+06, 0.67887900E+05, 0.15887100E+06, 0.17844400E+06, -.97579300E+05, 0.55823600E+06, -.27844000E+06, -.28922600E+06, 0.21001200E+06, 0.10952900E+06, -.35457100E+06, -.42783800E+06, -.43788900E+06, 0.22428700E+05, -.25839700E+06, 0.12911100E+06, 0.12920000E+06, -.33771700E+05, -.84526100E+04, 0.12359300E+06, 0.12122700E+06, 0.12383400E+06, 0.29947900E+05, -.72648400E+05, 0.36354700E+05, 0.42535000E+05, -.52210800E+05, -.61201000E+05, 0.77118500E+05, 0.11350600E+06, 0.11691300E+06, -.27930100E+05, -.23162200E+05, 0.11513300E+05, 0.64476300E+04, 0.37358700E+05, 0.43866800E+05, -.23465600E+05, -.49667500E+05, -.63232600E+05, 0.31494000E+05, 0.46779800E+06, -.23337400E+06, -.24218800E+06, 0.16413500E+06, 0.92524600E+05, -.29217900E+06, -.34760800E+06, -.35446100E+06, 0.17812400E+05, -.39259900E+06, 0.19612800E+06, 0.20765200E+06, -.12545600E+06, -.10170100E+06, 0.25127700E+06, 0.30158200E+06, 0.30927200E+06, -.17087100E+05, 0.28520300E+04, -.13824000E+04, -.41972800E+03, -.73760800E+03, -.68268900E+03, -.44681800E+03, 0.65738300E+03, -.90661000E+03, -.66513200E+03, 0.61499900E+05, -.30782100E+05, -.38505900E+05, 0.91679000E+05, 0.81111000E+05, -.92131000E+05, -.14030000E+06, -.16170300E+06, 0.50572200E+05, 0.12930800E+06, -.64485800E+05, -.58133400E+05, -.32196800E+05, -.48700300E+05, -.12458700E+05, 0.33293900E+05, 0.34080400E+05, -.48989600E+05, -.43465900E+05, 0.21683900E+05, 0.22831800E+05, -.22852200E+05, -.19408400E+05, 0.35513300E+05, 0.45575800E+05, 0.49910100E+05, -.59842900E+04, 0.15524400E+06, -.25627400E+06, 0.25347500E+06, 0.18191500E+06, 0.21210100E+06, 0.12620500E+06, 0.19025700E+06, -.15553600E+05, 0.11840100E+06, -.18316100E+06, -.19436700E+06, -.46341000E+05, 0.18326200E+06, -.13775700E+06, -.15596000E+06, -.13105800E+05, 0.10362700E+06, -.25657400E+06, 0.13879000E+06, 0.21497700E+06, 0.24037900E+06, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17505800E+01, -.31361300E+01, 0.58604300E+00, 0.72610200E+00, 0.58931600E+00, -.51236100E+00, -.31367100E+01, -.25001500E+01, 0.69328100E-01, 0.49259500E-01, -.29117300E+00, 0.27032900E+00, 0.13990300E+00, -.40576200E+04, 0.60178300E+04, 0.18838800E+04, 0.12024500E+05, -.40503700E+04, 0.69063400E+05, -.34683700E+05, -.27472800E+05, -.18749500E+05, -.43442600E+05, 0.10776000E+05, 0.31220100E+05, 0.23049400E+05, -.41928500E+05, -.91981200E+05, 0.46297100E+05, 0.48267100E+05, 0.19725700E+05, 0.42191000E+05, -.54908000E+04, -.26916500E+05, -.44780200E+05, 0.54651200E+05, -.19402900E+06, 0.97077900E+05, 0.10289100E+06, 0.77931200E+04, 0.47566700E+05, 0.35833200E+05, 0.52024800E+04, -.10787900E+05, 0.73017400E+05, 0.21674000E+05, -.10837100E+05, -.99985200E+04, -.36294700E+04, -.69889400E+04, -.15704700E+04, 0.18740800E+04, 0.44547500E+04, -.86435400E+04, 0.18078600E+06, -.90305500E+05, -.83631500E+05, 0.22300000E+04, -.30846600E+05, -.45880700E+05, -.32159400E+05, -.41602800E+05, -.69894100E+05, 0.47922600E+05, -.24336700E+05, -.21819700E+05, -.75282700E+04, -.28411700E+05, 0.54763000E+04, 0.16987900E+05, 0.24551000E+05, -.37818700E+05, 0.47579400E+05, -.24597900E+05, -.23779700E+05, 0.94868000E+04, -.10148300E+05, -.23513100E+05, -.22475500E+05, -.24397400E+05, -.35807800E+05, 0.13379600E+06, -.67271800E+05, -.74873300E+05, -.23003300E+05, -.78450000E+05, 0.35916200E+04, 0.42704800E+05, 0.51945400E+05, -.75534500E+05, -.22822700E+06, 0.11407100E+06, 0.10577000E+06, 0.66908400E+04, 0.55769700E+05, 0.43041400E+05, 0.17365800E+05, 0.12033900E+05, 0.90159600E+05, 0.40205600E+05, -.20930100E+05, -.20103400E+05, 0.75480100E+04, -.10279400E+05, -.19153000E+05, -.19338700E+05, -.19583500E+05, -.30876500E+05, 0.76857900E+05, -.38739600E+05, -.39856600E+05, -.13450300E+04, -.10959300E+05, -.18406800E+05, -.12474700E+05, -.11690800E+05, -.27955300E+05, -.14721200E+05, 0.73655300E+04, 0.10797600E+05, 0.61473400E+04, 0.34651900E+05, -.14476700E+05, -.21980000E+05, -.33483300E+05, 0.30073300E+05, -.19212300E+06, 0.96140200E+05, 0.89971700E+05, 0.41593500E+04, 0.55355400E+05, 0.36133500E+05, 0.15903900E+05, 0.18939600E+05, 0.75948700E+05, 0.16025500E+06, -.80858900E+05, -.77052300E+05, 0.13638100E+04, -.24803000E+05, -.38489200E+05, -.27258400E+05, -.33741700E+05, -.68121400E+05, 0.63697700E+04, -.29439900E+04, -.18913500E+04, -.11635800E+04, -.12318600E+04, -.11737400E+04, 0.90138800E+03, -.10996700E+04, -.18982700E+04, -.57204400E+05, 0.28727400E+05, 0.25068200E+05, 0.16321600E+05, 0.66302700E+05, -.28210700E+05, -.45083900E+05, -.56178500E+05, 0.69085000E+05, 0.78540600E+05, -.39177200E+05, -.35383400E+05, -.19101900E+05, -.32408600E+05, 0.47210300E+04, 0.22398100E+05, 0.21482400E+05, -.32815800E+05, 0.22661700E+05, -.11363900E+05, -.11635800E+05, -.27187700E+04, -.81152500E+04, -.52495800E+03, 0.71755300E+04, 0.56143600E+04, -.19578000E+05, -.49812400E+05, -.75454800E+04, 0.16616500E+05, -.21224200E+05, -.21647400E+05, 0.12068600E+05, -.65476800E+05, 0.43308800E+05, -.39227000E+05, 0.56884900E+04, 0.92951600E+04, -.11950500E+05, -.30378600E+04, 0.75327900E+05, 0.46044600E+05, 0.69263500E+04, -.65060500E+05, -.75479500E+04, -.36641300E+05, -.75421600E+04, 0.41272200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.19269200E+01, 0.46931200E+01, 0.18035500E+00, 0.52063100E+00, -.37961400E+00, -.63462600E+01, -.20182300E+01, 0.87124000E+00, -.44508000E+00, 0.10490200E+00, -.13981900E+01, -.43518700E+00, 0.79928700E-01, -.53929600E+00, 0.44551300E+04, -.71147600E+03, -.80516000E+04, -.52378400E+02, -.14405700E+06, 0.71339400E+05, 0.78775200E+05, 0.19708400E+05, 0.24479800E+05, 0.40810500E+05, -.15802700E+05, -.37538900E+05, 0.30833000E+05, 0.17609100E+06, -.86780900E+05, -.85383900E+05, -.32085200E+05, -.55645300E+05, -.36699200E+05, 0.41608600E+05, 0.71703800E+05, -.49421900E+05, 0.29554600E+06, -.14843200E+06, -.14017400E+06, -.23783400E+05, -.68309600E+05, -.77028900E+05, 0.23793300E+05, 0.62217100E+05, -.64370900E+05, -.40235400E+05, 0.19760600E+05, 0.20922100E+05, 0.66476500E+04, 0.10560400E+05, 0.89295800E+04, -.83069700E+04, -.13779400E+05, 0.11463200E+05, -.17898800E+06, 0.88783200E+05, 0.95917400E+05, -.57382900E+04, 0.31023900E+04, 0.72474500E+05, 0.26407100E+05, 0.13983200E+04, -.11887600E+04, -.15974200E+06, 0.78530100E+05, 0.81679600E+05, 0.98980600E+04, 0.21450000E+05, 0.48394800E+05, 0.32293600E+04, -.12214300E+05, 0.21264600E+05, -.62240900E+05, 0.26512100E+05, 0.31129900E+05, -.38944200E+04, -.28568700E+05, 0.29322900E+05, 0.27055100E+05, 0.29027200E+05, -.29084900E+05, -.32243100E+06, 0.15934600E+06, 0.15170600E+06, 0.50927300E+05, 0.59406200E+05, 0.76405100E+05, -.44648500E+05, -.84381100E+05, 0.76133300E+05, 0.26818000E+06, -.13442300E+06, -.14147300E+06, -.12992300E+05, -.36541700E+05, -.88681900E+05, 0.29374900E+03, 0.42338000E+05, -.36642800E+05, -.50245800E+05, 0.21648600E+05, 0.25122000E+05, -.26225200E+04, -.24753700E+05, 0.23808400E+05, 0.21682100E+05, 0.23682600E+05, -.24307700E+05, -.13572500E+06, 0.68644200E+05, 0.65690300E+05, 0.23576100E+05, 0.33420500E+05, 0.29631200E+05, -.21289000E+05, -.36180000E+05, 0.32090000E+05, 0.13417900E+06, -.67046700E+05, -.62994300E+05, -.15945300E+05, -.65569000E+04, -.39707700E+05, 0.31345600E+03, 0.13583600E+05, -.17310300E+05, 0.23632400E+06, -.11720900E+06, -.12354800E+06, -.11390800E+05, -.16263900E+05, -.81432500E+05, -.73941000E+04, 0.25492200E+05, -.25718900E+05, -.22511200E+06, 0.11154200E+06, 0.11470300E+06, 0.22136000E+05, 0.28986900E+05, 0.69620500E+05, -.38461800E+04, -.31434700E+05, 0.22881900E+05, 0.45594700E+04, -.11522700E+04, -.84315600E+03, -.31019900E+03, 0.23039900E+03, -.12850000E+04, 0.48504000E+03, -.15877500E+04, -.46663200E+03, 0.26238100E+06, -.13057500E+06, -.13385900E+06, -.20658500E+05, -.16841300E+05, -.88540300E+05, -.11446600E+05, 0.20064000E+05, -.27068300E+05, -.10498900E+06, 0.52369400E+05, 0.55865100E+05, 0.20254300E+05, 0.36019600E+05, 0.24816200E+05, -.31085300E+05, -.51897200E+05, 0.36092200E+05, -.48044000E+05, 0.23593000E+05, 0.23526000E+05, 0.75327600E+04, 0.11939800E+05, 0.11190600E+05, -.37033000E+04, -.13618200E+05, 0.63066800E+04, 0.83777300E+05, 0.22056500E+03, -.45205000E+03, 0.36621400E+05, 0.53198300E+04, 0.27163900E+05, -.59316800E+04, -.13501200E+05, 0.37522000E+05, 0.39907000E+05, -.31614600E+05, -.74690700E+04, -.37071900E+05, -.16225500E+03, -.46858600E+05, 0.12111300E+04, 0.11204200E+05, 0.19658200E+03, 0.40686600E+05, 0.29678300E+05, 0.33583600E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10920600E+01, 0.31008400E+01, 0.42285700E-01, 0.24096900E-01, -.90689800E+00, -.75991200E-01, 0.44803100E+01, 0.15902900E+01, -.14048300E+00, -.85724400E-01, 0.16620900E+01, -.98502300E+00, 0.19171400E+00, -.42850000E+00, -.45466700E+00, 0.69412900E+04, 0.11233200E+05, 0.34265700E+03, 0.17653700E+05, -.87407300E+04, -.68857800E+04, -.58650300E+04, 0.11329500E+05, -.77781700E+04, 0.46219100E+03, -.28012700E+03, 0.83837900E+04, 0.26879300E+05, -.13642300E+05, -.15586500E+05, 0.40586900E+04, -.45410900E+04, -.10080400E+05, -.28513800E+05, -.31114100E+05, -.10226900E+05, 0.17792800E+06, -.89294400E+05, -.92196900E+05, 0.32367600E+05, 0.31828600E+04, -.85356600E+05, -.10861200E+06, -.11124400E+06, -.16944400E+05, -.31124200E+05, 0.15142200E+05, 0.15709600E+05, -.12884600E+04, -.25434200E+04, 0.12955900E+05, 0.13303000E+05, 0.18632900E+05, 0.21150700E+04, -.26483500E+06, 0.13227200E+06, 0.13464700E+06, -.39746000E+05, 0.76098300E+04, 0.12724700E+06, 0.13825400E+06, 0.13543500E+06, 0.38279400E+05, -.12467800E+05, 0.63521600E+04, 0.72769800E+04, -.12838300E+05, 0.78696200E+04, 0.85662300E+04, 0.21159800E+05, 0.17046700E+05, 0.93516800E+04, -.16878200E+06, 0.84114100E+05, 0.84393100E+05, -.18730900E+05, 0.63982100E+04, 0.81244600E+05, 0.80620600E+05, 0.80840700E+05, 0.32549100E+05, -.15178400E+05, 0.77414700E+04, 0.10839000E+05, -.13214300E+05, 0.27821000E+05, 0.24829200E+04, 0.24715600E+05, 0.29335900E+05, 0.26491200E+05, 0.25837700E+06, -.12931200E+06, -.13331100E+06, 0.39754400E+05, -.43685000E+04, -.12440100E+06, -.14474600E+06, -.14586300E+06, -.35631500E+05, -.13595200E+06, 0.68206800E+05, 0.67976400E+05, -.14840300E+05, 0.69963300E+04, 0.65129700E+05, 0.65019500E+05, 0.64720100E+05, 0.28485200E+05, -.13108500E+06, 0.66123000E+05, 0.67855100E+05, -.15923300E+05, -.14769800E+05, 0.65865000E+05, 0.73674000E+05, 0.81489700E+05, 0.85495200E+04, -.19933500E+05, 0.98819400E+04, 0.86699600E+04, 0.43617400E+04, -.19753000E+05, 0.12138500E+05, 0.28639400E+04, 0.14342000E+04, -.15804800E+05, 0.21040100E+06, -.10523000E+06, -.10863800E+06, 0.35522700E+05, -.15942000E+05, -.10059000E+06, -.11466100E+06, -.11451500E+06, -.37149900E+05, -.26547100E+06, 0.13330400E+06, 0.13759900E+06, -.37257300E+05, -.80103800E+04, 0.13329600E+06, 0.14995900E+06, 0.15213100E+06, 0.33228500E+05, 0.51966500E+04, -.24542200E+04, -.20704600E+04, -.59211900E+03, 0.24278100E+03, -.15216800E+04, 0.61760800E+03, -.73502400E+03, -.26694500E+03, -.24214700E+05, 0.11630900E+05, 0.90848900E+04, 0.14275100E+05, -.32218100E+05, 0.10692800E+05, -.10127900E+05, -.44631200E+04, -.26093800E+05, 0.51383400E+04, -.25607600E+04, 0.49774600E+02, 0.67369800E+03, 0.29538800E+04, -.50483100E+04, 0.25098000E+04, 0.19211600E+04, 0.17813100E+04, -.19065400E+05, 0.95654700E+04, 0.99127600E+04, -.69650000E+04, 0.48105700E+03, 0.12116000E+05, 0.19670700E+05, 0.18400900E+05, 0.58685300E+04, 0.62363900E+05, -.68643500E+05, 0.70041400E+05, 0.67089000E+05, 0.64566900E+05, 0.35692400E+05, 0.95979900E+05, -.24373700E+05, 0.60446500E+05, -.50991000E+05, -.61947200E+05, -.93572400E+04, 0.48790700E+05, -.82363700E+05, -.80993200E+05, -.11815700E+05, 0.63056300E+05, -.68741900E+05, 0.73129600E+05, 0.60442800E+05, 0.62278600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.30189400E+01, -.77907000E+00, 0.34158200E+01, 0.32851100E+01, -.47533300E+01, -.10772700E+02, 0.31682100E+01, -.46870600E+01, -.67174700E+00, -.45100700E+00, -.41212100E+01, -.36999300E+01, 0.13489200E+01, -.12079700E+01, -.24263100E-01, 0.32033800E+01, 0.61295800E+05, -.25877700E+04, 0.62887600E+06, -.31356900E+06, -.31531800E+06, -.12375800E+06, -.20369300E+06, -.83820000E+05, 0.14015700E+06, 0.19216000E+06, -.21891200E+06, -.66365300E+06, 0.32989400E+06, 0.33881700E+06, 0.15127800E+06, 0.24035000E+06, 0.62188600E+05, -.20151300E+06, -.37537700E+06, 0.29739300E+06, -.15282100E+07, 0.76696900E+06, 0.77905900E+06, 0.46366800E+05, 0.29877600E+06, 0.40542000E+06, 0.57703900E+05, -.14843700E+06, 0.42536300E+06, 0.15930800E+06, -.79807800E+05, -.79337400E+05, -.36606100E+05, -.59509500E+05, -.14848600E+05, 0.49811900E+05, 0.85880200E+05, -.64854100E+05, 0.11626600E+07, -.57939200E+06, -.58373600E+06, 0.51834600E+05, -.11161200E+06, -.38258000E+06, -.20150500E+06, -.14260600E+06, -.29651700E+06, 0.55892600E+06, -.27782900E+06, -.28080800E+06, -.45960400E+05, -.12808700E+06, -.11439600E+06, 0.41933300E+05, 0.11757200E+06, -.18588200E+06, 0.29740700E+06, -.13831200E+06, -.14870200E+06, 0.61115200E+05, 0.38396600E+05, -.13740000E+06, -.12356000E+06, -.13900900E+06, -.93068600E+05, 0.12707100E+07, -.63235400E+06, -.65072100E+06, -.21752300E+06, -.37943100E+06, -.20755000E+06, 0.22991800E+06, 0.42709400E+06, -.42217200E+06, -.15481700E+07, 0.77570600E+06, 0.78029100E+06, 0.54126100E+04, 0.25313000E+06, 0.44673300E+06, 0.14027000E+06, -.37134400E+05, 0.42827100E+06, 0.24313200E+06, -.11301300E+06, -.12156700E+06, 0.48015500E+05, 0.30031900E+05, -.11118400E+06, -.10066100E+06, -.11266800E+06, -.77704600E+05, 0.60426600E+06, -.30423500E+06, -.30921000E+06, -.93363000E+05, -.16355900E+06, -.99793900E+05, 0.95711200E+05, 0.16678500E+06, -.22953100E+06, -.38248800E+06, 0.19132400E+06, 0.19735100E+06, 0.63989300E+05, 0.11940800E+06, 0.56619400E+05, -.81074200E+05, -.16462700E+06, 0.13556900E+06, -.13307900E+07, 0.66370900E+06, 0.67178600E+06, 0.90783500E+04, 0.21434500E+06, 0.38685700E+06, 0.12922000E+06, 0.13522000E+05, 0.34175900E+06, 0.11279800E+07, -.56333200E+06, -.57487900E+06, -.65732200E+05, -.19059200E+06, -.27863700E+06, -.53197600E+04, 0.89438100E+05, -.38050500E+06, -.72475800E+04, 0.14187300E+04, 0.33218400E+04, -.25735400E+04, -.16006700E+04, 0.35463400E+04, 0.14571800E+04, 0.35286100E+04, -.24037400E+04, -.83149200E+06, 0.41488700E+06, 0.42271300E+06, 0.10629000E+06, 0.22986600E+06, 0.14105200E+06, -.12253900E+06, -.25854400E+06, 0.29221200E+06, 0.48210800E+06, -.24049500E+06, -.24636300E+06, -.11496500E+06, -.18017500E+06, -.46601300E+05, 0.14458600E+06, 0.22025500E+06, -.18039200E+06, 0.13357800E+06, -.65876100E+05, -.68033500E+05, -.29828800E+05, -.45169800E+05, -.73684500E+04, 0.47604900E+05, 0.83832500E+05, -.93695800E+05, -.39362500E+06, 0.12657500E+05, 0.13927400E+05, -.16085100E+06, -.10492000E+06, -.52872400E+05, -.18963600E+06, 0.18964800E+06, -.24588900E+06, 0.14040900E+05, 0.11757800E+06, -.72934000E+04, -.96084000E+04, 0.26504400E+06, 0.28373500E+06, -.41217200E+04, -.26959200E+06, 0.13032600E+05, -.24201000E+06, -.12567000E+06, -.39829000E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13828600E+01, 0.30073400E+01, -.13643400E+00, 0.41572200E+00, -.79896300E-01, 0.17717500E+01, 0.16136700E+01, 0.20015800E+01, 0.51152100E-02, 0.69164600E-01, -.11894300E+01, -.38568400E+00, 0.12190600E-01, 0.25681500E+00, -.26438500E+00, 0.16080100E+00, 0.36438200E-01, 0.16640000E+04, -.62757700E+05, 0.30951900E+05, 0.30786700E+05, 0.11242500E+05, 0.15774200E+05, 0.10520700E+05, -.74457000E+04, -.90432100E+04, 0.20694600E+05, 0.42775500E+05, -.20519600E+05, -.21554400E+05, -.18257700E+05, -.20092200E+05, 0.33141400E+04, 0.23214200E+05, 0.32676800E+05, -.39857800E+05, 0.13977800E+06, -.70211600E+05, -.70230000E+05, -.92481200E+04, -.21610200E+05, -.34933700E+05, -.45118300E+04, 0.40162200E+04, -.61927700E+05, -.22478800E+05, 0.11072500E+05, 0.11173000E+05, 0.32860200E+04, 0.49084600E+04, 0.48306300E+04, -.94242700E+03, -.36475200E+04, 0.72920200E+04, -.15350800E+06, 0.76114400E+05, 0.76161900E+05, -.47482900E+04, -.63521100E+04, 0.56029700E+05, 0.38656800E+05, 0.39836200E+05, 0.48777900E+05, -.47026000E+05, 0.22643500E+05, 0.23307800E+05, 0.67725100E+04, 0.53176000E+04, 0.74876700E+04, -.52407100E+04, -.64841800E+04, 0.26515900E+05, -.64218100E+05, 0.29196700E+05, 0.32108200E+05, -.70037500E+04, -.15106900E+05, 0.29470300E+05, 0.26264000E+05, 0.30286900E+05, 0.22569900E+05, -.15030200E+06, 0.73971400E+05, 0.75664900E+05, 0.19314100E+05, 0.28766000E+05, 0.35104000E+05, -.29079600E+04, -.10449600E+05, 0.43237900E+05, 0.18194700E+06, -.90984100E+05, -.90205600E+05, -.17789500E+04, -.13835300E+05, -.56974400E+05, -.29126000E+05, -.23291800E+05, -.62251300E+05, -.54825500E+05, 0.25299200E+05, 0.27412800E+05, -.58847800E+04, -.11720300E+05, 0.25058200E+05, 0.23014200E+05, 0.25559900E+05, 0.18212300E+05, -.87837200E+05, 0.44429200E+05, 0.43987900E+05, 0.65355400E+04, 0.72046500E+04, 0.25505700E+05, 0.99690200E+04, 0.67691100E+04, 0.27439100E+05, 0.53437800E+05, -.26713400E+05, -.26979600E+05, -.56410200E+04, -.81586400E+04, -.12906600E+05, -.45427300E+03, 0.27335700E+04, -.14666200E+05, 0.18518800E+06, -.91786100E+05, -.92020300E+05, 0.10599300E+04, -.94972300E+04, -.63516600E+05, -.39729500E+05, -.37304900E+05, -.44724400E+05, -.16603900E+06, 0.82270800E+05, 0.82701200E+05, 0.39648600E+04, -.19796000E+04, 0.55019300E+05, 0.30143500E+05, 0.30600200E+05, 0.54925400E+05, -.85661800E+02, 0.71303900E+03, 0.42908500E+01, 0.35963100E+03, 0.95783500E+02, -.37305300E+02, 0.92497600E+02, 0.94046900E+03, 0.51193600E+03, 0.89213200E+05, -.44008000E+05, -.44194800E+05, -.11664800E+05, -.13294700E+05, -.17349400E+05, 0.44933500E+04, 0.85076200E+04, -.37069700E+05, -.44108100E+05, 0.21986000E+05, 0.21725500E+05, 0.12547500E+05, 0.19114900E+05, 0.25886600E+04, -.14042200E+05, -.20035900E+05, 0.19553600E+05, -.24962900E+04, 0.92133100E+03, 0.12489600E+04, 0.34706100E+04, -.21276800E+04, -.19809400E+04, -.41217400E+04, -.27483500E+04, 0.13490700E+05, 0.50615500E+05, -.16314900E+05, 0.15758000E+05, 0.27521800E+05, 0.25990000E+05, 0.19618800E+05, 0.14925400E+05, -.18420700E+05, 0.40628300E+05, 0.23899000E+04, -.19760600E+05, -.20863900E+05, -.48143900E+04, -.20828200E+05, -.31590000E+05, 0.11732800E+05, 0.22929800E+05, -.16178300E+05, 0.32904600E+05, 0.20789700E+05, 0.17462600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18358200E+00, 0.29324900E+01, 0.86029900E-01, -.26229100E+00, 0.86032000E-01, 0.51732400E+00, 0.10640400E+01, -.34498800E+00, -.10399000E-01, 0.14602600E+00, 0.57682500E+00, -.22561400E+00, 0.38117300E+00, 0.41708000E+00, -.33933100E+00, 0.62013300E-01, -.35588300E-01, 0.22224300E+00, -.54957400E+05, 0.27287700E+05, 0.26699100E+05, -.16879800E+04, -.70529700E+04, 0.19430000E+05, 0.91413700E+04, 0.10668000E+05, 0.30505100E+03, 0.56791100E+05, -.28216100E+05, -.27158000E+05, -.31311900E+04, -.91908100E+04, -.16810000E+05, -.53086000E+04, -.38220900E+04, -.68461200E+04, 0.48134100E+05, -.24129200E+05, -.20541800E+05, -.22553700E+05, 0.10354200E+04, -.87821400E+04, 0.13086800E+05, 0.61257300E+04, -.19933600E+04, -.31385600E+05, 0.15420900E+05, 0.15676800E+05, -.20089400E+04, -.37083000E+04, 0.13326500E+05, 0.98155700E+04, 0.12773000E+05, 0.46143700E+03, -.14602000E+06, 0.72759000E+05, 0.72011200E+05, 0.43601400E+04, -.20431200E+05, 0.65300600E+05, 0.55226900E+05, 0.59140600E+05, -.77018900E+04, -.48983000E+05, 0.24276000E+05, 0.23888100E+05, 0.47735800E+04, -.73411800E+04, 0.15755600E+05, 0.49111400E+04, 0.80395000E+04, -.22662100E+04, -.19591400E+06, 0.97338300E+05, 0.97956700E+05, -.13079500E+05, -.34773000E+05, 0.92840400E+05, 0.85893400E+05, 0.93157900E+05, -.14488100E+05, -.13150800E+06, 0.65342400E+05, 0.62384700E+05, -.34410100E+04, -.12914100E+05, 0.47983600E+05, 0.27482200E+05, 0.30206000E+05, 0.35679600E+04, 0.13892000E+06, -.69357600E+05, -.67325600E+05, -.13361300E+05, 0.16199100E+05, -.55099500E+05, -.35130700E+05, -.42272700E+05, 0.59144200E+04, -.16525300E+06, 0.82385200E+05, 0.82626100E+05, -.10974500E+05, -.29037400E+05, 0.78299800E+05, 0.73117900E+05, 0.78494500E+05, -.11970100E+05, -.13595700E+06, 0.68199200E+05, 0.66386600E+05, -.10023000E+05, -.16317200E+05, 0.61402900E+05, 0.51881700E+05, 0.59476200E+05, -.13766700E+04, 0.79755600E+05, -.39814300E+05, -.38416800E+05, 0.43269500E+04, 0.17680000E+05, -.32191200E+05, -.22750000E+05, -.26974000E+05, 0.50748100E+04, 0.15282900E+06, -.76125200E+05, -.74592600E+05, -.56224900E+04, 0.23151500E+05, -.63573900E+05, -.46869100E+05, -.52805700E+05, 0.58371600E+04, -.24323600E+06, 0.12150200E+06, 0.11908500E+06, -.13365300E+05, -.28598600E+05, 0.11168200E+06, 0.99023200E+05, 0.10613800E+06, -.71170500E+04, 0.20916200E+04, -.87136700E+03, -.10856200E+04, 0.74833200E+02, 0.74028300E+03, -.70715500E+03, 0.32006700E+03, -.99979400E+03, 0.84389200E+02, 0.11970100E+06, -.59767500E+05, -.57946700E+05, -.45836200E+03, 0.22635800E+05, -.46170300E+05, -.30825000E+05, -.33141300E+05, 0.71910300E+04, -.17634700E+05, 0.87905500E+04, 0.74027000E+04, 0.21748300E+04, 0.61801900E+04, 0.22152800E+04, -.51474400E+04, -.68394300E+04, 0.62137700E+04, -.41300100E+05, 0.20568600E+05, 0.20332800E+05, -.11654800E+04, 0.10140800E+04, 0.16558900E+05, 0.11974300E+05, 0.12166200E+05, -.20973200E+03, 0.52715600E+05, -.36618600E+05, 0.37721500E+05, 0.37242800E+05, 0.38976300E+05, 0.43626200E+05, -.56179900E+03, 0.13305800E+05, 0.29855900E+05, 0.35166900E+05, -.35660300E+05, -.32050900E+05, -.34139500E+05, 0.99655400E+04, -.21975600E+05, 0.91958700E+04, -.11911200E+05, -.36541900E+05, 0.20260100E+05, 0.43856300E+05, 0.33192500E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.82716500E+00, -.41948800E+01, -.23881400E+00, -.73573900E+00, 0.48060700E+00, 0.20253200E+00, 0.60721100E+00, 0.13450000E+01, 0.98298600E-01, 0.75851600E-01, 0.99098800E+00, -.36166600E-01, -.76039100E-01, -.14058000E+00, 0.19685800E+00, -.62248400E-02, -.57688800E-02, -.46684800E+00, -.10066100E+00, 0.67997100E+03, -.17304700E+03, 0.10142500E+05, 0.20695600E+05, -.10959900E+05, -.18409800E+05, -.23806900E+05, 0.15722500E+05, 0.26445400E+05, -.14694600E+05, -.14171000E+05, -.85531200E+04, -.15948900E+05, -.15044400E+04, 0.89577200E+04, 0.15262300E+05, -.13946500E+05, 0.27285500E+05, -.13206000E+05, -.15833700E+05, -.15745600E+05, -.30841300E+05, 0.35727400E+04, 0.17193400E+05, 0.26671400E+05, -.23084800E+05, 0.53316200E+04, -.21706500E+04, -.27086000E+04, 0.34041800E+04, 0.66964800E+04, -.57316500E+04, -.78337200E+04, -.11655600E+05, 0.42676500E+04, 0.37515400E+05, -.17789100E+05, -.18818100E+05, 0.11917900E+05, 0.33495100E+05, -.25573200E+05, -.27378300E+05, -.36754900E+05, 0.17348400E+05, 0.16018600E+05, -.64695400E+04, -.78777000E+04, 0.96270400E+04, 0.20057900E+05, -.14330100E+05, -.17419700E+05, -.22774300E+05, 0.13085300E+05, 0.51106200E+05, -.21725000E+05, -.25553400E+05, 0.25165600E+04, 0.26002900E+05, -.23396700E+05, -.18604100E+05, -.23730000E+05, 0.10389500E+05, 0.12341100E+05, -.42651500E+04, -.38951500E+04, 0.19125400E+05, 0.41436700E+05, -.24746000E+05, -.39435600E+05, -.53466400E+05, 0.29670800E+05, -.30002100E+04, 0.15390700E+04, 0.10357800E+04, -.15368300E+05, -.40702500E+05, 0.16988500E+05, 0.27339400E+05, 0.37086500E+05, -.25890700E+05, 0.43229100E+05, -.18944900E+05, -.21614300E+05, 0.18069300E+04, 0.21253300E+05, -.19642800E+05, -.16364100E+05, -.19856700E+05, 0.82596200E+04, 0.26264300E+05, -.13748100E+05, -.12091700E+05, 0.10068900E+05, 0.22862200E+05, -.21506000E+05, -.26020600E+05, -.36051000E+05, 0.12826100E+05, -.29617400E+05, 0.14787500E+05, 0.13807100E+05, -.73833500E+04, -.22110300E+05, 0.19638500E+05, 0.23559100E+05, 0.29438000E+05, -.13714600E+05, -.36311800E+05, 0.16883400E+05, 0.17698400E+05, -.14838600E+05, -.40391200E+05, 0.29431700E+05, 0.35133900E+05, 0.45819800E+05, -.23929000E+05, 0.51403800E+05, -.24536800E+05, -.24472000E+05, 0.15019200E+05, 0.42192600E+05, -.36822100E+05, -.40566000E+05, -.55386800E+05, 0.22401900E+05, -.68701100E+03, -.67616400E+03, 0.36345500E+03, 0.36682800E+02, -.64186900E+03, 0.40235400E+03, 0.20091400E+03, 0.93417100E+03, -.32493300E+03, -.44322900E+05, 0.21001300E+05, 0.21519300E+05, -.15135900E+05, -.38975000E+05, 0.33319200E+05, 0.40606500E+05, 0.48650100E+05, -.25331100E+05, -.23624500E+05, 0.11810800E+05, 0.12317500E+05, 0.67519400E+04, 0.98017100E+04, 0.12041500E+04, -.84885900E+04, -.11219500E+05, 0.10144300E+05, 0.27594900E+04, -.79851900E+03, -.11926200E+04, 0.21820000E+04, 0.63659000E+04, -.22918900E+04, -.61224400E+03, -.36307900E+04, 0.37444800E+04, -.13375700E+05, 0.31526800E+05, -.32017200E+05, -.18782600E+05, -.27832000E+05, -.23887600E+05, 0.13804700E+05, -.15564300E+05, -.53157400E+04, -.96263400E+03, 0.20765300E+05, 0.20598600E+05, 0.57335100E+03, -.21318900E+05, -.20876300E+03, -.94308300E+04, 0.18108500E+05, 0.31499000E+05, -.64370200E+03, -.29788500E+05, -.31100700E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.39054500E+01, 0.42339700E+01, -.34510800E+01, -.31722700E+01, 0.24235800E+01, 0.98523900E+01, 0.77597000E+01, 0.29581200E+01, 0.59278500E+00, 0.69072200E+00, 0.13102300E+01, 0.83562100E+00, 0.20341800E+00, 0.60568600E-01, 0.30501000E+00, -.28998100E+01, -.29528800E+00, 0.74090600E+00, -.17424300E+01, -.41357800E+00, 0.10328500E+05, -.13142300E+05, 0.23039700E+05, -.41379500E+04, -.18277600E+05, -.18645600E+05, 0.15769900E+05, 0.96338000E+05, -.48455500E+05, -.55776200E+05, -.12939200E+03, -.19976500E+05, -.25372300E+05, -.47984000E+04, -.34155800E+04, -.28239100E+05, -.46125200E+05, 0.23277800E+05, 0.11251800E+05, -.79831800E+05, -.87382100E+03, 0.46710000E+05, 0.86551400E+05, 0.64212400E+05, -.15873100E+05, -.90082200E+05, 0.44093200E+05, 0.45981900E+05, -.79551100E+04, -.11475400E+05, 0.39738700E+05, 0.30946200E+05, 0.44808100E+05, 0.85699500E+03, -.13275100E+06, 0.66480300E+05, 0.77663200E+05, 0.31578600E+05, 0.17175100E+05, 0.64849100E+05, 0.57272300E+05, 0.58112600E+05, 0.42722100E+05, 0.48779300E+05, -.24112100E+05, -.19266600E+05, 0.24282300E+05, 0.27587900E+05, -.39863900E+05, -.59746500E+05, -.56992100E+05, 0.26822400E+05, -.35957100E+06, 0.18126000E+06, 0.17979600E+06, -.24447100E+05, -.11330400E+05, 0.16807300E+06, 0.15409700E+06, 0.16882000E+06, 0.42228900E+05, -.70811800E+05, 0.35613600E+05, 0.46670500E+05, -.27992900E+05, 0.55885100E+05, 0.11308400E+05, -.10158200E+05, -.73731100E+04, 0.46131800E+05, 0.12375900E+06, -.61559700E+05, -.81264400E+05, -.53766400E+05, -.84929600E+04, -.47126000E+05, -.85779100E+04, -.26364500E+05, -.27828800E+05, -.29860300E+06, 0.15140000E+06, 0.14930200E+06, -.21548000E+05, -.63799300E+04, 0.14004200E+06, 0.13059500E+06, 0.14003400E+06, 0.36386600E+05, -.31998300E+06, 0.16020300E+06, 0.16876300E+06, -.38900300E+05, -.42679900E+05, 0.15656100E+06, 0.14653800E+06, 0.17606400E+06, 0.42583200E+04, 0.15689000E+05, -.78334100E+04, -.12823100E+05, 0.15583700E+05, -.26846700E+05, 0.44146500E+04, 0.17763100E+05, 0.10900400E+05, -.24035400E+05, 0.12583500E+06, -.63048100E+05, -.78596300E+05, -.24382100E+05, -.30436200E+05, -.51906900E+05, -.25286800E+05, -.36505500E+05, -.38459400E+05, -.42348000E+06, 0.21235700E+06, 0.23189600E+06, -.43184400E+05, -.25096200E+05, 0.21638200E+06, 0.21571500E+06, 0.22894100E+06, 0.35299500E+05, 0.60773000E+04, -.31182100E+04, -.14495500E+03, -.52886900E+03, 0.27560700E+04, -.25349100E+04, 0.23688900E+03, -.33588100E+04, 0.11347000E+04, -.62687800E+05, 0.30710400E+05, 0.18227900E+05, -.49316200E+04, -.64640300E+05, 0.46837000E+05, 0.69768600E+05, 0.75326700E+05, -.51228900E+05, -.12612500E+05, 0.63543400E+04, 0.18199800E+05, -.77290100E+04, 0.38477500E+04, 0.52287200E+04, -.27274000E+04, -.11100800E+05, 0.11945100E+04, -.86128500E+05, 0.43141200E+05, 0.44451600E+05, -.30040100E+04, 0.14929400E+05, 0.28667300E+05, 0.14301900E+05, 0.21067900E+05, 0.21873300E+05, 0.25075800E+05, -.63791200E+04, 0.98788100E+04, 0.27038900E+05, 0.12062800E+05, 0.33080600E+05, 0.98474400E+05, -.16772800E+05, 0.10713400E+05, 0.63179000E+05, -.28136000E+05, -.33142000E+05, -.69812700E+05, -.50946100E+05, -.45622500E+05, -.17614700E+04, 0.28355300E+05, -.71924200E+04, 0.23248000E+05, 0.21905600E+05, 0.21352800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12138400E+01, -.17648300E+01, -.38894800E+00, -.61873200E+00, 0.45269800E+00, 0.18007300E+01, 0.13718800E+01, 0.21379600E+01, 0.83751700E-01, 0.13079900E+00, 0.98624100E+00, -.33247700E+00, 0.55327700E-02, 0.11315000E+00, -.83651200E-01, -.10734200E+00, -.74865400E-01, 0.59844500E+00, -.91310700E+00, 0.92169700E+00, -.24521800E-01, -.13552100E+05, -.13406800E+05, 0.92003400E+04, 0.12926800E+05, 0.17135400E+05, -.10828500E+05, 0.15418100E+05, -.78826000E+04, -.60011200E+04, 0.91402700E+04, 0.80590400E+04, -.13209700E+05, -.15499700E+05, -.23201600E+05, 0.76224200E+04, -.41516600E+05, 0.21000200E+05, 0.25880700E+05, -.17533600E+05, 0.25480400E+05, 0.11363100E+05, 0.11336300E+05, -.53473200E+04, 0.16950800E+05, -.28984200E+05, 0.14091000E+05, 0.14596500E+05, -.60559800E+04, -.99040000E+04, 0.16884700E+05, 0.17472400E+05, 0.24750100E+05, -.45350100E+04, -.83343400E+05, 0.41633700E+05, 0.41376800E+05, 0.33049200E+04, -.21076600E+05, 0.48887200E+05, 0.53618800E+05, 0.57725200E+05, -.62811700E+04, 0.82184200E+04, -.39683600E+04, -.45253500E+04, 0.20243200E+04, -.87417600E+04, -.16529600E+04, -.40601500E+04, 0.12928100E+04, -.49388700E+04, -.18696400E+06, 0.94580600E+05, 0.93482800E+05, -.10731700E+05, -.22086400E+05, 0.88313900E+05, 0.83403600E+05, 0.88188200E+05, -.68562900E+03, -.33882000E+05, 0.17019200E+05, 0.11826300E+05, -.25932000E+05, -.22226000E+05, 0.28507400E+05, 0.36879200E+05, 0.48994000E+05, -.14842800E+05, 0.57877600E+05, -.28662100E+05, -.27537500E+05, -.68954500E+04, 0.30739900E+05, -.38639500E+05, -.38674900E+05, -.52889500E+05, 0.19038200E+05, -.15677600E+06, 0.79619600E+05, 0.78387700E+05, -.94943700E+04, -.17937000E+05, 0.74282400E+05, 0.70690100E+05, 0.74126000E+05, -.64673900E+03, -.12726300E+06, 0.63606500E+05, 0.61578200E+05, -.21996100E+05, -.31881400E+05, 0.71539300E+05, 0.75051800E+05, 0.90344400E+05, -.12805100E+05, 0.30592700E+05, -.15227100E+05, -.13043600E+05, 0.11120100E+05, 0.13331300E+05, -.17337500E+05, -.16692200E+05, -.24835900E+05, 0.67450200E+04, 0.76982900E+05, -.38458300E+05, -.37149800E+05, 0.20509400E+04, 0.25637100E+05, -.46286600E+05, -.47098500E+05, -.57309500E+05, 0.12643000E+05, -.20168500E+06, 0.10109200E+06, 0.98335000E+05, -.26340800E+05, -.38835400E+05, 0.11242100E+06, 0.12124000E+06, 0.13239500E+06, -.13251200E+05, 0.24537300E+04, -.13844100E+04, -.11103900E+04, -.20590600E+03, 0.97831200E+03, -.98877900E+03, -.60333300E+02, -.20286200E+04, 0.23603100E+03, 0.18051000E+05, -.91646200E+04, -.72593800E+04, 0.89130300E+04, 0.16709600E+05, -.15521600E+05, -.15545300E+05, -.21954600E+05, 0.95398200E+04, 0.15453600E+05, -.77055200E+04, -.89113200E+04, -.84414300E+04, -.82609600E+04, 0.10180500E+04, 0.58719500E+04, 0.91216400E+04, -.87686600E+04, -.38238700E+05, 0.19158100E+05, 0.18712300E+05, -.30637300E+04, 0.15451300E+04, 0.15759600E+05, 0.11190700E+05, 0.12394300E+05, 0.17925400E+04, 0.23700300E+05, -.33452500E+05, 0.34992300E+05, 0.29487300E+05, 0.31175000E+05, 0.37067600E+05, 0.18588200E+05, 0.14382900E+05, 0.13394400E+05, 0.25474300E+05, -.31015000E+05, -.31161900E+05, -.26202600E+05, 0.36752100E+04, -.15424200E+05, 0.74650000E+04, -.11605400E+05, -.33699600E+05, 0.11256100E+05, 0.38506900E+05, 0.30535400E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12465900E+01, 0.17033500E+01, -.75367300E+00, 0.14034800E+01, 0.75047200E+00, -.63973300E+01, 0.20892700E+01, -.25975400E+01, -.25902700E+00, 0.71704500E+00, 0.57569900E+01, 0.11050600E+01, 0.49899100E+00, 0.10321500E+01, -.37569500E+00, -.64094800E+00, -.23711800E+00, 0.26845100E+00, -.24937900E+00, -.36203500E+00, -.10018400E+01, 0.11150500E+01, 0.47031000E+05, -.17934900E+05, -.37330300E+05, -.38255700E+05, 0.35045100E+05, 0.11678500E+06, -.58389300E+05, -.55400500E+05, -.13409200E+05, -.36036500E+05, -.19613700E+05, 0.10238100E+05, 0.12335000E+05, -.47151400E+05, 0.35728900E+05, -.19374400E+05, -.86623500E+04, -.84790200E+05, -.32502200E+05, 0.29108300E+05, 0.84820700E+05, 0.65018300E+05, -.45626900E+05, -.83985300E+05, 0.41094900E+05, 0.42298000E+05, -.44500900E+04, -.57258700E+04, 0.33991400E+05, 0.23947100E+05, 0.35018200E+05, 0.49111000E+04, -.12237200E+06, 0.61289700E+05, 0.61239500E+05, 0.33508100E+05, 0.49047500E+05, 0.46743000E+05, 0.35853300E+05, 0.32693100E+05, 0.69432500E+05, 0.54382500E+05, -.27232500E+05, -.27852000E+05, 0.25592800E+05, 0.44514200E+05, -.47386000E+05, -.67733500E+05, -.67199700E+05, 0.38551000E+05, -.28494900E+06, 0.14022900E+06, 0.14247600E+06, -.23808000E+05, 0.82055100E+04, 0.13169600E+06, 0.11757800E+06, 0.13248600E+06, 0.58555100E+05, -.70673400E+05, 0.35137800E+05, 0.26476100E+05, -.69558300E+03, 0.10581400E+06, -.14070500E+05, -.52076700E+05, -.55237200E+05, 0.86166900E+05, 0.14760900E+06, -.74819400E+05, -.71523200E+05, -.62340400E+05, -.48353800E+05, -.35688600E+05, 0.14423800E+05, -.22571800E+04, -.66851800E+05, -.23371300E+06, 0.11588800E+06, 0.11685600E+06, -.20591500E+05, 0.10368400E+05, 0.10836200E+06, 0.98773400E+05, 0.10838500E+06, 0.50778000E+05, -.30388700E+06, 0.15313100E+06, 0.14791700E+06, -.20631300E+05, -.16036000E+05, 0.13311800E+06, 0.11449800E+06, 0.13956200E+06, 0.27500900E+05, -.62885300E+04, 0.30005000E+04, 0.73547100E+04, 0.44217600E+04, -.54626200E+05, 0.24171200E+05, 0.44736600E+05, 0.39064500E+05, -.43911000E+05, 0.11707000E+06, -.58816200E+05, -.56981300E+05, -.33687600E+05, -.73190500E+05, -.29196600E+05, 0.49230200E+04, -.24325600E+04, -.73813600E+05, -.38966300E+06, 0.19559400E+06, 0.18999200E+06, -.17618500E+05, 0.21903100E+05, 0.17334300E+06, 0.16025800E+06, 0.16949100E+06, 0.78259100E+05, 0.53255100E+04, -.20092400E+04, -.21884700E+04, 0.33388800E+03, 0.27977300E+04, -.22345700E+04, 0.44136000E+03, -.15353000E+04, 0.14126900E+04, -.94062800E+05, 0.46122300E+05, 0.49488700E+05, -.17560700E+05, -.10886200E+06, 0.77741500E+05, 0.10822600E+06, 0.11520400E+06, -.82722800E+05, -.44546500E+05, 0.22199400E+05, 0.20818100E+05, 0.50193900E+04, 0.17508900E+05, 0.59559600E+04, -.12961400E+05, -.20159000E+05, 0.15502900E+05, -.69223300E+05, 0.34539800E+05, 0.33856800E+05, -.13001700E+04, 0.17559900E+05, 0.20502000E+05, 0.87893200E+04, 0.15417500E+05, 0.26483300E+05, 0.19939800E+05, 0.22959100E+05, -.20010500E+05, 0.18318500E+05, -.10793900E+05, 0.69750700E+04, 0.11143400E+06, -.43437500E+05, 0.97305600E+04, 0.47243900E+05, -.98618400E+04, -.12641900E+05, -.55368400E+05, -.79309800E+05, -.47608700E+05, -.13492800E+05, 0.55861500E+05, 0.22979000E+05, 0.27902400E+05, -.46969700E+04, -.25777000E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.69146500E-03, 0.32185400E+00, -.56390000E-02, -.28156200E-01, 0.18034200E-01, 0.28738900E+01, 0.24665900E+01, -.65058800E+00, 0.17603700E+00, 0.10079000E+00, -.23995800E+00, 0.40184300E-01, 0.15496300E+00, 0.29097200E+00, -.37420800E+00, 0.22320300E-01, -.16867900E-01, 0.30397800E+00, 0.68831900E+00, -.12010600E+00, 0.44019100E-01, -.17528300E+00, -.67873000E-02, 0.12217600E+04, 0.26280900E+04, 0.33693700E+02, -.61893000E+03, 0.89338100E+04, -.44566000E+04, -.43609800E+04, 0.10934100E+04, 0.68236400E+03, -.50658200E+04, -.38892700E+04, -.45103500E+04, 0.14172400E+03, -.10447200E+04, 0.56097800E+03, 0.74194000E+03, -.50355400E+04, -.23566700E+04, -.15205300E+04, -.51438600E+04, -.10894300E+04, -.29895800E+04, -.24709500E+04, 0.11940800E+04, 0.12356800E+04, -.23809800E+03, -.20141700E+03, 0.19083100E+04, 0.29562200E+04, 0.24147700E+04, -.11810800E+03, -.29519100E+05, 0.14705900E+05, 0.14743600E+05, 0.25258100E+04, 0.14406200E+04, 0.16918000E+05, 0.22755600E+05, 0.16298900E+05, 0.35995500E+04, 0.55334400E+04, -.27922100E+04, -.27854400E+04, 0.32060600E+04, 0.19769600E+04, -.19338400E+04, -.51264500E+03, -.30014100E+04, 0.16016900E+04, -.35732000E+05, 0.17907200E+05, 0.17866100E+05, 0.60292500E+03, 0.25167500E+04, 0.18909300E+05, 0.24408100E+05, 0.18335800E+05, 0.29613400E+04, -.98600100E+04, 0.49156000E+04, 0.47006900E+04, -.55156900E+03, -.58264000E+03, 0.68394700E+04, 0.97659000E+04, 0.58834300E+04, -.73246200E+03, 0.25428000E+05, -.12641900E+05, -.12646400E+05, -.29143000E+04, -.20850300E+04, -.15109000E+05, -.20458400E+05, -.14697300E+05, -.22203100E+04, -.30904200E+05, 0.15491700E+05, 0.15452100E+05, 0.11087000E+03, 0.17055200E+04, 0.16330700E+05, 0.20442700E+05, 0.15975800E+05, 0.20001900E+04, -.18858500E+05, 0.93847800E+04, 0.93162200E+04, -.56792200E+03, 0.71861200E+03, 0.11418500E+05, 0.15762600E+05, 0.11378900E+05, 0.95819700E+03, -.86933800E+03, 0.45029400E+03, 0.55307800E+03, -.11851700E+04, -.75333400E+03, -.94151900E+03, -.33805100E+04, -.97770800E+03, 0.28058700E+03, 0.25395300E+05, -.12640700E+05, -.12633500E+05, -.19869800E+04, -.93469700E+03, -.15145200E+05, -.20684400E+05, -.14282300E+05, -.14683700E+04, -.45098500E+05, 0.22468700E+05, 0.22404800E+05, -.30916800E+03, 0.16246600E+04, 0.25141700E+05, 0.32556500E+05, 0.24525500E+05, 0.32943300E+04, -.37760200E+03, 0.14754600E+03, 0.14905400E+03, -.19742700E+03, -.15685100E+03, 0.16354700E+03, -.44961700E+01, -.17802300E+03, -.91336400E+02, 0.76593900E+03, -.34136800E+03, -.32172400E+03, -.30152300E+04, -.74783400E+03, -.17864800E+04, -.39147300E+04, -.63238900E+03, -.69277100E+03, -.23878000E+03, 0.11939000E+03, 0.35817700E+02, -.89944800E+03, -.78427600E+03, 0.55847500E+03, -.27374800E+03, 0.73021800E+03, -.74539100E+03, -.90939600E+04, 0.45390500E+04, 0.45339200E+04, 0.40966500E+03, 0.15517900E+04, 0.43056600E+04, 0.48578500E+04, 0.22553200E+04, 0.13123900E+04, 0.82574700E+04, -.82877800E+04, 0.82802400E+04, 0.84874500E+04, 0.75292100E+04, 0.92430800E+04, 0.26601800E+04, 0.58930800E+04, 0.13380300E+05, 0.31728100E+04, -.81985000E+04, -.61804200E+04, -.32125300E+04, 0.11146600E+04, -.11100500E+05, 0.27476100E+04, -.37845600E+04, -.83626600E+04, 0.12432800E+05, 0.96057200E+04, 0.74779700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.56100500E+00, -.24070700E+01, 0.31668900E+00, -.24925400E+00, 0.26160300E+00, -.34565800E+00, 0.22287500E+00, 0.12943900E+01, -.17892300E-01, -.13277600E+00, 0.12172100E+01, 0.31600400E+00, 0.84642200E-01, 0.45359900E-01, -.30393500E-01, 0.21995500E+00, -.94358800E-02, -.25342400E+00, -.25325200E+00, 0.27857900E-01, -.14809600E+00, 0.19049600E+00, -.21691800E+00, -.11822900E+01, 0.36617500E+04, 0.61708400E+04, 0.32275200E+03, 0.12106600E+05, -.61420300E+04, -.67579700E+04, -.46627700E+03, -.13605900E+04, -.53367600E+04, -.91181200E+04, -.91315700E+04, -.42895500E+04, -.42365800E+05, 0.21167300E+05, 0.19474700E+05, -.28679400E+05, -.12904400E+04, 0.20056900E+05, 0.18189400E+05, 0.14148500E+05, -.33054600E+04, -.12716100E+05, 0.62586400E+04, 0.63583000E+04, -.12867700E+04, -.14498800E+04, 0.63651700E+04, 0.69700800E+04, 0.70769300E+04, 0.40368200E+03, -.47900700E+05, 0.23967700E+05, 0.24156900E+05, 0.15572000E+05, 0.13766300E+04, 0.24126100E+05, 0.29282400E+05, 0.29203700E+05, 0.11045700E+05, 0.26007900E+05, -.12909400E+05, -.12800200E+05, 0.10581700E+05, 0.16260300E+04, -.12767600E+05, -.92717800E+04, -.94149400E+04, 0.26995100E+04, -.12226400E+06, 0.61158600E+05, 0.61131200E+05, -.70778700E+04, -.47836700E+04, 0.59817600E+05, 0.60754600E+05, 0.59997700E+05, 0.99933900E+04, -.18351900E+05, 0.92429900E+04, 0.11195200E+05, -.27511300E+04, -.13987000E+04, 0.10748800E+05, 0.17565400E+05, 0.18647800E+05, 0.11229500E+04, 0.28868300E+05, -.14374100E+05, -.14943700E+05, -.21596700E+05, -.18222100E+04, -.13918500E+05, -.16517200E+05, -.19313500E+05, -.67667400E+04, -.10482500E+06, 0.52586200E+05, 0.52412300E+05, -.63960600E+04, -.37786700E+04, 0.51105300E+05, 0.52240300E+05, 0.51152700E+05, 0.84765500E+04, -.65262400E+05, 0.32727400E+05, 0.33290300E+05, -.64833900E+04, -.57465600E+04, 0.34018600E+05, 0.39593200E+05, 0.40711400E+05, 0.35524700E+04, 0.59550100E+04, -.29783100E+04, -.38752100E+04, 0.16141500E+04, 0.10081200E+04, -.35928000E+04, -.70921000E+04, -.50890000E+04, -.21201000E+03, 0.40833800E+05, -.20445400E+05, -.21006300E+05, -.13815400E+05, -.16393300E+04, -.20063600E+05, -.24686000E+05, -.26130800E+05, -.63681500E+04, -.11778700E+06, 0.58947600E+05, 0.59793700E+05, -.53396100E+04, -.52290700E+04, 0.60582900E+05, 0.70228200E+05, 0.69852500E+05, 0.11375700E+05, -.93260600E+03, 0.43604500E+03, 0.55532300E+03, 0.25986000E+03, 0.45514000E+03, 0.20869700E+03, 0.22249000E+03, 0.83799400E+03, 0.43569800E+03, -.13830200E+05, 0.67565400E+04, 0.62063500E+04, -.66510100E+04, -.81542900E+03, 0.64230200E+04, -.53904900E+03, 0.15939100E+04, -.28478700E+04, 0.20970600E+04, -.10427200E+04, -.54975100E+03, -.60425900E+03, 0.11518900E+03, -.12834300E+04, 0.51673600E+03, 0.80303800E+03, -.70163400E+02, -.16051600E+05, 0.80610000E+04, 0.81564600E+04, -.36974900E+03, 0.90152600E+03, 0.83376000E+04, 0.10292200E+05, 0.12379900E+05, 0.33284300E+04, 0.10350300E+05, -.12429400E+05, 0.11455800E+05, 0.11351800E+05, 0.10898300E+05, 0.19294500E+05, 0.78198300E+04, 0.91245200E+04, 0.18488300E+05, 0.17204000E+05, -.90128600E+04, -.18833000E+05, -.18129800E+05, 0.21108700E+04, -.11573400E+05, 0.71754200E+04, -.85497700E+04, -.12317000E+05, 0.13192200E+05, 0.10270400E+05, 0.90209400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17292500E+01, -.23785400E+01, 0.11944800E+01, 0.18222100E+01, -.68068000E+00, -.96253800E+01, -.28999900E+01, -.25835800E+01, -.50224900E+00, -.27322600E-01, 0.16414500E+01, -.10317300E+01, 0.63161600E+00, 0.35972200E+00, 0.48009800E+00, 0.12006500E+01, 0.25693500E+00, -.46532700E+00, -.40209200E+00, 0.57876800E+00, -.18296400E+00, 0.41522300E+00, 0.44592600E-02, 0.12552300E+01, -.91846200E+00, 0.88837400E+04, 0.18488300E+04, -.77648900E+02, 0.35434600E+02, 0.24880100E+04, -.46362600E+04, -.28891500E+04, 0.22253800E+04, -.56321600E+04, -.55297600E+04, -.10117900E+05, -.48097700E+05, 0.24229300E+05, 0.30159500E+05, -.38346900E+05, 0.25104600E+03, 0.28840000E+05, 0.37044900E+05, 0.19973400E+05, -.67232300E+04, -.14208100E+05, 0.71129300E+04, 0.71755500E+04, -.14290100E+04, -.22306600E+04, 0.61781300E+04, 0.54646000E+04, 0.64939000E+04, 0.87489700E+03, -.35857700E+05, 0.17928400E+05, 0.17675700E+05, 0.17752000E+05, -.33064200E+04, 0.16062600E+05, 0.74852200E+04, 0.21878400E+05, 0.17429300E+05, 0.32842800E+05, -.16240600E+05, -.17033100E+05, 0.10020200E+05, -.33512300E+04, -.16031800E+05, -.14803600E+05, -.90581000E+04, 0.23032400E+04, -.12685000E+06, 0.63729100E+05, 0.63425000E+05, -.14667500E+05, -.10973900E+05, 0.59042900E+05, 0.48643300E+05, 0.60500900E+05, 0.18812900E+05, -.23775700E+05, 0.11888100E+05, 0.58198500E+04, 0.15227700E+04, 0.28103600E+04, 0.71257200E+04, 0.61028500E+04, 0.19550300E+05, 0.89971100E+04, 0.67419700E+04, -.32174000E+04, -.12715200E+04, -.27813000E+05, 0.49895600E+03, -.59229800E+03, 0.95878900E+04, -.69203100E+04, -.14075900E+05, -.10868200E+06, 0.54685200E+05, 0.54340100E+05, -.12236300E+05, -.77328100E+04, 0.50099500E+05, 0.42990800E+05, 0.50936300E+05, 0.17090200E+05, -.77453700E+05, 0.38626300E+05, 0.35686700E+05, -.75551200E+04, -.10901200E+05, 0.35520900E+05, 0.31384200E+05, 0.41856700E+05, 0.83696900E+04, 0.14845300E+05, -.74008300E+04, -.48441800E+04, 0.26339500E+04, -.83495600E+03, -.30659800E+04, -.63394800E+03, -.46505200E+04, -.52291700E+04, 0.28166100E+05, -.14085200E+05, -.12339100E+05, -.16881000E+05, -.13163800E+04, -.11697800E+05, -.36010600E+04, -.19095300E+05, -.12524900E+05, -.11992500E+06, 0.59966700E+05, 0.56136500E+05, -.71167100E+04, -.13690500E+05, 0.57317300E+05, 0.48944200E+05, 0.65562000E+05, 0.21808300E+05, -.15698700E+04, 0.77510300E+03, 0.96594100E+03, 0.82304800E+03, 0.81089300E+03, 0.30151100E+03, 0.27071100E+03, 0.17971600E+04, 0.88561200E+03, -.26436400E+05, 0.13161600E+05, 0.15527300E+05, -.55863300E+04, -.19952900E+04, 0.13741300E+05, 0.12207900E+05, 0.68316700E+04, -.76738400E+04, 0.24224800E+04, -.12105300E+04, -.27646600E+04, 0.23606500E+04, 0.23538400E+04, -.12062900E+04, 0.16289100E+04, 0.36056200E+02, 0.15060800E+04, -.53615400E+04, 0.26772100E+04, 0.20745200E+04, -.15217200E+04, -.35388500E+04, 0.45548400E+04, 0.58203700E+04, 0.14311400E+05, 0.43765300E+04, 0.27102900E+04, -.57961700E+04, 0.39759700E+04, 0.56618500E+04, 0.28275400E+04, 0.15671900E+05, 0.72027900E+04, -.23980800E+04, 0.52167000E+04, 0.15613500E+05, -.40524500E+03, -.22336000E+05, -.17635800E+05, 0.39959100E+02, 0.21287000E+04, 0.65851600E+04, -.35036300E+04, -.55342700E+04, -.71331900E+02, 0.17052900E+03, 0.23630800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20248000E+01, 0.35705700E+01, -.33763100E+00, 0.87653400E+00, -.84250300E+00, -.14483700E+01, -.38440400E+01, -.24758000E+00, -.15518000E+00, -.16091900E+00, -.14887900E+01, -.17815900E+00, -.72659500E+00, -.10111300E+00, 0.22298800E+00, 0.12694800E+00, 0.36017300E-01, 0.14916000E+00, 0.14620000E+00, 0.25970400E+00, -.76092700E-01, 0.83842000E-01, 0.13127100E+00, 0.59140700E+00, -.50102600E+00, 0.35393400E+00, 0.89671200E+03, -.55589000E+04, 0.28582900E+04, 0.16839800E+04, 0.17545600E+04, 0.20794400E+04, 0.93784800E+03, 0.15387100E+04, 0.81269700E+03, 0.47367400E+03, 0.64964200E+04, -.34810200E+04, -.58339500E+04, 0.42489300E+04, 0.86033200E+03, -.56425200E+04, -.81015900E+04, -.59318400E+04, 0.18137400E+04, 0.34199500E+04, -.16796500E+04, -.17468000E+04, 0.40748100E+02, 0.18195500E+03, -.12487900E+04, -.64063000E+03, -.14110400E+04, 0.25097100E+03, -.13329800E+05, 0.66225500E+04, 0.67320800E+04, -.46409300E+04, -.35822500E+04, 0.58290600E+04, 0.60328600E+04, 0.69354600E+04, 0.19467600E+04, -.51471800E+04, 0.24942300E+04, 0.28223400E+04, -.82929600E+03, -.19516200E+03, 0.23514100E+04, 0.84870300E+03, 0.24650500E+04, -.88417500E+02, 0.15455400E+05, -.82258100E+04, -.77279200E+04, -.18817400E+03, 0.27866700E+04, -.76188100E+04, -.61835300E+04, -.78406900E+04, 0.58536200E+04, -.46549600E+03, 0.16249200E+03, 0.28637400E+04, -.15268300E+04, -.21625300E+04, 0.24028400E+04, 0.20699900E+04, 0.19624700E+04, 0.67716200E+03, -.30967200E+03, -.13810600E+02, -.67871800E+03, 0.30759800E+04, 0.19528600E+03, -.20500100E+03, -.24508300E+04, -.10871100E+04, -.39073800E+04, 0.14093100E+05, -.74897200E+04, -.70462300E+04, -.50839400E+02, 0.22732000E+04, -.68859700E+04, -.59708500E+04, -.69625000E+04, 0.49771900E+04, 0.89428500E+04, -.43982200E+04, -.31698600E+04, -.75196300E+03, -.84107700E+03, -.32453300E+04, -.13442700E+04, -.37923300E+04, 0.19249600E+04, -.67048900E+04, 0.33224300E+04, 0.21674400E+04, 0.28908600E+03, -.97792800E+03, 0.19164100E+04, 0.17421400E+04, 0.11693000E+04, -.99288800E+03, 0.10842800E+04, -.52781900E+03, -.12045600E+04, 0.20302300E+04, 0.73361100E+03, -.57124200E+03, -.17416800E+04, -.12281800E+04, -.30488700E+04, -.68109900E+02, -.19960900E+02, 0.17055500E+04, -.33551000E+04, -.39260400E+04, -.70670300E+02, 0.10140600E+04, 0.31017800E+03, 0.45938200E+04, 0.59153300E+03, -.19131000E+03, -.30889800E+03, -.14158100E+03, -.27760800E+03, -.14863000E+03, -.10873900E+03, -.47341800E+03, -.14357000E+03, 0.83606900E+03, -.37681800E+03, -.12921700E+04, 0.11273700E+04, -.90016200E+03, -.34644700E+03, 0.13878100E+04, -.19781800E+04, -.14394200E+04, 0.23617600E+03, -.12002200E+03, 0.51637300E+03, -.34009800E+03, -.40743100E+03, -.15110600E+03, -.87059500E+02, 0.76198000E+03, -.14989200E+03, 0.44845500E+04, -.22845700E+04, -.20004800E+04, -.18205100E+03, -.96297300E+03, -.19669500E+04, -.19579400E+04, -.31869800E+04, 0.98397400E+03, 0.64181900E+03, -.11976900E+04, 0.13293600E+04, 0.38214100E+03, 0.18068900E+04, -.19271200E+03, 0.50312900E+04, -.17042300E+04, 0.40524500E+03, -.80704700E+04, -.43721100E+03, 0.72163600E+03, 0.76389400E+04, -.45859900E+04, -.97629900E+03, 0.53746100E+03, 0.43096100E+04, -.12982900E+04, 0.10074900E+04, 0.13368400E+04, 0.21137400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.24958000E-01, 0.25194900E+01, -.59261500E-01, 0.28292500E-01, 0.33736000E-01, 0.72636800E+00, -.61423400E+00, 0.17393200E-01, -.20423600E-02, 0.15459200E-02, 0.49168300E+00, -.20714300E-01, 0.32210600E-01, 0.29289400E-01, -.27235900E-01, 0.24275300E-01, -.12330400E-02, 0.17988000E-02, -.35366500E-01, 0.54051200E-01, -.20010300E-01, 0.61448900E-01, 0.25084400E-01, -.14576000E+00, -.44892000E-02, -.21371500E-01, -.48327400E-01, 0.17876700E+04, -.89739300E+03, -.96603300E+03, 0.20181600E+03, -.69363500E+02, -.10331300E+04, -.98489500E+03, -.92220200E+03, 0.23808000E+03, -.14181900E+04, 0.68916800E+03, 0.57543200E+03, -.15192900E+04, -.29518900E+03, 0.36670500E+03, 0.16531400E+03, 0.33388400E+03, -.14339300E+03, 0.77298900E+02, -.68917100E+02, -.45297900E+02, -.53923800E+02, -.31731800E+02, 0.36526200E+02, 0.11338200E+03, 0.71091400E+02, -.70122800E+02, -.42452200E+04, 0.21184100E+04, 0.21155300E+04, 0.62499400E+03, 0.31027300E+03, 0.21656800E+04, 0.23338700E+04, 0.23015200E+04, 0.88092200E+02, 0.53669500E+03, -.26305900E+03, -.25904400E+03, 0.81356900E+03, 0.19709800E+03, -.34148800E+03, -.37479500E+03, -.40321100E+03, 0.22144700E+03, -.60043100E+04, 0.30132600E+04, 0.30020800E+04, -.38996800E+03, 0.75799900E+03, 0.30960700E+04, 0.34362900E+04, 0.30711700E+04, -.11877900E+03, -.35788800E+03, 0.17817200E+03, 0.33186500E+03, -.25392200E+03, -.21770400E+03, 0.45791600E+03, 0.41404300E+03, 0.40774100E+03, -.18132500E+03, 0.37525200E+04, -.18853600E+04, -.19098400E+04, -.71148800E+03, -.59087300E+03, -.20281800E+04, -.23202400E+04, -.21239200E+04, 0.17678400E+03, -.51070300E+04, 0.26109700E+04, 0.25535200E+04, -.35375100E+03, 0.68743000E+03, 0.26263900E+04, 0.29258300E+04, 0.26058100E+04, -.14674700E+03, -.19240900E+04, 0.10324400E+04, 0.10364400E+04, -.36846100E+03, 0.34687100E+02, 0.12555300E+04, 0.16058500E+04, 0.13510400E+04, -.35477900E+03, -.36201700E+03, 0.17953400E+03, 0.10331700E+03, 0.20526900E+02, -.46696500E+02, 0.27944900E+02, -.14989900E+03, -.38205000E+01, 0.25828500E+02, 0.27326000E+04, -.13680100E+04, -.13836700E+04, -.53520200E+03, -.31594200E+03, -.14150800E+04, -.16216300E+04, -.14940000E+04, -.17759300E+02, -.67404600E+04, 0.34430700E+04, 0.34806600E+04, -.57913600E+03, 0.16344700E+03, 0.36627800E+04, 0.40522500E+04, 0.38454900E+04, -.45634500E+03, -.73570100E+02, 0.42782900E+02, 0.37269100E+02, -.16609100E+02, 0.70618200E+00, 0.26827300E+02, 0.15614600E+02, -.13525900E+02, -.91998300E+01, -.17594800E+03, 0.77609000E+02, 0.59244700E+02, -.59253800E+03, -.15729600E+03, 0.16224200E+03, 0.12736800E+03, 0.14401600E+03, -.27100800E+03, -.11573500E+02, 0.57329700E+01, 0.22658000E+02, -.10008400E+03, -.60736600E+02, -.34912500E+02, -.28090400E+02, 0.42852900E+02, -.21838800E+02, -.20302700E+04, 0.10107500E+04, 0.10262500E+04, -.63851000E+02, 0.21838000E+03, 0.97735400E+03, 0.89062600E+03, 0.79635700E+03, -.12566000E+03, 0.81043300E+03, -.79185900E+03, 0.77852700E+03, 0.75278400E+03, 0.64971800E+03, 0.12135300E+04, 0.98103100E+03, 0.43219900E+03, 0.13762700E+04, 0.67474300E+03, -.77440200E+03, -.66983300E+03, -.58570800E+03, -.38415900E+03, -.88047800E+03, -.19414100E+02, -.15454600E+03, -.79028600E+03, 0.99796500E+03, 0.88373900E+03, 0.54268700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.29126000E+01, 0.22232600E+01, -.11101700E+01, 0.21789700E+00, 0.34870200E+00, -.20531800E+01, -.43549800E+01, -.26633400E+01, -.88640200E-01, -.11572200E+00, 0.44286000E+01, 0.12252600E+01, -.56594700E+00, -.16521600E+00, 0.48549900E+00, -.52024900E+00, 0.37085900E-01, 0.33679300E+00, 0.11012300E+01, 0.26125500E+00, 0.22568600E+00, -.50876400E+00, -.78608300E-02, 0.17493800E+01, -.17483500E+01, 0.65853300E+00, 0.87755700E+00, 0.21977200E+01, 0.31023700E+03, -.97874700E+03, 0.67451800E+03, 0.15047800E+04, -.69252200E+03, -.10444100E+04, -.92951300E+03, -.25677600E+04, -.25612500E+05, 0.11851700E+05, 0.97765700E+04, -.19465600E+05, 0.58144500E+03, 0.11449500E+05, 0.13439100E+05, 0.12575900E+05, -.56879200E+04, 0.70714900E+04, -.32540000E+04, -.35315100E+04, -.84836100E+03, 0.65579600E+02, -.25509400E+04, -.15403400E+04, -.24672600E+04, -.31363400E+03, -.17433200E+05, 0.86316600E+04, 0.89811600E+04, 0.67367200E+04, -.98864900E+02, 0.85892200E+04, 0.66382700E+04, 0.89095400E+04, 0.11465300E+05, 0.18179200E+05, -.93031800E+04, -.88021800E+04, 0.91595400E+04, -.15744700E+03, -.94354200E+04, -.11226600E+05, -.92898000E+04, 0.32718400E+04, -.43068400E+05, 0.19475600E+05, 0.21534800E+05, -.94564300E+04, 0.25218700E+04, 0.20337600E+05, 0.17433700E+05, 0.20308100E+05, 0.10247800E+05, -.39488800E+04, 0.16995200E+04, 0.46933700E+04, -.24489600E+04, -.26264200E+04, 0.44520100E+04, 0.45604800E+04, 0.48986100E+04, -.17630400E+04, 0.11589700E+05, -.64809100E+04, -.68387500E+04, -.84347100E+04, -.15839200E+04, -.65603500E+04, -.48923700E+04, -.62416800E+04, -.91030900E+04, -.36906800E+05, 0.16194900E+05, 0.18453800E+05, -.78613400E+04, 0.22514800E+04, 0.17114700E+05, 0.14784400E+05, 0.17229900E+05, 0.89864300E+04, 0.45274200E+04, -.27598100E+04, -.93026000E+03, -.51155500E+04, -.41771300E+03, -.23914600E+03, 0.28006000E+04, 0.21281400E+02, 0.24824800E+04, -.83108800E+03, 0.31893500E+03, -.70595200E+03, 0.12736700E+04, 0.17747300E+02, -.12050200E+03, 0.65852100E+03, -.74922700E+03, -.11489700E+03, 0.13358100E+05, -.66711100E+04, -.76803900E+04, -.55809600E+04, -.12285800E+04, -.73870000E+04, -.60542500E+04, -.82985400E+04, -.63121200E+04, -.27646900E+05, 0.12975800E+05, 0.15292200E+05, -.84284100E+04, -.30129300E+03, 0.14952600E+05, 0.16749100E+05, 0.15635600E+05, 0.10476400E+05, 0.48621100E+03, 0.19738100E+03, -.22782900E+03, 0.12043400E+03, 0.95991800E+02, -.14194800E+03, -.21319500E+02, -.18187700E+03, 0.10174000E+03, -.12084500E+05, 0.60869700E+04, 0.48469100E+04, -.57702100E+04, -.53459900E+03, 0.64679500E+04, 0.90398700E+04, 0.56500100E+04, -.35146100E+04, 0.22634200E+04, -.11393800E+04, -.13756600E+03, -.11011500E+04, -.10779000E+04, -.13694800E+03, 0.75267900E+03, -.30161500E+03, -.15039800E+04, -.38424200E+04, 0.17806000E+04, 0.21887400E+04, -.75914800E+03, -.69882400E+03, 0.17677900E+04, 0.44868900E+03, 0.15077900E+04, 0.30331300E+04, 0.59442200E+03, -.12151900E+04, 0.13139200E+04, 0.27721000E+03, 0.14338300E+04, 0.82836300E+04, 0.15945700E+05, 0.13549300E+02, 0.47380500E+04, -.99373700E+03, -.53161100E+03, -.98236900E+04, 0.80517400E+03, -.74070300E+04, 0.27947100E+03, 0.42959500E+04, 0.16810500E+04, -.11611500E+04, 0.53376900E+03, 0.19375100E+04, 0.10739800E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.37307700E+00, -.72764700E+00, 0.44261900E+00, -.54209600E-01, -.41923300E+00, -.37373100E+00, 0.18566200E+00, 0.13059200E+01, -.36360400E-01, -.11322700E-01, -.26551000E+01, -.59146300E+00, -.21402900E+00, -.10690600E+00, 0.17933200E-02, 0.36361700E+00, 0.61002900E-01, 0.98264300E-01, 0.11623800E+00, 0.29920600E+00, -.12055600E+00, 0.14444500E-01, -.56130800E-02, 0.88264800E-01, 0.18073000E-01, 0.34464800E-01, -.62438000E-01, -.45589600E+00, -.22251200E+00, -.69275300E+03, 0.51873000E+03, 0.97257900E+03, -.82122000E+03, -.87224500E+03, -.43903200E+03, 0.26784100E+03, -.22540100E+04, 0.98800100E+03, -.42912200E+03, -.58876900E+03, 0.85927300E+03, -.35841900E+03, -.18660400E+04, 0.35072000E+03, -.54721900E+03, 0.23244400E+03, -.17704100E+03, -.12708500E+03, -.79617700E+02, -.73548900E+02, 0.18909900E+03, 0.56581100E+03, 0.29339400E+03, -.13404800E+03, -.11532100E+05, 0.57359400E+04, 0.59049700E+04, 0.34254400E+03, -.93544800E+03, 0.55352400E+04, 0.60964700E+04, 0.58731200E+04, 0.19613400E+04, 0.16877700E+04, -.81144400E+03, -.69122500E+03, 0.11158800E+04, 0.10697100E+03, -.81302000E+03, -.81486800E+03, -.13970800E+04, 0.81649400E+03, -.29903100E+04, 0.14702700E+04, 0.14952100E+04, 0.26358900E+03, 0.19435700E+04, 0.18013500E+04, 0.29395300E+04, 0.15995200E+04, 0.23295100E+04, -.13070100E+04, 0.62879600E+03, 0.22545500E+04, -.91356900E+03, -.13518600E+04, 0.20089400E+04, 0.23050700E+04, 0.18988900E+04, -.10505600E+04, 0.63889000E+04, -.32938800E+04, -.37586800E+04, 0.57869800E+00, 0.39744800E+02, -.38248300E+04, -.54853700E+04, -.35271800E+04, -.14933000E+04, -.24242300E+04, 0.12683300E+04, 0.12122900E+04, 0.16394300E+03, 0.16834000E+04, 0.14535500E+04, 0.22960400E+04, 0.13267800E+04, 0.18918500E+04, -.22319100E+04, 0.12945600E+04, 0.18729200E+04, -.38173300E+03, -.10609800E+03, 0.19086800E+04, 0.33868000E+04, 0.22146700E+04, 0.14504100E+03, -.30435000E+04, 0.15054500E+04, 0.88035300E+03, -.73752900E+02, -.45538700E+03, 0.66053600E+03, -.42260200E+02, 0.90129400E+03, 0.46465200E+02, 0.83063500E+04, -.41611600E+04, -.47133800E+04, -.10461000E+03, 0.24128900E+03, -.43622000E+04, -.53313100E+04, -.45542200E+04, -.10602100E+04, -.11792800E+05, 0.61252000E+04, 0.69057000E+04, -.68105600E+03, -.81614700E+03, 0.62564700E+04, 0.77237300E+04, 0.69183200E+04, 0.14276100E+04, 0.34739900E+02, 0.44157500E+02, -.70410800E+01, -.20061400E+02, -.23048000E+02, 0.19529000E+00, 0.33300300E+02, -.69568400E+02, -.16762700E+02, -.26907500E+04, 0.13075300E+04, 0.67716400E+03, -.84381700E+03, -.55085700E+03, 0.10283900E+04, 0.64011300E+03, 0.14671800E+04, -.88853900E+03, 0.80338600E+03, -.39998200E+03, 0.97625200E+02, -.53102000E+03, -.59307300E+03, -.12649800E+03, 0.81359500E+02, -.27916400E+02, -.61411000E+03, -.18058100E+04, 0.87762900E+03, 0.10498900E+04, 0.27362000E+03, -.12374400E+03, 0.86511800E+03, 0.92199800E+03, 0.37886100E+03, 0.52191400E+03, 0.17925100E+04, -.22333500E+04, 0.21996400E+04, 0.15648000E+04, 0.21763800E+04, 0.23667600E+04, 0.11954600E+04, 0.88468100E+03, 0.29836800E+04, 0.13005800E+03, -.17450700E+04, -.17677800E+04, -.27639900E+03, -.35697600E+03, -.23288900E+04, 0.10612700E+04, -.16766500E+03, -.22376700E+04, 0.24469300E+04, 0.24200400E+04, 0.21030200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.38481900E+01, -.52490700E+01, -.16091300E+01, -.10233000E+01, 0.10293400E+01, 0.11175600E+02, 0.11654700E+02, 0.60229200E+01, 0.76320000E+00, 0.57782100E+00, 0.52377100E+00, -.12076100E+01, -.24188800E+00, 0.26498500E+00, -.55472300E+00, -.10258800E+01, -.11895200E+00, 0.11877300E+01, -.19224700E+01, 0.28850300E+01, 0.88350900E-01, 0.22663100E+01, 0.18298400E+00, -.89868700E+00, -.11074500E+00, 0.17162400E+00, -.42244000E+00, 0.42315800E+00, 0.28253600E+00, 0.25594500E+01, 0.24729100E+04, 0.14856200E+04, -.96783300E+03, 0.31686400E+03, 0.13396500E+04, 0.51635200E+04, 0.40825600E+05, -.20314300E+05, -.19989400E+05, 0.28714200E+05, 0.27569600E+04, -.24542400E+05, -.31718800E+05, -.24979900E+05, 0.10767800E+05, -.39249700E+04, 0.18152400E+04, 0.18653000E+04, 0.79123800E+03, -.50989900E+03, 0.17114000E+04, 0.13468600E+04, 0.25578900E+04, -.75268700E+02, -.23645600E+05, 0.11803300E+05, 0.11611300E+05, -.15297900E+05, -.58236900E+04, 0.10038400E+05, 0.95565700E+04, 0.11920500E+05, -.12653700E+05, -.37347000E+05, 0.18381300E+05, 0.18577500E+05, -.10789200E+05, -.35740900E+03, 0.17493500E+05, 0.18114600E+05, 0.16468800E+05, -.43254800E+04, 0.57267000E+05, -.28958200E+05, -.28634400E+05, 0.90188300E+04, 0.12336100E+04, -.25708100E+05, -.20135300E+05, -.25667700E+05, -.79862200E+04, 0.19888100E+04, -.97846900E+03, -.12010900E+04, -.71331800E+03, -.22726100E+04, 0.24044800E+03, -.15884800E+04, -.23186600E+03, -.13150200E+04, 0.78017500E+04, -.37859800E+04, -.36585900E+04, 0.17204300E+05, 0.52840000E+04, -.54457200E+04, -.10976100E+05, -.66648200E+04, 0.91959000E+04, 0.49410100E+05, -.24784300E+05, -.24705100E+05, 0.78838600E+04, 0.11116100E+04, -.22343700E+05, -.17721800E+05, -.22462300E+05, -.61464700E+04, -.27184500E+04, 0.15589500E+04, 0.12646600E+04, 0.43255700E+04, -.21424100E+04, 0.70281100E+03, -.20131600E+04, 0.23817300E+04, -.31106400E+04, -.44123600E+03, 0.25618700E+03, 0.31123100E+03, -.18060400E+04, -.45797300E+03, -.50706000E+03, -.24075500E+04, -.31569900E+03, 0.11550700E+03, 0.12213500E+05, -.60147500E+04, -.57423400E+04, 0.11133400E+05, 0.44778200E+04, -.46251500E+04, -.58420500E+04, -.53365700E+04, 0.51016700E+04, 0.40783500E+04, -.22216200E+04, -.18955400E+04, 0.28684100E+04, -.74025300E+04, -.31970400E+04, -.83683000E+04, -.46726900E+03, -.12361900E+05, -.28145800E+04, 0.12787000E+04, 0.11529300E+04, -.60479200E+03, -.50669100E+03, 0.80869100E+03, -.36314900E+03, 0.47613600E+03, -.11392700E+03, 0.34394300E+05, -.17067900E+05, -.16933000E+05, 0.69639500E+04, 0.74726400E+03, -.15364600E+05, -.16317000E+05, -.14600700E+05, 0.36774600E+04, -.10835000E+04, 0.53189600E+03, 0.26857500E+02, 0.91316500E+02, -.11930000E+03, -.47997200E+03, -.47703700E+03, 0.14147300E+03, 0.58926000E+03, 0.15064200E+02, 0.20608300E+02, -.21995900E+02, -.32808100E+03, -.11990900E+04, -.59761600E+03, -.21786600E+04, -.19073900E+04, -.37745600E+04, 0.72925700E+04, -.66254300E+04, 0.69873200E+04, 0.66002300E+04, 0.74230400E+04, -.34596200E+04, -.11500100E+05, -.20539100E+04, 0.26400900E+04, -.88709800E+04, -.68057000E+04, 0.92368600E+04, 0.93940800E+04, 0.22587700E+04, -.77916700E+04, -.51252800E+04, 0.39545700E+04, -.67923900E+04, 0.67039100E+04, 0.72201300E+04, 0.73035400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17609300E+01, -.30907500E+01, 0.79333700E+00, -.20114200E-01, 0.14585400E+00, -.43667900E+00, 0.71044100E+00, 0.17435700E+01, -.29751800E-01, 0.66758700E-01, -.70729200E+00, -.46276200E+00, 0.29664600E+00, -.95240300E-01, 0.78345600E-01, -.85825600E-01, -.13510000E-01, -.22205200E+00, -.44536600E+00, -.57429700E-01, -.23032400E+00, 0.10094400E+00, 0.20083400E+00, -.82410600E+00, 0.68000500E+00, -.30590600E+00, 0.19004600E+00, 0.20607500E-02, -.27205500E+00, -.12985500E+01, -.83019300E-01, 0.94123100E+03, -.68205900E+03, -.69302000E+03, -.11921400E+04, 0.20710700E+03, -.22165800E+05, 0.11852300E+05, 0.12384500E+05, -.73596800E+04, 0.15221500E+04, 0.97994600E+04, 0.89694500E+04, 0.10698000E+05, 0.14867600E+04, -.39872900E+04, 0.19213500E+04, 0.20006900E+04, -.36603200E+03, -.98386800E+03, 0.21914900E+04, 0.24243000E+04, 0.28307800E+04, -.32471200E+03, -.37694300E+04, 0.17968000E+04, 0.17921400E+04, 0.53245600E+04, -.30602800E+04, 0.15258300E+04, -.70645200E+03, 0.10664500E+04, -.28446100E+03, 0.17516400E+04, -.81724400E+03, -.10128700E+04, 0.25122500E+04, -.72809300E+03, -.17765400E+04, -.34098600E+04, -.37080600E+03, 0.53076200E+03, -.10966000E+05, 0.72473500E+04, 0.54836000E+04, 0.12537600E+04, 0.19585800E+04, 0.58185300E+04, 0.73710800E+04, 0.53186700E+04, 0.29859700E+04, -.11008500E+04, 0.62399400E+03, -.74580600E+03, -.93843400E+03, -.18539100E+04, 0.15913900E+04, 0.11827000E+04, 0.12075500E+04, -.14610000E+04, -.12786900E+05, 0.69918800E+04, 0.65314900E+04, -.65482600E+04, 0.16995800E+04, 0.45419300E+04, 0.42347200E+04, 0.53633000E+04, 0.17812600E+04, -.99387500E+04, 0.64095500E+04, 0.49693500E+04, 0.76548700E+03, 0.17802800E+04, 0.51772200E+04, 0.63705700E+04, 0.49165700E+04, 0.25696800E+04, -.20259300E+05, 0.95270300E+04, 0.99776200E+04, -.98166000E+03, -.32904600E+04, 0.10010400E+05, 0.98152500E+04, 0.11030000E+05, -.41336600E+03, -.14692600E+04, 0.82566200E+03, 0.14203300E+04, -.21261500E+03, -.83402000E+03, 0.54405400E+03, 0.10782900E+04, 0.46460700E+03, -.55660700E+03, -.23743600E+03, 0.27740700E+03, 0.29382600E+03, -.44892200E+04, 0.14169500E+04, -.17346000E+03, 0.11121000E+04, 0.27939900E+02, 0.77093600E+03, -.29938800E+05, 0.14769900E+05, 0.15044100E+05, 0.67657200E+03, -.52396400E+04, 0.14713000E+05, 0.12435900E+05, 0.14656600E+05, -.36196400E+03, 0.46143500E+02, -.35622400E+03, 0.33223200E+02, -.29836800E+03, -.28883000E+03, 0.72139300E+01, -.16030000E+03, -.16782900E+03, -.20418200E+03, -.20562300E+04, 0.13220100E+04, 0.13563400E+04, -.22274100E+04, -.88464400E+03, 0.16637300E+04, 0.38824500E+04, 0.83302000E+03, -.14228900E+04, 0.22111600E+04, -.10942700E+04, -.12447800E+04, -.66588800E+03, -.10653500E+04, -.94838200E+01, 0.79642400E+03, -.26355500E+03, -.11599800E+04, -.21848100E+04, 0.11046100E+04, 0.10298100E+04, 0.17119600E+03, -.66550700E+03, 0.99358300E+03, 0.81243600E+03, 0.11033900E+04, 0.17927900E+03, -.15100500E+04, 0.13034900E+04, -.66087700E+03, -.15692500E+04, -.11859200E+04, 0.22727200E+04, -.64297500E+04, 0.21562600E+04, -.55512200E+03, 0.86975800E+04, 0.14885500E+04, -.37903000E+04, -.90100200E+04, 0.65342900E+04, 0.28032900E+04, 0.18478300E+04, -.55063600E+04, 0.11303800E+04, -.18902100E+04, -.48925900E+03, -.15314400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21939600E+01, -.54630800E+01, -.20464400E+00, -.12305300E+01, 0.13761200E+01, -.17803100E+00, 0.34162400E+01, 0.17619500E+01, 0.10353700E+00, -.69791300E-01, 0.54522000E+01, 0.39339100E+00, 0.35721200E+00, 0.11746600E+00, -.13420600E+00, 0.53013200E-01, -.58091000E-02, -.11237400E+01, -.21086900E+00, -.37806800E-01, 0.21464400E+00, -.64378700E+00, -.36101200E+00, -.86009600E+00, 0.52221700E+00, 0.33959000E+00, 0.29132700E+00, 0.57743600E+01, 0.41495200E+00, -.12698800E+01, -.25931600E+00, 0.77241800E+00, 0.12895800E+04, -.60476200E+03, 0.23209600E+04, 0.12876600E+04, 0.43091700E+05, -.21949400E+05, -.23331800E+05, 0.19276600E+05, 0.15206000E+04, -.20749100E+05, -.24348100E+05, -.22534300E+05, 0.22132500E+04, -.12793000E+04, 0.74157800E+03, 0.65111300E+03, 0.62069900E+03, 0.69207600E+03, 0.13384700E+03, 0.20683500E+03, -.16865500E+03, 0.67625600E+03, -.22350500E+05, 0.11200700E+05, 0.11470100E+05, -.10524900E+05, 0.13309800E+04, 0.10237600E+05, 0.13808700E+05, 0.10262900E+05, -.65237800E+03, -.78450300E+04, 0.38548000E+04, 0.41437900E+04, -.78342800E+04, 0.40877500E+02, 0.61594800E+04, 0.11248800E+05, 0.34489200E+04, -.32346000E+04, 0.12500900E+05, -.74535000E+04, -.62506600E+04, 0.10342100E+04, -.33983900E+04, -.60130700E+04, -.56835700E+04, -.53040900E+04, -.33149500E+04, -.32065800E+04, 0.15618200E+04, 0.33628900E+04, 0.15999100E+04, 0.11999300E+04, 0.24924000E+02, 0.27905700E+04, 0.32529700E+04, 0.20857700E+04, 0.26213000E+05, -.13419300E+05, -.13491600E+05, 0.13527100E+05, 0.20644300E+04, -.11614600E+05, -.15890600E+05, -.13058400E+05, -.74632600E+03, 0.11672200E+05, -.69127200E+04, -.58359900E+04, 0.12068700E+04, -.32157500E+04, -.56358100E+04, -.54553800E+04, -.53867300E+04, -.24379300E+04, 0.33505800E+04, -.14251900E+04, -.14683000E+04, 0.24247300E+04, 0.21833300E+04, -.29030100E+04, -.27992900E+04, -.38005400E+04, 0.16502100E+04, 0.20962400E+03, -.15938300E+03, -.80458900E+03, -.89950400E+03, -.87733400E+03, 0.33234600E+03, -.24744300E+04, 0.16584600E+04, -.70504600E+03, 0.19224800E+05, -.96729800E+04, -.10182500E+05, 0.91874200E+04, 0.63211300E+03, -.88430300E+04, -.12739500E+05, -.94562600E+04, -.15673000E+04, 0.81671500E+04, -.41530500E+04, -.41561300E+04, 0.89910800E+03, 0.30618600E+04, -.55652800E+04, -.27581900E+04, -.49540100E+04, 0.46256600E+03, -.21467800E+04, 0.12536300E+04, 0.86878500E+03, 0.40328300E+03, 0.38408700E+03, 0.54968700E+03, 0.98748500E+02, 0.74547600E+03, 0.48370500E+03, 0.54838800E+04, -.29087000E+04, -.35721900E+04, 0.56784800E+04, -.99582400E+02, -.44327400E+04, -.11236400E+05, -.99454800E+03, 0.29237300E+04, -.49280500E+02, 0.21712700E+02, 0.36753600E+03, 0.65962300E+03, 0.24716300E+03, -.71174400E+03, -.35683900E+03, 0.28022100E+03, 0.33738800E+03, 0.88945500E+03, -.43968400E+03, -.31650700E+03, 0.97380700E+02, 0.18890200E+02, -.49296700E+03, 0.30319700E+03, -.56797900E+03, -.81188000E+03, 0.79961000E+04, -.93968500E+04, 0.79227100E+04, 0.73742200E+04, 0.84694300E+04, -.27902500E+03, 0.36921300E+04, -.12976600E+04, 0.56791800E+04, -.13107700E+05, -.69357700E+04, 0.47708800E+04, 0.13232300E+05, -.62260100E+04, -.11266400E+05, -.17019400E+04, 0.66883400E+04, -.92270400E+04, 0.94448400E+04, 0.71833900E+04, 0.94187700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20583300E+01, 0.43709700E-01, 0.16835000E+01, 0.43767900E+01, -.16559900E+01, -.17713900E+02, 0.29043300E+01, 0.10529500E+01, -.95089300E+00, 0.11414300E+01, -.35248100E+01, -.57879600E+01, 0.34554700E+00, 0.32293400E+00, -.36943700E+00, 0.31357600E+01, 0.56738000E+00, 0.10157600E+01, -.98992800E+00, 0.13554900E+01, 0.11111900E+01, -.18929100E+00, -.57437400E+00, 0.24160400E+01, -.84694000E+00, 0.15172100E+01, -.39988600E+00, 0.65920800E+01, 0.10309200E+01, 0.26696800E+01, 0.12480300E+01, -.41506400E+01, -.18384400E+01, 0.75933000E+04, -.73690000E+04, 0.14106600E+05, 0.19116800E+06, -.92356200E+05, -.95624000E+05, 0.86810200E+05, 0.37634500E+03, -.88821000E+05, -.98433400E+05, -.90986400E+05, 0.10978900E+05, 0.42786300E+04, -.15801800E+04, -.21923000E+04, 0.39095500E+04, 0.28732800E+04, -.32787300E+04, -.19324800E+04, -.12145300E+04, 0.92701800E+03, -.84995900E+04, 0.37986400E+04, 0.54155400E+04, -.47399100E+05, 0.73029900E+03, 0.52076700E+04, 0.24750700E+05, 0.29369300E+04, -.29477800E+05, -.49367400E+05, 0.24939200E+05, 0.24527100E+05, -.38923200E+05, -.67589800E+04, 0.35716300E+05, 0.42499500E+05, 0.38224300E+05, -.17799000E+05, 0.15491300E+06, -.71142300E+05, -.77453400E+05, 0.17285600E+05, 0.86315600E+04, -.76111300E+05, -.65974700E+05, -.79067500E+05, -.24371000E+05, 0.14987000E+05, -.72417200E+04, -.77998500E+04, 0.96440800E+04, 0.97051800E+04, -.16070400E+05, -.13787800E+05, -.10067400E+05, 0.65604800E+04, 0.50089600E+05, -.22718200E+05, -.25768300E+05, 0.59941200E+05, 0.13389500E+04, -.23718800E+05, -.38440500E+05, -.23985200E+05, 0.15607800E+05, 0.13647700E+06, -.64311600E+05, -.68238200E+05, 0.13944500E+05, 0.32161900E+04, -.65574500E+05, -.61970200E+05, -.67205000E+05, -.22564100E+05, 0.45058700E+05, -.25789400E+05, -.23053600E+05, 0.17238800E+05, 0.13520300E+05, -.29789700E+05, -.31108700E+05, -.37085200E+05, -.28128600E+04, -.32878000E+05, 0.16726100E+05, 0.18166400E+05, -.59150400E+04, -.84878000E+04, 0.15580500E+05, 0.17906700E+05, 0.16990600E+05, -.29403200E+04, -.25739000E+04, 0.19750800E+04, -.75495400E+03, 0.42533000E+05, 0.31893900E+04, -.11186100E+04, -.16157400E+05, -.11532500E+04, 0.12277800E+05, 0.10212100E+06, -.52663700E+05, -.51163500E+05, 0.15684400E+05, 0.18951800E+05, -.59284600E+05, -.49796200E+05, -.70279200E+05, -.22297500E+05, 0.62906800E+04, -.44874300E+04, -.39753200E+04, -.54862100E+03, -.10014100E+04, -.17451000E+04, -.37173300E+03, -.27626000E+04, -.14562500E+04, -.28197200E+03, 0.13521200E+04, -.20280900E+04, 0.25894500E+05, -.18060600E+02, -.12199000E+05, -.16230100E+05, -.13751400E+05, 0.15338200E+05, -.14740800E+05, 0.73959600E+04, 0.83075900E+04, 0.54619300E+04, 0.25562700E+04, 0.30306800E+04, -.79817500E+04, 0.68749500E+04, 0.33912000E+04, 0.38071800E+05, -.18906000E+05, -.18920800E+05, -.33356600E+03, 0.73168600E+03, -.13337000E+05, 0.14001900E+04, -.15971900E+05, -.12308100E+05, 0.13096400E+05, -.14057600E+05, 0.11614100E+05, 0.14815000E+05, 0.94346400E+04, -.21211200E+05, -.11943800E+05, -.75213700E+04, -.13013500E+05, -.48573200E+05, -.13927100E+05, 0.39272200E+05, 0.50469700E+05, -.15934600E+05, -.12204200E+05, -.20059700E+05, 0.24748300E+05, -.14425800E+05, 0.76839100E+04, 0.11829800E+05, 0.15692300E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.61506600E+00, 0.68825100E+00, 0.25162900E+00, 0.14183300E+01, -.13714400E+00, -.52551900E+01, 0.17454400E+01, 0.32961400E+00, -.28087300E+00, 0.48601800E+00, 0.57050700E+00, -.19371600E+00, 0.25413700E+00, 0.19448600E+00, -.22087500E+00, 0.38675300E-01, -.60025300E-01, 0.30116800E+00, 0.29359900E+00, 0.15097500E-01, -.99044700E-01, -.11963200E+00, 0.22841000E+00, 0.58586400E+00, 0.37477600E+00, -.45414900E-01, 0.10709600E-01, -.44661800E+01, 0.91224100E-01, 0.65243400E+00, 0.20165600E+00, -.71098700E+00, 0.73059000E-01, 0.16564000E+00, -.26126300E+04, 0.63887400E+03, -.18505300E+05, 0.97463800E+04, 0.10552100E+05, -.77501000E+04, 0.71545000E+03, 0.87507300E+04, 0.86544200E+04, 0.71766800E+04, -.85971700E+03, 0.37343500E+04, -.20404500E+04, -.18074100E+04, -.25321100E+03, -.20391700E+03, -.15795000E+04, -.14379600E+04, -.10856400E+04, -.66198400E+03, 0.98590400E+04, -.49423100E+04, -.53509200E+04, 0.26488000E+04, -.23341100E+04, -.42097000E+04, -.67741700E+04, -.42209200E+04, -.17476600E+04, 0.18959600E+04, -.89782500E+03, -.99334000E+03, 0.33757700E+04, -.12245600E+04, -.14033900E+04, -.41232800E+04, 0.61940900E+03, 0.10167400E+04, 0.10464200E+05, -.39926200E+04, -.52318400E+04, -.20081200E+03, 0.52402600E+04, -.46812300E+04, -.43181200E+04, -.51328200E+04, -.71077000E+03, 0.41419600E+04, -.20096100E+04, -.33844700E+04, -.58440100E+03, -.11068600E+04, -.19010900E+04, -.24758400E+04, -.12466500E+04, -.13947800E+04, -.10889500E+05, 0.58270000E+04, 0.56740800E+04, -.26620000E+04, 0.19446600E+03, 0.40962000E+04, 0.47640400E+04, 0.30414500E+04, 0.26766700E+04, 0.88329300E+04, -.31214600E+04, -.44164600E+04, -.19043900E+03, 0.50030500E+04, -.39624300E+04, -.34330500E+04, -.41392800E+04, -.74959200E+03, 0.10176100E+05, -.51232200E+04, -.49520500E+04, -.25741200E+04, -.18315100E+04, -.31522200E+04, -.22289500E+04, -.20233400E+04, -.41230700E+04, -.17872300E+04, 0.94941000E+03, 0.11418400E+04, 0.15342600E+03, -.45105400E+02, 0.92514600E+03, 0.20779400E+04, -.11748400E+04, 0.12437200E+03, -.12385500E+05, 0.62531100E+04, 0.68887200E+04, -.20463800E+04, 0.11289100E+04, 0.51461700E+04, 0.67892300E+04, 0.48095400E+04, 0.23920200E+04, 0.62413300E+04, -.28914700E+04, -.29288400E+04, -.38754600E+04, -.32231500E+04, -.10385100E+04, -.20134100E+04, -.34674800E+03, -.56627900E+04, 0.85358600E+03, -.59240700E+03, -.10170300E+03, -.33930100E+03, -.36476700E+03, -.17288100E+03, -.92320300E+02, -.67457200E+03, -.37108000E+03, -.10768200E+04, 0.69536100E+03, 0.14335100E+04, -.25230500E+04, 0.65517700E+03, 0.10805900E+04, 0.50454900E+04, -.20845300E+04, -.14611300E+04, 0.18026600E+04, -.89055900E+03, -.11886500E+04, -.57202200E+03, -.44945500E+03, -.43316000E+02, 0.10531800E+04, 0.92881600E+03, -.60314800E+03, -.79682500E+03, 0.39448700E+03, 0.32840400E+03, -.31726100E+03, -.67902900E+03, 0.50966700E+03, -.66730000E+03, -.33807800E+03, -.13637700E+04, -.46871100E+04, 0.46700900E+04, -.35884300E+04, -.37900400E+04, -.39251600E+04, -.44687800E+03, 0.77935100E+03, 0.74654500E+02, -.35519200E+04, 0.30739600E+04, 0.36234700E+04, -.93838500E+03, -.25822400E+04, 0.67516300E+03, 0.66909100E+04, -.29754300E+02, -.16831600E+04, 0.44845200E+04, -.53953200E+04, -.34707600E+04, -.45049400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14395600E+01, 0.39600300E-01, -.99627300E+00, -.10284500E+01, 0.10617400E+01, 0.65281100E+01, 0.80230400E+01, 0.25740200E+01, 0.47100000E+00, 0.35489300E+00, -.48129800E+00, -.97833700E-02, -.35437600E+00, -.79298200E-01, 0.12295500E+00, -.10377400E+01, -.93767000E-01, -.75892600E-01, -.17021300E+00, 0.18123200E+00, 0.31702500E+00, -.45855900E+00, 0.17296300E+00, -.39190100E+00, -.49249300E+00, -.68842700E-01, 0.27226600E+00, 0.27956400E+01, -.35642400E+00, 0.13455400E+01, 0.15985600E+00, -.57168000E-01, 0.19101400E+00, 0.98413100E-01, -.28523400E+00, -.46520400E+04, -.38510600E+05, 0.19449200E+05, 0.19549900E+05, -.22709800E+05, -.61191800E+03, 0.18559100E+05, 0.23863800E+05, 0.19773600E+05, -.66621900E+04, 0.28527900E+04, -.13505600E+04, -.14037600E+04, -.10619700E+04, -.36402800E+03, -.91903900E+03, -.10317700E+04, -.16023600E+04, -.16478900E+03, 0.15029500E+04, -.72337300E+03, -.99570200E+03, 0.99602100E+04, 0.34583000E+03, 0.87084500E+03, -.25376800E+04, 0.50243200E+03, 0.10991500E+05, 0.18748000E+05, -.93036600E+04, -.93951800E+04, 0.10368300E+05, 0.13621700E+04, -.11313400E+05, -.13609100E+05, -.10262600E+05, 0.52742100E+04, -.53034400E+05, 0.26861400E+05, 0.26517300E+05, -.81208800E+04, 0.52881300E+03, 0.26100500E+05, 0.23846100E+05, 0.26118100E+05, 0.10143400E+05, -.19378500E+04, 0.10196000E+04, 0.51009600E+03, -.25529800E+04, -.17175200E+04, 0.30787000E+04, 0.15096200E+04, 0.11685300E+04, -.14347100E+04, -.26344600E+04, 0.14857900E+04, 0.14203100E+04, -.12650900E+05, -.17549200E+04, 0.17515900E+03, 0.54815000E+04, 0.11367200E+04, -.82565800E+04, -.47522000E+05, 0.23946300E+05, 0.23761000E+05, -.67686600E+04, 0.11137800E+04, 0.22814800E+05, 0.21713200E+05, 0.22989600E+05, 0.91678000E+04, -.50530600E+04, 0.21783800E+04, 0.26808500E+04, -.60267400E+04, -.25558100E+04, 0.46365600E+04, 0.57517300E+04, 0.47724200E+04, 0.20760300E+04, 0.19108300E+04, -.94362300E+03, -.10038500E+04, 0.16233200E+04, 0.71501800E+03, -.97939700E+03, -.45220200E+02, -.15028300E+04, 0.10222600E+03, 0.24564200E+04, -.12275500E+04, -.84660800E+03, -.80562700E+04, -.17260000E+04, -.25470300E+04, 0.67803300E+03, -.24015000E+04, -.55009100E+04, -.24532500E+05, 0.12001900E+05, 0.12346800E+05, -.76942300E+04, -.26023900E+04, 0.15440200E+05, 0.14970800E+05, 0.15214400E+05, 0.94896200E+04, 0.11682400E+04, -.64200500E+03, -.37883600E+03, -.28275100E+02, -.11210600E+03, -.33143400E+03, -.10254500E+03, -.54701500E+02, -.55744900E+02, -.11580100E+05, 0.58104400E+04, 0.62792200E+04, -.69177600E+04, -.11406500E+04, 0.75701500E+04, 0.10358700E+05, 0.63463800E+04, -.48939800E+04, 0.13400000E+04, -.66488100E+03, -.75245600E+03, -.91586600E+03, -.43581800E+03, 0.64813900E+02, 0.56772300E+03, -.82168200E+03, -.79492000E+03, -.43052200E+03, 0.23684800E+03, 0.18477700E+03, -.80252100E+03, -.49117300E+03, 0.58052600E+03, -.86545400E+03, 0.13644800E+04, 0.33658000E+04, -.26997700E+04, 0.30505200E+04, -.27157100E+04, -.26981600E+04, -.24009000E+04, 0.59859600E+04, 0.11855600E+05, -.24946100E+03, 0.23199700E+04, 0.49303500E+04, 0.24498800E+04, -.10477600E+05, -.50259400E+04, -.32464400E+04, 0.38778800E+04, 0.45346300E+04, -.16462200E+04, 0.29905600E+04, -.25127000E+04, -.22899200E+04, -.29345100E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10793900E+01, -.40936400E+01, 0.68588300E+00, -.14326700E+01, 0.72534600E+00, 0.69847300E+01, 0.29566400E+00, 0.49654800E-01, 0.40912200E+00, -.60107100E+00, 0.11408900E+01, 0.35240500E+00, -.16349200E+00, 0.48991700E+00, -.37074700E+00, 0.61855900E+00, -.19314400E+00, -.75557600E+00, 0.69682700E+00, 0.13481600E+00, -.15093700E+00, -.56345100E+00, -.13585300E+00, -.81134600E+00, -.21877300E+00, -.42664100E+00, -.35245400E+00, 0.85573800E+01, -.42000800E+00, -.10866700E+01, -.44989500E+00, 0.27018500E+00, 0.84990800E+00, -.20809000E-01, -.53807100E+00, 0.61331800E+00, -.63854700E+05, 0.32402600E+05, 0.33736100E+05, -.16867000E+05, 0.11352900E+04, 0.30312500E+05, 0.31261600E+05, 0.31616600E+05, 0.79289000E+04, -.65620400E+04, 0.30975100E+04, 0.33790700E+04, -.11876000E+04, -.20366100E+04, 0.37941900E+04, 0.38382600E+04, 0.53721500E+04, -.81197600E+03, 0.34600200E+05, -.17286100E+05, -.17505900E+05, 0.14860900E+05, -.33280200E+04, -.17608600E+05, -.23681500E+05, -.17204000E+05, -.65378300E+04, 0.22370600E+04, -.11773000E+04, -.12205600E+04, 0.54150700E+04, 0.66700300E+03, -.41049100E+04, -.85556200E+04, -.25000200E+04, -.38915500E+03, 0.68251900E+04, -.22681600E+04, -.34114500E+04, 0.45434100E+04, 0.33246800E+03, -.32140000E+04, -.35052800E+04, -.34429500E+04, 0.91125900E+03, -.48421000E+03, 0.30455800E+03, -.15236300E+04, -.79258600E+03, -.26371200E+04, 0.11571700E+04, -.35908200E+03, -.52287700E+03, -.20200600E+04, -.63042400E+05, 0.31894700E+05, 0.31727000E+05, -.18493600E+05, 0.25564500E+04, 0.29454900E+05, 0.32715400E+05, 0.30570200E+05, 0.75513300E+04, 0.54689500E+04, -.16893700E+04, -.27345100E+04, 0.36419100E+04, 0.67846100E+03, -.26306900E+04, -.23760800E+04, -.27485200E+04, 0.14476600E+04, -.16300800E+05, 0.78335800E+04, 0.79709000E+04, -.22634600E+04, -.65347800E+04, 0.98680900E+04, 0.10497600E+05, 0.15186200E+05, -.28781400E+04, 0.59359500E+04, -.28823100E+04, -.21924700E+04, 0.17794200E+03, 0.12667300E+04, -.25732700E+04, -.10381200E+04, -.37012200E+04, 0.42596400E+03, -.32768300E+05, 0.16458900E+05, 0.16722100E+05, -.14416300E+05, 0.16233500E+04, 0.17018400E+05, 0.22708600E+05, 0.17518000E+05, 0.45207000E+04, -.56114900E+04, 0.26567300E+04, 0.27600300E+04, 0.37334300E+04, -.82350400E+04, 0.43972000E+04, 0.55601600E+03, 0.84466500E+04, -.54719300E+04, -.11292300E+04, 0.29436800E+03, 0.86314600E+03, -.40933000E+03, -.18241600E+03, 0.34656900E+03, -.15813900E+03, -.29981800E+02, -.54440000E+02, 0.52715500E+04, -.24172400E+04, -.20137800E+04, -.45735500E+04, -.33934000E+03, 0.23836700E+03, 0.55947800E+04, -.12911500E+04, 0.27648900E+03, 0.42108600E+04, -.20982100E+04, -.21846800E+04, -.17960100E+04, -.11501800E+04, -.27010200E+01, 0.25883700E+04, -.14809000E+04, -.12120300E+04, -.87084000E+04, 0.43703900E+04, 0.42669500E+04, 0.65041400E+03, -.37501600E+03, 0.22033300E+04, -.15532700E+04, 0.22958400E+04, 0.52756700E+03, -.11352700E+05, 0.12636800E+05, -.10147100E+05, -.10927300E+05, -.10409700E+05, -.25759300E+04, -.15173600E+05, 0.45850700E+04, -.10009900E+05, 0.25573900E+05, 0.10675400E+05, -.39761800E+04, -.26415300E+05, 0.17717000E+05, 0.13769700E+05, 0.28791800E+04, -.14907200E+05, 0.12408600E+05, -.12324600E+05, -.99050500E+04, -.12625600E+05, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20162200E+01, 0.30853000E+01, -.95578300E+00, -.47536800E+00, 0.60661700E+00, 0.38582700E+01, 0.51418600E+01, 0.43159300E+01, 0.15472200E+00, 0.37239000E+00, -.12119600E+01, -.10268100E+01, -.36698900E-02, 0.96800800E-01, -.38269200E-02, -.69485500E+00, -.12893400E+00, 0.76227200E+00, -.13126200E+01, 0.93741500E-01, -.28209600E-01, 0.74093600E+00, 0.31010800E+00, -.67265500E+00, 0.19865500E+00, 0.38870000E-01, -.26494800E+00, 0.77413400E+01, -.74944000E-01, 0.14854100E+01, 0.54386900E-01, -.27782900E+00, -.32121100E+00, -.21050800E-01, -.24473800E-01, -.37262300E+00, 0.34092600E-02, 0.14464800E+04, 0.49093900E+03, 0.15521300E+04, 0.60606800E+02, 0.43177100E+03, 0.12105100E+04, 0.11619000E+04, 0.31617200E+04, -.46721600E+04, 0.27771600E+04, 0.23639400E+04, 0.45562000E+02, -.27905400E+02, 0.19931300E+04, 0.16648600E+04, 0.17931000E+04, 0.58311800E+03, 0.35733800E+04, -.18467300E+04, -.19473500E+04, 0.77806900E+03, 0.45386000E+03, -.94760800E+03, 0.21796000E+03, -.11976800E+04, -.18034200E+04, 0.11660100E+04, -.55682500E+03, -.60882700E+03, -.12144100E+04, 0.12174500E+04, -.56186000E+03, 0.64520600E+03, -.56825400E+03, -.14506100E+04, -.50939400E+04, 0.45704200E+04, 0.25478000E+04, 0.11520200E+04, -.25127000E+04, 0.27075300E+04, 0.37247000E+04, 0.26959400E+04, 0.82251700E+03, -.13734700E+04, 0.88157200E+03, -.21692100E+02, 0.58597600E+03, 0.69298900E+03, 0.48756300E+03, 0.77784700E+03, 0.29732000E+03, 0.83435800E+03, -.77106600E+04, 0.49630400E+04, 0.38190300E+04, -.18006100E+04, 0.10935100E+04, 0.36916000E+04, 0.40612300E+04, 0.44474800E+04, 0.47825000E+03, -.53628100E+04, 0.36163100E+04, 0.26815400E+04, 0.84481400E+03, -.29095500E+04, 0.26356400E+04, 0.30186200E+04, 0.26430500E+04, 0.10160800E+04, -.12188700E+05, 0.42369600E+04, 0.62528200E+04, -.37487200E+03, -.21315200E+04, 0.55872100E+04, 0.46496000E+04, 0.56769400E+04, 0.10695900E+04, -.37291600E+02, 0.15930300E+03, 0.31696200E+03, -.19963800E+03, -.24450000E+03, -.20847400E+02, -.51797300E+03, 0.10389700E+04, -.20623900E+03, -.16112300E+04, 0.10609100E+04, 0.97180300E+03, -.15199800E+04, 0.19529700E+02, 0.56787600E+03, 0.18817100E+03, 0.67157700E+03, -.71083700E+02, -.52133700E+04, 0.10630600E+04, 0.27707800E+04, 0.79737400E+03, -.14807000E+04, 0.30277500E+04, 0.33763800E+04, 0.29284400E+04, 0.51297500E+03, -.65916500E+03, -.29069100E+03, 0.36289500E+03, -.81507000E+02, -.15175100E+03, 0.19064000E+03, -.15404100E+03, 0.30745100E+03, 0.15637000E+01, -.19226600E+04, 0.14608300E+04, 0.11894300E+04, 0.54205500E+03, -.12366500E+04, 0.51384300E+03, -.12653400E+04, 0.14673100E+04, 0.16620800E+04, -.44094400E+02, 0.39811100E+02, -.89942300E+01, 0.11114500E+03, -.49260600E+02, 0.99172500E+02, -.36878100E+03, -.32102600E+03, 0.34108700E+02, 0.26135600E+04, -.11962000E+04, -.12989600E+04, 0.56403500E+02, 0.19335200E+03, -.87098400E+03, 0.31802100E+03, 0.89223800E+02, 0.26710300E+03, 0.37347100E+03, -.50212400E+03, 0.24677700E+03, 0.30533700E+03, 0.48685800E+02, -.21198400E+03, -.34928200E+04, 0.12799500E+04, -.58759600E+03, 0.15822700E+04, -.12708900E+03, -.21211200E+03, -.17775000E+04, 0.28302200E+04, -.80740600E+03, 0.32214700E+03, -.20465400E+04, -.65140000E+03, 0.61097000E+03, -.18282700E+03, 0.45193400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18912100E+01, -.37088400E+01, -.39379800E+00, -.16561500E+01, 0.18786500E+01, 0.87388000E+00, 0.34186700E+01, -.13867400E+01, 0.11733300E+00, 0.16308900E+00, 0.26089600E+01, -.96099900E-02, 0.48467800E+00, 0.77866500E-01, -.13152600E+00, -.29313300E-01, 0.10098900E-01, -.36476700E-01, 0.37598100E-01, 0.15687300E+00, -.58112500E-01, -.81706700E-02, 0.16791200E+00, 0.17915400E+00, -.47296100E+00, 0.66475400E-01, 0.24058000E+00, 0.55899300E+01, -.27838300E+00, 0.73958900E+00, 0.30807600E-01, 0.71879100E+00, 0.64258400E+00, -.19509500E-01, 0.37040800E+00, 0.62087500E+00, -.10543800E+00, -.24868900E+00, -.71330500E+03, -.22904500E+04, -.16223200E+04, 0.14697100E+04, 0.20252800E+04, 0.18358400E+04, 0.25663000E+04, -.12437300E+04, 0.84309000E+03, 0.62273900E+03, 0.21084600E+03, 0.29025100E+03, 0.52180700E+03, 0.77832500E+03, 0.58037000E+03, 0.46549800E+03, 0.38140300E+04, -.18650100E+04, -.17266000E+04, 0.20480800E+04, 0.19568100E+04, -.24756400E+04, -.10196300E+04, -.25079400E+04, -.11641000E+04, 0.33224000E+04, -.17546900E+04, -.16314100E+04, -.42777700E+03, 0.44619800E+02, -.93229100E+03, -.49926600E+03, -.12223300E+04, -.26700500E+04, -.29803500E+04, 0.98117000E+03, 0.14906500E+04, -.28267500E+03, -.28841600E+04, 0.34253800E+03, -.62167800E+03, 0.54141300E+03, 0.81771200E+03, -.24222400E+04, 0.12334800E+04, 0.17007100E+04, 0.93591600E+03, 0.15748800E+04, 0.19225200E+03, 0.11598700E+04, 0.68425200E+03, 0.15124500E+04, -.66537500E+04, 0.33310600E+04, 0.31269900E+04, -.41524000E+04, -.10319300E+04, 0.46439500E+04, 0.46971200E+04, 0.48960100E+04, -.71817000E+03, -.98063900E+03, -.39569600E+03, 0.49041500E+03, -.26031100E+03, -.32875000E+04, -.22136500E+03, -.16097400E+04, -.11947300E+03, 0.75584000E+03, -.22407100E+04, 0.62677600E+03, 0.11776300E+04, 0.15678900E+04, 0.11369400E+04, -.10989000E+03, -.85570900E+02, -.72397500E+03, 0.25635100E+04, 0.12173700E+04, -.60869000E+03, -.68424900E+03, 0.15121900E+03, 0.19177100E+03, -.45267600E+03, -.15642300E+02, 0.17311800E+03, 0.17663800E+02, -.39784900E+04, 0.19923100E+04, 0.16393600E+04, -.30469800E+04, -.12116600E+04, 0.26236900E+04, 0.21190800E+04, 0.24607000E+04, -.36511500E+03, -.10665500E+04, -.18737700E+03, 0.44488900E+03, 0.27628700E+04, 0.21855400E+04, -.15148000E+04, -.56676600E+03, -.19220500E+04, 0.28982900E+04, -.71444000E+03, 0.27111200E+03, 0.27565800E+03, 0.10492400E+03, 0.13357000E+03, 0.20157600E+03, 0.12043900E+02, 0.23958200E+03, 0.15948700E+03, -.28911700E+04, 0.14591700E+04, 0.10462900E+04, 0.68076500E+03, -.52416500E+02, 0.55615100E+03, -.22598300E+02, 0.11862300E+04, 0.28606900E+04, -.79010800E+03, 0.39271900E+03, 0.68196800E+03, 0.40063700E+03, 0.24990500E+03, 0.26956100E+03, -.34631100E+03, -.20459000E+03, 0.25885500E+03, -.71386800E+03, 0.41153800E+03, 0.40050200E+03, 0.71538600E+02, 0.62957000E+03, -.34351800E+01, 0.89104800E+03, 0.55809700E+03, 0.95397800E+03, -.56677000E+03, 0.47552800E+03, -.77195600E+03, -.63884500E+03, -.91564500E+03, -.13599700E+03, -.30139500E+04, 0.13874800E+04, -.19304300E+04, 0.17841300E+04, 0.84771600E+03, 0.91739700E+02, -.23039600E+04, 0.21342100E+04, 0.36648500E+03, 0.13422400E+03, -.14718600E+04, 0.49766500E+03, -.10022400E+04, -.90321600E+03, -.76379000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.23095300E+00, -.28789900E+01, 0.21554100E+00, -.14028600E+00, -.17895700E+00, 0.13782100E+01, 0.36300600E+01, -.12173400E+01, 0.14915400E+00, 0.91314300E-01, -.68112000E+00, 0.34530500E-01, 0.18735600E+00, 0.33712000E+00, -.42676100E+00, 0.12552500E+00, 0.11382500E-01, 0.24001600E+00, 0.62480800E+00, -.17073900E-01, 0.16791100E-01, -.21505800E+00, 0.77675500E-01, 0.61717200E+00, -.30409400E+00, 0.24892600E-01, -.69682800E-01, 0.37092600E+01, 0.13516100E+00, -.40823900E-01, -.35142600E-01, 0.30194900E+00, 0.30261300E+00, 0.10428600E+00, -.28316100E+00, 0.42724400E+00, 0.27972000E+00, -.49587200E+00, -.11298200E+00, 0.27998900E+04, -.34375700E+03, 0.18677800E+03, 0.42617900E+03, -.53007300E+03, 0.26149300E+04, -.33265600E+04, 0.18039000E+04, 0.16544100E+04, 0.22672900E+03, 0.11442200E+03, 0.13405300E+04, 0.91467000E+03, 0.10042100E+04, 0.39918900E+03, 0.71595000E+04, -.35267500E+04, -.37575700E+04, 0.41410400E+03, 0.50322200E+03, -.32312200E+04, -.26553700E+04, -.30155000E+04, -.23487300E+04, -.14890000E+04, 0.67393100E+03, 0.76149600E+03, -.16515800E+04, 0.63677500E+03, 0.72811100E+03, 0.90780000E+03, 0.39432000E+03, -.11055300E+04, 0.72100500E+04, -.41555300E+04, -.36054400E+04, 0.30277000E+04, -.13003600E+04, -.37845300E+04, -.41465300E+04, -.36987300E+04, -.61800300E+02, -.81092100E+03, 0.42946100E+03, 0.43098000E+03, 0.57922900E+03, 0.52797800E+03, 0.22608400E+03, 0.44476100E+03, 0.18118700E+03, 0.46824300E+03, -.90320200E+04, 0.45183300E+04, 0.45944600E+04, -.13723400E+04, 0.69375900E+02, 0.50706200E+04, 0.54899400E+04, 0.44258300E+04, 0.94472000E+03, 0.62399400E+04, -.36997600E+04, -.31166400E+04, 0.25683100E+04, -.13591200E+04, -.32107500E+04, -.35632400E+04, -.31905800E+04, 0.30789400E+02, -.41757600E+04, 0.20054300E+04, 0.22083600E+04, 0.12410600E+04, -.61458900E+03, 0.18999100E+04, 0.91097600E+03, 0.16588700E+04, 0.40319400E+03, 0.15027600E+04, -.75325100E+03, -.96029000E+03, -.12215600E+03, 0.52030900E+03, -.85784800E+03, -.10615500E+04, -.93864500E+03, 0.37750200E+03, -.47956100E+04, 0.23826400E+04, 0.26917900E+04, -.12476500E+04, -.21286100E+02, 0.25276900E+04, 0.23929600E+04, 0.24289900E+04, 0.10371200E+04, 0.59326300E+04, -.33018300E+04, -.28682800E+04, 0.29245600E+04, -.45140500E+03, -.28685400E+04, -.31792600E+04, -.26070200E+04, -.51264100E+03, -.18888100E+02, 0.50848900E+01, 0.55883600E+02, 0.25763000E+02, 0.49337600E+02, 0.25537600E+02, 0.51244600E+02, 0.33906100E+02, 0.43369600E+02, 0.14084000E+04, -.71326700E+03, -.42573200E+03, 0.98663000E+03, -.19685200E+03, -.84362700E+03, -.15915200E+04, -.80810800E+03, 0.15072600E+04, -.30748700E+03, 0.15251000E+03, -.24205000E+02, 0.74805700E+02, 0.23624100E+03, -.87965700E+02, -.12731800E+03, 0.25378400E+03, 0.36879500E+03, -.60620100E+03, 0.33069900E+03, 0.29869700E+03, 0.31695200E+03, 0.65700800E+02, 0.28643500E+03, 0.30281200E+03, 0.22775600E+03, 0.19214400E+03, -.50725500E+03, 0.55554400E+03, -.55493300E+03, -.42473100E+03, -.43182400E+03, -.15112100E+04, -.54924500E+04, 0.70246800E+03, -.16572900E+04, 0.45083200E+04, 0.52221900E+03, 0.86964800E+03, -.51791100E+04, 0.40937800E+04, 0.36626400E+03, -.32834800E+03, -.21578800E+04, 0.56391100E+03, -.57072800E+03, -.79598100E+03, -.64065000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.17507300E-01, 0.94113300E+00, -.29288800E-01, 0.11300300E+00, 0.46275500E-01, 0.23389300E-01, 0.38228800E-01, 0.26167900E+00, -.12727200E-01, -.25635900E-01, 0.11737300E+01, 0.24254700E-01, -.19717900E-01, -.17219400E-01, 0.14759800E-01, -.13165200E-01, 0.12473200E-02, 0.10304000E-01, -.15690700E-01, 0.39613300E-01, 0.11332900E-01, 0.18902600E-01, -.18385400E-01, 0.48210900E-01, -.52258300E-02, 0.15473800E-01, 0.39206700E-01, -.29059600E+00, 0.29992400E-01, -.56747100E-01, -.10481100E-01, 0.81094100E-01, -.48842100E-02, -.11829800E-01, 0.25407100E-01, -.60981500E-01, -.59018100E-01, 0.20524400E-01, 0.69510800E-01, 0.21830000E+00, 0.29206100E+03, -.25877300E+03, -.39858400E+03, -.14126200E+03, -.70925500E+03, 0.71706500E+03, -.42305400E+03, -.35468800E+03, -.87449500E+02, -.94008300E+02, -.26622400E+03, -.19446500E+03, -.17818400E+03, -.14765300E+03, -.16035800E+04, 0.78630800E+03, 0.84514100E+03, -.29732100E+03, -.32909700E+03, 0.78992200E+03, 0.46148500E+03, 0.78833900E+03, 0.56569100E+03, -.18846900E+03, 0.11209000E+03, 0.94147200E+02, 0.22447200E+03, -.16024100E+03, 0.39398900E+02, -.47913200E+02, 0.13837600E+03, 0.43573200E+03, -.61845800E+03, 0.50385300E+03, 0.30929300E+03, -.49767200E+03, 0.54007400E+03, 0.52607200E+03, 0.71554800E+03, 0.49327500E+03, -.37114500E+02, 0.43743700E+03, -.22602300E+03, -.20389800E+03, -.21635500E+03, -.29180300E+03, -.56632800E+02, -.20360000E+03, -.12187800E+03, -.26145400E+03, 0.18829000E+04, -.94239100E+03, -.95310500E+03, 0.75315400E+03, 0.13326400E+03, -.12488800E+04, -.13425200E+04, -.11479600E+04, -.15230800E+03, -.85931600E+03, 0.65853600E+03, 0.42892100E+03, -.43722200E+03, 0.60163300E+03, 0.54535300E+03, 0.76738700E+03, 0.53815100E+03, 0.16267200E+01, 0.94075300E+03, -.41841200E+03, -.50870500E+03, -.35441300E+03, -.22503600E+02, -.33304600E+03, -.12052200E+03, -.16184100E+03, -.29405900E+03, -.40090100E+03, 0.20171800E+03, 0.23654800E+03, 0.54780400E+01, -.96425800E+02, 0.20339500E+03, 0.22600300E+03, 0.14540200E+03, -.62472200E+02, 0.12203200E+04, -.60592700E+03, -.67873900E+03, 0.61923100E+03, 0.15345600E+03, -.72800200E+03, -.61148300E+03, -.71225900E+03, -.20505700E+03, -.84888700E+03, 0.56061000E+03, 0.39179200E+03, -.64805100E+03, -.14210600E+03, 0.56757300E+03, 0.47109900E+03, 0.62683100E+03, -.15177500E+03, -.37688200E+01, 0.65302200E+01, -.55662600E+01, -.19912700E+02, -.28322200E+02, 0.22162100E+00, -.13993000E+02, -.10110200E+02, -.21705900E+02, 0.13240400E+02, -.43258100E+01, -.72434700E+02, -.18309200E+03, 0.74848400E+02, 0.83168400E+02, 0.29667600E+03, -.65620400E+01, -.51318200E+03, 0.13658700E+03, -.67924900E+02, -.29819600E+02, -.65384700E+02, -.79844700E+02, 0.55474000E+01, 0.77834900E+02, -.55706400E+02, -.11094200E+03, 0.18606000E+03, -.10322800E+03, -.92611500E+02, -.47279800E+02, -.84983300E+02, -.56630400E+02, -.17321900E+03, -.11052800E+03, -.12867800E+03, 0.13341200E+03, -.12975800E+03, 0.18608700E+03, 0.13088200E+03, 0.17208800E+03, 0.21494000E+03, 0.12430800E+04, -.35455200E+03, 0.39789400E+03, -.10068300E+04, -.18112400E+03, -.13901100E+03, 0.12004300E+04, -.90252300E+03, -.61643600E+02, 0.29209200E+02, 0.54134300E+03, -.13441300E+03, 0.15585500E+03, 0.26452500E+03, 0.18402100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.38433500E+01, -.36549900E+01, 0.16179600E+01, 0.25189100E+01, 0.24380500E+00, -.10466900E+02, -.33037100E+01, -.68987300E+01, -.47209600E+00, 0.26225100E+00, -.74908200E+00, -.14293700E+00, 0.96413100E+00, 0.12253200E+01, 0.24223000E+00, 0.81537600E+00, 0.23227100E+00, 0.38622500E-01, 0.51870300E+00, 0.43395600E+00, -.39124300E-02, -.10655600E+00, 0.82845000E-01, 0.47259600E+01, -.26690100E+01, 0.13652600E+01, 0.97044900E+00, -.70060700E+01, -.10165100E+01, -.23506900E+01, -.13075400E+00, 0.26147800E+01, -.76819100E+00, -.53745200E+00, -.72581600E+00, -.17528500E+01, -.10955000E+01, -.10561800E+01, 0.63362700E+00, -.27117200E+01, 0.14183100E+02, 0.46606700E+04, 0.14303200E+05, 0.48139400E+04, 0.15436300E+05, -.96564100E+04, 0.62335000E+04, 0.46413500E+04, 0.76756800E+03, 0.20672100E+04, 0.32101800E+04, 0.13346000E+04, 0.81388100E+02, 0.27354000E+04, 0.31996800E+05, -.15646700E+05, -.16846700E+05, 0.37751000E+04, 0.46617800E+04, -.13085800E+05, -.89668800E+04, -.15306400E+05, -.10254500E+05, 0.13518000E+05, -.70841000E+04, -.69573300E+04, -.31997500E+04, 0.41010100E+04, -.49772100E+04, -.30335000E+04, -.72223000E+04, -.93082000E+04, 0.83796500E+04, -.82170900E+04, -.41909300E+04, 0.50223000E+04, -.77469900E+04, -.76406900E+04, -.15841000E+05, -.76551400E+04, 0.29650800E+04, -.71170900E+04, 0.37233800E+04, 0.26782800E+04, 0.33894600E+04, 0.42732600E+04, 0.20007100E+04, 0.31533100E+04, 0.13735400E+04, 0.41134200E+04, -.33589000E+05, 0.16806800E+05, 0.16985500E+05, -.10996100E+05, 0.18355700E+04, 0.21174300E+05, 0.29847900E+05, 0.21974000E+05, 0.16240500E+03, 0.11409300E+05, -.10501400E+05, -.56850900E+04, 0.54783100E+04, -.85198900E+04, -.84469300E+04, -.15583900E+05, -.84555600E+04, 0.45230700E+04, -.31891000E+04, 0.32699800E+03, 0.24829000E+04, 0.11896500E+04, -.11761500E+04, 0.27968500E+04, -.59582500E+03, -.34546700E+04, 0.44137700E+04, 0.49175100E+04, -.25021800E+04, -.28316300E+04, 0.81152400E+03, 0.19173700E+04, -.30082100E+04, -.23909300E+04, -.19952000E+04, 0.16092200E+04, -.21344500E+05, 0.10553800E+05, 0.12044200E+05, -.98672100E+04, -.66355400E+03, 0.10785700E+05, 0.11861800E+05, 0.11968600E+05, 0.15174100E+04, 0.28895200E+05, -.17439000E+05, -.13602200E+05, 0.33960000E+04, 0.27123000E+04, -.11090500E+05, -.95961600E+04, -.17216200E+05, 0.16245800E+04, 0.28327100E+04, -.14480400E+04, -.13329100E+04, 0.61638700E+03, 0.54608000E+03, -.71570400E+03, 0.29052100E+03, 0.52454900E+02, 0.26908700E+03, -.11739000E+05, 0.57584200E+04, 0.72569500E+04, 0.32838100E+04, -.34799300E+04, 0.23220800E+04, -.25797400E+04, 0.43157200E+04, 0.11472200E+05, -.34514500E+04, 0.17132700E+04, 0.99216400E+03, 0.99891700E+03, 0.20518600E+04, -.86307700E+02, -.19690400E+04, 0.77508700E+03, 0.24362100E+04, 0.31682800E+04, -.13582000E+04, -.16284300E+04, 0.20386200E+03, -.45741100E+03, -.82415500E+02, 0.14419000E+04, 0.93583800E+03, 0.95015400E+03, -.17843100E+04, 0.23027600E+04, -.33114800E+04, -.20955000E+04, -.30455300E+04, -.24601000E+04, -.66941300E+04, 0.50030100E+04, -.10934000E+05, 0.16284900E+05, 0.29241900E+04, -.15471000E+03, -.19450500E+05, 0.92575900E+04, 0.28302100E+04, 0.34600300E+03, -.66805500E+04, 0.25658500E+04, -.52579300E+04, -.50451600E+04, -.27963700E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24104900E+00, -.27419700E+01, 0.21895700E+00, -.19904000E+00, -.11927200E+00, 0.20684300E+01, 0.38784400E+01, -.10646900E+01, 0.17838400E+00, 0.15554900E+00, -.17119400E+00, -.10165600E+00, 0.30037500E+00, 0.47286000E+00, -.56949000E+00, 0.45576300E-01, -.12810400E-01, 0.39032600E+00, 0.61394100E+00, -.24534800E+00, 0.71262500E-02, -.26588100E+00, 0.22043200E+00, 0.63923100E+00, -.33869400E+00, -.25102300E-01, -.14382600E+00, 0.66659400E+01, 0.88787100E-01, 0.13000300E+00, 0.71561100E-01, -.93889100E-01, 0.28427600E+00, 0.10538600E+00, -.23353900E+00, 0.52048400E+00, 0.32437300E+00, 0.13174400E+00, -.19450100E+00, 0.17691700E+00, -.26679200E+01, 0.50162800E-01, -.10152200E+04, -.44601800E+03, -.18793800E+04, 0.17621400E+04, -.11228600E+04, -.88012000E+03, -.11384400E+02, -.10055800E+03, -.70689500E+03, -.37093900E+03, -.40761100E+03, -.31412000E+03, -.10302700E+04, 0.46848200E+03, 0.64060000E+03, 0.31291900E+03, -.11236300E+02, -.38925300E+03, -.83958000E+03, -.13587200E+03, 0.12114900E+04, -.13184000E+04, 0.73392200E+03, 0.65967800E+03, 0.16007800E+03, -.77682200E+03, 0.54854400E+03, -.29458400E+03, 0.70819100E+03, 0.89750800E+03, 0.51332300E+04, -.18929000E+04, -.25668600E+04, 0.38723100E+03, 0.25952300E+04, -.24345500E+04, -.17851400E+04, -.21896600E+04, 0.48475100E+02, 0.44641500E+03, -.24942600E+03, -.51223200E+02, -.13633400E+03, -.25961200E+03, -.33615000E+03, -.12361900E+03, -.22787800E+03, -.37268900E+03, 0.18810200E+04, -.95180300E+03, -.90664700E+03, 0.81489400E+03, -.81960200E+03, -.76533700E+03, -.16915800E+04, -.12354700E+04, -.25088900E+03, 0.50210000E+04, -.16630700E+04, -.25140900E+04, 0.18653100E+03, 0.24328800E+04, -.22091100E+04, -.16417500E+04, -.20620500E+04, -.26535200E+03, 0.36437600E+04, -.14875300E+04, -.19936400E+04, 0.32809400E+03, 0.87375200E+03, -.20004700E+04, -.14682300E+04, -.16277900E+04, -.43422400E+03, -.90738500E+03, 0.45903400E+03, 0.45321100E+03, 0.40358900E+01, -.88974300E+02, 0.44744500E+03, 0.68176100E+03, 0.13206500E+02, 0.30084400E+02, 0.31357000E+02, -.10108700E+02, -.16157100E+03, 0.62621300E+03, -.26025900E+03, 0.30144300E+03, 0.14811800E+03, 0.19289400E+03, -.68781400E+02, 0.13399300E+04, -.45801800E+02, -.79928300E+03, 0.60005800E+03, 0.96248000E+03, -.15359300E+04, -.15354100E+04, -.10853400E+04, 0.22591400E+02, 0.68053400E+02, -.17898900E+02, -.34596600E+02, -.21862400E+02, -.34381000E+02, -.37702200E+02, 0.44157800E+02, -.21198700E+03, -.35177600E+02, 0.69163400E+03, -.33460700E+03, -.48945000E+03, -.12428500E+03, 0.63838600E+03, -.51425400E+02, 0.12445300E+04, -.49641300E+03, -.10373700E+04, 0.25152500E+03, -.12359900E+03, -.78825600E+02, -.16186700E+03, -.16319000E+03, 0.45496100E+02, 0.37687000E+03, 0.90840700E+02, -.22495700E+03, -.19882600E+04, 0.94988100E+03, 0.97893400E+03, 0.23315000E+03, 0.21790800E+03, 0.46040800E+03, 0.20234200E+03, -.94833600E+02, 0.21678900E+03, -.55817900E+03, 0.58608200E+03, -.36716300E+03, -.48639800E+03, -.30560400E+03, -.51725100E+03, 0.27194400E+02, -.59989600E+03, -.15427100E+03, 0.31732300E+03, 0.40754100E+03, 0.51200900E+03, -.29891600E+03, -.75715100E+03, 0.83370700E+03, -.17674200E+03, 0.59522300E+03, 0.54681200E+03, -.64102900E+03, 0.63678800E+02, -.57428900E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.50119900E+00, 0.32960300E-01, -.35790800E+00, -.93963700E+00, 0.22628800E+00, 0.39945400E+01, 0.31131100E+01, -.19161800E-01, 0.24593000E+00, -.16077300E+00, 0.13509500E+01, 0.58699900E+00, -.92480100E-01, -.22342500E+00, 0.13461000E+00, -.22275000E+00, -.16279400E-01, -.19666600E+00, 0.46718300E-02, -.42364700E-01, -.11142400E+00, 0.16392700E+00, 0.53284400E-02, -.34953200E+00, -.18976500E+00, -.84619200E-02, 0.14622400E+00, 0.10551800E+01, -.11371200E-01, -.30681800E-01, -.13395500E+00, 0.86525900E+00, 0.41860900E+00, -.15772100E+00, 0.12307400E+00, 0.52120500E-01, -.56931700E-01, -.11285700E+00, 0.61729900E+00, 0.88883000E+00, 0.42714200E+01, 0.88188700E-01, -.44535100E+00, -.10068300E+04, -.33374300E+03, 0.82633100E+03, -.50593300E+03, -.39170300E+03, -.36091400E+03, -.83157100E+03, 0.14871400E+03, 0.89379600E+03, 0.59711200E+03, -.64513100E+03, -.39850600E+03, 0.14236600E+03, 0.41328800E+03, 0.61471100E+03, 0.38920700E+03, -.52956000E+03, -.11062200E+04, -.43227300E+03, 0.63374000E+03, -.11602200E+04, 0.66862000E+03, 0.61629100E+03, -.46992900E+03, -.60780300E+03, 0.61901700E+03, 0.16155700E+03, 0.11956700E+04, 0.36450300E+03, -.73341500E+04, 0.40742700E+04, 0.36673100E+04, -.93218300E+03, -.87280000E+03, 0.33357300E+04, 0.30838200E+04, 0.35637900E+04, -.59192900E+03, 0.18142100E+04, -.93693600E+03, -.69503000E+03, -.18206200E+03, -.22809800E+03, -.65942300E+03, -.28334000E+03, -.59849700E+03, -.40562300E+03, 0.16062100E+04, -.81414000E+03, -.87223400E+03, 0.40274000E+03, -.11461500E+02, -.74350600E+03, -.60309100E+03, -.15425400E+04, 0.11209800E+04, -.59256800E+04, 0.34822400E+04, 0.29597000E+04, -.84118200E+03, -.50539100E+03, 0.28144800E+04, 0.28025500E+04, 0.29251200E+04, -.80957900E+03, -.49595100E+04, 0.26940000E+04, 0.22775700E+04, 0.18415400E+03, -.42946700E+03, 0.17758600E+04, 0.15013300E+04, 0.18457600E+04, -.83379300E+02, 0.97408700E+03, -.48140800E+03, -.32742300E+03, 0.31683300E+03, 0.38274400E+02, -.15015600E+03, 0.26041800E+03, -.48780600E+03, -.19581400E+03, -.47192200E+03, 0.24899100E+03, -.12446500E+03, 0.34545500E+03, -.84645300E+02, 0.45599700E+03, 0.67444700E+03, 0.34594200E+03, 0.54974000E+03, -.52766300E+04, 0.30682100E+04, 0.25185900E+04, 0.78975200E+03, -.41446300E+02, 0.15079300E+04, 0.68573700E+03, 0.11464300E+04, 0.44818900E+03, 0.88284800E+02, -.26374500E+02, -.18488800E+03, 0.29452200E+02, 0.55536900E+02, -.74416800E+02, -.20803400E+02, -.16412400E+03, 0.38409500E+02, 0.98512600E+03, -.47477300E+03, -.91015500E+03, 0.57845300E+03, 0.53156200E+03, -.18660500E+03, 0.69784200E+03, -.87150500E+03, -.75442400E+03, 0.88207400E+02, -.44053800E+02, 0.66174800E+02, 0.89469300E+02, -.77652100E+02, -.75676100E+01, 0.24869300E+03, 0.12259000E+03, -.10812800E+03, -.10313200E+04, 0.47595200E+03, 0.54245500E+03, -.27359600E+03, 0.14783400E+03, 0.17150600E+03, -.27499300E+03, -.92796400E+02, 0.13543600E+03, -.16964000E+03, 0.13267500E+03, -.25545900E+02, -.13657900E+03, -.39348700E+02, -.21720000E+03, -.47303500E+03, -.64464000E+03, -.55899400E+03, -.34983700E+03, 0.62397400E+02, 0.38242300E+03, 0.44071300E+03, 0.14038400E+02, 0.35154500E+03, -.53897800E+03, 0.33476000E+03, 0.12098200E+03, -.58200500E+03, 0.25376900E+03, -.76547300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.28473600E+01, 0.22045200E+01, -.14348700E+01, -.10405700E+00, 0.26615800E+00, -.28237700E+01, -.52110900E+01, -.28147800E+01, -.11848800E+00, -.21262500E+00, 0.45152500E+01, 0.11327400E+01, -.59747500E+00, -.28294700E+00, 0.65097800E+00, -.38221800E+00, 0.42413300E-01, -.53162700E+00, 0.71511700E+00, 0.33465800E-01, 0.27264700E+00, -.90672600E+00, -.27441700E-01, 0.80630200E+00, -.11312600E+01, 0.69993400E+00, 0.11668900E+01, 0.21134100E+01, 0.87509300E+00, -.70870300E+00, 0.14171600E+00, -.16011100E+00, 0.78310300E-01, 0.10077300E+00, -.69087500E-01, 0.20574200E+00, 0.33529300E+00, -.10363000E+00, 0.51177400E+00, 0.50504400E+00, -.92860100E+00, -.15945900E+00, -.13391800E+01, 0.47276900E+00, -.28858100E+04, 0.15765400E+04, -.10924200E+04, -.84834500E+03, 0.43391600E+01, 0.31171400E+03, -.10348200E+04, -.13225400E+04, -.12805300E+04, 0.89348000E+02, 0.33367000E+02, -.77552000E+02, -.45894800E+01, 0.12069600E+03, 0.20607900E+03, 0.11845900E+03, 0.57970700E+03, 0.15479500E+03, 0.22760400E+04, 0.24702100E+04, -.10647300E+04, -.12963700E+04, 0.66480700E+03, 0.10117600E+02, -.10437900E+04, -.13147700E+04, -.15753100E+04, 0.14118000E+04, -.34635000E+04, 0.26603400E+04, 0.17307400E+04, -.50062400E+03, 0.35576700E+04, 0.18888500E+04, 0.24287100E+04, 0.20015400E+04, 0.86994100E+03, -.10599900E+04, 0.49277000E+03, 0.64957700E+03, 0.18687200E+03, -.19654600E+03, 0.44150700E+03, 0.43365700E+03, 0.66698700E+03, -.26538300E+01, 0.29980400E+04, -.15251800E+04, -.13607600E+04, 0.10448300E+04, -.10906000E+04, -.14308100E+04, -.18455800E+04, -.14534100E+04, -.16064000E+04, -.29896900E+04, 0.27246200E+04, 0.14922100E+04, -.55880400E+03, 0.34472600E+04, 0.17290100E+04, 0.23434400E+04, 0.18424600E+04, 0.49755600E+03, 0.60096800E+04, -.24738700E+04, -.31050700E+04, -.12383800E+04, 0.77817100E+03, -.22329200E+04, -.13154100E+04, -.26569200E+04, -.66955700E+03, -.20143700E+04, 0.10033100E+04, 0.85602200E+03, -.89936900E+02, -.12085800E+03, 0.73165700E+03, 0.66447000E+03, 0.37209400E+03, 0.18347900E+02, 0.99946600E+03, -.51017000E+03, -.38430500E+03, 0.91434600E+03, -.32384500E+03, -.71463300E+03, -.12729100E+04, -.75253100E+03, -.11605300E+04, 0.40831700E+04, -.10688500E+04, -.20541100E+04, -.14239600E+04, 0.14022300E+04, -.11575200E+04, 0.50171000E+03, -.13458500E+04, 0.34120700E+03, 0.10595500E+04, -.44520100E+03, -.48373400E+03, 0.10436500E+03, -.10803000E+02, -.31211000E+03, 0.98906600E+02, -.33859400E+03, -.87351800E+02, -.38640000E+04, 0.19146000E+04, 0.20619100E+04, -.75414100E+03, -.11736400E+02, 0.16989500E+04, 0.21101400E+04, 0.18318800E+04, -.14387500E+04, -.43395900E+02, 0.26899200E+02, -.11469900E+03, -.24443600E+03, -.57829600E+02, -.26113000E+02, 0.16314700E+02, 0.42469200E+03, -.11030800E+03, -.12514500E+03, -.10671000E+02, 0.10851400E+02, 0.28226800E+03, -.30214200E+02, 0.16581500E+03, 0.38567900E+03, -.61469400E+03, -.61106600E+02, -.12221400E+03, 0.30199700E+02, -.12479000E+03, -.51989400E+02, 0.77524400E+02, -.28317500E+03, 0.39006100E+04, -.42843300E+03, 0.61684600E+03, -.10577600E+03, 0.92745600E+02, -.54431000E+02, 0.16541700E+03, -.27416700E+04, 0.30491200E+03, 0.39069100E+03, 0.11025100E+04, 0.48935900E+02, 0.17206600E+03, 0.20294900E+03, 0.84845400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.76856900E+00, 0.62303500E+00, -.81033200E-01, 0.13678500E+01, 0.18259100E+00, -.54566600E+01, 0.21872900E+01, -.10958400E+00, -.26433300E+00, 0.45469700E+00, 0.17791700E+01, 0.62958400E+00, -.54842900E-01, 0.40190100E+00, -.43245300E+00, -.37993100E+00, -.13763200E+00, 0.20508300E+00, 0.67389000E+00, 0.70750100E-01, 0.18027100E+00, -.40368000E+00, -.19154600E-02, 0.17110800E+01, -.30815200E+00, 0.39810600E+00, 0.29239400E+00, -.50430700E+01, -.11933300E+00, 0.22527500E+00, 0.25618600E+00, 0.80861700E+00, 0.72547700E+00, 0.11778700E+00, 0.45224300E+00, 0.53594100E+00, -.16852100E+00, -.11937900E+01, 0.26852700E+00, 0.96916700E-01, 0.29602000E+01, 0.15958000E+00, -.17409600E+00, 0.52019700E+00, 0.14978500E-02, 0.48895000E+04, -.22714900E+04, -.23532500E+04, -.32234000E+02, 0.64566200E+03, -.20400400E+04, -.14218800E+04, -.19451300E+04, -.15829000E+03, 0.23418100E+04, -.11354400E+04, -.15728000E+04, 0.79065300E+03, 0.77881900E+03, -.20068800E+04, -.21477900E+04, -.12226100E+04, 0.24813100E+03, 0.17274100E+04, -.88692500E+03, -.74623100E+03, 0.78126600E+03, 0.35999200E+02, -.45513500E+03, -.63614700E+03, -.84428900E+03, -.40232500E+03, 0.21625000E+05, -.11104000E+05, -.10811500E+05, 0.37516100E+03, 0.10613800E+04, -.10842000E+05, -.11619400E+05, -.10585900E+05, -.40591200E+03, -.70703800E+02, 0.55223300E+02, -.24483200E+03, 0.41598100E+03, -.18359300E+03, 0.13659300E+03, 0.32318300E+03, 0.22724800E+03, -.29013900E+03, -.17508400E+04, 0.87174700E+03, 0.80319900E+03, 0.10050400E+04, -.14268300E+03, 0.11070200E+04, 0.90266900E+03, 0.78465900E+03, -.67418200E+03, 0.19476600E+05, -.10196300E+05, -.97382700E+04, 0.48221000E+03, 0.67924700E+03, -.96904800E+04, -.10476200E+05, -.95369000E+04, -.35857700E+03, 0.21661000E+05, -.11089200E+05, -.10407700E+05, -.76851600E+03, 0.68936300E+03, -.85364600E+04, -.56510600E+04, -.70113100E+04, -.16093800E+04, -.45146200E+03, 0.21860300E+03, 0.36336300E+02, 0.32637900E+03, 0.90509700E+03, -.35412600E+03, -.73219100E+03, -.96929600E+03, 0.98263000E+03, -.19929100E+04, 0.98060800E+03, 0.14383200E+04, -.99458300E+03, -.40589500E+03, 0.14916800E+04, 0.17341800E+04, 0.12214400E+04, -.24272000E+03, 0.22728200E+05, -.11740100E+05, -.11196600E+05, -.10951200E+04, 0.85828500E+03, -.96523000E+04, -.70240300E+04, -.73580700E+04, -.14240400E+04, -.42111800E+03, 0.20861800E+03, 0.35019900E+03, 0.65956200E+01, 0.19173200E+02, 0.16371800E+03, 0.16898700E+03, -.81218100E+02, 0.27604300E+02, 0.11095400E+04, -.56103200E+03, -.10024900E+03, -.77696400E+03, 0.67062200E+03, -.77313600E+03, -.29642000E+03, -.10011500E+04, 0.95613100E+03, 0.39726100E+03, -.19665700E+03, -.25984900E+03, -.36530400E+03, -.39182300E+02, -.38514300E+02, 0.42303100E+03, -.14392800E+03, -.68712600E+02, -.20574800E+04, 0.10507900E+04, 0.10888800E+04, 0.41033200E+03, 0.22672500E+03, 0.40690100E+03, -.36654700E+03, -.17598800E+03, 0.42862100E+03, -.74838300E+03, 0.13635900E+04, -.83055900E+03, -.72296700E+03, -.73309400E+03, -.58545700E+03, 0.31454000E+04, -.15785600E+03, -.66603700E+03, -.96645000E+03, 0.80802500E+03, 0.28184400E+03, 0.97465000E+03, -.12638900E+04, 0.12685900E+04, -.32124000E+02, 0.32069300E+03, 0.13472300E+04, -.97543300E+03, -.54372700E+03, -.12670300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13832500E+01, -.43678300E+01, -.16929900E+01, -.31168900E+01, 0.19839400E+01, 0.58391600E-01, -.79712900E+01, 0.18031600E+01, -.10049000E-01, -.32325900E+00, 0.38674900E+01, 0.28949400E+01, -.16448600E+00, -.24482400E+00, 0.38912500E+00, -.26752000E+01, -.47650600E+00, -.53486200E+00, -.22899900E+00, 0.62616000E+00, -.90429300E-01, 0.26859500E+00, 0.17093700E+00, -.93454700E-01, 0.41684300E-01, -.17129500E+00, 0.22591400E+00, 0.44434800E+01, -.25917600E+00, -.11266400E+01, 0.76960600E-01, 0.41390400E+00, 0.30689000E+00, -.22414300E-01, -.42474700E+00, 0.41434900E+00, 0.26823500E+00, -.52209700E-01, -.10746700E+01, -.17782400E+01, -.32708200E+01, 0.32870500E+00, -.35665200E+00, -.86912100E+00, -.55429600E+00, 0.14685500E-01, -.75367300E+03, 0.72168100E+02, -.50587700E+03, -.97446000E+03, 0.20520800E+03, 0.36502800E+03, 0.10998600E+04, -.68540700E+03, 0.10672500E+03, -.17706500E+03, 0.29637200E+03, 0.73929800E+03, 0.52052500E+01, -.13263100E+04, -.28993500E+04, -.10887000E+04, 0.57915900E+03, -.23764500E+04, 0.13336500E+04, 0.13059400E+04, -.22370100E+03, -.79421400E+03, 0.79191900E+03, -.13562200E+03, 0.19999900E+04, 0.33404500E+03, 0.64547400E+04, -.14106400E+04, -.32270300E+04, -.32296900E+03, 0.17583300E+04, -.30208600E+04, -.26975400E+04, -.26142600E+04, 0.85105100E+03, 0.27473900E+03, -.21622900E+03, 0.29470600E+03, 0.18182700E+03, -.64482800E+03, -.15867800E+03, -.23907200E+03, -.32558300E+03, -.46635600E+03, -.38747500E+04, 0.19150700E+04, 0.17669200E+04, 0.17542500E+03, -.39608600E+03, 0.15919300E+04, 0.13578300E+04, 0.12740400E+04, 0.10887000E+04, 0.64219200E+04, -.82625300E+03, -.32191100E+04, -.39632700E+03, 0.22922200E+04, -.28885100E+04, -.23274700E+04, -.26002700E+04, 0.79963900E+03, 0.99060200E+03, 0.50008900E+03, -.81920000E+03, 0.43617600E+02, 0.59503300E+03, -.14619200E+04, -.19024000E+03, 0.46214200E+03, 0.26013600E+03, 0.61818300E+03, -.28230600E+03, -.14932700E+03, 0.14247100E+03, 0.40621200E+03, 0.11289700E+02, 0.11673600E+04, -.87651700E+03, -.79317700E+02, -.32893600E+04, 0.16758600E+04, 0.10800300E+04, 0.19741900E+02, -.36793500E+03, 0.20330600E+04, 0.28084700E+04, 0.17049500E+04, 0.34565800E+03, 0.18806300E+04, 0.76808800E+03, -.12190900E+04, 0.11477100E+04, 0.11860200E+04, -.26634300E+04, -.22545200E+04, -.10485200E+04, 0.11739900E+04, -.52187200E+03, 0.26543700E+03, 0.10960300E+03, 0.11234500E+03, 0.28983300E+02, 0.12950100E+03, 0.13041600E+03, -.77581000E+02, 0.46529100E+02, 0.10325700E+04, -.46977000E+03, -.11825700E+04, 0.85831900E+02, 0.85615700E+03, 0.94402800E+02, 0.22103500E+04, -.13417100E+04, -.66739700E+03, 0.11321600E+03, -.53242400E+02, 0.13800200E+03, -.15591700E+03, -.43583400E+03, 0.48824000E+03, 0.61373700E+03, -.22647700E+03, -.51534300E+03, -.18228900E+04, 0.79952700E+03, 0.95925500E+03, 0.37463600E+03, 0.11481900E+03, 0.83636800E+02, 0.10032400E+03, -.25226500E+02, 0.37491400E+03, -.12836000E+04, 0.12326500E+04, -.80601700E+03, -.11303200E+04, -.92221500E+03, -.90184700E+03, 0.10397900E+04, -.12680300E+04, -.18946000E+04, 0.13416500E+03, 0.10378200E+04, 0.84176700E+03, 0.15085200E+02, -.13557100E+04, 0.24905900E+04, -.75268000E+03, 0.92559800E+03, 0.12443600E+04, -.21950600E+04, 0.28017000E+02, -.12382400E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17270800E+01, -.67600100E+00, 0.12764000E+01, 0.27441700E+01, -.50488500E+00, -.86778900E+01, -.10972800E+01, 0.44271700E+00, -.49340000E+00, 0.40009400E+00, -.83781800E+00, -.14443700E+01, 0.27525000E+00, 0.82918100E+00, -.44927600E+00, 0.10065000E+01, 0.18763700E-01, 0.30962800E+00, 0.53752000E-03, 0.24731700E+00, 0.23523600E+00, -.27227100E+00, 0.55329400E-02, 0.60073700E+00, 0.35474100E+00, 0.74157300E-01, 0.20633200E+00, -.94274900E+00, -.12707800E+00, -.31718300E+00, 0.15590900E+00, -.67044900E+00, -.33769600E+00, 0.18122000E+00, 0.39140500E+00, -.42874500E+00, -.23397000E+00, 0.19206500E-01, 0.65537100E+00, 0.31458400E+00, 0.72154300E+01, 0.70227000E-01, -.33631100E+00, -.10706800E+01, 0.63987200E+00, -.48246300E+00, -.33513300E+00, 0.18833600E+03, 0.31963700E+03, 0.50184700E+03, -.11937000E+03, -.42395100E+03, -.46971800E+03, 0.10929800E+03, 0.13958500E+04, -.71445800E+03, -.11352600E+04, 0.65826300E+02, -.77108400E+03, -.14597000E+04, -.26490500E+04, -.77555600E+03, -.15244100E+04, -.46071300E+04, 0.23640300E+04, 0.25544200E+04, 0.66848900E+03, -.28331200E+03, 0.15733000E+04, 0.66965800E+03, 0.20277700E+04, 0.68758300E+03, 0.20551000E+05, -.10197800E+05, -.10274800E+05, 0.14933000E+04, 0.89362500E+03, -.10109000E+05, -.10313900E+05, -.98173900E+04, -.15470800E+04, 0.12662400E+04, -.63603700E+03, -.52667800E+03, -.17664500E+03, -.59627100E+03, -.20202700E+03, -.77953100E+03, -.87275200E+03, -.10068800E+04, 0.20670200E+03, -.11103400E+03, -.77608500E+02, 0.93615400E+03, 0.51358300E+02, 0.39268600E+03, 0.49242800E+03, -.31334100E+02, 0.15219700E+04, 0.19139600E+05, -.93975600E+04, -.95725600E+04, 0.14589000E+04, 0.89431100E+03, -.92691200E+04, -.92701400E+04, -.91415900E+04, -.15403700E+04, 0.92980000E+04, -.44222700E+04, -.43414000E+04, 0.57329500E+03, 0.66912700E+03, -.42672500E+04, -.31888400E+04, -.27537800E+04, -.13101400E+04, 0.10678100E+04, -.53582100E+03, -.10659400E+04, 0.48324700E+03, 0.88972600E+03, -.87571500E+03, -.91913400E+03, -.16167500E+04, 0.83525200E+03, -.17917000E+04, 0.88828800E+03, 0.14100100E+04, -.31917800E+03, 0.41739500E+03, 0.14628900E+04, 0.21284700E+04, 0.12738600E+04, 0.17749300E+04, 0.13414400E+05, -.64174700E+04, -.67547600E+04, 0.13034900E+03, -.38777900E+03, -.66061300E+04, -.57876900E+04, -.39423200E+04, -.26098000E+04, 0.96899900E+01, 0.26696900E+02, 0.32169900E+03, -.95982500E+02, -.51117400E+02, 0.11778600E+02, 0.17402700E+03, -.19168600E+03, -.80394500E+02, 0.77853100E+04, -.38834700E+04, -.33475800E+04, -.37344900E+03, 0.12783100E+04, -.28001000E+04, -.12661700E+04, -.40104800E+04, -.26983800E+03, 0.36761300E+03, -.17700500E+03, -.23055600E+03, -.29098100E+03, -.10196300E+03, 0.10474300E+03, 0.53760100E+03, -.24640500E+03, -.45511000E+02, -.22886000E+04, 0.11183500E+04, 0.12026800E+04, 0.38771500E+03, 0.36913400E+02, 0.44740400E+03, -.21925100E+03, 0.40883300E+03, 0.27698800E+02, -.97113100E+03, 0.13028200E+04, -.79016000E+03, -.85209100E+03, -.70466500E+03, -.59463200E+03, -.18298700E+04, -.12974500E+03, -.22504100E+03, 0.73407200E+03, 0.68667200E+03, 0.68291000E+03, -.71304600E+03, 0.69952200E+03, 0.12789600E+04, -.54615500E+03, -.37810700E+03, 0.12291700E+04, -.11700300E+04, -.53396600E+03, -.13703200E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.28794100E+01, 0.32510700E+01, -.52844000E+00, 0.78150100E+00, -.71710800E+00, 0.53010900E+00, -.10704200E+01, -.13456300E+01, 0.16140200E-01, -.11446300E+00, -.97722300E+00, 0.28690900E+00, -.41494700E+00, -.10193100E+00, 0.17883400E+00, 0.58763900E+00, 0.63508100E-01, 0.24398000E+00, 0.13545800E+00, 0.15633600E+00, -.14359700E+00, 0.11904400E+00, 0.30842100E-01, 0.12274000E+00, -.62950800E+00, 0.16112400E+00, -.46781700E+00, 0.46741600E+01, -.33495400E+00, 0.16761300E+01, -.14413700E+00, 0.11602300E-01, -.55579900E-01, -.30550600E-01, -.16748500E+00, 0.34829300E+00, -.13587800E+00, -.18814500E+00, 0.29465200E+00, 0.40986100E+00, -.42550700E+01, -.19519700E+00, -.30485100E+00, -.10478200E+00, 0.23204100E+00, 0.21915300E+00, -.27573300E+00, 0.17919300E+00, -.52524100E+03, -.69648400E+03, 0.24325900E+03, 0.69833000E+03, 0.63414700E+03, -.33959500E+03, 0.12279100E+03, -.62635400E+02, 0.22143300E+03, 0.46550800E+03, 0.99801700E+03, 0.18358500E+02, 0.78646300E+03, -.12782100E+03, 0.16397700E+04, 0.61400600E+04, -.30934300E+04, -.30770900E+04, -.59763300E+03, -.10221600E+03, -.19532600E+04, -.14918700E+04, -.22570400E+04, -.64111600E+03, -.66868400E+04, 0.35451100E+04, 0.33437300E+04, -.12998700E+04, -.12899500E+03, 0.32497900E+04, 0.32371800E+04, 0.31623600E+04, 0.12779000E+04, -.98267000E+03, 0.49115900E+03, 0.55925700E+03, 0.60740700E+03, 0.29354400E+03, 0.85787600E+02, 0.10327800E+04, 0.57530400E+03, 0.75508300E+03, -.20190500E+04, 0.10029500E+04, 0.88841700E+03, -.11970700E+03, -.24986500E+03, 0.54419400E+03, 0.32057600E+03, 0.71584600E+03, -.68816500E+03, -.65334000E+04, 0.32794300E+04, 0.32635200E+04, -.12726700E+04, -.19393000E+03, 0.30672900E+04, 0.28259600E+04, 0.30872500E+04, 0.12856200E+04, -.45209000E+04, 0.18735900E+04, 0.20665800E+04, -.11139800E+04, -.13109300E+04, 0.19782700E+04, 0.22084300E+04, 0.21164900E+04, 0.39438200E+03, -.23163900E+04, 0.11560100E+04, 0.14464900E+04, -.17298700E+03, -.38998800E+03, 0.12215900E+04, 0.15231000E+04, 0.13618700E+04, -.42152400E+03, -.16109100E+04, 0.80972100E+03, 0.36685900E+03, -.37400300E+02, -.60722300E+03, 0.42084100E+03, 0.27956000E+02, 0.43096900E+03, -.11143000E+04, -.41703100E+04, 0.18088300E+04, 0.19754900E+04, -.47884600E+03, 0.15669800E+03, 0.17471700E+04, 0.24581800E+04, 0.11920100E+04, 0.19746000E+04, -.26814800E+03, 0.97697800E+02, -.11348500E+02, 0.13846800E+03, 0.80363700E+01, 0.84216300E+02, -.47590200E+02, 0.11095000E+03, 0.74634200E+02, -.11343200E+05, 0.56639800E+04, 0.51971100E+04, 0.93246500E+02, -.92813000E+03, 0.42127400E+04, 0.34473500E+04, 0.49575600E+04, -.52271400E+02, -.26906900E+03, 0.13179100E+03, 0.31078400E+03, 0.62884100E+02, -.30945600E+02, 0.80025700E+02, -.25868900E+03, 0.88451500E+02, -.11151000E+03, 0.11623700E+04, -.55987200E+03, -.56566200E+03, 0.25188200E+02, -.27965200E+02, -.31457500E+03, 0.22624000E+03, -.64037500E+03, 0.51686200E+02, -.75746200E+02, -.28392400E+03, 0.39848100E+01, -.10250000E+03, -.13500800E+03, -.95647600E+02, 0.29502000E+04, -.21710300E+03, -.13171300E+04, -.13466600E+04, 0.27561100E+03, -.33243000E+02, 0.14026900E+04, -.12540300E+04, 0.53749000E+03, 0.21900500E+03, 0.65209900E+03, -.24946900E+03, -.43347500E+03, 0.18197100E+02, 0.37478100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25335700E+01, -.12106900E+01, 0.17772300E+01, 0.10925800E+01, -.75778600E+00, -.10272400E+02, 0.26702900E+01, -.11603200E+00, -.64709400E+00, -.12044600E+00, 0.33739000E+01, -.40136500E+00, 0.12320200E+01, -.19996400E+00, -.42316600E+00, 0.11078900E+01, 0.28471900E-02, -.77801800E+00, 0.14101100E+01, -.32222800E+00, -.12385800E+00, -.12706900E+01, 0.46497800E-01, 0.51503700E+00, 0.21345500E-01, -.54315700E+00, 0.24371400E+00, 0.51286300E+01, -.77335400E+00, -.21174800E+01, -.61755800E+00, 0.14118500E+01, 0.13450300E+01, -.17555900E+00, 0.50653100E+00, 0.28296100E-01, 0.37445400E+00, -.43194100E+00, 0.94769400E-01, -.99370400E+00, 0.33274900E+01, 0.41167200E+00, -.12016700E+01, -.91204900E+00, -.13161700E+00, 0.86179000E-01, 0.56353200E+00, 0.15749200E-01, -.24373700E+00, -.96472800E+03, 0.44236400E+03, 0.10531900E+04, 0.99547700E+03, -.57322500E+03, 0.23695100E+04, -.12800600E+04, -.54846900E+03, 0.48633600E+03, 0.86764700E+03, -.15317300E+04, -.15683300E+04, -.20582200E+04, 0.50211000E+03, 0.16281300E+04, -.62931800E+03, -.84416300E+03, -.10517900E+04, -.78834600E+03, -.20059400E+03, -.11857800E+03, 0.53770200E+03, -.26122400E+03, -.77960300E+04, 0.47409700E+04, 0.38979800E+04, -.15913600E+04, -.10811200E+04, 0.37128000E+04, 0.34362400E+04, 0.37744900E+04, -.47151300E+03, 0.18863800E+04, -.98701500E+03, -.50028000E+03, 0.14734600E+03, 0.12994800E+03, -.10450200E+04, -.49446000E+03, -.19292000E+04, -.14571500E+03, -.11692000E+04, 0.53843700E+03, 0.56657200E+03, -.25603000E+03, 0.37890700E+02, 0.10102400E+03, 0.14468400E+03, 0.43866200E+03, 0.10917600E+04, -.69301600E+04, 0.40399400E+04, 0.34590700E+04, -.15220900E+04, -.87183100E+03, 0.32867900E+04, 0.29607900E+04, 0.33299300E+04, -.46810100E+03, -.11754100E+05, 0.55480100E+04, 0.52467900E+04, 0.21318200E+04, 0.42610800E+03, 0.26931900E+04, 0.28939400E+03, 0.23789700E+04, 0.18298100E+04, 0.44095900E+03, -.22171000E+03, 0.14192600E+03, -.13788000E+02, -.32088300E+03, 0.29119100E+03, 0.11762000E+04, 0.85731200E+03, -.46356700E+03, -.23348300E+04, 0.11747700E+04, 0.27078600E+03, 0.49733000E+03, -.10573300E+03, 0.83891000E+03, 0.77537700E+03, 0.13645500E+04, 0.62845800E+03, -.85763600E+04, 0.45138500E+04, 0.38970600E+04, 0.28622400E+04, 0.15475800E+04, 0.11171100E+04, -.10911200E+04, -.36368700E+03, 0.23261100E+04, 0.44398800E+03, -.18740400E+03, -.36534000E+03, 0.95561200E+02, 0.87095100E+02, -.20433700E+03, -.68880100E+00, -.15131400E+03, 0.45425000E+02, -.47623600E+04, 0.23918100E+04, 0.14949900E+04, 0.11743100E+04, 0.26809100E+03, 0.16532700E+04, 0.18510200E+04, 0.17188200E+04, -.15475200E+03, -.59633300E+03, 0.29845400E+03, 0.68961000E+03, 0.26968000E+03, -.16229200E+03, 0.45680800E+03, -.34536800E+02, -.42360600E+03, -.18116000E+03, 0.10858100E+04, -.58801600E+03, -.56933300E+03, -.71335300E+02, 0.27290000E+03, -.62086800E+03, 0.96678800E+02, -.36224400E+03, 0.18266400E+03, -.75156200E+03, 0.21540000E+03, -.41528500E+03, -.65318700E+03, -.59717800E+03, -.47420500E+03, -.59333700E+04, -.25495000E+03, -.17551000E+04, -.12334800E+04, 0.50031800E+03, 0.60295200E+03, 0.15486800E+04, 0.14900300E+04, 0.58509500E+03, -.32631800E+03, -.44577400E+02, 0.19776000E+03, -.11217600E+04, -.65139800E+02, -.17640700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11307700E+00, -.14515800E+00, -.62717900E-01, -.20196200E+00, 0.98317000E-01, 0.17693300E+01, 0.96354400E+00, 0.12410200E+01, 0.85301600E-01, -.65017500E-01, 0.10806800E+00, -.34331000E-01, -.37731900E-01, 0.26898400E+00, -.53849700E+00, 0.10885300E+00, -.38424900E-02, 0.33939700E-01, 0.12839600E-01, -.19931600E+00, 0.13007700E+00, -.22566300E+00, -.17270700E+00, -.34856600E+00, 0.34238100E+00, -.92574800E-01, 0.12294100E+00, 0.84459400E+00, 0.76462900E-01, -.72349700E+00, -.19888100E-01, 0.49377800E+00, 0.17718800E+00, -.94960800E-01, 0.13147700E+00, -.37671500E+00, -.33942200E+00, -.23774900E+00, 0.14263700E+00, 0.21633700E+00, 0.23845500E+01, 0.10579700E+00, -.64482600E-01, -.47776700E+00, -.21375600E+00, -.36301700E-01, 0.50511300E-01, 0.17690100E+00, 0.60363700E+00, 0.72293900E-01, 0.17023500E+03, 0.28290700E+03, -.58312900E+02, -.34377800E+02, -.27796300E+04, 0.13563800E+04, 0.14443500E+04, -.29239100E+03, -.71743300E+03, 0.18077300E+04, 0.19010400E+04, 0.15406600E+04, -.81363000E+03, -.28435200E+04, 0.15008200E+04, 0.14159800E+04, -.68430200E+02, -.17652200E+02, 0.95762200E+03, 0.11518100E+04, 0.13306900E+04, 0.31867700E+03, -.11202500E+05, 0.57175900E+04, 0.56011500E+04, -.71385400E+03, -.15118800E+04, 0.54800300E+04, 0.55711200E+04, 0.54560600E+04, -.84529600E+03, 0.15473400E+04, -.78694300E+03, -.70086500E+03, -.63551100E+03, -.10065200E+03, -.35640600E+03, -.69394600E+03, -.73999400E+03, -.48663200E+03, 0.34384700E+04, -.17270600E+04, -.16886000E+04, 0.69496800E+02, 0.40911200E+03, -.18212900E+04, -.18869300E+04, -.16535900E+04, 0.66330300E+03, -.96339500E+04, 0.49992800E+04, 0.48168800E+04, -.58536200E+03, -.12459400E+04, 0.47267600E+04, 0.48964900E+04, 0.46889000E+04, -.86678800E+03, -.35049100E+04, 0.19203900E+04, 0.16726900E+04, 0.81601900E+02, 0.26530300E+03, 0.18236600E+04, 0.21150800E+04, 0.14652700E+04, 0.42707400E+02, 0.33673800E+03, -.17147400E+03, -.17893900E+03, 0.30543300E+03, -.11696900E+03, -.18290500E+03, -.46611200E+03, 0.11915500E+03, -.36140000E+02, 0.31081900E+04, -.15520300E+04, -.16226900E+04, 0.56466500E+03, 0.56663600E+03, -.17999900E+04, -.20545500E+04, -.15720200E+04, 0.67608900E+03, -.68959800E+04, 0.37105000E+04, 0.33950000E+04, -.78393900E+02, -.41906000E+03, 0.37425600E+04, 0.40312900E+04, 0.32338400E+04, -.64275600E+03, 0.53828700E+03, -.23168500E+03, -.24810100E+03, -.21986500E+01, 0.65393200E+02, -.20111100E+03, -.35221500E+02, -.65307400E+02, -.11173700E+02, 0.42339900E+04, -.21159300E+04, -.21670100E+04, 0.44917800E+03, 0.34645800E+03, -.16642900E+04, -.18416200E+04, -.18928600E+04, -.59461200E+02, 0.48887900E+03, -.24189500E+03, -.20397400E+03, -.62045800E+02, -.15755500E+03, -.46861000E+02, 0.15577500E+02, 0.10595700E+03, -.11670300E+03, 0.10015100E+04, -.52639400E+03, -.51199300E+03, -.23681100E+03, 0.95225800E+02, -.30107500E+03, 0.15558300E+02, 0.11913300E+03, -.72809900E+02, 0.66324200E+03, -.84256500E+03, 0.69052800E+03, 0.69267000E+03, 0.62734000E+03, 0.56415900E+03, -.78006100E+02, 0.52790900E+03, 0.12734100E+04, -.49033800E+03, -.85125800E+03, -.20349600E+03, 0.64210900E+03, 0.32769400E+03, -.14219700E+04, -.11751600E+02, -.48703400E+03, -.84188500E+03, 0.10350500E+04, 0.49171700E+03, 0.84254300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.53215600E+00, 0.85678600E+00, 0.36366400E+00, 0.12709300E+01, -.30743900E+00, -.32153200E+01, 0.14072200E+01, 0.57574400E+00, -.17889000E+00, 0.33717200E+00, -.19325700E+01, -.99947500E+00, -.62169900E-01, 0.24674900E+00, -.20429200E+00, 0.57254200E+00, 0.42383500E-01, 0.33175900E+00, -.11583100E+00, 0.82866400E-01, 0.19607100E+00, -.11922400E+00, -.10989100E+00, 0.61326000E+00, 0.12777100E+00, 0.20050700E+00, -.15330900E-01, -.27121500E+01, 0.30420100E-01, 0.24154000E+00, 0.12598100E+00, -.55673900E+00, -.23553400E+00, 0.17206000E+00, 0.21573700E+00, -.43161800E-01, -.14704900E+00, -.11445900E+00, 0.92698200E-01, 0.34508300E+00, 0.15725800E+01, -.51884600E-01, 0.31512400E+00, -.65827500E+00, 0.76136700E-01, 0.40073400E-02, -.21352500E+00, 0.48198700E-01, -.36331000E+00, -.17427400E+00, 0.55613300E+00, 0.39418800E+03, 0.45304500E+03, 0.18917000E+02, 0.10176400E+04, -.53018500E+03, -.36859000E+03, 0.50153200E+03, 0.59562100E+03, -.93936500E+03, -.75019000E+03, -.58356300E+03, 0.94190900E+03, 0.31073000E+04, -.15180300E+04, -.15529300E+04, -.27126000E+03, -.42680700E+03, -.80618000E+03, -.83197000E+03, -.95536900E+03, -.37162900E+03, 0.43127300E+04, -.19787100E+04, -.21563200E+04, -.63936800E+02, 0.79079100E+03, -.21445500E+04, -.21145000E+04, -.20488700E+04, 0.67997300E+03, -.10903500E+04, 0.53046500E+03, 0.61939200E+03, 0.70421500E+03, 0.12532900E+03, 0.90325800E+02, 0.64300200E+03, 0.56913900E+03, 0.45614500E+03, -.20322100E+04, 0.10070100E+04, 0.97497400E+03, 0.24207700E+02, -.37822900E+03, 0.97134800E+03, 0.78585400E+03, 0.85291500E+03, -.86313700E+02, 0.38406500E+04, -.17634400E+04, -.19238400E+04, -.10475500E+03, 0.75199200E+03, -.18920800E+04, -.18876900E+04, -.18143800E+04, 0.58843700E+03, 0.14963300E+03, -.11337000E+03, -.19147700E+03, 0.10926700E+03, 0.23915700E+03, -.36418500E+03, 0.19643100E+03, 0.23084400E+03, 0.42518300E+03, -.85477400E+03, 0.42879400E+03, 0.53962000E+03, -.16159000E+03, -.21197800E+03, 0.56103300E+03, 0.93156400E+03, 0.30741100E+03, -.25040100E+03, -.23179700E+04, 0.11648600E+04, 0.95259000E+03, -.32665000E+03, -.53802600E+03, 0.13077400E+04, 0.12990400E+04, 0.10719300E+04, -.42033900E+03, 0.19559000E+04, -.91638100E+03, -.10485500E+04, 0.54227700E+03, 0.79028200E+03, -.15440600E+04, -.98897900E+03, -.10396000E+04, 0.12874900E+04, -.36185100E+03, 0.17875700E+03, 0.11614700E+03, 0.42901000E+02, -.46253800E+02, 0.11902900E+03, 0.19939400E+02, -.29380100E+02, 0.94453500E+01, -.52174800E+04, 0.26157300E+04, 0.23826800E+04, 0.22142900E+02, -.47518600E+02, 0.19477300E+04, 0.21868700E+04, 0.20999000E+04, -.17894300E+03, -.33296900E+03, 0.16599500E+03, 0.23866500E+03, 0.76181800E+02, 0.56186600E+02, 0.64540400E+02, 0.77623900E+01, -.83480200E+02, 0.21822300E+01, -.97330000E+03, 0.47474600E+03, 0.49128000E+03, 0.14154100E+03, -.68625500E+02, 0.23392300E+03, -.17224500E+01, -.24076200E+03, 0.85202200E+02, -.47371800E+03, 0.48259000E+03, -.43319700E+03, -.48257000E+03, -.42012100E+03, -.41100900E+03, 0.41094900E+03, -.37917700E+03, -.11859500E+04, -.19669900E+03, 0.63138500E+03, 0.27831600E+03, 0.15579000E+03, -.61072300E+03, 0.10515900E+04, -.72730000E+02, 0.44351700E+03, 0.47687100E+03, -.88789400E+03, -.20402800E+03, -.44831400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13910900E+01, 0.17892100E+01, 0.57747900E+00, 0.29046900E+01, -.78726700E+00, -.49207100E+01, 0.23559800E+01, -.19912900E+01, -.22951400E+00, 0.60727200E+00, 0.79053200E+00, -.88938300E+00, 0.27090000E+00, 0.12502400E+01, -.93992700E+00, 0.75622500E+00, -.17185500E-01, 0.88970400E+00, -.18579200E+00, -.17111500E+00, -.40756300E+00, 0.76756500E+00, 0.50055600E+00, 0.21067000E+00, 0.35668000E+00, 0.13369800E-01, 0.10411000E-01, -.40500900E+00, -.17926600E+00, 0.23480000E-01, 0.48476900E+00, -.85574600E+00, -.87044800E+00, 0.11492600E+00, -.13859700E+00, -.44374700E+00, -.35065700E+00, 0.11765400E+00, 0.24379200E+00, -.11808000E+01, 0.46807700E+01, 0.30132800E+00, 0.94260500E+00, -.92016500E+00, 0.34762200E+00, 0.80069100E-01, -.38773200E+00, 0.32331300E+00, -.16936900E+00, 0.13957100E+00, 0.19308700E+01, 0.34741400E+00, 0.10320300E+04, 0.35770400E+02, 0.59957300E+04, -.29543700E+04, -.30549300E+04, 0.10814800E+03, 0.13318900E+04, -.32129300E+04, -.29513200E+04, -.20684400E+04, 0.16539900E+04, 0.36033700E+04, -.19221000E+04, -.17698900E+04, 0.18440100E+03, 0.54087400E+03, -.14940900E+04, -.14802400E+04, -.17220900E+04, -.31088200E+02, 0.16992200E+05, -.87217900E+04, -.84965800E+04, 0.12379800E+04, 0.22689600E+04, -.82701700E+04, -.81406600E+04, -.82458100E+04, 0.19165400E+04, -.24211800E+04, 0.12298800E+04, 0.13794200E+04, 0.93504700E+03, -.32861800E+03, 0.10208200E+04, 0.15559300E+04, 0.20176400E+04, 0.59014700E+03, -.66148400E+04, 0.33219700E+04, 0.33901900E+04, -.34345200E+03, -.86418900E+03, 0.34182400E+04, 0.32463900E+04, 0.27909800E+04, -.11693900E+04, 0.13982000E+05, -.73294800E+04, -.69888700E+04, 0.95342200E+03, 0.18227800E+04, -.68418200E+04, -.68488400E+04, -.67989500E+04, 0.17308100E+04, 0.36199600E+04, -.19734600E+04, -.18325800E+04, 0.66528100E+03, 0.16523400E+04, -.27669000E+04, -.26358700E+04, -.50148400E+03, 0.15663500E+04, 0.61047400E+03, -.29679800E+03, -.46327000E+03, -.80684900E+03, -.96840600E+02, 0.21097700E+02, 0.46401200E+03, -.63299100E+03, -.37467600E+03, -.60183400E+04, 0.30091400E+04, 0.31380300E+04, -.87582800E+03, -.13892100E+04, 0.34122700E+04, 0.36651800E+04, 0.24845400E+04, -.15345700E+04, 0.12401200E+05, -.65180100E+04, -.62018100E+04, 0.59314800E+03, 0.29504700E+04, -.70959900E+04, -.61660600E+04, -.40628900E+04, 0.29824000E+04, -.15924600E+04, 0.73498000E+03, 0.79710800E+03, 0.62110900E+02, -.63753100E+02, 0.53676800E+03, 0.53502000E+02, 0.24731500E+03, 0.70760300E+02, -.40643900E+04, 0.20371500E+04, 0.21265000E+04, -.83866200E+03, -.71588200E+03, 0.20472400E+04, 0.23737700E+04, 0.20919100E+04, -.45549300E+03, 0.41251500E+02, -.21780300E+02, -.14681800E+03, -.26288900E+02, -.17348300E+03, 0.15156300E+03, 0.29315000E+03, -.19430600E+03, -.22837200E+03, -.24039000E+04, 0.12388900E+04, 0.11987700E+04, 0.34276000E+03, 0.13533700E+03, 0.56651800E+03, -.22208900E+03, 0.14365300E+03, 0.32292600E+03, -.13312400E+04, 0.14696100E+04, -.11600100E+04, -.11646300E+04, -.10679300E+04, -.10002400E+04, 0.11820000E+04, -.10576100E+04, -.13832100E+04, 0.37877500E+03, 0.14136200E+04, 0.32457100E+03, -.68171500E+03, -.21320900E+04, 0.19397000E+04, 0.42596800E+02, 0.14522100E+04, 0.14740700E+04, -.11965900E+04, -.70665000E+03, -.14807300E+04, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.47570500E+00, -.40884700E+01, 0.41435800E+00, -.15428000E+00, -.33109800E+00, 0.90429900E+00, 0.68306500E+01, -.15100500E+01, 0.15051300E+00, 0.12283100E+00, 0.13774000E+01, -.94100500E-01, 0.45110400E+00, 0.56501500E+00, -.65694200E+00, 0.31920200E+00, 0.23203900E-02, 0.25833800E+00, 0.58868900E+00, 0.19688300E+00, -.10841500E+00, 0.36915900E-01, 0.25757300E+00, 0.25304300E+00, -.36018200E+00, -.17832800E-01, 0.16599900E-01, 0.74186600E+01, 0.66363100E-01, -.87097000E-01, 0.18076500E+00, 0.43624800E+00, 0.54086000E+00, 0.11019600E+00, -.12371300E+00, 0.71871000E+00, 0.37917300E+00, -.66620100E+00, 0.14674300E+00, 0.50063600E+00, -.11495500E+01, 0.12877100E+00, -.33559200E+00, 0.13221500E+00, 0.18649600E+00, -.95550100E-02, 0.19595900E+00, 0.68141600E-01, -.54468200E-01, 0.12119000E+00, -.16941700E+00, -.18696800E+00, -.43161800E-02, 0.42776200E+02, -.61051600E+03, 0.28584300E+03, 0.36054600E+03, -.11156600E+02, -.29816100E+02, 0.45873900E+03, 0.66954200E+03, 0.64291500E+03, -.10876200E+02, 0.28252200E+03, -.98331000E+02, -.14604900E+03, -.10372900E+03, -.11142000E+02, -.67143000E+02, 0.12784400E+03, -.77036500E+02, -.16222400E+03, -.43532800E+04, 0.23386400E+04, 0.21798800E+04, -.53040100E+03, -.32430500E+03, 0.21820800E+04, 0.23913000E+04, 0.21580800E+04, -.20588900E+02, 0.86413900E+01, -.13243200E+02, 0.51390500E+02, 0.41304700E+02, 0.56528500E+02, 0.23486500E+02, 0.83198100E+02, 0.10164100E+03, 0.63662800E+02, 0.61540300E+03, -.31609800E+03, -.28561000E+03, 0.16701800E+02, 0.85161600E+02, -.34455500E+03, -.34772900E+03, -.39463500E+03, -.16821100E+03, -.36351100E+04, 0.19594900E+04, 0.18138800E+04, -.43680800E+03, -.27883100E+03, 0.18014900E+04, 0.19963100E+04, 0.17966400E+04, 0.14404600E+03, -.12135500E+04, 0.57093100E+03, 0.53774200E+03, -.17393700E+03, -.65780100E+02, 0.52391000E+03, 0.50502100E+03, 0.59313100E+03, 0.23083500E+03, 0.53565900E+02, -.28636800E+02, -.26094000E+02, -.26448800E+02, -.11230900E+03, 0.34954600E+02, -.46467400E+02, 0.13156200E+03, -.94276000E+02, 0.82415800E+03, -.41152200E+03, -.47908700E+03, 0.10950400E+03, 0.26231600E+02, -.48345500E+03, -.60070800E+03, -.58226500E+03, -.19242500E+03, -.19496900E+04, 0.10458500E+04, 0.92122100E+03, -.27078600E+03, 0.18693200E+02, 0.10202500E+04, 0.12581700E+04, 0.10923700E+04, 0.98416800E+02, 0.55929300E+02, -.73750500E+01, -.71597000E+01, 0.11001500E+02, 0.59802800E+01, -.23081100E+02, -.22047600E+02, 0.76495300E+01, 0.73599300E+01, -.30722300E+03, 0.15202500E+03, 0.10343800E+03, 0.13052600E+03, -.37279300E+02, 0.92795600E+02, -.16744500E+03, 0.19115900E+03, 0.13440800E+03, 0.81461200E+02, -.39497300E+02, 0.78312900E-02, 0.36979700E+02, 0.15385600E+02, -.49989400E+02, -.65198900E+02, -.39853700E+01, 0.15223200E+02, 0.28539100E+03, -.15487600E+03, -.15329900E+03, -.11823300E+03, -.88306200E+02, -.37860000E+02, -.10077800E+01, 0.11771000E+02, -.59632900E+02, 0.27084400E+03, -.34159200E+03, 0.24044100E+03, 0.24825800E+03, 0.20896200E+03, 0.20732400E+03, 0.30057600E+03, 0.10706600E+03, 0.25512600E+03, -.49799200E+03, -.22951800E+03, -.15899400E+03, 0.58293500E+03, -.29187800E+03, -.41590400E+03, 0.78597500E+02, 0.56945800E+02, -.34522700E+03, 0.31836200E+03, 0.11171800E+03, 0.35566300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18322900E+01, -.11314400E+01, 0.11369400E+01, 0.40414300E+00, -.42409600E+00, -.23716300E+01, -.28163100E+01, -.58340600E-01, -.12749400E+00, -.85897400E-01, -.19875400E+01, -.20281400E+00, -.25857600E+00, -.41260400E+00, 0.39846200E+00, 0.16283700E+00, 0.62501300E-02, -.70625500E+00, 0.20533500E+00, -.18761200E+00, -.71782900E-01, -.80603200E-01, -.74978000E-01, 0.39372800E-01, 0.10171200E+00, -.64955400E-01, 0.65684900E-01, -.13141600E+01, -.12492500E+00, 0.21291900E+00, -.67469700E-01, 0.18582700E+00, -.15082400E+00, -.49876900E-01, -.35417300E-01, -.18238200E+00, -.21203000E+00, 0.12756600E+00, 0.36133400E+00, 0.33041800E+00, 0.21597400E+01, -.65284300E-01, 0.24222700E+00, -.23828100E+00, -.50385300E-01, 0.11759800E+00, -.20996100E+00, 0.88173600E-01, 0.45207700E+00, -.69387700E-01, 0.64607900E+00, -.82228500E-01, -.14453700E+00, -.99414200E-01, 0.19692500E+04, -.94546500E+03, -.10432300E+04, -.13700100E+03, 0.43094400E+03, -.81571000E+03, -.44488100E+03, -.81459000E+03, 0.38797600E+03, 0.21272700E+04, -.11369300E+04, -.10414100E+04, 0.70001200E+02, 0.18470900E+03, -.80616500E+03, -.78931700E+03, -.10754800E+04, 0.11213000E+03, 0.35653300E+04, -.21202200E+04, -.17825400E+04, 0.40585000E+03, 0.93425700E+03, -.18661200E+04, -.20029300E+04, -.19440400E+04, 0.59716300E+03, -.88792200E+03, 0.45844200E+03, 0.49475100E+03, 0.43255100E+03, 0.97983300E+02, 0.17200300E+03, 0.24390400E+03, 0.16441400E+03, 0.32585400E+03, -.13508200E+04, 0.69120600E+03, 0.69071800E+03, 0.14457100E+03, -.34565600E+03, 0.62767900E+03, 0.52903500E+03, 0.60848100E+03, -.15043600E+02, 0.31833700E+04, -.17914200E+04, -.15906700E+04, 0.35963100E+03, 0.86948400E+03, -.16125400E+04, -.17209900E+04, -.16510200E+04, 0.42006300E+03, 0.32109200E+03, -.33503500E+02, -.10867800E+03, 0.47375500E+02, 0.15905300E+03, -.26328200E+03, -.27983500E+03, -.86668900E+02, 0.84177800E+02, -.96199700E+03, 0.48193100E+03, 0.39406100E+03, -.17674700E+03, -.89641600E+02, 0.42385200E+03, 0.47233200E+03, 0.29161200E+03, -.88354700E+02, -.24478600E+04, 0.12189700E+04, 0.13234000E+04, -.12376200E+03, -.41950900E+03, 0.11044900E+04, 0.94953400E+03, 0.11032500E+04, -.15602800E+03, 0.25514900E+04, -.13540800E+04, -.12254400E+04, -.10691900E+03, 0.52784800E+03, -.13736600E+04, -.10309800E+04, -.10824100E+04, 0.55221900E+03, -.40345000E+03, 0.17962200E+03, 0.20034100E+03, 0.36321700E+02, -.21259700E+02, 0.14619800E+03, 0.15875100E+01, 0.15217000E+03, 0.31746300E+02, -.35986400E+04, 0.17899400E+04, 0.18728900E+04, -.18599800E+03, -.39932800E+03, 0.14597700E+04, 0.13377900E+04, 0.16781200E+04, -.31955600E+03, -.57007100E+03, 0.28249600E+03, 0.20242400E+03, 0.36305900E+02, 0.90477600E+02, 0.15264900E+03, -.17062400E+03, -.30007800E+02, 0.89226700E+02, -.71434700E+02, 0.56193000E+02, 0.40311200E+02, 0.15006100E+03, 0.65758200E+02, 0.33359900E+02, 0.94637400E+02, -.10891200E+03, 0.90638400E+01, -.52142400E+03, 0.36849500E+03, -.47543500E+03, -.41593300E+03, -.42467200E+03, -.39202000E+03, 0.57054800E+03, -.93531400E+02, -.60923500E+03, 0.44657700E+02, 0.49514800E+03, 0.30309200E+03, -.20662500E+03, -.48260800E+03, 0.62792000E+03, 0.11073200E+02, 0.34434300E+03, 0.39160200E+03, -.42841500E+03, -.34133600E+03, -.39773100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18460400E+01, -.13733500E+01, 0.10335400E+00, -.28732000E+01, -.19017500E+00, 0.12853200E+02, -.29983800E+01, 0.41198500E+00, 0.61892700E+00, -.12433600E+01, -.14238400E+01, 0.15484300E+01, -.56648000E+00, -.89748900E+00, 0.10047700E+00, -.71869700E+00, -.26093600E-01, -.41741400E+00, 0.11202100E+01, -.67708700E-01, -.11149600E+00, -.64695400E+00, -.17361500E+00, -.86843500E+00, -.54209300E+00, -.66291900E+00, 0.23121300E+00, 0.69080800E+01, -.39479400E+00, 0.10162000E+01, -.94552900E-01, -.69933200E-01, -.28177800E+00, -.56850200E+00, -.47147700E+00, -.52604600E+00, 0.25054900E+00, 0.10391100E+01, -.13992900E+01, -.30937500E+01, -.11994100E+02, 0.41489000E+00, -.12639600E+01, -.58348200E+00, 0.99562100E+00, -.12465600E+01, 0.89687900E+00, 0.12200100E+01, 0.19478300E+01, 0.10994700E+01, 0.18516200E+01, 0.10160800E+01, 0.92153500E+00, -.13899300E+00, -.32021600E+01, 0.24965200E+03, -.35561500E+03, 0.12433000E+04, 0.72972500E+03, -.11888100E+04, -.25770800E+04, -.19669400E+04, 0.38560200E+03, -.26353300E+04, 0.67533100E+03, 0.12783400E+04, 0.93737800E+01, -.21533900E+03, 0.10941300E+04, 0.67142000E+03, 0.12049600E+04, -.62919200E+03, -.14378700E+04, -.14307600E+04, 0.72223500E+03, 0.96356400E+03, -.17335300E+04, 0.21759600E+03, -.14001200E+04, -.14278300E+03, -.35103200E+03, -.40893400E+03, 0.31220600E+03, -.60608600E+03, -.85021700E+03, 0.28330500E+03, -.10276700E+03, -.96817200E+03, -.12921700E+03, 0.12565500E+02, -.14255800E+04, 0.84052000E+03, 0.41820300E+03, -.86246100E+03, 0.19250300E+03, 0.59281300E+03, 0.12646200E+04, 0.81390300E+03, -.12406700E+04, -.15495000E+04, -.10334500E+04, 0.79240800E+03, 0.91671900E+03, -.16425900E+04, 0.33576900E+03, -.10441200E+04, 0.28911500E+02, 0.31677300E+02, 0.59473900E+03, -.19287700E+03, 0.33022400E+03, 0.75753500E+03, -.55496600E+03, 0.61682300E+03, -.24063200E+03, -.68956500E+03, -.39346500E+03, 0.11083500E+04, -.53184300E+03, -.22954000E+03, 0.22378400E+03, 0.92323400E+02, -.55340100E+03, -.80858500E+03, -.36745000E+03, 0.22128200E+03, 0.23581800E+04, -.11601000E+04, -.90116000E+03, -.59472000E+03, -.52607500E+03, -.56968700E+03, 0.59222100E+03, -.23897100E+03, -.12487800E+04, -.43767900E+04, 0.87723500E+03, 0.25683000E+04, 0.19872400E+04, -.12113100E+04, 0.21212900E+04, -.12641200E+04, 0.34404800E+03, -.10745000E+04, -.16841900E+04, 0.61138200E+03, 0.74833900E+03, -.45138500E+03, 0.19651800E+01, 0.53286000E+03, -.30524600E+03, 0.50075900E+03, 0.13484000E+03, 0.63061500E+04, -.31516500E+04, -.28809200E+04, -.27811800E+03, -.25781200E+03, -.27014700E+04, -.24635100E+04, -.27873800E+04, 0.11450200E+04, -.97314500E+03, 0.46501700E+03, 0.49181100E+03, 0.36703800E+03, 0.47415300E+03, 0.10549600E+03, -.12732300E+03, -.59142500E+03, 0.31539100E+03, -.10809000E+04, 0.71906200E+03, 0.61758900E+03, -.62848000E+03, 0.35492900E+03, 0.39251000E+03, -.58079400E+03, 0.75951500E+03, 0.41061600E+03, 0.58476300E+03, 0.37858900E+03, 0.83480100E+02, 0.37092200E+03, -.18674900E+02, 0.28904400E+03, -.14888500E+04, -.86407600E+03, 0.26409600E+03, 0.30369900E+04, -.39241200E+03, -.59813200E+03, -.34342500E+04, 0.28550600E+04, -.40284100E+03, -.23426700E+03, -.99671700E+03, 0.33470300E+03, 0.31897700E+03, 0.23634900E+03, -.51970800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15489700E+01, -.18946900E+00, -.92802100E+00, -.20136600E+01, 0.99099700E+00, 0.97761500E+01, 0.53190600E+01, 0.18332900E+01, 0.61064300E+00, -.12580400E+00, 0.23071600E+00, 0.88780500E+00, -.74062300E+00, -.46080300E+00, 0.51243300E+00, -.41781900E+00, -.17291600E+00, -.50080200E+00, -.25402700E+00, -.34777700E-01, -.10546600E+00, 0.13220700E+00, -.99472500E-01, -.16519600E+01, 0.33492900E-01, -.28756000E+00, -.23595700E+00, 0.45855500E+01, -.75980600E-01, 0.69811500E+00, -.23770400E+00, 0.35019400E+00, 0.60489700E+00, 0.75418300E-01, 0.74451600E-01, 0.13766100E+01, 0.46750200E+00, -.20302000E+00, 0.15908100E+01, 0.23833400E+01, 0.22241200E+01, -.29864100E+00, -.43917300E+00, 0.20245500E+01, 0.36213200E+00, -.46738700E+00, -.40662800E+00, -.20075000E+00, -.73990200E+00, -.93624300E+00, -.14029000E+01, -.31765900E+00, -.12440500E+00, -.19999300E+01, -.37606400E+00, -.36245500E+00, 0.33686900E+03, 0.29968800E+03, 0.91444000E+03, 0.33476100E+03, 0.16076700E+04, 0.66431800E+03, 0.67031400E+03, 0.46108500E+04, -.23009900E+04, -.23007800E+04, -.58103400E+03, -.30073500E+03, -.11747100E+04, -.20154800E+03, -.12478600E+04, -.79630400E+03, -.70342200E+04, 0.36337500E+04, 0.35243900E+04, -.11211200E+04, -.10819700E+04, 0.35209200E+04, 0.38859200E+04, 0.33895000E+04, 0.49355400E+02, 0.11078800E+03, -.59754500E+02, 0.22285300E+03, 0.25708700E+03, 0.43994100E+03, -.43112700E+03, 0.18877100E+02, -.49845000E+03, 0.43783000E+03, 0.44468700E+03, -.22757100E+03, -.26418100E+03, -.70275100E+02, 0.95492000E+02, -.72252600E+03, -.95084000E+03, -.68164800E+03, -.25092900E+03, -.61629700E+04, 0.32343700E+04, 0.30732200E+04, -.98925300E+03, -.88038300E+03, 0.30224100E+04, 0.32797500E+04, 0.29838500E+04, 0.33145400E+03, -.48500600E+04, 0.22735400E+04, 0.21212000E+04, 0.50759100E+02, 0.41278600E+03, 0.16627200E+04, 0.13298100E+04, 0.20531400E+04, 0.92584800E+03, -.16050700E+04, 0.79983600E+03, 0.98219200E+03, -.53595000E+02, -.40078200E+03, 0.85579500E+03, 0.62929900E+03, 0.12477800E+04, -.23111100E+03, -.53870200E+02, 0.22785800E+02, -.47446100E+03, 0.18429500E+03, -.41553400E+03, -.49504900E+03, -.12058100E+04, -.46336900E+03, -.48803200E+03, -.45898200E+04, 0.22225500E+04, 0.21022900E+04, 0.33118800E+03, 0.13873200E+04, 0.18253200E+04, 0.26935400E+04, 0.18158200E+04, 0.14422800E+04, -.61193900E+03, 0.31888400E+03, 0.22630300E+03, 0.82395700E+02, 0.57878000E+02, 0.17846200E+03, -.73431300E+02, 0.31485900E+03, 0.12816900E+03, -.70155900E+04, 0.34883000E+04, 0.29984300E+04, 0.61311600E+03, -.88127400E+01, 0.20975900E+04, 0.69991700E+03, 0.26479800E+04, 0.70609500E+03, -.37020900E+03, 0.18175300E+03, 0.39031700E+03, 0.13994400E+03, 0.38534300E+02, 0.16535700E+03, -.42763400E+03, -.19803400E+03, 0.26192700E+02, 0.69413700E+03, -.34261500E+03, -.35198000E+03, -.46915200E+02, 0.87563500E+02, -.13540300E+03, 0.17250100E+03, -.26676200E+02, 0.79529900E+01, 0.17225600E+03, -.56942000E+03, 0.19434300E+03, 0.26126100E+03, 0.26854200E+02, 0.23951300E+03, 0.71731100E+03, 0.37056000E+03, -.27586300E+03, -.17505300E+04, -.21740900E+03, -.15906900E+03, 0.19592500E+04, -.73404500E+03, -.62367500E+03, 0.15028600E+03, 0.18694100E+03, -.53564900E+03, 0.35689800E+03, -.90230700E+01, 0.54593200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.10863800E+01, 0.99398800E+00, 0.30678300E+00, 0.21334800E+01, -.10811000E+00, -.64528100E+01, -.43332800E+00, 0.19248200E+00, -.34089900E+00, 0.50345900E+00, 0.10237800E+00, -.81650700E+00, 0.25723200E+00, 0.48973600E+00, -.18990100E+00, -.74213200E-01, 0.67297800E-02, 0.43967400E+00, -.29505200E+00, 0.21153600E+00, -.20070200E-01, 0.31842400E+00, 0.27221800E+00, 0.30825700E+00, 0.18982000E+00, 0.98727500E-01, 0.20263400E+00, 0.30298300E+01, 0.28182500E+00, 0.10526300E+01, 0.28547300E+00, -.96405500E+00, -.75817900E+00, 0.10099900E+00, -.35420200E+00, -.61860800E+00, -.24594600E-02, 0.57330200E+00, -.97343700E+00, -.20556300E+01, -.55448600E+01, -.18420800E-01, -.62228100E+00, -.10916100E+00, 0.29707400E+00, -.23798500E+00, -.68245700E-01, 0.11728200E+00, -.43178000E+00, -.74045600E-01, 0.78064900E-01, -.50867800E-01, -.25610300E+00, -.35014400E+00, 0.29335000E+01, -.25850400E+00, 0.32834600E+00, 0.83345400E+03, -.11134900E+04, -.30352400E+03, -.19948700E+04, -.64789500E+03, -.10214600E+04, -.53562700E+04, 0.26433500E+04, 0.25911700E+04, 0.11722400E+04, 0.10836500E+04, 0.86930800E+03, 0.24245600E+03, 0.19643100E+04, 0.38314500E+02, 0.69509300E+04, -.30958700E+04, -.34766200E+04, -.52117200E+02, -.23407000E+04, -.30135800E+04, -.36033900E+04, -.28001300E+04, -.10444300E+04, 0.83465300E+03, -.40436600E+03, -.75281500E+03, -.13319300E+04, -.24602400E+03, 0.39387400E+03, 0.99677600E+02, -.36599900E+03, -.67320300E+03, -.20644200E+04, 0.10199800E+04, 0.10251200E+04, -.11198300E+04, 0.68216800E+03, 0.12735000E+04, 0.17257900E+04, 0.13667800E+04, -.20911700E+04, 0.50532700E+04, -.26942100E+04, -.25240100E+04, -.83480000E+02, -.24399000E+04, -.24925900E+04, -.33130200E+04, -.23536500E+04, 0.59903700E+02, 0.52328700E+04, -.32748400E+04, -.26124200E+04, 0.68437900E+03, -.42503800E+03, -.23188800E+04, -.19669900E+04, -.27059600E+04, 0.14531100E+03, 0.27640000E+04, -.13813100E+04, -.12075900E+04, 0.42070400E+03, 0.50878400E+03, -.13526700E+04, -.96288600E+03, -.95379400E+03, 0.52468900E+03, 0.33411800E+04, -.16669600E+04, -.16943800E+04, -.44809500E+03, 0.77000400E+03, -.13695500E+04, -.45526500E+03, -.14111100E+04, -.86280100E+03, 0.32175300E+04, -.20801600E+04, -.17188600E+04, 0.14693100E+04, -.14270900E+04, -.14603600E+04, -.28859800E+04, -.20485100E+04, -.14411200E+04, 0.50935800E+03, -.29405200E+03, -.15123800E+03, -.15630200E+03, 0.53762500E+01, -.15807900E+03, 0.87388200E+02, -.24100100E+03, -.75611200E+02, 0.83325000E+04, -.41522200E+04, -.40702300E+04, -.10640500E+04, -.77730800E+03, -.25624800E+04, -.18068100E+04, -.34443300E+04, 0.10101600E+04, 0.14756200E+04, -.73548800E+03, -.55253300E+03, -.36889200E+03, -.46014500E+03, -.66059600E+02, 0.82441100E+03, -.25759900E+03, -.53096900E+03, 0.11854600E+04, -.56747600E+03, -.62075400E+03, 0.11050500E+03, -.42216200E+02, -.65333300E+03, -.80043600E+02, 0.26067800E+03, 0.27042600E+03, 0.40465700E+03, 0.22279100E+03, 0.54271100E+03, 0.20796800E+03, 0.36635700E+03, 0.53889900E+03, -.32696400E+04, -.19071200E+03, 0.66021600E+03, 0.89578600E+03, -.48941900E+03, -.10464700E+04, -.61530500E+03, 0.28075800E+04, -.32729500E+03, 0.31008000E+03, -.14360800E+04, 0.14761300E+03, 0.81505000E+02, 0.62894200E+03, -.18252700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.38170500E+01, 0.87126800E-01, 0.24787900E+01, 0.54196800E+01, -.26560900E+01, -.32831400E+02, -.19565900E+02, -.26995100E+01, -.20238600E+01, 0.38905300E+00, -.25362900E+01, -.20256300E+01, 0.10349800E+01, -.92448200E-02, 0.12433500E+00, 0.44792900E+00, 0.49651800E+00, 0.79657200E+00, 0.52980200E+00, 0.56937800E+00, -.40169700E-01, -.11243600E+00, 0.46337300E+00, 0.29016800E+01, 0.83889200E-01, 0.88872900E+00, 0.11602500E+01, -.13128600E+02, 0.16032000E+00, 0.34595300E+01, 0.74122800E+00, -.18823900E+01, -.63649100E+00, 0.33458000E+00, 0.99886200E+00, -.79918500E+00, -.41905000E+00, 0.35889300E+00, -.86667100E+00, -.23687000E+01, -.25597600E+01, 0.16820700E+00, -.22675700E+01, 0.29911900E+00, 0.10678200E+01, 0.50343500E-02, 0.43345400E+00, -.95469200E-01, -.19960600E+01, 0.75413700E+00, -.17725800E+01, -.35483100E+00, -.26072700E+00, 0.11340400E+01, -.11252800E+01, 0.58743700E+00, 0.12697500E+00, -.18640000E+01, -.36567900E+04, 0.34046500E+03, -.33111400E+04, -.27579100E+03, -.25140900E+04, -.95195400E+04, 0.47302400E+04, 0.46059900E+04, 0.24589900E+04, 0.24174100E+04, 0.87778300E+03, -.46647700E+03, 0.33288600E+04, 0.10704400E+04, 0.24389000E+05, -.11200300E+05, -.12203600E+05, -.35018500E+02, -.19372500E+04, -.10886700E+05, -.11697400E+05, -.10258400E+05, -.11961600E+04, 0.28717700E+03, -.10488100E+03, -.32591100E+03, -.18447000E+04, -.82801600E+03, 0.14224500E+04, 0.10285700E+04, 0.18019400E+02, -.10536200E+04, -.50207900E+04, 0.24697900E+04, 0.28684800E+04, -.18001100E+04, 0.81857800E+03, 0.33068600E+04, 0.42082700E+04, 0.32414700E+04, -.27949500E+04, 0.18550800E+05, -.94936500E+04, -.92757400E+04, -.26282500E+03, -.22748900E+04, -.89666900E+04, -.10394900E+05, -.84471400E+04, 0.62055000E+03, 0.90242000E+04, -.59911300E+04, -.47821300E+04, 0.99763000E+03, -.70907100E+03, -.50420500E+04, -.40149700E+04, -.46277200E+04, 0.41136600E+03, 0.49011300E+04, -.24581900E+04, -.26303700E+04, 0.50768400E+03, 0.11748800E+04, -.23402000E+04, -.70618900E+03, -.22342700E+04, 0.84032500E+03, 0.28116100E+04, -.14188500E+04, -.11867400E+04, -.42970100E+03, 0.19806000E+04, -.11861600E+04, 0.61768300E+03, -.15695900E+04, -.43380300E+03, 0.81116500E+04, -.49818600E+04, -.44985000E+04, 0.12247400E+04, -.34205100E+04, -.45294900E+04, -.63653500E+04, -.37489400E+04, -.23804000E+04, 0.58347000E+03, -.36761700E+03, 0.19051500E+03, -.12639300E+03, -.18130100E+03, -.12762400E+03, 0.27119900E+03, -.39725400E+03, -.24370300E+03, 0.10446400E+05, -.52122500E+04, -.46934400E+04, -.26587800E+04, -.20116500E+04, -.19787500E+04, -.30414600E+02, -.41727500E+04, 0.80114400E+02, 0.35059200E+04, -.17399600E+04, -.15383700E+04, -.10534500E+04, -.12166800E+04, -.81068500E+02, 0.17167900E+04, -.79347700E+02, -.12599300E+04, 0.26616800E+04, -.12778100E+04, -.14827500E+04, 0.77155200E+03, -.64499200E+03, -.13106500E+04, 0.48911300E+03, 0.32539500E+03, -.26162500E+03, 0.41995500E+02, 0.40934300E+03, 0.79745900E+03, -.22185000E+03, 0.46987200E+03, 0.54203600E+03, -.51457200E+04, -.58847400E+03, 0.44564900E+03, 0.61957700E+03, -.29164600E+03, -.14413900E+04, -.25045300E+02, 0.36601500E+04, 0.11147400E+04, 0.42470400E+03, -.17902300E+04, 0.25326300E+03, -.95938600E+03, 0.75083300E+03, -.40651600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.80471000E+00, -.53211200E+00, 0.58708700E+00, 0.10710800E+01, -.15939300E+00, -.24743600E+01, -.16985800E+01, -.46391200E+00, -.13295100E+00, 0.57455600E-01, -.50629300E+00, -.23261600E+00, 0.11317200E+00, 0.39586400E+00, -.60518800E-01, 0.16790100E+00, 0.22891700E-01, 0.11938100E+00, 0.11503200E-01, 0.96730600E-02, -.33509600E-01, 0.11572000E-01, 0.10727200E+00, -.49981700E+00, 0.43469700E+00, -.25908000E+00, 0.20572000E+00, -.19573100E+00, -.43830000E-01, 0.47524200E+00, -.63049400E-01, -.15511200E+00, -.46672000E-01, 0.44718500E-02, 0.26051000E+00, -.21004100E+00, -.10902700E+00, 0.25436000E+00, 0.54575200E+00, 0.91880500E+00, 0.42639500E+01, -.60942200E-01, -.81893100E+00, 0.13433900E+00, 0.48060000E+00, -.43193700E+00, -.11706300E+00, 0.26454000E+00, -.39235500E+00, 0.10858200E-01, -.30341700E+00, -.46204800E+00, -.19400300E-01, -.48428300E+00, 0.48115000E-01, -.45598500E-01, 0.18191600E+00, 0.19236600E+00, -.34377500E-01, -.28137100E+03, -.62529200E+03, -.22274400E+03, 0.13163000E+03, 0.55970200E+03, -.28070200E+03, -.28670200E+03, -.11355500E+03, -.37028700E+03, -.40974900E+02, -.31332400E+03, -.83572300E+02, -.54189600E+02, 0.39731100E+04, -.19905000E+04, -.19864100E+04, -.19046800E+03, 0.78124000E+03, -.20213700E+04, -.21360700E+04, -.19638000E+04, 0.14306700E+03, -.39580600E+03, 0.19861600E+03, 0.27232000E+03, 0.33173200E+03, 0.11360800E+02, 0.28225900E+02, 0.22091500E+02, 0.95317400E+02, 0.13580300E+03, -.43299400E+03, 0.21680100E+03, 0.30662500E+03, 0.36674300E+03, -.26311600E+03, 0.33244900E+03, 0.43116600E+03, 0.24606600E+03, 0.31512100E+03, 0.39643600E+04, -.19673500E+04, -.19853800E+04, -.11628600E+03, 0.75426400E+03, -.19725000E+04, -.20358100E+04, -.19211600E+04, 0.15141000E+03, 0.59906100E+03, -.28449200E+03, -.36285600E+03, -.19775800E+03, -.10949300E+03, -.41701400E+03, -.40946200E+03, -.26385900E+03, -.10186900E+03, -.44527200E+03, 0.22207600E+03, 0.14979700E+03, 0.47996900E+02, 0.70359200E+02, 0.20745500E+03, 0.48122200E+03, -.11670100E+03, -.50380100E+01, -.13576500E+04, 0.67834100E+03, 0.71206900E+03, 0.26768500E+02, -.15790300E+03, 0.79208200E+03, 0.10363000E+04, 0.75556400E+03, 0.16276100E+03, 0.12356000E+04, -.60147100E+03, -.67987600E+03, -.42952400E+03, -.93595000E+02, -.92053000E+03, -.98621200E+03, -.66470500E+03, -.30527900E+01, -.23277700E+03, 0.11146600E+03, 0.17055000E+03, 0.14678600E+01, -.58997800E+02, 0.79779600E+02, 0.41114900E+01, 0.27320400E+01, -.95023500E+01, -.17590200E+04, 0.87947100E+03, 0.94210700E+03, 0.50290500E+02, 0.19287500E+03, 0.70797400E+03, 0.11787100E+04, 0.55594000E+03, -.24868900E+03, -.26747900E+03, 0.13413200E+03, 0.13065400E+03, 0.61504200E+01, 0.11678300E+03, 0.37880200E+02, 0.10436300E+02, 0.13785600E+02, 0.97384400E+02, -.64060000E+03, 0.32043900E+03, 0.29970500E+03, 0.72741500E+02, -.13117000E+03, 0.18025700E+03, -.55600500E+02, -.11196100E+03, -.78025300E+02, -.32401700E+03, 0.37147800E+03, -.33150800E+03, -.32644500E+03, -.29015200E+03, -.34557000E+03, 0.62840500E+03, -.37352500E+03, -.74845900E+03, -.33581900E+03, 0.37040800E+03, 0.36066600E+03, 0.34108800E+03, -.68268400E+03, 0.83251900E+03, -.23661400E+03, 0.51018500E+03, 0.35254600E+03, -.74754700E+03, -.23428600E+03, -.35487700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12453100E+01, 0.19108000E+01, 0.80716900E+00, 0.15270200E+01, -.11766200E+01, -.95722800E+00, 0.30530000E+00, -.21160700E+01, -.11527800E+00, -.19120500E+00, -.90093100E+00, -.12918300E+00, 0.12477000E+00, 0.17195600E+00, -.44608800E+00, 0.49948600E+00, 0.95893900E-01, 0.59489200E+00, 0.11237500E+00, -.58026400E+00, -.11135900E+00, 0.37571200E+00, -.49128300E-01, -.34998800E-01, -.19498700E-01, 0.96728000E-01, -.63276500E-01, -.31838800E+00, -.19595300E+00, 0.81465100E+00, 0.20110100E+00, 0.18051800E+00, 0.32371100E+00, -.16856000E-01, 0.29692000E+00, 0.20844200E+00, -.36755300E-01, -.39575300E+00, 0.36613700E+00, 0.29720300E+00, 0.22831000E+01, 0.92531000E-01, -.44990600E+00, 0.81339100E-01, -.46822300E-01, 0.13251900E+00, 0.11167700E+00, -.68000300E-01, -.15703100E+00, 0.26150000E+00, -.48352700E+00, -.29482800E+00, 0.15196600E+00, 0.76785400E+00, -.10795100E+01, -.41853100E-01, -.18095500E+00, -.17030200E+00, -.54036300E-02, 0.62120800E+00, -.33552900E+03, -.25834800E+03, -.64092800E+02, -.16168400E+04, 0.79793600E+03, 0.82081000E+03, 0.14227200E+03, 0.20955700E+03, 0.39594800E+03, 0.22630700E+03, 0.68635800E+03, 0.35347000E+03, -.21984300E+04, 0.11004500E+04, 0.10980300E+04, 0.14232400E+03, -.25361300E+03, 0.97744100E+03, 0.69947500E+03, 0.98920100E+03, -.37328200E+02, 0.16664100E+03, -.87002600E+02, -.14708100E+03, -.25155900E+03, -.58948900E+02, -.10228400E+03, -.42402900E+03, -.25555700E+03, -.13817300E+03, -.20115100E+03, 0.10079300E+03, -.39933900E+00, -.14164000E+03, 0.94264800E+02, -.74437800E+02, -.54738900E+02, 0.41644200E+01, 0.20865000E+03, -.22379700E+04, 0.11404500E+04, 0.11223900E+04, 0.75302100E+02, -.22176700E+03, 0.10277800E+04, 0.78836200E+03, 0.10239300E+04, -.17660200E+03, -.12880200E+04, 0.63626800E+03, 0.72022000E+03, 0.16395100E+03, 0.75546300E+02, 0.58778300E+03, 0.36831700E+03, 0.54410000E+03, 0.33997000E+02, 0.59157600E+03, -.29371900E+03, -.21951000E+03, 0.41744600E+02, 0.66221800E+02, -.21282700E+03, -.12639700E+03, -.18255300E+03, -.44217500E+01, 0.45180500E+03, -.22323000E+03, -.26339000E+03, 0.18473700E+02, 0.37542200E+02, -.22015600E+03, -.46531000E+01, -.11463500E+03, 0.92885600E+02, -.17638700E+04, 0.86377700E+03, 0.95168300E+03, 0.46368700E+03, 0.10034400E+03, 0.77089500E+03, 0.16976500E+03, 0.53776300E+03, 0.12121200E+03, -.18860100E+03, 0.99181100E+02, 0.28945700E+02, -.32148600E+02, 0.96254600E+02, 0.34391200E+02, -.57019400E+02, 0.76166100E+02, 0.71923100E+02, 0.24972000E+04, -.12446600E+04, -.13254100E+04, -.18086300E+03, -.60703500E+02, -.81873700E+03, -.49732000E+03, -.10285600E+04, -.20825900E+03, 0.11479800E+03, -.57860900E+02, -.63156100E+02, -.24420400E+02, -.10843700E+03, 0.98107000E+02, 0.79653000E+02, -.51049800E+02, -.10557400E+03, 0.18150300E+03, -.90895900E+02, -.66653600E+02, -.99170300E+02, 0.19003200E+03, -.12509000E+03, -.94930300E+01, 0.13871600E+03, 0.10742300E+03, 0.70028100E+01, -.13869000E+02, 0.57560000E+02, 0.40178300E+02, -.29148300E+01, 0.52398600E+02, -.25485800E+03, -.14579700E+03, 0.25774400E+03, 0.60111900E+03, -.96850400E+02, -.35650200E+02, -.67719900E+03, 0.32899600E+03, -.92907400E+02, -.99973700E+02, -.11612600E+03, -.56563600E+01, 0.13341600E+03, 0.11553900E+03, -.18987100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.55783300E+01, -.13029000E+01, 0.41608300E+01, 0.35885400E+01, -.31208300E+01, -.15991700E+02, -.12926500E+02, -.70207300E+01, -.10472900E+01, -.10121500E+01, 0.14354100E+01, 0.83975200E+00, 0.51837600E+00, -.26705100E+00, 0.72838500E-01, 0.28263500E+01, 0.40294400E+00, -.67859000E+00, 0.22574900E+01, -.69480900E+00, -.36356700E+00, -.72385700E+00, -.70090900E+00, 0.12689500E+01, 0.17750200E+00, 0.59716000E-01, 0.52648100E+00, -.11382200E+02, 0.42085400E+00, -.34293300E+01, -.30941700E+00, 0.12525800E+01, 0.70444200E+00, -.29286300E+00, 0.14543900E+01, -.73560400E+00, -.93612400E+00, -.10199900E+01, 0.11248700E+01, 0.26833600E+01, 0.12496700E+02, 0.15922600E+00, -.13104800E+01, -.64063700E+00, -.65333800E+00, 0.55335100E+00, 0.77396000E+00, -.38277600E+00, -.86460200E-01, 0.70533000E+00, 0.10025300E+01, 0.75569900E-01, -.17627800E-01, 0.31903800E+01, -.79400900E+00, 0.31289900E+00, -.27804100E+00, -.62049800E+00, 0.12254400E+00, 0.29081400E+01, -.15361000E-01, -.79974200E+03, -.60106200E+02, -.35473800E+04, 0.17656300E+04, 0.17754900E+04, 0.61640100E+03, 0.10245500E+04, 0.70104300E+03, 0.34412500E+03, 0.10305600E+04, 0.10003100E+04, -.50417300E+04, 0.23533100E+04, 0.25113900E+04, 0.13623100E+04, -.82087300E+03, 0.22711000E+04, 0.19807800E+04, 0.23348400E+04, -.37139200E+03, 0.92115600E+03, -.46079800E+03, -.65207000E+03, -.85028300E+03, -.44558500E+03, 0.11972500E+03, -.14583700E+03, -.28670600E+03, -.59723800E+03, -.84449000E+02, 0.47688100E+02, -.18430000E+03, -.54543500E+03, 0.47430900E+03, -.16454400E+03, -.42688600E+03, 0.21261200E+03, 0.20891900E+03, -.52614000E+04, 0.25186800E+04, 0.26446600E+04, 0.10747400E+04, -.90870700E+03, 0.25164200E+04, 0.22621400E+04, 0.24947200E+04, -.10166100E+04, -.56499400E+03, 0.51079800E+03, 0.39543200E+03, 0.60696900E+03, 0.37158400E+03, 0.66784200E+03, 0.52753600E+03, 0.96484300E+02, -.10493200E+03, 0.66566500E+03, -.32815600E+03, -.14069900E+03, -.14321300E+03, -.15377900E+03, -.37183500E+03, -.76664500E+03, -.90041500E+01, -.42443100E+02, 0.17237400E+04, -.85592800E+03, -.92510000E+03, -.17418300E+03, 0.37987300E+03, -.75929000E+03, -.86556100E+03, -.24571200E+03, 0.12160400E+03, -.16646600E+04, 0.95358800E+03, 0.91475300E+03, 0.12949900E+04, 0.21091900E+03, 0.11859700E+04, 0.35221200E+03, 0.14927000E+03, 0.18442000E+03, 0.77864000E+03, -.41145400E+03, -.52853000E+03, -.12724300E+02, 0.12016100E+03, -.27083600E+03, 0.25510000E+02, -.36290300E+03, 0.55123200E+01, 0.55857400E+04, -.27763000E+04, -.29341900E+04, -.52444000E+03, -.72478600E+03, -.18094000E+04, -.16834200E+04, -.19433200E+04, -.63433600E+03, 0.75801300E+03, -.38012900E+03, -.39409100E+03, -.15887500E+03, -.41213300E+03, -.32242200E+00, 0.36456200E+03, 0.37467800E+02, -.34980200E+03, 0.88765600E+03, -.44251800E+03, -.39932000E+03, -.87974800E+02, 0.42434400E+03, -.45376800E+03, -.10704200E+03, -.28775400E+03, 0.32489700E+03, 0.22286400E+03, -.50101300E+02, 0.32783400E+03, 0.19724500E+03, 0.32539400E+03, 0.30781700E+03, -.14066900E+04, 0.40644700E+03, 0.12253900E+04, 0.21596000E+04, -.35646000E+03, -.32238000E+03, -.24835700E+04, 0.15682100E+04, -.92985800E+03, 0.28576300E+03, -.91226800E+03, -.62968900E+02, 0.10057500E+04, 0.51069400E+03, 0.15943600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.51582100E+01, 0.47011000E+01, 0.27037800E+01, 0.47870000E+01, -.90162400E+00, -.27536500E+02, 0.12341700E+01, -.36017500E+01, -.16692100E+01, 0.93961700E+00, 0.35895000E+01, -.65454400E+00, 0.27548900E+01, 0.43531100E+00, 0.17170100E+00, 0.12957800E+01, 0.76418600E-01, -.47056500E+00, 0.18184800E+01, -.70739500E+00, -.21527800E+00, -.13234000E+01, 0.40581800E+00, 0.35871400E+01, -.60942300E+00, 0.23809700E+00, 0.11201600E+01, -.15349000E+02, -.64704700E+00, -.40927100E+01, -.90358100E+00, 0.33189900E+01, 0.82019200E+00, -.37587500E+00, 0.54022000E+00, -.14928400E+01, -.10798200E+01, -.16509300E+01, -.23231500E+01, -.16088700E+01, 0.11403700E+01, 0.56721500E+00, 0.10549300E+01, -.42972900E+01, -.13068200E+01, 0.10540700E+01, 0.99360400E+00, 0.34847500E+00, 0.21525800E+01, 0.16360400E+01, 0.35279000E+01, 0.54294800E+00, 0.14615200E+00, 0.28711400E+01, -.23068900E+00, 0.86717900E+00, -.21766700E+01, 0.50338100E+00, -.74956500E+00, 0.14691200E+01, -.33520500E+00, 0.89796000E-01, 0.15674900E+04, 0.34100300E+04, -.16430300E+04, -.17595400E+04, 0.11192000E+04, 0.15685400E+04, -.21557200E+04, -.10823100E+04, -.19511100E+04, -.15500600E+03, 0.16769200E+05, -.80197000E+04, -.83854000E+04, 0.10231600E+04, -.83773900E+03, -.74166700E+04, -.62766700E+04, -.69596200E+04, 0.97629300E+03, -.20301900E+04, 0.10211000E+04, 0.99085500E+03, -.23013700E+03, -.15021300E+02, 0.12191100E+04, 0.17434500E+04, 0.85917600E+03, 0.66338000E+03, -.41762200E+04, 0.20647300E+04, 0.22648500E+04, -.10586300E+04, 0.77687200E+03, 0.24174400E+04, 0.23984200E+04, 0.22552800E+04, -.31861800E+04, 0.13587900E+05, -.67077900E+04, -.68034100E+04, 0.80014300E+03, -.89076500E+03, -.62467800E+04, -.54539000E+04, -.59245800E+04, 0.14440700E+04, 0.38510200E+04, -.21775800E+04, -.20657900E+04, 0.66374400E+03, 0.18365600E+03, -.24347800E+04, -.21687100E+04, -.17275700E+04, 0.12658800E+04, 0.23934900E+03, -.12329000E+03, -.21684300E+03, -.10099700E+03, 0.16327500E+03, -.24290000E+03, -.56267400E+03, 0.95311200E+02, 0.13389200E+03, -.88266600E+03, 0.41826000E+03, 0.52178500E+03, -.87668400E+03, 0.24591700E+03, 0.45315300E+03, 0.74675100E+02, 0.11281300E+03, -.22125000E+04, 0.78684200E+04, -.39820900E+04, -.41117400E+04, 0.62065300E+03, -.73464100E+02, -.41693200E+04, -.36050500E+04, -.30725900E+04, 0.24118500E+04, -.91510300E+03, 0.47545800E+03, 0.64489000E+03, -.86992000E+01, -.39543200E+02, 0.30443800E+03, 0.17489400E+03, 0.17367900E+03, 0.61042200E+02, -.44502000E+04, 0.22097800E+04, 0.24279200E+04, -.98056300E+03, -.13541500E+04, 0.21982400E+04, 0.47948600E+03, 0.23676700E+04, 0.21406900E+03, 0.87945300E+03, -.43470300E+03, -.36563300E+03, -.34805400E+03, -.41597300E+03, -.22754700E+02, 0.18527700E+03, -.31986900E+03, -.42606300E+03, 0.11357500E+02, -.12633300E+02, -.64670300E+02, 0.57989400E+03, -.17605600E+03, -.23481400E+03, 0.73283500E+02, 0.54594500E+03, 0.16664500E+03, -.10895100E+03, 0.18108800E+03, 0.19386200E+03, -.24851500E+03, 0.69261500E+02, 0.24386700E+03, -.15124000E+04, -.12906000E+02, 0.37624100E+03, -.14023400E+04, 0.25878500E+03, -.12194700E+04, 0.14922800E+04, 0.54490800E+03, -.79694200E+02, 0.12327200E+04, -.10336300E+03, 0.14343800E+03, 0.29506200E+03, 0.38138900E+02, -.28488800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.99034800E+00, -.39960600E+00, 0.49748400E+00, 0.49674800E+00, -.54454700E+00, -.38929100E+01, -.58922700E+01, -.19977800E+01, -.27311600E+00, -.22191800E+00, 0.26707100E+00, 0.17758600E+00, 0.19998100E+00, 0.62489100E-01, -.60323000E-01, 0.52774700E+00, 0.38909700E-01, -.23291500E-01, 0.11277000E+00, 0.46768000E-01, -.16593900E+00, 0.39364600E+00, -.16546400E+00, 0.39411400E+00, 0.36685800E+00, 0.87777100E-01, -.20917000E+00, -.45746900E+01, 0.23270400E+00, -.78817800E+00, -.95572800E-01, 0.38908600E-01, -.13121000E+00, -.37068100E-01, 0.20670500E-01, -.64539200E+00, 0.46770700E-01, -.34887300E+00, -.29579000E+00, -.13623400E+00, -.95956500E+00, -.27874600E-01, 0.29515000E-01, -.13685800E-01, -.86725200E-01, 0.47010800E-01, -.20797700E-01, -.59012300E-01, -.10502200E+00, -.10170000E+00, -.24022300E+00, -.21998600E-01, -.52583500E-01, 0.17409500E+00, 0.36831000E+00, -.26184500E-02, -.19268800E-02, 0.86065300E-02, 0.44861700E-01, 0.36601900E+00, -.37789400E+00, 0.88751800E-01, -.49529500E-01, -.12596700E+04, 0.62953500E+03, 0.62956400E+03, 0.13388300E+02, 0.15983100E+03, 0.33793100E+03, 0.38765500E+03, 0.50795300E+03, 0.90858900E+02, -.21152000E+04, 0.11229200E+04, 0.10577400E+04, -.15153700E+03, -.70753300E+03, 0.10812300E+04, 0.11267200E+04, 0.11674800E+04, -.17775300E+03, 0.34734800E+03, -.17346500E+03, -.24163200E+03, -.23611000E+03, -.30097000E+02, -.51040100E+02, -.84169200E+02, -.19238000E+03, -.12556800E+03, 0.23489500E+02, -.14596400E+02, -.64914000E+02, -.19182100E+03, 0.21923300E+03, -.61943500E+02, -.12612400E+03, -.49833700E+02, -.16652100E+03, -.20569100E+04, 0.10514900E+04, 0.10284100E+04, -.16489700E+03, -.64357800E+03, 0.10293300E+04, 0.10541000E+04, 0.10652500E+04, -.17007400E+03, -.42798000E+03, 0.13117600E+03, 0.25751500E+03, 0.10899300E+03, 0.90598800E+02, 0.15911800E+03, 0.10653600E+03, 0.15973200E+03, 0.13938400E+03, 0.60588400E+03, -.30281600E+03, -.23680300E+03, 0.72079400E+02, 0.53341200E+02, -.28170600E+03, -.42665300E+03, -.12234900E+03, 0.37661200E+02, 0.67039800E+03, -.33666700E+03, -.36864300E+03, 0.42034100E+02, 0.11047600E+03, -.33098400E+03, -.40298500E+03, -.36114900E+03, -.11169800E+03, -.60999900E+03, 0.25527300E+03, 0.34831500E+03, 0.22398300E+03, 0.25122600E+02, 0.32268800E+03, 0.19981800E+03, 0.30862200E+03, 0.10033000E+03, 0.32297600E+02, -.11911400E+02, -.52305900E+02, -.17426200E+01, 0.48612200E+02, -.15850100E+02, 0.44438000E+02, 0.35790800E+02, 0.21019000E+02, 0.22349100E+04, -.11179400E+04, -.11619800E+04, 0.10503500E+03, 0.76944200E+02, -.85378300E+03, -.95379100E+03, -.94431100E+03, 0.13495900E+03, 0.23617400E+03, -.11840300E+03, -.99389100E+02, -.51407700E+02, -.13745100E+03, 0.27338600E+02, 0.10922700E+03, -.64189200E+02, -.12957700E+03, 0.15199200E+03, -.74938700E+02, -.62134400E+02, 0.27869400E+02, 0.18857100E+03, -.14002000E+03, -.30766000E+02, 0.15501700E+03, 0.16731500E+03, 0.80056900E+02, -.46291000E+02, 0.13452400E+03, 0.11437400E+03, 0.10743400E+03, 0.12639000E+03, -.25465400E+03, 0.64388500E+02, 0.40195900E+03, -.15098700E+03, -.16178900E+03, -.16214300E+03, 0.19887700E+03, 0.25298400E+03, -.45766300E+03, 0.92294300E+02, -.16862100E+03, -.30243600E+02, 0.34731700E+03, 0.19055300E+03, 0.28577500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13928400E+01, 0.19119500E-01, -.70403400E+00, -.20819700E+01, 0.49887600E+00, 0.11586800E+02, 0.12859000E+02, 0.18026500E+01, 0.71539100E+00, -.21574200E+00, 0.35411900E+01, 0.36565800E+00, -.25191900E+00, -.45945500E+00, -.63524900E-01, -.72906600E-01, 0.38457400E-02, -.17230400E+00, 0.20870200E+00, 0.17116400E+00, 0.26650200E+00, -.15815800E+00, -.20670200E+00, -.37943900E+00, -.43918200E+00, 0.97792600E-01, 0.78271300E+00, 0.65715200E+01, 0.12351600E+00, -.49876200E+00, -.15741900E+00, 0.17435800E+01, 0.87559300E+00, -.16632700E+00, 0.34302700E+00, -.35163500E-01, -.18664400E+00, -.49546000E+00, 0.11819900E+01, 0.17841900E+01, 0.12218800E+02, 0.29630300E+00, -.20200500E+01, 0.18386600E+01, 0.20363300E+00, 0.37617100E+00, -.81613900E-02, 0.21767000E-01, -.52745900E+00, -.89625400E-01, -.80425300E-01, 0.70811300E+00, -.37035000E+00, 0.19803100E+01, 0.77665300E+00, 0.89251200E-01, 0.24780000E+00, -.36035500E+00, 0.38572900E+00, 0.10784600E+01, 0.28500400E+00, 0.29540300E+00, -.91891300E-01, 0.10994600E+01, -.41160900E+02, 0.41668500E+02, -.45544500E+03, -.45281000E+03, 0.16177600E+03, 0.11149600E+03, 0.10111400E+03, -.25077600E+03, -.11952000E+04, 0.50802300E+03, 0.59444900E+03, -.49296800E+02, 0.38229200E+03, 0.58335600E+03, 0.61264700E+03, 0.56805400E+03, 0.48968700E+03, 0.84010700E+02, -.35018900E+02, 0.72960600E+01, 0.88418600E+02, 0.11367600E+03, -.19208100E+03, -.23056800E+03, -.24267100E+03, 0.10809000E+03, -.59821800E+03, 0.30661800E+03, 0.19730100E+03, -.13939200E+03, -.13752300E+03, 0.16101200E+03, 0.65443500E+01, 0.11050900E+03, 0.91938100E+02, -.14128400E+04, 0.50180500E+03, 0.70949200E+03, -.10409600E+03, 0.21114200E+03, 0.67503300E+03, 0.63042000E+03, 0.67149500E+03, 0.33115200E+03, -.12124000E+04, 0.55779700E+03, 0.68130300E+03, 0.13768200E+03, 0.15456100E+03, 0.44960300E+03, 0.55206800E+03, 0.44746500E+03, 0.25222200E+03, -.30430100E+03, 0.15605200E+03, 0.16379200E+03, -.22266400E+01, -.29733600E+01, 0.13884700E+03, 0.25161900E+03, 0.10090000E+03, -.17841500E+02, -.58315800E+03, 0.30103600E+03, 0.27901200E+03, 0.79681100E+02, -.88620900E+02, 0.22535800E+03, 0.16229600E+03, 0.18771000E+03, 0.59076000E+02, -.20458000E+04, 0.92411000E+03, 0.11198800E+04, 0.31495900E+03, 0.10990000E+03, 0.75648800E+03, 0.70195400E+03, 0.79860300E+03, 0.32376000E+03, -.93008500E+01, -.43149200E+02, -.95205300E+02, 0.37771900E+02, -.51251300E+02, -.36898800E+01, -.19455700E+02, 0.38651800E+02, -.42551100E+02, -.56168000E+02, 0.40863900E+02, -.67154400E+02, 0.48610700E+03, 0.41263200E+03, -.15151400E+03, 0.50555700E+02, -.95676400E+02, 0.26962300E+03, -.53369900E+03, 0.26562200E+03, 0.19342200E+03, 0.17455900E+03, 0.10186400E+03, 0.10963000E+03, -.16463600E+03, -.32709100E+02, 0.10896400E+03, -.20296200E+03, 0.11903100E+03, 0.13264500E+03, -.17028400E+01, 0.94931700E+02, 0.73763800E+02, 0.13515600E+03, 0.83956300E+02, 0.75124500E+02, -.19042900E+03, 0.63595800E+02, -.18716300E+03, -.12363700E+03, -.16715800E+03, -.13941100E+03, 0.15219000E+02, -.64571400E+02, -.44090600E+03, 0.95258600E+02, 0.14662800E+03, 0.14224400E+03, -.15543800E+03, 0.43554500E+02, 0.23973900E+03, -.92578600E+02, -.29773000E+01, 0.78336200E+02, -.29893700E+03, -.85904400E+02, -.11924100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.22824700E+01, 0.17633200E+00, 0.12067700E+01, 0.21532500E+01, -.11516000E+01, -.68012700E+01, -.55516800E+01, -.46491800E+01, -.40514700E+00, -.20305000E+00, 0.30449900E+00, 0.35175100E-01, 0.60809300E+00, 0.69858400E+00, -.31954400E+00, 0.73483600E+00, 0.21038600E+00, 0.26685900E+00, 0.27530500E+00, -.36296400E+00, -.24052800E+00, 0.14623000E+00, 0.92412000E-01, -.10505000E+01, 0.10405600E+01, -.50771000E+00, 0.24650100E+00, -.49457900E+01, 0.21593400E+00, -.82847400E+00, -.82463100E-01, 0.75786700E+00, 0.46779500E+00, -.13597800E+00, 0.80965100E+00, -.34725500E+00, -.30681100E+00, -.28182200E+00, -.59674500E-01, 0.14952400E+01, -.59986200E+00, -.24978400E+00, -.96033900E+00, -.81545600E+00, -.59551000E-01, 0.34561000E+00, 0.30374100E+00, -.70795300E+00, -.36817200E+00, 0.70122700E+00, 0.71617800E+00, 0.66040800E+00, -.17497900E+00, 0.19844300E+00, -.45829700E+00, 0.37750700E-01, -.66070900E+00, 0.30698300E+00, -.25995600E+00, -.24306100E+00, 0.24241800E+00, -.57743400E+00, 0.13479600E+00, -.73567500E+00, 0.34351800E+00, -.48544000E+02, 0.55112100E+03, 0.43817400E+03, -.19943000E+03, -.42702900E+03, -.18487500E+03, 0.42608000E+03, 0.28183700E+04, -.14711400E+04, -.14110500E+04, 0.12284900E+03, -.18599800E+02, -.15760000E+04, -.19992200E+04, -.14869500E+04, -.25191700E+03, -.39494900E+03, 0.19993600E+03, 0.17920100E+03, 0.78016100E+02, -.15586500E+03, 0.31067100E+03, 0.31171300E+03, 0.33935800E+03, -.11059400E+03, 0.27979000E+03, -.13832000E+03, -.33894900E+02, 0.36084600E+03, -.13079000E+03, -.15719300E+02, 0.24478000E+02, 0.10982600E+02, 0.99470400E+01, 0.29217700E+04, -.14927900E+04, -.14606700E+04, 0.20264600E+03, -.86590500E+02, -.15554900E+04, -.19149100E+04, -.14809900E+04, -.24983300E+03, 0.16042100E+04, -.68387100E+03, -.92667300E+03, -.82769900E+02, 0.69440900E+02, -.55712900E+03, -.48966600E+03, -.61608700E+03, -.97588500E+02, -.10947600E+03, 0.54943700E+02, 0.13771000E+02, -.55973300E+02, -.11387200E+01, 0.18349800E+02, 0.53019700E+02, -.11574700E+03, -.41376300E+01, -.72029600E+02, 0.35445100E+02, 0.85131000E+02, -.63361700E+02, -.19781600E+02, 0.76770600E+02, 0.11731300E+03, 0.10659600E+03, 0.62600700E+02, 0.27076300E+04, -.12584000E+04, -.15241300E+04, -.32719500E+03, 0.29158100E+03, -.10500700E+04, -.79826600E+03, -.10858400E+04, -.44505400E+02, 0.59811500E+02, -.44103900E+02, 0.75233700E+02, 0.42866000E+02, 0.22993700E+02, 0.43897500E+01, 0.71285400E+02, -.81599500E+02, 0.24727600E+02, -.11659200E+03, 0.62043500E+02, 0.17874100E+03, -.58617500E+03, -.46319300E+03, 0.31771000E+03, 0.60994500E+03, 0.17022700E+03, -.49177900E+03, 0.24830300E+03, -.12249500E+03, -.96122000E+02, -.19760000E+03, -.49426800E+02, -.44376200E+02, 0.13970400E+03, 0.56333900E+02, -.90054300E+02, 0.21684500E+03, -.10524500E+03, -.14786000E+03, 0.17264100E+03, 0.15748500E+02, -.89248300E+02, -.11795900E+02, -.33199800E+03, 0.78255000E+02, -.36969900E+02, 0.18271400E+03, -.52300000E+02, -.45937500E+02, -.42782900E+00, -.63879400E+02, 0.42993400E+03, 0.96045300E+01, 0.17746600E+03, 0.20817700E+02, 0.43299400E+02, 0.69346500E+02, -.10490600E+03, -.35853200E+03, 0.15894100E+03, 0.55809700E+01, 0.16590900E+03, 0.16600200E+03, 0.63225000E+00, 0.22990100E+02, -.87375300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.48142300E+01, 0.45246500E+01, -.24902300E+01, -.48793700E+01, 0.22351800E+01, 0.11947500E+02, 0.99733300E+01, 0.11117000E+02, 0.56214800E+00, 0.11048200E+00, 0.55785900E+00, 0.50342400E-02, -.12443500E+01, -.13003700E+01, 0.76332100E+00, -.96680600E+00, -.58329800E+00, -.77990600E+00, -.80328100E+00, -.27238100E+00, 0.53929200E-01, -.33615400E+00, -.10899700E+00, -.30843300E+00, 0.29014900E-01, 0.44988300E+00, -.85171400E+00, 0.97733400E+01, -.22513300E+00, 0.19938500E+01, -.42847600E+00, -.13407000E+01, 0.66450400E+00, 0.14392000E+00, 0.13282800E+01, 0.49164500E+00, 0.39973000E+00, 0.10274200E+01, 0.11902400E+01, 0.38099200E+00, 0.38281400E+01, 0.16825600E-01, 0.10285100E+01, 0.67185900E+00, -.29153200E+00, -.83423200E+00, -.64034300E+00, 0.82059000E+00, 0.97895300E+00, -.10406700E+01, 0.45032900E+00, -.99450800E+00, 0.54814500E+00, -.26323300E+01, -.22121800E+01, -.11413100E+00, 0.10935800E+01, 0.18002400E+00, 0.24657800E-01, 0.32579900E+01, -.41244100E+00, 0.13218300E+00, -.27053600E+00, 0.39663900E+01, -.18829500E+00, -.22032300E+01, 0.14551400E+04, 0.13038200E+04, -.67218900E+03, -.14779700E+04, -.10000300E+04, 0.14447300E+04, 0.60839700E+04, -.35124700E+04, -.30447200E+04, 0.36681700E+04, 0.26995200E+04, -.34342300E+04, -.35331300E+04, -.34824100E+04, 0.24740600E+03, -.25398500E+04, 0.12562600E+04, 0.13189200E+04, 0.29783000E+03, -.38762500E+03, 0.10843100E+04, 0.42498700E+03, 0.54842200E+03, 0.35799900E+02, -.10625500E+04, 0.54669300E+03, 0.48749200E+03, 0.57162200E+02, -.15599500E+03, 0.55908400E+03, 0.77296900E+03, 0.53820700E+03, 0.99817700E+03, 0.56445200E+04, -.28687600E+04, -.28147100E+04, 0.31502200E+04, 0.22560700E+04, -.28433300E+04, -.28407000E+04, -.28286200E+04, -.55015400E+03, 0.50712000E+03, 0.50834100E+03, -.35629700E+03, 0.78213400E+03, 0.32793700E+03, 0.19765100E+03, -.43965800E+03, 0.11279900E+03, -.44725400E+03, 0.46057500E+03, -.21815100E+03, -.25196100E+03, -.91650300E+03, -.24692400E+03, -.31101300E+01, 0.37795700E+03, -.17264400E+03, -.20799000E+03, -.65116500E+03, 0.33755000E+03, 0.38157600E+03, -.90470600E+03, 0.78889600E+02, 0.59194200E+03, 0.82822900E+03, 0.84487900E+03, 0.53250700E+03, 0.20140700E+04, -.51880000E+03, -.11209000E+04, 0.14537000E+04, 0.83632200E+03, -.93894600E+03, -.20334800E+04, -.12132100E+04, 0.34209400E+03, 0.21685200E+03, -.13429600E+03, -.16966900E+03, 0.29135100E+02, -.76499900E+02, -.50146600E+02, -.79602500E+02, -.22679900E+03, -.29081300E+02, -.91887600E+03, 0.48939200E+03, 0.44495800E+03, -.19890300E+04, -.15274600E+04, 0.12585700E+04, 0.20131400E+04, 0.14520500E+04, -.19301800E+04, -.11197500E+04, 0.55765800E+03, 0.41987800E+03, 0.11351300E+03, 0.33919200E+03, 0.11593000E+03, -.40454200E+03, -.29220300E+03, 0.41133400E+03, 0.14716800E+02, -.23532300E+02, -.24997700E+01, -.37964100E+01, -.47576200E+03, 0.25676700E+03, 0.45580800E+03, -.35408100E+03, -.43459900E+03, 0.21050000E+02, -.61028100E+02, -.14682300E+03, -.18916000E+03, -.10126100E+02, 0.79066900E+02, -.17687800E+04, 0.28061400E+03, 0.50112500E+03, 0.48891800E+04, 0.25897200E+03, -.76443800E+02, -.58051500E+04, 0.14269700E+04, 0.86611600E+03, 0.14426700E+03, -.61513100E+03, -.87017200E+02, 0.70619000E+02, -.17917600E+03, 0.42233700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.86955800E+00, 0.50554600E+00, 0.27073000E+00, 0.16561600E+01, -.41343300E-01, -.28718000E+01, 0.35790800E+00, -.52888000E+00, -.13646900E+00, 0.17658900E+00, 0.54791000E+00, -.11134600E+00, 0.20997100E+00, 0.20055700E+00, -.39742300E-01, -.82749100E-01, 0.11140800E-01, 0.28480200E-01, -.91904700E-01, 0.18759500E-01, 0.34036600E-01, 0.32396700E-01, 0.83689900E-01, 0.24093500E+00, 0.33681600E-01, -.84693800E-03, 0.28877800E+00, -.44756800E+00, -.68308500E-01, -.43988400E+00, -.12835900E+00, 0.32007400E+00, -.90287300E-01, -.71897500E-01, -.26857200E+00, -.51659800E+00, -.16365100E+00, 0.10508200E+00, -.36376200E+00, -.24382700E+00, 0.24809600E+01, 0.74332000E-01, -.11113900E+00, -.52060400E+00, -.19138800E+00, 0.42299200E+00, 0.10826100E+00, -.24764400E+00, -.31228300E+00, 0.24723300E+00, -.89532800E-02, -.94626400E-02, -.29350600E+00, 0.78626900E+00, 0.12808700E+01, -.36041200E-01, -.17909600E+00, -.17404400E+00, 0.16204000E+00, 0.20734700E+00, -.41606200E+00, 0.16271100E+00, -.79502800E-01, 0.72849800E+00, -.14053300E+00, -.14193600E-01, -.15054700E+00, -.16072900E+03, 0.45481700E+01, -.24477100E+03, -.56870700E+02, -.12501200E+02, -.57697800E+03, 0.19419200E+03, 0.28795900E+03, 0.15835500E+03, 0.45135200E+03, 0.18925600E+03, 0.10513500E+03, 0.13701200E+03, 0.27938600E+03, -.35392100E+03, 0.17595000E+03, 0.20649900E+03, 0.12732000E+03, 0.28573000E+02, 0.72404200E+02, -.71183400E+02, -.56317700E+00, 0.68781400E+02, -.40282400E+03, 0.20399300E+03, 0.20544800E+03, 0.99998500E+02, -.24476900E+03, 0.13616600E+03, 0.12214300E+03, 0.12184700E+03, 0.12230200E+02, -.43365900E+03, 0.16088200E+03, 0.21865400E+03, 0.14436700E+03, 0.32514600E+03, 0.16197500E+03, 0.74431800E+02, 0.14755600E+03, 0.21907700E+03, 0.71285600E+02, 0.10638600E+03, -.59572800E+02, 0.88174600E+02, 0.16686500E+03, 0.77891800E+01, -.10778100E+02, -.17526400E+03, 0.82880100E+02, -.52491900E+03, 0.26326300E+03, 0.24147200E+03, -.38702800E+02, -.40116000E+02, 0.23422900E+03, 0.34169800E+03, 0.12839100E+03, -.24392000E+02, -.66355200E+03, 0.33265800E+03, 0.34675000E+03, 0.47745700E+02, -.12328200E+03, 0.24886200E+03, 0.20654000E+03, 0.25415000E+03, 0.92264400E+01, -.13459900E+03, 0.15649500E+03, 0.35465100E+02, 0.70845400E+02, 0.26358100E+03, 0.26151300E+02, -.28941800E+02, -.18409100E+03, 0.86549600E+02, 0.32515000E+02, -.22006200E+02, -.14770800E+02, 0.26914400E+02, -.44688500E+02, 0.55929500E+01, 0.13175500E+02, 0.18856800E+02, -.17714500E+02, -.57076300E+03, 0.28779900E+03, 0.29334200E+03, 0.58633500E+02, 0.13907900E+00, 0.28803700E+03, 0.64507600E+03, 0.25634100E+03, -.38465900E+02, -.51245700E+03, 0.25571800E+03, 0.23364500E+03, 0.32870700E+02, 0.11356900E+03, 0.11226900E+03, -.14505700E+03, -.31692200E+02, 0.78354700E+02, 0.78145100E+02, -.40293100E+02, -.42120200E+02, 0.12377000E+03, 0.26441100E+02, 0.22253200E+02, 0.15120300E+03, -.76440900E+02, 0.75626900E+02, -.18840700E+03, 0.18870100E+03, -.23584300E+03, -.13432200E+03, -.18431600E+03, -.16043100E+03, 0.16433300E+03, -.55911500E+02, -.33687500E+03, 0.33091700E+03, 0.14897000E+03, 0.15960700E+03, -.44178600E+03, -.12225500E+03, 0.33662800E+03, -.67589800E+02, 0.10279600E+03, 0.19388300E+03, -.32364900E+03, -.89183900E+02, -.19637200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36048900E+01, -.29893900E+01, 0.23220800E+01, 0.30058200E+01, -.14392700E+01, -.12027300E+02, -.85715000E+01, -.56394200E+01, -.67645100E+00, -.10850100E+00, -.79222400E+00, -.60151200E+00, 0.10725000E+01, 0.31593500E+00, 0.14204400E+00, 0.11178700E+01, 0.41565000E+00, -.23629300E+00, 0.90777400E+00, -.24711200E+00, -.18052400E+00, -.62510800E+00, 0.17404400E+00, 0.89814400E+00, -.35864500E+00, -.84444200E-01, 0.45638300E+00, -.11945800E+02, -.21882500E+00, -.11597600E+01, -.23840300E+00, 0.84316900E+00, 0.48609100E+00, -.80122600E-02, -.64022100E-01, 0.49538600E+00, 0.21138300E+00, -.57157900E+00, -.18111600E+00, -.13625800E+00, -.61323500E+01, -.37610700E+00, 0.68218100E+00, -.33951200E+00, 0.39799300E+00, -.49653900E-01, -.37813200E+00, -.18549200E+00, -.11311300E+00, 0.19660300E+00, -.10108400E+00, 0.30311500E+00, -.46153500E+00, -.16625800E+01, 0.48169000E+00, 0.59262000E-01, -.35595000E+00, -.25425200E-01, -.63751900E-01, -.10842600E+01, 0.12447700E+00, -.74955400E+00, 0.12886000E+00, 0.71223600E+00, 0.13788100E+00, 0.34443200E+00, -.90038100E-01, 0.43082400E+00, 0.24424600E+03, -.78279900E+03, -.76529900E+03, 0.55731700E+02, 0.96329600E+03, -.54479500E+03, -.48061200E+03, 0.14654800E+03, 0.80674400E+03, -.52185800E+03, -.66044700E+03, -.81428700E+03, 0.42767600E+03, -.19621600E+03, 0.99356100E+02, 0.23517500E+03, 0.19548800E+03, 0.48054200E+02, 0.60127400E+01, 0.17514700E+03, 0.44591800E+03, 0.11875100E+03, 0.30376900E+03, -.14756700E+03, -.49728100E+02, 0.10169900E+02, -.38297300E+03, 0.47446900E+02, 0.30624800E+03, 0.15587800E+03, -.10637200E+03, 0.88820700E+03, -.44492500E+03, -.44265700E+03, 0.17454200E+03, 0.74500300E+03, -.48860300E+03, -.56940400E+03, -.65802800E+03, 0.45626800E+03, -.13847400E+04, 0.76012100E+03, 0.59875400E+03, -.25294900E+03, -.14502600E+03, 0.67629100E+03, 0.21440400E+03, 0.25835100E+03, -.42647600E+02, -.17723900E+03, 0.88194300E+02, -.43331900E+02, -.26532900E+03, -.33778600E+03, 0.28679500E+03, 0.61962600E+03, 0.10812000E+03, -.29768600E+03, -.18296100E+03, 0.90402200E+02, 0.15289800E+03, -.48358400E+02, -.22779200E+03, 0.15302700E+03, 0.51372100E+03, 0.42499500E+03, -.85456200E+02, -.11116800E+04, 0.59859000E+03, 0.47398400E+03, -.47080000E+03, -.36956900E+02, 0.53094600E+03, 0.21997400E+03, 0.69005500E+02, -.47658500E+02, 0.69152900E+02, -.20736100E+02, 0.35562100E+02, 0.15002800E+02, -.14322300E+02, 0.87355700E+00, -.61904600E+02, -.98542500E+02, -.61797000E+01, -.92642400E+03, 0.45686400E+03, 0.54618000E+03, -.31847300E+03, -.50945900E+03, 0.44316800E+03, 0.14317200E+04, 0.12020400E+04, -.45863800E+03, -.11675700E+03, 0.59117600E+02, 0.21637100E+02, 0.17762300E+03, 0.31286200E+03, -.23961200E+03, 0.62187300E+01, 0.24248100E+03, 0.24750000E+03, -.51198300E+03, 0.25359100E+03, 0.22928600E+03, -.11297800E+03, -.28826700E+03, 0.45018600E+03, -.15864500E+03, -.38498700E+03, -.17723800E+03, 0.77755500E+02, -.10730300E+02, -.88618100E+02, -.33246900E+02, -.32468400E+02, -.11605600E+03, 0.49717000E+03, -.17977700E+03, -.48480600E+03, 0.48787100E+03, 0.11549000E+03, 0.13615900E+03, -.53564700E+03, -.49947300E+03, 0.31359300E+03, -.11258400E+03, 0.33613100E+03, -.29138100E+02, -.20335500E+03, -.23556800E+03, 0.10462200E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13585200E+01, 0.36567700E+01, 0.61764400E+00, 0.27242600E+01, -.12665500E+01, -.65383200E+01, 0.47431000E+01, -.16913900E+01, -.37376200E+00, 0.58123900E+00, -.17705300E+01, -.70925400E+00, 0.20620800E+00, 0.42827500E+00, -.94927800E+00, 0.96034700E+00, 0.18590600E-01, 0.33458100E+00, 0.71057500E+00, -.47878900E+00, 0.33133700E-01, -.47910500E+00, 0.12750100E+00, 0.20327100E+01, 0.62611100E-01, 0.14630600E+00, -.46509900E+00, -.10627300E+02, -.44989300E+00, -.20322300E+00, 0.44974900E+00, -.40099800E+00, -.19904000E+00, 0.99394200E-01, 0.37704100E+00, 0.26365800E+00, -.33776400E+00, -.10100100E+01, -.61490000E+00, -.12201100E+01, -.44103600E+01, 0.16271300E+00, 0.11108200E+01, -.15960600E+01, -.22249600E+00, 0.94543300E+00, 0.32756000E+00, 0.76572500E-01, 0.10876000E+01, 0.57497000E+00, 0.13518300E+01, 0.50351800E+00, 0.41701700E+00, 0.19981600E+00, -.13009400E+01, 0.25789500E+00, -.10541700E+01, 0.53699400E-01, -.50868400E+00, -.38293700E+00, 0.12798400E+01, -.88809400E+00, 0.17943400E+00, 0.90850000E+00, -.21394300E+00, 0.12527900E+01, -.59873000E-01, -.17478100E+01, -.52450200E+00, -.10406100E+04, -.64646800E+03, -.24024400E+03, 0.23989200E+04, -.13393100E+04, -.12023300E+04, 0.14728200E+04, 0.13412100E+04, -.10124100E+04, -.73206700E+03, -.13685200E+04, 0.78644800E+03, 0.18516800E+03, -.87631200E+02, -.46498900E+02, -.19667300E+03, -.14115800E+03, 0.18051000E+03, 0.43557700E+03, 0.36484500E+03, -.53505700E+02, -.13158700E+04, 0.66387000E+03, 0.66027400E+03, -.61841400E+03, -.40091300E+03, 0.79291000E+03, 0.98677400E+03, 0.91304600E+03, -.70147500E+03, 0.10684200E+04, -.73205700E+03, -.52526400E+03, 0.11701500E+04, 0.91730600E+03, -.45207500E+03, -.32869200E+03, -.63728200E+03, 0.66838200E+03, -.22074100E+03, 0.25686200E+03, 0.82681400E+02, 0.34584900E+03, -.65618100E+01, 0.21949300E+03, -.15349000E+03, -.49512500E+03, 0.44549200E+02, -.10424200E+04, 0.52256200E+03, 0.45797300E+03, -.42168500E+03, -.30818700E+03, 0.56299000E+03, 0.84702300E+03, 0.58777300E+03, -.14495400E+03, -.53684800E+03, 0.27212200E+03, 0.32195000E+03, -.25442300E+03, -.67912400E+02, 0.26834100E+03, 0.43728100E+03, 0.52951200E+03, -.34526600E+03, -.13173900E+04, 0.72127700E+03, 0.61697400E+03, 0.59700000E+03, -.41279000E+02, 0.50743600E+03, -.45213100E+03, -.25130400E+03, 0.51923000E+02, 0.91114200E+03, -.48345600E+03, -.42532100E+03, -.46507300E+01, -.20645500E+03, -.24700600E+03, -.35656200E+02, -.43578200E+03, -.19723300E+03, -.20232800E+04, 0.10198200E+04, 0.10598300E+04, -.24905700E+03, -.71321000E+03, 0.97336600E+03, 0.17426600E+04, 0.15298000E+04, -.28604700E+02, -.19762500E+03, 0.98672400E+02, 0.63077600E+02, 0.14323000E+03, 0.17259900E+03, -.16797200E+03, -.44392600E+02, 0.17292100E+03, 0.15422800E+03, 0.23278500E+03, -.11494300E+03, -.12929600E+03, 0.40781500E+02, -.35943000E+03, 0.22704900E+03, 0.81703600E+02, -.61512200E+03, -.16836900E+03, -.80365900E+02, 0.21849700E+03, -.21371500E+03, -.19744200E+03, -.11782400E+03, -.10523700E+03, -.97373900E+03, -.28565900E+02, -.83691400E+03, 0.20073000E+04, 0.21501700E+03, -.74074700E+02, -.22558800E+04, 0.73525700E+03, 0.66386000E+03, 0.10986000E+03, -.20547900E+03, 0.16354500E+03, -.51040800E+03, -.24114800E+03, -.72336600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.47909100E+00, 0.10230200E+00, 0.99148300E-01, 0.10465000E+01, -.11886700E+00, -.57077600E+01, 0.24714100E+01, 0.77975200E+00, -.28082100E+00, 0.64003200E+00, -.12289300E+01, -.28860600E+00, 0.12285500E+00, -.14526100E+00, 0.17822500E+00, 0.99208900E-01, 0.36173000E-01, 0.46511800E+00, -.14514300E+00, 0.25686600E+00, -.39886700E-01, 0.31995000E+00, 0.36061100E-02, 0.16044200E+01, -.29302000E+00, 0.52991700E+00, -.69173700E-01, -.76500000E+01, -.32002200E+00, 0.57077500E+00, 0.24238200E+00, -.71691100E+00, -.50661900E+00, 0.16772200E+00, 0.54410800E+00, 0.96518600E-01, -.32670400E+00, -.42838600E+00, 0.37230100E+00, -.84860000E+00, 0.13728400E+01, 0.21366900E+00, 0.52582300E+00, 0.29489100E+00, -.18407300E+00, -.16942700E+00, -.30641200E-01, 0.35425700E+00, 0.18002700E+00, -.37199200E+00, -.90453100E+00, -.25132200E+00, 0.16842500E+00, 0.12154500E+01, -.12621000E+01, 0.66204200E-01, -.10129500E+00, -.54724000E+00, 0.12705800E+00, -.32903100E+00, -.22152400E+00, 0.26526800E+00, 0.73408000E-01, -.27535200E+00, 0.24472900E+00, -.56349200E+00, -.10926100E-02, -.19554500E+00, 0.45178200E+00, -.14813200E+00, 0.31626300E+03, 0.67602600E+02, -.19851100E+04, 0.95058200E+03, 0.99105400E+03, -.63064700E+02, 0.52243500E+02, 0.89892900E+03, 0.64386300E+03, 0.95304100E+03, -.66280200E+02, -.26344900E+03, 0.12593800E+03, 0.96802200E+02, 0.11492300E+03, 0.74140500E+02, 0.21646700E+02, -.14254700E+03, -.11726000E+03, 0.65788000E+02, -.20489400E+03, 0.10204100E+03, 0.62196800E+02, -.32156500E+02, 0.53984800E+01, -.35159900E+02, -.11474000E+03, -.39637400E+02, 0.19605200E+03, -.19075500E+04, 0.99610000E+03, 0.95601600E+03, -.85161200E+02, 0.14432600E+03, 0.88845100E+03, 0.70027300E+03, 0.93233700E+03, -.17141400E+03, -.92871900E+03, 0.53720800E+03, 0.48104900E+03, 0.77655800E+02, 0.15799500E+03, 0.35068400E+03, 0.25639300E+03, 0.38533100E+03, -.15569200E+02, -.38307500E+03, 0.19162500E+03, 0.25563300E+03, 0.32786100E+02, -.33561800E+02, 0.12744400E+03, 0.14781400E+03, 0.71423000E+02, -.62655600E+00, 0.12315400E+03, -.58352000E+02, -.10630700E+03, 0.28850500E+02, 0.27071100E+02, -.10824200E+03, -.87164500E+02, -.12495000E+03, 0.56231000E+02, -.92099900E+03, 0.50838200E+03, 0.48238500E+03, 0.25892300E+03, 0.30316400E+03, 0.34879400E+03, 0.23815900E+03, 0.29650300E+03, 0.11074000E+03, -.12464300E+03, 0.64012600E+02, 0.10363300E+02, -.47179100E+01, 0.16689000E+02, 0.35266600E+02, -.12299200E+02, 0.45017800E+02, 0.28111200E+02, -.35976200E+03, 0.18345400E+03, 0.11712200E+03, -.11376300E+02, 0.73273000E-01, 0.10157300E+03, 0.12074100E+03, -.24624000E+03, -.26486900E+02, -.44407300E+03, 0.22077600E+03, 0.22715400E+03, 0.92368500E+02, 0.12295800E+03, 0.12298500E+03, -.42918000E+02, -.74178500E+02, 0.13173800E+03, 0.21963900E+03, -.11339200E+03, -.93501200E+02, 0.15738800E+02, -.79414500E+01, -.11398200E+03, 0.13736300E+02, -.93289700E+02, -.34453000E+02, 0.91214700E+00, -.28140900E+01, 0.10717000E+02, 0.44966500E+02, 0.27668200E+02, 0.27263400E+02, 0.48310100E+02, -.48679600E+02, -.37428200E+02, 0.25879000E+03, -.38794300E+02, 0.83470700E+01, -.30101200E+03, -.67176900E+01, 0.63454200E+02, -.76240800E+02, 0.15672800E+01, 0.70119200E+01, -.28802900E+02, 0.12009900E+03, 0.26383800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21554700E+01, 0.45399400E+01, 0.12681200E+01, 0.38387400E+01, -.17978600E+01, -.11261500E+02, -.14719500E+00, -.16342200E+01, -.68367800E+00, 0.58153900E+00, -.28972700E+01, -.21917000E+01, 0.77195600E+00, 0.18643600E+00, -.24683000E+00, 0.76271100E+00, 0.32056000E+00, 0.62512300E+00, -.16877200E+00, -.17477000E+00, -.62831500E-01, 0.28251500E+00, 0.40007100E+00, 0.90593500E+00, 0.36588500E+00, 0.15852900E+00, 0.16447900E+00, -.51808200E+01, 0.25541600E+00, 0.22004200E+01, 0.41923500E+00, -.14034100E+01, -.14813600E+01, 0.62384400E-01, -.68562800E+00, -.13941800E+01, -.17402000E+00, 0.78456200E+00, -.17169900E+01, -.27016200E+01, -.63309300E+01, 0.35565300E-01, -.15357200E+01, 0.33279100E+00, 0.67039600E+00, 0.17042500E+00, 0.17924800E+00, -.12534900E+00, -.12141400E+01, 0.35236300E+00, -.11949100E+01, -.40215600E+00, -.59872100E+00, 0.29274200E+01, 0.39387400E+01, -.26746800E-01, -.23215600E+00, 0.70856200E-01, 0.43404300E+00, -.38635000E+00, 0.27211500E+00, 0.20654500E+00, 0.24494200E-01, 0.12383000E+01, 0.15082700E+00, 0.71081200E+00, -.44713900E+00, -.13372900E+01, -.31346500E+00, 0.10654200E+01, 0.34051600E+00, 0.70174800E+03, -.31693600E+04, 0.13901100E+04, 0.15857700E+04, -.76741900E+03, -.71152900E+02, 0.12517600E+04, 0.10086800E+04, 0.13999800E+04, -.52817200E+03, -.60158800E+03, 0.29155700E+03, 0.36435100E+03, 0.43766400E+03, 0.11999200E+03, -.16492400E+03, -.54643100E+03, -.27709600E+03, 0.20987000E+03, 0.17046900E+04, -.84496000E+03, -.79130000E+03, 0.82830000E+03, -.16165400E+03, -.90526100E+03, -.93701100E+03, -.10030400E+04, 0.14649800E+04, -.16647800E+04, 0.87599400E+03, 0.82832400E+03, -.56181300E+03, 0.15897600E+03, 0.70976200E+03, 0.66879600E+03, 0.79675300E+03, -.61121100E+03, -.36109100E+03, 0.49911100E+03, 0.10984700E+03, -.17316400E+03, 0.35612800E+03, 0.74325500E+02, 0.32723700E+03, 0.29813400E+03, -.23825800E+02, 0.64339300E+02, -.30218200E+02, -.45803600E+02, 0.16267900E+03, -.13488500E+03, 0.12478400E+03, 0.26780100E+03, -.84364700E+02, -.22153600E+03, -.90778200E+03, 0.45732700E+03, 0.45318300E+03, 0.27536200E+03, -.24404100E+03, 0.47838300E+03, 0.54261300E+03, 0.43290100E+03, 0.77809700E+03, -.31068800E+03, 0.36333700E+03, 0.90896900E+02, -.36554000E+03, 0.37590700E+03, 0.51426100E+02, 0.71672200E+03, 0.29779300E+03, 0.71867200E+02, -.87064700E+03, 0.44978200E+03, 0.42301400E+03, -.50186500E+02, 0.59773900E+02, 0.23299300E+03, -.11364500E+03, 0.27598000E+03, 0.13422400E+03, -.12875900E+03, 0.66538400E+02, 0.63721200E+02, -.33501900E+02, 0.21741000E+02, 0.28868500E+03, 0.64741200E+03, 0.23128100E+03, -.11167600E+04, -.61992600E+03, 0.30912200E+03, 0.29318300E+03, 0.61970500E+02, 0.13250000E+03, 0.19545400E+03, -.19572300E+03, -.18467500E+03, 0.11722000E+03, -.71473900E+03, 0.34698600E+03, 0.35450600E+03, -.18012300E+03, 0.16998100E+03, 0.11049200E+03, -.62762800E+02, 0.29298800E+03, -.22690700E+02, -.81619100E+02, 0.34685300E+00, -.12553000E+03, -.43121600E+02, -.13243500E+03, -.19443700E+03, 0.12419800E+04, -.20511800E+03, 0.33839300E+02, -.80734700E+03, 0.80390600E+02, 0.54402300E+03, 0.83212700E+03, -.95317200E+03, 0.11866300E+03, -.43242900E+03, 0.43247000E+03, -.30533500E+01, -.11466200E+03, -.20556000E+02, -.99803100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18005900E+01, 0.16115500E+01, 0.82867100E+00, 0.26967800E+01, -.91263400E+00, -.10396000E+02, 0.43730900E+01, -.13326500E+01, -.49084200E+00, 0.60894500E+00, -.12911400E+01, -.14858700E+00, 0.37386800E+00, 0.14960600E-01, -.38057000E+00, 0.45517600E+00, 0.49468500E-01, 0.19937100E+00, 0.90295000E+00, -.28601100E+00, 0.79776100E-01, -.64503400E+00, -.65702500E-02, 0.12020500E+01, 0.22442300E+00, -.25198700E+00, 0.22729700E+00, -.54502100E+01, -.45187400E+00, -.21502000E+01, -.21676200E+00, 0.49341800E+00, -.26699100E+00, -.11288600E+00, 0.27182300E+00, -.10697900E+01, -.67390900E+00, -.53801100E+00, -.72490700E+00, -.79637300E+00, 0.70788200E+01, 0.45002800E+00, 0.13573300E+01, -.21605600E+01, -.23735700E+00, 0.55386100E+00, -.88326000E-01, 0.64022400E+00, 0.15983100E+01, 0.11678000E+01, 0.23403600E+01, 0.49561600E+00, 0.10475900E+01, 0.21998500E+01, -.12186400E+01, 0.63922900E+00, -.14472300E+01, 0.39443700E+00, -.56007200E+00, -.21643800E+00, 0.61397000E+00, -.28958900E+00, 0.34231500E+00, -.21770700E+00, -.34763000E+00, -.47625700E+00, 0.17338100E+00, 0.20250300E+01, 0.35676800E+00, -.10279900E+01, -.32622000E-01, -.82629900E+00, 0.58575700E+04, -.30556800E+04, -.29347500E+04, 0.69745100E+03, -.36463100E+03, -.26803700E+04, -.25464000E+04, -.23998100E+04, -.12244000E+04, 0.11946700E+04, -.59250900E+03, -.63742800E+03, -.25182900E+03, -.22967300E+03, -.26140100E+03, 0.21507100E+03, 0.99585100E+02, -.23126400E+03, 0.33587000E+03, -.16384500E+03, -.20441000E+03, 0.27768100E+03, 0.23008600E+03, 0.20584800E+02, 0.25768400E+02, 0.64488300E+02, 0.60151100E+03, 0.56541600E+04, -.29511800E+04, -.28264800E+04, 0.71088800E+03, -.36962100E+03, -.26237200E+04, -.24306200E+04, -.24391500E+04, -.10187600E+04, 0.35780200E+04, -.16337100E+04, -.17737400E+04, 0.14910700E+03, -.32189000E+03, -.13012200E+04, -.75458300E+03, -.10872100E+04, -.45741000E+03, -.11236000E+03, 0.58392900E+02, 0.10911500E+03, 0.47387800E+02, 0.21789300E+03, -.53335400E+01, -.79629500E+02, -.39049400E+02, 0.20132600E+03, -.18583200E+03, 0.10125400E+03, 0.87359900E+02, -.47909100E+02, 0.28255800E+03, 0.21969500E+03, 0.27580500E+03, 0.25980700E+03, 0.44971500E+03, 0.28223900E+04, -.13337300E+04, -.14038300E+04, 0.18631900E+03, -.69061800E+03, -.10474800E+04, -.99694300E+03, -.69958500E+03, -.65790800E+03, 0.99277100E+01, -.57840500E+02, -.48938900E+02, -.33896400E+02, -.83824200E+02, -.32757500E+02, -.52739500E+02, -.22767500E+03, -.33971800E+02, -.67397000E+03, 0.35868400E+03, 0.31044200E+03, -.87883700E+02, 0.17425800E+03, 0.29420500E+03, 0.15320400E+03, 0.32067200E+03, -.16749600E+03, 0.11495100E+04, -.57300900E+03, -.58057300E+03, -.16044000E+03, -.29777300E+03, -.33435400E+03, 0.24553100E+03, 0.20911900E+03, -.24051700E+03, -.67122900E+03, 0.33730500E+03, 0.34463200E+03, -.14582000E+03, -.13644600E+03, 0.20067200E+03, -.16795800E+03, -.30666600E+01, -.15136000E+03, 0.86214200E+02, -.21741800E+02, 0.12989700E+03, -.44552700E+02, 0.10915500E+03, 0.59661300E+02, -.87043700E+03, 0.84475800E+02, -.12174000E+03, 0.16043700E+03, 0.17675900E+02, 0.50701100E+02, -.11417800E+03, 0.73075100E+03, 0.32869100E+03, -.42040800E+01, -.30344800E+03, -.84370100E+02, -.22800100E+03, -.13152900E+03, 0.80785900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.83699400E+00, -.54968300E-01, 0.46763400E+00, 0.13256000E+01, -.51831900E+00, -.43064300E+01, -.11885000E+01, -.14945100E+01, -.20215600E+00, 0.18685300E+00, -.11842400E+01, -.12307100E+01, 0.27084600E+00, 0.23529600E+00, 0.64515200E+00, 0.46353500E+00, 0.26037400E+00, 0.15069200E+00, -.14329000E+01, 0.36352200E+00, -.29748500E+00, 0.12907800E+01, 0.22887400E+00, -.29928600E+00, 0.13531200E-01, 0.57774500E+00, -.29767100E+00, 0.28914800E+00, 0.39355500E+00, 0.18342200E+01, 0.31533500E+00, -.50460200E+00, -.55314200E+00, 0.62010100E-01, 0.22221700E-01, -.94666300E-01, -.31679000E+00, 0.63201000E+00, 0.45569300E-01, 0.92725500E+00, -.27357400E+01, -.27399000E+00, -.14074900E+01, 0.49142300E+00, 0.60480500E+00, 0.18970000E+00, 0.26318400E+00, -.30479000E+00, -.60098300E+00, 0.12697800E+00, -.25539400E+00, -.19414800E+00, -.33013400E+00, -.55561500E+00, 0.29065700E+00, 0.50104900E-01, 0.15774800E+00, -.23413300E+00, 0.16521100E+00, 0.14399300E+01, 0.44746300E+00, -.27853000E+00, -.76531200E-01, 0.17855600E+01, -.73155400E-01, 0.40755700E+00, -.33372200E-02, -.22438600E+00, -.21978500E+00, 0.47846400E+00, -.65434000E+00, 0.16383300E+00, -.34240100E+00, -.15962700E+03, -.25989000E+01, 0.68865300E+03, -.90500800E+02, 0.98563700E+02, 0.38242900E+03, 0.16922600E+03, -.42363500E+03, 0.44761500E+03, -.22418500E+03, -.23724200E+03, -.17272100E+03, -.52832900E+02, -.14663600E+03, -.10063300E+03, -.94370300E+02, 0.30799700E+02, 0.23265800E+03, -.11061300E+03, -.13101200E+03, 0.29775700E+02, 0.98447600E+02, -.10217400E+03, -.56955100E+02, -.11807600E+03, 0.34854400E+03, -.82172300E+02, -.35397900E+02, 0.43462600E+02, 0.60564000E+03, -.85799200E+02, 0.14730900E+03, 0.46975000E+03, 0.19155200E+03, -.43595400E+03, 0.37707100E+03, 0.31644600E+02, -.18544600E+03, 0.17410800E+03, 0.81852100E+02, -.53948600E+02, -.10299200E+02, -.91816600E+02, -.10899200E+03, -.20996300E+03, 0.10775700E+03, 0.95544700E+02, 0.37464600E+01, -.87662500E+02, 0.12499000E+03, 0.31794900E+02, 0.17205300E+03, -.17363600E+02, -.36411300E+03, 0.18591200E+03, 0.19731800E+03, -.13250600E+02, 0.37767400E+02, 0.21512200E+03, 0.25306400E+03, 0.25944700E+03, 0.16290900E+03, -.25287900E+03, 0.25496400E+03, 0.11862600E+03, 0.27830400E+03, -.15126400E+03, 0.19459700E+03, 0.27211800E+02, 0.20947600E+03, -.20131500E+03, -.25246800E+02, -.15334700E+01, 0.25844600E+02, -.65768500E+02, -.48962100E+02, -.10890400E+02, -.83523500E+02, -.88712100E+02, -.21213900E+02, -.21985100E+03, 0.11940900E+03, 0.12435700E+03, 0.56225200E+02, -.12995500E+02, 0.93566500E+02, -.46311900E+02, 0.14519100E+03, -.76544800E+02, -.22664900E+02, 0.11198500E+02, 0.46725900E+01, 0.75030000E+02, 0.27027500E+02, -.25277000E+02, 0.12680500E+02, -.16934100E+02, 0.62220800E+02, -.36005900E+03, 0.17629100E+03, 0.17774600E+03, -.22053200E+03, -.65726700E+02, 0.11519500E+03, -.21564900E+03, 0.44734200E+02, -.11804600E+03, 0.10372200E+02, 0.33814000E+02, 0.32029500E+01, -.23081500E+02, 0.31651000E+01, 0.22888600E+02, -.36577200E+03, -.80997900E+01, -.28868200E+02, 0.53260800E+03, 0.89719700E+01, 0.35856400E+02, -.61078700E+03, 0.34794500E+03, 0.45822100E+01, -.34664900E+02, -.14882300E+03, -.90695000E+01, -.36206900E+02, -.35873300E+02, -.74905900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.95151300E+00, 0.81769700E+01, -.82349200E+00, 0.31447700E+00, 0.65883400E+00, -.18087300E+01, -.13661100E+02, 0.30336900E+01, -.30129900E+00, -.24572300E+00, -.27720400E+01, 0.18240400E+00, -.90381300E+00, -.11297400E+01, 0.13143500E+01, -.63453000E+00, -.42484100E-02, -.51583000E+00, -.11783800E+01, -.39287000E+00, 0.21979600E+00, -.76287700E-01, -.51791300E+00, -.50215200E+00, 0.72083700E+00, 0.38049500E-01, -.34087400E-01, -.14845500E+02, -.13062600E+00, 0.17301700E+00, -.36113800E+00, -.87301500E+00, -.10818800E+01, -.21899600E+00, 0.24667300E+00, -.14377800E+01, -.75772000E+00, 0.13298600E+01, -.28849700E+00, -.98924600E+00, 0.23552800E+01, -.25833700E+00, 0.67167300E+00, -.26060700E+00, -.37463800E+00, 0.23678100E-01, -.39365100E+00, -.13244700E+00, 0.10768300E+00, -.24409200E+00, 0.33675900E+00, 0.37072300E+00, 0.51799900E-02, -.19717100E+01, 0.13791000E-01, 0.49505100E-03, -.42761400E-02, -.38345800E-02, 0.21605300E-03, -.65155400E-02, 0.72941500E-02, 0.39936200E-02, 0.32688800E-02, -.15333600E-01, 0.50619400E-02, 0.79958100E-02, -.49722900E-02, -.54414100E-02, -.11440900E-02, 0.37803200E-02, 0.28872300E-03, 0.21277600E-02, -.13772400E-02, -.10552000E-01, 0.73874100E+01, 0.13877900E+02, 0.34971500E+01, 0.25556700E+01, 0.68182600E+01, 0.38767400E+01, -.63400000E+01, 0.34522700E+00, -.26108500E+00, -.14916700E+01, -.21309000E+01, -.45876900E+00, -.58115800E+00, -.39890800E+00, -.88739400E+00, 0.10734300E+01, -.30039200E+01, 0.15165600E+01, 0.26161900E+00, -.34534100E+01, 0.12198600E+01, 0.11220700E+01, 0.26382300E+01, 0.14411800E+01, 0.76206300E+01, -.40205800E+01, 0.24745800E+01, 0.20348700E+01, 0.11284100E+02, 0.35029400E+01, 0.37755300E+01, 0.81192800E+01, 0.49024000E+01, -.64692400E+01, -.16778800E+02, 0.99765900E+01, 0.84054700E+01, 0.65193400E+01, 0.11818600E+01, 0.68593800E+01, -.27787700E+00, 0.34233800E+01, -.96762300E-01, 0.45842400E+01, -.22373500E+01, 0.21869900E+00, -.21394000E+01, -.16445100E+00, -.57655800E+00, 0.17034600E+01, 0.16640900E+01, -.81632800E-01, 0.25836100E+00, -.64180300E-01, -.13571700E+01, -.13000400E+01, 0.14515600E+01, 0.64644600E+00, 0.18732900E+01, 0.14427900E+01, 0.34300800E+01, -.32950400E+02, 0.17313000E+02, 0.16742700E+02, 0.12522700E+02, -.99486600E+00, 0.13037600E+02, -.10071900E+01, 0.77610300E+01, -.45807500E+00, 0.56635000E+01, -.29079800E+01, -.50417300E+01, -.91358300E+00, -.99732000E+00, -.19286500E+01, -.65620100E+00, -.21013100E+01, -.10495100E+01, -.11520000E+02, 0.58939500E+01, 0.37292900E+01, -.18806100E+01, -.15063200E+00, 0.48788300E+01, 0.26951400E+01, 0.64556700E+01, -.10950200E+01, -.11589800E+01, 0.54600900E+00, 0.57642900E+00, 0.16396600E+01, 0.43815100E+00, -.58351200E+00, -.10489800E+01, -.35734400E+00, 0.12616800E+01, 0.14553000E+01, -.80945800E+00, -.14594000E+00, -.19503600E+01, -.27624100E+01, 0.50391700E+00, 0.76981100E+00, 0.36946200E+00, -.38502600E+01, 0.21364200E+01, -.20759300E+01, 0.15629200E+01, 0.78614200E+00, 0.15443400E+01, 0.17507400E+01, -.16767900E+02, 0.34260800E+00, -.31078300E+00, 0.19012900E+02, -.85437600E+00, -.66530000E+00, -.20861800E+02, 0.13768300E+02, 0.21482800E+01, -.52959300E+00, -.53743400E+01, -.21169000E+01, -.63604300E+00, 0.10121000E+00, 0.18545200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.50549800E+01, 0.25128200E+01, 0.23635200E+01, 0.53807200E+01, -.15930400E+00, -.24130300E+02, -.83469100E+01, -.46268900E+01, -.13972500E+01, 0.80024900E+00, 0.37441700E+01, -.72668000E+00, 0.15615000E+01, 0.24024700E+01, -.72115100E+00, 0.10672000E+01, -.12530500E+00, 0.40263300E+00, 0.97826800E+00, -.85632200E+00, -.73966200E+00, -.29269900E+00, 0.11302300E+01, 0.10789900E+01, 0.36767600E-01, -.37888500E+00, 0.11948800E+01, 0.17581100E+01, -.67845100E+00, -.33947300E+01, -.29985200E+00, 0.10310500E+01, -.13846900E+01, -.46674800E+00, 0.60078100E+00, -.29271800E+01, -.15159600E+01, 0.79053600E+00, 0.16634300E+01, -.14183700E+01, 0.20997000E+02, 0.91287200E+00, -.19550500E+00, -.17357900E+01, 0.11093200E+01, -.13486000E+01, -.74015000E+00, 0.16282700E+01, 0.14318600E+01, 0.77120000E+00, 0.15668100E+01, -.13221300E+01, 0.10392400E+01, -.21236100E+01, -.93286400E+00, -.26554900E+00, -.32088200E+00, 0.88313600E+00, -.56449400E+00, 0.31921300E+00, -.29862100E+00, -.31892700E+00, 0.94970700E-01, -.35710300E+00, -.59892300E+00, -.40480400E+00, 0.34843700E+00, -.19817300E+01, -.59296800E+00, 0.64988300E+00, 0.62652000E+00, -.41026800E-01, -.18400100E+00, 0.30976100E+01, 0.14036400E+01, -.34143000E+04, -.32991000E+02, -.42908200E+03, -.16077500E+04, -.69018800E+03, 0.17606200E+04, -.17895900E+04, 0.89381500E+03, 0.11911600E+04, 0.64056700E+03, 0.35424500E+03, 0.37518300E+03, 0.50197900E+02, 0.11350900E+03, 0.45614000E+02, -.42314600E+03, 0.21405000E+03, 0.46262000E+03, 0.38154500E+03, -.68396000E+03, 0.23756500E+03, 0.31855400E+02, 0.18981600E+03, -.14409100E+04, 0.15250500E+04, -.70774700E+03, -.77391000E+03, -.27229700E+04, 0.14387900E+03, -.11924700E+04, -.23242900E+04, -.13548600E+04, 0.23200600E+04, -.31295300E+04, 0.16086400E+04, 0.14081600E+04, -.87934900E+03, -.10417500E+03, 0.79060100E+03, 0.98206100E+03, 0.10984600E+04, 0.97478400E+03, -.75802900E+03, 0.37211100E+03, 0.10862400E+03, 0.26680400E+03, 0.27356100E+03, 0.10269800E+03, 0.12364200E+03, -.40457000E+03, 0.94253100E+02, -.10011900E+03, 0.42639000E+02, 0.12924700E+03, 0.50590200E+03, -.51253300E+03, -.25785100E+03, -.54102800E+03, -.52507800E+03, -.71086800E+03, -.14857500E+04, 0.79105500E+03, 0.57897900E+03, -.21048800E+04, 0.50471800E+03, 0.16158800E+03, 0.15505800E+04, 0.60565400E+03, 0.75306800E+03, -.93505300E+03, 0.52053400E+03, 0.66822900E+03, 0.24980400E+03, 0.25196800E+03, 0.37219800E+03, 0.29926600E+03, 0.66671100E+03, 0.23145700E+03, 0.40138200E+03, -.22933500E+03, -.22967000E+02, 0.11754300E+02, -.40290600E+02, -.15033500E+03, 0.36607200E+03, -.54083900E+03, 0.35786500E+03, -.41853200E+03, 0.21210300E+03, 0.23490300E+03, -.33120900E+03, 0.54501600E+01, 0.31639700E+03, -.14340400E+03, -.64223300E+02, -.23580800E+03, 0.65216700E+03, -.32874500E+03, -.38782600E+03, 0.90007700E+03, 0.50862400E+03, -.27366500E+03, 0.68895400E+03, 0.14313100E+03, 0.74930100E+03, -.42199800E+03, 0.19017800E+03, -.31796800E+03, -.98736800E+02, -.33311000E+03, -.40118500E+03, 0.30612400E+04, -.19533100E+03, -.17701400E+03, -.35553400E+04, 0.11113200E+03, 0.25953800E+03, 0.39054900E+04, -.26926500E+04, 0.43022400E+02, -.85025400E+02, 0.12671600E+04, 0.32290200E+03, -.12985100E+03, 0.12891300E+02, -.35703500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37031300E+01, 0.42176400E+01, 0.23472100E+01, 0.46000800E+01, -.15665400E+01, -.28878200E+02, -.37904300E+01, -.23635500E+01, -.17378600E+01, 0.63342000E+00, 0.26864400E+01, -.15174900E+01, 0.19098300E+01, 0.70768100E-01, 0.40936100E+00, 0.13486300E+01, 0.22554800E+00, -.52665100E+00, 0.13481600E+01, -.71073600E+00, -.26361100E+00, -.13768900E+01, 0.53474900E+00, 0.18680300E+01, 0.75485800E-01, 0.21785100E+00, 0.60628000E+00, -.27474300E+01, 0.53751600E+00, -.19360900E+01, -.42135200E+00, -.11684500E-01, 0.25912800E+00, 0.10644900E+00, 0.14171900E+01, -.86725800E+00, -.23173900E+00, 0.35358500E+00, -.10102500E+01, 0.98285000E+00, -.55905500E+00, -.79431000E-01, -.68368200E-01, -.21998900E+01, -.55975700E+00, 0.23242100E+00, 0.81546700E+00, -.53764700E+00, -.22177400E+00, 0.77321100E+00, 0.21503100E+01, 0.10597300E+01, -.43709300E+00, 0.93772400E+00, 0.34751800E+01, -.11167300E+00, -.83804900E+00, 0.14485300E+01, -.71774700E+00, -.90488100E+00, -.75450900E+00, 0.61784300E-01, 0.48441200E+00, -.22387900E+01, 0.96119100E-01, 0.10774300E+01, -.54887100E+00, -.11693600E+01, 0.28021600E+00, -.88560800E-01, 0.36460200E+00, 0.34287200E-01, 0.87795300E+00, -.42569100E+00, 0.41161900E+00, -.40290100E+00, 0.16792700E+04, -.16478900E+03, -.61388300E+02, -.57816100E+03, 0.19844500E+04, -.25082300E+04, 0.12432800E+04, 0.12568900E+04, 0.38480500E+03, 0.22229800E+03, 0.60519400E+03, -.14946700E+03, 0.83210400E+02, 0.31108400E+03, -.15772800E+04, 0.78926100E+03, 0.79129800E+03, -.20665400E+03, -.54720400E+03, 0.47069100E+03, 0.48107700E+03, 0.39141800E+03, -.75161500E+03, 0.60926800E+02, 0.25533200E+02, -.31833800E+02, -.24813400E+02, 0.13737800E+04, -.14408100E+03, -.18037400E+03, -.39531100E+03, 0.19293400E+04, -.38510300E+04, 0.20449400E+04, 0.19297600E+04, 0.12871200E+03, 0.48278700E+03, 0.13855200E+04, 0.66982800E+03, 0.10060200E+04, 0.90078100E+03, -.65591400E+03, 0.32800100E+03, 0.26940900E+03, -.34207700E+03, -.37329400E+03, 0.30965400E+03, 0.29280800E+03, 0.23335700E+03, -.25656900E+03, -.58873900E+03, 0.28612800E+03, 0.33141000E+03, -.40186800E+02, -.44992400E+03, 0.19968600E+02, -.16942400E+03, -.96722100E+02, -.49070600E+03, -.31999800E+04, 0.16924400E+04, 0.15865500E+04, -.72607200E+02, 0.97304700E+03, 0.10425300E+04, 0.70713500E+03, 0.49831300E+03, 0.98007900E+03, -.68359700E+02, 0.95974100E+02, 0.96866800E+02, 0.83855100E+02, 0.12901500E+03, 0.83203900E+02, 0.11258300E+03, 0.37153300E+03, 0.66126100E+02, -.50224300E+03, 0.22836300E+03, 0.30468300E+03, -.65386200E+02, -.47619000E+03, 0.16042300E+03, 0.22598300E+03, 0.10499000E+03, 0.13100000E+03, -.17506900E+04, 0.87337200E+03, 0.87060100E+03, 0.99380200E+02, 0.41283200E+03, 0.53084800E+03, -.52764900E+03, -.35182900E+03, 0.26965100E+03, 0.57732000E+03, -.29675600E+03, -.30114100E+03, 0.48115300E+03, 0.20228000E+03, -.10106200E+03, 0.53671800E+03, 0.18047900E+03, 0.34006400E+03, -.30273500E+03, 0.21590600E+03, -.40708100E+03, -.85361300E+02, -.36623800E+03, -.18764500E+03, 0.72447200E+03, -.38718500E+02, 0.30224800E+02, 0.51184000E+03, 0.13824000E+03, 0.31254100E+02, -.72401000E+03, -.63722500E+03, -.11316300E+03, 0.14249600E+02, 0.33702700E+03, 0.31947500E+03, 0.18880400E+03, -.26169400E+02, -.37285600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.40784100E+00, 0.42020900E+01, 0.22753500E+00, -.35456600E+00, 0.26092900E-01, -.34754600E+00, 0.32690900E+01, -.32036900E+00, -.77517400E-01, 0.20408500E+00, 0.74040800E+00, -.37785300E+00, 0.56276200E+00, 0.53510000E+00, -.37309300E+00, 0.78384300E-01, -.53812200E-01, 0.24618300E+00, 0.10858500E+01, -.39860000E-01, -.38668900E-01, 0.41715400E-01, 0.84539500E-01, -.10870500E+00, -.19635900E-02, 0.90904000E-03, 0.89278700E-01, 0.55033300E+00, -.56913400E-01, 0.92599400E-01, 0.11306800E+00, 0.32228400E-01, 0.11724400E+00, -.15327700E-01, 0.16437600E+00, 0.84013900E-01, 0.26171100E-01, 0.80385900E-01, 0.17568000E+00, -.38205800E+00, -.14612300E+00, 0.11628600E+00, -.21955600E+00, 0.19359100E+00, 0.14876600E+00, -.83801100E-02, 0.10999900E+00, 0.45530700E-01, -.13233900E+00, 0.10249700E+00, -.18712800E+00, -.98711200E-01, 0.20005400E-01, -.52508900E-01, -.56718100E+00, 0.13512300E-01, 0.62479600E-01, -.15006100E+00, 0.70182700E-01, -.20764800E+00, -.24636100E+00, -.22750700E-01, -.88406900E-02, 0.20805400E+00, 0.21836400E+00, 0.89542400E-01, 0.43144500E-01, 0.23903800E+00, -.65190400E-03, -.23450900E-01, -.58343300E-01, 0.96517500E-01, -.11946700E+00, -.22954700E-01, -.40446200E-01, -.26501000E-01, 0.37882900E-01, 0.69714100E+02, 0.24667800E+03, 0.64242500E+02, -.23144200E+03, 0.21378500E+03, -.10698600E+03, -.93624100E+02, -.21217300E+02, -.51394300E+02, -.63918000E+02, -.61033400E+01, 0.87255600E+02, -.23547400E+02, 0.32610700E+03, -.16224500E+03, -.14543700E+03, 0.12023100E+03, 0.52556300E+02, -.11352100E+03, -.84630800E+02, -.10094200E+03, 0.11709700E+03, 0.37630700E+03, -.16002700E+03, -.18762300E+03, 0.48798900E+02, 0.16520400E+03, -.11742000E+03, 0.12227800E+03, -.13294600E+03, -.12099900E+03, 0.58865400E+02, -.39081700E+02, -.27449700E+02, -.12536200E+03, -.21271600E+03, 0.38322500E+02, 0.10446200E+03, 0.14060000E+03, -.23568900E+03, -.21422200E+03, 0.10606100E+03, 0.91805700E+02, 0.91547200E+01, -.52098300E+02, 0.12436200E+03, 0.32565500E+02, 0.53916800E+02, -.40439700E+02, -.42405200E+02, 0.21731200E+02, 0.22446900E+02, 0.52650000E+02, -.21925300E+02, 0.63025100E+02, 0.10888600E+03, 0.75775500E+02, -.11683000E+02, -.35056100E+03, 0.16969800E+03, 0.17420100E+03, -.21115900E+03, -.39574900E+03, 0.22856200E+03, 0.24346900E+03, 0.34564600E+03, -.36294600E+03, -.56334500E+02, 0.31686300E+02, 0.48740500E+02, -.20644100E+02, 0.38262700E+01, 0.83403800E+01, -.32274700E+02, -.35331800E+02, 0.14993800E+02, -.34957100E+03, 0.17322800E+03, 0.18850500E+03, 0.33301200E+01, -.51602300E+02, 0.18939600E+03, 0.88936100E+02, 0.16624500E+03, -.11142600E+03, 0.25985600E+03, -.12950100E+03, -.11633300E+03, -.14145700E+02, -.34731000E+02, -.87814900E+02, 0.69802400E+02, 0.58505500E+02, -.26142300E+02, -.22545300E+03, 0.11203000E+03, 0.10779200E+03, -.12118600E+03, -.10639000E+03, 0.76456500E+02, -.14815300E+03, 0.19177500E+01, -.97471800E+02, 0.43038000E+02, -.41064500E+02, 0.60243500E+02, 0.14303600E+02, 0.42652900E+02, 0.14341800E+02, 0.30900200E+02, -.35437300E+02, 0.49679000E+01, -.15215700E+03, -.11927800E+02, 0.32685300E+02, 0.20118500E+03, -.21242500E+02, 0.13789100E+02, -.23173800E+02, 0.33147000E+02, -.58955500E+02, -.62257500E+01, -.23071300E+02, 0.65438500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.32762700E+01, -.19812700E+00, -.19985100E+01, -.26635600E+01, 0.10884600E+01, 0.11813800E+02, 0.88099700E+01, 0.42010400E+01, 0.70623100E+00, 0.40850900E-01, 0.18980200E+01, 0.26574800E+00, -.75681600E+00, -.50008800E+00, -.76635100E-01, -.33734800E+00, -.27125500E+00, -.24907500E+00, -.10985200E+01, 0.42815300E+00, 0.17706000E+00, 0.43327300E+00, -.17249900E+00, -.79522800E+00, 0.72169000E-01, 0.16319100E+00, -.34928800E+00, 0.94356600E+01, 0.53309900E-01, -.14213400E+00, 0.10822800E+00, 0.34876000E+00, -.41474300E-01, 0.46935800E-01, 0.61624200E-01, 0.16961100E+00, -.17693500E+00, 0.47139800E-01, 0.14338100E+01, 0.15910500E+01, 0.85309700E+01, 0.11832700E+00, 0.54883600E+00, 0.60540600E+00, -.98184900E-01, -.11771400E+00, -.41954500E+00, 0.56278200E+00, 0.84840700E+00, -.63346600E+00, 0.65028900E+00, -.33401800E+00, 0.53587400E+00, -.19571100E+01, -.97086900E+00, -.21854800E+00, 0.42469400E+00, 0.22157300E+00, -.18299500E+00, -.90616300E+00, -.57002300E+00, 0.25028200E+00, -.73014900E-01, -.10077500E+01, -.53112600E+00, -.89271100E+00, 0.24046500E+00, -.31850000E+00, -.38099100E+00, 0.28032100E+00, 0.37899600E+00, 0.21527300E+00, -.88751500E-02, -.11993700E+01, 0.43804000E-01, 0.10903300E+00, -.34374000E+00, -.19969800E-01, 0.33138600E+03, 0.96101400E+02, -.57380500E+02, -.42224400E+03, 0.21335600E+03, 0.21413600E+03, 0.97860000E+02, 0.93344300E+02, -.21788900E+02, -.19022300E+03, -.68637200E+02, 0.21523500E+03, -.10437700E+03, 0.51832600E+02, 0.57314900E+02, 0.38906500E+03, 0.14101500E+02, -.45771800E+02, -.73979100E+02, -.16100100E+03, 0.19825200E+03, 0.63920600E+03, -.31966500E+03, -.32479500E+03, 0.97202900E+02, -.57860500E+02, -.26921700E+03, 0.85666200E+02, -.20469700E+03, 0.96573300E+02, -.45537100E+03, 0.27183400E+03, 0.24463500E+03, -.19373700E+03, -.16402500E+03, 0.33530300E+03, 0.32125100E+03, 0.44957400E+03, -.50073000E+01, -.13588300E+04, 0.67717300E+03, 0.58782400E+03, 0.65907100E+02, -.18431600E+03, 0.51777200E+03, 0.66181300E+02, 0.21430500E+03, -.81232400E+00, -.80090300E+03, 0.39640300E+03, 0.46180800E+03, 0.16550300E+03, -.13345400E+03, 0.31313800E+03, 0.26168700E+03, 0.27120900E+03, -.64910000E+00, -.50459000E+03, 0.30239500E+03, 0.22643700E+03, -.44262000E+03, -.22604200E+03, 0.33682200E+03, 0.45522200E+03, 0.50738300E+03, -.21726900E+03, -.27970000E+03, 0.13936700E+03, 0.24333800E+03, -.20361300E+01, 0.32671800E+02, 0.89553200E+02, 0.40596500E+01, 0.98606900E+02, 0.61055500E+02, -.11413000E+04, 0.56438000E+03, 0.65987600E+03, 0.17139400E+03, -.22222900E+03, 0.43699200E+03, 0.15001300E+03, 0.26825300E+03, -.72843600E+02, -.47544300E+03, 0.23829400E+03, 0.23150400E+03, 0.20574900E+02, 0.13360700E+03, 0.16427600E+03, -.95252400E+02, -.13379900E+03, 0.10852100E+03, -.51047300E+03, 0.25841600E+03, 0.23315100E+03, -.12752500E+02, 0.92886600E+02, 0.95963500E+02, -.16940300E+03, 0.12769800E+03, 0.11804500E+03, -.14197500E+03, 0.19395800E+03, -.15536300E+03, -.53877600E+02, -.15062500E+03, -.97495800E+02, 0.53416200E+03, -.93110800E+02, -.12818300E+03, -.37901600E+03, 0.78214400E+02, 0.14559200E+03, 0.34363100E+03, -.37538300E+03, -.18125400E+02, -.81450500E+02, 0.21890400E+03, 0.17755600E+03, -.66340500E+02, -.37262300E+02, -.19883600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.12912200E+00, -.19264900E+01, 0.12526800E+00, -.13282300E+00, -.80803000E-01, 0.19207100E+01, 0.25498200E+01, -.93644600E+00, 0.15530700E+00, 0.10721600E+00, -.90786700E+00, 0.55932900E-02, 0.15363300E+00, 0.31525700E+00, -.40164400E+00, 0.22944100E-01, -.13653400E-02, 0.31974300E+00, 0.58898100E+00, -.27298200E+00, 0.47096000E-01, -.32487800E+00, 0.91786900E-01, 0.72189000E+00, -.25973000E+00, -.53689900E-02, -.12021400E+00, 0.41716000E+01, 0.12766400E+00, -.38293300E-01, -.72599700E-01, 0.38220200E-01, 0.14963600E+00, 0.87369500E-01, -.28148500E+00, 0.31848900E+00, 0.22011200E+00, 0.56058000E-01, -.13995600E+00, 0.72935200E+00, -.27640100E+00, -.13464300E-01, 0.68805800E+00, 0.56133400E-01, -.51866500E-01, 0.48921400E-02, -.82248600E-01, -.31563600E-01, -.65441500E-01, -.71953700E-01, -.36863400E-01, 0.29989300E-01, -.19410400E-02, -.30395600E+00, 0.33310300E-01, 0.97763300E-02, 0.91986900E-01, -.10684900E+00, 0.48179100E-01, -.18025000E+00, -.55927600E-03, 0.85591700E-02, 0.96362500E-02, -.16701700E+00, -.34043400E-01, -.15276800E-01, -.10824300E-01, 0.29344100E+00, 0.56036900E-01, -.86021700E-01, -.22007500E-01, -.39077000E-01, 0.17831500E-01, -.95404100E-01, 0.33184400E-01, -.22660000E-01, -.31253200E-01, -.12477900E+00, 0.12584300E-02, 0.30405100E+02, 0.17551600E+02, 0.12860700E+02, -.63259700E+01, -.12185100E+02, -.16447000E+02, -.93224900E+01, -.73138800E+01, 0.13090600E+01, 0.66434700E+01, -.37024400E+01, 0.19341700E+02, -.96640600E+01, -.11281700E+02, -.10369000E+02, 0.12799100E+02, -.12189600E+02, -.20581300E+02, -.12808200E+02, 0.11882300E+02, -.19059000E+02, 0.99713500E+01, 0.76851900E+01, 0.15889600E+00, 0.98311500E+01, 0.12069400E+02, 0.19397200E+02, 0.38793900E+02, 0.39872000E+01, 0.62846000E+02, -.14496500E+02, -.25846700E+02, -.90920900E+01, -.28289600E+02, -.14018400E+02, 0.94748800E+01, -.23743700E+02, -.26295900E+02, -.13549900E+02, 0.70216100E+01, 0.76561900E+01, 0.89040700E+01, 0.15775900E+02, -.47556600E+01, -.12077000E+02, 0.56718400E+01, 0.10888300E+02, 0.48227700E+02, -.24195200E+02, -.24061400E+02, 0.11874200E+01, 0.21355800E+02, -.18735000E+02, -.74641600E+01, -.28897000E+02, 0.17085200E+02, -.23195900E+02, 0.24403300E+02, 0.16361700E+02, -.85594600E+01, -.61225700E+02, 0.19924000E+02, 0.21993200E+02, 0.23398200E+02, -.18753500E+02, 0.89128900E+02, -.46002700E+02, -.41253500E+02, 0.12839500E+01, 0.51585900E+01, -.30093900E+02, 0.41528200E+01, -.30229200E+02, -.65056800E+01, -.31947600E+01, 0.24509600E+01, 0.38447400E+01, 0.39682500E+01, 0.15571100E+02, -.12274300E+02, -.27201900E+02, -.29602900E+01, 0.13041700E+02, 0.29083600E+02, -.14411900E+02, -.98133100E+01, -.33348600E+01, -.10014600E+02, -.44683900E+01, 0.12931500E+02, 0.63128900E+01, -.62206900E+01, 0.28329900E+02, -.14125800E+02, -.14451100E+02, -.94636300E+01, -.29643700E+00, -.17765800E+02, -.67599700E+01, -.19904600E+02, -.21489100E+01, 0.16096000E+02, -.19447000E+02, 0.21073500E+02, 0.88460000E+01, 0.17916400E+02, 0.11513800E+02, -.11740200E+02, -.19329000E+01, 0.16731900E+01, -.89835800E+01, -.11225600E+02, -.10362100E+02, -.13608400E+01, 0.21913200E+02, -.94243900E+00, -.34715200E+01, -.72815500E+01, -.20334000E+02, 0.23321100E+01, 0.18503100E+02, 0.24585600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.65522300E+00, 0.39801200E+00, 0.45722800E+00, 0.13483600E+01, -.28394900E+00, -.38022700E+01, 0.11230700E+01, 0.59880000E+00, -.19073300E+00, 0.33717200E+00, -.19121300E+01, -.93559800E+00, -.50895700E-01, 0.22227200E+00, -.12885600E+00, 0.53668200E+00, 0.52684000E-01, 0.21062900E+00, 0.52412200E-02, 0.76518200E-01, 0.19194600E+00, -.28720800E+00, -.90082800E-01, 0.24748200E+00, 0.23171200E+00, 0.74271800E-01, 0.10243900E+00, 0.25676000E+00, 0.15003700E-01, -.12708000E+00, 0.15410100E+00, -.54108300E+00, -.25389400E+00, 0.15900800E+00, 0.27459000E+00, -.11341400E+00, -.13322800E+00, -.40717600E-01, 0.21812200E+00, 0.34814800E+00, 0.15255700E+01, -.10043800E-01, -.10221500E+00, -.91369200E+00, 0.21666500E+00, -.91446300E-01, -.49842300E-01, 0.11705900E+00, -.76335400E-01, 0.67561200E-01, 0.55648300E+00, 0.84693500E+00, 0.20159800E-01, 0.63756600E+00, 0.56022100E-01, 0.59896300E-02, -.21813500E+00, 0.19765500E+00, -.11305700E+00, 0.27807200E+00, -.47911600E-03, -.45916800E-01, -.13771600E+00, 0.11511300E+00, -.17065300E+00, 0.93494100E-02, 0.75298200E-01, -.32856900E+00, -.10762000E+00, -.74456200E-01, -.17823300E+00, -.80311800E-01, 0.28982400E+00, -.89997700E-01, -.14867100E+00, -.16625600E-02, -.71514600E-01, 0.52275300E+00, -.13825400E+00, -.16930800E+01, 0.48110600E+03, -.43294200E+03, 0.21743800E+03, 0.22922300E+03, 0.21956900E+02, 0.12292200E+03, 0.32988000E+02, -.14354700E+03, -.19754300E+03, 0.13845200E+03, -.34503700E+03, 0.17200300E+03, 0.17868100E+03, -.16101300E+03, -.11008000E+03, 0.64869700E+02, -.36311200E+01, 0.12485900E+02, -.21852400E+03, -.68145600E+03, 0.29958300E+03, 0.33852900E+03, -.74973800E+02, -.11213500E+03, 0.30834200E+03, 0.22605900E+03, 0.33233000E+03, 0.35736600E+03, -.11240500E+04, 0.61407100E+03, 0.55602800E+03, 0.15916200E+03, 0.41004800E+03, 0.29264200E+03, 0.19624500E+03, 0.23031800E+03, 0.42407500E+03, -.22886000E+03, 0.11515100E+03, 0.64484200E+02, 0.29505600E+02, -.41106300E+02, 0.61908900E+02, 0.37716300E+02, 0.88017500E+02, -.41789900E+01, -.22802300E+03, 0.10954800E+03, 0.13947300E+03, 0.16830100E+02, -.67996100E+02, 0.43528600E+01, -.67426500E+02, -.25003700E+02, -.54344700E+02, -.46799100E+03, 0.28065000E+03, 0.21448400E+03, 0.19870900E+03, 0.54423800E+03, 0.15633300E+02, 0.14017100E+03, -.11682600E+02, 0.53295800E+03, -.36899600E+02, 0.24566300E+02, 0.68324700E+02, 0.17784100E+02, 0.37273800E+02, 0.21088600E+02, 0.41727000E+02, 0.84510300E+02, 0.12529300E+02, 0.19813700E+03, -.10337300E+03, -.58717700E+02, 0.96173000E+02, -.40318700E+01, -.17492100E+03, -.13812800E+03, -.16620200E+03, 0.18168500E+03, -.53447600E+03, 0.26734200E+03, 0.26690900E+03, 0.41947800E+02, 0.10674000E+03, 0.20361400E+03, -.10188700E+03, -.14994700E+03, 0.77588500E+02, 0.84250000E+02, -.40758400E+02, -.52285700E+02, 0.18588800E+03, 0.19573800E+03, -.80543100E+02, 0.10117700E+03, 0.48359300E+02, 0.18071900E+03, -.13942500E+03, 0.15305000E+03, -.13433200E+03, -.53989600E+02, -.12950900E+03, -.61203600E+02, 0.22022500E+03, -.18779300E+02, -.55622400E+02, -.55395100E+02, 0.46548600E+02, -.46757500E+01, 0.70947500E+01, -.21635800E+03, -.71636300E+02, -.16417300E+02, 0.75175000E+02, 0.16902300E+03, 0.33797400E+01, 0.26772000E+02, -.18598800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.75347900E+00, -.74266600E-01, -.42570200E+00, -.14778300E+01, 0.51905300E+00, 0.78400300E+01, -.67663900E+00, 0.14369100E+00, 0.41575600E+00, -.54908700E+00, 0.12381900E+01, 0.67427100E+00, -.48630400E+00, 0.25261100E+00, -.18215600E+00, 0.34311000E+00, -.17401000E+00, -.66224500E+00, -.21903700E+00, -.53002300E+00, -.94099100E-01, -.38929300E-01, -.26093300E+00, -.14138800E+01, 0.27286100E+00, -.24342700E+00, -.20563400E+00, 0.49244400E+01, 0.56843900E-01, -.17122100E+01, -.74860700E+00, 0.17164900E+01, 0.82750700E+00, -.36070000E+00, -.15070800E-01, -.47541900E+00, 0.21155000E+00, 0.68846200E-01, 0.13868700E+01, 0.21446200E+01, 0.78478600E+01, -.14557400E+00, 0.85473100E+00, 0.69188500E+00, -.16083300E+00, -.10887500E+00, -.75940300E+00, 0.70559000E-02, 0.28547300E+00, -.54813800E+00, 0.42058700E+00, -.26088800E+00, 0.72755200E-01, -.16147000E+01, 0.70243600E+00, -.41699700E+00, 0.44533300E+00, 0.67105000E+00, -.25653900E+00, -.13440500E+00, -.21178000E+00, -.24995000E-01, -.95489100E-01, 0.29881900E+00, -.46756400E+00, -.53975500E+00, 0.15699300E+00, 0.73923100E+00, 0.15779400E-01, -.95281500E-01, 0.22327500E+00, 0.14772300E+00, 0.10830900E+00, -.40510600E+00, -.15306100E+00, -.20091700E-01, -.13775100E+00, -.15878000E+00, 0.40277500E+00, -.21380300E+01, 0.30985800E+00, 0.77853000E+03, -.38553600E+03, -.42014900E+03, -.20909400E+03, -.19942200E+03, -.71130300E+02, 0.16949800E+03, 0.38026900E+02, -.25235300E+03, 0.51093600E+02, -.24746400E+02, -.28844000E+02, -.14624100E+03, 0.13033500E+03, 0.39929300E+02, 0.59725800E+02, 0.11231300E+03, -.32062300E+02, -.65891300E+02, -.66682400E+01, 0.31191100E+02, -.12963200E+02, 0.20135200E+02, 0.33560600E+02, 0.24686200E+02, 0.44215700E+02, -.85712700E+02, 0.39497600E+03, -.18584300E+03, -.17022400E+03, -.18424600E+02, -.14805600E+03, -.13664800E+03, 0.36703900E+00, -.19708100E+03, -.10841700E+03, 0.46365200E+03, -.23105100E+03, -.19469700E+03, -.35045200E+02, 0.10092200E+03, -.18232100E+03, -.16122400E+02, -.34837900E+02, 0.22364000E+02, 0.37357700E+03, -.18715600E+03, -.20122600E+03, -.32052300E+02, 0.15989500E+03, -.11606600E+03, -.10342200E+03, -.11051800E+03, 0.49101200E+02, -.75215800E+02, 0.40750100E+02, 0.77624500E+02, 0.35672700E+02, -.31181300E+03, 0.72252700E+02, 0.20365300E+02, 0.28634300E+02, -.18083400E+02, 0.81522700E+03, -.41592300E+03, -.42848500E+03, 0.24324100E+01, -.29443800E+02, -.25608900E+03, 0.25392100E+02, -.28800900E+03, -.10408500E+03, 0.18558900E+03, -.91094600E+02, -.10628700E+03, -.84524900E+02, 0.11435100E+03, -.83211500E+02, -.49428000E+02, 0.55577900E+01, -.13710500E+02, 0.61643700E+03, -.30779800E+03, -.28451700E+03, -.75612500E+02, -.20022000E+03, -.14671500E+03, 0.24336500E+03, 0.17441800E+03, -.15311800E+03, 0.59135500E+03, -.29310400E+03, -.29094400E+03, -.88340300E+02, -.11207800E+03, -.19109600E+03, -.97453300E+02, -.33025900E+03, -.11168100E+03, 0.11526600E+02, -.69745100E+02, 0.12068300E+03, -.26729800E+02, 0.11280400E+03, 0.28131600E+02, -.30017200E+03, 0.59444800E+02, 0.48368100E+02, 0.66326300E+01, -.11546900E+02, -.60272800E+02, -.39975100E+01, 0.25976800E+03, 0.63338400E+02, 0.72814700E+02, -.14063100E+03, -.76551300E+02, 0.77743200E+01, 0.78573800E+02, 0.16455500E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.81903000E+00, 0.14680300E+00, 0.10104000E-01, 0.12332700E+01, 0.44310500E-01, -.46765300E+01, 0.15281900E+01, -.15642100E+00, -.22062800E+00, 0.42072600E+00, 0.30069500E+00, -.51867000E+00, 0.27045500E+00, 0.52573500E+00, -.29150900E+00, 0.19991600E+00, -.11694200E-01, 0.12703400E+00, -.42145600E+00, 0.37355000E-01, 0.23950500E+00, 0.90709800E-01, -.71057900E-01, 0.27324600E+00, 0.11867400E+00, 0.14431400E+00, 0.17483300E+00, -.71124300E+00, -.34851700E-01, -.28460800E+00, 0.13828500E+00, 0.75352500E-01, -.20663500E+00, 0.14506400E-01, -.14217800E+00, -.38017400E+00, -.24921200E+00, -.18375300E+00, 0.10039000E+00, -.44010500E-01, 0.49120300E+01, 0.18582500E+00, 0.94919600E-01, -.54521600E+00, -.18509300E-01, 0.40063400E+00, 0.13483800E-01, 0.12922200E+00, 0.20655400E+00, 0.25036000E+00, 0.82647400E+00, -.10537900E+00, -.10743800E-01, 0.61737200E+00, 0.15883700E+00, 0.12321400E+00, -.25158900E+00, -.59640400E+00, 0.19015100E+00, -.87452400E+00, 0.43916700E-01, -.22314300E+00, 0.63442200E-01, 0.23744700E+00, 0.15154300E+00, 0.32471200E+00, -.68892800E-01, 0.10647900E+01, -.50087800E-01, -.34654500E-01, -.13477600E+00, -.49063900E-01, 0.13234400E-01, -.10379800E+00, -.73513100E-01, -.83082300E-01, -.17819800E+00, -.94293800E-01, 0.18389800E+00, -.13618100E+01, 0.46429500E+00, -.24254900E+00, -.55326300E+01, -.69191400E+02, -.34189300E+02, -.79969600E+02, -.56751300E+01, 0.70367200E+02, 0.16485300E+03, -.86262800E+02, 0.43857900E+03, -.21720200E+03, -.23597600E+03, -.44977700E+02, 0.19611500E+03, -.18220000E+03, -.92711700E+02, -.97789300E+02, 0.62276500E+02, 0.32122900E+03, -.83001200E+02, -.16259200E+03, 0.31482400E+02, 0.18101600E+03, -.13244400E+03, -.45882500E+02, -.14724000E+03, 0.47894700E+00, 0.25126200E+03, -.10026300E+03, -.67158600E+02, -.12620200E+03, -.44612100E+03, 0.17972300E+02, 0.31644300E+02, 0.57934800E+02, -.34460600E+03, 0.62464200E+03, -.31093600E+03, -.23399600E+03, -.33474700E+02, 0.13096900E+03, -.23852100E+03, -.14159800E+03, -.10745900E+03, 0.37999200E+02, 0.74778400E+03, -.37048400E+03, -.41205100E+03, -.74742000E+02, 0.13654500E+03, -.25003900E+03, -.77723800E+02, -.26591000E+03, 0.34636500E+02, -.33953500E+03, 0.17324500E+03, 0.23716700E+03, -.97987300E+02, -.69447800E+03, 0.26123200E+03, 0.31840500E+02, 0.27430200E+03, -.31195400E+03, 0.14772500E+03, -.60586200E+02, -.10758000E+03, -.34390600E+02, 0.25379600E+02, -.59007600E+02, -.22213500E+02, -.67393800E+02, -.25668900E+01, 0.16678300E+03, -.81646900E+02, -.11813800E+03, -.10461900E+03, 0.83717100E+02, -.62290900E+02, -.85954100E+02, 0.89976500E+02, -.45134400E+02, 0.33683000E+03, -.16878200E+03, -.12180500E+03, 0.98414100E+01, -.53035500E+02, -.14442800E+03, -.19753300E+01, -.36259500E+02, -.21047100E+02, 0.81523200E+02, -.47436200E+02, -.30311300E+02, -.19187700E+03, -.17262200E+03, 0.22984000E+02, 0.12010700E+01, 0.13766400E+03, -.18972400E+03, 0.28456300E+03, -.36170200E+03, 0.27945500E+03, 0.15615000E+03, 0.21539800E+03, 0.18862600E+03, -.34434700E+03, 0.13703400E+02, 0.13359500E+03, 0.12555200E+03, -.15008600E+03, -.17557500E+03, -.11843300E+03, 0.35534700E+03, -.40691600E+02, 0.35157600E+02, -.12800500E+03, -.35953700E+03, 0.10950200E+03, 0.46053100E+02, 0.30901600E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24551300E+01, 0.15302400E+01, 0.15148000E+01, 0.28918900E+01, -.16420800E+01, -.91112700E+01, -.63293100E+00, -.37310600E+01, -.45999300E+00, -.19471700E-01, -.15433200E+01, -.45295100E+00, 0.49671600E+00, -.12038700E+00, 0.20049000E-01, 0.75680000E+00, 0.33378200E+00, -.45987600E+00, 0.10734300E+01, -.75398500E+00, -.56175400E-01, -.99483900E+00, 0.92435800E-01, -.12364800E-01, -.10071900E-01, -.13007700E+00, 0.24318900E+00, 0.17454000E+01, -.12537600E+00, -.62993400E+00, 0.55233800E-01, 0.58912900E+00, 0.27630400E+00, -.10752600E+00, -.48485400E-02, -.53150900E-01, -.13608400E+00, -.20085500E+00, -.30217900E+00, -.23966400E-01, -.22280400E+01, 0.47457600E-01, -.40763700E-01, -.14920400E+01, -.32962000E+00, 0.56923800E+00, 0.49919500E+00, -.39495300E+00, 0.37721500E+00, 0.10327400E+01, 0.72859800E+00, 0.36709600E+00, -.17676400E+00, -.19485500E+00, 0.22180900E+00, -.33107600E-01, -.80436800E+00, 0.18290300E+00, -.21432300E+00, -.70337200E+00, 0.49925400E+00, -.56910700E+00, -.22888200E+00, 0.41563700E+00, -.54989900E+00, 0.67875100E+00, -.16667200E+00, -.28916400E+00, -.19755100E+00, 0.27101200E+00, -.50040200E+00, 0.14472700E+00, -.12109900E+00, 0.59265900E+00, -.40021200E-01, 0.49259900E-01, -.15515800E+00, 0.14989400E+01, -.47202000E+00, 0.30301100E+00, 0.20732300E+00, -.10188100E+01, -.12720600E+01, -.12109500E+03, -.45874200E+01, -.74572400E+02, 0.29343900E+02, 0.12974700E+03, 0.35450300E+02, -.99759900E+02, -.14942500E+03, 0.77106000E+02, 0.16450000E+02, -.10142500E+03, 0.32078700E+03, 0.43601800E+02, 0.64339800E+02, 0.13799400E+03, -.68653700E+02, -.63405900E+02, 0.25480100E+02, 0.25218000E+02, -.15626600E+02, -.49743900E+02, 0.40115100E+02, 0.19258400E+02, 0.53309900E+02, -.56226200E+02, -.74692900E+03, 0.45167100E+03, 0.47933400E+03, -.28106000E+02, -.32569600E+03, 0.36295400E+03, 0.37319700E+03, 0.40921800E+03, 0.51608200E+01, 0.48117000E+03, -.23898000E+03, -.14598400E+03, -.11337500E+03, 0.19448300E+03, -.22464700E+03, -.91577100E+02, -.54190000E+02, 0.96740900E+02, 0.82087100E+03, -.41137900E+03, -.43643200E+03, -.70184700E+02, 0.28687300E+03, -.32707000E+03, -.23886900E+03, -.36509500E+03, 0.45194100E+01, -.10832800E+04, 0.58947400E+03, 0.64775700E+03, 0.62685600E+02, -.47565700E+03, 0.47467900E+03, 0.19837700E+03, 0.47276700E+03, 0.12084000E+03, 0.55551300E+03, -.27622100E+03, -.31275400E+03, -.88092800E+00, 0.30675400E+02, -.18111000E+03, 0.35933600E+02, -.22446400E+03, -.20646600E+02, -.80470800E+02, 0.37827100E+02, 0.99057000E+01, -.12925600E+03, 0.96586100E+02, -.35959300E+02, -.42880000E+02, 0.18154500E+03, 0.18108500E+02, 0.34000100E+03, -.17033600E+03, -.12714900E+03, -.25646100E+02, -.11471200E+03, -.82588800E+02, 0.44805500E+02, -.13862800E+03, -.74171600E+02, 0.54332600E+03, -.27151600E+03, -.25933400E+03, -.46425000E+02, -.53711300E+02, -.18693200E+03, 0.38099800E+02, -.14543200E+03, -.10778500E+01, 0.16804600E+03, -.23243200E+03, 0.22976400E+03, 0.75180400E+02, 0.16136800E+03, 0.17001500E+03, -.41600900E+03, 0.70923400E+02, 0.55345800E+02, 0.16104700E+03, -.69325500E+02, -.22642000E+03, -.15421300E+03, 0.39977600E+03, 0.85960300E+02, 0.12349600E+03, -.17801800E+03, -.23683300E+03, 0.47834900E+02, 0.67714100E+02, 0.25732000E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25398000E+01, -.25092600E+01, 0.14429400E+01, 0.18067000E+01, -.23754100E+00, -.65787600E+01, 0.35818400E+00, -.40712800E+01, -.31366800E+00, 0.20962200E+00, 0.25966900E+01, -.81728200E+00, 0.14255900E+01, 0.57768500E+00, 0.52133500E+00, 0.13177600E+01, 0.25862500E+00, -.39438500E+00, -.16909800E+00, 0.18684300E+00, -.36033300E+00, 0.28270200E+00, 0.28585100E+00, 0.16073300E+01, -.99396400E+00, 0.71415700E+00, 0.63710200E-01, -.41711300E+01, -.13716500E+00, -.67780300E+00, -.62123900E+00, 0.13675500E+01, 0.79279000E+00, -.45482900E-01, 0.17716700E-01, 0.13874800E+00, -.26536900E-01, -.18987000E+00, -.53156000E+00, 0.54397000E+00, -.24541700E+01, -.30501100E+00, 0.38196200E-02, -.29177900E-01, -.31310200E+00, 0.50027400E+00, -.15679000E+00, -.72972200E+00, -.90185000E+00, 0.37931100E-01, -.77159500E+00, -.45043300E+00, -.60139700E+00, -.12520800E+01, 0.20421600E+00, -.72365000E-01, 0.22009000E-01, -.11358700E+00, 0.73306700E-01, 0.18393300E+01, 0.16871400E+01, -.20151800E+00, 0.19188000E+00, -.10270500E+01, 0.23913700E+00, -.11650900E+00, 0.96216800E-01, 0.27454100E+00, -.95218300E-01, -.67142400E-01, -.91564300E+00, -.47414400E+00, -.38073200E+00, 0.97569600E+00, 0.55205100E+00, 0.18215900E+00, -.16264100E+00, 0.55272200E+00, 0.54545400E-01, 0.27977800E+00, -.58069900E+00, -.73178300E+00, -.28336700E+00, 0.26533200E+00, 0.18795500E+03, 0.90517200E+02, 0.44268200E+02, 0.11631100E+03, -.20482900E+03, 0.49605600E+02, -.41410500E+03, 0.20660800E+03, 0.21742400E+03, -.22807800E+03, 0.34136800E+02, 0.23957000E+03, 0.20231200E+03, 0.21865600E+03, -.16994400E+03, -.39026600E+03, 0.18167200E+03, 0.18969500E+03, -.89601400E+02, -.59976800E+02, 0.19353500E+03, 0.10717000E+03, 0.21165600E+03, -.16535200E+03, 0.72174900E+03, -.34120400E+03, -.40662600E+03, 0.35710300E+03, 0.66491900E+03, -.57114600E+03, -.65345100E+03, -.78788000E+03, 0.36255600E+03, 0.76816600E+03, -.38104900E+03, -.34639400E+03, -.91653700E+02, 0.37274400E+02, -.28509500E+03, -.18796300E+02, -.18097700E+03, -.22767000E+02, 0.11563200E+03, -.58818400E+02, -.72758600E+02, -.10631000E+03, 0.97052300E+02, -.41813200E+02, -.13134800E+03, 0.25062200E+02, -.15686600E+02, 0.17644600E+04, -.87150700E+03, -.89057100E+03, 0.50997200E+03, 0.81326800E+03, -.95537700E+03, -.82676700E+03, -.11605500E+04, 0.55247100E+03, 0.52230600E+03, -.26073400E+03, -.32255200E+03, 0.61556200E+02, -.67024900E+02, -.13778100E+03, 0.12461600E+03, -.88493400E+02, -.10869400E+03, 0.48912400E+03, -.24202300E+03, -.28123400E+03, -.17977600E+02, 0.19418200E+03, -.19662200E+03, -.23990600E+02, -.22705300E+03, 0.40501000E+02, -.27962200E+03, 0.13853800E+03, 0.11907300E+03, 0.90299800E+02, 0.70711200E+02, 0.23021200E+02, 0.40520000E+02, 0.15736500E+02, 0.11721500E+03, 0.38991400E+03, -.19574500E+03, -.18338200E+03, 0.20250300E+03, -.54744800E+02, -.15008400E+03, 0.12835200E+03, -.20907100E+03, -.42562100E+02, -.10253300E+03, 0.10697300E+03, -.82555500E+02, -.98374400E+02, -.90183200E+01, -.64014700E+02, -.27820400E+03, 0.91775400E+02, 0.54713000E+01, 0.88437700E+02, 0.11312500E+03, -.34586300E+02, -.68875800E+02, 0.10577300E+03, 0.88055800E+02, 0.10610600E+03, -.13185700E+03, 0.14762200E+03, -.36247600E+02, 0.33753600E+02, -.80305500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.25181200E+01, -.45160900E+00, -.14430200E+01, -.37465000E+01, 0.14911100E+01, 0.13728600E+02, -.10121800E+01, 0.78589700E+00, 0.69601800E+00, -.73278300E+00, 0.33637000E+01, 0.22459900E+01, -.45653300E+00, -.32023400E-01, -.83015900E-01, -.13516200E+01, -.37097500E+00, -.43171400E-01, 0.11434100E-01, -.36104100E-01, 0.84634500E-01, 0.32199500E+00, -.25307300E+00, -.22188100E+01, 0.66560400E+00, -.99895500E+00, 0.25401600E-01, 0.27045000E-01, 0.27467800E+00, 0.11897300E+00, -.26203000E+00, 0.57509900E+00, 0.15855600E+00, -.29932500E+00, -.22251500E+00, 0.25591200E+00, -.95950000E-01, 0.29231100E+00, -.35840300E+00, 0.14885300E+01, -.77360000E+00, -.49284300E-01, -.35302300E-01, 0.27173600E+00, -.22701400E-01, -.52218900E+00, 0.40816300E+00, 0.29789900E+00, 0.60246300E+00, -.32455900E-01, 0.67153100E+00, 0.25789200E+00, 0.48681900E+00, 0.22941800E+00, -.18891000E+01, 0.40740100E+00, -.26422600E-01, 0.12548300E+00, -.28040100E+00, 0.39930500E+00, -.65741100E-02, 0.61497900E+00, 0.35840800E+00, -.24085300E+01, 0.23458300E+00, 0.70527800E+00, -.32760100E+00, -.73213300E-01, -.48560400E+00, 0.18920100E+00, 0.26044700E+00, -.16895400E+00, -.26579400E+00, -.33826900E+00, 0.47279000E+00, 0.19935500E+00, 0.40876900E-01, -.22913000E-01, 0.57223100E+00, 0.33159900E+01, -.15912500E+01, -.45466100E+00, 0.53933800E-01, -.23326700E+00, -.27552500E+00, 0.18680300E+03, -.98800800E+01, 0.12984500E+02, -.58650100E+03, 0.58808900E+02, 0.78295800E+02, -.38744200E+02, -.20243900E+02, -.38757500E+03, 0.10460000E+03, 0.67471000E+02, 0.16162000E+03, 0.63534400E+02, 0.15176600E+03, -.74989300E+03, 0.33902200E+03, 0.37240300E+03, -.15395000E+03, -.10039700E+03, 0.36134800E+03, 0.23262900E+03, 0.37706400E+03, -.23462800E+03, -.57697900E+03, 0.27865700E+03, 0.25162600E+03, 0.33018000E+03, 0.56493100E+03, -.88959100E+02, -.24004600E+03, -.20076500E+03, 0.40798100E+03, 0.90374800E+03, -.44787600E+03, -.45028400E+03, 0.79226600E+02, 0.35903600E+03, -.45581000E+03, -.31071900E+02, -.93438600E+02, 0.31193100E+03, 0.10884900E+03, -.56003100E+02, -.52455400E+02, -.10019400E+03, 0.18759600E+03, -.28044700E+02, -.28590200E+02, 0.86792200E+02, 0.27418500E+03, -.63641200E+02, 0.12660800E+02, 0.23631400E+02, 0.57325200E+03, 0.62267700E+03, -.30477900E+03, -.32258200E+03, -.42544700E+03, 0.64631600E+03, 0.37035200E+03, -.17702000E+03, -.20466800E+03, 0.75535100E+01, -.60161700E+02, -.10921400E+03, 0.70588900E+02, -.20466000E+02, -.92835400E+02, -.74339200E+01, 0.51519600E+01, 0.57775000E+00, -.18113900E+02, 0.45385700E+03, -.15517700E+03, -.24462600E+02, 0.31060600E+02, 0.28500700E+03, -.50467900E+03, 0.25100700E+03, 0.24056800E+03, 0.11776500E+03, 0.97077300E+02, 0.12933800E+03, -.95955400E+02, -.19958800E+03, 0.16187100E+03, 0.34482400E+03, -.17535500E+03, -.16896500E+03, 0.11799300E+03, -.41362300E+02, -.14988100E+03, 0.25541400E+03, 0.16622900E+03, -.13716900E+03, -.15649200E+01, -.12951700E+03, 0.35580300E+02, -.31785400E+02, 0.44783400E+02, 0.29153100E+01, -.34705700E+03, 0.75917300E+02, -.11147800E+03, 0.19981800E+03, -.75387200E+01, -.34415200E+02, -.17062700E+03, 0.18304800E+03, 0.13021000E+03, 0.20199900E+02, -.17096400E+03, -.10512200E+03, -.16798700E+03, 0.54988100E+02, 0.24595900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.97601000E+00, 0.21415600E+00, 0.49758600E+00, 0.20543700E+01, -.60882700E+00, -.10232300E+02, 0.37414700E+01, 0.91535500E+00, -.50859100E+00, 0.91994400E+00, -.22850000E+01, -.12485600E+01, 0.30275800E+00, -.58200600E+00, 0.52016000E+00, 0.50714300E+00, 0.25771400E+00, 0.77033400E+00, -.38458000E+00, 0.59813400E+00, 0.72048100E-01, 0.44706300E+00, -.68855000E-01, 0.13806600E+01, -.22089100E+00, 0.50845500E+00, 0.76036900E-01, -.36801600E+01, -.39383200E-02, 0.21688000E+00, 0.44611200E+00, -.13648100E+01, -.70542200E+00, 0.38204500E+00, 0.60005600E+00, 0.48276600E+00, -.18862100E+00, -.53152000E+00, 0.69701400E+00, 0.13072400E+00, -.35070100E+00, 0.59303700E-01, -.13840600E+00, 0.99723800E-01, -.22261500E+00, -.16411800E+00, 0.33666500E+00, -.20823000E+00, -.32938600E+00, -.17056400E+00, -.11167000E+01, 0.23864400E+00, -.25877900E+00, 0.40690000E-01, -.91935500E+00, -.17534600E+00, -.28149800E+00, -.17182800E+00, -.10073100E+00, -.13683400E+01, -.62190400E+00, -.62775000E-01, -.49256200E-01, -.17343900E+01, 0.24318200E+00, 0.21994900E+00, -.11020600E+00, -.20205200E+01, 0.11671800E+00, 0.41670800E+00, 0.12833600E+01, 0.49091600E-01, -.17657700E+00, -.21065900E+00, 0.17599800E+00, 0.82209000E-01, -.13136700E+00, -.11423000E+00, 0.61792600E+00, -.93046400E+00, 0.13270700E+00, -.44195000E+00, 0.12965500E+00, -.15138900E+00, -.21296100E-01, -.21751800E+00, 0.86042300E+02, 0.16378500E+03, -.18921500E+02, 0.38379500E+02, -.66131300E+02, 0.33651100E+02, 0.42489000E+02, -.14609400E+03, 0.10855100E+02, 0.91276000E+02, 0.14123400E+03, 0.13666200E+03, 0.47121200E+02, -.39782800E+03, 0.18960300E+03, 0.19620200E+03, -.69940000E+02, -.20342600E+02, 0.19050000E+03, 0.13159300E+03, 0.21216800E+03, -.88307700E+02, -.78382500E+03, 0.44730700E+03, 0.39021700E+03, 0.16783100E+03, 0.34797500E+03, 0.95047400E+02, 0.51010200E+02, 0.12667900E+03, 0.26563200E+03, 0.64136200E+03, -.31805800E+03, -.31518300E+03, -.15847300E+02, 0.16777300E+03, -.26277300E+03, 0.57759300E+02, -.55697100E+02, 0.48260500E+02, 0.65298100E+02, -.35800700E+02, -.35181500E+02, -.51314900E+02, 0.40937800E+02, 0.92943900E+01, 0.14247300E+02, 0.18669700E+02, 0.38277600E+02, -.42929500E+03, 0.25713600E+03, 0.23065700E+03, 0.22280200E+03, 0.37285300E+03, -.38070500E+02, 0.27650100E+02, 0.19187100E+02, 0.36500900E+03, 0.26739600E+03, -.12342800E+03, -.14342700E+03, 0.87401500E+01, 0.45222500E+01, -.85957700E+02, 0.34862000E+02, -.66687900E+02, -.28020200E+02, -.57951900E+02, 0.26696600E+02, 0.26209300E+02, -.34095300E+02, 0.20613900E+03, -.42334000E+02, 0.10228000E+03, 0.13441800E+03, 0.80218900E+02, 0.25990900E+03, -.12966000E+03, -.12723800E+03, -.77148200E+02, -.95837400E+02, 0.12635400E+02, 0.10942800E+03, 0.18086300E+02, -.50529700E+02, 0.31191000E+03, -.15717900E+03, -.15469300E+03, 0.99541400E+02, 0.10463200E+02, -.15275100E+03, 0.91437200E+02, -.73969900E+02, -.43195500E+02, -.29968700E+02, 0.23278100E+01, 0.25102300E+02, -.43533700E+02, 0.89951500E+01, -.15874000E+02, -.34966900E+02, 0.32686600E+02, -.58961700E+02, 0.10719700E+03, 0.35863100E+02, 0.74558000E+01, -.98542600E+02, -.49679300E+02, 0.10887500E+03, 0.18624400E+02, -.18657200E+02, 0.12522300E+02, -.84278700E+02, -.13408600E+02, 0.98835900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.19921700E+01, 0.10627400E+00, -.13270600E+01, -.20814300E+01, 0.15074500E+01, 0.13671000E+02, 0.12690200E+02, 0.36638400E+01, 0.89030400E+00, 0.31193500E+00, -.54277200E+00, 0.40734200E+00, -.78420600E+00, -.83548600E-01, 0.74220500E-01, -.10616600E+01, -.18556800E+00, -.14084200E-01, -.70514300E-01, 0.15607500E+00, 0.31393900E+00, -.51792700E+00, 0.55928500E-01, -.85605400E+00, -.40851600E+00, -.44302600E-01, 0.24798600E+00, 0.60281200E+01, -.42781600E+00, 0.19801600E+01, 0.17267500E-01, 0.55291900E-01, 0.35525000E+00, 0.19448400E+00, -.22693900E+00, 0.14830600E+01, 0.61656100E-02, -.26785500E+00, 0.54292300E+00, 0.16323200E+01, 0.26415800E+01, -.46103400E-01, -.61957500E-01, 0.78329200E+00, -.22935500E+00, -.10674000E+00, 0.60456000E-03, -.43925600E-01, -.23360600E+00, -.43593100E+00, -.12967700E+01, -.39492000E+00, 0.13642300E+00, 0.39976800E+00, -.92267400E+00, -.12704200E+00, 0.40852800E+00, -.18677000E+00, 0.10462400E+00, 0.11559500E+01, 0.29149800E+00, 0.55326600E+00, -.31743200E-01, 0.23606600E+00, 0.69844300E-01, 0.45712600E-01, -.11373700E+00, 0.30997400E+00, -.32943500E+00, 0.16808200E+00, -.33973100E+00, 0.13865800E+00, -.24789400E+00, 0.66943700E+00, 0.40117700E+00, 0.24609000E+00, 0.44857800E-01, -.72695700E+00, -.67411600E-01, 0.19758300E+01, -.11968400E+01, -.29151000E+00, 0.33114100E+00, 0.27928200E+00, 0.44595300E+00, 0.37190600E+00, -.56775200E+00, -.12481400E+03, 0.99128400E+02, 0.81262300E+02, 0.17405000E+03, -.88479500E+02, -.98806900E+02, 0.81944000E+02, -.10253300E+03, -.14186300E+03, -.17475000E+03, -.12378300E+03, -.36297300E+02, 0.55250300E+02, 0.31068700E+01, -.23953900E+02, 0.32437600E+02, 0.13603500E+03, -.24020800E+02, 0.60500500E+02, -.21749200E+02, 0.11478000E+02, -.89845400E+03, 0.43080300E+03, 0.47077600E+03, -.11265100E+03, 0.24016100E+02, 0.38724800E+03, 0.41196700E+03, 0.62403800E+03, -.10557300E+03, -.43466700E+03, 0.21541300E+03, 0.18773200E+03, 0.21627000E+02, -.25086600E+03, 0.24494500E+03, 0.12661300E+03, 0.16086800E+03, -.19003600E+03, -.93761700E+01, 0.37201000E+01, -.12861400E+01, 0.41626400E+02, -.17000700E+03, -.20170700E+02, -.24695800E+02, -.68962200E+01, -.17071200E+03, -.57523800E+03, 0.29188100E+03, 0.30861800E+03, -.17246200E+03, 0.12678700E+03, 0.29056000E+03, 0.45989000E+03, 0.41961400E+03, -.13101900E+03, -.14562300E+03, 0.78288900E+02, 0.10911500E+03, -.42610400E+02, 0.25939300E+02, 0.30978300E+02, -.68879400E+02, -.80148000E+01, 0.38856900E+02, 0.12290700E+03, -.64660700E+02, -.54524700E+02, 0.10643800E+03, -.14625500E+03, -.39443100E+02, -.45108500E+02, -.88132600E+02, -.25040200E+02, 0.21156400E+03, -.10492400E+03, -.96493100E+02, -.65132300E+02, -.26497500E+02, 0.73042300E+01, 0.91199400E+02, 0.12942900E+03, -.33576800E+02, -.20634300E+03, 0.10459800E+03, 0.10061300E+03, -.25993800E+02, -.56901300E+01, 0.58395000E+02, -.84438100E+02, -.72878500E+02, -.44429400E+01, -.36204700E+02, 0.60819200E+02, -.25260600E+02, 0.86446600E+01, -.41404200E+02, -.32611300E+02, 0.38461300E+03, -.57495700E+02, 0.11481400E+02, -.10105400E+03, 0.28972100E+01, 0.72574000E+02, 0.92302800E+02, -.33730000E+03, -.14514500E+03, -.54097900E+02, 0.15135100E+03, 0.35904900E+02, 0.63099200E+02, -.28142200E+02, -.27995600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.21809900E+01, -.13125900E+01, -.50617000E+00, -.43703000E+01, 0.27200700E+00, 0.15714900E+02, -.61156000E+01, -.16545500E+01, 0.78892400E+00, -.14173700E+01, -.18243400E+01, 0.19116800E+01, -.34247300E+00, -.86479100E+00, -.17627200E-02, -.80111600E+00, -.83561700E-01, -.76377900E+00, 0.11791600E+01, -.34662400E+00, 0.80772200E-01, -.92106300E+00, -.37937700E+00, -.36670100E+01, 0.11376900E+01, -.19796000E+01, -.28873000E+00, 0.24558900E+01, -.46395000E+00, -.12308900E+00, -.84477800E+00, 0.51259200E+00, 0.83877700E+00, -.15863100E+00, -.13485600E+01, 0.62792600E+00, 0.11703200E+01, 0.12049000E+00, -.99694700E+00, 0.25371300E+01, 0.21843200E+00, -.37310200E+00, -.18904100E+01, 0.38197000E+00, -.14970900E+00, 0.47575600E+00, 0.77034000E+00, -.15488600E+01, -.17603900E+01, 0.74173200E+00, -.15448600E+01, 0.73135300E+00, -.47531000E+00, 0.41304100E+01, -.11198000E-01, 0.38196600E+00, -.85842100E+00, -.35540300E+00, -.48674200E-01, 0.17166400E+01, 0.16289100E+01, 0.47661600E+00, 0.14420600E+00, -.76697600E+00, 0.57258200E-01, 0.11300600E+01, -.46286200E+00, 0.11749000E+01, -.60351100E+00, 0.19634900E+00, -.11036600E+01, 0.45221900E+00, 0.51775600E-01, -.30441800E+00, -.40681800E+00, 0.27276500E+00, -.10690600E+00, 0.73215400E+00, -.10480200E+00, 0.50350200E+01, -.65465300E+00, 0.39388700E+00, -.15036900E+01, 0.49234500E+00, 0.31360200E+00, 0.81328100E+00, -.47938800E+00, -.35419900E+00, 0.59164400E+03, 0.15122400E+03, 0.83463900E+03, -.41881500E+03, -.38885300E+03, 0.12214000E+03, -.31893300E+03, -.27336800E+03, -.11608700E+03, -.26382900E+03, 0.10240700E+03, 0.36230500E+03, -.17847300E+03, -.16753200E+03, 0.58626200E+02, 0.18874200E+03, -.17541000E+03, -.45394600E+02, -.22416800E+03, 0.65019600E+02, -.16554700E+03, -.59304500E+02, 0.10208600E+03, -.25958700E+03, -.10460600E+03, 0.19260200E+03, 0.37302500E+02, 0.27969900E+03, -.33800900E+03, 0.19628800E+03, -.10188000E+03, -.13468000E+03, 0.35705600E+02, -.43659700E+03, 0.11656500E+03, 0.11135200E+03, 0.19171200E+02, -.39653900E+03, -.11976500E+03, 0.63442500E+02, 0.69735500E+02, -.73096400E+02, -.40802900E+03, 0.19008900E+03, 0.36482000E+03, 0.18934400E+03, -.17717900E+03, 0.27473200E+03, -.23278900E+03, -.87083400E+02, -.45271600E+03, -.71459300E+02, 0.12063300E+03, 0.24800800E+03, 0.24160300E+03, -.50185200E+03, -.64750000E+03, 0.32055200E+03, 0.35783900E+03, -.10659800E+03, -.17685200E+02, 0.16802000E+03, -.16923100E+03, 0.10421000E+03, 0.44828300E+02, 0.57222400E+03, -.28537900E+03, -.25965900E+03, 0.53228800E+02, -.26807200E+03, -.58827600E+02, 0.27298400E+02, -.81865700E+02, -.25757300E+03, 0.47170100E+03, -.23445000E+03, -.23582300E+03, 0.62083000E+01, 0.56115100E+02, -.19030600E+03, 0.84430000E+02, 0.33198000E+03, 0.43674200E+02, -.10629500E+04, 0.53248100E+03, 0.52532100E+03, -.31339500E+03, -.17315000E+03, 0.42553300E+03, -.18979700E+03, 0.38697300E+03, -.23041900E+03, 0.17085800E+03, -.65537700E+02, 0.43287200E+02, 0.12556800E+03, 0.26121600E+02, 0.37968400E+01, 0.58266900E+03, -.14450900E+03, 0.16917200E+03, 0.21282600E+02, -.78280200E+02, 0.11620900E+03, -.27349700E+02, -.46181300E+03, -.31530000E+03, -.15190000E+03, 0.24722100E+03, -.11243700E+03, 0.18144800E+03, -.16502400E+03, 0.13715100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.78666400E+01, -.84861200E+01, 0.36294700E+01, 0.26172900E+01, -.27494500E+01, -.19345700E+02, -.15775100E+02, -.14594800E+02, -.99954000E+00, -.13595400E+01, 0.82917700E+01, 0.28611800E+01, 0.76394300E+00, -.11278900E+00, 0.38060700E-01, 0.30350900E+01, 0.34189900E+00, -.24278700E+01, 0.27644600E+01, 0.11381300E+00, -.54044700E+00, -.30852400E+00, -.85691500E+00, 0.13669500E+01, 0.15591400E+00, 0.28163900E+00, 0.52665200E+00, -.19285300E+02, 0.60288900E+00, -.43672400E+01, 0.31279000E-02, 0.10844800E+01, 0.10045800E+01, -.17294400E+00, 0.10577700E+01, -.75333800E-01, -.51738700E+00, -.26479000E+01, -.64632900E-02, 0.13433400E+01, 0.74604900E+01, 0.30163800E+00, -.25846200E+01, -.38565800E+00, -.31753400E+00, 0.33207200E+00, 0.12121300E+01, -.40555000E+00, -.83840900E+00, 0.70102200E+00, 0.11049900E+00, -.40754600E-01, 0.19413100E+00, 0.25263100E+01, -.18810000E+01, 0.39550100E+00, 0.37918400E-01, -.89888500E+00, 0.43361700E+00, 0.32893500E+01, -.98985900E+00, 0.51122500E+00, -.16911300E+00, 0.37695700E+01, 0.18684600E+00, -.13567500E+00, 0.20490600E+00, 0.13467600E+01, 0.82370600E+00, -.68939100E+00, -.67101200E-01, -.29034900E+00, 0.23952000E+00, 0.63505700E+00, -.26520400E+00, -.22027900E+00, 0.24989600E-01, -.18376000E+01, 0.29639900E+00, -.35440300E+01, 0.54042200E+00, 0.70696500E+00, 0.10535600E+01, -.69544700E+00, -.40672800E+00, -.27398200E+00, 0.64848500E+00, 0.41892500E-01, 0.12118500E+00, -.13134800E+03, 0.58037200E+02, -.27391000E+02, -.32377700E+02, -.43537500E+02, 0.26630300E+03, -.30865200E+02, -.10288400E+03, -.26244500E+02, -.30745900E+03, 0.17655900E+03, -.89450100E+02, -.94085800E+02, 0.14154000E+01, 0.71638400E+02, -.65544100E+02, -.55942400E+02, -.60876400E+02, -.85895800E+02, 0.14396600E+04, -.68496400E+03, -.71087300E+03, -.13173900E+03, -.41279500E+03, -.37361300E+03, -.20622400E+03, -.60111900E+03, -.35990400E+03, -.28604600E+03, 0.14275300E+03, 0.14331900E+03, -.89579200E+00, 0.77815100E+02, 0.17444800E+02, -.22386700E+03, 0.15551400E+02, 0.85447900E+02, 0.71824300E+03, -.35635400E+03, -.36509300E+03, -.45558500E+02, 0.27377100E+03, -.34434900E+03, -.35366500E+03, -.41412200E+03, -.70693800E+02, 0.10103100E+04, -.48596100E+03, -.51933600E+03, -.80343900E+02, -.58736100E+03, -.25930700E+03, -.32983900E+03, -.51311100E+03, -.22928400E+03, 0.39114300E+03, -.20701100E+03, -.18216700E+03, 0.36269500E+02, 0.25814600E+02, -.11665800E+03, 0.24105100E+02, -.83330500E+02, -.14337400E+02, -.69831100E+02, 0.39516400E+02, 0.37923200E+02, 0.75124200E+01, -.51025300E+02, 0.34164000E+01, -.20904000E+03, -.33829000E+02, -.26270300E+02, -.11507100E+03, 0.57243500E+02, 0.78791900E+02, 0.30425400E+02, 0.22328700E+02, -.56069800E+02, -.55840400E+02, -.69278200E+02, 0.21885800E+02, 0.34960600E+03, -.17386000E+03, -.17612000E+03, 0.84950500E+01, 0.42339900E+01, -.11572500E+03, -.59641200E+02, -.23022300E+03, 0.99919000E+02, 0.12526400E+03, -.10578900E+03, 0.10342200E+03, 0.77273400E+02, 0.13286000E+03, 0.11566400E+03, -.32108000E+03, 0.72447200E+02, 0.12519100E+03, -.49603800E+02, -.78132400E+02, -.21099600E+03, 0.59919500E+02, 0.39135600E+03, -.90462700E+02, 0.13652800E+03, -.17588600E+03, -.98097300E+02, 0.14251800E+03, 0.12938300E+03, 0.17512800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37634900E+01, -.31934800E+01, 0.29059600E+01, 0.52660600E+01, -.20977800E+01, -.27623900E+02, -.86047600E+00, -.23694300E+01, -.15471300E+01, 0.52340200E+00, 0.38631400E+01, -.40673800E+01, 0.14673000E+01, 0.67631500E+00, -.41483100E+00, 0.35570500E+01, 0.40106200E+00, -.44473500E+00, 0.30327200E+00, 0.14622500E+01, 0.74461500E+00, -.89463700E+00, -.45931900E+00, 0.39078700E+01, -.13207700E+01, 0.17675900E+01, -.65981700E-02, 0.28293100E+01, 0.29724800E+00, -.33869200E+01, 0.86729800E+00, 0.16925400E+00, -.17604700E+00, 0.51086000E+00, 0.43078400E+00, -.15011200E+00, -.29575100E+00, -.17810600E+01, 0.11019800E+01, 0.10076000E+01, 0.14681000E+02, 0.40291200E+00, 0.47723700E+00, -.15975400E+01, -.38430700E+00, 0.12971000E+01, -.12969300E+00, -.25513300E+00, 0.32287800E+00, 0.42774400E+00, 0.23523700E+01, 0.84442500E-01, 0.72028100E+00, 0.45419700E-01, 0.31795200E+01, -.69173300E+00, -.85036500E+00, 0.16728600E+01, -.78485700E+00, -.12339900E+01, -.12423200E+01, 0.17954800E+00, -.24519700E+00, -.15745000E+01, -.68987600E+00, 0.10992600E+00, 0.15301800E+00, -.23180800E+01, -.55419600E+00, -.31611900E-01, -.92171100E+00, 0.13785800E+00, 0.43918300E+00, -.14206000E+01, -.24245600E+00, -.99946700E-01, -.45986100E-01, 0.91455600E+00, -.20856700E+00, 0.47511200E+00, 0.10478300E+01, -.12505500E+01, -.22360200E+00, -.26788900E+00, -.79702400E-01, -.49339700E-01, 0.34922600E+00, 0.46272800E+00, 0.20815300E+00, 0.20947300E+00, -.12589000E+04, 0.62978500E+03, 0.52885200E+03, -.69476800E+02, 0.29356900E+03, 0.45300800E+03, 0.38377900E+03, 0.42138400E+03, -.40986200E+01, 0.13902700E+03, -.96235000E+02, -.75325600E+02, 0.41023800E+02, -.22374800E+03, -.86998600E+02, -.14991100E+03, -.51060800E+02, 0.10719500E+03, 0.10119300E+02, 0.82350000E+02, -.64687000E+02, 0.27999500E+03, -.37726900E+03, 0.10366500E+03, -.16207700E+01, -.14387600E+03, 0.21844400E+03, 0.27477900E+03, -.13446800E+03, 0.74989300E+02, -.22940400E+03, 0.79060900E+02, -.10043200E+03, 0.78203500E+02, 0.90308800E+02, 0.14677400E+01, -.10260000E+03, 0.52785900E+02, -.60606100E+02, -.43755600E+02, 0.26047000E+03, 0.13002800E+02, -.43129800E+02, -.31926600E+02, 0.50425000E+02, -.11587200E+04, 0.62526200E+03, 0.46918300E+03, 0.78968900E+03, -.16285600E+03, 0.35761700E+03, -.43711000E+03, -.85615000E+02, 0.54339700E+03, 0.62933600E+03, -.33948400E+03, -.55506200E+03, 0.85491400E+02, -.27295000E+02, -.18876800E+03, 0.59901000E+02, -.14898600E+03, -.61315900E+02, -.56630600E+03, 0.28901400E+03, 0.63762800E+02, -.14538000E+03, 0.81116400E+02, 0.18863600E+03, 0.13510500E+03, 0.27363100E+03, -.80819100E+02, -.20551800E+03, 0.99898900E+02, 0.32439200E+02, 0.10095300E+03, -.13589600E+02, 0.59350500E+02, 0.34604900E+02, 0.33300100E+02, 0.21011200E+02, 0.98404200E+03, -.48850000E+03, -.44145300E+03, 0.65271200E+02, -.12780900E+02, -.34979600E+03, -.64700600E+02, -.42575900E+03, 0.57392900E+02, -.15444300E+03, 0.20997400E+03, -.13156900E+03, -.12874400E+03, -.78919300E+02, -.77611900E+00, -.10318500E+04, 0.91183400E+02, -.22226400E+01, 0.33492100E+02, 0.13479700E+03, -.10831700E+03, -.54545900E+02, 0.95674000E+03, 0.24734000E+03, 0.15724900E+03, -.35818300E+03, 0.25399000E+03, -.23263700E+02, 0.20177500E+02, -.71510300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23916900E-01, 0.45597300E+00, -.24410300E-01, -.30011900E-01, 0.52336000E-01, 0.38551000E+01, 0.49109900E+01, -.65340300E+00, 0.24388400E+00, 0.14372500E+00, 0.28489600E+00, 0.54033200E-01, 0.23287700E+00, 0.39178000E+00, -.47911400E+00, 0.21942600E-01, -.33872800E-01, 0.33504700E+00, 0.79239500E+00, -.91354000E-01, 0.31368600E-01, -.20376000E+00, 0.57071000E-01, 0.10793400E+01, -.61902500E-02, -.26510600E-01, 0.12874300E+00, 0.61134100E+00, -.58783000E-01, -.75362900E-01, 0.10404400E+00, 0.81794500E-01, 0.51524800E-01, 0.74232300E-03, 0.87349400E-01, 0.11824600E+00, 0.11447300E-01, -.63243200E-01, 0.26201100E+00, -.37912800E+00, -.68673200E+00, 0.51548200E-01, -.72147300E-01, 0.71922200E-01, 0.12577700E+00, -.54350100E-01, 0.49355500E-01, 0.89697300E-01, 0.71592600E-01, -.21780000E-02, -.16053300E+00, -.16306800E+00, -.42455100E-01, 0.24711500E+00, 0.20482300E+00, -.86109100E-01, -.23952800E-01, 0.15796000E+00, -.59161600E-01, -.28386000E+00, -.51821100E-03, -.11426100E-01, -.37706300E-01, -.48482900E+00, -.83577000E-01, -.38303400E-01, -.14058300E-01, -.26093600E+00, -.74558000E-01, 0.20663600E-01, -.45415100E-02, 0.44050600E-03, -.16523200E-02, 0.20818800E+00, -.95249100E-01, 0.64459900E-01, 0.23603100E-01, 0.32224300E+00, -.31304000E-01, -.29213800E+00, 0.16341400E-01, -.11875700E+00, -.12924700E+00, 0.14527200E+00, 0.12687200E+00, -.12388500E-01, 0.12237000E-01, 0.81694100E-01, -.27592700E-01, -.10066100E-01, 0.24592700E-01, -.53295700E+00, 0.14781200E+01, 0.10107800E+02, -.13279000E+02, -.21661200E+01, 0.16250600E+02, 0.22513200E+01, 0.16335700E+02, 0.68900700E+02, -.35107900E+02, -.32038700E+02, 0.16604000E+01, 0.19169500E+02, -.36218800E+02, -.52174600E+02, -.37715900E+02, 0.94367000E+01, -.30831700E+02, 0.31019200E+01, 0.15703000E+02, -.34517200E+01, -.85345700E+01, 0.16291100E+02, -.52640300E+01, 0.34209500E+02, -.23672600E+02, 0.43060100E+02, -.21448800E+02, -.18260800E+02, 0.11364400E+02, 0.54673500E+01, -.96147500E+01, 0.44880700E+01, -.36828000E+01, -.46926200E+01, -.69539800E+02, 0.34568700E+02, 0.32120700E+02, 0.78723000E+01, -.26514100E+02, 0.26518400E+02, 0.33397700E+02, 0.35615000E+02, -.12026700E+02, -.10814200E+03, 0.47112900E+02, 0.57000200E+02, -.10989600E+02, -.17591900E+02, 0.52410100E+02, 0.28298900E+02, 0.66438600E+02, -.46943100E+02, -.10894200E+03, 0.54936500E+02, 0.50897900E+02, -.72619700E+01, -.99936200E+01, 0.37899900E+02, -.69403300E+01, 0.37378900E+02, 0.24698300E+01, -.25915200E+02, 0.12961600E+02, 0.97184500E+01, 0.39943000E+01, -.21690300E+00, 0.19094900E+02, 0.19707600E+02, 0.25130300E+02, -.55735600E+01, -.18069800E+02, 0.90371400E+01, 0.90619900E+01, 0.14502000E+01, -.11450600E+01, 0.80935700E+01, -.20416500E+02, -.83108300E+01, -.42299300E+01, -.24538800E+02, 0.12227900E+02, 0.12995000E+02, -.38354300E+01, -.89888900E+01, 0.28341500E+02, 0.28435500E+02, 0.59710000E+02, -.18612700E+02, 0.29082000E+00, -.96462500E+01, -.46549800E+01, 0.11967300E+01, -.97944700E+01, -.18684500E+01, -.20030300E+01, -.10397500E+02, -.10341000E+02, -.44795400E+01, -.30024600E+01, 0.81125100E+01, 0.38078800E+01, -.75495000E+01, 0.12092300E+01, -.88491300E+01, 0.11446500E+02, -.87500400E+01, -.93159800E+01, -.10637600E+02, -.12184800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.32589800E+01, -.23595500E+01, -.15406600E+01, -.47274900E+01, 0.17437400E+01, 0.17931400E+02, -.48734500E+01, 0.24908900E+01, 0.84739000E+00, -.10829200E+01, 0.36081000E+01, 0.11296200E+01, -.78529800E+00, 0.33121400E+00, -.23588600E+00, -.80284200E+00, -.39127900E+00, -.24051100E+00, -.71462500E+00, 0.29271400E+00, 0.10898200E+00, 0.60088400E+00, -.23921000E+00, -.36787800E+00, -.60981300E+00, 0.22009700E+00, -.68235700E+00, 0.53359700E+00, 0.16885500E+00, 0.17490800E+01, -.22787400E+00, 0.35778700E+00, 0.73588700E+00, -.55891500E-01, -.67658200E+00, 0.11359500E+01, 0.49395700E+00, 0.26927500E+00, -.11891000E+00, 0.57470100E+00, -.31757500E+01, -.28504900E+00, 0.11103200E+01, 0.18954300E+01, -.60818200E+00, -.31957200E+00, -.40226500E+00, -.27774500E+00, -.85039600E+00, -.14199100E+01, -.19593500E+01, -.91602000E+00, -.40091200E+00, -.21498800E+01, 0.11986100E+00, -.38943400E+00, 0.15417400E+01, -.44152800E+00, 0.49865700E+00, 0.20949100E+01, -.59971400E+00, 0.99299300E+00, -.28444700E+00, 0.73732300E+00, 0.15721200E+00, -.23227000E+00, 0.62808600E-01, -.79040600E+00, -.40937900E-01, -.11968600E+00, -.55566900E+00, 0.50219200E+00, -.67335600E+00, -.44180300E-02, 0.31049200E+00, -.55940300E-01, 0.26101800E+00, 0.15485800E+01, -.93871500E+00, -.37148500E+00, -.32505500E+00, 0.24003100E+00, -.61250500E+00, 0.48509000E+00, -.71024000E+00, 0.10357900E+01, -.15498100E+01, 0.32058200E-01, -.10014500E+00, -.78282300E+00, 0.88187500E+00, 0.52568800E+00, 0.81136900E+02, -.83354300E+02, -.22053000E+03, 0.30096300E+02, -.18686800E+02, 0.43573200E+02, -.18674200E+03, -.52644500E+03, 0.21353600E+03, 0.25563200E+03, -.10676700E+03, -.22340100E+02, 0.25195400E+03, 0.17817000E+03, 0.27641000E+03, -.10846100E+03, 0.20315600E+04, -.10072800E+04, -.96166600E+03, -.41605600E+02, 0.45552600E+03, -.94814000E+03, -.75593000E+03, -.12817600E+04, -.79075400E+02, -.62697600E+03, 0.31286400E+03, 0.11337000E+03, 0.15128600E+03, -.87224100E+02, 0.17913900E+03, -.80340500E+02, 0.37190500E+02, -.30872600E+02, -.26366900E+03, 0.13254700E+03, 0.24059300E+03, 0.68966900E+01, 0.33683800E+02, 0.18943100E+02, -.13334500E+03, -.82766800E+02, 0.87244200E+02, 0.31382300E+04, -.15593300E+04, -.14872700E+04, -.37336900E+03, 0.31705600E+03, -.12838900E+04, -.60041400E+03, -.13896500E+04, -.30182500E+03, 0.74508700E+02, -.37120900E+02, 0.19108000E+03, 0.62175500E+01, -.33821100E+02, 0.31843100E+01, 0.54010900E+02, 0.69007600E+02, -.48454700E+02, 0.95127400E+02, -.42294300E+02, 0.16105200E+03, 0.10808500E+03, -.16708200E+03, -.18745500E+02, -.33864900E+02, -.16767900E+03, -.43530100E+01, -.42852300E+03, 0.21656000E+03, 0.28468300E+03, -.46994500E+02, 0.10989500E+03, 0.53897900E+02, -.14161300E+03, -.34699600E+00, 0.80599900E+02, -.10926100E+03, 0.52491100E+02, 0.73505800E+01, 0.25257400E+03, 0.83906800E+02, 0.72873300E+02, 0.23134700E+03, 0.57059900E+02, 0.90923200E+02, -.89409900E+02, 0.42748400E+02, -.93283300E+02, -.36949300E+02, -.47693500E+02, -.83448700E+02, 0.45594300E+03, 0.46232600E+02, -.59682200E+02, -.73116900E+02, 0.21979000E+02, 0.56669300E+02, 0.84194100E+02, -.40524300E+03, -.91001100E+02, -.34183800E+02, 0.91425900E+02, 0.36616200E+02, -.27216600E+02, 0.13967700E+02, -.10167400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.28585400E+00, -.28870400E+01, 0.25463400E+00, -.14726900E+00, -.18596600E+00, 0.19188000E+01, 0.44927000E+01, -.13449900E+01, 0.18242600E+00, 0.12219500E+00, 0.21146800E+00, -.18119300E-01, 0.31108900E+00, 0.45755100E+00, -.56762800E+00, 0.17270800E+00, 0.51047100E-02, 0.27778400E+00, 0.74299700E+00, -.23138400E-01, -.16410300E-01, -.21740300E+00, 0.16172100E+00, 0.63683900E+00, -.31902000E+00, -.91534500E-02, -.57687500E-01, 0.50221800E+01, 0.60396200E-01, 0.22141900E-01, 0.80182100E-01, 0.21135500E+00, 0.36488800E+00, 0.10227300E+00, -.19237800E+00, 0.58095700E+00, 0.30121900E+00, -.41020200E+00, -.59685600E-01, 0.45165000E+00, -.17250900E+01, 0.32483300E-01, 0.11107800E+00, -.64239100E-01, 0.17875600E-01, 0.13585200E-01, 0.91919300E-01, -.61738400E-02, 0.44332200E-02, 0.72614300E-01, -.44493400E-01, -.37631500E-01, -.41175900E-01, 0.15513600E+00, 0.11649400E+00, -.34104300E-01, -.48127500E-01, 0.89969900E-01, -.35994100E-01, -.10322600E-01, 0.45051700E-01, -.34989600E-02, -.47772100E-01, -.19759900E+00, -.37373200E-01, 0.32533800E-01, -.21835200E-01, -.25629600E+00, -.18313800E-01, 0.21753500E-01, -.71822700E-01, -.31079200E-01, 0.35696500E-01, 0.71059200E-01, -.22714100E-01, 0.12559000E-01, 0.27119300E-01, 0.25395400E+00, -.80321100E-01, -.79733600E+00, 0.57841200E-02, -.24100600E+00, -.13853900E+00, 0.10727300E+00, 0.99906600E-01, 0.26542100E-01, 0.78888400E-01, 0.50713100E-01, 0.47638300E-01, 0.93996000E-01, 0.52666400E-01, -.29376100E+00, 0.83635100E-01, 0.34020200E+02, 0.17028200E+02, -.42583600E+01, 0.80748700E+01, -.15974600E+01, 0.14432700E+02, 0.15621700E+03, -.68530200E+02, -.79572100E+02, 0.19582400E+02, 0.56299100E+01, -.73709600E+02, -.69207800E+02, -.75564200E+02, 0.20379200E+02, -.19244200E+03, 0.10389400E+03, 0.94399100E+02, -.27056400E+02, -.68731800E+02, 0.10076600E+03, 0.86330100E+02, 0.15352100E+03, -.10706700E+02, 0.97620000E+01, -.47251200E+01, 0.39659200E+01, 0.40024200E+01, 0.12726500E+02, -.20649500E+01, 0.86730000E+01, -.51738000E+01, 0.78665900E+01, -.40839700E+02, 0.20008900E+02, 0.15603900E+02, 0.15329800E+02, -.18918500E+02, 0.24230100E+02, 0.42456300E+02, 0.32404000E+02, -.21066500E+02, -.35171500E+03, 0.18227000E+03, 0.17332800E+03, -.41804100E+02, -.76584500E+02, 0.16241100E+03, 0.11673300E+03, 0.20455700E+03, -.19369500E+02, -.38272700E+02, 0.20427900E+02, 0.10792900E+02, -.31728900E+01, 0.23063600E+01, 0.11992700E+02, -.17496100E+01, 0.74861900E+01, 0.54106100E+01, -.42319200E+02, 0.20627200E+02, 0.13748000E+02, 0.31847000E+01, 0.10870000E+02, 0.18946500E+02, 0.15164200E+02, 0.20870000E+02, -.94210200E+00, 0.14852100E+02, -.74925200E+01, -.82268900E+01, 0.13779900E+01, -.86924300E+01, 0.60074300E+01, 0.74492600E+00, -.80420400E+01, -.10327100E+02, -.12903600E+02, 0.61809300E+01, 0.79157700E+01, -.28588000E+02, -.78323200E+01, 0.10461000E+02, -.45039600E+01, 0.37522000E+02, -.59555100E+01, 0.50821800E+00, -.81563300E+01, 0.50723200E+01, 0.75818400E+00, -.58321700E+01, -.36149700E+00, 0.16769900E+02, -.16993000E+02, -.12204500E+02, -.10107700E+02, -.15788700E+01, 0.45173400E+01, 0.89215500E+01, -.16561300E+02, 0.13092200E+02, -.37747400E+01, 0.23383300E+02, -.76789900E+01, -.13097000E+02, -.40400600E+01, -.25936300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18612800E+01, 0.33028900E+01, 0.11383200E+01, 0.28344700E+01, -.17156200E+01, -.60695600E+01, 0.94246400E+00, -.33550300E+01, -.38792800E+00, 0.23463700E-01, -.10982300E+01, -.74455000E+00, 0.55738800E+00, 0.24068200E+00, -.45120900E+00, 0.77584000E+00, 0.23153500E+00, 0.42677600E+00, 0.23217300E+00, -.63418000E+00, -.12809800E+00, 0.22437300E+00, 0.13234700E+00, 0.17669900E+00, 0.70910600E-01, 0.94586000E-02, 0.31266700E+00, -.12740200E+01, -.35373400E+00, 0.24305700E+00, 0.76148200E-01, 0.53628400E+00, 0.12030100E+00, -.93632200E-01, -.21973700E+00, -.12218100E+00, -.18241200E+00, -.40427400E+00, -.33149000E+00, -.33146000E+00, 0.30346700E+00, 0.95664500E-01, -.16554800E+00, -.97113500E+00, -.14150200E+00, 0.59894200E+00, 0.19534200E+00, -.25037100E+00, -.41726800E-01, 0.83866900E+00, 0.16512900E+00, -.47712000E-01, -.25882400E-02, 0.10361000E+01, 0.38896200E+00, 0.57700400E-01, -.66392300E+00, -.19344600E+00, 0.27635400E-01, 0.93868100E-01, 0.99962300E+00, -.41106600E+00, 0.41749700E-01, 0.14761000E+01, -.21394500E+00, 0.30742400E+00, -.19884000E+00, 0.10618700E+01, 0.11837500E+00, -.17574900E-01, -.20013700E+00, 0.55905700E-01, 0.31161700E+00, 0.29787700E+00, 0.58427700E-01, -.66343900E-01, 0.24428800E-01, -.14315500E+01, 0.14780200E+00, -.26126900E+01, 0.31933500E+00, 0.52169500E+00, 0.42814300E+00, -.22125100E+00, 0.39552100E-01, -.39490000E+00, -.29402800E+00, -.21506400E+00, 0.22384500E+00, 0.16099000E+00, -.19535100E+00, -.15465300E+01, -.32400000E+00, -.26341500E+01, 0.18654200E+03, -.16844000E+02, -.15066300E+02, 0.19138100E+02, -.48244200E+02, 0.35002200E+03, -.11886400E+03, -.18306400E+03, 0.21593200E+02, 0.15989800E+03, -.15411400E+03, -.14345400E+03, -.13462300E+03, -.13530200E+02, -.83603200E+03, 0.47672500E+03, 0.42887800E+03, -.91132200E+02, -.15679900E+03, 0.34916700E+03, 0.35751600E+03, 0.53629800E+03, -.96923500E+02, 0.27177400E+02, -.12399000E+02, -.15194900E+02, 0.49555000E+02, 0.15026700E+03, -.40013900E+02, -.19861100E+02, 0.19973200E+02, 0.72095400E+02, 0.20680900E+03, -.10649200E+03, -.11622900E+03, 0.41343300E+01, 0.72832400E+02, -.74523900E+02, -.26040500E+01, -.65055300E+02, -.96110000E+02, -.11104500E+04, 0.61271700E+03, 0.57086200E+03, -.12528000E+03, -.28325300E+03, 0.45325900E+03, 0.44447000E+03, 0.60292000E+03, -.42915200E+02, 0.55846000E+02, -.18837400E+02, -.18418500E+02, -.65587300E+01, 0.35432600E+02, -.27920600E+02, -.27665000E+01, -.40932700E+02, 0.21137100E+02, -.21521900E+03, 0.10441600E+03, 0.10326700E+03, 0.90323500E+01, 0.13726300E+03, 0.31797600E+02, -.22783700E+02, 0.11422700E+03, 0.41716600E+02, 0.10173400E+03, -.50829600E+02, -.34563700E+02, -.14090400E+02, -.49824700E+02, 0.23964100E+02, 0.12012500E+02, -.56579800E+02, -.12448100E+02, 0.11883000E+03, -.60057400E+02, -.59726500E+02, -.27424500E+02, 0.34179600E+02, -.70725200E+02, 0.95883900E+01, -.83262100E+01, 0.11459500E+02, 0.41025700E+02, -.79434100E+02, 0.85338600E+02, 0.15181700E+02, 0.36208900E+02, 0.51469800E+02, 0.37459200E+02, -.18684400E+02, -.38530100E+02, -.86151100E+02, -.21947600E+02, -.74013300E+02, 0.88165400E+02, -.44570900E+02, 0.67721100E+02, 0.36217600E+02, 0.35892000E+02, -.84257700E+02, -.40597700E+02, 0.13170000E+02, 0.76346400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36018000E+01, -.20258000E+01, 0.23806200E+01, 0.23107900E+01, -.14871400E+01, -.92636900E+01, -.77492700E+01, -.68164200E+01, -.53788600E+00, -.41270100E+00, 0.15749400E+01, 0.71801700E+00, 0.75118800E+00, 0.28586100E+00, -.36582100E+00, 0.11342400E+01, 0.37663900E+00, -.22464200E-01, 0.21775700E+01, -.45442000E+00, 0.10246600E+00, -.13905100E+01, -.17477900E+00, 0.18625100E+01, -.11804900E+01, -.15385100E+00, 0.75120200E+00, -.80537500E+01, 0.11233100E-02, -.33839500E+01, -.39966000E+00, 0.14232600E+01, 0.90923700E+00, -.20695100E+00, 0.22841300E+00, 0.23290300E+00, -.16840700E+00, -.12937100E+01, -.62122900E-01, 0.29206700E+00, -.13353700E+01, 0.25635500E-01, 0.49640000E+00, -.86714900E+00, -.36279800E+00, 0.17075600E+00, 0.18562200E+00, -.20321000E+00, 0.52075900E+00, 0.57369800E+00, 0.78085600E+00, 0.95329900E+00, -.83073900E-01, -.11303000E+00, -.56102000E+00, 0.89051200E-01, -.53267200E+00, 0.21504000E+00, -.28300400E+00, -.14412000E+01, -.42228400E+00, 0.43876000E-01, 0.20877700E+00, -.24252100E+01, 0.19143700E+00, 0.57679500E+00, -.34444700E+00, -.24275500E+00, 0.48086000E+00, -.89764000E-01, 0.12047400E+01, -.60212100E-01, 0.96394400E-01, -.53906800E+00, 0.45494400E+00, -.30155900E-01, 0.20441700E+00, 0.35786100E+00, 0.57810400E+00, -.30026600E+01, 0.19599400E+00, 0.11041700E+01, 0.21875600E+00, -.43475900E+00, -.34665000E-01, -.29620000E+00, 0.30543500E+00, 0.49837800E+00, -.55031800E+00, 0.98641500E-01, -.16176200E+00, -.11914700E+00, 0.20329800E+00, -.86175700E+00, -.39635500E+00, 0.60004600E+02, 0.16698600E+03, 0.49451900E+02, 0.12724500E+03, 0.23945100E+03, -.10524700E+03, -.12249700E+03, 0.83767500E+01, -.76952600E+02, -.11883700E+03, -.17831600E+03, -.12713800E+03, 0.47039100E+02, -.49591200E+03, 0.20484200E+03, 0.21806100E+03, -.21688400E+02, -.18812800E+03, 0.23906400E+03, 0.76338300E+02, 0.31928000E+03, 0.52724700E+02, 0.56891500E+03, -.28315700E+03, -.22980700E+03, -.25577000E+02, 0.11363500E+03, -.18494600E+03, 0.20517500E+02, -.81322300E+02, 0.40578200E+02, -.14721400E+03, 0.75402300E+02, 0.52115500E+02, -.46778300E+02, -.34688200E+02, 0.13976900E+03, 0.29502700E+03, 0.22746800E+03, 0.27292600E+02, -.97279800E+03, 0.44566700E+03, 0.47866900E+03, 0.57845800E+02, -.13217700E+03, 0.39367300E+03, 0.10304700E+03, 0.46147800E+03, 0.60704500E+02, -.62379500E+03, 0.30544600E+03, 0.23223900E+03, -.20594700E+02, -.30769200E+02, 0.18686400E+03, -.67197000E+02, 0.10414000E+03, 0.48540300E+02, 0.33729700E+03, -.16489400E+03, -.22332600E+03, -.10160000E+03, 0.11711600E+03, -.61528200E+02, 0.49754700E+02, 0.62654800E+02, -.48775300E+02, 0.79484200E+02, -.40636200E+02, -.76867000E+02, 0.68205400E+02, -.28915300E+02, -.20206500E+02, -.11632000E+03, -.59832300E+02, -.17143300E+02, -.65091800E+03, 0.32370700E+03, 0.33928800E+03, -.17255300E+03, -.38390400E+02, 0.29666400E+03, 0.73079500E+02, 0.32717400E+03, -.40822000E+02, 0.98665700E+02, -.12548100E+03, 0.19540200E+02, 0.17032000E+02, -.21958600E+02, 0.42827800E+02, -.13353800E+03, -.45282600E+02, -.32390800E+02, 0.10347900E+03, -.12533700E+02, -.16971200E+02, -.10000800E+03, 0.92320600E+02, 0.13178600E+03, -.20006900E+02, 0.77543200E+01, -.13587200E+03, -.88312200E+02, -.13165900E+03, 0.35379000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.55401700E+01, 0.27721200E+01, 0.37343500E+01, 0.30641200E+01, -.27714100E+01, -.16599200E+02, -.14467400E+02, -.73752700E+01, -.11403400E+01, -.96435000E+00, -.12499800E+01, 0.84789100E+00, 0.38752700E+00, -.39223100E+00, 0.32997300E+00, 0.24894900E+01, 0.37608100E+00, -.71292200E+00, 0.24237300E+01, -.24248600E+01, -.32963100E+00, -.19149100E+01, -.46349700E+00, 0.17881700E+01, -.17692900E+00, -.16145300E-01, 0.54003800E+00, -.44907900E+01, -.30761600E+00, -.29402800E+01, -.93762600E+00, 0.77431600E+00, 0.53479300E+00, -.22839800E+00, 0.10286400E+01, -.32995500E+00, -.59296900E+00, -.56944500E+00, 0.74503800E+00, 0.12964100E+01, 0.59099900E+01, 0.16134200E+00, -.65613200E+00, -.72827700E+00, -.55989700E+00, 0.21677500E+00, 0.63082200E+00, -.18885900E+00, 0.47002900E+00, 0.58854500E+00, 0.75541900E+00, 0.65635900E-01, 0.14920800E+00, 0.26792500E+01, -.13765300E+01, 0.87851400E-01, -.69196600E+00, 0.21594100E-01, -.23380400E+00, 0.18326200E+01, 0.73564600E+00, 0.51864900E+00, 0.11365500E+00, -.10254900E+01, -.23960000E+00, -.16621300E+00, -.67840700E-01, -.41262100E+00, -.68680700E-01, 0.17576400E+00, 0.72871500E+00, 0.21479300E+00, 0.58717800E-02, -.55055500E+00, -.17372100E+00, -.58488400E-01, -.11328200E+00, -.10726300E+01, 0.35685800E+00, -.33140200E+01, 0.57206400E-01, 0.54578500E+00, 0.11260600E+00, -.83530100E-01, -.27856200E+00, 0.30717800E-01, -.49430300E+00, -.72019800E-01, -.23811600E+00, -.58312000E+00, -.17992900E+00, -.32950700E+01, 0.16417400E+00, 0.98972200E-02, 0.28232300E+00, -.13849600E+00, 0.98508000E+02, 0.40053600E+02, -.39467900E+02, 0.18257800E+03, -.11320100E+03, -.85172400E+02, 0.29692800E+00, 0.92231500E+02, -.99904000E+02, -.16993900E+03, -.96387600E+02, 0.38655500E+02, -.35465800E+03, 0.19747600E+03, 0.16446500E+03, 0.28985000E+02, -.84615200E+02, 0.18043500E+03, 0.12786100E+03, 0.19017400E+03, -.64413000E+02, 0.48497100E+03, -.24075500E+03, -.20024500E+03, -.17912000E+02, 0.37481600E+01, -.10872900E+03, 0.45666000E+02, 0.54187400E+02, -.93943900E+02, -.16169200E+03, 0.78273200E+02, 0.53253000E+02, -.19706100E+02, -.89649600E+02, 0.72392600E+02, 0.13120000E+03, 0.12500100E+03, -.13921500E+03, -.93979200E+03, 0.48614500E+03, 0.45941600E+03, 0.94542500E+02, -.12484300E+03, 0.38709100E+03, 0.19875800E+03, 0.37786700E+03, -.81224400E+02, -.69755800E+03, 0.35462100E+03, 0.30171300E+03, -.38809700E+02, -.43098600E+02, 0.22906400E+03, -.67732500E+02, 0.18276200E+03, 0.48154500E+02, 0.98031300E+02, -.51157500E+02, -.91327900E+02, -.96237800E+01, 0.13992900E+02, 0.11190100E+02, 0.39243900E+02, 0.16720400E+03, -.66966800E+02, 0.15232700E+03, -.76110700E+02, -.82236100E+02, -.20479200E+02, -.85707600E+02, 0.11822400E+02, -.49159800E+02, -.51348200E+02, -.87691300E+02, -.17961700E+03, 0.88838500E+02, 0.10017500E+03, -.52999300E+02, -.24448700E+02, 0.13625300E+03, 0.76562900E+02, 0.19431700E+03, -.54744700E+02, 0.24406900E+02, -.48392900E+02, -.19203400E+02, -.51213600E+01, -.52166700E+02, 0.20981400E+02, -.12381100E+03, -.32880400E+02, 0.10530600E+02, -.37821900E+02, 0.22105600E+01, -.21385100E+02, 0.32673600E+02, 0.10420700E+03, -.18706300E+02, 0.11174400E+02, -.19057700E+01, -.51352800E+02, 0.14891200E+02, -.85902100E+02, -.18583300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11609700E+01, 0.25161400E+00, -.76055200E+00, -.17959000E+01, 0.85166600E+00, 0.10863500E+02, 0.59746000E+01, 0.17165200E+01, 0.64770400E+00, -.25969100E+00, 0.94823900E+00, 0.40785300E+00, -.62810600E+00, 0.44486200E-01, 0.11128500E+00, -.16632900E-01, -.10006800E+00, -.21582800E+00, -.57242800E+00, -.17962600E+00, 0.29226300E-01, 0.30585400E+00, -.31098400E+00, -.11085200E+01, 0.15591500E-01, 0.39397000E-01, 0.19201300E+00, 0.40614700E+01, 0.18585600E+00, -.20267400E+01, -.23839900E+00, 0.12897500E+01, 0.42654200E-01, -.17841000E+00, -.65562800E+00, 0.21710200E-01, -.10300600E+00, -.14211000E+00, 0.65455500E+00, 0.90118200E+00, 0.47561700E+01, 0.73146000E-01, 0.50277600E+00, 0.48885000E+00, 0.75307600E-01, -.15437000E+00, -.25759500E+00, 0.41720500E+00, 0.67039400E+00, -.33894100E+00, 0.55166800E+00, 0.98751600E-02, 0.22300100E+00, -.99995300E+00, -.34830800E+00, -.10648400E+00, 0.15972800E+00, 0.24258400E+00, -.24525000E+00, -.14853000E+01, -.19037300E+00, -.25857900E+00, 0.15112700E+00, -.85306300E+00, 0.36643600E-01, 0.36153200E+00, -.43140000E-01, -.18860800E+00, -.45976500E-01, 0.26127800E+00, 0.88752800E-01, 0.20446900E+00, -.24753300E+00, -.20163600E-01, -.22974700E+00, -.20102500E-01, -.55548100E-01, -.92059800E+00, 0.89376600E-01, 0.27581700E+01, -.70092800E+00, -.12014100E+00, 0.27460000E+00, -.83896400E-01, -.18556700E+00, 0.36505600E+00, -.40352300E+00, 0.79460300E-01, -.10809500E+00, -.19209100E+00, 0.10857200E+00, 0.37296900E+00, 0.88538200E-01, 0.24955200E+01, -.29184400E+00, -.33789900E+00, -.32522600E+00, 0.57443500E+02, -.11289300E+03, -.26026500E+02, -.74499900E+00, 0.19114300E+02, -.28484100E+02, 0.10672400E+03, 0.12542000E+02, -.20777100E+02, 0.10729100E+02, -.32714000E+02, -.42302700E+03, 0.21273400E+03, 0.23476400E+03, -.54656100E+02, -.88610200E+02, 0.18718000E+03, 0.28318100E+03, 0.30988100E+03, -.13409800E+03, -.11415900E+03, 0.57085800E+02, 0.51474900E+02, 0.10391700E+02, 0.19057800E+02, 0.56947300E+02, 0.58688700E+02, 0.12409500E+03, -.46392700E+02, 0.29836200E+02, -.17014300E+02, -.22026400E+02, 0.13497900E+02, -.45157400E+02, -.19640100E+02, -.29053600E+01, -.22294000E+02, -.14757700E+03, -.72044700E+03, 0.36597100E+03, 0.37661900E+03, -.62281700E+02, -.19660700E+03, 0.30351500E+03, 0.34958400E+03, 0.44537600E+03, -.15238100E+03, -.38061300E+03, 0.19820000E+03, 0.20882300E+03, -.57763800E+01, 0.23875000E+02, 0.11689500E+03, -.28085700E+02, 0.81631000E+02, 0.62692200E+02, -.15928700E+03, 0.75767800E+02, 0.84451100E+02, 0.17484700E+02, -.30264000E+02, 0.56279800E+02, 0.39173500E+02, 0.16762400E+03, -.24263200E+02, 0.30204100E+03, -.15033200E+03, -.12978500E+03, -.79858300E+02, -.10463300E+03, -.16348600E+02, 0.22070400E+02, -.25285300E+02, -.99032500E+02, -.24567700E+03, 0.12255200E+03, 0.12032500E+03, 0.42016400E+02, 0.81406500E+02, 0.71958200E+02, 0.39719600E+02, 0.29532200E+02, 0.70709300E+02, -.19665500E+02, -.17290600E+02, 0.25046400E+01, -.16952600E+02, -.33549100E+02, 0.77679000E+01, 0.47324500E+02, -.16756900E+02, -.42349100E+02, -.46746200E+02, 0.15916200E+02, -.15049400E+02, 0.51731100E+02, -.28762600E+02, 0.23150700E+02, 0.11619900E+02, 0.25274700E+02, -.24777000E+02, -.15765900E+02, -.71450400E+02, 0.10071200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.50634200E+01, -.11608100E+01, 0.41682000E+01, 0.73860900E+01, -.14532700E+01, -.23761900E+02, -.65200700E+01, -.69438400E+00, -.13942000E+01, 0.73946100E+00, -.75268500E+01, -.39568800E+01, 0.34105900E+00, 0.24304400E+01, -.12263100E+01, 0.30604900E+01, 0.90642700E-01, 0.94316000E+00, 0.90282600E+00, 0.69678500E+00, 0.67915600E+00, -.13856200E+01, -.23443100E+00, 0.93653000E+00, 0.11991100E+01, -.39813900E+00, 0.97253600E+00, -.26840000E+01, -.29880000E+00, 0.32405600E+01, -.70745400E-01, -.15875700E+01, -.89909300E+00, 0.17256300E+00, 0.21040200E+01, -.25633500E+01, -.11652000E+01, 0.97629600E+00, 0.23017700E+01, 0.35988500E+01, 0.33921600E+02, 0.60138000E+00, -.23342600E+01, 0.10954100E+00, 0.82617100E+00, -.10080000E+01, -.93908900E-01, 0.36441900E+00, -.18856100E+01, 0.10809500E+01, -.26455300E+00, -.10234500E+01, 0.56841500E+00, 0.16979200E+01, -.26930500E+01, 0.61566400E+00, -.77338000E+00, -.10433300E+01, 0.10731500E+00, 0.14255800E+01, 0.21787600E+01, -.79324100E+00, 0.39086000E+00, -.24390400E+00, -.44315200E+00, -.11544600E+01, 0.43393100E+00, 0.13118700E+01, -.35162700E+00, 0.11573400E+00, 0.11917200E+01, -.33321800E+00, 0.12180800E+01, -.13968000E+01, -.17019000E+00, 0.37223000E+00, -.85523700E+00, -.16394600E+00, 0.19388300E+01, -.61724300E+01, 0.18487400E+01, 0.14795700E+01, 0.13281800E+01, 0.41010800E+00, 0.46607500E+00, -.53127200E+00, 0.97062500E+00, 0.19649300E+00, 0.16416500E+00, -.36931800E+00, -.17501800E+00, 0.50368500E+01, -.18878400E+00, -.33431500E+01, -.28011300E+00, 0.13439900E+01, -.18460100E+01, 0.80091100E+00, -.47033700E+03, 0.72516300E+03, -.29452900E+03, -.37039400E+03, 0.16095600E+03, 0.13248200E+03, -.34138000E+03, -.21114200E+03, -.31367000E+03, 0.21731600E+03, -.12430300E+04, 0.74112200E+03, 0.56575800E+03, 0.39588600E+03, 0.81952000E+03, 0.27994300E+03, -.26339700E+03, -.53364100E+03, 0.75679600E+03, 0.18815600E+03, -.94012000E+02, -.90492200E+02, -.93114200E+02, -.41713000E+03, 0.14259500E+03, 0.16253100E+03, 0.28849400E+03, -.35625000E+03, -.44679000E+03, 0.21899200E+03, 0.21768700E+03, 0.49007400E+02, -.13172600E+03, 0.14603600E+03, 0.30332800E+02, 0.20985200E+03, -.32402200E+03, -.87096400E+03, 0.53529200E+03, 0.36696700E+03, 0.22029300E+03, 0.81245900E+03, 0.25746400E+03, 0.17045500E+02, -.55311000E+03, 0.64139300E+03, 0.48300000E+03, -.23254400E+03, -.23793900E+03, -.20101700E+02, -.93346300E+02, -.11675000E+03, 0.41180400E+02, -.62148700E+02, -.88255400E+02, -.31435500E+01, -.37459600E+01, -.21599400E+01, 0.13836800E+03, -.19068400E+03, 0.11594700E+03, 0.11204900E+03, 0.15290200E+03, -.15196000E+03, -.23701400E+03, 0.11784100E+03, 0.12549100E+03, -.31141600E+01, 0.11925800E+02, 0.84843300E+02, 0.84123100E+02, 0.10086100E+03, -.40670400E+02, 0.89805300E+03, -.44725900E+03, -.44516500E+03, 0.94702900E+02, -.31618400E+02, -.32656700E+03, -.18325100E+03, -.45034600E+03, 0.37007600E+02, -.14792300E+03, 0.35811000E+03, -.23315900E+03, -.11190500E+03, -.13611700E+03, -.18211000E+03, 0.32336700E+03, -.66111200E+02, 0.11055500E+03, -.45819000E+03, 0.10464100E+03, 0.84302000E+02, 0.42437300E+03, -.25171100E+03, -.28946300E+03, 0.71574000E+02, 0.14132600E+03, 0.36398300E+03, 0.15965800E+03, 0.72848500E+02, -.21634800E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.52093800E+01, -.33125900E+01, 0.42942100E+01, 0.66500100E+01, -.20846100E+01, -.26178900E+02, 0.44095700E+01, -.95959500E+00, -.15129000E+01, 0.80836000E+00, 0.37002600E+01, -.52932400E+01, 0.20044900E+01, 0.13027600E+01, -.11844500E+01, 0.49312500E+01, 0.34982400E+00, -.93435600E-01, 0.92591100E+00, 0.11751500E+01, 0.41400500E+00, -.12398300E+01, -.16620200E+00, 0.45059500E+01, -.20804700E+01, 0.15215400E+01, 0.35582100E+00, 0.77822100E+01, -.21174900E+00, -.52327100E+01, 0.24972300E+00, 0.22169900E+01, -.31548700E+00, 0.15341600E+00, -.78813000E+00, -.13588600E+01, -.80620200E+00, -.10508600E+01, 0.69187600E+00, -.75014900E+00, 0.20520400E+02, 0.83828100E+00, 0.34155700E+01, -.26794900E+01, -.84322500E+00, 0.16005100E+01, -.79027800E+00, 0.46636400E+00, 0.19965400E+01, 0.70540000E+00, 0.33599000E+01, -.40341200E+00, 0.10203000E+01, -.13656100E+01, 0.58111100E+00, -.25589200E+00, -.86875900E+00, 0.12091700E+01, -.89666400E+00, -.21762600E+00, -.63017900E+00, 0.85551400E+00, 0.17632700E+00, -.46951000E+01, -.13587800E+01, -.15469800E+01, 0.74051500E+00, -.10761400E+01, -.12774200E+01, -.11581600E+00, -.23911100E+01, -.47858200E+00, -.50747900E+00, -.61871500E+00, 0.47278300E-01, 0.70351700E+00, -.74804400E+00, 0.22318000E+01, -.55329700E+00, 0.40868600E+01, 0.12627000E+00, -.17541400E+01, -.61033900E+00, 0.67872700E+00, 0.80306300E+00, 0.56096700E+00, -.10291100E+01, 0.58143200E+00, 0.45489600E+00, -.65988200E+00, 0.91939700E+00, 0.23001100E+01, 0.56032600E-01, 0.82964800E+01, -.10059700E+01, -.67350100E+00, -.17335700E+01, 0.63241600E-01, 0.33374500E+00, -.93474000E+03, 0.36453900E+03, 0.47755300E+03, -.17025000E+03, 0.37466300E+02, 0.43121900E+03, 0.22459000E+03, 0.46218100E+03, -.16499000E+03, 0.26214800E+04, -.12709500E+04, -.12201600E+04, -.16773300E+03, -.18776800E+03, -.88785400E+03, -.20684400E+03, -.84351800E+03, -.52968700E+03, 0.13614900E+03, -.64986000E+02, -.19124700E+03, 0.11991500E+03, 0.33271800E+03, -.16076300E+03, -.14467600E+03, 0.85178100E+02, 0.15314200E+03, -.24582300E+03, 0.11634100E+03, 0.19271700E+03, -.79275300E+02, 0.96960100E+02, 0.82536100E+02, 0.88371000E+02, 0.72684000E+01, 0.86672100E+02, 0.21734700E+04, -.10514700E+04, -.10226400E+04, -.97795500E+02, -.38902000E+03, -.80851000E+03, -.23769100E+03, -.60773600E+03, -.46791100E+03, -.10569900E+04, 0.54820800E+03, 0.64589900E+03, 0.17312700E+02, 0.47466900E+02, 0.32968500E+03, -.58982600E+02, 0.33417800E+03, 0.13659500E+03, 0.15569900E+03, -.81874800E+02, 0.26675500E+02, 0.62039600E+00, 0.21283100E+03, -.16354800E+03, -.18414600E+03, 0.89902700E+02, 0.91129100E+02, 0.94268800E+02, -.45384800E+02, -.50754900E+02, -.72212300E+02, -.80418200E+02, 0.41350800E+02, -.12962800E+03, -.12884500E+03, -.50176900E+02, -.71939200E+03, 0.35628300E+03, 0.33654800E+03, 0.12013100E+03, 0.31586700E+03, 0.19036600E+03, 0.85768400E+02, 0.19177700E+03, 0.21187300E+03, -.31585900E+02, 0.11585800E+02, -.79040200E+02, -.46740100E+02, -.97390400E+02, 0.34627100E+02, 0.52659100E+01, 0.56846300E+02, -.69460200E+02, -.14063200E+03, 0.45235200E+02, -.43881300E+02, 0.15458500E+03, 0.11481000E+03, 0.10598500E+03, 0.13385300E+02, -.10026900E+03, 0.10797000E+02, -.75991500E+02, -.15015300E+03, -.53217100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.78513700E+01, -.48446200E+01, 0.67801000E+01, 0.11128700E+02, -.27435300E+01, -.36328700E+02, -.38848000E+00, -.49368500E+00, -.20781900E+01, 0.11264300E+01, -.70002500E+01, -.76632300E+01, 0.10569100E+01, 0.29534500E+01, -.17319500E+01, 0.62690500E+01, 0.42928800E+00, 0.10304500E+01, 0.10587500E+01, 0.20739000E+01, 0.81797100E+00, -.16470200E+01, -.41441400E+00, 0.31335500E+01, -.33390200E+00, 0.68033300E+00, 0.14634600E+01, 0.75635000E+01, -.62405000E+00, 0.32253800E+01, 0.10660500E+00, -.25939500E+00, -.76037500E+00, 0.27825600E+00, 0.20552000E+01, -.27711500E+01, -.14477400E+01, 0.79735300E-01, 0.21043500E+01, 0.20170600E+01, 0.34246700E+02, 0.10391800E+01, -.15396200E+01, -.37259900E+00, -.65262900E-01, 0.26250600E-02, 0.42838400E-01, -.82409700E+00, -.16056400E+01, 0.13800200E+01, 0.13022100E+01, -.43062500E+00, 0.67135000E+00, 0.22250200E+01, -.21104000E+01, 0.64647200E+00, -.81138400E+00, -.37491200E+00, -.95561000E-01, 0.30552500E+01, 0.16534600E+01, -.11855500E+01, 0.32642900E+00, 0.73323900E+00, -.13384700E+00, -.17269900E+01, 0.11477300E+01, 0.15706500E+01, -.38390200E+00, -.81104600E+00, 0.12488800E+00, -.13172100E+01, 0.95482300E+00, -.82882200E-01, -.10345500E+01, 0.67196300E+00, -.13737200E+01, 0.10131000E+00, 0.72386100E+00, -.48046900E+01, 0.24684500E+01, 0.38384600E+00, 0.18493400E+01, -.56561100E+00, 0.59326300E+00, -.11402400E+01, 0.14339100E+01, 0.72288600E+00, -.27193400E+00, -.21543500E+00, 0.56993000E+00, 0.48946400E+01, -.16331600E-01, -.36199500E+01, 0.73903200E+00, 0.14029200E+01, -.19277200E+01, 0.13983200E+00, 0.94160100E+00, 0.58635800E+00, -.13520800E+03, 0.16508200E+02, 0.33891700E+02, -.28601200E+03, -.37690600E+01, 0.22130200E+02, -.64763300E+02, -.58725800E+02, -.16454400E+03, -.15612500E+02, -.38297200E+02, 0.31447600E+03, 0.35091500E+03, -.16129000E+03, -.25649300E+03, 0.14008000E+02, 0.45516900E+03, -.19336600E+03, 0.95114200E+02, 0.30279500E+03, -.18152800E+03, -.31100700E+03, 0.16424900E+03, 0.17217600E+03, -.96989900E+02, -.12495600E+03, 0.21194100E+03, -.10240500E+03, -.19406200E+03, -.94356300E+01, -.90564300E+02, -.47715600E+02, -.15806500E+02, -.23684300E+01, -.85003600E+02, -.65840900E+03, 0.22519400E+03, 0.32461300E+03, 0.43616600E+03, 0.48337500E+03, 0.33551600E+02, -.31950100E+03, 0.94947700E+02, 0.57879700E+03, 0.89933400E+02, -.59636200E+02, -.31671900E+03, -.27500500E+02, -.40036100E+02, -.39535200E+02, -.38245200E+02, -.88450200E+02, -.26397400E+02, -.31403200E+03, 0.15520600E+03, -.31710100E+02, -.41331300E+02, -.35521000E+03, 0.23376500E+03, 0.24799900E+03, 0.82517400E+02, -.17267400E+03, 0.40894600E+03, -.20617500E+03, -.27865100E+03, -.51772700E+02, -.14391800E+03, -.52858300E+02, 0.14062600E+03, 0.57690300E+02, -.14217300E+03, 0.12134900E+03, -.55935500E+02, -.10455800E+02, -.15578400E+03, -.12304400E+03, -.34250800E+02, -.94651200E+02, 0.44475300E+02, -.92744800E+02, 0.56814600E+02, -.12860600E+02, 0.86071400E+02, 0.53873200E+02, 0.61840300E+02, 0.77612100E+01, -.20925300E+03, -.45581600E+02, 0.12691600E+01, 0.17811100E+03, -.37248500E+02, -.49362300E+01, -.17026900E+03, 0.29750100E+02, -.21999100E+02, -.10533400E+02, 0.29283900E+02, 0.32394500E+01, 0.48335400E+02, 0.67813100E+02, 0.65833900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.46192600E+00, 0.57579800E+01, -.43000400E+00, 0.28179500E+00, 0.35722300E+00, -.27565300E+01, -.72600400E+01, 0.24375300E+01, -.29837000E+00, -.18263300E+00, 0.13586500E+01, -.69968400E-01, -.37499900E+00, -.67424000E+00, 0.85343400E+00, -.25051900E+00, -.22716700E-01, -.47976600E+00, -.12493800E+01, 0.34256000E-01, -.33097000E-01, 0.42942600E+00, -.15576000E+00, -.12354500E+01, 0.60939700E+00, -.50282200E-01, 0.13950100E+00, -.74193200E+01, -.26990100E+00, 0.84320400E-01, 0.70007400E-01, -.60488900E+00, -.60474000E+00, -.20826800E+00, 0.56720700E+00, -.85442200E+00, -.55915300E+00, 0.99197100E+00, 0.22627000E+00, -.19968500E+01, 0.55088000E-02, -.41717700E-03, -.16096800E-02, 0.13021800E-02, -.41807800E-03, 0.45214200E-03, 0.18358000E-03, -.99859400E-04, -.15902800E-02, 0.26650500E-04, -.20014800E-02, -.16691600E-03, -.10847700E-02, 0.64911300E-02, 0.12620500E-02, 0.43077500E-03, -.76919800E-03, -.13390800E-02, 0.36373900E-03, -.67266600E-04, 0.31798700E-02, 0.36940700E-03, 0.68427400E-03, -.22008900E-02, 0.14753300E-02, 0.76717100E-03, -.78747700E-03, 0.75967500E-03, 0.11543000E-03, 0.19378800E-03, 0.79473500E-03, -.22175300E-03, 0.40267400E-03, -.93567000E-03, -.47796900E-04, -.28201900E-03, 0.21501000E-03, 0.85925900E-03, -.14854400E-03, 0.90467700E-02, -.13933500E-02, -.14684400E-02, -.26278200E-03, 0.15663400E-02, -.51103300E-04, 0.50840000E-03, 0.98813300E-03, 0.58701600E-03, -.17981700E-03, -.27387200E-03, 0.60124700E-03, 0.11581400E-01, -.27118100E-04, -.49672100E-02, -.23083200E-02, 0.11040800E-02, -.18534600E-02, 0.27516400E-03, 0.11382700E-02, -.22075200E-02, -.43365000E-02, 0.74909200E+01, -.27215200E+00, -.85544100E+00, 0.69606400E+00, 0.34624300E+00, 0.48996700E+00, -.64053700E+00, 0.34379800E+01, -.20072900E+01, -.21185900E+01, 0.82473600E+00, 0.93737000E+00, -.20269100E+01, -.10823700E+01, -.60625500E+00, 0.52123600E+00, -.96845600E+00, 0.48373100E+00, 0.11435400E+01, -.40017200E+00, -.45392300E+00, 0.49779000E+00, 0.52260700E+00, -.47284400E+00, -.10067000E+00, 0.99232100E+00, -.49945200E+00, -.75855500E+00, -.11873800E+00, -.36856200E+00, -.26521300E+00, -.24832700E-01, -.21233700E+00, -.44012300E+00, 0.14019900E+00, -.38442900E+00, 0.85330800E-01, 0.13284200E+01, 0.92102300E+00, -.85660200E+00, -.11033100E+01, 0.38383700E+00, 0.11371100E+01, -.20973200E+01, 0.10471300E+01, 0.58719100E-01, -.10121500E+00, 0.13580100E-01, 0.58764100E+00, -.28742100E+00, 0.37826300E+00, 0.24407900E+00, -.15411100E+01, 0.74292400E+00, 0.12761100E+00, -.25737400E+00, -.10617800E+01, 0.86190000E+00, 0.80145400E+00, 0.52636000E+00, -.49222200E+00, 0.25245500E+01, -.12659800E+01, -.15898300E+01, -.51438300E+00, -.95097000E+00, -.17988000E+00, 0.46167200E+00, 0.70356700E-02, -.80920100E+00, -.15147100E+01, 0.76935000E+00, 0.94376500E+00, -.40706600E+00, 0.25824500E+00, 0.38292200E+00, -.15279500E+00, 0.71739300E+00, 0.43501500E-01, 0.24952500E+00, -.15341800E+00, 0.38480900E+00, 0.22590500E+00, 0.16259600E+00, 0.16301900E+00, -.69338200E+00, -.17067500E+00, -.26248000E+00, 0.77899700E+00, -.15495900E+00, -.14139700E+00, -.69342000E+00, 0.42912800E-01, 0.34450100E+00, -.86327900E-01, 0.10751000E+00, -.70544800E-01, -.77426000E-01, 0.19679700E-02, -.85013600E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24542400E+01, -.97605200E+00, 0.11932400E+01, 0.20232800E+01, 0.10200000E+00, -.75472600E+01, -.55056100E+01, -.37201000E+01, -.39060700E+00, 0.13988700E+00, -.27954100E+01, 0.19704700E+00, 0.29998700E+00, 0.94477000E+00, -.26657600E-02, 0.15353400E+00, 0.64131200E-01, 0.21631700E+00, 0.67898900E+00, -.51024600E-01, 0.15928700E-01, -.37203200E+00, 0.10247800E+00, 0.18328300E+01, -.67041500E+00, 0.12391600E+00, 0.73070500E+00, -.75906700E+01, -.59586000E+00, -.49675500E+00, -.22646800E+00, 0.88419500E+00, -.72754700E+00, -.37736800E+00, 0.11264700E+00, -.16529900E+01, -.88091800E+00, 0.82849300E-01, 0.95413200E+00, -.22021600E-01, 0.15926800E+02, 0.58400000E+00, -.74538600E+00, 0.37965000E+00, 0.55142400E+00, -.74610200E+00, -.13505600E+00, 0.27043800E+00, -.45447900E+00, 0.80952600E-01, -.39270100E+00, -.25932600E+00, 0.16756800E+00, -.78389000E+00, -.89547800E+00, 0.40046400E-01, 0.66240700E-01, 0.46266700E-02, -.86398300E-01, 0.42225400E+00, 0.37836800E+00, -.88077500E-01, 0.19799200E-01, -.25108500E+00, -.30543500E+00, 0.27792500E-01, -.44079800E-01, -.93243000E-01, -.20436100E+00, 0.33722200E+00, 0.32515100E+00, 0.16867400E+00, 0.22952400E+00, -.58304800E+00, 0.13664700E+00, 0.10444200E+00, -.16630900E-01, 0.11546500E+00, 0.66794100E+00, -.37070700E+00, 0.91653200E-01, 0.42666300E+00, -.29640400E+00, 0.90787000E-01, 0.11431900E+00, 0.31483100E+00, -.26601200E+00, -.29933900E+00, 0.42956000E+00, 0.28932800E-01, -.17889700E+00, -.80239500E+00, -.29361500E-01, -.54081700E+00, 0.35044300E+00, 0.36360000E+00, -.14858300E+00, 0.66029500E+00, -.23689900E-01, -.68242800E-01, -.22380900E+00, 0.32916000E+00, 0.47865500E+02, -.86317200E+02, -.48266600E+01, 0.42729400E+02, -.88682000E+01, 0.61915200E+02, -.75443700E+02, 0.42470900E+02, 0.77078000E+01, 0.12031100E+03, 0.17763700E+03, -.66021100E+01, -.16013800E+03, -.27617100E+03, 0.23742200E+03, 0.20264100E+03, -.10196700E+03, -.97644800E+02, -.53961100E+02, -.89981200E+02, -.48739400E+02, -.42280500E+00, -.53483700E+02, -.45973200E+02, 0.16248500E+02, -.71446000E+01, 0.85691300E+01, 0.50735400E+01, 0.19013800E+02, -.10843500E+02, -.61910700E+02, -.25212100E+02, 0.46512300E+02, 0.21270000E+03, -.10680600E+03, -.12769900E+03, 0.12483800E+03, 0.25460900E+03, -.11438700E+03, -.22505600E+03, -.34017600E+03, 0.21885300E+03, 0.35742200E+03, -.18156400E+03, -.19339900E+03, -.66406400E+01, -.33827200E+02, -.10208700E+03, 0.19006200E+02, -.85537400E+02, -.59115900E+02, 0.21570800E+03, -.10739200E+03, -.10198900E+03, -.55427800E+01, -.34220600E+02, -.66646700E+02, -.78810400E+01, -.10752900E+03, -.21920500E+02, -.14854700E+03, 0.74117300E+02, 0.58895500E+02, 0.18949200E+02, 0.42852300E+02, 0.58601000E+01, 0.41465900E+02, 0.23135800E+02, 0.25645100E+02, 0.49948900E+03, -.24863700E+03, -.24872200E+03, -.16253200E+02, -.10459900E+03, -.15260800E+03, -.67601800E+02, -.13867300E+03, -.75308200E+02, -.94774900E+01, 0.64963300E+02, -.20032400E+02, -.20386100E+01, 0.19008300E+02, -.27950800E+02, -.41278300E+02, 0.14348000E+02, 0.66080500E+02, 0.73344600E+01, 0.34490000E+01, 0.21180800E+02, -.19005800E+02, 0.43167600E+02, -.71969600E+02, 0.89609500E+01, -.25998200E+02, 0.67003300E+02, 0.58063700E+02, 0.75714100E+02, -.30693900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17094900E+01, 0.11386900E+01, 0.12030800E+01, 0.26411300E+01, -.42525700E+00, -.89705800E+01, -.17761900E+01, 0.58708200E+00, -.54214000E+00, 0.42284200E+00, -.26423300E+01, -.12539200E+01, 0.21261100E+00, 0.68429000E+00, -.27079300E+00, 0.70695100E+00, 0.32210600E-02, 0.32499500E+00, 0.15930600E+00, -.94515900E-01, 0.26833700E+00, -.53325400E+00, -.16815200E-01, 0.75329700E+00, 0.44895500E+00, -.52929000E-02, 0.26585500E+00, -.31742500E+01, -.22488100E-01, -.38449200E+00, 0.28092700E-02, -.62947300E+00, -.47154400E+00, 0.14785900E+00, 0.25696000E+00, -.70109500E+00, -.27845000E+00, 0.15631600E+00, 0.12594600E+00, 0.33077800E+00, 0.56249900E+01, 0.42834100E-01, -.39801600E+00, -.12447900E+01, 0.58865800E+00, -.49856000E+00, -.29290300E+00, 0.54357600E+00, -.19054600E+00, 0.19410000E-01, 0.19664700E+00, 0.31562100E+00, -.28933800E-01, -.18681600E+01, -.22514100E+00, -.15206800E+00, -.34728500E-01, 0.40953200E+00, -.12243200E+00, 0.35569000E+00, -.30107700E+00, -.40211600E+00, -.11670400E+00, 0.10698700E+01, -.30303300E+00, -.34320200E+00, 0.22086600E+00, -.16526600E+00, -.89238800E-01, 0.46251300E-01, 0.20357700E+00, 0.46065000E-01, 0.10292200E+00, 0.12592500E+01, 0.67918400E+00, 0.29354300E+00, 0.91058600E-02, -.22510300E-01, 0.13985300E+00, -.26518500E+01, 0.35570700E+00, 0.47046000E+00, 0.39764000E+00, -.15968600E+00, 0.35957400E+00, -.54085500E+00, 0.20074300E+00, 0.25444900E+00, -.25745700E+00, -.49432400E-01, -.25436500E+00, -.76463100E+00, -.35557300E+00, -.32707300E+00, 0.24797800E-01, -.11339500E+00, 0.14942300E+00, -.38805900E+00, 0.10003100E-01, 0.15099800E+00, -.10490300E+00, -.23475900E+00, -.24081000E+00, -.65840300E+02, 0.56571400E+01, 0.12468500E+02, -.82928800E+01, -.35394400E+02, 0.62936800E+03, -.32330300E+03, -.32876600E+03, 0.10213300E+03, 0.20760900E+03, -.31213000E+03, -.21855100E+03, -.29058600E+03, 0.11470400E+03, -.21383100E+03, 0.10691000E+03, 0.11837400E+03, 0.93716600E+00, -.10727900E+03, 0.85919000E+02, 0.21358900E+02, 0.66805300E+02, -.31848200E+02, -.11467900E+03, 0.59095700E+02, 0.59335900E+02, -.29228000E+02, -.59898100E+01, 0.62379700E+02, 0.88092200E+02, 0.87556100E+02, 0.12192700E+02, 0.62770200E+03, -.32167100E+03, -.32451900E+03, 0.11635100E+03, 0.17859200E+03, -.29575300E+03, -.21467200E+03, -.22777300E+03, 0.10530200E+03, -.70051100E+02, 0.26983700E+02, 0.23402700E+02, -.17399900E+02, -.27760100E+02, 0.16606100E+02, -.27555000E+02, -.16858100E+02, -.12537700E+02, -.14826900E+03, 0.77312300E+02, 0.71185900E+02, 0.39329000E+02, -.11086000E+03, 0.71279800E+02, 0.52065700E+02, 0.88676200E+02, -.66436100E+02, -.60055300E+02, 0.30110000E+02, 0.27886700E+02, 0.26382900E+02, 0.20492800E+02, 0.73161900E+01, -.34828500E+02, -.32220900E+02, 0.11705000E+02, -.14011700E+03, 0.70219500E+02, 0.70930200E+02, -.62640800E+02, -.34311800E+02, 0.50616800E+02, -.14434300E+02, 0.95556300E+02, -.17989800E+02, 0.12930000E+02, -.13136700E+02, -.61488900E+00, 0.40686700E+01, -.94024000E+01, -.25615300E+01, 0.20743300E+02, -.13044000E+02, -.20208200E+02, -.14542600E+02, -.24479400E+01, -.23302800E+01, 0.22049100E+02, -.24084600E+02, -.45611800E+02, -.44629800E+01, -.16820900E+01, -.25558200E+02, 0.55769600E+01, -.14865600E+02, -.70857700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14783300E+00, -.20303200E+01, 0.14072500E+00, -.11255500E+00, -.11138800E+00, 0.18853300E+01, 0.27341200E+01, -.10746400E+01, 0.16071400E+00, 0.91798200E-01, -.86137400E+00, 0.49394100E-01, 0.14669500E+00, 0.29959000E+00, -.39652300E+00, 0.70319900E-01, 0.86399500E-02, 0.25390400E+00, 0.67181100E+00, -.10980800E+00, 0.45010400E-01, -.28847500E+00, 0.45679000E-01, 0.76456500E+00, -.25170800E+00, 0.20556900E-01, -.94595900E-01, 0.27198600E+01, 0.10844000E+00, 0.11119000E-01, -.52148600E-01, 0.16834600E+00, 0.20376600E+00, 0.86671900E-01, -.25737700E+00, 0.34542800E+00, 0.21041000E+00, -.30725900E+00, -.16046600E+00, 0.82111100E+00, -.39014900E+00, -.32198900E-01, 0.24407200E+00, -.10673900E+00, -.84773100E-01, 0.14285800E-01, -.24081800E-01, -.34223200E-01, 0.42728100E-01, -.99519900E-02, 0.43583100E-01, 0.50995300E-01, -.22380700E-01, -.26290800E+00, 0.78307800E-01, -.19310200E-01, -.29247000E-01, 0.43834300E-01, -.21721300E-01, -.98080500E-02, 0.33685800E-01, 0.10031000E-01, -.24334100E-01, -.12424700E+00, -.22048600E-01, 0.34237100E-01, -.18862500E-01, -.13191400E+00, -.42253400E-02, -.54457000E-02, -.35917800E-01, -.35517600E-01, -.93364400E-02, 0.97184200E-01, 0.15601100E+00, 0.17475900E-01, 0.45844500E-02, 0.14957400E+00, -.66586100E-01, -.28809500E+00, -.14216400E-01, -.15561700E+00, -.98396500E-01, 0.96373300E-01, 0.53043500E-01, 0.97254900E-02, 0.60459400E-01, 0.38419300E-01, 0.16844300E-01, 0.55991100E-01, 0.20670400E-01, -.77127600E-01, 0.33208000E-01, 0.43133100E+00, -.26708300E-01, 0.62367800E-02, -.25100700E-02, -.25153500E-01, -.81775900E-02, -.16849500E-02, -.18603000E-02, -.33224200E+00, 0.37329200E-03, 0.37271400E-01, 0.16613800E+01, -.64468700E-01, 0.13828100E+01, 0.42781400E+00, 0.35283900E+02, -.14669100E+02, -.18061200E+02, 0.36471400E+01, 0.60787700E+01, -.15825600E+02, -.13540700E+02, -.24658000E+02, 0.10126800E+01, 0.54412400E+01, -.26479500E+01, -.26622400E+01, -.38420300E-01, 0.86558200E+00, 0.63698000E-02, 0.48976200E+01, 0.25557600E+01, -.27564900E+00, -.75521700E+01, 0.36491500E+01, 0.34133700E+01, -.35801600E+00, 0.60404700E-01, 0.28005600E+01, 0.30013500E+01, 0.32893300E+01, 0.15404600E+01, 0.27194000E+02, -.11316800E+02, -.13893100E+02, 0.46420900E+01, 0.67870100E+01, -.13694700E+02, -.11891900E+02, -.22856300E+02, 0.39538300E+01, 0.30059300E+01, -.13441200E+01, -.18533700E+01, 0.19738300E+00, -.14994700E+01, -.58284800E+00, 0.11798600E+01, 0.10653100E+01, -.14069800E+01, -.90693400E+01, 0.44949300E+01, 0.40520300E+01, -.17002700E+01, 0.25920900E+01, 0.53536500E+01, 0.67530800E+01, 0.56750200E+01, -.15255000E+01, 0.20375100E+01, -.10220700E+01, -.12133900E+01, -.23888400E+01, -.34571200E+01, 0.24517700E+01, 0.56605000E+00, 0.14045400E+01, -.27741400E+01, 0.53645300E+01, -.26798100E+01, -.25051900E+01, 0.30764700E+01, 0.25963100E+01, -.43500600E+01, -.47124500E+00, -.34258600E+01, 0.43039400E+00, -.96803800E+00, 0.49708700E+01, -.29863800E+01, -.12878500E+01, -.20561900E+01, -.19297000E+01, 0.60775800E+00, -.11627900E+01, -.22678600E+01, -.45981100E+01, 0.10517100E+01, 0.15920000E+01, 0.51112600E+01, 0.43409600E-01, 0.39771800E+01, -.10137900E+01, 0.83787800E+00, 0.55400300E+01, -.33188400E+01, 0.70471000E+00, -.40041400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20751000E+01, 0.38403100E+00, -.89176300E+00, -.28348500E+01, 0.86429400E+00, 0.19909600E+02, 0.21416800E+02, 0.28128900E+01, 0.12247300E+01, -.17912700E+00, 0.41764800E+01, -.15793100E+00, -.32207800E+00, -.11615200E+00, -.46635000E+00, 0.26811600E+00, -.27145100E-01, -.70643200E-02, 0.50081400E+00, 0.21689100E+00, 0.66912600E+00, -.67017500E+00, -.38292900E+00, 0.56771300E+00, -.87683100E+00, 0.42119300E+00, 0.11351600E+01, 0.11766900E+02, 0.21484100E+00, -.20136200E+01, 0.25956900E+00, 0.20772800E+01, 0.47388100E+00, -.14512400E+00, 0.15520400E+00, -.44631600E+00, -.47890600E+00, -.71756000E+00, 0.12482100E+01, 0.84416700E-01, 0.14314800E+02, 0.71150000E+00, -.17405400E+01, 0.12202800E+01, 0.44341100E+00, 0.94162700E+00, 0.16664400E-01, 0.54984600E+00, 0.54541700E-01, 0.18340700E+00, 0.12053400E+01, 0.56511300E+00, -.46080800E-01, 0.33508000E+01, 0.15279900E+01, 0.13237300E+00, 0.16529100E+00, -.32531200E+00, 0.39743700E+00, -.44552800E+00, -.95446700E-01, 0.34077800E+00, 0.44539300E-01, 0.11891100E+00, 0.14141300E+01, 0.16456400E+00, -.18230700E+00, 0.33834300E+00, 0.42516000E+00, -.39882600E+00, 0.26371300E+00, -.45279200E-01, 0.14605300E+00, -.25661800E+00, -.41813800E+00, -.30788800E+00, 0.35638300E+00, 0.10341300E+01, -.49337900E+00, 0.31891700E+01, 0.21555300E+00, -.42405700E+00, -.32569500E+00, -.38963000E+00, -.46906200E+00, -.11895400E+00, 0.60493800E+00, -.87978500E+00, -.23338800E-01, 0.18014800E-01, 0.16505800E+00, 0.17174400E+01, -.64732300E-02, -.32975000E+01, 0.28091000E+00, 0.18483900E+00, -.66929800E+00, 0.48487500E+00, 0.83804400E-01, -.36238100E+00, 0.35590500E-01, 0.43862400E+00, -.44314100E+00, 0.34492900E+00, -.25823500E+01, -.46056100E+02, 0.13947400E+01, -.15936900E+02, 0.15610100E+03, -.51952700E+02, -.75688300E+02, -.81806900E+02, -.28906100E+03, 0.64741200E+02, 0.14690700E+03, 0.60124100E+02, -.21538000E+03, 0.25743100E+03, -.12791200E+03, -.12742400E+03, -.16329300E+02, 0.11104200E+03, -.89390800E+02, 0.23620500E+02, -.81630700E+02, 0.35615200E+02, 0.46856800E+02, -.24904900E+02, -.17798500E+02, 0.41382300E+02, -.16139100E+02, -.15740400E+02, -.73336400E+01, -.42628000E+02, -.42185000E+02, -.54468500E+03, 0.29105000E+03, 0.26317100E+03, 0.81766000E+01, -.27295000E+03, 0.27926000E+03, 0.19313700E+03, 0.26906600E+03, -.14402300E+03, -.25626500E+03, 0.13413700E+03, 0.11633600E+03, -.55513200E+01, -.18551600E+02, 0.99588000E+02, 0.29295500E+01, 0.77203000E+02, 0.13865100E+02, 0.27203500E+03, -.13756800E+03, -.13857000E+03, -.45655300E+02, 0.94421100E+02, -.88442000E+02, -.34632100E+02, -.10783500E+03, 0.33231500E+02, 0.85243700E+02, -.42597500E+02, -.60739800E+02, -.42432100E+02, -.94887800E+02, 0.20789300E+02, -.65958600E+00, -.41163300E+02, -.80526000E+02, 0.12069900E+03, -.61793600E+02, -.58146300E+02, 0.59282600E+00, 0.54187900E+00, 0.31033500E+01, 0.76706500E+02, -.20430600E+01, -.21328100E+02, 0.96626800E+01, -.26023000E+02, 0.13994500E+02, 0.33866100E+01, 0.77939900E+01, 0.77279400E+01, -.13034100E+03, -.26482600E+02, -.13881600E+02, 0.19715600E+02, -.32367500E+01, -.34966100E+01, -.17884700E+02, 0.13350200E+03, 0.96521200E+02, -.11537800E+02, -.18091800E+02, -.19057900E+02, -.40238800E+02, 0.33645200E+02, -.10546300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.37559500E+01, 0.78477800E+01, 0.17610000E+01, 0.71549000E+01, -.26264900E+01, -.27209600E+02, 0.11621400E+02, -.27669300E+00, -.15208300E+01, 0.20733000E+01, -.36772400E+01, -.54045000E+01, 0.10321500E+01, 0.29419800E+00, 0.89624200E-01, 0.34811300E+01, 0.57871800E+00, 0.14071100E+01, -.21137500E+01, 0.18685100E+00, -.48582700E-01, 0.15871800E+01, 0.25515100E+00, 0.52454000E+01, -.11362500E+01, 0.25939500E+01, -.10727400E+01, -.18837000E+02, 0.39965600E+00, 0.17486600E+01, 0.11409000E+01, -.29128300E+01, -.15828300E+01, 0.61743700E+00, 0.21662300E+01, -.51527400E+00, -.94639300E+00, -.53883300E+00, 0.24424900E+01, 0.47124200E+00, 0.89909300E+01, -.40508000E-01, 0.67106800E+00, 0.81986800E+00, 0.49380600E+00, 0.83000800E+00, -.60322900E+00, -.45445100E+00, -.13937900E+01, -.94328300E+00, -.93102600E+00, -.12113800E+00, -.11087900E+01, 0.57777000E+00, 0.13853000E+01, -.43893700E+00, -.22874200E+00, -.13180500E+01, 0.56929700E+00, -.23388200E+01, -.18638200E+00, -.92803100E+00, -.21789300E+00, 0.34968300E+00, 0.31399600E+00, 0.38423200E+00, 0.62964900E-02, -.36956900E-01, 0.54826000E+00, -.24643500E+00, 0.11825300E+01, -.73031400E+00, -.16468000E+00, 0.15929100E+01, 0.66354200E-01, -.33913600E+00, -.39940700E+00, 0.64905100E+00, 0.25000900E+00, -.12157300E+02, 0.27463900E+01, -.12108500E+01, 0.19121000E+01, 0.49959900E+00, 0.74788300E+00, -.11883100E+01, 0.78955300E-01, -.17789800E+01, 0.10220500E+00, -.66919200E+00, -.19777000E+00, -.33133100E+01, -.38300400E+00, -.22782500E+01, 0.84436000E+00, -.34990300E+00, 0.18363700E+00, 0.10827800E+01, -.73673400E+00, -.26348000E+00, -.17298000E-01, -.17920400E+01, 0.15624500E+01, -.13478800E+01, 0.23368300E+01, 0.79244600E+00, 0.71662500E+02, -.81194900E+02, 0.17927200E+04, -.75353500E+03, -.91966100E+03, 0.37557500E+03, 0.94399700E+03, -.10595400E+04, -.83959600E+03, -.12338600E+04, 0.43306800E+03, -.12413600E+04, 0.62495100E+03, 0.66620000E+03, 0.65863000E+02, -.34605100E+03, 0.52666600E+03, 0.15940000E+03, 0.73321400E+03, -.12894500E+03, -.84992000E+03, 0.42288600E+03, 0.35223800E+03, -.17086000E+03, 0.37150900E+02, 0.34883300E+03, 0.36100800E+03, 0.52097100E+03, 0.83575600E+02, 0.23432900E+04, -.10499800E+04, -.11691700E+04, 0.32696900E+03, 0.89489600E+03, -.12163200E+04, -.80517400E+03, -.14960100E+04, 0.42952700E+03, 0.44031900E+03, -.23618800E+03, -.24878700E+03, -.10674500E+02, -.69664800E+02, -.14439200E+03, -.38159200E+02, -.10971900E+03, -.78614400E+02, -.15997900E+04, 0.81022100E+03, 0.73593700E+03, 0.15667500E+03, -.37513600E+03, 0.72153000E+03, 0.43115000E+03, 0.90928600E+03, -.29457900E+03, 0.43091400E+03, -.21423800E+03, -.16590600E+03, -.15736000E+03, -.21468100E+03, 0.27642200E+02, 0.14546100E+02, 0.20251200E+03, -.24774800E+03, 0.19064600E+03, -.93982000E+02, -.79896400E+02, 0.88905700E+02, 0.64373500E+02, -.99466900E+02, 0.48115800E+02, -.20094800E+03, 0.87920400E+02, -.70946700E+02, 0.18501700E+03, -.17866800E+03, -.12639900E+03, -.19345700E+03, -.98782300E+02, 0.24278000E+03, 0.15873500E+02, -.12611800E+03, -.43194100E+03, 0.11166000E+03, 0.83741600E+02, 0.42257800E+03, -.25649800E+03, -.14659300E+03, 0.19533300E+02, 0.50825300E+02, 0.18229100E+03, -.36435900E+02, -.13520700E+03, -.11453400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20385300E+01, 0.14944600E+01, -.27848500E+00, 0.33072300E+01, 0.33348500E+00, -.14890900E+02, 0.69666400E+01, -.47517800E+00, -.69771200E+00, 0.15849200E+01, 0.27304600E+01, -.11882200E+01, 0.65372400E+00, 0.81310700E+00, 0.13177200E+00, 0.72710500E+00, -.31690800E-02, 0.46032600E+00, -.13218100E+01, 0.44724800E+00, 0.74330200E-01, 0.96481900E+00, 0.11128800E+00, 0.45587900E+01, -.12547500E+01, 0.21924100E+01, -.55308000E+00, -.15185200E+02, 0.12098900E+00, -.34542900E+00, 0.64874300E+00, -.12405800E+01, -.12578000E+00, 0.62847400E+00, 0.70443800E+00, 0.71092100E+00, -.33054900E-01, -.15110200E+01, 0.33860500E+00, -.66985000E+00, 0.14058900E+01, -.16504700E-01, 0.89996200E+00, 0.53839500E+00, -.53869900E+00, 0.13379000E+01, -.21134000E+00, -.67356200E+00, -.92477300E+00, -.11593500E+01, -.19057200E+01, -.39657900E+00, -.98380300E+00, 0.15841700E+01, 0.20581000E+01, -.55073600E+00, -.44072300E+00, -.10854200E+01, 0.48644700E+00, -.10422600E+01, 0.15030200E-01, -.42921600E+00, -.48438200E+00, 0.19055700E+01, 0.26556600E+00, 0.40149400E+00, -.11237900E+00, -.15774000E+01, -.17519700E+00, 0.60264700E+00, 0.43716100E+00, -.23801400E-02, -.43315600E+00, 0.80360400E+00, -.10432900E+00, -.10740600E+00, -.43288800E+00, 0.60991400E+00, 0.45615600E-01, -.32701500E+01, 0.82262000E+00, -.21152800E+01, -.34454000E-01, 0.89502100E+00, 0.97873100E+00, -.16140400E+00, -.47775000E+00, -.30167900E+00, 0.33939800E-02, -.45139800E+00, -.23922200E+00, -.34728200E+01, -.19345100E+00, 0.16823700E+01, 0.89720300E+00, -.85566900E+00, 0.14412600E+01, 0.13685200E+00, -.44734100E+00, 0.18233500E+00, 0.64398900E-01, -.62719000E+00, 0.13115200E+01, 0.72701700E+00, -.28623900E+01, 0.16087700E+00, 0.44462200E+00, 0.11078200E+03, -.69367400E+03, 0.29872000E+03, 0.36384900E+03, -.19504100E+03, -.43124000E+03, 0.35912000E+03, 0.16891100E+03, 0.30881100E+03, -.12472800E+03, 0.42243200E+03, -.21280600E+03, -.18194700E+03, -.49443000E+02, 0.14155200E+03, -.17204900E+03, 0.17186200E+01, -.14686900E+03, 0.36006400E+02, 0.51759300E+03, -.25538600E+03, -.27830800E+03, 0.48028400E+02, 0.21481100E+02, -.22427700E+03, -.22121600E+03, -.25912300E+03, 0.14435200E+02, -.10273400E+04, 0.46785300E+03, 0.52271100E+03, -.24287100E+03, -.40762200E+03, 0.48970600E+03, 0.23328300E+03, 0.42248900E+03, -.14213000E+03, 0.40643200E+03, -.21133400E+03, -.22362200E+03, 0.36791500E+02, 0.58990100E+02, -.13227600E+03, 0.27979900E+02, -.10825100E+03, -.37402500E+01, 0.38801900E+03, -.19204200E+03, -.21511300E+03, -.14687400E+03, 0.91317600E+02, -.13569800E+03, -.16124300E+02, -.13672800E+03, 0.56598800E+02, 0.24594000E+03, -.12319000E+03, -.10689800E+03, -.36062400E+02, -.40768900E+02, -.71826200E+02, 0.94359300E+02, 0.10046000E+03, -.30268400E+02, 0.19861900E+03, -.97522200E+02, -.96126900E+02, 0.11053200E+02, 0.19739100E+02, -.75320400E+02, -.25827400E+02, -.22115800E+03, 0.16228900E+02, 0.50727300E+02, -.32016400E+02, 0.61826900E+02, 0.33200500E+02, 0.71699800E+02, 0.33138100E+02, -.71050800E+02, 0.21846200E+02, 0.58953300E+02, 0.16494200E+03, -.29342400E+02, -.23130900E+02, -.17181700E+03, 0.87935000E+02, 0.84615000E+02, 0.21786700E+01, -.11547500E+02, -.20886100E+02, 0.10540400E+02, 0.36251000E+02, 0.97013900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.61107100E+01, 0.18868800E+01, -.39938800E+01, -.54308500E+01, 0.29887900E+01, 0.17273500E+02, 0.73139100E+01, 0.10290200E+02, 0.96312800E+00, -.29012100E-01, 0.36918100E+01, 0.19456100E+01, -.20088900E+01, -.12725300E+01, -.47255900E-01, -.25621000E+01, -.70395500E+00, -.84959700E+00, 0.43625300E+00, -.15444900E+00, 0.64922000E+00, -.15196300E+01, -.21248400E+00, -.13090500E+01, 0.70558700E-01, -.21211500E+00, 0.84199900E+00, 0.15312700E+02, 0.42070400E+00, 0.34184500E+00, -.93793300E-01, -.17241300E+00, 0.12205900E+01, 0.30551500E+00, 0.37719900E-01, 0.11906200E+01, 0.92143200E+00, 0.12357400E+00, 0.17964900E+01, 0.13240800E+01, 0.66643400E+01, -.65138300E-01, 0.71833400E+00, 0.21189100E+01, -.16501000E+00, -.39884100E+00, -.80902700E+00, 0.36142100E+00, -.35855500E+00, -.15291200E+01, -.12844700E+01, -.14494600E+01, -.85652000E-01, 0.42366800E+00, 0.19443700E+01, -.62714800E+00, 0.16518000E+01, 0.12977100E+00, 0.16340700E+00, 0.10043400E+01, 0.20794800E+00, 0.12743100E+01, 0.18469300E+00, -.84676200E+00, -.16736300E+00, -.15295500E+01, -.17842800E+00, 0.11871800E+01, 0.35671200E+00, -.58164200E+00, 0.74142300E+00, 0.15379300E+00, 0.63559800E+00, -.18653900E+01, -.49913800E+00, -.36302800E+00, 0.62678400E+00, -.70001100E+00, -.56603100E+00, 0.41979000E+01, -.92366600E+00, -.92004000E-01, -.17549500E+01, 0.34267300E+00, -.64297100E+00, 0.69411600E+00, -.28119100E+00, -.45205100E+00, 0.24122800E+00, 0.42966100E+00, -.31230700E+00, -.14504400E+01, 0.71213700E-01, -.26057800E+00, 0.77969900E+00, -.52006900E+00, 0.26128400E+00, -.11423000E+01, -.75572100E-01, -.45843900E+00, 0.23367900E+00, 0.22672300E+01, -.82706500E+00, -.24950400E+01, -.97243200E+00, 0.33401200E+00, -.49507200E+00, -.27507900E+00, 0.33120300E+04, -.16477700E+04, -.16643500E+04, 0.29987100E+03, 0.47319600E+03, -.14029500E+04, -.10505900E+04, -.18067300E+04, 0.10947500E+03, -.39682100E+03, 0.20004600E+03, 0.23858300E+03, -.11785800E+02, -.31416200E+03, 0.20929500E+03, 0.12509000E+03, 0.56452000E+03, -.21458800E+03, -.36493100E+03, 0.18718500E+03, 0.16833300E+03, -.11944300E+03, 0.28626400E+02, 0.18387500E+03, 0.30417100E+03, 0.29484300E+03, 0.52723800E+02, 0.25835000E+04, -.12875300E+04, -.13099900E+04, 0.37034100E+03, 0.18428500E+03, -.10888000E+04, -.96507200E+03, -.13310100E+04, 0.42247100E+01, 0.18152600E+03, -.11942400E+03, -.11503600E+03, -.23248000E+02, -.14447800E+03, -.50356000E+02, -.68791000E+02, -.15433600E+03, -.10656800E+03, -.74799700E+03, 0.38714400E+03, 0.35762500E+03, 0.64388100E+02, -.37862700E+03, 0.40536700E+03, 0.31869300E+03, 0.77913400E+03, -.38181300E+03, 0.48539200E+01, -.21637200E+01, 0.21222600E+02, 0.35389800E+02, -.18502600E+02, -.66434300E+01, -.98932800E+02, -.42780700E+00, -.44949300E+02, -.62533500E+02, 0.31571500E+02, 0.34566600E+02, -.13819000E+03, -.16999800E+03, 0.81320400E+02, 0.24197900E+01, -.55289600E+01, -.10644200E+03, 0.80177700E+02, -.73208400E+01, -.81047400E+02, -.25170800E+02, -.70798600E+02, -.10728600E+02, -.17562000E+03, -.17915600E+02, -.17970800E+02, -.17793700E+03, 0.26294900E+02, -.13824600E+01, 0.17820900E+03, 0.24571300E+03, -.17185400E+03, 0.12902000E+02, -.12011000E+03, -.39814100E+02, 0.51979500E+02, -.10107500E+03, 0.16574500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.32125500E+00, 0.13023800E+00, 0.21662400E+00, 0.81549600E+00, -.94668800E-01, -.19570900E+01, 0.82332200E+00, 0.57479600E+00, -.10179100E+00, 0.23532200E+00, -.95743300E+00, -.59747200E+00, -.65307500E-01, 0.24954900E+00, -.19772400E+00, 0.36399700E+00, -.51204000E-02, 0.22000000E+00, -.70426700E-01, 0.12197000E+00, 0.12421700E+00, -.61733900E-01, -.70099100E-01, 0.32954000E+00, 0.11677100E+00, 0.11031500E+00, -.22622200E-01, -.11562500E+01, -.29290800E-01, 0.12215800E+00, 0.14175200E+00, -.35004300E+00, -.17624600E+00, 0.11410200E+00, 0.19964100E+00, -.36328100E-01, -.13739400E+00, -.92967900E-01, 0.20295600E+00, 0.22950500E+00, 0.18812300E+01, -.23220300E-02, 0.15553600E+00, -.43058800E+00, 0.78492000E-01, 0.30469700E-01, -.12729600E+00, 0.17525700E-01, -.30430000E+00, -.22241100E-02, 0.23955500E+00, 0.56854100E+00, 0.24814900E-01, 0.37510100E+00, 0.19466500E-01, 0.30868000E-01, -.70418300E-01, -.67174100E-01, -.44405200E-02, -.15804500E+00, 0.22445400E+00, -.51442500E-01, 0.32910400E-02, -.17847000E+00, -.28693100E-01, 0.68734700E-01, 0.95749800E-02, -.37550800E-01, -.55364900E-01, 0.15465900E-01, -.52155500E-01, -.42281600E-01, 0.72682900E-01, -.36135900E+00, -.20678800E+00, -.17948400E-01, -.82420100E-01, 0.57484100E-01, 0.99262600E-01, -.12937300E+00, 0.12401100E+00, 0.19090800E-01, -.16705400E+00, 0.52264000E-02, 0.32377400E-01, -.32376800E-03, 0.37797700E-01, -.86832600E-01, 0.81153700E-01, -.14145800E-01, -.53109900E-01, -.83512600E+00, 0.34877500E-02, 0.43979100E+00, 0.10591300E+00, -.80918100E-01, 0.14441400E+00, 0.42884800E-01, -.72587200E-01, -.10665100E-02, 0.20341700E-01, 0.13348900E+00, 0.19121800E+00, 0.65978600E-01, -.66720100E+00, 0.17923200E+00, 0.54090100E-01, 0.10380900E+00, 0.20195500E-01, -.11385600E+02, -.55565500E+00, -.13911300E+02, 0.21138900E+02, -.10333000E+01, -.27383500E+02, -.34426600E+02, 0.10774500E+02, 0.35748600E+02, -.17956400E+02, -.25876400E+02, 0.10076500E+02, 0.73619300E+01, -.17920600E+02, -.15157300E+02, -.47346600E-01, 0.40945800E+01, -.48769300E+02, 0.24712900E+02, 0.25215800E+02, -.19695900E+01, 0.81058400E+01, 0.20152600E+02, 0.19685100E+02, 0.19854400E+02, 0.15726900E+02, 0.13580600E+03, -.77810700E+02, -.73789000E+02, -.31419000E+02, 0.33630000E+02, -.44796300E+02, -.29125200E+02, -.82915600E+02, 0.77699400E+01, 0.40233500E+02, -.20871100E+02, -.74009300E+01, 0.57568800E+01, -.75116500E+00, -.13150300E+02, 0.97728200E+01, -.22165500E+01, -.49436200E+01, 0.36107200E+02, -.17628500E+02, -.11900200E+02, 0.87154800E+01, 0.27641100E+02, -.21766800E+02, -.15390300E+02, -.14980000E+02, 0.14659500E+02, -.10034900E+03, 0.49966600E+02, 0.55042600E+02, 0.26476200E+02, 0.40244300E+02, 0.76428800E+01, -.21613300E+02, -.72359300E+01, 0.37847000E+02, -.16500300E+02, 0.82291700E+01, 0.62808800E+01, 0.11012400E+02, 0.59500100E+01, -.10409100E+01, -.41815800E+01, 0.13649000E+02, 0.90519700E+01, -.64410100E+01, 0.10130200E+02, -.13455700E+02, -.50739200E+01, -.64210800E+01, -.74504100E+01, 0.65428500E+02, 0.13261100E+01, 0.14503300E+01, -.28910600E+02, 0.35027900E+01, 0.49513000E+01, 0.28960100E+02, -.35519400E+02, -.76899500E+01, 0.30297200E+00, 0.79970900E+01, 0.10601900E+02, -.20906500E+01, -.35753500E+01, -.92661700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.19727600E+01, -.11967600E+01, -.70423900E+00, -.42679700E+01, 0.35354500E+00, 0.13602100E+02, -.51204300E+01, -.20493800E+01, 0.69494300E+00, -.12341900E+01, -.57861800E+00, 0.14080400E+01, -.19182900E+00, -.68550100E+00, 0.31263200E+00, -.48199600E+00, -.39409500E-01, -.71610300E+00, 0.12229500E+00, -.21235000E+00, 0.17850400E+00, -.16893300E+00, -.48969800E+00, -.15890600E+01, 0.45690800E-01, -.76131100E+00, -.73836000E+00, 0.12955100E+01, -.17623200E+00, -.25241900E+01, -.54474100E+00, 0.99485200E+00, 0.22643600E+00, -.24274000E+00, -.14903000E+01, -.65341100E-01, 0.61121600E+00, -.19582700E+00, -.10355600E+01, 0.36049000E+00, 0.52564500E+00, -.80073900E-01, -.45734500E+00, -.18162300E+00, -.32056800E+00, 0.58003700E+00, 0.36921000E+00, -.71122500E+00, -.34562400E+00, 0.37275800E+00, -.39027300E-01, 0.36913800E+00, -.61239400E-01, 0.28344300E+01, 0.12571000E+01, 0.86916600E-01, -.88898500E+00, 0.54010500E+00, -.32859100E+00, 0.10033400E+01, 0.76204900E+00, 0.22594000E+00, -.40212100E-01, -.37253200E-01, -.14402400E+00, -.97730500E-01, 0.60999400E-01, 0.10060500E+01, -.77635500E-01, -.51896000E+00, -.92835900E+00, -.62105200E-01, 0.33245500E+00, -.26614400E+00, -.52516600E+00, 0.54224100E-01, -.19888100E+00, 0.12345600E+01, -.10873000E+00, 0.69776900E+00, 0.88503100E+00, 0.52383800E+00, -.79243300E+00, 0.61810600E+00, 0.28009100E+00, 0.84544200E-01, -.13449600E+00, -.89732300E-01, 0.38994800E+00, -.21813700E+00, 0.24932900E+00, 0.28039400E+01, -.46978100E-01, 0.50602100E+01, -.14269900E+01, -.42439600E+00, -.38535300E+00, 0.21974700E+00, 0.23280700E-01, 0.42552300E+00, -.18219000E+00, -.10328000E+01, -.34056200E+00, 0.59401000E+00, 0.62262400E+00, -.58142700E+00, 0.21456600E+00, 0.15779500E+00, -.10835300E+00, 0.29683100E+01, -.60019800E+02, 0.11134500E+03, -.50722800E+02, -.56097100E+01, -.14526700E+03, -.19204000E+03, -.20350900E+02, 0.11301100E+03, -.56829200E+02, -.95283700E+01, -.49947000E+02, -.77717000E+01, -.10137400E+02, 0.53179000E+02, -.64199700E+02, -.24615900E+02, 0.35473500E+03, -.17569900E+03, -.18254400E+03, 0.33702700E+02, -.24788800E+02, -.15073100E+03, -.14094600E+03, -.13467800E+03, -.88078400E+02, -.48054100E+03, 0.23672400E+03, 0.24238900E+03, 0.21263200E+03, -.41968000E+02, 0.14338900E+03, -.11090200E+03, -.15177200E+02, 0.15782700E+02, -.58419100E+02, 0.23460000E+02, -.63519400E+02, -.25642400E+02, -.48681800E+02, 0.27134200E+02, -.29089900E+02, -.32524300E+02, -.17431700E+02, 0.13859100E+03, -.68265400E+02, -.11534300E+03, -.63145700E+02, -.52942100E+02, 0.21183600E+01, 0.28942000E+02, -.48062600E+02, -.59047500E+02, 0.22652600E+03, -.11340900E+03, -.15641200E+03, -.73786300E+02, -.12540400E+03, -.21890900E+02, 0.55846800E+02, 0.15871000E+02, -.99544500E+02, 0.30072100E+03, -.14942700E+03, -.13347100E+03, -.36717000E+02, -.75166300E+02, -.47010900E+02, 0.63098000E+02, -.12105700E+03, -.10092400E+03, 0.77311900E+02, -.39144500E+02, 0.59811100E+02, 0.41824800E+02, 0.66612600E+02, 0.35929200E+02, -.32847400E+03, -.16549700E+02, 0.30330500E+02, 0.14689100E+03, -.37027700E+02, -.24764200E+02, -.14735000E+03, 0.23219200E+03, 0.36808100E+02, -.20287800E+01, -.51614500E+02, -.41722500E+02, 0.18582500E+02, 0.66252900E+02, 0.34272600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20737000E+01, 0.53875300E+01, 0.60857600E+00, 0.39844500E+01, -.13431000E+01, -.73628200E+01, 0.53255500E+01, -.35997000E+01, -.37094400E+00, 0.88302200E+00, 0.19701300E+01, -.65143600E+00, 0.59862000E+00, 0.15074600E+01, -.13415500E+01, 0.88114600E+00, -.31667400E-01, 0.98919200E+00, 0.16781400E+00, -.69399000E+00, -.93220900E+00, 0.11011200E+01, 0.10121300E+01, -.53346700E-01, 0.74347300E+00, -.31323100E+00, -.16502900E+00, -.42791800E+01, -.35591300E-01, 0.18019100E+00, 0.44500900E+00, -.15028600E+01, -.10106600E+01, 0.38875900E-01, 0.16106000E+00, -.71743000E+00, -.37785500E+00, 0.68351000E+00, 0.17785400E+00, -.11978300E+01, 0.60982000E+01, 0.35990900E+00, 0.17246800E+01, -.75742900E+00, -.19355700E+00, -.10653700E+00, -.22394100E+00, -.21276500E-01, -.60470400E+00, 0.22410600E-01, 0.40784600E+00, -.21917500E+00, 0.72521500E+00, 0.12055200E+00, -.71425100E+00, -.26400100E+00, -.54014900E-01, -.91371500E-01, -.19807100E+00, -.48739200E+00, 0.10426000E+01, -.16451200E+00, 0.10212300E+00, -.59084500E+00, -.11893100E+00, 0.61160900E+00, -.13429000E+00, -.90432300E+00, -.42675000E+00, 0.65635300E+00, 0.53780200E+00, 0.13753500E+00, 0.82661800E-01, 0.37009300E+00, 0.39386200E+00, 0.21095400E+00, 0.12878600E+00, -.17113900E+00, 0.22431200E+00, -.14641500E+01, -.26406700E+00, 0.50406300E+00, -.61176200E+00, 0.31919900E-01, 0.58572000E-01, -.54594600E-02, 0.20933800E+00, -.20402400E+00, 0.32634400E-01, 0.28373100E-01, -.50191100E+00, 0.19175200E+01, -.11366100E+00, -.60530300E+00, 0.76425000E+00, -.26737000E+00, 0.52736300E-01, -.14128500E-01, -.29472500E+00, -.66828100E-01, -.23101700E+00, -.25623600E+00, 0.11001200E+01, 0.28035200E+00, 0.73672800E+01, -.10278100E+01, -.32460100E-01, -.51327800E+00, 0.29650400E+00, 0.13445100E+01, -.42965000E+00, -.31943400E+03, -.10044200E+04, 0.29756100E+03, 0.37654700E+03, 0.45645300E+03, -.58731200E+03, 0.55784600E+03, -.27902900E+03, -.15122200E+03, -.13185700E+03, 0.16525800E+03, -.18040500E+03, 0.58117200E+02, -.24264300E+03, 0.15824000E+02, 0.64144400E+03, -.32195300E+03, -.38667500E+03, 0.66635200E+02, -.49154900E+02, -.24200000E+03, -.20565200E+03, -.28475500E+03, -.13783100E+03, -.17120600E+04, 0.84835600E+03, 0.87271700E+03, -.87855500E+02, -.83087800E+03, 0.82337600E+03, 0.39482900E+03, 0.82944000E+03, -.32134700E+03, -.16778200E+03, 0.91313500E+02, -.80758700E+02, 0.21466700E+02, 0.26440400E+02, 0.67169900E+02, -.21193900E+01, 0.28573400E+02, 0.46653100E+02, 0.54847400E+03, -.28021000E+03, -.39955000E+03, -.20713700E+03, 0.63769200E+02, -.12755500E+03, -.39885300E+02, -.22538700E+03, 0.11312800E+02, 0.61323600E+03, -.30766700E+03, -.35292100E+03, -.11576800E+03, -.25957400E+03, -.86601700E+02, 0.14626800E+03, 0.73048800E+02, -.21384900E+03, 0.17436500E+03, -.87217200E+02, -.55707300E+02, -.73633600E+02, -.27347600E+02, 0.65255400E+01, 0.41399400E+02, -.20031600E+03, -.47782100E+02, 0.76638100E+02, -.12203300E+03, 0.11724500E+03, 0.46264500E+02, 0.99911400E+02, 0.71816700E+02, -.47512700E+03, -.10153300E+02, 0.81964000E+02, 0.24989500E+03, -.32431500E+02, -.51909800E+02, -.24947200E+03, 0.39783200E+03, 0.17340400E+03, 0.12169200E+02, -.68846100E+02, -.89558000E+02, 0.22889700E+02, 0.75899500E+02, 0.12885100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.27173600E+01, 0.20404500E+01, 0.16072700E+01, 0.39465700E+01, -.17196700E+01, -.14264200E+02, -.14011700E+01, -.19546200E+01, -.74640200E+00, 0.56330700E+00, -.39672100E+01, -.18332900E+01, 0.71362600E+00, -.15265800E+00, 0.18744500E+00, 0.54950400E+00, 0.40502500E+00, 0.26732200E+00, 0.24010900E+00, -.14546300E+00, 0.90925000E-02, -.33749800E+00, 0.27790500E+00, 0.10293100E+00, 0.35050500E+00, -.16131700E+00, 0.16984100E+00, 0.27370700E+01, 0.22999000E+00, 0.80538800E+00, 0.44818700E-01, -.10386500E+01, -.12466500E+01, 0.76324200E-01, -.76321800E+00, -.13810400E+01, -.67765300E-01, 0.81143700E+00, -.17429100E+01, -.13366700E+01, -.35703300E+01, 0.65997700E-02, -.99365100E+00, -.97437100E+00, 0.96664500E-01, 0.10630800E+00, 0.30977300E+00, -.27235600E+00, -.59557600E+00, 0.82262100E+00, -.64852200E-01, 0.72118500E-01, -.43331400E+00, 0.17633400E+01, 0.32302700E+01, 0.22652900E-01, -.71614000E+00, 0.38675000E+00, 0.20072100E+00, -.62851400E+00, -.13066700E+00, -.19995900E+00, -.20749000E+00, 0.14978400E+01, -.29094100E+00, 0.19081100E+00, -.17003400E+00, -.13440900E+00, -.89213000E-01, 0.59547400E+00, -.13789400E+00, 0.89301200E+00, 0.46509000E+00, -.54261000E+00, -.70252600E-01, 0.24748000E-01, -.32059000E+00, 0.11167600E+01, 0.15111100E+00, -.27735200E+01, 0.14598300E+01, -.19654200E-01, 0.15862700E+00, 0.38284600E+00, -.38909200E-01, -.20428200E+00, 0.60253500E+00, 0.68476600E+00, -.41588400E-03, 0.26947900E+00, 0.39624900E+00, 0.26347100E+01, 0.11578500E+00, 0.16090800E+01, -.82736900E+00, 0.54860000E+00, -.68037500E+00, 0.57494600E+00, 0.33883800E+00, 0.10751200E+00, -.13863400E+00, -.26252500E+00, 0.18539900E+00, 0.46133400E+00, 0.43243200E+00, -.43739100E+00, -.12503800E+00, 0.32490600E-02, 0.12740800E+00, 0.24904000E-01, 0.12639600E+00, 0.52355000E+00, 0.33126100E+03, -.86563900E+02, -.11083900E+03, 0.54451800E+02, 0.14635000E+03, -.24518800E+03, 0.12285800E+03, 0.26640200E+02, 0.11148700E+03, 0.23794200E+02, 0.17895500E+02, -.17200800E+03, -.85034500E+02, 0.96748200E+02, -.14034200E+03, 0.68841000E+02, 0.11201400E+03, -.45294300E+02, 0.38348900E+02, 0.48336100E+02, 0.17627000E+02, 0.55481800E+02, 0.65173400E+02, 0.11498000E+04, -.56914300E+03, -.55679100E+03, -.20356900E+03, 0.30398100E+03, -.44933500E+03, -.12797400E+03, -.28918800E+03, 0.70100700E+01, -.71849800E+02, 0.44467700E+02, 0.13316500E+03, -.14147600E+02, 0.24491600E+02, 0.98337300E+01, 0.27063500E+01, 0.53816200E+02, 0.88536000E+01, 0.11193200E+03, -.56599000E+02, 0.17800600E+02, 0.10256000E+03, 0.96180300E+02, -.13605600E+03, -.20944200E+03, -.23944700E+03, 0.14189500E+03, -.33328700E+03, 0.16724600E+03, 0.17570000E+03, 0.71166700E+02, 0.15889000E+03, 0.23508500E+02, -.68834600E+02, -.34658300E+02, 0.14757700E+03, -.17182400E+03, 0.84578800E+02, 0.68979600E+02, 0.11110000E+02, 0.38384500E+02, 0.23863400E+02, -.42626800E+02, 0.16318900E+03, 0.16736000E+02, -.32151600E+01, 0.49857700E+01, 0.65787900E+01, 0.21552500E+02, 0.66455100E+01, 0.10923500E+02, 0.32348200E+03, 0.34377300E+02, 0.93087100E+01, -.58770500E+02, -.26547800E+02, -.15334900E+02, 0.58305700E+02, -.32054900E+03, -.94903500E+02, 0.70947400E+01, 0.67957500E+02, -.35032800E+01, 0.12862900E+02, 0.31443200E+00, -.27950800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.68901000E+01, -.59455200E+00, -.52890100E+01, -.83616200E+01, 0.36357500E+01, 0.35567900E+02, 0.10166000E+02, 0.18716900E+01, 0.21939800E+01, -.61326400E+00, 0.35929200E+01, 0.55068300E+01, -.16552600E+01, -.12010900E+01, 0.92268700E+00, -.39710300E+01, -.61060100E+00, -.71793500E+00, -.11961700E+01, -.23187500E+00, -.48521800E+00, 0.13800300E+01, 0.11825700E+00, -.30568400E+01, -.23568400E+00, -.73963100E+00, -.11631300E+00, 0.76728800E+01, -.54222700E+00, -.13458600E+01, -.12025700E+00, 0.22191200E+01, -.73068000E+00, -.75510800E+00, -.13800000E+01, 0.20802700E+00, -.50453800E+00, 0.30112800E+00, -.19167400E+00, -.13315200E+01, -.69121800E+01, 0.44085900E+00, 0.72431900E+00, 0.38819700E+00, 0.34697600E+00, -.78930900E+00, 0.29057800E+00, 0.12227900E+01, 0.33881600E+01, -.53106100E+00, 0.16679600E+01, 0.53778400E+00, 0.12913300E+01, -.25960900E+01, -.43785300E+01, 0.30814500E+00, 0.35533600E-01, 0.49127400E+00, -.53540300E+00, -.20074400E+01, -.18881400E+01, 0.18785200E+00, 0.58736100E-01, -.81049500E+00, 0.18459600E+00, 0.45392300E+00, -.11839000E+00, -.97570600E+00, -.58500500E+00, 0.58311400E+00, 0.14706100E+01, 0.64775400E+00, -.90897800E+00, -.33148100E+00, 0.48114400E+00, 0.17372700E+00, -.20278600E+00, 0.64980300E+00, 0.87288800E+00, 0.10791900E+01, -.82086500E+00, 0.24996300E+00, -.15886800E+00, -.55137600E+00, -.68577700E+00, 0.11468800E-01, 0.12270200E+00, -.19719000E+00, -.62211300E+00, -.65119100E-02, -.27809600E+00, -.78810400E+00, 0.28875200E+00, -.11476600E+01, 0.45049400E+00, -.67410400E-01, 0.11193000E+01, -.12399000E+01, -.52060200E+00, 0.44930000E-01, -.54245200E-01, 0.34788500E+00, 0.37110900E+00, 0.49350300E+00, 0.29957800E+01, -.92558400E+00, -.20445000E+00, -.60342300E+00, -.31053600E+00, 0.48738100E+01, 0.48564900E-01, -.26038800E+00, -.18277700E+01, -.94971700E+02, 0.77838600E+02, 0.48652800E+03, -.31781200E+02, -.67312900E+03, 0.33653700E+03, 0.37409200E+03, 0.51999300E+02, 0.10550700E+02, 0.16407300E+03, -.76975600E+02, 0.59886300E+02, 0.97475400E+02, 0.26024300E+03, -.12995700E+03, -.14984600E+03, -.71104200E+02, -.24763100E+02, -.76488800E+02, -.39523400E+02, -.12634100E+02, -.70849700E+02, 0.85791400E+02, -.40862400E+02, -.70171500E+01, -.36695000E+02, -.60387400E+02, -.10678100E+03, 0.80524900E+02, 0.47138400E+03, -.11141400E+03, -.53969600E+03, 0.27354900E+03, 0.21813600E+03, -.36745400E+02, 0.43385800E+02, 0.14352800E+03, -.95246300E+02, 0.92259900E+02, 0.80786500E+02, -.18665600E+03, 0.93082900E+02, 0.55510700E+02, 0.42644600E+02, -.42322600E+02, -.22575400E+01, -.13623900E+03, -.25279000E+02, 0.58990000E+02, 0.86429000E+03, -.42995000E+03, -.44595200E+03, -.17857800E+03, -.26536300E+03, -.10309700E+03, 0.14961000E+03, 0.11929500E+03, -.25947500E+03, -.31787800E+03, 0.15841200E+03, 0.16958400E+03, -.11178700E+03, 0.17944100E+02, 0.10089400E+03, 0.10551600E+02, 0.12159600E+03, -.24113100E+02, 0.85427900E+02, -.13637600E+03, 0.13445000E+03, 0.57548900E+02, 0.44510600E+02, 0.97433700E+02, -.98320800E+02, 0.31389400E+02, -.22872200E+01, 0.96156900E+02, -.53039800E+02, -.77198100E+02, -.97020900E+02, -.69083500E+02, -.32458000E+02, 0.20447100E+02, 0.11622300E+02, -.14715200E+03, 0.25574200E+02, -.52767500E+02, 0.10310400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.27460600E+01, 0.23812700E+01, 0.76524500E+00, 0.37790500E+01, -.76174000E+00, -.12728000E+02, 0.44871900E+01, -.37379400E+01, -.52294400E+00, 0.92244700E+00, -.28488600E+00, 0.19596200E+00, 0.57469000E+00, 0.75984400E+00, -.21180300E+00, 0.18558800E+00, 0.51253200E-01, 0.14952700E+00, 0.64648200E+00, -.51133700E+00, -.97896400E+00, 0.33366900E+00, 0.93396400E+00, -.79268700E+00, 0.10088600E+01, -.66345300E+00, 0.73689600E+00, -.23997100E+01, -.57774100E+00, -.50436700E+00, -.46665000E-01, -.14023200E-01, -.30633100E+00, -.15085600E+00, 0.82447100E+00, -.69325400E+00, -.71184800E+00, 0.53166000E+00, 0.19533300E+01, 0.11536900E+01, 0.17964100E+02, 0.41586100E+00, 0.63102000E+00, -.58447100E+00, -.14279800E+00, -.72742200E+00, -.12043300E+00, 0.13907100E-01, -.78544100E+00, 0.49062300E+00, -.74064500E+00, -.67931900E+00, 0.84249900E+00, 0.47253800E+00, -.17993300E+01, -.22914200E+00, -.12147900E+00, -.92886900E-01, -.29027800E+00, -.21009600E+00, 0.35715700E+00, 0.48870200E+00, -.93344500E-01, -.24791600E+01, -.13214000E+01, -.73727200E+00, 0.15901100E+00, 0.60334700E+00, 0.10857600E-01, -.89432800E+00, 0.92125900E-02, -.89729700E-01, 0.11580300E+01, 0.10956800E+00, 0.37218800E+00, 0.22296100E+00, -.19628300E+00, 0.68842000E+00, -.44746300E+00, -.73868400E+01, 0.14564900E+01, 0.65450400E-01, -.93685100E+00, 0.11895300E+01, -.52292800E+00, 0.73591700E+00, -.34570600E-01, 0.38214200E+00, 0.39208000E+00, 0.38456600E+00, -.95266300E-02, 0.18524700E+01, 0.53585600E+00, 0.61654100E+01, 0.43874400E+00, -.12199700E+01, -.68181500E+00, -.13103100E+01, 0.43204600E+00, 0.45259200E+00, 0.60852100E-01, 0.13197200E+01, -.15273200E+00, -.30684200E+00, -.53776000E+01, -.43187700E-01, -.35114000E+00, 0.90629800E+00, 0.52142600E+00, -.56294000E+00, 0.54053000E+00, 0.24683900E+00, 0.34462600E+00, -.14425100E+00, 0.24006900E+03, 0.34502900E+03, 0.10207600E+03, -.41534100E+03, 0.20954900E+03, 0.28044600E+03, -.20566700E+02, -.19325000E+03, 0.21297200E+03, 0.61476600E+02, 0.33118200E+03, -.97874000E+02, -.54810600E+03, 0.27021700E+03, 0.20450300E+03, -.10055800E+03, -.28536300E+02, 0.24863100E+03, 0.30741800E+03, 0.35760700E+03, -.57043200E+01, -.10692800E+02, 0.13727300E+02, 0.22233000E+01, 0.94171900E+02, 0.82013800E+02, -.42764100E+02, 0.52687100E+02, 0.11688800E+03, 0.20556300E+03, -.56560100E+03, 0.29010600E+03, 0.22181300E+03, 0.98546600E+01, -.19243000E+02, 0.16679700E+03, -.30508000E+02, 0.13179900E+03, 0.60502800E+02, -.66641900E+03, 0.32904300E+03, 0.25032500E+03, 0.67250500E+02, -.17313400E+03, 0.30504100E+03, 0.14115100E+03, 0.43743000E+03, -.13019800E+03, 0.26205200E+03, -.13155500E+03, -.12513400E+03, -.47488800E+01, -.90344500E+02, 0.33120800E+01, -.51859200E+02, 0.39197400E+02, -.11052400E+03, -.89247500E+03, 0.44468300E+03, 0.46162400E+03, -.47716000E+01, 0.27906600E+02, 0.30086600E+03, 0.50956700E+02, 0.30811200E+03, 0.90954400E+02, -.44524000E+02, -.19448100E+02, -.85046900E+02, -.60490500E+02, -.13366300E+03, -.22852400E+01, 0.48058700E+02, -.39598000E+01, -.53820100E+02, -.12721000E+03, 0.63225000E+02, -.50233600E+01, 0.12787000E+03, -.68402600E+02, -.66600200E+02, 0.27725600E+02, 0.27209600E+02, -.15402800E+02, -.59969000E+01, -.18138700E+03, -.38439900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.22175000E+01, 0.23012100E+00, -.14432700E+01, -.30237900E+01, 0.15607500E+01, 0.15761300E+02, 0.66451900E+01, 0.24691200E+01, 0.95176400E+00, -.10569700E+00, -.65066300E+00, 0.11119400E+01, -.88418400E+00, -.34274400E+00, 0.30143900E+00, -.45410100E+00, -.22030300E+00, -.55174400E+00, -.24597200E-01, -.55549600E+00, 0.78347600E-01, -.41158100E+00, -.33773700E+00, -.14997900E+01, 0.17706200E-03, -.20689900E+00, -.30087000E+00, 0.12197900E+01, -.76218900E-01, -.61643400E+00, -.33371800E+00, 0.48050600E+00, 0.70828900E+00, -.38348700E-01, -.24642500E-01, 0.97763500E+00, 0.31762900E+00, -.10213000E+00, 0.64797000E+00, 0.18417200E+01, -.62662100E+00, -.21649100E+00, 0.12424200E+01, -.25503600E-02, -.24573800E+00, -.15308800E+00, -.17031000E+00, 0.10015800E+00, 0.11057300E+01, -.40242700E+00, 0.91850200E+00, 0.14774900E+00, 0.36596100E+00, -.16386100E+01, -.38064400E+01, 0.22680700E+00, -.51609300E-01, -.52779500E+00, -.29224400E+00, 0.84919500E+00, 0.51224700E+00, -.14767600E+00, 0.16920300E+00, -.63206300E+00, 0.52931600E-02, -.19415500E-01, 0.21160900E+00, -.49486700E+00, -.16819700E+00, -.42581600E+00, -.51869900E+00, -.41685500E+00, -.55555600E+00, 0.94459500E+00, 0.25902600E-01, 0.74977200E-01, 0.25114000E+00, 0.13987000E+01, -.78448400E+00, 0.43974500E+01, -.52175600E+00, -.22843300E+00, -.14285000E+01, 0.44830100E+00, -.24567200E+00, 0.33322700E+00, -.39818500E+00, -.73074800E+00, -.25075700E-01, -.44250200E+00, 0.12999300E+00, 0.17814900E+01, 0.37405300E-01, -.60251000E+00, -.28646400E+00, 0.10813500E-01, -.66342500E+00, 0.58191700E+00, -.83590100E-01, -.20455400E+00, 0.19470300E+00, -.57381800E+00, -.71730000E+00, -.90838400E+00, -.15104000E+00, 0.49868600E+00, 0.16157500E+00, 0.10404700E+00, 0.28328200E+00, 0.14323400E+01, -.77181700E-01, -.29148000E+00, -.67264500E+00, -.22036200E+00, 0.15800800E+00, 0.13091500E+03, -.98837800E+02, -.23897400E+03, 0.11845900E+03, 0.53250300E+02, 0.66638300E+02, 0.11220400E+03, 0.15016900E+02, -.85205900E+02, -.23107900E+03, 0.14187600E+03, 0.25351100E+03, -.12670600E+03, -.66896400E+02, 0.47814500E+02, 0.21414400E+02, -.12019900E+03, -.16388500E+03, -.17881600E+03, -.13507100E+02, 0.22698600E+03, -.11264100E+03, -.91988000E+02, -.40157200E+02, -.99285500E+01, -.96004200E+02, 0.19981200E+01, 0.96311200E+02, -.15236200E+03, -.26991900E+03, 0.14327900E+03, 0.17618600E+03, -.55370900E+02, -.18573000E+02, 0.88221800E+02, -.33390500E+02, 0.59891600E+02, 0.86031300E+01, 0.10806300E+03, -.55745100E+02, 0.74258100E+01, 0.16302000E+02, 0.50529900E+02, -.96805500E+02, -.10636400E+03, -.28685700E+03, 0.97289600E+02, -.14491500E+03, 0.73467300E+02, 0.41180200E+02, -.28413700E+02, 0.26161800E+02, 0.97065000E+01, -.37113700E+02, -.97952000E+02, 0.43157500E+02, 0.24681700E+03, -.12421600E+03, -.13391600E+03, -.75738200E+01, -.52396500E+02, -.52516700E+02, 0.64213400E+02, 0.49038500E+02, -.10477900E+03, 0.48257200E+02, -.64907400E+02, 0.91547700E+02, 0.63649100E+02, 0.91116500E+02, 0.43205700E+02, -.72108200E+02, 0.22153500E+01, -.41151600E+02, 0.15930800E+03, -.63250200E+02, -.34556200E+02, -.15961600E+03, -.21071900E+02, 0.67099000E+02, -.18734000E+02, 0.70029900E+01, -.82743600E+02, -.47692600E+02, 0.86257900E+02, 0.11684200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11552100E+01, 0.33603900E+01, 0.67091800E+00, 0.23892700E+01, -.98525800E+00, -.93520100E+01, 0.27010100E+01, -.67669700E+00, -.55717100E+00, 0.61227500E+00, -.63426100E+00, -.12033000E+01, 0.46754600E+00, 0.43108400E-01, -.28035800E+00, 0.73687400E+00, 0.97618300E-01, 0.56578900E+00, 0.20482100E+00, -.24828000E+00, 0.26975400E-01, -.17142600E+00, 0.24665000E+00, 0.14351500E+01, 0.24439700E+00, 0.14293100E+00, -.13651900E+00, -.80784400E+01, 0.35710500E+00, 0.24499100E+00, 0.39884500E+00, -.11026100E+01, -.43824900E+00, 0.15603300E+00, 0.14414400E+01, -.69250000E+00, -.34015000E+00, 0.12218600E+00, 0.68526800E+00, 0.55094100E+00, 0.59480700E+01, 0.49851800E-01, -.43191000E+00, 0.13915600E+00, 0.39889300E+00, 0.40052000E+00, 0.27209300E-01, -.25541900E+00, -.73106800E+00, 0.19947300E+00, 0.18107200E+00, 0.13118300E+00, -.18967200E+00, 0.11867500E+01, 0.10545900E+01, -.30245400E-01, -.19478000E+00, -.15457300E+00, 0.11711900E+00, -.41001900E+00, -.22037400E+00, 0.10664200E+00, -.48740400E-01, -.71416400E+00, -.10117000E-01, 0.11960800E+00, -.98878400E-01, 0.74795200E+00, 0.27832500E+00, -.51998200E+00, 0.56797400E-01, -.36388900E+00, 0.24527900E+00, 0.43501500E+00, 0.98916200E-01, -.20080500E+00, 0.71051900E-01, 0.53258300E+00, 0.18723800E-01, -.49738100E+01, 0.12863300E+01, 0.28880500E+00, 0.11120900E+01, 0.17034200E+00, 0.19203900E+00, -.57819000E+00, -.64930800E-02, -.28646100E+00, -.91338500E-01, -.23886100E+00, 0.17060400E+00, 0.10620900E+01, -.19823700E-01, -.12897200E+01, -.48333000E+00, 0.29580400E+00, -.30026400E+00, -.18247300E+00, -.23079700E-01, 0.28569200E-01, -.38134300E-01, -.84476300E+00, -.19772900E+00, -.58718800E+00, 0.24725500E+01, -.16114700E+00, 0.28927100E+00, -.33208900E+00, -.17725100E+00, -.43950700E+00, 0.20925400E+00, 0.28186300E-01, 0.18486900E+00, 0.25614600E-01, -.37702700E-02, -.69962600E+00, -.68118600E+02, -.22980500E+03, 0.11385600E+03, 0.76574800E+02, 0.40590700E+02, 0.66720700E+02, 0.40479700E+02, 0.14839200E+02, -.51967700E+02, 0.75774000E+02, 0.14257600E+03, -.69804300E+02, -.35731400E+02, 0.53172700E+02, 0.12609300E+02, -.69171700E+02, -.96467600E+02, -.12351100E+03, -.35239800E+01, 0.44786000E+00, -.66738600E+00, 0.32836200E+01, -.70604800E+01, -.26055900E+02, -.90857100E+01, 0.35040100E+02, 0.61324500E+02, -.98822100E+02, -.92740700E+02, 0.45462800E+02, 0.78164100E+02, -.27978900E+02, -.16554500E+02, 0.32065900E+02, -.16362000E+02, 0.23116200E+02, -.40933700E+01, -.14841000E+03, 0.75423500E+02, 0.11554800E+03, 0.22372000E+01, 0.14234400E+02, 0.22064400E+02, 0.30545800E+02, -.33147600E+02, 0.31074500E+02, -.82212100E+02, 0.41822400E+02, 0.34671900E+02, -.28227200E+02, 0.77111400E+01, 0.10673600E+02, -.20459600E+02, -.49964100E+02, 0.19612000E+02, 0.21970100E+03, -.11007900E+03, -.11744300E+03, 0.14518900E+02, -.39672900E+02, -.64584500E+02, 0.55272600E+02, 0.61900100E+01, -.66516700E+02, 0.14939400E+02, -.40670700E+02, 0.46290200E+02, 0.26144900E+02, 0.50367500E+02, 0.93859100E+01, -.16746400E+02, -.11704800E+02, -.58425300E+02, 0.81108700E+02, -.28703600E+02, -.36496500E+01, -.81229800E+02, -.97029200E+00, 0.72776000E+02, -.23420000E+02, 0.36696800E+01, -.52291200E+02, -.58240800E+02, 0.51276100E+02, 0.12286200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.28400300E+01, -.10613500E+01, 0.19560800E+01, 0.13260000E+01, -.12787900E+01, -.62165400E+01, -.84453200E+01, -.47221000E+01, -.37801900E+00, -.53234300E+00, -.39825800E+00, 0.88512800E+00, -.87169700E-02, -.19311800E+00, 0.43107300E-03, 0.12183100E+01, 0.25103500E+00, -.47026000E+00, 0.20348400E+01, -.64381300E+00, 0.30139300E-01, -.12882000E+01, -.44336500E+00, 0.12185100E+01, -.42941800E+00, -.11674700E+00, 0.47714500E+00, -.97613100E+01, 0.19794100E-01, -.22735500E+01, -.28381200E+00, 0.53196900E+00, 0.36993500E+00, -.83691500E-01, 0.31493100E+00, 0.16732900E+00, -.28546900E+00, -.97534700E+00, 0.29333300E+00, 0.26533100E+00, 0.11275900E+01, -.35745900E-02, 0.46837100E+00, -.40681500E+00, -.27622300E+00, -.18048800E-01, -.59212800E-01, 0.62610800E-01, 0.68693700E+00, 0.90375600E-01, 0.63470900E+00, 0.16584400E+00, 0.43610000E-01, 0.37555400E+00, -.16239000E+00, 0.80167900E-01, -.15956300E+00, 0.33938400E-01, -.80944600E-01, 0.11049700E+00, -.88672600E-01, 0.29410300E+00, 0.18535700E-01, -.93304700E+00, -.88334600E-01, -.17476900E+00, 0.94757300E-02, -.99431200E-01, -.13339600E+00, 0.29792400E-01, 0.39551900E+00, 0.56936000E-01, -.47417800E-01, -.20928500E+00, 0.16462900E+00, 0.13181600E+00, -.79581400E-01, 0.63808200E+00, 0.10824100E+00, -.72621600E+00, 0.37154000E-01, 0.23264400E+00, -.32721400E+00, 0.22429600E+00, 0.91731700E-01, -.23430400E-01, -.14139900E+00, 0.22639400E+00, -.18614200E+00, -.21082600E+00, -.14924400E+00, -.19153700E+00, 0.82389800E-02, -.24406500E+00, -.31261300E-01, 0.10820500E+00, 0.28627500E+00, -.20363700E+00, -.71264900E-01, 0.58872300E-01, -.56307100E-02, -.25300900E+00, 0.11205300E+00, 0.42834000E+00, 0.50821200E+00, 0.22538800E-02, 0.22499200E-01, 0.59565800E-01, 0.36784800E-01, 0.14970900E+01, 0.72614500E-01, 0.46224900E-01, -.13986200E+00, 0.83345400E-01, -.25970000E-01, -.26032600E-01, -.78081800E-02, 0.78636100E+02, -.39129600E+02, -.53466400E+02, 0.16436400E+01, 0.17555700E+02, -.31196200E+02, -.21258100E+02, -.43086100E+02, 0.12657100E+02, -.35363300E+02, 0.17110900E+02, 0.24724600E+02, -.61744800E+01, 0.21302100E+01, 0.12551600E+02, 0.40533400E+01, 0.89146700E+01, 0.10326800E+02, 0.81443200E+02, -.40163800E+02, -.34401800E+02, -.10751800E+02, -.48398900E+00, -.34684600E+02, -.15455600E+02, -.34570000E+02, 0.18288800E+01, -.61996000E+02, 0.33625900E+02, 0.38338300E+02, 0.28902300E+01, 0.84164300E+01, 0.22983200E+02, 0.54450200E+01, 0.30603400E+02, 0.77175300E+01, 0.92367100E+02, -.46902200E+02, -.38761000E+02, 0.41161800E+01, 0.33859800E+02, -.45100700E+02, -.37729400E+02, -.69405900E+02, 0.24025900E+02, -.52876000E+02, 0.26445400E+02, 0.19462600E+02, 0.13504900E+01, 0.95076000E+01, 0.18958100E+02, -.25155900E+01, -.88340700E+01, 0.12294000E+02, 0.19045100E+02, -.96000000E+01, -.10517400E+02, 0.69578900E+01, 0.15697100E+02, -.11617300E+02, -.25385100E+01, 0.24686000E+02, -.15187800E+00, -.10976700E+02, 0.16174000E+02, -.71867800E+01, -.35610500E+01, -.61805100E+01, -.35386300E+01, -.76794700E+01, 0.45489900E+01, 0.49411800E+01, -.99461400E+00, 0.24288300E+01, 0.16111700E+01, 0.10991500E+01, -.16989800E+01, -.54616500E-01, 0.10363000E+01, -.90182500E+00, 0.20902500E+02, 0.10868900E+01, 0.95257300E+01, -.25031900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.49637000E+01, 0.86341700E+00, 0.26906400E+01, 0.55456200E+01, -.26875600E+01, -.22665900E+02, -.52771700E+01, -.61673300E+01, -.13599500E+01, 0.13385400E+00, 0.31567500E+01, -.15734100E+01, 0.18362700E+01, 0.13450800E+01, -.11821200E+01, 0.22531500E+01, 0.39149600E+00, 0.52324800E+00, 0.29063900E+00, -.36497900E+00, -.18387700E+00, 0.12876000E+00, 0.14109900E+00, 0.11283500E+01, 0.47078900E+00, 0.18703700E+00, 0.70023200E+00, -.45247100E+01, 0.32589400E-01, -.26840500E+01, 0.86313500E-01, 0.13292700E+01, -.21865300E+00, -.41990500E+00, 0.61197200E+00, -.23065200E+01, -.10310600E+01, -.10223200E+00, -.71726100E+00, -.13875600E+01, 0.66335400E+01, 0.55068400E+00, -.10458500E+01, -.26465400E+01, -.40192800E-01, 0.81276700E+00, 0.66235600E+00, 0.25854300E+00, 0.85663600E+00, 0.18465000E+01, 0.26493200E+01, 0.59237200E+00, 0.28907300E+00, 0.23306500E+01, -.84133800E+00, 0.57362500E+00, -.12476900E+01, -.62877800E+00, 0.10932100E+00, -.18842100E+01, -.30190300E+00, -.45914900E+00, 0.67465300E-01, -.11623000E+01, -.39360300E+00, 0.11359700E+00, 0.59824200E-01, 0.19381900E+01, -.90672600E-02, -.21811400E+00, -.13434000E-01, -.16578200E+00, 0.29745500E+00, -.84684100E+00, -.61445100E+00, -.68114300E-01, -.35468200E+00, -.19860400E+00, 0.32685200E+00, 0.10221500E+01, 0.85239300E+00, -.29556400E+00, 0.26875000E+00, 0.29940300E+00, -.23581500E-01, -.12280000E+00, -.17858000E+00, -.30798900E+00, 0.46990900E-01, -.24014600E+00, -.24810900E+00, -.42599600E+00, -.26653200E+00, -.10834500E+01, 0.71197100E+00, -.24032000E-01, -.10360100E-01, 0.28384800E+00, 0.21619800E-01, -.27925800E-01, 0.37623700E+00, -.20795000E-01, -.24831900E+00, -.24284200E+00, -.17572800E+01, 0.21448200E+00, -.12335000E+00, 0.18435500E+00, 0.57520100E+00, 0.74358400E-02, -.44197000E+00, 0.24896000E+00, 0.25417500E+00, -.46128300E+00, -.18243800E+00, 0.61675200E+00, -.43559400E+00, 0.20019000E+00, 0.24078200E+01, -.13307400E+02, 0.42379300E+02, 0.37376900E+02, -.31801200E+02, -.96990300E+02, 0.25106000E+02, 0.42312100E+02, -.25139400E+03, 0.12445900E+03, 0.12314100E+03, -.47569400E+02, 0.21656800E+02, 0.10212100E+03, 0.48371000E+02, 0.10471800E+03, 0.60804200E+02, 0.49162000E+03, -.23861200E+03, -.26544900E+03, 0.10727700E+02, 0.31265600E+02, -.19033700E+03, -.86057100E+02, -.18812100E+03, 0.38453500E+01, -.15900000E+03, 0.84745300E+02, 0.10673400E+03, 0.25921300E+02, 0.39391900E+02, 0.47096900E+02, 0.12810700E+02, 0.13926800E+03, 0.28092600E+02, 0.17414700E+03, -.86302500E+02, -.77164300E+02, 0.56477400E+02, 0.12381000E+03, -.11939200E+03, -.14961700E+03, -.14711600E+03, 0.77290300E+02, -.12459800E+01, 0.11971900E+01, 0.17156100E+02, -.16629600E+02, -.64975000E+01, 0.25529600E+01, -.86186500E+01, 0.81619200E+02, -.13250600E+02, -.65350700E+02, 0.32593800E+02, 0.30304900E+02, 0.40900100E+02, 0.38788800E+02, 0.14033800E+02, 0.35009000E+02, 0.62532900E+02, 0.19298200E+02, -.68935600E+02, 0.49129700E+01, -.47423400E+02, -.43931000E+02, -.46720900E+02, -.17822300E+02, -.46903900E+02, 0.46451600E+02, 0.25446600E+02, -.66097100E+02, 0.39943300E+02, 0.80828700E+01, 0.65494600E+02, 0.40397800E+02, -.45601300E+02, 0.26418100E+02, -.45654900E+02, 0.27036500E+02, 0.16421700E+02, -.37417500E+02, -.26831100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.19421400E+01, 0.32725000E+00, 0.10160600E+01, 0.27693400E+01, -.11098300E+01, -.10186200E+02, 0.21576800E+01, -.90179200E+00, -.52638200E+00, 0.44541600E+00, -.47763600E+00, -.15223900E+01, 0.62382500E+00, 0.29626400E+00, -.23332900E+00, 0.10604200E+01, 0.27321400E+00, 0.20544000E+00, -.37838200E+00, 0.83474100E-01, 0.43001200E-01, 0.15259300E+00, -.27143500E-01, -.25817400E+00, 0.21112900E+00, 0.97880000E-01, 0.22102200E+00, 0.41597300E+01, 0.13505300E+00, -.75478000E+00, 0.27827200E+00, 0.83310600E+00, -.35331100E+00, -.19040000E+00, 0.39723100E+00, -.10657600E+01, -.75956500E+00, 0.53916000E-01, 0.44143600E+00, 0.18750800E+00, 0.41338100E+01, 0.32746700E+00, -.89716900E+00, -.13493500E+01, 0.19704300E+00, 0.20848900E+00, 0.46690400E+00, 0.47858600E+00, 0.13901600E+01, 0.10098600E+01, 0.21021000E+01, 0.38746500E+00, 0.27457800E+00, -.25692200E-01, -.13272500E+01, 0.27316500E+00, -.53232100E+00, -.26547900E+00, -.18684400E+00, -.18455500E+01, 0.18578500E+00, -.59248400E+00, 0.17514000E+00, -.19711100E+00, -.43328300E-01, 0.97456100E+00, -.79306500E-01, 0.56100800E+00, -.47157200E+00, 0.63802300E+00, -.40636800E+00, 0.49528700E+00, -.30082300E+00, -.36976100E+00, -.42383500E+00, -.43183300E-02, -.21892600E+00, 0.96367000E+00, -.13433500E+00, 0.35288800E+01, 0.14589300E+00, -.18381800E+00, -.41147700E-01, 0.40118900E+00, -.10679900E+00, 0.19678800E+00, -.44286000E+00, -.33472800E+00, -.95511600E-01, -.43070200E+00, -.33720900E+00, 0.41892300E+00, -.40125400E+00, -.37785300E+00, -.35534800E+00, -.69647500E-01, -.12308300E+00, 0.38523900E+00, -.61973700E-01, -.12537600E+00, -.54494600E-01, -.43068600E+00, -.24717500E+00, 0.28979100E+00, -.13954300E+01, 0.34171500E+00, 0.11289700E+00, 0.77739400E-01, 0.41275000E-01, 0.62576800E+00, -.36776000E+00, -.13352700E-01, -.26289800E+00, -.14696800E+00, -.31866800E+00, 0.69284500E+00, -.87335400E+00, -.15465000E+01, 0.10574900E+00, -.57428500E+02, 0.23833800E+02, -.47283700E+01, -.17065600E+02, -.76431500E+02, -.17757200E+02, 0.18662100E+02, -.10049200E+03, 0.49372000E+02, 0.73743500E+02, -.30224000E+02, 0.32640300E+02, 0.21225200E+02, -.29221100E+02, 0.88690800E+00, 0.46683400E+02, 0.44264300E+03, -.21767100E+03, -.20189800E+03, -.14435600E+02, 0.27050100E+02, -.19607000E+03, -.11939900E+03, -.21088400E+03, -.69278200E+00, -.13544200E+03, 0.72867900E+02, 0.11204100E+03, 0.72852900E+00, 0.69925500E+01, 0.50365300E+02, 0.13854500E+02, 0.94137900E+02, 0.95513500E+01, 0.69279300E+02, -.35366100E+02, -.13193700E+01, 0.45859600E+02, 0.36327400E+02, -.64364600E+02, -.10397700E+03, -.10052700E+03, 0.46608400E+02, -.78059600E+02, 0.39494300E+02, 0.26517700E+02, -.96222400E+01, 0.17284000E+02, 0.28197200E+02, -.15922000E+02, 0.34087300E+01, 0.22029400E+02, 0.24240900E+02, -.12810700E+02, -.17898900E+02, 0.44612300E+02, 0.22324800E+02, -.11290500E+02, 0.26480200E+02, 0.75433600E+02, -.92319600E+01, -.26985500E+02, 0.13306400E+02, -.18009000E+02, -.65805400E+01, -.17109900E+02, 0.80776400E+01, -.56707300E+02, 0.39113500E+02, 0.20988700E+02, -.81646100E+01, 0.44310000E+01, -.11671400E+02, 0.76303100E+01, 0.25417000E+02, -.60441400E+02, 0.17866700E+02, -.30872300E+02, 0.22135000E+02, 0.25475500E+02, -.71532800E+00, -.41843200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.25538900E+01, 0.14729100E+01, -.14825300E+01, -.24356700E+01, 0.15798200E+01, 0.10740600E+02, 0.36677900E+01, 0.25120100E+01, 0.66976100E+00, -.18497100E+00, 0.67084300E+00, 0.14802500E+01, -.91460500E+00, -.20485200E+00, 0.36876900E+00, -.10699500E+01, -.28383400E+00, -.44633200E+00, 0.47185600E+00, -.36306500E+00, 0.20545800E+00, -.74579200E+00, -.25975300E+00, -.10574900E+01, -.21565500E-01, -.29726500E+00, 0.42874000E+00, 0.88809900E+01, 0.20840900E+00, -.15234600E+01, -.48694500E+00, 0.35927400E+00, 0.35793100E+00, -.11211500E+00, -.27514300E+00, -.31188200E+00, 0.32951500E+00, 0.20647900E+00, 0.14099600E+00, 0.43716800E+00, 0.45159000E+01, 0.13805500E+00, 0.43294300E+00, -.18494100E+00, -.21947400E+00, -.31891300E+00, -.17397500E+00, 0.43805800E+00, 0.86923800E+00, -.10615400E+00, 0.98869700E+00, -.13736000E+00, 0.27129800E+00, 0.69395900E+00, 0.65492300E+00, -.42804200E-01, 0.16717300E-01, 0.55043500E+00, -.22342900E+00, 0.32554800E+00, -.33098500E+00, 0.21184400E+00, 0.66070800E-01, 0.78982200E+00, -.38904200E-01, -.64427200E+00, 0.47009400E-01, 0.98618800E+00, 0.12414200E+00, -.31637100E+00, 0.25980600E+00, -.84305500E-01, 0.39113600E+00, -.27786300E+00, -.18209900E+00, -.87744900E-01, 0.14179600E+00, -.56837100E+00, 0.15558100E+00, -.96249000E-01, 0.81614000E-01, 0.49042600E+00, 0.19163100E+00, -.52651600E+00, -.88409900E-01, -.31288800E-01, 0.18776800E+00, -.55097200E-01, -.82685700E-01, 0.31560100E+00, -.17777700E+00, -.21516400E-01, -.16548500E+00, -.82378100E+00, 0.45024700E+00, 0.26635200E+00, 0.58907000E-01, -.86106000E-01, 0.75471500E-01, 0.95016400E-01, 0.43442000E-01, 0.42754500E+00, 0.28853000E+00, 0.14340400E-01, -.50100100E-01, -.44197000E+00, -.14464000E+00, -.10501200E+00, -.75905900E-02, -.20508700E+00, -.27142300E+00, 0.14699800E+00, -.19358800E+00, 0.27490000E+00, -.17728400E+00, -.20760100E+00, 0.95986900E-01, -.14261300E+01, 0.54568300E-01, 0.65110900E+00, -.20963100E+02, -.29546300E+02, 0.30186100E+02, 0.39289200E+02, -.40624300E+02, -.22340400E+02, 0.41892700E+02, -.20766900E+02, -.20739000E+02, 0.32724400E+02, 0.16473500E+02, -.35731400E+02, -.27132700E+02, -.26616000E+02, -.63765100E+01, -.15371700E+03, 0.76089100E+02, 0.73284800E+02, -.23723800E+02, -.25109100E+02, 0.66629100E+02, 0.31105200E+02, 0.46972100E+02, -.12374400E+02, 0.23962300E+02, -.13497100E+02, -.10861600E+02, -.12399300E+02, -.24781800E+02, -.99712700E+00, -.50060300E+01, -.53239400E+02, -.13330600E+02, -.85818500E+02, 0.43204000E+02, 0.44303800E+02, -.29575600E+02, -.78596600E+02, 0.81763100E+02, 0.89465800E+02, 0.41956700E+02, -.48072200E+02, -.26377300E+03, 0.13135000E+03, 0.13372900E+03, 0.47533700E+02, 0.77461300E+02, 0.28794300E+02, -.76321800E+02, -.73716200E+02, 0.78438900E+02, 0.71242500E+02, -.35411500E+02, -.36713200E+02, -.80515800E+01, -.48930900E+02, 0.86877300E+01, 0.34840800E+02, -.14983700E+02, -.26519800E+02, 0.14027400E+02, -.24545100E+02, 0.11362700E+02, 0.12003900E+02, 0.20450700E+02, 0.20883200E+00, 0.15473500E+02, -.12593900E+02, -.24990600E+02, 0.33444200E+02, -.12257300E+02, 0.24517600E+01, -.33230300E+02, -.15801500E+02, 0.34533000E+02, -.70657100E+01, 0.15662300E+02, -.36178700E+02, -.21714300E+02, 0.23790500E+02, 0.14573400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10253200E+01, -.21588700E+00, -.23335300E+00, -.20318000E+01, 0.50649500E-01, 0.60068900E+01, -.12533400E+01, -.53564800E+00, 0.29757000E+00, -.62123100E+00, 0.11121800E+01, 0.10169100E+01, -.10503900E+00, -.37278000E+00, 0.94972700E-01, -.45993600E+00, -.30778000E-01, -.26522900E+00, 0.39955000E+00, -.24283400E+00, 0.92107100E-01, -.24992800E+00, -.16569700E+00, -.25079000E+01, 0.77965700E+00, -.98890000E+00, 0.38656100E+00, 0.55684200E+01, 0.35231200E+00, -.85487200E+00, -.20652100E+00, 0.77795500E+00, 0.14007000E+00, -.29285500E+00, 0.18394300E+00, -.35997000E+00, -.25900900E+00, 0.52241300E+00, 0.70592200E+00, 0.22368100E+01, 0.59156700E+01, 0.22967900E-01, -.94326400E+00, 0.10099300E+00, 0.33747100E+00, -.43062000E+00, 0.31332900E+00, 0.21847500E+00, 0.11733700E+00, 0.51119200E+00, 0.98086700E+00, 0.37025400E+00, 0.34041300E+00, -.41538500E+00, -.12966700E+01, 0.25208000E+00, -.61408000E-01, 0.22866100E+00, -.26045300E+00, -.28188200E+00, -.42477400E-01, 0.26791100E+00, 0.25948500E+00, -.24379400E+01, -.17520100E-01, 0.30700000E+00, -.19958900E+00, 0.46204900E+00, -.19200500E+00, -.46468100E-01, 0.13567400E+00, 0.45046400E-02, 0.13125600E+00, -.64712900E+00, 0.29251500E+00, 0.16347800E-01, 0.60498400E-01, 0.68025000E+00, 0.43087200E+00, 0.10384200E+01, -.18604700E+00, -.49407000E-02, -.27289700E+00, -.87228400E-01, -.36932700E+00, 0.27808600E+00, 0.67465200E+00, -.21152600E+00, 0.91525500E-01, 0.31291200E+00, -.35227500E-01, 0.14198700E+01, -.48864700E-01, 0.70647400E+00, -.30466000E+00, 0.95191800E-01, -.57135100E+00, -.47932600E-01, 0.83375600E-01, -.12155600E+00, -.13377900E+00, 0.39415000E+00, -.12543000E+00, -.33401700E+00, -.12674800E+01, 0.20447200E+00, -.74352100E-01, -.21168200E-01, 0.15469400E+00, 0.43357900E+00, 0.33520300E+00, 0.86645700E-01, 0.26958800E+00, 0.51527700E-01, 0.12280300E+00, 0.47881500E-01, 0.16389400E-01, 0.68998400E+00, 0.71272500E-01, -.42707600E+00, -.53250500E+00, -.75998100E+02, 0.23196000E+02, 0.22778300E+02, 0.51131400E+02, -.73449100E+02, -.33751900E+02, 0.16208700E+02, 0.47859700E+01, -.58891200E+00, 0.15119700E+02, -.29572100E+01, -.17224500E+02, -.19919400E+02, 0.17517500E+02, 0.86903500E+02, -.42485500E+02, -.40528900E+02, 0.32047100E+01, 0.29731600E+02, -.38476100E+02, -.58455300E+02, -.10205700E+03, 0.45722900E+01, 0.10575300E+03, -.51813400E+02, -.49360000E+02, -.68295500E+00, -.16956900E+02, -.30583300E+02, 0.56634000E+01, -.33878200E+02, -.17765500E+02, -.15832200E+03, 0.78354400E+02, 0.71037000E+02, 0.85836100E+01, -.86633800E+02, 0.91918800E+02, 0.81941600E+02, 0.13284600E+03, -.76548100E+02, -.14494300E+03, 0.71980300E+02, 0.78546500E+02, 0.41572300E+02, 0.60608500E+02, -.15189700E+01, -.52803700E+02, -.22333900E+02, 0.53921900E+02, 0.53979800E+02, -.26914600E+02, -.25940400E+02, 0.14933800E+02, -.29474300E+02, -.37473500E+01, 0.12931900E+02, -.25083800E+02, -.46699800E+01, -.97268200E+01, -.85208100E+01, -.15470300E+02, -.46470100E+01, -.52209900E+01, 0.14033800E+01, -.74297800E+01, 0.13056100E+02, 0.41155900E+01, -.26865500E+02, 0.42062700E+01, -.17229700E+01, 0.26704500E+02, 0.87367700E+01, -.46705700E+02, 0.69485200E+01, -.88432600E+01, -.10128300E+02, 0.17286000E+02, -.14561800E+02, 0.15957400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.16618900E+01, 0.38977600E+00, 0.95052900E+00, 0.27010200E+01, -.10779300E+01, -.96344600E+01, 0.31850200E+01, -.17111600E+00, -.52665700E+00, 0.48155300E+00, 0.18266700E+00, -.18062600E+01, 0.65986200E+00, 0.31552300E+00, -.28403600E+00, 0.11974600E+01, 0.24896300E+00, 0.24754300E+00, -.61445600E+00, 0.21438500E+00, -.39972100E-02, 0.42291800E+00, 0.35867400E-01, 0.17103000E+00, 0.79546500E-01, 0.31378600E+00, 0.30987600E+00, -.37304900E+00, 0.27954300E-01, 0.11962100E+00, 0.13772700E+00, 0.11171300E+01, -.34576600E+00, -.18904900E+00, 0.25380400E+00, -.93599600E+00, -.93643800E+00, 0.96213100E-01, 0.44696100E+00, 0.29237800E+00, 0.58264400E+01, 0.26117100E+00, -.19974000E+00, -.48920400E+00, 0.25780000E+00, 0.10409600E+00, -.38551800E-01, 0.54978200E+00, 0.88199900E+00, 0.55534500E+00, 0.11248300E+01, -.48683500E-01, 0.36065100E+00, -.25381100E+00, -.10274200E+01, 0.24601200E+00, -.10716700E+00, -.43127500E+00, 0.33499500E-02, -.17509100E+01, 0.20890900E+00, -.29854600E+00, 0.89369700E-01, -.92902200E+00, -.69683000E-01, 0.75735600E+00, -.84894300E-01, 0.85077700E+00, -.48255800E+00, 0.25527600E+00, -.80647800E+00, 0.13688100E+00, -.33968600E+00, 0.12975300E+00, -.23802600E+00, 0.10579400E+00, -.32994300E+00, 0.59073800E+00, -.79223800E-01, 0.43792300E+01, -.28376200E+00, -.87887800E+00, 0.50848600E+00, 0.48840100E+00, 0.26612800E+00, 0.59920500E+00, -.72460000E+00, 0.17588800E+00, -.30516900E-01, -.37877300E+00, 0.75010100E-01, 0.65193800E+00, -.38115900E-01, 0.34180000E+00, -.11362200E+00, 0.11571200E+00, -.34085600E+00, 0.81384000E+00, 0.12360800E-01, -.63817100E-02, 0.13791800E+00, -.33438400E-01, -.39151600E-02, -.18719000E+00, -.31110500E+00, -.10559600E+00, -.86132900E-01, -.11413600E+00, 0.17030700E+00, -.54465900E+00, -.51763400E+00, 0.10542700E+00, 0.63730500E-01, -.80958200E-01, -.31940600E+00, 0.26044100E+00, -.20101300E+00, -.41608300E+00, -.13079000E-02, 0.59295300E+00, -.21448600E+00, 0.23640700E+00, 0.23188200E+02, 0.31154000E+01, -.32611800E+02, 0.82435100E+01, -.50974300E+02, 0.26571700E+02, 0.24993700E+02, -.22223100E+01, -.27700000E+01, 0.11643900E+02, -.58490900E+00, 0.37801600E+02, -.94036100E+01, 0.76255500E+02, -.36877000E+02, -.58150200E+02, 0.20428100E+02, 0.38375700E+02, -.33693000E+02, -.38941500E+01, -.44949100E+02, 0.25836300E+02, -.98496800E+02, 0.44034600E+02, 0.59025400E+02, -.98855000E+01, -.99647800E+01, 0.29995700E+02, -.13470000E+02, 0.25017200E+02, 0.30106800E+01, 0.80366300E+01, -.17621100E+01, 0.19929300E+00, -.15433200E+02, 0.57264500E+01, 0.22706900E+02, 0.14337800E+02, -.48360000E+02, -.29984200E+01, -.13438200E+02, 0.68896600E+01, 0.15597600E+02, -.12096600E+02, -.12354400E+02, 0.10720700E+02, -.11086200E+02, 0.19506500E+02, -.12280300E+02, -.64062600E+02, 0.32263600E+02, 0.30391700E+02, 0.84641700E+01, -.31122000E+01, 0.29490800E+02, 0.12991900E+02, -.70608500E+01, -.22724900E+01, -.84389300E+01, 0.39078000E+01, -.70700300E+01, -.82178400E+01, -.64189500E+01, -.57692500E+01, 0.13994300E+01, 0.25334400E+00, 0.39344900E+01, 0.22923600E+01, 0.72453100E+01, 0.53968700E+01, -.24261200E+01, -.26605000E+01, 0.17816500E+02, 0.32858900E+01, -.19895300E+01, -.20780000E+01, -.62027500E+01, 0.25543000E+01, -.62937500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10191100E+02, 0.23425900E+01, -.48812400E+01, -.10857300E+02, 0.69798800E+00, 0.47326700E+02, 0.13226200E+02, 0.10553700E+02, 0.25981300E+01, -.15442400E+01, 0.41534600E+01, 0.71206100E+00, -.22065500E+01, -.40209600E+01, 0.81409300E+00, -.15547900E+01, 0.13754800E+00, -.86282000E+00, -.12518000E+01, -.58454600E+00, 0.10059800E+01, -.38289800E+00, -.12917100E+01, -.53967100E+01, 0.24154300E+00, -.12237200E+00, -.20415500E+01, 0.28419200E+02, 0.26491800E+01, 0.16639700E+01, 0.12152900E+00, -.29418600E+01, 0.15432100E+01, 0.94415800E+00, -.21492100E+01, 0.46009200E+01, 0.33718400E+01, -.92113500E-02, -.56560300E+01, -.53409400E+00, -.68070900E+02, -.22471100E+01, 0.22896100E+01, 0.35114900E+00, -.20602700E+01, 0.24866800E+01, 0.27755900E+00, -.19385400E+01, 0.22857100E+01, -.11757100E+01, 0.17655000E+01, 0.33688100E+01, -.18733800E+01, 0.40995500E+01, 0.54348100E+01, -.11010100E-01, -.38985500E+00, 0.16490500E+01, -.28300300E+00, -.72248200E+00, 0.14087700E+01, 0.13318600E+00, 0.42730400E-01, -.44112800E+00, 0.30245300E+01, 0.19750100E+01, -.70003900E+00, -.32080800E+00, 0.44365100E+00, -.55667700E+00, -.74251000E+00, -.58138000E+00, -.56089000E+00, -.52251200E+00, -.53734500E+00, -.68213600E+00, 0.72183600E+00, 0.27562700E+01, -.18327300E+01, 0.11850700E+02, -.20785200E+01, -.26399400E+01, -.24506700E+01, 0.14791800E+01, -.32285000E+00, 0.28578900E+00, 0.15838400E+01, 0.79429300E+00, -.85841900E+00, 0.70603100E+00, 0.28973200E+00, 0.74237400E+01, -.99143500E-01, -.50747300E+01, -.25592800E+01, -.16884500E+00, 0.14014000E+01, -.29942500E+01, -.64680300E-01, -.44245200E+00, 0.38637300E+00, -.18277100E+01, -.41881400E+01, 0.55466200E+00, 0.33863200E+01, 0.14363700E+00, -.11559200E+00, 0.31548100E+00, 0.63525800E+00, -.77740000E+01, -.61637700E+00, 0.33048300E+00, 0.17325700E+01, -.10069400E+01, -.14608300E+01, 0.20088900E+01, -.37898400E+01, -.58171300E+01, 0.16665000E+00, -.42503100E-01, -.78844700E+00, -.94935500E+00, 0.21487300E+01, 0.25423500E+03, 0.27342100E+03, -.30435200E+02, -.26148300E+03, 0.12479500E+03, 0.12736100E+03, 0.14921500E+02, -.60989100E+02, 0.15129000E+03, 0.20085900E+03, 0.12275700E+03, 0.57992600E+01, 0.12790800E+03, -.66218300E+02, 0.64044200E+01, 0.85988200E+02, 0.90119800E+02, -.15443800E+03, -.11920500E+03, -.11880800E+03, 0.15845600E+03, -.66246200E+03, 0.35848300E+03, 0.29238300E+03, 0.33811000E+02, -.10172300E+02, 0.22659000E+03, 0.55127400E+02, 0.21325000E+03, 0.65417700E+02, -.67807900E+03, 0.32602100E+03, 0.31151100E+03, -.56828500E+00, 0.67342300E+02, 0.18440300E+03, 0.26826600E+03, 0.47472800E+03, -.75471900E+02, 0.13715100E+03, -.69032500E+02, -.11493800E+03, -.89022200E+02, -.13911000E+03, 0.14061500E+03, 0.48599400E+02, -.61846300E+02, -.93308900E+02, -.58020800E+02, 0.26803300E+02, 0.38039800E+02, 0.99790600E+02, 0.66359100E+02, -.81985100E+02, 0.14048400E+03, 0.32312300E+03, -.27060500E+02, -.80694300E+02, 0.71697700E+02, -.70809200E+02, -.59818100E+02, -.10002200E+03, -.54251900E+02, 0.11366900E+03, -.69602700E+02, -.18130600E+03, -.23361000E+02, 0.45803400E+02, 0.47968000E+02, 0.26140400E+02, -.65957700E+02, 0.15718000E+03, -.48358600E+02, 0.67422700E+02, 0.10216000E+03, -.16375200E+03, -.26363800E+02, -.18539700E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.78046200E+01, 0.69273600E+01, 0.29686500E+01, 0.68515300E+01, 0.62783700E-01, -.37862400E+02, -.57358100E+01, -.80592000E+01, -.22077300E+01, 0.13099100E+01, 0.10532500E+02, -.16831700E+00, 0.33926400E+01, 0.24716700E+01, -.20262500E+00, 0.11263200E+01, -.73762200E-01, -.39403200E-01, 0.18191000E+01, -.14173500E+01, -.16838300E+01, -.69537800E-01, 0.19947700E+01, 0.15038100E+01, -.43412700E+00, -.51145100E+00, 0.23364500E+01, -.22317600E+00, -.81019100E+00, -.52657500E+01, -.11312300E+01, 0.37337800E+01, -.35153200E+00, -.93761800E+00, 0.14723200E+01, -.34961700E+01, -.20826700E+01, 0.54540500E+00, 0.22745000E+01, -.14644800E+01, 0.23373700E+02, 0.98214800E+00, -.40798300E+00, -.21109500E+01, 0.10256200E+00, -.13964100E+01, -.36200600E+00, 0.10343900E+01, 0.13180600E+01, 0.90857100E+00, 0.12890900E+01, -.10570400E+01, 0.14789600E+00, -.18390600E+01, -.43456600E+00, -.53745800E+00, -.29985400E+00, 0.13451300E+01, -.86511900E+00, 0.49751000E+00, -.46845900E+00, 0.26931600E+00, 0.64748800E+00, -.29125900E+01, -.84002500E-01, -.22004300E+00, 0.14785500E+00, -.21429600E+01, -.54739600E+00, 0.60547800E+00, 0.92845200E+00, -.20277700E+00, -.47377500E+00, 0.39869900E+01, 0.21538800E+01, 0.10733600E+01, 0.48065500E+00, -.40328800E+00, -.41024200E+00, 0.23270500E+01, -.14249000E+01, -.40164300E+00, -.57805000E+00, 0.61333800E+00, -.61070700E+00, 0.32640900E+00, -.43506200E+00, 0.21560500E+00, -.36909300E+00, -.29815900E+00, -.40360000E+00, 0.88288400E+01, 0.40502800E-01, 0.14793900E+01, 0.49927100E+00, -.99845200E+00, -.53664200E+00, -.11298000E+01, 0.34462400E+00, 0.60951400E+00, -.85198600E-01, -.13529200E+01, 0.25845800E+00, 0.13005600E+01, 0.72797800E+01, -.20839000E+01, -.13839100E+00, 0.11067500E+00, -.52488900E-01, 0.17670200E+00, 0.12712000E+00, 0.12585700E+01, -.92116900E-01, -.23479800E+00, 0.74903300E+00, 0.31567700E+00, 0.54059400E+00, 0.29492400E+01, 0.10393500E+00, -.90757600E+00, 0.20619600E+01, -.29794300E+00, -.31161700E+01, -.25670400E+00, 0.21137600E+03, -.19209100E+02, -.71817800E+02, 0.38457200E+02, 0.64375900E+01, -.92594000E+02, -.19357000E+02, 0.48276400E+02, 0.20716900E+02, 0.69422500E+02, 0.11029500E+02, 0.55476100E+03, -.27004400E+03, -.33485700E+03, 0.91571800E+02, 0.72722300E+02, -.24617000E+03, -.14631300E+03, -.29430800E+03, 0.45321100E+02, -.40343000E+02, 0.85051600E+01, 0.71378300E+02, 0.35970100E+02, 0.39706500E+02, -.29283500E+01, 0.23146000E+02, 0.12740200E+03, 0.20292100E+02, 0.39076800E+02, -.12959500E+02, -.20621000E+02, 0.29782700E+02, 0.14273800E+03, -.74074200E+02, -.10311600E+03, 0.15912900E+02, 0.34468100E+02, 0.76259600E+03, -.37974800E+03, -.33021700E+03, -.15664300E+03, -.22799100E+03, -.84035600E+02, 0.19002200E+03, 0.25590500E+03, -.22884100E+03, -.28499200E+03, 0.14195200E+03, 0.13948000E+03, 0.78027900E+02, 0.91628600E+02, 0.33542600E+02, -.10902100E+02, -.28205500E+02, 0.68789300E+02, -.37515200E+02, 0.30002100E+02, -.36676000E+02, -.47601600E+02, -.66443900E+02, 0.10127700E+01, -.32832900E+02, 0.42516400E+02, 0.53842300E+02, -.75629400E+02, 0.46212200E+02, -.26449000E+01, 0.74412400E+02, 0.75896600E+02, -.49674300E+02, 0.27391800E+02, -.67741000E+02, 0.47759800E+02, 0.36879400E+02, -.94733500E+02, -.10763900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13512600E+01, -.10678100E+01, 0.13386700E+00, -.23002300E+01, -.21809900E+00, 0.85659900E+01, -.30139700E+01, 0.51037000E+00, 0.40029900E+00, -.84456000E+00, -.19450700E+01, -.42669300E+00, -.23566700E+00, -.48277500E+00, 0.18982200E+00, 0.48791200E+00, 0.81095900E-01, -.39520200E+00, -.19324800E+00, -.12311800E+00, -.24186800E-01, -.75709400E-01, -.20126300E+00, -.15691200E+01, 0.61463600E-01, -.50371800E+00, -.52814800E+00, 0.53870000E+01, -.83569100E-01, -.24702300E+00, -.59129500E+00, -.66883200E-01, -.20404400E+00, -.16487500E+00, -.72849600E+00, -.36885900E+00, 0.28391600E+00, 0.92688000E+00, -.29985000E+00, 0.42939800E+00, 0.72714400E+00, -.14466200E+00, 0.56353800E+00, 0.31936800E-01, 0.18989500E+00, -.75333800E+00, -.46036100E+00, 0.14233800E+00, 0.15365400E+00, 0.14212300E-01, 0.40246900E+00, 0.40377600E-02, 0.34010400E+00, -.11811000E+01, -.64658800E+00, 0.19895500E+00, 0.20162200E+00, 0.20000800E+00, -.58925600E-01, 0.58006700E+00, 0.29743700E+00, -.15563000E+00, -.11029000E-02, 0.19753100E+00, -.19708600E+00, -.66051800E+00, 0.33145700E+00, 0.12646500E+01, -.25697900E-01, -.42403200E+00, -.58275700E+00, -.35107400E+00, 0.17492900E+00, -.31423200E-01, -.51097700E-01, 0.17485600E+00, -.19458000E+00, 0.44833600E+00, 0.32390500E+00, 0.32718500E+00, 0.45778100E+00, 0.68023000E+00, 0.49234400E+00, -.47576100E+00, 0.34300100E+00, -.21833400E+00, 0.17045700E+00, -.10858700E-01, -.13031400E+00, -.62972800E-01, 0.11563300E+00, 0.21375100E+01, -.77425200E-01, 0.12094100E+01, -.55624900E+00, 0.47515200E+00, -.80332800E+00, 0.75907600E+00, 0.15531800E+00, 0.20797700E+00, 0.31356500E-01, -.40937700E+00, 0.19706200E+00, 0.19992600E+00, 0.20190200E+01, -.49984400E+00, 0.18743800E-01, -.40073800E+00, -.10411300E+00, 0.28340000E+01, -.13994900E+00, 0.28093400E+00, -.28398600E+00, 0.19615800E+00, -.64171600E-01, 0.18654000E+00, -.97325700E-01, -.84827600E+00, -.98494300E-01, 0.95513800E+00, -.20815700E+00, -.30535800E+00, 0.34351500E+00, 0.78677200E-01, -.26965900E+00, -.18084600E+02, 0.20722400E+03, -.10069200E+03, -.10455600E+03, 0.58005900E+02, 0.35403400E+02, -.10903500E+03, -.94102000E+02, -.92996700E+02, -.54179100E+01, -.13096500E+03, 0.65842900E+02, 0.48818900E+02, -.37621300E+02, -.80625800E+02, 0.86001200E+02, 0.67472600E+02, 0.95627500E+02, -.75879100E+02, 0.19916800E+03, -.11094100E+03, -.86124500E+02, -.56431100E+01, -.92038400E+01, -.72035600E+02, -.22884300E+02, -.10426700E+03, -.21609100E+02, 0.57716900E+02, -.23129100E+02, -.20989700E+02, -.17810000E+02, -.21342300E+02, -.10252500E+02, -.35493800E+01, -.83070600E+01, -.11015000E+02, -.71400900E+02, 0.35775700E+02, 0.54507000E+02, 0.38066100E+02, 0.53549700E+02, -.36993000E+02, -.19653900E+02, 0.18705500E+02, 0.46896600E+02, -.31788100E+01, 0.18391000E+01, -.15475800E+01, -.36683600E+02, -.59243100E+02, 0.27330300E+02, -.80887900E+01, -.82602200E+02, -.46029600E+01, 0.36900900E+02, -.75595300E+02, 0.45317600E+02, 0.24306100E+02, 0.53478200E+02, 0.20108200E+02, -.22485700E+02, 0.15456000E+01, 0.10978200E+02, 0.27028800E+02, -.24554500E+02, -.13122500E+02, -.27785300E+02, 0.15504900E+02, 0.31686400E+01, 0.16125500E+01, -.99205000E+01, -.93863300E+02, 0.63364300E+01, 0.19975100E+02, 0.10071300E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.36504600E+01, -.44710900E-01, 0.21367100E+01, 0.47266200E+01, -.24416300E+01, -.26136700E+02, -.10618400E+02, -.43946800E+01, -.15835300E+01, 0.31342500E+00, 0.13614600E+01, -.13597500E+01, 0.17367000E+01, 0.44870300E+00, -.47786400E+00, 0.55325500E+00, 0.31887500E+00, 0.77022900E+00, 0.87827400E-01, 0.52917500E+00, -.32711100E+00, 0.43692900E+00, 0.84134800E+00, 0.26279100E+01, -.17433600E+00, 0.29322800E+00, 0.46326200E+00, -.27554000E+01, -.20889400E+00, -.20876300E+00, 0.36478600E+00, -.20627200E+00, -.84596200E+00, 0.20269000E+00, -.24179200E+00, -.10567400E+01, -.34706300E+00, -.26197300E+00, -.16140600E+01, -.33110100E+01, -.46871900E+01, 0.16348100E+00, -.25640800E+01, -.57259400E+00, 0.67129600E+00, 0.75382100E+00, 0.39029000E+00, -.79475500E-01, -.13664300E+01, 0.86043300E+00, -.12888100E+01, -.69080800E-02, -.80777400E+00, 0.24570700E+01, 0.51140100E+01, -.10390300E+00, -.36861900E+00, 0.14781800E+00, 0.63303400E+00, -.15460600E+01, -.26551600E-01, -.21223100E+00, -.26356400E+00, 0.33808800E+00, 0.48095600E-02, 0.60010100E-01, -.37916800E+00, 0.11489100E+01, 0.52132100E+00, 0.23787300E+00, 0.34043900E+00, 0.10398300E+00, 0.82248100E+00, -.43206600E+00, 0.15498300E+00, -.17949700E+00, -.28694400E+00, -.12183500E+01, 0.75823400E+00, -.54295400E+01, 0.99574500E+00, -.52793900E+00, 0.16983500E+01, -.72297700E+00, 0.74239200E+00, -.54732700E+00, 0.64755500E+00, 0.34855000E+00, 0.10520300E+00, 0.67311300E+00, -.98152900E-01, -.26996600E+01, -.21961700E-01, 0.19180000E+01, 0.41706500E+00, -.10814100E+00, 0.86412300E+00, -.33930100E-01, 0.60043400E-01, 0.10602300E+00, -.25752000E+00, 0.61929600E+00, 0.13402100E+01, 0.12700500E+01, -.35976300E+01, -.14855700E+00, -.71119600E-01, 0.65085900E+00, -.46993200E+00, -.39882600E+01, 0.42946100E-01, 0.14396600E+00, 0.11793300E+01, 0.12883600E+00, 0.17524600E+00, -.14595600E+01, 0.83229600E+00, 0.12895500E+01, -.58962200E-01, -.90674500E+00, 0.11763900E+01, 0.90130200E+00, -.78937200E+00, -.22461300E+00, 0.20993500E+00, -.15663500E+01, 0.21294500E+03, -.10314700E+03, -.10333400E+03, 0.31054600E+02, 0.35206600E+01, -.98067500E+02, -.86496300E+02, -.67624400E+02, -.36829900E+02, 0.38079500E+02, -.16409500E+02, -.46706300E+01, 0.94019200E+00, -.32458600E+02, -.39301200E+01, 0.31195500E+02, 0.15532400E+02, -.40857300E+02, -.19217200E+03, 0.83986300E+02, 0.85356900E+02, -.10803800E+02, 0.44876600E+01, 0.44798800E+02, -.52524500E+02, 0.19968100E+02, 0.28131600E+02, 0.21576600E+03, -.10221000E+03, -.11095100E+03, -.42581800E+02, -.35268400E+02, -.54016700E+02, -.19660900E+02, -.67084300E+02, -.23141600E+02, 0.19317100E+03, -.96104900E+02, -.10546000E+03, -.37245400E+02, -.69044900E+02, -.33882400E+02, 0.27949900E+02, 0.44558400E+02, -.61207700E+02, -.12681600E+03, 0.63859300E+02, 0.66092700E+02, -.47875700E+02, 0.45676000E+01, 0.59462600E+02, 0.13257200E+02, -.18368400E+02, 0.96674000E+01, 0.53440600E+02, -.77281300E+02, 0.55040700E+02, 0.27636500E+02, 0.43772400E+02, 0.35168400E+02, -.59001900E+02, 0.13848200E+01, 0.31395500E+02, 0.42620200E+02, -.28060100E+02, -.25880100E+02, -.43396200E+02, 0.13180400E+02, -.83909900E+01, 0.39557300E+01, -.73974100E+01, -.90512100E+02, 0.21313200E+02, 0.15388600E+02, 0.78777200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.42688200E+01, 0.34213600E+01, -.23650400E+01, -.32242000E+01, 0.11564900E+01, 0.12617400E+02, 0.50233400E+01, 0.77113700E+01, 0.59203600E+00, -.10373900E+00, -.13228400E+00, 0.88906300E+00, -.15012800E+01, -.72034400E+00, -.62249200E+00, -.16203800E+01, -.51540800E+00, 0.19745600E+00, -.24157100E-01, 0.16272800E-01, 0.34474800E+00, -.28088100E+00, -.12990600E+00, -.16185600E+01, 0.84919900E+00, -.54717000E+00, 0.73001900E+00, 0.96120900E+01, -.14375200E-01, 0.82534400E+00, 0.28420000E+00, -.69295900E+00, 0.84382200E-01, 0.98045500E-01, 0.90648100E-01, 0.14742100E+00, 0.19539800E+00, 0.25840600E+00, 0.57018900E+00, -.33538300E+00, 0.45976500E+01, 0.30063500E+00, 0.90174200E-01, 0.31144400E+00, -.25184500E+00, -.47467900E+00, 0.44839700E-01, 0.51491500E+00, 0.31405700E+00, -.40678600E+00, 0.70409900E-01, -.29934500E+00, 0.38790400E+00, 0.81201200E+00, 0.14183700E-01, -.93497000E-01, 0.54479100E+00, -.23171000E-01, 0.10217000E+00, 0.35112100E+00, -.85560100E+00, 0.47728000E+00, 0.18579700E-01, 0.16723700E+01, -.22153900E+00, -.87583600E+00, 0.85613300E-01, 0.70736500E+00, 0.25661900E+00, -.38143900E+00, 0.69110100E+00, 0.39486700E+00, 0.50358800E+00, -.89569000E+00, -.49659600E+00, -.26855800E+00, 0.37031700E+00, -.14335600E+01, -.26067800E+00, -.69438900E+00, 0.11889100E+00, 0.11939600E+01, -.55585200E+00, -.29979100E+00, -.87751600E+00, -.21166500E-01, -.38006400E+00, -.46973100E+00, 0.28923900E+00, 0.58579200E-01, -.15356300E+00, -.25600900E+01, -.37605200E-01, -.10449100E+00, 0.88564400E+00, -.29727700E+00, -.15759000E+00, 0.10559000E+00, -.70864000E-01, -.17686500E+00, 0.51776200E-01, 0.10086200E+01, -.17130000E+00, -.98133700E+00, -.20647400E+01, 0.48952000E+00, -.17262300E+00, -.74638500E-01, 0.48933000E+00, 0.10147600E+01, 0.68596700E-01, -.66261900E-01, -.12143900E+00, 0.74163000E-01, 0.31278300E-01, 0.22857000E+00, 0.12289500E-01, 0.17568500E+00, 0.21709800E+00, -.12612400E+00, -.22088600E+00, 0.42795900E+00, -.28180600E+00, -.10584800E+00, -.49638600E-01, -.29087100E+00, -.60886800E+00, 0.21908200E+01, -.48331700E+00, 0.20544500E+02, 0.41642800E+00, 0.17600600E+01, -.37185600E+01, -.11974600E+02, -.14529400E+02, 0.33879400E+02, -.16407300E+02, -.13362800E+02, 0.25729500E+00, 0.32097300E+01, -.12733600E+02, 0.45319500E+01, -.31859600E+02, -.46284100E+01, -.12401800E+03, 0.53155000E+02, 0.58219700E+02, -.45119700E+01, -.59117000E+01, 0.31410600E+02, -.26774600E+02, 0.14642800E+02, 0.13928200E+02, 0.90361600E+02, -.40617200E+02, -.48218500E+02, -.12840500E+02, -.19167600E+02, -.13474600E+02, 0.14303100E+02, -.19218900E+02, -.22602700E+02, 0.81459700E+02, -.40513800E+02, -.44541200E+02, -.13683600E+02, -.32277200E+02, -.17936500E+02, 0.49594900E+01, 0.24819300E+02, -.37184200E+02, -.11321000E+03, 0.56591200E+02, 0.57619800E+02, -.18315200E+02, -.28966600E+02, 0.61828500E+02, 0.26564600E+02, 0.34709300E+02, -.35504600E+00, 0.14651800E+02, -.49207100E+02, 0.16906300E+02, 0.31938300E+01, 0.12432200E+02, 0.63335600E+01, -.11643400E+02, -.92309000E+01, 0.91028000E+01, -.21360100E+01, -.47586700E+01, -.55762000E+01, 0.16738300E+01, -.11561800E+02, -.14218600E+01, -.38951700E+01, 0.10644400E+02, -.57910200E+02, 0.44608600E+01, -.81643400E+00, 0.37019500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.54342200E+01, -.52789100E+01, 0.27425000E+01, 0.50528700E+01, -.14821300E+01, -.22863400E+02, -.67338600E+01, -.88412500E+01, -.10936200E+01, 0.13767300E+00, 0.35269900E+01, -.13442400E+00, 0.19462400E+01, 0.78290200E+00, 0.94837600E+00, 0.75363300E+00, 0.58057100E+00, -.72387500E+00, 0.16324500E+00, 0.60494800E+00, -.59669000E+00, 0.45231500E+00, 0.49001400E+00, -.52598500E+00, 0.27216000E+00, 0.47007300E-01, 0.12678500E+01, -.18448700E+01, 0.16098200E+00, 0.44328300E+00, 0.29546900E-01, 0.80054800E+00, -.36949300E+00, -.36597800E+00, 0.10841400E+00, -.11744700E+01, -.69378600E+00, 0.82330900E+00, -.79710800E+00, 0.39492700E+00, 0.16241300E+01, 0.15431600E+00, -.38896200E+01, -.20406100E+00, 0.99848100E+00, 0.29346600E+00, 0.13850100E+01, -.57459100E+00, -.14749600E+01, 0.16852800E+01, -.31322000E+00, 0.50863900E+00, -.23403100E+00, 0.48039300E+01, 0.57309300E+00, 0.71667000E+00, -.69194000E+00, -.69754800E+00, 0.35034400E+00, 0.87855900E+00, -.28752100E+00, 0.81110500E+00, 0.30688200E+00, -.13824500E+01, 0.18807500E+00, 0.11435200E+01, -.73740000E+00, 0.16073800E+01, -.25932100E+00, 0.34847000E+00, -.11772900E+00, 0.49755800E+00, 0.27323500E+00, -.86670800E+00, -.23999600E+00, -.12618400E+00, 0.19306500E+00, -.39390300E+00, 0.15654400E+00, 0.23674500E+01, -.50104300E+00, -.18926100E+00, -.19125000E+00, -.21112700E+00, -.26831200E+00, 0.24254400E+00, 0.11485600E+01, 0.60338100E+00, 0.21365100E+00, 0.87472000E+00, -.56372100E+00, -.23798200E+01, -.11992000E+00, 0.38615200E+01, -.60483200E+00, -.21533700E-01, 0.42379400E+00, -.11744600E+01, 0.37392800E-02, -.11446200E+00, -.56513700E-01, 0.17830300E+01, -.45945000E+00, -.79488700E+00, -.19385500E+01, 0.64946600E-01, -.40349800E+00, -.74700200E-01, 0.47608000E+00, 0.58551000E+00, 0.23771300E+00, -.13017700E-01, 0.13665900E+00, 0.24226000E+00, 0.20270600E+00, -.45765400E+00, 0.53604600E+00, 0.21934900E+00, 0.10811900E+00, -.44342800E-01, -.37084900E+00, 0.48103200E-01, -.96825700E-01, -.58346700E-01, -.16378700E+00, -.34092400E+00, -.43719500E+00, 0.54599500E+00, -.12737900E+02, 0.12746500E+02, 0.14610100E+02, -.28260200E+01, -.48482900E+01, 0.18222800E+02, 0.37397400E+02, 0.13555400E+03, -.66029500E+02, -.75440200E+02, -.57212500E+01, -.18349600E+02, -.32428700E+02, 0.58131700E+01, -.32203000E+02, -.62246500E+01, 0.16433500E+03, -.82732300E+02, -.68393300E+02, 0.21150500E+02, 0.31798700E+02, -.59762300E+02, 0.29048400E+02, -.58254300E+01, 0.17391300E+01, 0.27532400E+02, -.13513100E+02, -.15289200E+02, -.10154800E+02, 0.56880500E+02, -.33745300E+02, -.51459300E+02, -.86303400E+02, 0.40240600E+02, 0.27798600E+02, -.13957700E+02, 0.10247000E+02, 0.15679600E+02, 0.14925500E+02, -.25960300E+02, 0.42780300E+02, 0.56463800E+02, 0.14974600E+02, -.35925300E+02, 0.18013800E+02, 0.17551300E+02, 0.21876200E+02, 0.78626800E+02, -.35684800E+02, -.65969100E+02, -.54119900E+02, 0.76103700E+02, -.38204500E+02, 0.45053100E+02, -.12490300E+02, -.21327200E+02, -.76997400E+01, -.13445600E+02, -.10356000E+02, 0.12890700E+02, 0.89925200E+01, -.44455200E+02, 0.19061100E+02, 0.63822400E+01, 0.44479800E+02, 0.18295600E+02, 0.17400900E+02, 0.78016200E+01, -.19086500E+02, 0.54133500E+02, -.28254900E+01, 0.95649200E+00, -.91439700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20192300E+01, 0.24070300E+00, 0.12639400E+01, 0.27215700E+01, -.13553400E+01, -.14486100E+02, -.58044800E+01, -.17743700E+01, -.89155500E+00, 0.25262200E+00, -.76597300E-02, -.14383200E+01, 0.90301800E+00, 0.41829100E+00, -.20979900E+00, 0.85898500E+00, 0.18379500E+00, 0.37554900E+00, -.41708800E+00, 0.20337300E+00, -.29018900E+00, 0.37927100E+00, 0.50875200E+00, 0.18190600E+01, -.21612700E+00, 0.57512800E+00, -.72365200E-01, 0.16531600E+00, -.70621700E-01, -.52941500E+00, 0.26960700E+00, -.69217200E+00, -.59844400E+00, 0.26567500E+00, -.75968100E-01, -.51878400E+00, 0.26327300E-01, 0.35193700E-01, -.81992100E+00, -.21823500E+01, -.36326300E+01, 0.63491300E-01, -.35788600E+00, -.80560400E+00, 0.66853400E-01, 0.37025400E+00, 0.27187500E-01, -.87105300E-01, -.47507400E+00, 0.14093300E+00, 0.28035400E-01, 0.18403300E+00, -.54035000E+00, 0.49593400E-01, 0.24350400E+01, -.21722200E+00, -.24004600E+00, 0.23980000E+00, 0.16119500E+00, -.10988800E+01, 0.19092700E+00, -.67674500E+00, -.94978300E-01, 0.45120600E+00, 0.10701500E+00, -.16916000E+00, 0.96120800E-01, 0.49842300E-02, 0.44962400E+00, -.12119900E+00, 0.16127100E+00, -.16453000E+00, 0.22582700E+00, 0.21256000E+00, -.18832000E+00, -.13695000E+00, -.70270400E-01, -.20591700E+00, -.64627400E-02, -.24601100E+01, 0.75836900E+00, -.10513400E+00, 0.27688300E+00, -.23004000E+00, 0.22510200E+00, -.64273200E+00, 0.51926200E+00, -.29953300E+00, 0.34563900E-01, 0.12284600E-01, -.52070800E-01, -.90508600E+00, -.39661900E-01, -.78125000E+00, 0.31244700E+00, -.14403800E+00, 0.24667000E+00, 0.23775300E+00, -.14479100E-01, -.10078700E+00, -.22934300E-01, -.12778900E+00, 0.27986000E+00, 0.86920400E+00, -.15642500E+01, 0.62178800E+00, 0.98617000E-01, 0.36843100E+00, -.19449500E+00, -.69055800E+00, -.16858900E+00, -.53320500E-01, 0.15783700E+00, -.18969500E+00, 0.45641100E-01, 0.16868000E+00, -.45280400E+00, -.14762900E+01, 0.40952000E-01, 0.18740600E-01, 0.73469400E+00, -.16803800E+00, -.99443000E-01, 0.10686200E+00, 0.32335800E-01, -.41310800E+00, 0.44781500E+00, -.13300200E+00, 0.56134300E-01, -.34089100E+02, -.13721800E+02, 0.10704400E+02, 0.18572200E+02, 0.14430500E+02, -.10943800E+02, -.18828100E+02, 0.86744900E+01, 0.16484900E+02, -.17608100E+02, -.24845000E+02, 0.21159800E+02, 0.10074300E+02, 0.35228900E+02, -.24678600E+02, 0.22394000E+02, -.11652200E+02, -.14571400E+02, 0.37326100E+01, 0.19255000E+02, -.99703300E+01, -.62842800E+01, -.32352100E+01, 0.49505000E+01, 0.97308600E+02, -.48102900E+02, -.49696900E+02, 0.72221600E+01, 0.36660800E+02, -.47422200E+02, -.58404800E+02, -.60047800E+02, 0.25951200E+02, 0.97885300E+02, -.48764000E+02, -.49265400E+02, -.72932000E+01, -.17550100E+02, -.17756700E+02, 0.35177800E+02, 0.18925100E+02, -.22902800E+02, -.36605000E+02, 0.18603900E+02, 0.19002300E+02, -.26904300E+02, 0.17793600E+02, 0.26276900E+01, -.56550900E+02, -.21451800E+02, 0.12870300E+02, 0.10304500E+02, 0.18088900E+02, 0.14999800E+01, 0.46568300E+01, -.26803300E+01, 0.71479500E+01, -.18982200E+02, 0.27849500E+01, 0.33196100E+02, -.73712800E+01, -.27989000E+01, -.60796800E+01, 0.74149700E+01, 0.40318700E+01, -.23184600E+02, 0.36170800E+01, -.21312900E+01, 0.21254900E+02, 0.27148300E+02, -.51922200E+01, 0.14605700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.53974600E+01, -.20584000E+01, -.31075700E+01, -.82580400E+01, 0.34512500E+01, 0.32894600E+02, -.10106200E+02, 0.12945100E+01, 0.16597500E+01, -.17886700E+01, 0.26554800E+01, 0.49940600E+01, -.16170500E+01, 0.46448400E+00, -.94234600E+00, -.31447500E+01, -.93485500E+00, -.80394700E+00, 0.16384000E+01, -.71117300E+00, 0.41431800E+00, -.13177600E+01, -.31047300E+00, -.22250900E+01, 0.50235800E+00, -.16537800E+01, 0.47214200E+00, -.24084800E+01, -.72224300E+00, 0.10994900E+01, -.54035700E+00, 0.64247300E+00, 0.15750800E+01, -.27290100E+00, -.13783400E+01, 0.15123800E+01, 0.12467500E+01, -.10446700E+00, -.99752800E+00, -.65873300E+00, -.10967200E+01, 0.11693400E-02, 0.11937800E+01, 0.13082400E+01, -.12874300E+01, 0.31842000E+00, 0.17703100E+00, -.10783600E+01, -.19142700E+01, -.92853600E+00, -.24824900E+01, -.55413100E+00, -.48665200E+00, 0.41164500E+01, 0.14375300E+01, -.13084300E+00, 0.77862400E+00, -.52759100E+00, 0.39163000E+00, 0.33655500E+01, 0.97433600E+00, 0.19645600E+01, 0.38922600E+00, 0.50292800E+00, 0.49475900E+00, -.91154800E-01, -.69720800E+00, 0.24986700E+01, 0.46646600E+00, -.72806700E+00, 0.32488600E+00, 0.11262800E+01, 0.48910500E+00, -.21706700E+01, -.32503000E+00, -.65403700E+00, 0.10920700E+01, -.67273100E+00, -.11762400E+01, -.15268800E+01, -.13494600E+01, 0.15028600E+01, -.30479400E+01, 0.34785500E+00, -.93188900E+00, 0.10759700E+01, -.69343800E+00, -.17301800E+01, 0.15152600E+01, 0.10328200E+01, -.29617700E+00, -.70759900E+01, 0.60497100E+00, -.41858700E+01, 0.21644600E+01, -.13501400E+01, 0.24072400E+01, -.21196500E+01, -.58947900E+00, -.92246500E+00, -.35306200E+00, 0.25005800E+01, -.40955200E-01, -.21071000E+00, -.38981600E+01, 0.97727400E+00, -.24718700E+00, 0.47264500E+00, 0.32465300E+00, 0.30365600E+01, -.11622000E+00, -.55371600E+00, -.18665600E+01, 0.78569300E+00, 0.42620400E+00, 0.24468000E+00, 0.19087600E+00, 0.11867300E+01, 0.10964800E-01, 0.92269400E+00, 0.97823100E+00, -.10066300E+01, 0.50309100E+00, 0.33419900E+00, 0.75350900E-02, 0.98484400E+00, -.76726900E+00, -.89947100E+00, 0.64267100E+00, -.20257400E+01, -.96934000E+02, 0.37745700E+02, 0.11067500E+03, 0.52208600E+02, -.11384000E+03, -.60487200E+03, 0.29417200E+03, 0.36197200E+03, -.41313400E+02, -.73014100E+02, 0.27284600E+03, 0.13505700E+03, 0.24296500E+03, -.85766100E+02, 0.23665100E+03, -.11812600E+03, -.15142200E+03, 0.23808600E+02, 0.32557600E+02, -.89157100E+02, -.10476900E+02, -.11003100E+03, -.44124800E+00, 0.31760100E+03, -.15912000E+03, -.17325300E+03, 0.18311500E+02, -.63257300E+01, -.72369300E+02, -.70971300E+02, -.70236700E+02, 0.11062400E+02, 0.28325800E+03, -.14224200E+03, -.16748300E+03, 0.45355400E+02, -.54032100E+02, -.51839700E+02, 0.74983100E+02, 0.79440800E+02, -.79207800E+02, -.53562400E+03, 0.26693200E+03, 0.27348700E+03, -.15659900E+03, -.50876600E+02, 0.23681400E+03, -.10049500E+03, 0.36007400E+02, 0.37029200E+02, 0.77370700E+02, -.10027400E+03, 0.49301000E+02, 0.42288900E+02, 0.19399500E+02, 0.15115300E+02, -.12820600E+01, -.62845900E+02, 0.96481500E+02, -.44904100E+02, -.37070400E+02, -.99041300E+01, 0.45256800E+02, -.54134800E+02, -.95783600E+02, -.19729100E+02, 0.65275300E+02, -.98439500E+02, 0.87176500E+02, -.93109600E+01, 0.12723400E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.34554900E+01, 0.13524400E+01, -.24912600E+01, -.54192100E+01, 0.97085700E+00, 0.17394300E+02, 0.21732800E+01, -.73687400E+00, 0.98595600E+00, -.80670300E+00, 0.15224700E+01, 0.25024600E+01, -.61468300E+00, -.15776300E+01, 0.88478200E+00, -.17295700E+01, -.16026200E-01, -.63424800E+00, -.15157500E+00, -.44747500E+00, -.37580800E+00, 0.51974200E+00, -.92741700E-01, -.93423900E+00, -.87482900E+00, 0.75693000E-01, -.54071700E+00, 0.26041700E+01, 0.35690600E+00, 0.57550800E+00, -.26639000E+00, 0.11232200E+01, 0.70732600E+00, -.29267900E+00, -.76494900E+00, 0.93470600E+00, 0.55699600E+00, -.81436400E-01, -.98463000E+00, -.22640100E+00, -.12557300E+02, -.18127400E+00, 0.10158400E+01, 0.21246400E+01, -.13334300E+01, 0.10029800E+01, 0.49292300E+00, -.10686800E+01, 0.72424000E+00, -.51622300E-01, 0.22036500E+00, -.30036900E+00, 0.39504700E-01, 0.21049100E+01, -.29517400E-01, 0.19829600E+00, -.18773400E+00, -.48556800E+00, 0.75594800E-01, -.10190900E+01, 0.32044000E+00, 0.64493700E+00, 0.31686900E+00, -.19083200E+01, 0.29250400E-01, 0.31389400E+00, -.48956400E+00, 0.63378600E+00, 0.17253800E+00, 0.95814400E-01, -.13908200E+00, 0.25486800E+00, -.15050800E+00, -.38768700E+00, -.16509800E+00, -.26740900E+00, 0.34949000E+00, -.42030000E-01, -.59851200E+00, 0.72343800E+01, -.11959000E+01, -.10142800E+01, -.43132600E+00, 0.32983100E+00, -.30722300E+00, 0.80702700E+00, -.31222800E+00, -.41106300E+00, 0.31936700E+00, 0.27700200E-02, 0.42005000E+00, 0.15773400E+01, 0.19025200E+00, -.20700700E+00, -.65093200E+00, 0.14112700E+00, -.82278000E+00, 0.11726400E+01, 0.13771500E+00, -.57956500E+00, -.13107600E+00, 0.60533000E+00, -.84063900E+00, -.17141300E+01, -.12645600E+01, 0.35892400E+00, -.21595200E+00, -.18046800E+00, 0.16429300E+00, -.45767600E+01, 0.12431600E+00, -.16900700E+00, 0.93191400E+00, -.42120700E+00, 0.20645400E+00, -.63753800E+00, 0.10442100E+01, 0.13159600E+01, -.11070000E+00, -.11637400E+01, -.44216100E+00, 0.46969400E+00, -.12842900E+00, -.29314300E+00, -.23200900E+00, -.12683800E+01, 0.64776400E+00, -.81850900E-01, -.22469900E-01, -.33706300E+00, -.13429100E+00, -.98060700E+01, -.26458000E+02, -.10226300E+02, -.42226700E+01, -.27787700E+02, 0.14675500E+02, 0.37319800E+02, 0.22477400E+02, 0.19018600E+02, -.15419600E+02, -.40966100E+02, -.52990800E+02, 0.21435300E+02, 0.25345800E+02, -.10911700E+02, -.30796900E+02, 0.11007900E+02, -.24017000E+01, -.14193500E+00, 0.84254300E+01, 0.32952900E+02, -.11065300E+02, -.32139800E+02, 0.15912400E+02, 0.41240800E+01, 0.28566900E+02, 0.41267100E+02, -.97578400E+01, -.47780100E+02, -.39431000E+02, 0.31260800E+02, 0.24097300E+03, -.12011400E+03, -.14480000E+03, -.71912100E+02, -.10291300E+03, -.38389000E+01, 0.78632500E+02, 0.10243400E+03, -.99466200E+02, 0.53281100E+02, -.27187900E+02, -.22009500E+02, 0.18294100E+02, -.23992100E+02, -.10267900E+02, 0.13685700E+02, -.19705200E+02, -.26841000E+02, -.70929300E+01, -.10631900E+01, 0.95549800E-01, -.20765300E+01, -.19793100E+01, -.25845900E+01, -.26954700E+02, 0.62164700E+01, 0.10159300E+02, 0.88316000E+01, 0.26507500E+01, 0.34030700E+01, -.93624200E+01, 0.11605400E+02, -.11464100E+02, 0.34178000E+01, -.40458700E+01, 0.15454600E+02, 0.10280200E+02, 0.22168500E+02, -.39700900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.18043200E+01, 0.87386400E+00, 0.70771300E+00, 0.28236800E+01, -.48234800E+00, -.80189100E+01, 0.11342300E+01, -.20783700E+01, -.33378900E+00, 0.62985400E+00, -.14484000E+01, -.50312800E+00, 0.18206400E+00, 0.86322400E+00, -.27782500E+00, 0.43740300E+00, 0.33201200E-01, 0.24309300E+00, 0.27052200E+00, -.22462800E+00, -.40033300E+00, 0.24517700E-01, 0.46597900E+00, -.87073700E-01, 0.50719700E+00, -.14107600E+00, 0.49456800E+00, 0.87683700E+00, -.40280300E+00, -.64774300E+00, 0.32763800E+00, -.20611100E+00, -.69288900E+00, 0.31206700E-02, 0.21170800E+00, -.60776500E+00, -.55801400E+00, 0.21551500E+00, 0.12538300E+01, -.19687600E-01, 0.10867500E+02, 0.39817400E+00, 0.17181100E+00, -.92016100E+00, 0.51160300E+00, -.30214100E+00, -.13769100E+00, 0.41632000E+00, -.10655600E-01, 0.51150000E+00, 0.10399600E+01, -.22046200E+00, 0.10100600E+01, 0.10301900E+01, -.40452000E+00, -.52977000E-01, -.31343000E+00, 0.19096300E+00, -.21154500E+00, 0.31301800E+00, -.26691600E+00, 0.28144000E+00, -.32505600E+00, -.96068100E+00, -.10259600E+01, -.44769700E+00, 0.17931500E+00, -.36182000E+00, -.18141900E+00, -.48574800E+00, -.64517500E+00, -.11341600E+00, 0.78538800E+00, -.11319900E+00, -.22524300E+00, 0.41837700E-01, -.25866600E+00, 0.14887300E+01, -.65625900E+00, -.39166200E+01, 0.23036200E+01, -.53808600E+00, -.23244400E-01, 0.38136600E+00, -.28107200E+00, 0.54518600E+00, -.96222100E-01, 0.18678400E+00, 0.17368900E+00, 0.22082400E+00, 0.39582000E+00, 0.13107000E+01, 0.43683600E+00, 0.39526500E+01, -.27597800E+00, -.34806000E+00, -.76907200E+00, -.16054500E+00, 0.36847600E+00, 0.20002400E+00, 0.28156000E-01, 0.11017400E+01, -.17481600E+00, -.51936400E+00, -.46602000E+01, 0.17530000E+00, -.24528900E+00, 0.32276500E+00, -.29289700E-01, -.10776300E+01, 0.52706900E+00, -.23096000E+00, 0.17461500E+00, 0.75672500E-01, 0.61134200E+00, -.59277600E+00, 0.21142300E+00, -.38995800E+00, -.24082200E+00, 0.34327100E+00, 0.10045100E-01, -.39806000E+00, 0.13882000E+00, -.20582900E-01, -.27078600E+00, 0.62735900E+00, -.47923500E-01, -.36701300E+00, 0.86549500E-01, 0.10173300E+01, -.64026200E-01, 0.16312800E+00, -.22519200E+02, -.29746300E+02, 0.28079800E+00, 0.15416200E+03, -.73993500E+02, -.78282000E+02, 0.46114600E+02, 0.69778700E+02, -.88145600E+02, -.56495000E+02, -.11624000E+03, 0.35569500E+02, -.19464100E+03, 0.97412000E+02, 0.95982800E+02, -.13266500E+02, -.14811500E+02, 0.61125000E+02, -.15402600E+02, 0.59568700E+02, 0.14387800E+02, -.40639600E+02, 0.19726900E+02, 0.17994100E+02, -.19630500E+02, -.58886200E+02, 0.42035700E+02, 0.74030600E+02, 0.61774700E+02, -.51124500E+02, 0.43706300E+02, -.21860700E+02, -.27969600E+02, -.33876900E+02, -.37450100E+02, 0.38362700E+01, -.20897700E+02, -.15940400E+02, -.29390100E+02, 0.49127900E+02, -.24307700E+02, -.23309900E+02, 0.22026200E+02, -.44707600E+01, -.41707500E+01, 0.60822600E+02, 0.73372500E+01, -.25516400E+02, 0.39141500E+01, -.19161600E+02, 0.28920700E+01, 0.14044500E+00, 0.10590400E+01, 0.58128100E+01, -.31149200E+01, 0.31312200E+01, -.17671700E+02, 0.18736800E+02, -.48873900E+00, -.42485200E+01, -.18926800E+02, 0.21723200E+01, 0.95160900E+01, -.36334200E+01, -.35869900E+01, -.22006500E+02, -.13274200E+02, -.71122500E+01, -.58215900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.35722200E+01, -.68017500E+01, -.18270400E+01, -.62007700E+01, 0.21311900E+01, 0.25088600E+02, -.47938200E+01, -.14666400E+00, 0.14335000E+01, -.16467600E+01, 0.41871400E+01, 0.49199200E+01, -.11558300E+01, 0.53056500E-01, -.55275600E+00, -.27165200E+01, -.64931300E+00, -.61282300E+00, 0.11073400E+01, 0.35939300E+00, -.43125000E-01, -.22152100E+00, -.22293600E+00, -.12189100E+01, -.72790200E+00, -.98703000E+00, 0.40960900E-01, 0.11330500E+02, -.49289400E+00, 0.19172800E+00, 0.71777600E-02, -.10462000E+01, -.13374500E+00, -.66607500E+00, -.97755200E+00, -.10575300E+01, 0.94349400E+00, 0.15308000E+01, -.17614300E+01, -.50233600E+01, -.41441400E+01, 0.93771400E+00, -.23959100E+01, -.30251800E-01, 0.99319300E+00, -.72400400E+00, 0.13614600E+01, 0.10847100E+01, 0.90588700E+00, 0.10593300E+01, 0.82624800E+00, -.90445600E-01, 0.83111400E+00, 0.37395400E+01, -.32039000E+01, 0.12342400E+01, 0.28291900E+00, -.17890300E+01, 0.10505200E+01, 0.35782800E+01, 0.38687100E+00, 0.77491400E+00, -.58575600E+00, 0.37212800E+01, -.76121000E-01, -.16109700E+01, 0.23282900E+00, 0.20589800E+01, 0.29195300E+00, -.48282300E+00, -.33392100E+00, -.74289300E+00, 0.52984300E-01, 0.87905100E+00, -.38957900E+00, 0.52089000E-01, -.17071000E+00, 0.15819800E+01, -.41002600E+00, 0.11015200E+01, 0.97224200E+00, -.48331100E+00, -.10106700E+00, -.21051200E+00, 0.20961600E+00, 0.17403500E+00, -.41608500E-01, 0.30519300E+00, 0.17018800E+00, 0.42663000E+00, 0.31151400E+00, 0.14551600E+01, 0.29104400E+00, 0.64931400E+01, -.34841500E+00, 0.33552100E+00, -.62336000E+00, -.23389100E+00, 0.26237100E+00, 0.92459100E+00, 0.43188500E-03, 0.10113600E+01, 0.11640500E+01, 0.73543100E+00, 0.27592000E+00, -.10793900E+01, -.26947200E+00, -.29781500E-01, -.37147700E-01, 0.33262600E+00, 0.87677600E+00, 0.29382800E+00, 0.54522900E+00, 0.57227200E+00, -.43111100E-01, -.11488800E+01, 0.91393900E+00, 0.20561800E+01, 0.65310700E-01, -.19504000E+01, 0.17208100E+01, 0.95203500E+00, -.10109500E+01, -.32382600E+00, 0.40409900E+00, -.17859500E+01, 0.52395200E+00, 0.67396800E+00, 0.93144800E+00, 0.37035600E+00, -.51082200E+00, 0.68520600E+00, -.15465100E+00, -.61875000E+02, 0.34077300E+01, 0.16754000E+03, -.84313900E+02, -.85701800E+02, -.23794400E+02, 0.48668100E+02, -.68737600E+02, -.88806500E+02, -.12774400E+03, 0.47109600E+01, 0.23722900E+03, -.12091800E+03, -.11994700E+03, -.10567000E+02, -.23922000E+02, -.69421300E+02, 0.15589700E+02, -.93961400E+02, -.35076500E+02, -.16094700E+03, 0.80017900E+02, 0.79870700E+02, 0.13741800E+00, -.10293600E+03, 0.10620000E+03, 0.13771400E+03, 0.18678800E+03, -.73595500E+02, -.33321600E+03, 0.16561600E+03, 0.16255200E+03, 0.65160200E+02, 0.12474400E+03, 0.26038300E+02, -.12153500E+03, -.16324000E+03, 0.12566200E+03, 0.21152600E+03, -.10474100E+03, -.10721400E+03, 0.85804100E+01, -.62421700E+02, -.31530800E+02, 0.52460800E+02, -.12372600E+02, -.51343300E+02, 0.34040100E+02, -.14217200E+02, -.75982100E+00, 0.22500100E+02, 0.93499800E+01, 0.44372100E+01, 0.24639800E+02, -.13509600E+02, -.29398100E+02, 0.28932600E+02, -.18223300E+02, -.26016100E+01, -.28571500E+02, -.37196100E+02, -.14064200E+02, -.16648700E+02, 0.26945500E+02, -.22473600E+02, -.13209700E+02, -.14882600E+02, 0.44197900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.74751500E+01, 0.59168200E+01, 0.46067900E+01, 0.75400200E+01, -.32748900E+01, -.38065900E+02, -.15564000E+02, -.65581400E+01, -.24068000E+01, 0.44077100E+00, -.67355700E+00, -.28310200E+01, 0.29741600E+01, 0.36369700E+00, 0.23113200E+00, 0.18343500E+01, 0.62552200E+00, -.93621800E-01, 0.16473000E+01, -.12314700E+01, -.28533600E+00, -.13591700E+01, 0.72455200E+00, 0.27166000E+01, -.26903400E+00, 0.63351500E-01, 0.11789300E+01, -.12416600E+02, -.36207800E-01, -.21425700E+01, -.59839800E+00, 0.33804700E+00, -.75899300E+00, -.67860100E-01, -.12291200E+01, -.17733600E+01, 0.11831000E+00, 0.76466000E-02, -.42336500E+01, -.49354300E+01, -.19426500E+02, -.13363600E+00, -.21912700E+00, -.31162600E+01, -.10887800E+00, 0.26449600E+00, 0.40680900E+00, -.20873400E+00, 0.99532100E-01, 0.12828000E+01, 0.11752900E+01, 0.48184300E+00, -.11473400E+01, 0.23135900E+01, 0.62133600E+01, 0.41989500E-01, -.16712700E+01, 0.11821000E+01, -.37505900E-01, -.37657200E+00, -.23594100E+00, -.78293000E+00, 0.35888500E+00, 0.45372000E+01, 0.24409600E+00, 0.44270300E+00, -.60337300E+00, 0.19095900E+00, 0.10015500E+01, 0.10225300E+01, 0.68355300E+00, 0.10573000E+01, 0.63727400E+00, 0.31274900E+00, 0.38283300E+00, -.15087100E+00, 0.40259000E+00, -.18354000E+01, 0.12111100E+00, -.17415900E+01, -.19250000E+00, -.24844600E-01, 0.31283300E+00, -.39196600E+00, -.45834200E-01, -.38464300E+00, 0.11904900E-02, 0.34832500E+00, -.87685800E-01, 0.19603300E+00, -.41857900E+00, -.26532400E+01, -.44606900E+00, -.54977200E+01, 0.17662000E+01, -.10153900E-01, 0.13033600E+01, -.70172900E+00, 0.20735400E-01, -.33591800E-01, 0.58894700E-01, -.10611400E+00, 0.55796500E-01, 0.77860500E+00, 0.12017000E+01, -.50906100E+00, -.31339200E+00, -.11881400E+00, -.56979500E-01, 0.21053400E+01, -.56240800E+00, 0.13890000E+00, -.53064100E+00, -.81301100E-01, -.14304000E+00, 0.11026800E+01, -.16049900E+01, -.52655400E+01, 0.49455900E-01, 0.11336200E+01, 0.12835900E+01, -.90102900E+00, -.15173800E+00, 0.15380000E+00, -.26709100E-01, 0.56070900E+00, -.15895800E+00, 0.87478700E-01, -.25224500E+00, 0.22074500E+01, 0.32863000E+00, 0.42836800E+00, 0.16722100E+01, -.74185800E+00, 0.54797200E+02, 0.22533000E+03, -.11538500E+03, -.13479700E+03, -.74178600E+02, -.53540200E+02, -.48322700E+02, 0.18369600E+02, 0.32717100E+02, -.14034000E+01, 0.33334400E+03, -.16688200E+03, -.15171200E+03, 0.22370200E+02, 0.40280400E+02, -.85087000E+02, 0.55289800E+02, -.53593300E+02, -.24534100E+02, -.17010900E+03, 0.85489600E+02, 0.97186800E+02, -.57793700E+01, -.71878500E+01, 0.50174500E+02, 0.48672800E+02, 0.70685800E+02, 0.58226900E+01, -.27750500E+03, 0.13870500E+03, 0.16637000E+03, 0.35389500E+02, 0.10933600E+03, 0.34188500E+02, -.12349800E+02, -.73760100E+02, 0.11472200E+03, 0.45415100E+03, -.22574300E+03, -.23163000E+03, 0.21094800E+02, 0.17349200E+02, -.18419600E+03, -.67241200E+02, -.12815500E+03, -.21123700E+02, -.55199300E+02, 0.91588800E+02, -.27840500E+02, -.23198900E+02, -.12413500E+02, -.35402400E+02, 0.36482300E+02, 0.99750100E+01, -.19308800E+02, -.10104700E+01, 0.23694900E+02, 0.25529900E+02, 0.16114900E+01, -.15076000E+02, 0.94475700E+01, -.21509900E+01, -.26688800E+01, 0.10947700E+03, -.12095700E+02, 0.22271100E+02, -.58435800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.20122800E+01, -.56231800E+00, -.11888400E+01, -.37288400E+01, 0.16304300E+01, 0.11164000E+02, -.28229900E+01, 0.58448900E+00, 0.60938700E+00, -.72055800E+00, 0.16676800E+01, 0.24714900E+01, -.49377500E+00, -.30728800E+00, 0.40179200E+00, -.16307100E+01, -.29826600E+00, -.63697800E+00, 0.80445900E+00, -.35726200E+00, 0.13727400E+00, -.72143600E+00, -.26455900E+00, -.27697000E+01, 0.66781000E+00, -.11870700E+01, 0.28993300E+00, 0.68618800E+01, 0.37184700E+00, -.12990600E+01, -.42523700E+00, 0.56157000E+00, 0.33374300E+00, -.24312000E+00, -.48057100E+00, 0.31762600E+00, 0.27330700E+00, 0.36097000E+00, -.71265500E+00, 0.16392600E+01, -.41630100E+01, -.12164500E+00, -.44475300E+00, -.79441800E+00, -.17489200E+00, -.49163700E+00, 0.87651200E+00, 0.96055200E-01, 0.94504000E+00, 0.42131500E+00, 0.13585600E+01, 0.58415500E+00, 0.32424500E+00, -.34386100E+00, -.14779400E+01, 0.32421600E+00, -.43097500E+00, 0.60011800E+00, -.61334200E+00, 0.76061000E-01, 0.40470100E+00, 0.62146400E-01, 0.34733500E+00, -.21875300E+01, -.97188000E-02, 0.11029000E+01, -.37676900E+00, -.69341700E+00, -.59146200E+00, 0.52954100E+00, -.94474600E-01, -.35154900E-01, -.71010900E-01, -.15942500E+00, 0.39812600E+00, 0.15889000E+00, 0.17760200E+00, 0.26367600E+00, 0.32389800E+00, 0.48950100E+01, -.12226900E+01, -.56113400E+00, -.48049500E+00, -.25705900E-02, -.33843900E+00, 0.73285200E+00, 0.49979200E+00, 0.11398900E+00, -.89354100E-01, 0.13832200E+00, -.13026500E+00, 0.19680100E+01, -.20869500E+00, -.19106900E+00, -.23138700E+00, 0.72724900E-01, -.42801700E+00, 0.58240700E-01, 0.17909300E+00, -.83040500E-01, 0.72421900E-01, -.29350300E-01, -.52572000E+00, -.19565900E+00, -.14178600E+01, 0.17975700E+00, -.11192000E+00, 0.82768200E-01, 0.21964100E+00, -.15510700E+00, 0.99617000E-01, 0.13592800E+00, 0.33854900E+00, -.25168800E+00, -.14453400E-01, 0.46243400E+00, -.49126500E+00, -.49433900E+00, 0.46836400E-01, -.99007800E-01, -.74887100E+00, 0.13088100E+00, 0.15831200E-02, -.48057800E-02, 0.12419300E+00, 0.87999200E+00, -.72504200E+00, -.11928900E+00, -.36966900E+00, 0.32346500E+00, -.57340800E-01, 0.92372100E-01, 0.20238100E+00, -.17536000E+00, 0.80777700E-02, 0.15315600E+03, -.76026900E+02, -.50606500E+02, 0.31185700E+00, 0.19593700E+02, -.63660500E+02, -.37091200E+02, -.71397300E+02, 0.51121700E+01, -.19435200E+03, 0.97385400E+02, 0.78451000E+02, -.34494100E+01, 0.62636700E+01, 0.57264500E+02, -.19147100E+02, 0.41416600E+02, 0.27218200E+02, 0.41411400E+02, -.20995300E+02, -.30409700E+02, -.21509300E+02, -.35794900E+02, 0.71641300E+01, 0.30682300E+02, 0.14651500E+02, -.31376700E+02, -.91313800E+02, 0.45446600E+02, 0.27777900E+02, 0.21251100E+02, 0.25367600E+02, 0.11645100E+02, -.38887200E+02, -.47620400E+02, 0.31163100E+02, -.26963500E+02, 0.13746200E+02, 0.17519600E+02, -.16297700E+02, 0.18895300E+02, 0.12887400E+02, 0.87708700E+01, 0.44130200E+02, 0.52367600E+01, 0.84123800E+01, -.13732800E+02, 0.53121700E+01, 0.44415000E+01, 0.38266000E+01, 0.95014700E+01, -.24878700E+02, 0.20048000E+01, 0.64069000E+01, 0.86598900E+00, -.54039600E+01, -.93003300E+01, -.75669200E+00, -.67755700E+01, -.42202600E+01, 0.15484200E+01, 0.44117700E+01, -.14038700E+02, 0.57319800E+01, -.39765500E+01, 0.63168900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.18269400E+01, -.10429000E+01, 0.10854000E+00, -.28884500E+01, -.22562400E+00, 0.11418600E+02, -.83630000E+00, 0.79739900E+00, 0.56553700E+00, -.99434900E+00, -.14014100E+01, 0.17099000E+00, -.67832200E+00, -.60164700E+00, 0.14701000E+00, 0.56452200E+00, 0.69040600E-01, -.38942500E+00, 0.32935900E+00, -.17693100E+00, 0.62272700E-03, -.33960800E+00, -.37607600E+00, -.21771100E+01, 0.16048300E+00, -.57942900E+00, -.11803600E-01, 0.70707700E+01, 0.21186300E+00, -.84930400E+00, -.37798800E+00, 0.65597700E+00, 0.29323500E+00, -.30685300E+00, 0.37992400E+00, -.23618600E+00, -.20191600E+00, 0.77566600E+00, 0.13863200E+01, 0.31263200E+01, 0.90919400E+01, 0.35476300E-01, 0.59170700E+00, 0.14270600E+00, -.19254900E+00, -.42077300E+00, 0.16222100E+00, -.21395800E+00, 0.26736500E+00, 0.27113200E+00, 0.10889800E+01, 0.48895000E+00, 0.50566600E+00, -.70094800E+00, -.29618000E+01, 0.29805100E+00, 0.19053100E+00, -.42448100E+00, -.14640600E+00, 0.52893200E+00, -.97428500E+00, 0.40148700E+00, -.27268200E-02, -.12674700E+01, -.14253400E+00, -.23004900E+00, 0.25946700E-01, 0.14041100E+01, 0.66988500E-01, -.62279200E+00, -.25727200E+00, -.42969700E+00, 0.20421600E+00, -.17766000E+00, 0.83873000E-01, -.73903700E-01, 0.17591000E+00, 0.13924800E+00, 0.11183200E+00, -.26261900E+00, -.67476800E-01, 0.90927600E-01, 0.96034700E-01, 0.38271600E-01, 0.25056200E-01, 0.44615000E-01, 0.22271700E+00, 0.31585200E+00, 0.87570000E-01, 0.20178400E+00, -.51569000E-01, -.31439100E+00, 0.21892000E-01, 0.23919400E+01, 0.47913800E-02, -.12658200E+00, -.24478700E+00, -.41760800E+00, 0.65684200E-01, 0.36518200E+00, -.19563500E-01, 0.69829800E+00, 0.10274600E+00, 0.31321500E+00, -.77692000E+00, -.19970500E+00, -.17301400E+00, -.14207200E+00, -.13548700E-01, 0.12535100E+01, 0.35118300E+00, -.18182600E-01, -.16724500E+00, 0.29103400E+00, -.90838300E-01, -.19918100E-01, -.18065600E+00, -.16324400E+01, 0.33169100E+00, 0.20558300E+00, 0.42827300E+00, -.21641500E-01, 0.32208700E+00, 0.89957300E-01, 0.53172300E-01, 0.41794000E+00, -.74174800E+00, 0.14108300E+00, 0.34570300E+00, 0.41139300E+00, 0.13282600E+00, 0.87738600E-01, -.46158200E+00, 0.34483200E+00, 0.28570700E-01, 0.54549700E+00, 0.25943500E+01, -.11472500E+02, 0.55554600E+02, 0.49466900E+02, -.30309300E+02, -.18570700E+02, -.41799000E+02, 0.47310500E+02, -.17087000E+03, 0.86713500E+02, 0.84865900E+02, -.78722700E+01, -.36107000E+01, 0.56400600E+02, -.15106800E+02, 0.63562900E+02, 0.14399200E+02, -.61839300E+02, 0.30867400E+02, 0.27669100E+02, 0.12272400E+02, 0.18588100E+01, 0.16859200E+02, 0.15523800E+02, 0.14616400E+02, -.50100000E+01, 0.21248100E+03, -.10596900E+03, -.11561300E+03, -.67286000E+02, -.95948000E+02, -.12381100E+01, 0.46042100E+02, 0.51944000E+02, -.89631400E+02, 0.87952800E+01, -.50597700E+01, -.30859800E+01, 0.14993500E+02, 0.17900700E+02, -.17620900E+02, 0.37666800E+01, -.13530900E+02, -.91387800E+01, 0.22536400E+01, 0.13353000E+02, -.12403200E+01, -.24279700E+01, -.55919600E+01, 0.30990000E+01, 0.12671100E+02, -.27438200E+01, -.16795700E+02, 0.23690000E-01, 0.17296800E+01, -.18670700E+01, -.14782900E+00, 0.68534800E+01, 0.10279000E+02, -.34742200E+01, -.42504100E+01, 0.15760000E+02, -.12203800E+02, 0.66176800E+01, -.15679300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.48814700E+01, -.19713800E+01, -.29723100E+01, -.76296400E+01, 0.31606500E+01, 0.28057700E+02, -.86599900E+01, 0.11213900E+01, 0.14079700E+01, -.15679400E+01, 0.38705600E+01, 0.36436900E+01, -.13515600E+01, 0.43532800E+00, -.36450500E+00, -.22996700E+01, -.74830300E+00, -.76139300E+00, 0.15792500E+00, -.26394900E+00, 0.39204800E+00, -.21033500E+00, -.43992100E+00, -.10758600E+00, -.84400000E+00, -.13513000E+00, -.54346900E+00, -.16787800E+01, -.19772700E+00, -.11269900E+01, -.32377800E+00, 0.14193300E+01, 0.10084000E+01, -.20644500E+00, -.18997400E+01, 0.11590800E+01, 0.91393700E+00, -.69192100E+00, -.83160200E+00, -.70685400E+00, -.12322600E+01, -.42665300E-01, 0.14006700E+01, 0.12511900E+01, -.11156000E+01, 0.83228400E+00, -.67868000E-01, -.67248200E+00, -.91696800E+00, -.13977800E+01, -.15650000E+01, -.82604400E+00, -.44783700E+00, 0.16817300E+01, 0.23811600E+01, -.47314100E+00, 0.87863100E+00, -.15474700E+00, 0.31535300E+00, 0.29485600E+01, -.44600300E+00, 0.17006700E+01, -.10597700E+00, 0.16592900E+01, 0.83725200E-01, -.81005900E+00, -.13952000E+00, 0.30639600E+00, 0.46236000E+00, -.61685000E+00, -.32067500E+00, 0.97297600E+00, 0.17123300E+00, -.15816500E+01, -.30716500E+00, -.55419000E+00, 0.75985600E+00, 0.11572100E+01, -.12693500E+01, -.12476200E+01, 0.15214500E+00, 0.10330000E+01, -.20713800E+01, 0.90904100E+00, -.14560000E+01, 0.10376000E+01, -.12359100E+01, -.61989200E+00, 0.54445800E+00, -.56594900E+00, 0.81342700E+00, 0.36097600E+00, 0.10430700E+01, 0.74825100E+00, -.10187500E+00, -.12362000E+01, 0.71738700E+00, -.14954000E+01, -.22415800E+00, -.35168900E+00, -.12702600E+00, 0.27337800E+00, -.12583700E+01, -.67739300E+00, -.12261300E+01, 0.67766700E+00, 0.47948600E-02, 0.35205900E+00, 0.49618900E+00, 0.22060900E+01, 0.87509900E+00, -.18002300E+00, -.14250700E+00, -.42342900E+00, 0.38109900E+00, 0.75903800E+00, -.64447800E+00, -.53576400E+00, -.22979400E+00, -.21883600E+00, -.74942300E+00, -.53300100E+00, -.67135500E+00, 0.12327100E-01, 0.14550100E+00, 0.17361100E+00, -.12629800E-01, -.34786800E+00, 0.50538900E-01, -.93907400E-01, 0.27411600E+00, 0.48485800E-01, 0.87999700E+00, -.56856400E+00, -.18228300E+00, 0.11012600E+01, -.18113600E+01, -.60806800E+02, 0.23914400E+02, 0.78642500E+01, -.11127200E+02, 0.45998200E+01, 0.23442700E+02, 0.47770600E+02, 0.56783300E+02, -.27437500E+02, 0.23012600E+01, 0.93859300E+00, 0.19371800E+02, -.23350600E+01, 0.87945700E+01, -.37117900E+01, -.19548200E+01, -.23280200E+03, 0.11700500E+03, 0.13060300E+03, 0.41729000E+02, 0.24578500E+02, 0.49850900E+02, 0.26475500E+02, 0.71512600E+02, 0.17497100E+02, 0.90228100E+02, -.44795100E+02, -.20517600E+02, -.48761600E+02, -.35084600E+02, 0.58917200E+01, 0.45857900E+02, 0.24912200E+02, -.41361500E+02, 0.21396700E+03, -.10727500E+03, -.11334200E+03, 0.23401300E+02, 0.20434600E+01, -.10404500E+03, -.50772100E+02, -.11650200E+03, -.17245900E+02, -.21097000E+02, 0.61790500E+02, -.17586500E+02, -.11703900E+02, -.11836400E+02, -.22182900E+02, 0.77668800E+02, -.73854200E+01, -.40252100E+02, 0.36680100E+01, 0.13764900E+02, 0.20316600E+02, -.34342700E+01, 0.28783000E+01, 0.16370600E+02, -.39750400E+01, -.71002200E+01, 0.64753200E+02, -.25184200E+02, 0.17303000E+02, -.31443500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12961700E+02, -.55903100E+01, -.82384600E+01, -.14322700E+02, 0.67954800E+01, 0.64473900E+02, 0.45500000E+01, 0.10533400E+02, 0.38757300E+01, -.15437100E+01, -.49148600E+01, 0.58280800E+01, -.55634300E+01, -.15921100E+01, 0.88275500E+00, -.55137500E+01, -.10762100E+01, -.15568700E+01, -.76610600E+00, 0.92548400E+00, 0.15028800E+01, -.98646300E+00, -.15779600E+01, -.32543800E+01, -.70335400E+00, -.12174200E+00, -.59411300E+00, 0.13158500E+02, -.22908100E+00, 0.25654300E+01, 0.18241300E+00, 0.54282300E+00, 0.19763300E+01, 0.38315600E+00, -.20272200E+01, 0.42151100E+01, 0.21010300E+01, -.16680000E+01, 0.35685700E+01, 0.47681300E+01, 0.76125200E+01, -.75556700E+00, 0.53965500E+00, 0.53840400E+01, -.19562500E+00, 0.70121900E-01, -.12574900E+01, -.88428500E+00, -.15117400E+01, -.33552100E+01, -.37958700E+01, -.17516900E+01, -.73468100E-01, -.14741800E+01, 0.12002800E+01, -.12361400E+01, 0.25445800E+01, 0.45897300E+00, -.24110300E-01, 0.30594300E+01, 0.17814500E+01, 0.13835400E+01, -.25415000E+00, 0.88727300E+00, -.73168300E+00, -.17842600E+01, 0.69448000E-01, 0.19171800E+01, 0.10946300E+00, -.66924700E+00, -.57051600E+00, 0.79453300E+00, 0.67766200E+00, -.18046400E+01, -.63207400E+00, -.24540100E+00, 0.26010000E+00, -.30391500E+01, -.59438300E+00, 0.17463000E+01, -.15700800E+01, 0.69084700E+00, -.24720000E+01, 0.20362100E+01, -.53373700E+00, 0.10394200E+01, -.10732300E+01, 0.63771400E+00, 0.88822000E+00, 0.31332100E+00, 0.25657700E-02, -.19640300E+01, 0.40846000E+00, 0.14880200E+01, -.41263600E+00, -.19175000E+01, 0.16068300E+01, -.33454500E+01, -.68867800E-02, -.68177900E+00, 0.16770900E+00, 0.19742400E+01, -.35053200E+01, -.41311100E+01, 0.34941100E+01, -.30511500E+00, -.65162200E+00, -.48009500E+00, 0.13759800E+01, 0.44121200E-01, 0.10606000E+01, -.27641400E+00, 0.49381000E+00, -.33140800E+00, 0.54180200E+00, -.59313100E+00, 0.13240800E+01, 0.37986900E+01, -.63725100E+00, -.75484000E+00, -.29332300E+01, -.44191100E+00, 0.12537100E+01, 0.21327800E+00, -.37279200E+00, 0.11529300E+01, -.20371100E+00, -.16518700E+01, -.29479200E+00, -.88536800E+00, 0.31132200E+00, -.23459200E+01, 0.27392800E+01, -.10833700E+01, -.11255000E+00, 0.17071800E+00, 0.11749700E+01, -.41712600E+00, -.14480500E+03, -.13084000E+03, 0.66041000E+02, 0.18158600E+00, 0.68195400E+02, -.74498000E+02, 0.12567000E+04, -.63011800E+03, -.61865900E+03, 0.62938100E+02, 0.64745600E+02, -.37513000E+03, 0.96399500E+02, -.32908500E+03, -.10820700E+03, 0.46264300E+02, -.20559100E+02, -.15026600E+02, 0.88336400E+02, 0.13722500E+03, -.81076900E+02, -.16069900E+03, -.10523900E+03, 0.11899000E+03, 0.13841200E+03, -.68872100E+02, -.50746800E+02, 0.19795200E+02, 0.54075100E+02, -.77659100E+02, 0.15038500E+03, 0.11788200E+03, 0.23148200E+01, 0.34685700E+03, -.17232800E+03, -.17879200E+03, -.35414200E+02, -.13952400E+03, -.74894600E+02, -.15025500E+03, -.28050200E+03, -.29763700E+01, -.30905100E+02, 0.45936200E+02, -.89578400E+01, -.13903100E+02, 0.81278200E-01, -.53633700E+02, 0.16633800E+02, -.13722700E+01, 0.69481100E+02, -.21952300E+02, 0.24425200E+02, 0.44531300E+02, 0.21449200E+02, -.21851300E+02, -.78577500E+02, 0.12277400E+02, 0.15717800E+02, 0.71121500E+02, 0.64653200E+02, 0.14102900E+02, 0.57519400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.84721100E+00, 0.77163800E+00, -.18921300E+00, 0.12999600E+01, 0.29881100E+00, -.37471000E+01, 0.66085600E+00, -.13492300E+01, -.15357700E+00, 0.48279100E+00, 0.19575900E+01, 0.54850400E-01, 0.19602600E+00, 0.89194300E+00, -.38391700E+00, -.17271700E-01, -.13548100E+00, 0.36981600E+00, -.36577300E+00, -.18960700E+00, -.50818400E+00, 0.68812900E+00, 0.53443600E+00, 0.27946200E+00, -.15522500E-01, 0.12679300E+00, -.70737600E-01, 0.12815700E+01, -.16216600E+00, -.40033600E+00, 0.25520600E+00, -.25606500E+00, -.63404800E+00, -.80021300E-02, -.15392500E+00, -.42149100E+00, -.27912400E+00, 0.12069600E+00, -.69724400E-01, -.11539400E+01, 0.18806800E+00, 0.20170800E+00, 0.47847400E+00, -.76813900E+00, 0.17644800E+00, -.24073900E-01, -.12149600E+00, 0.37253300E+00, 0.49394000E+00, 0.33163900E+00, 0.13518700E+01, 0.56831000E-01, 0.61181300E+00, 0.27044700E+00, 0.62511700E-01, 0.10178800E+00, -.22342400E+00, 0.13374700E+00, -.85962900E-01, -.22285000E+00, -.16702600E+00, -.70076500E-01, 0.40298700E-02, -.47563300E-01, -.23106700E+00, -.15571300E+00, 0.57345500E-01, 0.97261600E-01, 0.55566000E-01, -.99497500E-01, -.16302900E+00, -.11265800E+00, 0.79209200E-01, -.68338300E-01, -.23069300E+00, -.42347600E-01, -.18197000E-01, -.78567500E-02, -.24957100E+00, 0.15820800E+01, 0.69151600E-01, -.37999400E+00, -.27910400E-01, -.55888700E-01, -.79954200E-01, -.20350700E-01, 0.15691400E+00, -.72912700E-01, 0.57414000E-01, 0.57874600E-01, 0.18509000E+00, -.10292200E+01, 0.74548400E-01, 0.81415600E+00, -.22678800E+00, -.18676800E-01, -.16806400E+00, 0.22538200E+00, 0.62852400E-01, -.53703800E-01, 0.10359800E+00, 0.46788400E+00, -.46918900E+00, -.44143200E+00, -.21838800E+01, 0.43748800E+00, -.84141800E-01, -.11286100E-01, 0.42080600E-01, 0.26015900E-01, 0.41432400E+00, -.29845900E+00, 0.72454700E-01, 0.23462700E-01, 0.10601300E+00, -.36908100E-01, 0.11294600E+00, 0.96030300E+00, -.47242300E-01, -.84650800E-01, -.41459700E+00, 0.19409500E+00, 0.42084600E+00, 0.26332400E-02, -.55206300E-01, 0.15806900E-01, -.93805100E-01, 0.17339500E+00, -.51561500E-01, -.23149500E+00, -.36080300E-01, -.35247100E+00, -.86183900E-01, -.47377400E-01, 0.16532600E+00, -.13480800E+00, -.29680300E+00, 0.18777600E-01, 0.24847900E-01, 0.32618700E+02, -.10975100E+02, -.15533600E+02, -.35209800E+02, 0.72973200E+01, 0.51516700E+02, -.24589100E+02, -.29305200E+02, 0.50330600E+01, 0.65265000E+01, -.18199500E+02, -.38209200E+01, -.10608700E+01, -.27371100E+01, 0.36943800E+02, -.18490800E+02, -.22387300E+02, 0.64411400E+01, 0.67222000E+01, -.13367100E+02, -.10684600E+02, -.19406100E+02, 0.95556100E+01, 0.16072100E+03, -.80278200E+02, -.91150700E+02, -.31474200E+02, -.55700800E+02, -.14796200E+02, 0.45655300E+02, 0.57555500E+02, -.59024300E+02, -.16806800E+02, 0.82542600E+01, 0.10016700E+02, -.66720400E+01, 0.31786300E+01, 0.46998200E+01, -.22283800E+02, -.45063100E+02, 0.81240200E+01, 0.80667800E+01, 0.77678200E+00, 0.25837300E+01, 0.25812200E+01, 0.39131800E+00, -.11238200E+01, 0.35803800E+02, -.19463400E+01, 0.11615400E+02, -.13795300E+02, -.16090300E+01, 0.20674400E+01, 0.13507300E+02, -.16004000E+02, -.13290300E+02, -.19133800E+01, 0.98254300E+01, 0.55990700E+01, 0.10871000E+02, 0.75341400E+01, 0.15418700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.25333700E+01, -.25262400E+00, 0.14310000E+01, 0.34745700E+01, -.16174600E+01, -.22813300E+02, -.14410800E+02, -.25941500E+01, -.13823200E+01, 0.23532000E+00, -.92030400E+00, -.60087700E+00, 0.65146700E+00, -.11858500E-01, 0.13955500E+00, 0.14980000E+00, 0.23089000E+00, 0.15749500E+00, 0.27167000E+00, 0.19408800E+00, -.15801300E+00, -.74292300E-01, 0.38021900E+00, 0.59658600E+00, 0.21960300E+00, 0.14534600E+00, 0.82018400E+00, -.11539600E+01, -.76518000E-01, 0.42223800E+00, 0.43177600E+00, -.70172900E+00, -.41161100E+00, 0.14072900E+00, 0.27736500E+00, -.23764500E+00, -.86700100E-01, 0.70444100E-01, -.27893000E+00, -.13552500E+01, -.35285100E+01, 0.83454500E-01, -.11094300E+01, -.64808500E+00, 0.17125400E+00, 0.19293600E+00, 0.51661900E+00, -.27797100E+00, -.66366700E+00, 0.50016000E+00, -.40852300E+00, 0.24089200E+00, -.32585200E+00, 0.12430300E+01, 0.58208600E+00, 0.25598100E-01, -.40171600E+00, -.43036200E+00, 0.19277500E+00, -.10243500E+01, 0.74372000E-01, -.29597400E+00, 0.71156900E-01, -.56930300E-01, 0.13964200E+00, 0.45011200E+00, -.13733600E+00, -.25679100E+00, 0.33845600E+00, -.29597900E-01, 0.47039600E+00, 0.25828500E+00, 0.17457900E+00, -.38161500E+00, -.30315900E+00, -.19287600E+00, 0.98717100E-01, 0.47381600E+00, -.24590500E+00, -.13897000E+01, 0.10082000E+01, 0.38811300E+00, -.46063200E+00, 0.22058700E+00, -.47264300E+00, -.34515100E+00, 0.37806300E+00, -.27916400E+00, 0.23633300E+00, 0.99877700E-01, -.18019800E-01, -.69674000E+00, -.53324100E-01, 0.96956800E-02, -.22961400E+00, 0.25667600E+00, -.60682800E+00, 0.47239000E+00, -.96792300E-01, -.28407000E+00, 0.71826100E-02, 0.11464300E+00, -.40607700E+00, -.98619400E+00, -.72248500E+00, 0.74295600E+00, 0.55510800E-01, -.71593900E-01, 0.53475900E+00, 0.87109800E+00, 0.25571400E+00, -.34498700E-01, 0.35953100E+00, -.27077300E+00, -.85877000E-02, 0.43215400E+00, -.29135000E+00, 0.13140200E+01, 0.25821700E+00, -.80691000E+00, -.12894400E+01, 0.39464900E+00, -.20490300E-01, -.49202900E-01, -.29362100E+00, -.46195600E+00, -.20699900E+00, 0.67637200E+00, 0.47117600E+00, 0.34273000E+00, -.10687800E+00, -.43570900E+00, -.17100400E-01, 0.30317600E+00, -.14310600E+00, -.33676300E+00, -.75672400E-01, -.91209600E-01, -.10289100E+00, -.24293100E+00, -.16660600E+02, -.18712000E+02, -.37123200E+02, 0.23105600E+02, 0.10666200E+03, -.50753700E+02, -.54776800E+02, 0.10366300E+02, -.33480400E+01, -.18100400E+02, 0.24783000E+02, 0.15458800E+02, -.21904700E+02, -.46375700E+02, 0.23835500E+02, 0.20161900E+02, 0.36037500E+02, 0.45189600E+02, -.68016700E+01, -.35563400E+02, -.34611000E+02, 0.35519400E+02, 0.28560600E+03, -.14213400E+03, -.15070400E+03, -.90983700E+02, -.11514400E+03, -.89780200E+01, 0.98586400E+02, 0.11358100E+03, -.11493500E+03, 0.15329800E+03, -.77726800E+02, -.75694600E+02, 0.30661900E+02, -.39861000E+02, -.41636300E+02, 0.21437400E+02, -.38962900E+02, -.42777800E+02, -.87710100E+01, 0.14729300E+02, -.34122400E+01, -.10352000E+02, -.82346400E+01, -.14314400E+02, 0.12553200E+02, -.14291600E+01, 0.20850900E+01, 0.46829600E+01, 0.10591700E+02, 0.12856900E+02, -.53105800E+01, -.49325300E+01, -.97058700E+01, 0.21203300E+00, 0.58167200E+01, 0.31200000E+02, 0.41554900E+01, 0.19067300E+02, -.21075700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14030700E+02, -.57919000E+01, -.84783400E+01, -.15439200E+02, 0.78181000E+01, 0.74108100E+02, 0.43615200E+01, 0.12616900E+02, 0.43921300E+01, -.16550700E+01, -.83559100E+01, 0.72440100E+01, -.63586600E+01, -.14649600E+01, 0.23147000E+00, -.66996300E+01, -.13460300E+01, -.40646000E+00, 0.62090200E+00, 0.10637300E+01, 0.18501000E+01, -.14675000E+01, -.19364800E+01, -.51268500E+01, 0.45574300E+00, -.18048300E+01, -.39418700E+00, 0.12561100E+02, -.43423900E+00, 0.55200200E+01, -.25121500E+00, -.30533100E+00, 0.27252300E+01, 0.36948800E+00, -.11493600E+01, 0.47477200E+01, 0.22217800E+01, -.16587400E+01, 0.39585000E+01, 0.73002800E+01, 0.15479000E+02, -.83318300E+00, 0.18286300E+01, 0.54719100E+01, -.19570700E+01, -.58036200E+00, -.12334600E+01, -.18652000E+01, -.29166200E+01, -.34463900E+01, -.49565200E+01, -.14149200E+01, -.38622300E+00, -.82151200E+00, 0.68070500E+00, -.13756700E+01, 0.25783200E+01, 0.79232100E+00, -.19253200E+00, 0.37230500E+01, 0.21763300E+01, 0.19022500E+01, -.19205400E+00, -.12627500E+01, -.74636300E+00, -.95847800E+00, -.38699300E+00, 0.25163000E+01, -.20002600E+00, -.60765900E+00, -.90236700E-01, 0.11052600E+01, 0.11288000E+01, -.25357600E+01, -.20305400E-01, -.17063800E+00, 0.47406400E+00, -.43820200E+01, -.25513600E-01, -.47463800E+00, -.24325900E+01, 0.78767300E+00, -.27660700E+01, 0.18807400E+01, -.10931400E+00, 0.11591700E+01, -.40872900E+00, -.13010900E+00, 0.16402700E+01, 0.93524000E+00, -.50679200E+00, -.29360300E+01, 0.22486300E+00, -.44847500E+01, 0.13653200E+01, -.12304400E+01, 0.20732900E+01, -.18039800E+01, -.58405600E+00, -.14060900E+01, -.13491800E+00, 0.12494400E+01, -.86119000E+00, -.49086800E+01, 0.12545200E+02, -.16995800E+01, -.51012000E+00, -.99012300E+00, 0.14429600E+01, -.37098300E+01, 0.15284900E-02, 0.62612500E+00, 0.69577400E+00, -.41081100E+00, 0.98718700E+00, -.10390600E+01, 0.30613900E+01, 0.76105500E+01, -.87654100E+00, -.65253800E-01, -.33890700E+01, -.25658000E+00, 0.19966300E+01, 0.24416800E+00, -.50679600E+00, 0.17308400E+01, -.50652200E+00, -.52273600E+00, -.15713000E+00, -.22650100E+01, 0.85761400E+00, -.26605500E+01, 0.16544600E+01, -.12937400E+01, 0.40614800E+00, -.98764300E+00, -.25546400E+01, 0.86271300E+00, -.88874700E+00, 0.25904300E+00, 0.81816000E+00, -.11297400E+03, -.13044600E+03, -.11007100E+02, 0.13623800E+04, -.67985900E+03, -.69724100E+03, 0.67971400E+02, 0.44620700E+02, -.41138900E+03, 0.93079100E+02, -.33655900E+03, -.12647000E+03, 0.28432400E+03, -.14225500E+03, -.15679300E+03, 0.13186500E+03, 0.16811400E+03, -.16544200E+03, -.23355300E+03, -.21226500E+03, 0.12535300E+03, 0.53114500E+03, -.26570900E+03, -.31362900E+03, -.53274400E+02, -.10141700E+03, -.10273000E+03, 0.22295800E+03, 0.19005000E+03, -.15471900E+03, 0.34930400E+03, -.17437300E+03, -.17179700E+03, -.41570700E+02, -.13431100E+03, -.46718600E+02, -.11441600E+03, -.36704000E+03, 0.50292700E+01, 0.55813200E+01, 0.40936000E+02, -.89012000E+01, -.27151900E+01, -.10278600E+02, -.38407300E+02, -.63485300E+00, -.33204700E+01, 0.92071700E+02, -.66966000E+02, 0.15697900E+02, 0.30965600E+02, 0.66002200E+02, 0.16940600E+02, -.11192800E+03, 0.12124800E+02, -.18709300E+01, 0.74293700E+02, 0.85837600E+02, 0.10570700E+02, 0.74568400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.99541200E+01, -.97201900E+00, -.53953700E+01, -.11117800E+02, 0.54086700E+01, 0.45310000E+02, 0.10257800E+02, 0.12499100E+02, 0.27039200E+01, -.26089900E+00, -.62843500E+01, 0.31033000E+01, -.36640300E+01, -.26831000E+01, 0.23801600E+01, -.45161100E+01, -.78945200E+00, -.10448800E+01, -.52644400E+00, 0.27264500E+00, 0.35944900E+00, -.57218700E+00, -.18581700E+00, -.23714500E+01, -.95099300E+00, -.46690300E+00, -.13674400E+01, 0.12380900E+02, -.21069900E+00, 0.52502100E+01, -.31885500E+00, -.27377300E+01, 0.38269900E+00, 0.85718700E+00, -.12763400E+01, 0.47171400E+01, 0.21173900E+01, 0.56040900E+00, 0.16683400E+01, 0.26218700E+01, -.13297200E+02, -.11168900E+01, 0.23828900E+01, 0.55068900E+01, 0.17748900E+00, -.16273000E+01, -.15833400E+01, -.46032000E+00, -.16672000E+01, -.37616600E+01, -.55041200E+01, -.12872900E+01, -.54495900E+00, -.50745800E+01, 0.16137600E+01, -.11445200E+01, 0.27126500E+01, 0.11013600E+01, -.12139200E+00, 0.35399700E+01, 0.67180500E+00, 0.96160300E+00, -.17280100E+00, 0.19341700E+01, -.88740400E+00, -.19125700E+01, 0.16745300E-01, -.26960900E+01, -.77572600E-01, 0.53707800E+00, 0.15398900E+00, 0.53768500E+00, -.58473200E-01, 0.47283800E+00, 0.39017800E+00, 0.20146700E+00, 0.70343700E+00, -.50160700E+00, -.48445200E+00, -.48194600E-01, -.14451400E+01, 0.13768800E+01, -.31280900E+01, 0.13912600E+00, 0.36539200E+00, -.40214100E+00, -.62386900E+00, -.76650400E+00, 0.39491000E+00, -.22181600E+00, -.62651000E+00, -.51740100E+01, -.73242000E+00, -.44473900E+01, 0.90816900E+00, -.52353200E+00, 0.14521300E+01, -.28262200E+00, -.70204900E+00, -.66637200E+00, -.21775200E+00, -.10905800E+01, 0.39694400E+00, -.49639000E+00, 0.44164900E+01, 0.43131900E+00, 0.50320200E+00, -.22108200E+00, -.95975900E-03, 0.44713700E+01, -.34838900E+00, -.21165500E+00, -.12862100E+01, -.18466800E+00, 0.50349800E-01, 0.12995600E+01, -.12196000E+01, -.19235200E+01, 0.56262100E+00, 0.94405000E+00, 0.58792200E-01, -.15547400E+01, -.17413400E+01, 0.14479400E+00, -.66787100E+00, 0.18511300E+01, -.74517500E+00, 0.31085100E+00, 0.19298300E+00, 0.14943400E+01, 0.54629700E+00, 0.17186700E+01, 0.12755700E+01, -.22620100E+00, 0.54095000E+00, -.38366400E+00, 0.15704400E+01, 0.35737000E+00, 0.45211600E+00, 0.20845700E+00, -.10597600E+01, -.50665900E+00, -.70288700E+02, 0.79054000E+01, -.19800600E+03, 0.99041300E+02, 0.10202100E+03, 0.84345400E+01, -.44868200E+02, 0.62016700E+02, 0.30919100E+02, 0.91713700E+02, -.29958100E+00, 0.19464900E+03, -.99279300E+02, -.97292700E+02, -.12139200E+02, 0.54227000E+01, -.55171200E+02, -.30332500E+02, -.84293100E+02, 0.49207000E+01, -.17959100E+03, 0.89248100E+02, 0.79553000E+02, 0.54609700E+02, 0.67433200E+02, -.40734900E+00, -.97745800E+02, -.51652200E+02, 0.73732600E+02, -.39266200E+03, 0.19534700E+03, 0.19604000E+03, 0.82220000E+02, 0.14270100E+02, 0.17324200E+03, 0.15989800E+03, 0.27612700E+03, 0.30558800E+02, 0.16529100E+02, -.61939200E+02, -.12010300E+02, 0.22550900E+01, -.70080600E+01, 0.46077800E+01, -.19374100E+02, 0.57671600E+01, 0.57526800E+01, -.12037400E+02, -.27204700E+01, -.67793200E+01, 0.12073600E+02, 0.18512400E+01, 0.22514200E+01, 0.59499500E+01, 0.30840700E+01, -.58927200E+02, -.53110800E+01, -.56257200E+02, -.28127800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.14252200E+01, 0.14577700E+01, 0.85991400E+00, 0.24618400E+01, -.92333400E+00, -.11344900E+02, 0.23057500E+01, -.83090500E+00, -.60292000E+00, 0.59982300E+00, -.73046900E+00, -.76780800E+00, 0.54116100E+00, -.20414200E+00, 0.48116800E-01, 0.52715900E+00, 0.14303200E+00, 0.14904100E+00, 0.64013000E+00, -.57481600E-01, -.35678900E-01, -.57375300E+00, 0.23968900E+00, 0.47161500E+00, 0.53085300E+00, -.19149200E+00, 0.42567600E+00, -.22921600E+01, 0.56079900E-01, -.24738600E+00, 0.11892200E+00, -.62786300E+00, 0.67164300E-01, 0.17997200E+00, 0.14036300E+01, -.31070700E+00, -.10746300E+00, -.79793900E-01, 0.78570000E+00, 0.11987500E+01, 0.64183700E+01, 0.53701900E-01, -.11349000E+01, -.25105500E+00, 0.19626300E+00, 0.25207800E+00, 0.29195100E+00, -.42930000E+00, -.85489600E+00, 0.58740900E+00, -.18866600E+00, 0.17752200E+00, -.10017000E+00, 0.54696800E+00, 0.27615100E+00, -.73795100E-01, -.27241200E+00, -.77873000E-01, 0.11139500E-01, -.84808800E+00, -.37397200E-01, -.19244800E+00, -.19820100E+00, -.89840700E+00, -.27993300E+00, 0.14929700E+00, -.38291700E-01, 0.50318800E+00, 0.46325100E-01, -.38507200E+00, -.18324400E+00, -.34774300E+00, 0.31194200E+00, 0.51264400E+00, 0.24577300E-01, 0.19136900E-02, -.12151400E+00, 0.46345700E+00, 0.20421600E+00, -.17532200E+01, 0.10965900E+01, -.19692500E+00, 0.61324300E+00, 0.38644600E+00, 0.37547100E+00, -.52899600E+00, 0.54612400E+00, 0.25943200E+00, -.40440200E-01, 0.39821100E+00, 0.50679600E-01, 0.28411800E+01, -.24066300E+00, -.67387300E+00, -.79461700E+00, 0.38598100E+00, -.34882200E+00, -.17073300E+00, -.87219100E-02, -.26792000E-01, -.40291300E-02, -.74146200E+00, -.14156900E+00, -.63438200E+00, 0.30408600E+01, -.46052100E+00, 0.11768300E+00, -.18859100E+00, -.49919800E-01, -.11885200E+01, 0.10538400E+00, -.22759800E-02, 0.37507100E+00, -.91410600E-02, -.61486400E-02, -.64103600E+00, 0.99495900E+00, 0.18797200E+01, -.68875400E-01, -.36406400E+00, -.82387300E-01, 0.15074000E+00, 0.72807700E-01, 0.66128200E-02, 0.98912400E-02, 0.25521700E-01, 0.83583500E-01, -.16602500E+00, -.23320100E+00, -.37686900E+00, -.15327000E-02, -.18559700E+00, 0.40921500E+00, 0.26908500E-02, 0.11674200E-01, -.73151400E+00, 0.80068300E-01, -.36237600E+00, -.61851600E-01, -.49424800E-02, -.33195500E+00, -.40909400E-01, 0.76872400E-01, 0.20413500E+02, 0.52960100E+02, -.24785400E+02, -.31969800E+02, 0.99339300E+01, 0.17298300E+02, -.10654600E+02, 0.40323100E+01, 0.62177700E+01, -.34247100E+00, -.14406100E+02, 0.79163300E+01, 0.32949600E+01, 0.28631000E+02, 0.57501600E+02, -.25063100E+02, -.58602300E+02, -.40960300E+02, 0.45357500E+02, 0.18957700E+03, -.94449200E+02, -.10323900E+03, -.39351700E+02, -.57075100E+02, -.20181200E+02, 0.72569900E+02, 0.73505800E+02, -.63428300E+02, 0.39780200E+02, -.20692100E+02, -.18637800E+02, -.67093700E+01, -.34120400E+01, -.24934100E+02, -.58687400E+02, -.78582800E+02, 0.18955700E+01, -.74471900E+01, 0.26180300E+02, -.62142300E+01, -.51255400E+01, -.41061600E+01, -.70800500E+01, 0.13008000E+01, 0.10987100E+01, 0.18480200E+02, -.12078700E+02, 0.68795300E+01, 0.49611400E+01, 0.11949300E+02, 0.29216600E+00, -.16384100E+02, 0.43618000E+01, -.94376600E+00, 0.36702500E+02, 0.16885300E+02, 0.10255700E+02, 0.21787000E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.33320200E+01, -.33940300E+00, 0.19209700E+01, 0.48342500E+01, -.21052800E+01, -.24916500E+02, -.92796900E+01, -.35433400E+01, -.14560200E+01, 0.63627800E+00, -.75589300E+00, -.25289100E+01, 0.15243400E+01, 0.43699000E+00, -.15980300E+00, 0.85993500E+00, 0.46958700E+00, 0.10528300E+01, -.20541500E+00, 0.10585100E+01, 0.80464500E-02, 0.75822400E+00, 0.42035800E+00, 0.28519400E+01, 0.44737300E+00, 0.62227200E+00, 0.94571700E-01, -.19342000E+02, 0.42392800E+00, 0.37982800E+00, 0.98555300E+00, -.12290600E+01, -.12655100E+00, 0.59406800E+00, 0.60978300E+00, 0.14547400E+00, -.28784200E+00, -.10886800E+01, -.16690000E+01, -.21753800E+01, -.73530800E+01, -.26114600E+00, -.75385100E-01, -.13713200E+01, -.34322300E+00, 0.87565600E+00, 0.12890100E+00, -.83524000E+00, -.17434100E+01, 0.49634000E+00, -.10269900E+01, 0.10960800E-01, -.95752600E+00, 0.15951800E+01, 0.32659800E+01, -.15115000E+00, -.86447100E+00, 0.66921000E-01, 0.18527800E+00, -.36412700E+00, 0.42848400E+00, -.65969200E+00, -.84033100E-01, 0.46573200E-01, 0.23256600E+00, 0.60210600E+00, 0.12946800E+00, -.17132200E+01, 0.16581600E+00, -.21081000E+00, -.80983500E+00, -.28012700E+00, -.80840600E-01, 0.10055000E+01, -.31971500E+00, 0.41556300E-01, -.87957300E-01, -.29478200E+00, -.88397400E+00, 0.90714300E+00, 0.66300600E-01, -.13246400E+01, -.74696900E+00, 0.50211600E+00, 0.11899100E+00, -.33870200E+00, 0.12621400E+00, -.92550300E+00, 0.20835900E+00, -.31231000E+00, 0.13741200E+00, 0.59073000E+00, -.12927500E-01, 0.12322300E+00, -.36426000E-01, -.83809800E+00, 0.40534800E-01, 0.68919300E+00, -.19884000E+00, -.40639700E+00, -.19053100E-01, -.53024900E+00, 0.90171600E-01, -.11762100E+01, 0.27884500E+01, -.84080400E-01, 0.18207900E+00, -.23510000E+00, 0.16588000E+00, 0.29059900E+00, -.83496700E-01, 0.14851700E+00, 0.69455000E-01, -.31741700E+00, 0.47013100E+00, 0.76378600E-01, 0.69342900E+00, 0.54642900E+00, -.25477500E+00, 0.35839700E+00, -.58370600E+00, -.78697500E+00, 0.12202600E+00, -.87589300E-01, -.41811500E-01, 0.96437300E+00, -.47122400E+00, -.28427200E+00, -.60565900E+00, 0.12897700E+00, 0.42118000E+00, 0.13242000E+00, 0.66691900E+00, -.76664100E+00, 0.41724000E+00, 0.59166000E+00, 0.48156100E+00, 0.11188500E+00, 0.12445100E+00, 0.16031300E+00, 0.36525500E-01, 0.50204400E-01, 0.18109700E+00, -.51116900E+00, -.22981500E+03, 0.11148500E+03, 0.11373400E+03, -.73694900E+01, -.47278400E+01, 0.61322500E+02, -.20135300E+02, 0.16489400E+02, 0.32667000E+02, -.39206300E+02, 0.19425400E+02, 0.19718900E+02, -.16182500E+02, -.17883300E+02, 0.14929100E+02, 0.16632000E+02, 0.38180100E+02, -.20234400E+02, -.18851600E+03, 0.93827500E+02, 0.96385500E+02, 0.44854100E+02, 0.64358000E+02, 0.25331000E+02, -.65011300E+02, -.10220100E+03, 0.68784300E+02, -.14714300E+03, 0.74234900E+02, 0.73217200E+02, 0.13152300E+02, 0.55743500E+02, 0.34953700E+02, 0.29177300E+02, 0.71532400E+02, 0.47402800E+02, 0.17202500E+01, 0.12345400E+02, -.10794600E+02, 0.31860100E+00, -.10502600E+02, 0.70106700E+01, 0.33457700E+00, 0.81556100E+00, -.17459100E+02, 0.68682100E+01, -.15628600E+01, -.62278800E+01, -.67105000E+01, 0.15497200E+01, 0.18882100E+02, -.69496200E+00, -.17455800E+01, -.34993000E+01, -.15006400E+02, -.18609000E+02, -.25826400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.68907100E+01, -.12511900E+01, -.41879000E+01, -.71137600E+01, 0.29112700E+01, 0.35529600E+02, 0.10508400E+02, 0.46340200E+01, 0.21479300E+01, -.64095000E+00, -.11594200E+00, 0.31611300E+01, -.21725300E+01, -.94326100E+00, 0.30307900E+00, -.24851500E+01, -.50158200E+00, -.37479300E+00, -.95006100E+00, 0.17382800E+00, 0.37827400E+00, 0.27462000E+00, -.51775400E+00, -.52727400E+01, 0.13671500E+01, -.15227900E+01, -.40825800E-02, 0.14666200E+02, 0.25776900E+00, 0.14647000E+01, -.11054200E+00, 0.74633400E+00, -.18099700E+00, -.24877700E+00, -.16015700E+00, 0.58785000E+00, -.28903900E+00, 0.66205400E+00, 0.23367300E+01, 0.49971800E+01, 0.10556500E+02, -.10601100E+00, -.80302800E+00, 0.20527300E+01, 0.51962000E+00, -.10216800E+01, -.91796400E-01, 0.75014800E+00, 0.12363100E+01, -.65276400E+00, 0.58677300E+00, -.70024600E-02, 0.10594900E+01, -.18002800E+01, -.39252800E+01, 0.21798200E+00, 0.48449200E+00, 0.11898800E+00, -.44722500E+00, -.13655500E+01, -.41814700E+00, 0.81759600E+00, 0.13977700E+00, -.46220300E+01, -.59519400E+00, 0.77467600E-02, -.23500000E+00, -.40805900E+00, -.11825800E+01, 0.70426500E+00, 0.63222200E+00, 0.42036400E+00, -.30924800E+00, -.17057300E+01, 0.28803400E+00, 0.43386600E+00, -.59873400E+00, 0.66963200E+00, 0.16338800E+01, 0.54582500E+01, -.11348100E+01, -.75753200E+00, -.62596200E+00, 0.14171400E+00, -.23820500E+00, 0.86361500E+00, 0.80800300E+00, 0.32986600E+00, 0.21284200E-01, 0.54558200E+00, -.12013900E-01, 0.22603100E+01, 0.74801100E-01, 0.25909300E+01, -.91649000E+00, 0.26031500E+00, -.44330200E+00, -.63270700E-01, 0.49830000E-01, -.13835000E+00, 0.23199200E-02, 0.69497400E+00, -.23248400E+00, -.11868100E+01, 0.54096800E+00, -.52963000E+00, -.27514200E+00, -.15236000E+00, 0.33290100E+00, -.13273900E+01, 0.25148300E+00, 0.63294800E-01, 0.49225600E+00, 0.12424400E+00, 0.26425000E+00, -.37070000E+00, 0.10278400E+01, 0.25469700E+01, 0.38766400E+00, -.89219100E+00, 0.34185200E+00, 0.70876300E+00, -.10331200E+01, -.77160800E-01, 0.20127600E-01, -.30525400E+00, 0.10234400E+00, 0.29714200E+00, -.12744000E+00, 0.11048900E+00, 0.15755800E+00, -.41742700E+00, 0.75388000E+00, -.51672600E+00, 0.15289400E+00, 0.30597800E+00, -.32031300E-01, 0.54095500E+00, -.22741800E+00, 0.13764600E+01, -.83022000E+00, 0.28761600E+00, 0.95100800E-01, 0.13582900E+01, -.43922700E+00, -.54767600E+01, 0.13289000E+02, -.36218900E+02, -.79282900E+02, -.45850500E+01, 0.21454200E+02, -.46427400E+02, -.33976800E+02, -.18873100E+03, 0.93234700E+02, 0.10504600E+03, -.41568200E+02, -.55802500E+02, 0.86299800E+02, 0.85825300E+02, 0.11315200E+03, -.55082000E+02, -.40295000E+03, 0.20104900E+03, 0.23031100E+03, 0.63018600E+02, 0.11874100E+03, 0.53150700E+02, -.12920400E+03, -.15768500E+03, 0.14068000E+03, -.67512800E+01, 0.39851900E+01, -.14806800E+01, 0.78835800E+02, -.29767400E+01, 0.72174400E+01, 0.15311800E+03, 0.21052800E+03, -.17802700E+02, -.54037300E+01, 0.68747500E+01, -.95134100E+01, -.83100200E+01, -.10089700E+02, 0.46109400E+01, -.39693100E+02, 0.74596400E+00, -.47157800E+02, 0.49447600E+02, 0.23441500E+01, -.43136200E+01, -.49480400E+02, 0.31936700E+01, 0.50909600E+02, -.36924800E+01, -.85477300E+00, -.21553200E+02, -.45845100E+02, -.29188500E+02, -.82354600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15833500E+02, 0.97318800E+01, -.64338100E+01, -.14182900E+02, 0.92546800E+00, 0.72381900E+02, 0.11001700E+01, 0.19801900E+02, 0.37744800E+01, -.24059400E+01, -.84228100E+01, -.11160900E+01, -.55085000E+01, -.39953800E+01, 0.10742800E+00, -.19513700E+01, -.92237500E-01, 0.64819900E-02, -.18761000E+01, -.20839600E+01, 0.29022700E+01, -.23103800E+01, -.27303500E+01, -.76223700E+01, 0.16611300E+01, -.28065100E+00, -.40784700E+01, 0.42254700E+02, 0.49155000E+01, 0.87604800E+00, 0.10527500E+01, -.94366700E+01, -.22124100E+01, 0.18029700E+01, -.49714800E+01, 0.31392100E+01, 0.44834100E+01, 0.26036700E+01, -.10422600E+02, -.22449500E+01, -.93688800E+02, -.28902200E+01, 0.45793400E+01, -.20880500E+01, -.25849500E+00, 0.23232500E+01, -.62884900E+00, -.32068300E-01, 0.59894900E+01, -.12259100E+01, 0.78229400E+01, 0.44659200E+01, -.41678300E+00, 0.13672700E+01, 0.84840600E+01, 0.47109400E-01, -.20951300E+01, 0.43402100E+01, -.13711700E+01, -.32409800E+01, 0.11202900E+01, -.19246900E+01, -.46348300E+00, 0.24645100E+01, 0.37499300E+01, 0.43251700E+01, -.10287700E+01, -.55511000E+01, -.11055200E+00, 0.97700300E+00, -.42831000E+00, 0.45479000E-01, -.41164500E+00, -.22757300E+01, -.57133700E+00, -.13759800E+01, 0.10509000E+01, 0.71816300E+01, -.13057300E+01, 0.13794100E+02, -.23463700E+00, -.37671000E+01, -.29176700E+01, -.40931600E+00, -.66496600E+00, 0.32926600E+00, 0.29770100E+01, -.82676800E+00, -.12064800E+01, 0.74440900E+00, 0.12023300E+01, 0.67189400E+01, 0.13493100E+00, -.19170000E+02, -.14568600E+01, 0.27062000E+01, 0.13946700E+01, -.41134500E+00, 0.62369200E-01, -.13016800E+01, 0.46615600E-01, -.15215800E+01, -.27488300E+01, 0.32794700E+01, -.40204800E+01, 0.17807300E+01, -.11912400E+00, 0.52035800E+00, -.45607300E+00, -.12919700E+02, -.14078400E+01, -.34427800E+00, 0.13197200E+01, -.40873300E+00, -.26341300E+01, 0.15863700E+01, -.49581500E+01, -.11998700E+02, 0.83469000E-01, 0.21162100E+01, -.70826400E+00, -.11801600E+01, 0.44806200E+01, 0.13387900E+01, -.54535900E+00, 0.42853000E+00, 0.51066200E+00, -.19321100E+01, -.36454700E+00, 0.58481700E+00, -.14878200E+00, -.23822500E+01, 0.73031100E+00, 0.31232500E+00, -.75323200E+00, 0.13457000E+01, 0.20565500E+00, 0.21936500E-01, 0.20704700E+00, -.13510700E+01, 0.11881300E+01, 0.36098800E+00, -.10776300E+01, 0.13307600E+00, 0.21462900E+01, -.18423300E+01, 0.39724400E+02, -.47346400E+02, -.18202800E+03, 0.57472700E+01, 0.91846900E+02, 0.54607600E+02, -.10767300E+03, -.11216500E+03, 0.52124800E+02, 0.83518500E+02, -.77379500E+02, -.23515700E+02, 0.68493800E+02, 0.71509300E+02, 0.14963200E+02, -.43022900E+02, -.33104700E+03, 0.16575200E+03, 0.22585000E+03, 0.38062100E+02, 0.70693300E+02, 0.35044600E+02, -.13364700E+03, -.56791600E+02, 0.11207800E+03, -.29873100E+03, 0.14757000E+03, 0.13968500E+03, 0.17806000E+03, -.10727000E+03, 0.15069100E+03, 0.35366200E+03, 0.59327100E+03, -.11033800E+03, 0.97564000E+01, -.10979900E+03, 0.21463700E+02, -.32089900E+01, 0.15993500E+02, 0.18130800E+02, -.32060600E+02, -.44015400E+01, -.37855300E+02, 0.85543300E+02, -.11051800E+02, -.21490400E+02, -.85894600E+02, -.29641400E+01, 0.85631900E+02, -.90340500E+01, 0.95219000E+01, -.12742500E+03, -.62731200E+02, -.41535600E+02, -.10470100E+03, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.89364400E+01, 0.44307500E+01, -.73716900E+01, -.11714200E+02, 0.48865200E+01, 0.44469300E+02, 0.15762200E+01, 0.34274600E+01, 0.25120900E+01, -.10648000E+01, 0.26169200E+01, 0.90382700E+01, -.23066100E+01, -.15657900E+01, 0.14374000E+01, -.75473400E+01, -.10108700E+01, -.68015400E+00, -.10230500E+01, -.16348400E+01, -.44813600E+00, 0.13306900E+01, 0.31388000E+00, -.36444800E+01, 0.12511800E+01, -.13350000E+01, 0.65222200E+00, -.13217400E+02, -.44170800E+00, 0.12164400E+01, -.87381000E+00, 0.18830000E+01, 0.17759400E+01, -.61178900E+00, 0.56259500E-01, 0.18387600E+01, 0.31373000E+00, -.24088400E+00, -.28298400E-02, 0.78649800E+00, -.10907000E+02, -.54225300E+00, -.16952700E+01, 0.28036200E+01, 0.37212900E+00, -.11200600E+01, 0.20301900E+00, 0.10614900E+00, -.11069400E+01, -.14675800E+01, -.30022900E+01, -.83877500E+00, -.64446900E+00, -.11915100E+01, -.63367300E+00, -.53581400E-01, 0.14667800E+01, -.83154800E+00, 0.63563800E+00, 0.26938400E+01, 0.59611900E+00, -.88083200E-01, 0.12163000E+00, 0.52416000E+01, 0.74982000E+00, 0.10222400E+00, -.34726600E+00, 0.86610300E+00, 0.10676100E+01, -.16399700E-01, 0.15369700E+01, 0.65000000E+00, 0.12155600E+00, 0.71010900E+00, 0.25725400E+00, -.64658900E+00, 0.10311700E+01, -.26009100E+01, 0.93317300E-01, -.28973100E+01, -.11551100E+01, 0.22451300E+01, -.73664600E+00, -.25302000E+00, -.10548700E+01, 0.12416800E+00, -.57292200E+00, -.75472000E+00, -.14696900E+00, 0.24456600E+00, -.76534900E+00, -.37190800E+01, 0.35364800E+00, -.11157500E+01, 0.89249300E+00, -.58750800E+00, 0.14304900E+01, -.57227600E+00, -.32826600E+00, -.66537200E+00, -.34488100E+00, 0.14783900E+01, -.53079500E-01, -.65352300E+00, -.78065700E+00, -.10279800E+00, -.27764900E+00, -.26963400E+00, 0.21280400E+00, 0.40709800E+01, 0.47988300E+00, -.25789600E+00, -.11811300E+01, 0.70642300E+00, 0.18644700E+00, 0.66475800E-01, 0.32390400E-01, 0.11377400E+01, 0.21612900E-01, 0.95133900E-01, 0.75390200E+00, -.12446200E+00, -.85687500E+00, -.10437000E+00, 0.20933400E+00, 0.59315200E+00, -.10326300E+01, 0.87395800E+00, -.65187700E+00, -.30374900E+00, -.13732200E+00, 0.70094300E+00, -.45771800E+00, 0.11953700E+00, 0.75521000E-01, 0.11233500E+00, 0.70695900E+00, -.49913600E+00, -.10185800E-01, 0.31653500E+00, -.19028100E+01, -.29052100E-01, 0.32634100E+00, 0.16665300E+01, -.11829600E+01, 0.10528800E+01, -.55880700E-02, 0.38214400E+02, 0.98820100E+02, -.51917700E+01, -.22397100E+02, 0.11398100E+02, 0.55862300E+02, 0.38984600E+02, -.17875500E+02, -.22502000E+02, 0.16292700E+02, 0.62180100E+01, -.16316200E+02, -.11493300E+02, -.25534900E+02, 0.12995500E+02, 0.27668800E+03, -.13819800E+03, -.13533400E+03, -.32116200E+02, -.62679600E+02, -.47903100E+02, 0.10212500E+03, 0.10024100E+03, -.85639400E+02, 0.37736500E+01, -.67188800E+00, 0.28485200E+00, -.53746300E+02, 0.63612300E+02, -.30139200E+02, -.14883600E+03, -.23125300E+03, 0.70487700E+02, -.14840200E+02, 0.22769400E+02, 0.56658800E+00, -.32056600E+01, -.25737900E+00, -.12835100E+02, 0.62485600E+02, -.23689700E+01, 0.17005200E+02, -.43194200E+02, 0.89312100E+01, 0.13092900E+02, 0.43186800E+02, -.70434600E+00, -.22958100E+02, 0.16966300E+01, -.30203500E+01, 0.38405400E+02, 0.21098500E+02, 0.16683700E+02, 0.67353300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.25639900E+01, -.52224200E+01, -.12401100E+01, -.47746200E+01, 0.20147200E+01, 0.13806000E+02, -.58975400E+01, 0.19899500E+01, 0.76307700E+00, -.10631000E+01, 0.28212600E+01, 0.19371000E+01, -.64929900E+00, -.17536100E+00, 0.45321200E+00, -.13698700E+01, -.31129700E+00, -.99706600E+00, 0.15146600E+00, 0.23808700E+00, 0.12974900E+00, -.41806100E+00, -.27119000E+00, -.15198800E+01, -.23118800E+00, -.38655900E+00, 0.18914000E+00, 0.84470400E+01, -.10403000E+00, -.40030200E+00, -.67651900E+00, 0.10085100E+01, 0.81737500E+00, -.23352800E+00, -.64777700E+00, 0.13076400E+00, 0.50608800E+00, 0.74144600E+00, 0.38047600E+00, 0.37297000E+00, 0.69105000E+01, 0.11319100E+00, 0.43141200E+00, 0.14375900E+01, -.14377500E+00, -.66877800E+00, -.48039900E+00, 0.21551600E+00, -.58177900E+00, -.58057200E+00, -.12942500E+01, -.98289200E+00, 0.10838700E+00, 0.27654200E-01, 0.20672100E-01, -.79695500E-01, 0.11179400E+01, -.33743200E+00, 0.36142400E+00, 0.14324100E+01, -.33207500E-01, 0.99763200E+00, 0.27954300E-01, -.29515200E+00, 0.69180500E-01, -.12286000E+01, 0.17480800E+00, 0.19555500E+01, 0.22611100E+00, -.98831100E+00, -.38994700E+00, -.14286400E+00, 0.34399400E-01, -.17304300E+00, -.72068800E-01, 0.71446000E-01, 0.75888000E-01, 0.55285200E+00, -.40891800E+00, -.52910400E-01, 0.12451200E+00, 0.90119700E+00, -.90814900E-01, -.15743300E+00, -.13622500E+00, 0.41955200E+00, -.75054300E+00, -.16830000E+00, 0.70821300E-01, 0.38693300E-01, 0.28387000E+00, 0.11618200E+01, 0.27663700E+00, -.22732700E+00, 0.29981700E+00, 0.40230500E+00, -.55071000E+00, -.10613500E+00, 0.20976900E-01, 0.16170200E+00, 0.12020400E+00, 0.50437800E+00, 0.35037400E+00, -.80532700E+00, 0.15937000E+01, -.51770800E+00, -.11702300E+00, -.37473800E+00, 0.15390400E+00, 0.11445200E+01, -.21733100E+00, 0.42380400E-01, -.48758000E+00, 0.48119800E+00, -.20473600E+00, -.41341100E+00, 0.45286400E+00, -.36194000E-01, 0.29912600E-01, 0.85444700E+00, 0.93967600E+00, -.64374000E-01, 0.52372500E+00, 0.50775000E-01, -.77971300E-01, 0.26433900E+00, -.24621500E+00, 0.12257500E-01, -.55618300E-01, -.71806500E+00, -.79743300E-01, -.77893800E+00, -.44733400E+00, 0.94472600E-01, -.43231900E+00, -.42052600E+00, 0.28264500E+00, -.42155600E+00, 0.67302100E-01, 0.29037400E-01, 0.12937100E+00, -.10985300E+00, -.28698700E-01, 0.61738800E+00, -.33615300E+00, 0.11382500E+00, -.13114500E+00, 0.32398200E+00, -.31170000E+02, 0.46779700E+01, 0.25750500E+02, 0.26837600E+02, -.20400400E+02, -.94245200E+01, 0.28660500E+01, 0.61328100E+01, -.69487600E+01, -.54062800E+01, 0.53333100E+01, 0.19817500E+01, 0.53968000E+01, -.10120500E+01, -.72653300E+02, 0.36253000E+02, 0.35803400E+02, 0.23442900E+01, 0.12513000E+02, 0.19319500E+02, -.25837300E+02, -.28384600E+02, 0.24165700E+02, -.28121100E+02, 0.14117000E+02, 0.13528200E+02, 0.38335800E+02, -.11850800E+02, 0.20356300E+02, 0.71950800E+02, 0.10884900E+03, -.21419400E+02, 0.34550000E+01, -.12273700E+02, -.14605300E+01, 0.15621500E+01, -.22068800E+01, 0.23547600E+01, -.19838500E+02, -.52152900E+00, -.73059000E+01, 0.20089500E+02, -.32485500E+01, -.22173900E+01, -.20004400E+02, -.13646500E+01, 0.80099100E+01, -.29684700E+01, 0.32250200E+01, -.83383800E+01, -.86470500E+01, -.58238400E+01, -.31344600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.11170000E+02, 0.26106900E+01, -.76611200E+01, -.64308500E+01, 0.58130900E+01, 0.31907500E+02, 0.25917300E+02, 0.15768600E+02, 0.20565100E+01, 0.20249900E+01, -.51162800E+01, -.17605000E+01, -.11393200E+01, 0.40591000E+00, 0.26407800E-01, -.56329700E+01, -.78289700E+00, 0.14733200E+01, -.44372900E+01, 0.13940300E+01, 0.95020400E+00, 0.11667900E+01, 0.11746100E+01, -.26648400E+01, 0.20142100E+00, -.25687800E+00, -.94727300E+00, 0.19209800E+02, -.71711200E+00, 0.66486400E+01, 0.57750900E+00, -.18676900E+01, -.11974900E+01, 0.66113900E+00, -.27477400E+01, 0.15284100E+01, 0.17192200E+01, 0.16426900E+01, -.10917200E+01, -.29527200E+01, -.15030500E+02, -.46439200E+00, 0.21191400E+01, 0.21241000E+01, 0.12951400E+01, -.60674000E+00, -.17430500E+01, 0.44065500E+00, -.10832000E+01, -.16632900E+01, -.27881600E+01, -.43880200E+00, -.49180200E+00, -.49102100E+01, 0.37002200E+01, -.84793900E+00, 0.63040300E+00, 0.10477500E+01, -.19410100E+00, -.56139500E+01, 0.67232000E+00, -.16164800E+01, 0.10347900E+00, -.13894100E+01, 0.30898000E-01, 0.68273800E+00, -.35650800E+00, -.11055400E+01, -.41587600E+00, 0.47693900E+00, -.58737200E+00, 0.14683300E+00, -.24208800E-01, -.32543000E+00, -.16855500E+00, -.15595500E+00, 0.21704200E+00, 0.17413400E+00, -.42873200E+00, 0.48688600E+01, -.57028700E+00, -.10722600E+01, -.22337800E+00, 0.68330600E-01, 0.51324700E-01, 0.27515900E+00, -.14327900E+00, -.31342100E+00, 0.15936200E+00, -.33792500E+00, 0.43494800E+00, 0.82828500E+00, 0.85001700E-01, -.31317500E+00, -.37306300E-01, -.18381700E-01, -.46456200E+00, 0.69728700E+00, 0.57168700E-01, -.36717300E+00, -.37977400E-01, 0.57012900E+00, -.16498700E+00, -.11503800E+01, 0.54444500E-01, -.70938900E-01, -.75190000E-01, -.19240000E+00, -.64797200E-01, -.39995300E+01, -.33396600E+00, -.19363800E+00, 0.25394500E+00, -.14143800E+00, -.51825300E-01, 0.18327700E+00, -.44322600E+00, -.24918700E+01, 0.43625700E-02, 0.28768400E-01, -.35946900E+00, -.32869800E+00, 0.58661900E+00, 0.15321800E+00, -.23574100E+00, 0.39367000E+00, -.15134900E+00, -.21114300E+00, 0.91189700E-01, 0.16574000E-01, 0.12290100E+00, 0.26338000E+00, 0.25443500E+00, 0.13041900E+00, -.27077800E-01, -.41410600E+00, 0.20394100E+00, -.10550300E+00, 0.14400100E+00, -.16700500E+00, -.30086200E-01, -.24555300E+00, 0.31878800E+00, 0.26554500E+00, -.70511100E+00, 0.33375800E+00, -.14808700E+00, -.23546100E+00, -.60599200E+00, 0.10377300E+02, -.14500200E+01, 0.86573900E+01, 0.10745400E+01, 0.24900100E+02, -.13013500E+02, -.13139600E+02, -.51020600E+01, -.10020000E+02, -.24818900E+01, 0.90464100E+01, 0.42667100E+01, -.98403700E+01, 0.29512600E+02, -.14999300E+02, -.17516200E+02, -.61020100E+01, -.15596300E+02, -.21201700E+01, 0.28109800E+01, -.20886800E+02, -.15112800E+02, 0.88067300E+02, -.43742500E+02, -.43549500E+02, -.74202300E+01, 0.19619100E+02, -.22562800E+02, 0.55034800E+01, -.24889300E+02, 0.80560700E+01, 0.43156800E+01, 0.56416300E+01, 0.25377600E+01, 0.22660400E+00, -.17654800E+01, 0.54950500E+00, 0.21313200E+02, -.30699600E+01, 0.12554900E+01, -.12946600E+01, -.86311000E+00, -.11743000E+01, 0.13722700E+01, -.29613700E+01, -.22790700E+01, -.12803000E+01, 0.23186200E+01, 0.85943200E+01, 0.19985300E+01, 0.37681000E+01, -.57492300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.75414000E+01, 0.63916600E+01, -.50283400E+01, -.96475200E+01, 0.37010800E+01, 0.55530400E+02, 0.15750900E+01, 0.67299500E+01, 0.30709600E+01, -.11161700E+01, -.97168100E+01, 0.25705500E+01, -.38502300E+01, -.27527700E+00, -.18883000E+00, -.32688900E+01, -.54681900E+00, 0.10720900E+01, -.18162700E+01, -.21378500E+01, 0.71258500E+00, 0.33881000E+00, -.78690300E+00, -.39425500E+01, 0.52549700E-01, -.80906900E+00, -.10305300E+01, 0.16404800E+02, 0.10272200E+01, -.53611300E+00, -.25165100E+00, -.96100600E+00, -.21108800E+01, -.18582800E+00, -.43401700E+01, -.64844900E+00, 0.70416800E+00, 0.16562500E+01, -.16637900E+01, -.23414400E+01, -.17549700E+02, -.39373200E+00, 0.25241400E+01, 0.15993700E+01, 0.88945300E+00, -.83974300E+00, -.11225700E+01, 0.14179000E+01, 0.26193100E+01, -.16881300E+01, 0.10531400E+01, -.25496200E+00, 0.37046100E-01, -.33864500E+01, -.50593500E+00, 0.15427600E+00, 0.34591200E+00, 0.17615100E+00, -.41024600E-01, -.17571900E+01, -.11196400E+00, -.95624600E+00, -.34693900E+00, 0.12464300E+01, 0.16048000E+00, 0.52029400E+00, 0.67232200E-01, -.26486700E+01, -.81792600E+00, 0.16054300E+01, -.23662400E+00, 0.21420300E+00, -.14215500E+01, 0.65570900E+00, -.33379800E+00, 0.13175000E+00, -.79930200E+00, 0.16601300E+01, 0.21681600E-02, 0.57410000E+01, -.41190400E+00, -.17989100E+01, 0.50642500E+00, -.11409300E+01, -.56736100E+00, 0.77364000E+00, 0.76848700E+00, -.57618300E+00, -.10107900E+01, -.36784200E+00, 0.41531400E+00, 0.39926500E+01, 0.57462300E+00, 0.85634600E+00, -.21335900E+00, 0.62426600E+00, -.82446900E+00, 0.94104800E+00, 0.62067700E+00, 0.34748000E+00, 0.34323500E+00, 0.38973400E+00, 0.24981600E+00, 0.83303100E+00, -.85379900E+01, 0.34168100E+00, -.13464000E+00, 0.86076300E+00, -.77399300E+00, -.92861400E+01, -.49576400E+00, -.10764400E+00, 0.89797900E+00, -.35468200E+00, 0.96534600E-01, -.35332700E-02, -.28514100E+00, -.36692700E+01, -.28836500E+00, -.25685100E+00, 0.21507500E+01, 0.13241100E+01, -.20222300E+01, -.35116000E+00, 0.84154300E+00, -.18613800E+01, 0.15682700E+01, -.98396800E+00, -.11890000E+01, -.50742000E+00, -.45696300E+00, -.18632300E+01, -.11636500E+01, -.28715200E+00, -.59688300E+00, 0.23467600E+01, 0.12558900E+01, 0.43073500E+00, 0.44638200E+00, 0.45723100E-03, -.33912600E+00, 0.14497800E+00, -.33859400E+00, -.15696200E+01, -.46229700E+00, -.74718700E-01, -.12842800E-01, 0.28901400E+00, 0.15083600E+01, -.16208600E+00, -.18980600E+02, -.31313600E+02, -.58535800E+01, -.10658100E+03, 0.53176700E+02, 0.51028300E+02, 0.19899500E+02, 0.10794000E+03, -.20057900E+02, -.11040900E+03, -.50343700E+02, 0.75895900E+02, 0.21973000E+03, -.10902300E+03, -.10816200E+03, -.41096400E+02, -.78891300E+02, -.20251600E+02, 0.89198400E+02, 0.13211100E+03, -.80755700E+02, 0.66261500E+02, -.32524600E+02, -.32784500E+02, -.32981300E+02, -.35727800E+02, -.36947500E+02, -.44309300E+02, -.11301400E+03, -.35563100E+02, -.20434300E+01, 0.82261900E+01, 0.65993800E+01, -.10231200E+02, 0.66238600E+01, 0.20092100E+01, 0.93052000E+00, 0.29869100E+01, 0.40315400E+02, -.79704700E+00, 0.60504100E+01, -.28816000E+01, -.34618300E+00, 0.68900800E+01, -.96537200E+01, 0.37119400E+01, -.77670500E+01, 0.41929400E+01, 0.29807600E+02, 0.24788500E+02, 0.24221800E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.88697400E+01, -.68222800E+01, -.46372300E+01, -.85515100E+01, 0.28794500E+01, 0.46220800E+02, 0.61740900E+01, 0.84329100E+01, 0.26975500E+01, -.12493700E+01, -.14742800E+01, 0.18602500E+01, -.37215300E+01, -.46134000E+00, -.57948600E+00, -.21698900E+01, -.58970100E+00, 0.57284500E-01, -.19766100E+01, 0.14083600E+01, 0.50559800E+00, 0.12667600E+01, -.64702000E+00, -.32464600E+01, -.22038000E-01, -.70060200E-02, -.39521200E+00, 0.16077900E+02, -.10798500E+00, 0.45126500E+01, 0.51795300E+00, -.13135700E+01, 0.70262900E+00, 0.27507000E+00, -.68785900E+00, 0.23873300E+01, 0.10681600E+01, 0.91262800E+00, 0.31385900E+01, 0.23762100E+01, 0.92254200E+01, -.34934200E+00, 0.36161400E+00, 0.52506700E+01, 0.65396000E+00, -.90676800E+00, -.15874300E+01, 0.19825600E-01, -.19179700E+01, -.23211500E+01, -.41167000E+01, -.19519900E+01, 0.41602700E+00, -.40856900E+01, -.19811700E+01, -.71510900E+00, 0.30856400E+01, -.10339200E+01, 0.90643600E+00, 0.22506300E+01, 0.11249500E+01, 0.70095900E+00, -.69530700E+00, 0.11359400E+01, -.58181900E+00, -.21744200E+01, 0.62017800E+00, 0.24348500E+01, 0.88346600E-01, -.95270700E+00, -.92432300E+00, -.24068900E+00, -.12342500E+00, 0.38233800E-01, -.18013900E+00, 0.14642500E+00, -.11390200E+00, -.11483800E+01, -.47075500E+00, 0.63574400E+00, -.88046000E+00, 0.93532500E+00, -.68456700E+00, 0.21722500E+00, 0.69009800E-01, 0.46605100E+00, -.13872500E+01, 0.88811300E-01, 0.36823100E+00, -.23448800E+00, 0.29266200E+00, -.23616100E+01, 0.36486100E+00, 0.45469900E+01, 0.10503300E+00, -.84382800E+00, -.21550100E+00, -.19166300E+00, -.24191900E-01, 0.14280200E+00, 0.77462500E-01, 0.11188500E+01, -.46298500E+00, -.11607400E+01, -.89353600E+00, 0.13916500E+00, -.19893100E+00, -.21218400E+00, 0.32545100E+00, 0.34089000E+01, 0.53990000E+00, -.31749600E+00, -.48155200E+00, 0.23733500E+00, 0.28715500E+00, -.15925400E+00, 0.65136100E+00, 0.23997900E+01, -.54617200E-01, -.46772400E+00, -.36188100E+00, 0.38243600E+00, -.19463900E+00, -.16580500E+00, 0.17796700E-01, -.24480000E-02, -.41578300E+00, 0.12869600E+01, -.23123000E+00, -.31404900E-01, -.13506200E+00, 0.71858300E+00, -.89229900E+00, 0.35909100E+00, 0.81207400E-01, -.26491100E+00, 0.18628200E+01, -.40857400E+00, 0.37399800E+00, -.12880600E+00, -.13699000E+01, -.24039700E+00, 0.92416300E-01, -.15439100E+00, -.93308600E+00, -.39687900E+00, 0.24366100E+00, 0.15150700E+00, -.14333500E+00, -.19162200E+00, -.30667800E+00, -.53007400E+02, 0.11089800E+02, -.11343200E+03, 0.53761800E+02, 0.57112900E+02, -.36087400E+00, 0.85600500E+01, 0.19743300E+02, -.19958600E+02, 0.49543000E+02, 0.10185300E+02, -.90319000E+02, 0.44934400E+02, 0.46135000E+02, 0.23399100E+02, 0.32445900E+02, 0.19259200E+02, -.17620100E+02, -.61679400E+02, 0.33719800E+02, 0.10253600E+03, -.49829100E+02, -.52025200E+02, -.48653900E+00, 0.39779500E+02, -.45042900E+02, 0.12626700E+02, -.81564100E+02, 0.28868100E+02, -.14242000E+02, 0.39756000E+02, -.17635600E+02, -.12579800E+02, -.21243700E+02, -.77753400E+01, 0.16705900E+01, 0.58321800E+01, -.21991400E+01, 0.23014700E+01, 0.12406400E+02, 0.71905100E+01, -.25498100E+01, 0.87748000E+01, -.69533500E+00, 0.64132700E+01, -.95071900E+01, 0.27621500E+02, 0.35539500E+01, -.11092700E+02, -.20300500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17545500E+01, 0.91580200E+00, 0.11542500E+01, 0.15416700E+01, -.11785900E+01, -.32484200E+01, -.15910700E+01, -.24857200E+01, -.16460700E+00, -.24673700E+00, -.19622900E+01, 0.75274900E-01, -.18451200E-01, -.19745300E+00, -.87225400E-02, 0.62178800E+00, 0.19044600E+00, -.59814400E+00, 0.12640200E+01, -.87993200E+00, -.54632700E-01, -.11472100E+01, -.52435200E-01, 0.17758000E-01, -.18170100E-01, 0.33408400E-01, -.20650000E-01, 0.31608000E+00, -.11098200E+00, 0.48513600E+00, 0.88051500E-01, 0.13061200E+00, 0.19468500E+00, -.36966700E-01, 0.29722800E+00, 0.29381800E-01, -.92228200E-01, -.85434300E-01, 0.32344700E+00, 0.30773700E+00, 0.15109000E+01, 0.51484100E-01, -.99096400E-01, -.75179800E-01, -.91078900E-01, 0.88599500E-01, 0.64778400E-01, -.14417700E-01, 0.15593600E+00, 0.22157300E+00, -.70515300E-01, -.17225200E+00, 0.88154900E-01, 0.39603100E+00, -.73240600E+00, -.68827300E-02, -.15434600E+00, -.10849300E+00, -.33170300E-01, 0.31901300E+00, 0.73757800E+00, 0.21709400E-01, 0.14780400E-03, -.32850800E+00, -.73491000E-01, 0.26351500E-01, -.16586300E-01, -.51903000E-01, -.11812700E+00, 0.10309300E+00, -.17772600E-01, 0.61633000E-01, -.11098500E+00, 0.56369700E-01, 0.30549000E-01, 0.55290900E-01, -.76589500E-01, 0.29666500E+00, -.30472500E-01, 0.25768900E+00, -.11577400E+00, -.16108500E+00, -.18749100E+00, 0.22282500E+00, 0.48759200E-01, 0.62268200E-01, -.97138700E-01, 0.94552200E-01, -.54428100E-01, -.75094900E-01, -.45091000E-01, -.16898100E+00, -.23008600E-01, 0.12371900E+00, -.11521200E+00, 0.67582700E-04, 0.12095400E+00, -.51905400E-01, -.12006300E-01, 0.78191000E-02, 0.20939400E-02, -.11796900E+00, -.14094000E-01, 0.90449100E-02, 0.21095500E+00, -.17285500E-01, 0.25342700E-01, 0.25884400E-01, 0.37876000E-03, 0.18735300E+00, 0.15806800E-01, -.74701600E-02, -.19653200E-01, 0.79697500E-02, -.18873400E-01, 0.89887300E-02, -.29374300E-02, -.32142200E-01, -.11598600E-01, 0.87044600E-01, 0.86646800E-01, -.10037200E+00, -.10573100E+00, -.43802000E-02, 0.20277400E-02, -.19951800E-01, 0.90677000E-02, -.22294900E-01, -.49726600E-02, -.97740900E-01, 0.13861100E-02, -.13932700E+00, 0.64333500E-01, -.28177200E-01, -.68474400E-02, -.72642600E-01, 0.70975500E-01, -.70415200E-01, 0.11688500E-01, -.41363300E-01, 0.97694800E-04, 0.22972300E-01, -.27917500E-01, 0.13233600E+00, 0.20120300E+00, -.79656700E-01, 0.40927800E-01, 0.16684500E-01, -.15526900E-02, -.12743800E-01, -.81424900E-01, 0.41167900E-01, 0.25457300E+01, -.21507900E+02, 0.10767200E+02, 0.10534600E+02, 0.85832600E+00, 0.74291000E+01, 0.42077500E+01, -.42204200E+01, -.77517600E+00, 0.63091300E+01, 0.10326700E+01, -.46400200E+00, -.35955000E+00, -.60882200E+00, 0.58333500E+00, 0.13062600E+01, 0.44730700E+01, 0.12391500E+02, 0.29859800E+01, 0.15103100E+01, -.72914800E+00, -.68947600E+00, -.14079200E+00, -.68056200E+01, -.34653400E+01, -.53269600E+01, -.23151700E+01, -.85650100E+01, -.98263700E+00, -.74899900E+00, 0.10521700E+01, -.21321300E+00, 0.19132100E+01, 0.23238100E+00, -.46285600E+01, 0.71966400E+00, 0.26866800E+01, 0.16106600E+01, 0.42495900E-01, 0.12560400E-01, -.16708200E+01, 0.10197700E+01, 0.43953000E-01, 0.61318500E-01, -.94853100E+00, -.14441600E+01, 0.16134900E+01, 0.85098600E+00, 0.22592600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.58914200E+01, 0.29552100E+01, -.32748900E+01, -.44330100E+01, 0.20238000E+01, 0.19521400E+02, 0.14205500E+02, 0.10175600E+02, 0.10931500E+01, 0.18083400E+00, -.12589700E+00, 0.74969600E+00, -.16424400E+01, -.88143900E+00, -.20196700E+00, -.14542500E+01, -.63538300E+00, 0.17988300E+00, -.14643600E+01, 0.46572300E+00, 0.10776800E+00, 0.74089700E+00, -.13687500E+00, -.33387500E+01, 0.13059600E+01, -.73596900E+00, -.56441100E+00, 0.22723200E+02, -.35167500E+00, 0.25889800E+01, 0.74345800E-02, -.38691800E+00, -.65068100E+00, -.52789200E-01, 0.51571300E+00, -.37275000E+00, -.51312800E+00, 0.72960100E+00, 0.21560300E+01, 0.27717200E+01, 0.14461600E+02, 0.36284000E+00, -.17732200E+01, 0.98004700E+00, -.97640000E-01, -.52766900E+00, 0.86542200E-01, 0.81507900E+00, 0.11939100E+01, -.40349600E+00, 0.10393700E+00, -.66130400E+00, 0.98242800E+00, 0.10010200E+01, -.23024300E+01, -.26916700E-01, 0.81126800E+00, -.88260900E-01, 0.54112600E-01, 0.12577000E+01, -.11927000E+01, 0.14771300E+01, -.20067700E+00, -.15192700E+01, -.68933000E+00, -.13551600E+01, 0.20348500E+00, 0.11636200E+00, -.11224400E+01, 0.11326400E+00, 0.82178300E+00, 0.25697900E+00, 0.34530100E+00, -.15895500E+01, 0.14709300E+00, 0.12639800E+00, -.23383600E+00, -.37243300E+00, 0.11204600E+01, -.31930400E+00, -.46110500E-01, 0.23974300E+00, 0.21394400E+00, -.28231500E+00, -.24434600E+00, 0.23364600E+00, 0.54996600E+00, 0.29583500E+00, 0.18074400E+00, 0.44897900E+00, -.70208900E-01, 0.14753400E+00, 0.20835800E-01, 0.19379400E+01, -.20143900E+00, -.70370500E-01, 0.27574200E-01, -.17447700E+00, 0.93967200E-01, 0.33479900E-01, -.91101600E-01, 0.31007300E+00, 0.19272800E+00, 0.30124500E+00, -.97147800E+00, -.10512800E+00, -.82732400E-01, 0.25414100E+00, 0.28954500E-01, -.35638000E+00, 0.97772900E-01, 0.17247400E+00, 0.40198800E+00, -.95346000E-01, 0.33283900E+00, -.16544200E+00, 0.30296000E+00, 0.12789700E+01, 0.18997100E-01, -.62364100E+00, 0.15938200E+00, 0.32306300E+00, -.23151600E+00, -.10252300E+00, 0.57283900E-01, -.49216600E+00, 0.52355600E+00, -.36868800E+00, 0.52086500E+00, -.23723500E-01, -.28332700E-01, 0.53752500E+00, -.44310200E-01, 0.39093500E+00, -.14480100E+00, -.36302800E+00, -.52971200E+00, -.16828700E+00, -.12429600E+00, -.48484400E+00, 0.30436800E+00, -.11783500E+00, -.16597700E+00, 0.38022200E+00, -.33165500E+00, 0.32061600E+00, -.10576500E+00, 0.10990500E+00, 0.26011500E-01, -.28507400E+00, 0.31182300E+00, 0.21030900E-01, 0.21844200E+01, 0.13601300E+03, -.68326600E+02, -.67361800E+02, -.24793800E+01, -.37042300E+02, -.23586800E+02, 0.17749800E+02, -.37500400E+02, -.31480200E+02, -.23050300E+02, 0.10847900E+02, 0.38726100E+01, 0.12147200E+02, 0.52434800E+01, -.11051900E+01, -.29036200E+02, -.86228100E+02, -.37581300E+01, -.68495000E+02, 0.34039500E+02, 0.34445600E+02, -.10712200E+01, 0.35119200E+02, 0.39010500E+02, 0.27202000E+02, 0.67329800E+02, 0.51825200E+02, 0.99473900E+01, -.72522500E+01, 0.33228600E+00, 0.87269900E+01, -.56974200E+01, 0.17081200E+01, 0.32665700E+02, -.57735800E+01, -.10803500E+02, -.20280500E+02, -.63096300E+01, -.32276900E+01, 0.20811200E+02, -.87115800E+01, 0.74938700E+00, -.17714300E+01, 0.79034100E+01, -.72317700E+01, -.82314400E+01, -.72262700E+01, -.11173300E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12317300E+02, -.69138300E+01, -.66350900E+01, -.11601600E+02, 0.49500800E+01, 0.62827100E+02, 0.21396200E+02, 0.12687800E+02, 0.38525800E+01, -.91051300E+00, -.22847400E+01, 0.31772800E+01, -.48012700E+01, -.89408400E+00, 0.17030900E+00, -.24535900E+01, -.89471100E+00, -.64037400E-01, -.32839000E+01, 0.15860900E+01, 0.28020000E+00, 0.20244400E+01, -.98753400E+00, -.83859600E+01, 0.16882500E+01, -.12800900E+01, -.16792100E+01, 0.35755800E+02, 0.11933700E+01, 0.33247600E+01, 0.34791300E+00, -.62159200E+00, -.65129700E+00, -.14889500E+00, 0.94250900E+00, 0.73516300E+00, -.45374900E+00, 0.27003100E+01, 0.64317700E+01, 0.10900200E+02, 0.28362400E+02, -.33273600E+00, -.64003900E+00, 0.49265200E+01, 0.10309300E+01, -.15241200E+01, -.51259700E+00, 0.45837500E+00, 0.78889100E+00, -.21448500E+01, 0.39989200E+00, -.12401500E+00, 0.14742600E+01, -.59996900E+01, -.71487100E+01, -.25411600E+00, 0.26023600E+01, -.10036900E+00, -.56883300E+00, -.54871100E+00, -.18113500E+01, 0.16738400E+01, -.39064900E+00, -.96487600E+01, -.11705300E+01, -.65687600E+00, 0.38105400E+00, -.16904100E+01, -.17354200E+01, -.18674000E+00, -.55404600E-02, -.95875800E+00, -.38104800E+00, -.65427500E+00, 0.79331400E+00, 0.57710000E+00, -.29808000E+00, 0.24430100E+01, 0.13621200E+01, 0.57581700E+01, -.63272000E+00, -.10815500E+01, 0.38531400E-01, 0.67595700E+00, -.92839500E-01, 0.10643500E+01, 0.12679300E+01, 0.24061700E+00, -.23316100E+00, -.12907600E+00, 0.46463600E+00, 0.86677700E+01, 0.38299400E+00, 0.99602700E+01, -.32070200E+01, -.34305600E+00, -.23011200E+01, -.31377200E+00, 0.59296800E+00, 0.57469000E+00, 0.25893800E+00, -.30809900E+00, -.14052700E+01, -.13440800E+01, 0.66516100E+00, -.53858400E+00, -.65190900E-01, -.78479400E-01, 0.34128900E+00, -.21434300E+01, 0.77651500E+00, 0.28234300E+00, 0.10047300E+01, -.33336800E+00, 0.96901200E+00, -.69677800E+00, 0.25713300E+01, 0.89334900E+01, 0.80080500E-01, -.24316500E+01, -.12254100E+01, 0.18237900E+01, -.14822600E+01, -.47526800E+00, 0.32521300E+00, -.12238800E+01, 0.14022500E+01, 0.46946800E+00, 0.99215800E-01, -.11541100E+01, -.41898500E+00, 0.44107900E+00, -.11415500E+01, 0.27096500E+00, -.16314600E+00, -.50426300E+00, -.15053000E+01, 0.88879500E+00, -.70393800E+00, 0.46710100E+00, -.11187100E+01, 0.38137200E+00, -.50468100E+00, 0.49559200E+00, -.11289500E+01, 0.72731500E+00, 0.29611500E+00, 0.83727000E+00, 0.43041300E+00, -.10422500E+01, 0.20661900E+00, 0.61699600E+00, 0.32731500E+01, 0.10191800E+01, 0.48948200E+01, -.99188700E+00, 0.23673700E+02, 0.41566400E+02, -.30642200E+02, -.50357500E+02, -.31198200E+02, 0.41848800E+02, 0.13271500E+03, -.66142600E+02, -.76274500E+02, -.11503600E+02, -.31344400E+02, -.21802800E+02, 0.14832900E+02, 0.37459800E+02, -.35132100E+02, -.17466100E+03, 0.84446200E+02, 0.86263300E+02, 0.42588500E+01, 0.19891100E+02, 0.64284400E+02, 0.18885000E+02, 0.29605600E+02, 0.36544700E+02, 0.99195100E+01, -.16126900E+02, -.38559300E+01, 0.12042900E+01, -.96983300E+01, 0.14327700E+01, -.34546600E+01, 0.36500500E+01, 0.22409100E+02, -.12171100E+01, 0.11357900E+01, -.17003800E+01, 0.90261500E+00, 0.29808400E+01, -.26224600E+02, 0.49589700E+01, -.27835600E+01, -.16241000E+02, 0.23593100E+02, -.27557200E+02, 0.11504900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.12372500E+02, 0.36010600E+01, -.10089900E+02, -.15586700E+02, 0.74001400E+01, 0.61292400E+02, 0.17055700E+02, 0.56374600E+01, 0.37307100E+01, -.73401200E+00, 0.42922800E+01, 0.10956800E+02, -.32068500E+01, -.19179200E+01, 0.22578600E+01, -.81095400E+01, -.13447400E+01, -.10170100E+01, -.26992000E+01, -.13447500E+01, -.34922800E+00, 0.22281400E+01, -.26552700E+00, -.76767800E+01, 0.23529700E+01, -.20821100E+01, -.70629500E+00, 0.35626400E+01, -.77425000E+00, 0.52694800E+00, -.84176000E+00, 0.30874900E+01, 0.85318300E+00, -.10088500E+01, 0.17781000E+01, 0.15687000E+01, -.12412200E+01, -.74809300E+00, 0.42454700E+01, 0.72200500E+01, 0.81764800E+01, -.14497800E+00, -.33775800E+01, 0.23913300E+01, 0.76364800E+00, -.14598400E+01, 0.61829600E+00, 0.94717000E+00, 0.29757800E+01, -.10736000E+01, 0.49967400E+00, 0.17979000E+00, 0.14514400E+01, -.29867400E+01, -.95748700E+01, 0.30406500E+00, 0.84675400E+00, -.34835900E+00, -.56669200E+00, 0.21256400E+01, -.18930200E+01, 0.58593900E+00, -.31899800E-01, -.44879000E+00, 0.38101200E-01, 0.42852800E+00, 0.19511500E+00, -.20960100E+01, -.96963600E+00, 0.46606700E+00, 0.25680500E+01, 0.33849800E+00, -.64536300E+00, 0.12317300E+00, 0.80280000E+00, 0.57438600E-01, 0.19820500E+00, -.18527200E+00, 0.17358600E+01, -.17810900E+01, -.46048200E+00, 0.14450600E+01, -.34842300E+00, -.14004400E+00, -.13721800E+01, -.20383500E-01, 0.15726800E+01, -.28720900E+00, -.61311200E+00, 0.43307500E+00, -.76077300E+00, 0.20924800E+01, 0.57372000E-01, -.23590300E+00, -.11098600E+01, -.42349100E-03, 0.74848200E+00, -.86301400E+00, -.32002100E+00, -.58546700E+00, -.27725800E+00, -.38109000E+00, -.60211700E+00, -.66584000E+00, 0.49272900E+01, -.95639900E+00, -.10966400E+00, -.61686600E+00, 0.35550500E+00, 0.68790000E+01, 0.50672600E-01, 0.11375800E+00, -.16884600E+01, 0.50438700E+00, 0.56624100E+00, 0.11361000E+01, 0.15058500E+00, 0.40671700E+01, -.37044800E-01, 0.24167800E-01, -.13028700E+01, -.80336500E-01, -.13536200E+00, 0.16404200E-01, -.97057100E-02, 0.13101200E+01, -.34588400E+00, 0.21513200E+00, 0.31272700E+00, 0.16144100E+00, 0.46998100E-01, 0.12879300E+01, 0.30214100E+00, -.17448100E-01, 0.99471100E-01, -.13900900E+01, -.11888600E+01, -.22110000E+00, -.36493500E+00, 0.41439200E+00, -.12247300E+01, -.10702900E+00, -.48655200E-01, 0.24648700E+01, -.86850100E+00, 0.14196600E+01, -.12549100E+00, 0.54992700E+00, 0.26578300E-01, -.13786300E+00, -.17399500E-01, 0.36918900E+00, 0.10791600E+01, 0.96956900E+00, 0.27200600E+00, 0.62295800E+01, 0.75057300E+01, 0.44937500E+01, 0.23207500E+01, 0.14481500E+02, -.25777100E+02, 0.71098800E+00, -.72002500E+02, 0.36094500E+02, 0.40919000E+02, 0.10164200E+02, 0.16595100E+02, 0.45151900E+01, -.24964400E+02, 0.38713000E+01, 0.17465000E+02, 0.38821200E+02, -.18965600E+02, -.19945500E+02, -.46918400E+01, -.39333800E+02, 0.24343500E+01, 0.32995600E+02, 0.50166400E+02, -.35904700E+02, 0.50115400E+01, -.37592500E+02, 0.90064600E+01, 0.55315400E+01, 0.13814700E+02, 0.61519500E+00, 0.24659100E+02, -.22417900E+01, -.19040900E+01, 0.46106900E+01, -.51961400E+01, -.54137400E+00, -.46840000E+01, -.24404500E+01, 0.25561700E+01, -.18593100E+01, 0.21361100E+01, -.37991100E+02, -.31774300E+01, 0.85100700E+01, 0.13760400E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.39988300E+01, -.38696300E+01, -.24573300E+01, -.74752000E+01, 0.31390400E+01, 0.23546800E+02, -.10505700E+02, 0.49044200E+00, 0.12915500E+01, -.15848000E+01, 0.16511200E+00, 0.44156300E+01, -.14056800E+01, -.46231300E-01, 0.32223900E+00, -.29652100E+01, -.67094500E+00, -.10535300E+01, 0.66606800E+00, -.19779600E+00, 0.38385600E+00, -.62770500E+00, -.61310200E+00, -.16747700E+01, 0.42204400E-01, -.10181200E+01, -.25069400E+00, 0.40758700E+01, -.57276100E+00, -.25594300E+01, -.51537500E+00, 0.12568400E+01, 0.85779700E+00, -.46091900E+00, -.12037100E+01, -.28326000E+00, 0.79683200E+00, -.14981500E+00, -.11178100E+00, -.81462700E+00, 0.12039700E+02, 0.56989900E+00, 0.11044300E+00, 0.20874900E-01, -.93007200E+00, 0.58824000E+00, 0.51756900E+00, -.36531600E+00, -.67801800E+00, -.39486700E-01, -.25291400E+00, -.60562000E+00, 0.62574800E-02, 0.53852900E+01, 0.10647400E+01, 0.67608500E-01, -.72965700E-01, -.61470600E+00, 0.26615600E+00, 0.29726500E+01, 0.13688900E+00, 0.14336700E+01, 0.23989200E+00, 0.26508700E+01, 0.25787100E+00, -.14188300E+01, 0.94130900E-01, 0.31427900E+01, 0.75368300E+00, -.12636700E+01, 0.14475300E+00, 0.37337500E+00, 0.46777300E+00, -.79737700E+00, -.87025000E+00, -.35567900E+00, 0.32244500E+00, 0.29619900E+00, -.74030900E+00, -.51554900E+01, 0.11441000E+01, 0.24837400E+01, -.80779500E+00, 0.96260100E-01, -.76874800E+00, 0.17597300E+00, -.86979300E+00, -.12245300E+01, 0.97881800E+00, 0.13466500E+00, 0.33805900E+00, 0.11607400E+00, 0.21990500E+00, 0.81881900E+00, 0.19877900E+00, -.54595200E+00, -.30297100E+00, -.81084700E+00, -.16866000E+00, 0.26185200E+00, -.22882800E+00, -.82709300E-01, 0.28372000E-01, -.32389000E+00, 0.54037700E+00, 0.10045600E+00, 0.29031800E+00, 0.12568800E+00, -.21409900E-01, 0.23922100E+01, 0.90079400E+00, -.33018500E+00, -.63685400E+00, 0.32098600E+00, 0.13662400E+00, -.41468300E+00, 0.87515400E+00, 0.98151300E+00, -.14846400E-01, -.36248700E+00, 0.11715900E+01, 0.47556600E+00, -.15964400E+00, 0.15269500E-01, 0.13823900E+00, -.73511000E+00, 0.11950200E+00, -.12308300E+00, 0.64793800E-01, -.13379800E+01, 0.50593500E+00, -.30933400E+00, 0.39304500E+00, -.32795700E+00, 0.22025700E+00, 0.20985200E-01, -.28242700E+00, 0.30386700E+00, 0.23617400E+00, 0.38095800E+00, 0.27433100E+00, -.42230500E-01, 0.17275900E+00, -.12370400E+01, 0.11676600E+00, -.36090400E+00, -.72323300E-01, -.33137200E+00, 0.33041500E-01, 0.89985400E-02, -.22426100E+00, -.21488200E-01, -.70022800E+00, -.63742300E+00, -.24405800E-01, -.34193700E+00, 0.31379400E+02, 0.59289400E+02, -.33371500E+02, -.66658300E+02, -.72899000E+02, 0.47942500E+02, 0.14047700E+03, -.70082200E+02, -.71485100E+02, -.34127500E+02, -.48081800E+02, -.14693100E+02, 0.44674100E+02, 0.19568100E+02, -.52838000E+02, 0.26596500E+02, -.13612300E+02, -.13208200E+02, 0.95213700E+01, 0.17492100E+02, -.22135700E+02, -.80451900E+01, -.91080700E+01, 0.17269000E+02, 0.28981500E+01, 0.21350300E+02, -.22008500E+01, 0.18392500E+01, -.41321100E+01, -.27985200E+00, 0.16701300E+02, -.19539900E+01, 0.26862500E+01, -.93743100E+01, -.40531200E+00, 0.83843200E+00, 0.92336700E+01, -.22603100E+01, -.14116400E+01, -.17140000E+01, 0.17826500E+01, 0.21225800E+02, 0.14560400E+01, 0.68100400E+01, -.18125700E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.49540800E+01, 0.49350200E+00, 0.40574400E+01, 0.71070000E+01, -.35743100E+01, -.22760100E+02, -.50479800E+01, -.26494300E+01, -.14267500E+01, 0.11118900E+00, -.12824500E+01, -.41326200E+01, 0.12478000E+01, 0.14785300E+01, -.16213300E+01, 0.38892600E+01, 0.52853900E+00, 0.91206600E+00, 0.46476600E+00, 0.22145600E+00, -.78138700E+00, 0.38745700E+00, 0.46631000E+00, 0.75565000E+00, 0.86501800E-01, 0.31597100E+00, 0.29165000E+00, 0.54210700E+01, -.10955300E+00, -.69544100E+00, 0.28922400E+00, 0.43134000E+00, -.82743400E+00, -.33218300E+00, 0.21510800E+00, -.23525800E+01, -.81993700E+00, 0.11268500E+01, -.99622700E+00, -.24021800E+01, 0.31807200E+00, 0.43754800E+00, 0.52523500E+00, -.34288900E+01, 0.29083600E+00, 0.56720100E+00, 0.12952400E+00, 0.11188100E+01, 0.25857800E+01, 0.18384300E+01, 0.41919900E+01, 0.92281600E+00, 0.61990100E+00, 0.11196500E+01, -.10595100E+01, 0.68271800E+00, -.17232300E+01, -.16534000E+00, -.22679400E+00, -.41314400E+01, -.24403500E-01, -.85076600E+00, 0.27452300E+00, -.28465000E+01, -.21120400E+00, 0.10474700E+01, -.18934100E+00, 0.14852600E+01, -.39446200E+00, 0.27458800E+00, -.16719900E+00, 0.25762500E+00, -.41807500E-01, -.10143200E+01, -.28916300E+00, -.13383000E+00, -.19134900E+00, 0.74017300E+00, 0.19668400E+00, 0.28298600E+01, 0.33681500E+00, -.59665500E+00, 0.38925000E+00, 0.43754200E+00, 0.12732500E+00, 0.42368300E+00, -.74696800E+00, -.28927100E+00, 0.40033100E-01, -.43258800E+00, -.13802700E+00, -.12535800E+01, -.34215000E+00, -.17087000E+00, -.22227000E+00, 0.20661000E+00, -.15220100E+00, 0.14014800E+01, -.93744200E-01, -.22675100E+00, -.17370700E+00, -.14366900E+00, -.26449300E-02, 0.14595000E+00, -.16420600E+01, 0.24017000E+00, 0.13576000E-01, 0.14352200E+00, 0.23789700E+00, -.11009300E+00, -.10115900E+01, 0.13087400E-01, -.19650800E+00, -.15549000E+00, -.60121900E+00, 0.79997500E+00, -.76934000E+00, -.11924000E+01, 0.36784700E+00, 0.14497800E+01, 0.43874600E+00, 0.62329800E-01, 0.11475700E+01, 0.14103600E+00, -.10238500E+00, 0.13061900E+00, -.19384400E+00, -.93332000E-01, 0.26582000E+00, 0.18228300E+00, 0.34640200E+00, -.42661700E+00, 0.21443100E+00, 0.65343000E-01, -.18363800E+00, -.41948200E+00, 0.38863400E+00, -.57128500E+00, -.39865500E-01, -.13427400E+00, 0.78979500E+00, -.16196600E+00, -.66043300E-01, 0.12264500E+01, -.24152900E+00, 0.56685300E+00, 0.16498200E+00, 0.40968500E+00, -.44969000E+00, 0.33735400E+00, 0.24266400E+00, 0.26953300E+00, -.77905400E+00, 0.68100100E+00, 0.21458300E-01, -.18731000E+00, 0.44047400E+00, -.44729300E+02, 0.19153200E+02, 0.54275500E+02, 0.71003200E+02, -.32118000E+02, -.26235500E+03, 0.13114700E+03, 0.12622400E+03, 0.38287000E+02, 0.76112400E+02, 0.39808100E+02, -.82629500E+02, -.57225800E+02, 0.85572400E+02, 0.88099200E+02, -.43392900E+02, -.44345300E+02, -.18669700E+02, -.62932600E+02, -.91859500E+01, 0.22892700E+02, 0.30386100E+02, -.68940200E+02, 0.10323700E+02, -.35585400E+02, 0.65127600E+00, 0.10773800E+02, 0.13469000E+02, 0.37247100E+01, -.18138500E+02, -.85295900E+00, -.25092200E+02, 0.24453200E+02, -.10167600E+02, -.89076100E+00, -.23825900E+02, -.13716100E+01, 0.52963900E+01, -.52921000E+01, 0.24365100E+01, -.35195900E+02, -.17136300E+02, 0.61146500E+01, 0.15477100E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10468000E+02, 0.66412500E+01, -.57598500E+01, -.10089600E+02, 0.23649500E+01, 0.52488600E+02, -.88402100E+01, 0.93197100E+01, 0.28902900E+01, -.17166400E+01, -.16025100E+02, 0.93601500E+00, -.58285400E+01, -.12656900E+01, 0.62897900E+00, -.34294600E+01, -.23606300E+00, 0.97512200E+00, -.28007500E+01, -.97501500E+00, 0.80498800E+00, 0.93213300E+00, -.10595000E+01, -.65032300E+01, 0.15872000E+01, -.44036200E+00, -.22297500E+01, 0.24052300E+02, 0.20733700E+01, 0.74088300E+01, 0.98315200E+00, -.73791000E+01, -.23933900E+01, 0.84508100E+00, -.20008600E+01, 0.18533600E+01, 0.23839100E+01, 0.23625100E+01, 0.93061300E+00, 0.27388900E+01, -.22823900E+02, -.16065400E+01, -.16891000E+01, 0.51432300E+01, 0.17834500E+01, -.26358100E+01, -.10776800E+01, -.34347200E+00, -.14902500E+01, -.32053700E+01, -.25985200E+01, 0.52848000E+00, -.73719200E+00, -.50235900E+01, 0.42618900E+01, -.12864700E+01, 0.25088800E+01, 0.12843400E+01, 0.39212400E+00, -.35354300E+01, -.13070700E+01, -.15009700E+01, -.16153600E+01, 0.49180300E+01, -.55390500E+00, 0.14834500E+01, -.49273900E+00, -.30225000E+01, 0.79696300E-01, 0.11130000E+01, 0.12553800E+01, 0.10743800E+01, 0.96215800E+00, -.70170400E+00, -.69955400E+00, -.79081100E+00, 0.57545700E+00, -.26850200E+01, 0.86898900E+00, -.13848100E+01, 0.67355700E+00, 0.56565600E+00, 0.13680600E+00, -.80442900E+00, -.95665400E+00, -.30532700E+00, 0.98340000E+00, -.59882700E-01, -.60670700E+00, 0.48064900E+00, -.53156500E+00, -.40149700E+01, -.23317600E+00, -.62828200E+01, 0.12459400E+01, 0.97155400E+00, 0.11685700E+01, 0.10559600E+01, 0.60480100E-03, -.73651800E+00, 0.59529600E+00, 0.28284400E+00, -.36480000E+00, -.14569200E+01, -.62526700E+01, 0.66341700E+00, -.18782200E+00, 0.53636000E+00, 0.41757200E+00, -.75527300E+01, -.11792600E+01, -.11854100E+00, 0.11955700E+01, -.70080500E+00, -.53823200E+00, 0.81987400E+00, -.13327200E+01, -.60480000E+01, 0.52487700E+00, 0.82543200E+00, -.54899900E+00, 0.42679800E+00, 0.96341100E+00, 0.13305100E+00, -.25746100E+00, 0.79422700E-01, 0.17213100E-01, 0.85560700E+00, -.13516200E+01, 0.11598700E+01, -.31200900E+00, -.81921900E+00, -.70618800E+00, -.68763300E+00, 0.16932100E+00, 0.16194600E+01, 0.27315700E+01, -.17984300E+00, 0.61382000E+00, 0.10924100E+01, -.10838000E+01, 0.83839800E-01, 0.27153600E-01, -.57066700E+00, 0.32208700E+00, 0.62112500E-01, 0.20579200E+00, -.23524900E+00, 0.54068300E-01, 0.13158600E+01, -.62686100E+00, 0.88606100E+00, -.68600100E+01, -.20751400E+01, 0.83320900E+00, 0.12736400E+00, 0.13980500E+00, -.35932000E+00, 0.29847900E+02, 0.25667200E+02, -.46859800E+02, -.85565000E+01, -.32272100E+03, 0.16096300E+03, 0.16068500E+03, 0.58824900E+02, 0.99888300E+02, 0.36706500E+02, -.55360100E+02, -.37387700E+02, 0.10498600E+03, 0.15707400E+03, -.77413000E+02, -.76186500E+02, -.28307900E+02, -.11548100E+03, -.49158000E+02, -.49644100E+02, 0.17719200E+02, -.11375900E+03, -.46550000E+01, -.26059500E+02, 0.13109100E+02, 0.14623800E+02, 0.39403100E+02, -.84831800E-01, 0.14977300E+02, -.65699300E+01, -.17522800E+02, -.11176600E+02, -.14901100E+02, -.96730200E+00, 0.12036500E+02, -.78865500E+01, 0.31631200E+02, -.78749100E+01, 0.73204100E+01, -.24260700E+02, -.27377600E+02, 0.45605300E+02, 0.19266900E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.36127800E+01, -.50440600E+01, -.18715800E+01, -.61427900E+01, 0.27987800E+01, 0.20818700E+02, -.22322700E+01, 0.24275000E+01, 0.12105200E+01, -.11428200E+01, 0.31388400E+01, 0.31814700E+01, -.13289900E+01, -.20111700E+00, 0.45451700E+00, -.14978900E+01, -.46736100E+00, -.94590200E+00, 0.53873400E+00, 0.55272100E-01, 0.21945800E+00, -.70513000E+00, -.68599700E+00, -.29439000E+01, 0.79488700E-01, -.81767900E+00, -.12638500E+00, 0.13327400E+02, 0.79789300E+00, -.28641500E+01, -.58631300E+00, 0.40003800E+00, 0.11941800E+01, -.13471800E+00, -.60371700E-01, 0.11529900E+01, 0.71988500E+00, 0.64664600E+00, 0.31388100E+00, 0.36309800E+01, -.10404400E+01, -.29747700E+00, 0.16586100E+01, -.92522500E+00, -.78262100E+00, -.85025100E+00, 0.63978600E+00, -.17906000E+00, 0.12613100E+01, -.25725300E+00, 0.29198800E+01, 0.12938000E+01, 0.59767400E+00, -.45454500E+01, -.38043500E+01, 0.13495400E+00, 0.21546100E+00, 0.98797000E+00, -.10195800E+01, 0.62524700E+00, -.44337400E+00, -.30240000E+00, 0.24856200E+00, -.31178800E+01, -.17872900E+00, 0.16194900E+00, 0.15578900E+00, 0.22221400E+00, 0.21261700E+00, -.78256300E+00, -.33554300E+00, -.11141300E+01, 0.24192100E+00, 0.20743600E+00, 0.53159900E+00, 0.21363700E-01, 0.57704100E+00, -.28459100E+00, 0.95291800E-01, 0.34109000E+01, -.12512600E+01, -.30522100E+00, -.52541500E+00, 0.17182700E+00, -.33939000E+00, 0.41702400E+00, 0.31481100E+00, 0.64332400E-01, -.23259600E+00, -.54879600E+00, -.16165900E+00, 0.43716000E+00, -.15442300E+00, -.14235900E+01, 0.42289900E+00, -.91227100E-01, -.50560000E+00, -.31680600E+00, 0.32815600E+00, 0.99895600E-01, 0.49813400E+00, 0.73269300E-03, -.14939900E+01, -.64156700E+00, -.21825500E+01, 0.61447900E+00, -.24653100E+00, -.40710700E-01, 0.55599900E+00, 0.13797100E+01, -.12562900E+00, 0.38704100E-01, -.19915700E-01, -.66416000E+00, -.59573500E-01, 0.15707400E+01, -.14102500E+01, -.34524100E+01, 0.43172700E+00, 0.39690900E+00, -.22328000E+01, 0.22582700E+00, 0.14182200E+01, 0.22237400E+00, -.17543700E+00, 0.12642700E+01, -.65682700E+00, 0.44616800E+00, -.31138900E+00, 0.15238400E+01, -.45822700E-01, 0.46491500E+00, -.48544100E+00, -.10979400E+00, 0.37034400E+00, 0.18111400E+00, -.12342100E+00, 0.12085800E+00, -.52712100E-01, -.15174800E+00, 0.28499800E+00, -.45259100E-01, -.15665200E+00, -.81288100E+00, 0.16797100E+00, -.33572700E+00, 0.16810000E-01, -.27342500E+00, -.35827400E+00, 0.37320500E+00, -.54748200E+00, 0.40642100E+00, -.21631500E+01, -.48941600E+00, 0.28607300E+00, -.19240900E+00, 0.44400200E+00, -.91089300E+00, 0.42528200E+00, 0.29035800E+02, 0.45316500E+02, -.27488200E+01, -.99813300E+02, 0.50327800E+02, 0.46466900E+02, 0.15256700E+02, 0.26271800E+02, 0.15919500E+02, -.40209400E+02, 0.58886300E+01, 0.36149100E+02, 0.23400000E+02, -.11351400E+02, -.12125500E+02, -.17440300E+02, -.57168100E+02, 0.14648200E+02, 0.40089400E+02, 0.55938200E+02, -.60544700E+02, 0.11036400E+02, -.53914200E+02, 0.91223200E+01, 0.56751800E+01, 0.13884000E+02, 0.48028800E+01, -.98238800E+01, 0.84997700E-01, 0.77880600E+00, 0.24929000E+02, -.73412800E+01, -.36735300E+01, -.24874100E+02, -.14006400E+00, -.68281200E+01, -.17829900E+01, 0.13933000E+01, -.53972100E+02, 0.14433000E+01, -.26511700E+01, 0.26336200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.13022600E+02, 0.20804400E+01, -.99771600E+01, -.16283100E+02, 0.81341700E+01, 0.63320400E+02, 0.12734000E+01, 0.76174100E+01, 0.37441900E+01, -.14067900E+01, 0.33796400E+01, 0.11539700E+02, -.40700000E+01, -.23172300E+01, 0.20724400E+01, -.95706500E+01, -.14310000E+01, -.20286300E+01, 0.45243400E+00, -.22976900E+01, -.76328900E+00, -.50722700E+00, 0.61729100E+00, -.59319700E+01, 0.32711400E+00, -.21451400E+01, 0.39442900E+00, 0.95853300E+01, -.30148100E+00, -.61881200E+00, -.13172200E+01, 0.27637700E+01, 0.23986500E+01, -.60109900E+00, -.16009500E+01, 0.33455700E+01, 0.17364300E+01, 0.57607000E+00, 0.74118400E+00, 0.13385500E+01, -.19764100E+02, -.10618000E+01, 0.10784400E+01, 0.31598700E+01, 0.11193900E+00, -.99412800E+00, -.82620800E+00, -.27358100E+00, 0.51845700E+00, -.27039300E+01, -.22004800E+01, -.80325400E+00, -.83870900E+00, -.33857100E+01, 0.18153700E+01, -.97425600E+00, 0.25808900E+01, 0.12221800E+01, -.29706700E+00, 0.30525400E+01, 0.88847900E+00, 0.12012900E+01, 0.43315400E+00, 0.10062100E+01, 0.18382200E+00, -.42397800E+00, -.63683500E+00, 0.13168200E+01, 0.74020400E+00, -.55150700E-01, 0.82815500E+00, 0.11541500E+01, 0.22662000E+00, -.12968700E+01, 0.97606800E-01, -.74527900E+00, 0.19898200E+01, -.17293700E+01, -.12233800E+01, 0.47724300E+01, -.29898400E+01, 0.20110000E+01, -.39751100E+01, 0.66239000E+00, -.94821900E+00, 0.10947800E+01, -.24673800E+01, -.14492300E+01, 0.60070000E+00, -.31455000E+00, -.14201900E+01, -.98064200E+01, 0.72343600E+00, 0.14848900E+01, 0.24212200E+01, -.23978600E+01, 0.32990500E+01, -.33737500E+01, -.10662700E+01, -.75416100E+00, -.29605300E+00, 0.43164400E+01, -.30176200E+00, -.16080400E+01, -.11482600E+01, 0.51165700E+00, -.71042100E+00, -.49215300E+00, 0.68242800E+00, 0.96638300E+01, 0.78604900E-01, -.92910300E+00, -.35012700E+01, 0.92128500E+00, 0.14446200E+00, 0.13758400E+01, -.22341700E+01, -.36204400E+01, 0.28766800E+00, 0.12208400E+01, 0.11269800E+01, -.25404100E+01, -.79286500E+00, 0.29508000E+00, 0.20859500E+00, 0.19960200E+01, -.10549800E+01, -.31390100E+00, 0.12469600E+01, 0.12586300E+01, 0.44486700E+00, 0.11877900E+01, 0.80188900E+00, 0.62790300E+00, -.41844200E+00, -.11466800E+01, -.13756600E+01, -.73568700E+00, -.44799400E+00, 0.76408000E+00, -.23625100E+00, -.35837100E+00, 0.76183900E-01, 0.52591100E+01, -.46703300E-01, 0.14416400E+01, -.27963600E+00, 0.18678500E+00, -.97621100E+00, 0.22915900E+01, -.79540100E+00, 0.66415700E+00, -.77607200E+01, -.14485000E+01, 0.29859100E-01, 0.13234200E+00, -.79884800E+00, 0.15155100E+01, 0.83494400E+00, -.41062700E+00, -.72294100E+02, 0.18566800E+02, 0.30408300E+03, -.15169100E+03, -.15263700E+03, -.40287600E+02, -.80068800E+02, -.63226800E+02, 0.50629000E+02, 0.63118700E+02, -.90977700E+02, -.24098000E+03, 0.12037200E+03, 0.11963500E+03, 0.40608100E+02, 0.30460400E+02, 0.97044600E+02, 0.75360900E+02, 0.19333700E+03, 0.55336600E+02, 0.12832800E+02, -.53136800E+02, 0.28526700E+02, 0.24756400E+01, 0.65925100E+01, 0.19502100E+01, 0.18702600E+02, -.79780600E+00, 0.19453800E+02, -.18109500E+02, -.85775500E+00, 0.96887600E+00, 0.17393100E+02, -.52504300E+01, -.16329600E+02, 0.12982200E+01, 0.42714100E+01, -.55094400E+02, 0.16230800E+02, -.37898100E+02, 0.55839900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.45153800E+01, -.23990300E+01, -.22408900E+01, -.61399900E+01, 0.25598200E+01, 0.24923700E+02, 0.45392500E-01, 0.34305100E+01, 0.12843000E+01, -.11296300E+01, 0.46678400E+01, 0.22922300E+01, -.13149500E+01, 0.31763300E+00, -.21722100E+00, -.83897700E+00, -.58733700E+00, -.19672900E+00, -.67905000E+00, 0.28475600E+00, 0.67616900E-01, 0.75457300E+00, -.55692900E+00, -.18799300E+01, 0.62488100E-01, -.26756200E+00, -.55721200E+00, 0.20107300E+01, 0.48223600E+00, 0.10484500E+00, -.16034500E+00, 0.19674500E+00, 0.82515700E+00, -.17964700E+00, 0.36502800E+00, 0.12092400E+01, 0.25467700E+00, 0.34039400E+00, 0.10502200E+01, 0.25278300E+01, -.37286600E+00, -.23580000E+00, 0.13202800E+01, 0.11832800E+01, -.16207100E+00, -.73892500E+00, -.11929400E-01, 0.11056300E+00, 0.74610900E+00, -.11280600E+01, 0.11092800E+01, 0.36965300E+00, 0.59889900E+00, -.27445700E+01, -.35984500E+01, 0.95436600E-01, 0.10318400E+01, 0.30122400E+00, -.50062300E+00, 0.18407100E+01, -.32746900E+00, 0.50093900E+00, 0.27461200E+00, -.24124800E+01, 0.28462800E+00, 0.13277000E+00, 0.10279000E+00, -.29691500E+00, -.27148500E+00, -.38308400E+00, 0.20543800E-01, -.12062300E+01, -.51314300E+00, 0.68538900E+00, 0.44544600E+00, 0.15116700E+00, 0.52514400E+00, -.12971400E+01, 0.11386700E+00, 0.62257400E+01, -.26603900E+01, -.51799300E+00, -.69808900E-01, -.27842200E+00, -.77255500E-01, 0.79125600E+00, -.45173600E+00, -.15832500E+00, -.19295700E+00, -.69835400E+00, -.49597300E+00, -.21340700E+01, -.18159200E+00, -.17877400E+01, 0.85629000E+00, -.80218300E+00, 0.70202100E+00, -.12328700E+01, -.67402700E-01, 0.15118200E+00, 0.41819200E+00, 0.17662600E+00, -.11235000E+01, 0.38633400E-02, 0.81309200E+00, 0.39175900E+00, -.10918600E+00, -.35675900E+00, -.18932500E-01, 0.20608100E+01, -.19559500E+00, -.28328900E+00, -.10448900E+01, -.31210600E+00, -.62521600E-01, 0.65042800E+00, -.10270300E+01, -.33045300E+01, 0.11029100E+00, 0.75880100E+00, -.81733700E+00, -.10155900E+01, 0.46741000E+00, 0.95929500E-01, -.18353600E+00, 0.10191600E+01, -.34505000E+00, 0.22717300E+00, -.12909500E-01, 0.16046800E+01, -.22877700E+00, 0.35504100E+00, -.16745800E+00, 0.93374100E-01, 0.29134400E+00, 0.18249300E+00, -.86538600E-01, -.85094100E-02, -.14883100E+00, -.19999700E+00, 0.24644500E+00, 0.40553000E-01, -.26619400E+00, -.48058300E+00, 0.13393200E+00, -.88467900E-01, 0.73807100E-01, 0.32015100E+00, 0.27298000E+00, 0.10386600E+00, -.38208100E-01, 0.15094500E+00, -.23505100E+00, -.16323300E-02, 0.24300000E+00, 0.19956500E-01, -.27343000E-01, -.38397700E+00, 0.11062300E+00, 0.40860800E+00, -.17451500E-01, 0.16949500E+02, 0.10242900E+02, -.52266500E+01, -.72788100E+01, 0.32174200E+01, 0.37782700E+01, -.70731400E+01, -.24309600E+01, 0.71114700E+01, 0.10322600E+01, -.73858300E+02, 0.36532300E+02, 0.36772600E+02, 0.72371400E+00, -.70751200E+01, 0.23469800E+02, -.17165600E+02, 0.88707600E+01, 0.43868600E+01, -.78493300E+00, -.29662000E+01, -.22080100E+01, 0.18580200E+01, 0.63250700E+00, -.24263800E+01, -.61515200E+01, 0.15469400E+01, -.56237500E+00, -.58168300E+01, 0.13671400E+00, 0.19465800E+01, 0.60898300E+01, 0.69709000E+00, -.26754700E+01, 0.10320800E+01, -.33642000E+00, -.29575300E+01, -.32625800E+00, -.84583300E+01, 0.76986500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.35685800E+01, 0.43107900E+00, -.19580300E+01, -.52215600E+01, 0.22549400E+01, 0.30364000E+02, 0.16423500E+02, 0.40784400E+01, 0.17940100E+01, -.88846600E+00, 0.33485400E+01, 0.28808600E+01, -.15560600E+01, -.29280300E+00, -.21525200E+00, -.11457400E+01, -.47387400E+00, -.69056100E+00, 0.65682300E+00, -.69269000E+00, 0.15788100E+00, -.65206700E+00, -.63002300E+00, -.42259500E+01, 0.79163800E+00, -.15290700E+01, 0.12055700E+01, 0.99345600E+01, -.14259400E+00, -.26404300E+01, -.10577200E+01, 0.37460600E+01, 0.13295800E+01, -.73439400E+00, -.11708200E+00, -.42118800E-01, -.22684600E+00, -.16048100E+00, 0.24661500E+01, 0.33921500E+01, 0.18746700E+02, 0.42471800E+00, -.29969400E+00, 0.24779500E+01, 0.42193500E+00, -.10358400E+01, -.42242100E+00, 0.10262500E+01, 0.87354500E+00, -.31198500E+00, -.41137800E+00, -.15593500E-01, 0.95936500E+00, 0.16442400E+01, -.15578500E+01, 0.75187600E-01, 0.78693900E+00, 0.33419500E+00, -.36249900E+00, -.18020700E+01, -.84116400E+00, 0.98315500E+00, 0.36502700E+00, -.25255400E+01, -.44780600E-01, 0.25692500E+00, -.44637000E+00, 0.16418400E+01, -.12576800E+00, -.19134400E+00, 0.75216500E+00, 0.44076400E+00, 0.15543800E+00, -.50154800E+00, -.52707700E+00, 0.88435900E-01, 0.18387600E+00, -.19530200E+01, 0.53579300E-01, 0.66271500E+01, -.18881000E+01, 0.97794500E+00, 0.12687600E+00, -.40286800E+00, -.39685500E+00, 0.82425200E+00, -.42844600E-01, -.22453800E-01, -.50564300E-01, 0.38107300E-01, -.24795900E+00, 0.12593800E+01, -.83125600E-01, 0.40803900E+01, -.78955700E+00, -.52810600E+00, -.64009700E+00, 0.94540100E+00, 0.19058100E+00, -.34715800E-01, 0.65503100E-02, 0.77538500E+00, -.49113400E+00, -.39478300E+00, 0.10623100E+01, -.64842100E+00, -.31334200E+00, -.51786900E+00, 0.12934600E+00, 0.26124700E+01, -.31748800E+00, 0.31779500E+00, -.49908100E+00, 0.23131500E+00, 0.41991500E+00, -.75143200E-01, 0.13022000E+01, 0.23761100E+00, -.47923600E-01, 0.10779100E+01, 0.67641800E+00, 0.23890300E+00, 0.43990700E+00, -.84841300E-01, 0.11332400E+00, 0.39792900E+00, 0.10416900E+00, -.17780300E-01, -.47088600E+00, 0.47852100E+00, 0.20235400E+00, -.38993700E+00, -.47828000E+00, -.37682000E+00, 0.56767100E+00, -.10890500E-01, 0.90947900E+00, -.42822000E+00, -.18081900E+00, -.11121100E+00, 0.12490800E+00, 0.26858400E+00, -.28770500E+00, -.67380000E+00, 0.27685700E+00, 0.16085600E+00, 0.13233400E+00, 0.40648600E+00, -.46798600E-01, -.50275800E+00, 0.89716800E-01, -.19421100E-01, 0.11335900E+01, 0.95114900E+00, -.56327600E-01, 0.33653500E-01, 0.40777800E+00, -.44548200E+00, -.36772300E+00, 0.23536900E+00, -.32859300E+00, 0.51975800E+00, -.18290800E+03, 0.91523100E+02, 0.92747400E+02, 0.29434900E+02, 0.53560000E+02, 0.31265600E+02, -.45042100E+02, 0.15328600E+02, 0.61321000E+02, -.26831900E+02, 0.13866200E+02, 0.12973100E+02, -.86673900E+01, -.41436700E+02, 0.10827100E+02, 0.32135100E+01, 0.50692700E+02, -.43085500E+02, -.51173400E+00, -.24419100E+02, 0.30306500E+01, 0.55182100E+01, 0.11553600E+02, -.33104900E+01, -.95743400E+00, 0.15582100E+00, -.48383100E+01, 0.66766800E+01, -.57762000E+01, 0.37198000E+01, -.66743200E+01, 0.84872100E+00, 0.68081100E+01, -.24647200E+01, -.70438500E+00, -.24947600E+02, -.46830700E+01, 0.10659100E+02, 0.90883200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.20596300E+01, 0.52297700E+00, 0.11171300E+01, 0.37271600E+01, -.12890400E+01, -.17875400E+02, 0.27704200E+01, -.33798600E+00, -.94064600E+00, 0.11853700E+01, -.22480900E+01, -.21390000E+01, 0.94881400E+00, -.38211600E+00, 0.55181800E+00, 0.65261500E+00, 0.41444600E+00, 0.80470600E+00, -.60066000E+00, 0.65375600E+00, -.10790200E-01, 0.66870400E+00, 0.26683700E+00, 0.22842000E+01, -.42104000E+00, 0.81417500E+00, 0.77386200E-01, -.81880700E+01, -.77961400E-01, 0.17710400E+01, 0.77305200E+00, -.13335900E+01, -.11124300E+01, 0.41448200E+00, 0.28995700E+00, 0.36761500E+00, -.59870500E+00, -.29455800E+00, -.17976800E+00, -.13393600E+01, -.39540900E+01, 0.10702600E+00, -.70318900E+00, 0.14701400E+00, 0.29647900E+00, 0.26475100E+00, 0.42777500E+00, -.13272300E+00, -.70487500E+00, 0.15295800E+00, -.13308600E+01, -.39917200E-01, -.46787200E+00, 0.64142100E+00, 0.51049700E+00, 0.12714600E-01, -.14237500E+00, -.53816600E+00, 0.19438000E+00, -.39096100E+00, 0.33138600E+00, -.95335200E-01, 0.23729000E+00, 0.12857800E+00, 0.42149400E+00, 0.58453100E+00, -.38605000E+00, -.50178600E+00, 0.28941000E+00, 0.36408300E+00, 0.63244900E+00, 0.33206700E+00, -.22664400E+00, 0.34781100E+00, 0.12807700E+00, -.14164100E+00, 0.33374700E+00, 0.14674900E-01, -.16549700E+00, -.73098600E+00, -.24402900E+00, 0.24832100E+00, -.54687800E+00, -.10683700E+00, -.13195000E+00, -.14576600E+00, -.12014800E+00, -.76004000E+00, 0.13877700E+00, -.61057500E-01, -.34492100E+00, -.25523800E+01, -.23946100E+00, -.11941000E+01, 0.33046600E+00, -.32812000E+00, 0.69740800E+00, -.32993900E-02, -.33624400E+00, -.31492500E+00, -.28420300E+00, -.12487000E+00, 0.43667900E+00, 0.22519900E+00, 0.97262300E+00, 0.11049900E+00, 0.19880600E+00, -.13782900E+00, -.46648100E-01, 0.30699600E+01, -.27896700E+00, -.74833600E-02, -.92056200E+00, 0.28390100E+00, -.10216300E+00, 0.56224900E+00, -.56293500E+00, -.85466800E+00, 0.94518500E-01, 0.11098000E+01, 0.50697700E+00, -.62554800E+00, -.44361500E+00, 0.99165600E-01, -.15693400E+00, 0.91179700E+00, -.52780200E+00, 0.16823200E+00, 0.15888900E+00, 0.21141000E+00, 0.29748700E+00, 0.46126500E+00, 0.20916300E+00, -.17498000E+00, 0.16208300E+00, 0.63479600E-01, 0.37718700E+00, 0.91213500E-01, 0.67658900E-01, 0.33791000E+00, -.35906100E+00, -.80167700E-01, 0.22923700E+00, 0.19440600E+00, -.23592100E-01, 0.15883300E+00, 0.69745200E-01, 0.74782000E-01, -.53295200E-01, 0.27543400E-01, -.15700100E-01, 0.17459600E+00, -.44975500E+00, 0.13508600E+00, 0.16322400E+00, 0.66839000E-04, -.38200400E-01, 0.32349600E+00, 0.12443100E+00, 0.71167200E-02, 0.58244100E-01, -.33521200E+00, -.15420200E+00, 0.10396900E+01, 0.26379600E+01, -.70339400E+01, -.14884000E+01, -.80368200E-01, 0.68290000E+01, 0.21519100E+02, -.29036100E+01, -.28355100E+02, 0.14020400E+02, 0.14001200E+02, 0.52511400E+01, 0.26096200E+01, 0.62526900E+01, -.93450700E+01, -.19725000E+02, 0.63713100E+01, -.54846800E+01, 0.92572400E+01, -.36521400E+01, -.27627700E+01, -.22327900E+01, -.29069600E+01, -.32375100E+01, 0.22271000E+00, -.44122700E+01, 0.17361900E+01, 0.30855300E+01, 0.28253900E+01, -.18021400E+01, 0.55940700E+00, 0.47453600E+01, -.42704900E+00, -.55452300E+00, 0.91972900E+01, -.43254600E+01, 0.41531600E+01, -.21226500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.75514200E+01, -.38974200E+01, 0.58534000E+01, 0.89896700E+01, -.43152500E+01, -.36592300E+02, -.11532700E+02, -.52246500E+01, -.21905700E+01, 0.31845300E+00, -.14696200E+01, -.48389900E+01, 0.24817100E+01, 0.69638600E+00, -.53161000E+00, 0.37076700E+01, 0.80791100E+00, 0.15440400E+00, 0.96486200E+00, 0.72957000E+00, 0.88332100E-01, -.86541500E+00, 0.26501900E+00, 0.28936000E+01, -.48025100E+00, 0.49769500E+00, 0.83517000E+00, -.67963500E+01, 0.10440500E-01, -.77390600E+00, 0.15689000E+00, 0.10642400E+00, -.45043100E+00, 0.25456300E+00, -.95710700E+00, -.10004800E+01, 0.20775400E+00, -.31209000E-01, -.14035200E+01, -.20236500E+01, 0.19084300E+00, -.49793900E-01, -.18935700E+00, -.94695400E+00, 0.18199700E+00, 0.75069600E+00, -.12707500E+00, -.10670800E+00, -.17538500E+01, 0.87233700E+00, -.77033900E+00, -.53802500E+00, -.10884000E+01, 0.39489300E+01, 0.64122800E+01, 0.47922900E-01, -.79967700E+00, -.34760000E+00, 0.58193500E+00, -.13371000E+01, 0.53256200E+00, 0.31208400E+00, 0.24588200E+00, 0.48371400E+00, 0.36607600E-01, -.38980300E+00, -.50922700E+00, 0.15993300E+01, 0.84581000E+00, 0.53798600E+00, -.45419000E+00, 0.55783400E+00, 0.69233100E+00, -.22875300E+01, -.57730000E+00, -.14623000E+00, -.36503700E+00, -.38130900E+00, 0.26235800E+00, 0.84385500E+00, 0.14961000E+00, -.10060900E+01, 0.60112100E+00, 0.16295200E+00, 0.78106600E-01, 0.47126100E+00, 0.46183600E+00, 0.67601300E+00, 0.62367400E+00, 0.40560700E+00, 0.41467700E+00, 0.61294200E+00, 0.26022000E+00, 0.27381200E+01, -.24315200E+00, -.12187100E+00, -.56231000E+00, -.53696200E+00, 0.56166100E+00, 0.16061600E+00, -.17698200E+00, 0.17511500E+01, -.82963600E-01, -.15009000E+00, -.34333500E+01, 0.44822300E+00, -.32304900E+00, 0.12097000E+00, -.10168400E+00, -.50630900E+01, 0.12070200E+01, 0.13898800E+00, 0.19712100E+01, -.25172900E+00, 0.42747800E+00, -.16718900E+01, 0.11322700E+01, 0.81386100E-01, -.23542100E+00, -.11673700E+01, 0.10297100E+01, -.15281200E+00, -.12155500E+01, -.21880200E+00, 0.41264400E+00, -.83113600E+00, -.30864600E+00, -.92920900E-01, 0.30646700E+00, -.46744500E+00, -.26436500E+00, -.18680700E+00, -.45844000E+00, 0.10659600E+00, -.60942400E-01, 0.69245400E+00, 0.13223700E-01, 0.49374200E+00, -.14369000E+00, 0.25281200E+00, -.83698700E+00, 0.33226200E+00, -.30643600E-01, -.28142400E+00, 0.39454200E+00, -.58283600E+00, 0.27969000E+00, 0.96971000E-01, -.90704500E+00, 0.49442000E+00, -.52750300E-01, -.19738400E+00, -.20538700E+01, -.10234700E+01, -.32561700E+00, 0.10740100E-01, -.23499500E+00, 0.46394900E-01, -.81188400E-01, -.89860800E+00, 0.36578800E-01, 0.69172800E+00, 0.24934700E+00, 0.45593800E+00, -.17667900E+02, -.16955300E+02, -.20683800E+02, 0.33404000E+02, -.13143000E+01, -.15915200E+02, -.28222500E+01, 0.71955400E+02, -.35352900E+02, -.36982900E+02, -.13630100E+02, -.28062700E+02, -.62102300E+01, 0.40974600E+02, 0.40682000E+02, -.43855900E+02, 0.10384900E+02, -.22090800E+02, 0.76484200E+01, 0.17391800E+01, 0.13332800E+01, 0.10092000E+02, -.67144700E+02, 0.36397100E+01, 0.30311400E+02, 0.14613400E+02, -.56845800E+01, -.72828300E+01, -.15011500E+02, 0.25809200E+01, -.31225500E+02, 0.19577300E+00, -.39247300E+00, -.21905000E+02, 0.29395400E+02, 0.61677800E+01, -.22526400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.13821300E+02, 0.11756900E+01, 0.84106800E+01, 0.14273100E+02, -.58847700E+01, -.70992800E+02, -.20474400E+02, -.95087500E+01, -.42665400E+01, 0.12731500E+01, -.47524000E+00, -.62373800E+01, 0.42830800E+01, 0.18287900E+01, -.58341800E+00, 0.49467300E+01, 0.10178900E+01, 0.75140700E+00, 0.17971300E+01, 0.34048700E-01, -.73592100E+00, -.32400200E+00, 0.94624400E+00, 0.10876100E+02, -.27967900E+01, 0.31573400E+01, -.34921700E-01, -.32736800E+02, -.59334800E+00, -.24880300E+01, 0.32552800E+00, -.13898900E+01, 0.46848800E+00, 0.47934500E+00, 0.43689200E+00, -.11177100E+01, 0.51535400E+00, -.13544600E+01, -.43699000E+01, -.96755500E+01, -.17596200E+02, 0.27834700E+00, 0.14235900E+01, -.36692500E+01, -.10281900E+01, 0.20848300E+01, 0.40782900E+00, -.17051300E+01, -.32566100E+01, 0.12475300E+01, -.17838100E+01, -.72198400E-01, -.22035600E+01, 0.38145300E+01, 0.77165300E+01, -.39939200E+00, -.82616800E+00, -.61758000E+00, 0.10426200E+01, 0.26244600E+01, 0.80393100E+00, -.15282500E+01, -.29436500E+00, 0.88222000E+01, 0.14108400E+01, 0.33338300E+00, 0.40581000E+00, 0.97629600E+00, 0.24909800E+01, -.15749300E+01, -.14375700E+01, -.96074200E+00, 0.53828300E+00, 0.39932400E+01, -.37462600E+00, -.84453000E+00, 0.11147100E+01, -.15850200E+01, -.32666200E+01, -.12506000E+02, 0.22731600E+01, 0.13848800E+01, 0.20908700E+01, -.17495700E+00, 0.55936200E+00, -.15876400E+01, -.15094700E+01, -.31645300E+00, -.33590200E-01, -.93327700E+00, 0.28272000E+00, -.27729100E+01, 0.10586300E+00, -.31438000E+01, 0.11471800E+01, -.57054500E+00, 0.44644600E+00, 0.31214600E-01, 0.17409000E-01, 0.43944500E+00, -.83050300E-01, -.14415600E+01, 0.38617200E+00, 0.19783500E+01, 0.48233300E+00, 0.63096900E+00, 0.55298000E+00, 0.14744300E+00, -.82153900E+00, -.13013800E+00, -.46486900E-01, -.71791800E-01, -.34920300E+00, -.19156700E+00, -.30749700E+00, -.20254300E+00, -.92891300E+00, -.27597600E+01, 0.18264300E+00, 0.69040900E+00, 0.12246700E+01, -.98758900E+00, 0.11190800E+01, 0.14881200E+00, 0.10250900E+00, 0.17183300E+00, 0.75357600E+00, -.10309800E+01, -.33188600E+00, 0.95664200E-01, -.92005700E-01, -.29090700E+00, -.39411200E+00, 0.74861800E+00, 0.68837400E-01, -.11576900E+01, -.12573400E+01, -.94053700E+00, -.49913200E+00, -.13190400E+01, 0.20751700E+01, 0.18707700E+00, -.10570100E+01, 0.46688300E+00, 0.13819300E+01, -.58225800E+00, 0.44385300E+00, 0.94445600E+00, 0.10939400E+00, -.45468700E+00, 0.28606100E-01, -.12161400E+00, 0.13938600E+01, 0.77599400E+00, -.48640100E+00, -.30153600E+00, 0.58433800E+00, 0.37375300E+00, -.38261700E+00, 0.42293200E+00, 0.11309800E+00, 0.97832800E+00, 0.11283000E+01, -.53769900E+00, 0.62027500E+00, 0.60309500E+02, 0.60682600E+02, -.59685700E+02, 0.90950000E+01, -.14552900E+02, 0.37716500E+02, -.18680100E+03, 0.91846500E+02, 0.94173800E+02, 0.13136000E+02, 0.84093100E+02, 0.24028400E+02, -.11068600E+03, -.59377800E+02, 0.99472300E+02, -.82718200E+01, 0.58350600E+02, -.13565400E+02, -.11275800E+01, -.63277500E+01, -.63354000E+00, 0.39508200E+02, 0.10935000E+01, -.28826000E+01, -.51934400E+02, 0.51239900E+01, -.32842400E+01, 0.52594300E+02, 0.40914600E+00, 0.19220400E+01, 0.77247700E+01, -.29115100E+01, 0.58766600E+02, -.22093800E+01, -.27555100E+02, -.35377600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10527000E+02, 0.58837200E+01, -.87974200E+01, -.16531600E+02, 0.74673600E+01, 0.49839000E+02, 0.74600000E+01, 0.58562900E+01, 0.28650300E+01, -.12182600E+01, 0.67832400E+01, 0.11430700E+02, -.21789300E+01, -.24092900E+01, 0.29015000E+01, -.89362700E+01, -.15037500E+01, -.20777300E+01, -.97417300E+00, -.24854400E+01, 0.26972600E+00, -.80270200E-01, -.43800200E+00, -.25582400E+01, -.23441700E+00, -.80064000E+00, -.12575600E+00, 0.25771200E+01, -.78879700E+00, -.31506700E+01, -.10097600E+01, 0.16685200E+01, -.25864200E+00, -.12071900E+01, -.72156200E+00, -.62242600E+00, -.19555800E+00, 0.44182400E+00, 0.27822400E+01, 0.26071700E+00, 0.21014300E+02, 0.10260500E+01, -.21490900E+01, 0.28368900E+01, 0.50874900E+00, -.21597500E+01, 0.74621500E+00, 0.18626100E+01, 0.13197200E+01, -.15503000E+01, -.13615600E+01, -.14994300E+01, 0.12302200E+01, 0.59519900E+00, -.48804200E+01, 0.16158300E+00, 0.17856400E+01, -.97769000E+00, 0.43665400E+00, 0.43648300E+01, -.23331300E+01, 0.25967200E+01, -.81369100E+00, 0.40527900E+01, -.13182000E+01, -.40417600E+01, 0.92708000E+00, -.14954500E+01, -.53303700E+00, 0.73408800E+00, 0.10360900E+01, 0.58382000E+00, 0.17877600E+00, -.14144900E+01, 0.88625900E-01, 0.43267600E+00, -.54833200E+00, 0.53796900E+00, 0.11365900E+01, -.11152300E+01, 0.56907800E+00, 0.27332400E+00, -.15900000E+00, 0.83865200E+00, -.12298400E+01, 0.62118900E+00, 0.10923300E+01, 0.14742800E+01, -.20461700E-01, 0.89029000E-01, -.27956200E+00, 0.75433800E+01, 0.40144300E+00, 0.14070400E+02, -.22797800E+01, -.14546500E+01, -.98261800E+00, -.30901500E+01, 0.11932800E+01, 0.15355700E+01, -.57333600E-01, 0.31797300E+00, -.10988900E+01, 0.16266000E+01, -.55471900E+01, -.58648300E+00, -.26139400E+00, 0.98338200E+00, 0.92265600E-01, 0.62063200E+00, 0.16251200E+01, 0.83059300E+00, 0.13813200E+01, -.27679900E+00, 0.96681200E+00, -.38752800E+00, 0.29714000E+00, 0.58795800E+00, -.61452000E-01, -.25776900E+01, 0.83659600E+00, 0.12866400E+01, -.37338900E+01, -.47954900E+00, 0.11716100E+01, -.16778900E+01, 0.94367000E+00, 0.71127600E+00, 0.32156900E+00, 0.23246300E+00, -.12197000E+01, 0.22443800E+00, -.16432700E+01, 0.17683600E+00, -.32021900E+00, 0.25394500E+01, -.20655100E+01, 0.30080500E+00, -.18020700E+00, 0.31869200E+00, -.53514100E+00, 0.20051200E+00, -.95147400E+00, -.10633700E+01, -.13382900E+01, 0.66498800E+00, 0.15835200E+00, 0.87059000E+00, 0.66366200E+00, 0.62283600E-01, 0.86894300E+00, 0.58910900E+00, -.44279300E+00, 0.96580300E+00, 0.62721600E+00, 0.98294600E-01, 0.59220900E+00, 0.13794300E+01, 0.29701100E+00, 0.50009800E+00, 0.32372200E-01, -.25358800E+00, -.81010500E+00, -.60085700E+00, -.67704500E+00, -.19413900E+00, 0.29345600E+02, 0.13378500E+02, 0.42315700E+02, 0.75816300E+02, 0.29818700E+02, -.35265600E+03, 0.17462200E+03, 0.17500500E+03, 0.48920300E+02, 0.45364600E+02, 0.74638400E+02, -.10953900E+03, -.70870800E+02, 0.52248100E+02, -.30156300E+02, 0.85004600E+02, -.21165800E+02, -.13848200E+02, -.18178800E+02, -.15283100E+02, -.38058400E+02, 0.84929800E+01, 0.21905300E+02, -.24771400E+02, 0.13484500E+02, 0.15568900E+02, 0.24067400E+02, 0.91144200E+01, -.22809400E+02, 0.54808600E+01, -.88378800E+01, 0.84830900E+02, 0.23355100E+02, -.86073500E+01, -.27307500E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.41355700E+01, -.81255900E-01, -.22545700E+01, -.74917600E+01, 0.26165200E+01, 0.35675600E+02, -.59416700E+01, 0.82024500E+00, 0.18583200E+01, -.23658600E+01, 0.41556800E+01, 0.42243600E+01, -.19115000E+01, 0.75936900E+00, -.10660000E+01, -.13261700E+01, -.83461500E+00, -.16117000E+01, 0.12580200E+01, -.17642500E+01, 0.39099200E-01, -.16714100E+01, -.46988800E+00, -.46129500E+01, 0.83926500E+00, -.16995200E+01, -.13045900E+00, 0.18952400E+02, -.51245100E-02, -.35605100E+01, -.17066700E+01, 0.26004900E+01, 0.21989800E+01, -.80548000E+00, -.63348700E+00, -.62176000E+00, 0.12600300E+01, 0.81449800E+00, 0.52922400E+00, 0.25845100E+01, 0.76798200E+01, -.23742100E+00, 0.16034000E+01, -.14067000E+00, -.52323200E+00, -.53338100E+00, -.10536200E+01, 0.31010800E+00, 0.14572500E+01, -.36381200E+00, 0.24785300E+01, -.76375400E-02, 0.95934200E+00, -.15216500E+01, -.10816200E+01, -.11970900E+00, 0.30097300E+00, 0.11442500E+01, -.42377500E+00, 0.55383000E+00, -.34960600E+00, 0.15784000E+00, -.46216200E+00, -.81730000E+00, -.96939500E+00, -.13453900E+01, 0.77810800E+00, 0.10016100E+01, -.68211500E+00, -.66350800E+00, -.12377600E+01, -.63517100E+00, 0.42374700E+00, -.85374200E+00, -.28061200E+00, 0.32821200E+00, -.68023500E+00, 0.57841700E-01, 0.29002200E+00, 0.19783900E+01, 0.39207100E+00, -.50938000E+00, 0.73506000E+00, 0.33665800E+00, 0.30629100E+00, 0.28259500E+00, 0.13716200E-01, 0.13678300E+01, -.25075600E+00, -.99589700E-01, 0.61344200E+00, 0.46585800E+01, 0.38805500E+00, 0.17253100E+01, -.43219100E+00, 0.58133600E+00, -.12456100E+01, 0.50623200E-01, 0.62311300E+00, 0.56762900E+00, 0.56517400E+00, 0.13261400E+00, -.85142800E+00, -.41833400E+00, -.13941100E+01, -.21118000E+00, -.38201100E+00, 0.24752400E+00, 0.16696700E+00, -.56997300E+01, 0.46231300E+00, 0.70323600E-01, 0.17211900E+01, -.64815300E+00, 0.17992700E+00, -.88448100E+00, 0.91145800E+00, 0.15707300E+01, -.12336200E+00, -.21000100E+01, -.12198200E+01, 0.10506200E+01, 0.83816300E+00, -.18253000E+00, 0.26540700E+00, -.16262000E+01, 0.88227400E+00, -.27287100E+00, -.19291000E+00, -.42520600E+00, -.57449300E+00, -.68184000E+00, -.50011300E+00, 0.42413500E+00, -.34481300E+00, -.21601700E+00, -.10784500E+01, -.86919700E-01, -.21587700E+00, -.84839900E+00, 0.80795500E+00, 0.11620500E+00, -.34763800E+00, -.51913600E+00, -.15997400E-01, -.72204800E+00, -.76871300E-01, -.35647400E+00, -.31260200E+00, -.10856700E+00, -.83614000E-01, -.19094400E+00, 0.97760900E+00, -.47173200E+00, -.32066600E+00, 0.62234600E-01, -.93390300E-01, -.50825200E+00, -.25197000E+00, -.15833600E+00, -.46009700E-01, 0.39749600E+00, 0.13534800E+00, 0.83321500E+00, 0.28165900E+00, 0.30909200E+00, -.43471800E+00, 0.20162000E+02, -.52679700E+01, -.30534500E+02, 0.73197400E+01, -.46811600E+02, 0.23494800E+02, 0.23306500E+02, 0.10683600E+02, -.15115200E+01, 0.13100200E+02, 0.10116300E+02, 0.47384500E+02, -.86609800E+01, 0.26862800E+01, 0.15468400E+01, 0.15772600E+01, 0.21742200E+01, -.20158000E+01, -.19420900E+01, 0.32927800E+00, -.40809200E+00, 0.85031000E+01, 0.11386700E+01, -.33612900E+01, 0.25668000E+01, -.12960200E+01, -.57461900E+00, -.96631500E+01, -.14725700E+01, 0.10052500E+01, 0.11583300E+01, 0.89956900E+01, -.76078400E+01, -.12140000E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.26102000E+02, -.41793800E+01, 0.16834900E+02, 0.29032800E+02, -.14286700E+02, -.12691500E+03, -.24469800E+01, -.23405900E+02, -.73440200E+01, 0.29491500E+01, 0.24071600E+01, -.10736200E+02, 0.10370200E+02, 0.25736100E+01, -.15972800E+01, 0.10877800E+02, 0.23116200E+01, 0.31530700E+01, 0.37609000E+00, 0.29564300E+01, -.27024500E+01, 0.47715600E+01, 0.19917900E+01, 0.94548400E+01, 0.11092500E+01, 0.13426300E+01, 0.73923800E+00, -.66336100E+02, -.28574200E+01, 0.37559300E+01, 0.87123400E+00, 0.41627300E+00, -.15337400E+01, -.79263900E+00, 0.62103100E+01, -.51972800E+01, -.47195500E+01, -.52481500E+00, -.21364000E+01, -.68004100E+01, 0.21027300E+02, 0.23135200E+01, -.51643100E+01, -.59188200E+01, 0.34855800E+00, 0.31381100E+00, 0.36007800E+01, 0.21626500E+00, -.34102100E+01, 0.64388400E+01, -.13002200E+01, 0.12967000E+01, 0.48572800E+00, 0.65039200E+01, -.99048200E+01, 0.29143100E+01, -.37030600E+01, -.59787100E+01, 0.21895600E+01, -.28990700E+01, -.21933100E+01, -.18989700E+01, -.74441700E-01, 0.19402900E+01, 0.63882000E+00, 0.21004400E+01, 0.42354900E+00, 0.25992500E+01, 0.76223400E+00, -.59193500E+00, 0.49137500E+00, -.15515500E+01, -.13310000E+01, 0.67598400E+01, 0.11804600E+01, 0.11418900E+01, -.22650800E+01, -.90876400E+00, 0.18507000E+01, -.21127000E+02, 0.40047500E+01, 0.97829800E+00, 0.85371100E+01, -.19245900E+01, 0.19675000E+01, -.27840000E+01, 0.16964600E+01, 0.89679100E+00, -.52411500E+00, 0.53983200E+00, 0.17744100E+00, -.41202000E+00, -.81777000E+00, 0.17802500E+01, -.16020000E+01, 0.27786900E+01, -.26227400E+01, 0.58189600E+01, -.47908700E+00, 0.68654700E+00, -.46218400E+00, -.49960900E+01, 0.47725600E+01, 0.13468300E+01, 0.91399900E+01, -.13064300E+01, 0.13902200E+01, -.10042100E+01, -.15555500E+01, 0.19349700E+01, -.38962200E+00, 0.24236800E+00, 0.28807000E+00, 0.62611900E+00, 0.27635500E+00, -.83390200E+00, 0.22166800E+01, 0.75383100E+01, -.11562800E+00, -.15338700E+01, -.22672500E+00, 0.27047600E+01, 0.15156600E+01, -.57234800E+00, -.26013000E+00, -.22922500E+01, 0.59655800E+00, 0.68348500E+00, 0.37156400E+00, -.20292400E+01, 0.11986000E+00, 0.24051400E+01, -.10671400E+01, 0.42224200E+00, 0.78036300E+00, -.30016800E+01, 0.36941900E+01, -.85747900E+00, 0.10621800E+01, -.77884200E+00, -.18016500E+01, -.87297400E+00, 0.12422000E+01, -.28351100E+01, -.10120400E+01, -.19925800E+00, -.83404100E+00, -.10561600E+01, -.43462200E+00, -.16651300E+01, -.81239100E-01, -.72788800E+00, 0.34482600E+01, 0.44825300E+00, -.53568400E+00, -.40145400E+00, 0.82857900E+00, -.22285900E+01, -.81626100E+00, 0.73418200E+00, -.19015700E+00, -.15240600E+00, 0.21749000E+01, -.33956300E+00, 0.40856800E+00, -.23931800E+00, -.51387700E+00, 0.87191600E+00, 0.60181300E+02, -.21117500E+02, -.11803200E+02, 0.22466200E+03, -.11281200E+03, -.10943200E+03, -.58547300E+01, 0.85323200E+02, -.12658400E+03, -.12850800E+03, -.26699600E+03, 0.58390700E+02, -.16854200E+02, 0.12944300E+03, -.30500500E+02, -.94915000E+01, -.20512600E+02, 0.45146700E+01, 0.58958800E+02, -.14053500E+01, 0.16751600E+01, -.42791100E+02, 0.83026000E+01, -.78557600E+01, 0.42914800E+02, 0.51542200E+00, -.46781900E+01, 0.27335700E+01, -.29749700E+01, 0.13225500E+03, 0.57747700E+01, 0.46284900E+02, -.40327600E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.72447200E+01, 0.45128300E+01, 0.46429700E+01, 0.56086300E+01, -.34081600E+01, -.29182000E+02, -.13679500E+02, -.10337000E+02, -.18933100E+01, -.57124200E+00, 0.24164000E+01, -.71107300E-01, 0.21191900E+01, 0.26594000E+00, -.94409300E-01, 0.24308000E+01, 0.58960700E+00, -.25165800E+00, 0.26165900E+01, -.21372900E+01, -.21705700E+00, -.20683200E+01, 0.75807800E-01, 0.32800500E+01, -.12372900E+01, 0.66891900E-02, 0.11679700E+01, -.52695900E+01, -.73892000E+00, -.48596200E+01, -.10825200E+01, 0.24540500E+01, 0.15116100E+01, -.48489400E+00, 0.81625000E+00, -.38412800E+00, -.45296900E+00, -.15822000E+01, -.52211900E+00, -.72081400E+00, -.19161100E+01, 0.33813300E+00, -.96833900E+00, -.27199800E+01, -.70455400E+00, 0.83872400E+00, 0.10787500E+01, -.52253300E+00, 0.82170100E+00, 0.19286200E+01, 0.19055900E+01, 0.12694700E+01, -.11396000E+00, 0.22583900E+01, -.71771500E+00, 0.26223400E+00, -.16198300E+01, 0.36713100E+00, -.40900700E+00, 0.26667700E+00, -.11357000E+00, -.31957500E+00, 0.20303400E+00, 0.23020100E+00, 0.11099600E+00, 0.65764400E+00, -.26543300E+00, -.53882000E+00, 0.47159600E+00, 0.15305100E+00, 0.15271700E+01, 0.19403100E+00, 0.22862800E+00, -.65639600E+00, 0.21382100E-01, -.23906500E+00, 0.10535400E-01, -.13683600E+01, 0.85147100E+00, -.82887800E+01, 0.11570500E+01, 0.15605900E+01, 0.55371800E+00, -.61319000E+00, -.27574600E+00, -.84109100E+00, 0.18339400E+00, 0.12293700E+00, -.42469200E+00, -.81608100E-01, -.35784800E+00, -.30179200E+01, 0.82700700E-01, -.25812200E+01, 0.60588500E+00, 0.11438500E+01, 0.12281000E+00, 0.12087100E+00, 0.48470900E-01, 0.15144800E-02, 0.25155400E-01, 0.46719900E+00, 0.88362300E-01, -.11849300E+01, 0.28644700E+01, -.46709700E+00, -.13690500E+00, -.43336000E+00, 0.25248900E+00, -.18975800E+01, 0.16807500E-01, 0.26047400E+00, 0.48765800E+00, 0.59540600E-02, 0.21089200E-01, -.54353900E+00, 0.74326900E+00, -.95876200E+00, -.85656900E-01, 0.80801100E-02, -.86633700E+00, 0.26118200E-02, 0.11358900E+01, 0.82745900E-01, -.15931100E+00, 0.39081200E+00, -.55885900E+00, 0.37933600E-01, 0.71975400E-01, 0.94601400E-01, -.83690800E-01, -.69431000E+00, 0.20277300E-01, -.41969200E-01, -.97019900E-01, -.98246900E-01, -.16952200E+00, -.28448800E+00, -.48008400E-01, -.30686900E+00, 0.70133400E+00, 0.10010700E+00, -.18895500E+00, -.11632000E+00, 0.77407300E+00, -.41712700E+00, 0.58227500E-01, -.14339100E+00, -.10278600E+00, 0.92784300E-01, 0.21986100E+00, -.20072100E+00, 0.54906600E+00, 0.21458200E+00, -.20711100E+00, 0.31931300E-01, -.19194000E-01, 0.34867900E+00, -.35311100E-01, 0.19149900E+00, 0.17441900E+00, -.47132700E-01, 0.51748800E-01, -.23433800E+00, -.16392300E+00, -.14240700E-01, 0.24060600E+00, -.12860700E+00, -.68603500E-01, -.44801600E+02, -.14395900E+01, 0.69663900E+02, -.33226800E+02, -.34385300E+02, -.34364200E+01, 0.13755000E+02, -.32221900E+02, -.91099300E+01, -.50772900E+02, 0.11126500E+02, -.32053500E+01, 0.21807200E+02, -.90314800E+01, -.24301900E+01, -.85219700E+01, -.10266500E+01, 0.92688100E+01, -.85464800E+00, -.10901400E+01, 0.22177400E+01, 0.29418000E+01, -.49671100E+00, -.19031200E+01, -.47760800E+00, -.63905000E+00, 0.21999900E+00, 0.51413800E+00, 0.22118400E+02, -.72680700E-01, 0.24077500E+00, -.97485300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.65799300E+01, 0.12868300E+01, -.35922200E+01, -.66883000E+01, 0.25974100E+01, 0.34421900E+02, 0.37858300E+01, 0.54160000E+01, 0.19535200E+01, -.63806300E+00, -.79719300E+01, 0.17826600E+01, -.22921500E+01, -.73112300E+00, 0.27460400E+00, -.17931500E+01, -.52479500E+00, -.25281300E+00, -.91439500E+00, -.54328900E+00, 0.34909400E+00, -.46211200E-01, -.64246700E+00, -.21206800E+01, 0.76897200E+00, -.69402700E+00, -.10237800E+01, 0.15523200E+01, -.85428100E+00, 0.21598800E+01, -.44055800E+00, -.20062500E+01, -.60097200E+00, -.23734700E-03, -.88320300E+00, 0.37676700E+00, 0.87771300E+00, 0.11838700E+01, 0.47835100E+00, -.10045000E+01, -.10455500E+01, -.28125400E+00, 0.72073300E+00, 0.16387500E+01, 0.12589400E+00, -.77402900E+00, -.75318900E+00, 0.29524800E+00, 0.10890900E-01, -.11586300E+01, -.11919200E+01, -.86381400E+00, 0.32615600E+00, -.54433400E+00, -.90800800E+00, -.23664500E-01, 0.56334600E+00, -.43514000E+00, 0.24011800E+00, 0.12169300E+01, 0.94133200E+00, -.10841300E+00, -.11330500E+00, 0.21536800E+01, -.40473700E+00, -.14323700E+01, 0.29526200E+00, 0.25738400E+01, 0.43102000E+00, -.86923300E+00, 0.32571100E-03, -.43649500E+00, 0.22278500E+00, 0.50770300E+00, -.29346900E+00, -.75117000E-01, -.89209400E-01, -.13612100E+01, -.12711000E+00, -.15033900E+01, -.29828700E+00, 0.13665500E+01, 0.60558300E-01, -.36378400E+00, 0.11244800E+00, -.12754000E+00, -.16811500E+01, -.46657000E+00, 0.86998200E-01, -.77930200E+00, -.10349200E+00, -.43153900E+01, 0.47976700E-01, -.11622700E+01, 0.16675300E+01, -.53029000E-01, 0.75959200E+00, -.28014700E+00, 0.10288900E+00, 0.57896600E+00, 0.98341000E-01, 0.66563000E+00, 0.34669900E+00, 0.97019000E+00, -.23567800E+01, -.34772800E+00, -.30516300E-01, 0.34724600E-01, -.64913300E+00, 0.46386000E+00, 0.26823800E+00, -.54154200E+00, -.80027100E+00, 0.58686300E+00, -.45983900E+00, -.10000300E+01, 0.52448400E+00, -.18982500E+01, 0.46846700E+00, -.12862200E+00, 0.65695900E+00, 0.90112800E+00, 0.69370900E+00, 0.53511500E-02, -.20924500E+00, -.43423200E+00, 0.18396000E-01, -.15728800E+00, 0.75117200E+00, -.22653800E+00, -.20374100E-02, -.23280500E+00, -.31605100E-01, 0.10217400E+01, -.41539800E+00, -.41373300E+00, -.19863400E+00, -.26225100E+00, -.93856000E-01, -.16076600E-01, 0.14895700E+01, -.91722400E-01, -.10010700E+00, 0.41415200E+00, -.13021900E+00, -.82238000E-01, -.18143600E+00, -.36204700E+00, 0.40059700E-01, 0.56890800E+00, -.31209500E+00, 0.35714700E+00, -.32331900E+01, 0.67088700E-01, 0.21461200E+00, -.12494600E+00, -.52720100E-01, -.72520900E+00, 0.38443400E+00, 0.43641600E+00, 0.65792300E-01, -.13161000E+00, 0.58896700E-02, 0.79299700E+00, -.32847900E+00, -.20384400E+00, 0.24283400E+00, -.39533200E+00, -.26309600E-01, 0.35458100E+00, 0.80631800E+01, 0.57435900E+02, -.27442700E+02, -.28696800E+02, -.66575500E+01, -.63540700E+02, -.30367700E+01, 0.16554600E+02, 0.10938300E+03, -.72489400E+02, 0.18822000E+02, -.40829400E+02, 0.21395600E+02, 0.12485700E+02, 0.26009100E+02, 0.17078000E+02, -.46596800E+02, -.93189600E+00, -.28437300E+01, -.40788800E+02, -.14957500E+02, -.13971100E+02, 0.41283100E+02, -.34563500E+01, 0.41790400E+01, -.40818100E+01, 0.50086800E+01, -.41773600E+02, -.51991700E+01, 0.45568400E+01, 0.10466200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.17959200E+02, -.88896700E+01, 0.97676600E+01, 0.17776800E+02, -.66010900E+01, -.88958900E+02, -.32265500E+01, -.19965600E+02, -.47721500E+01, 0.22743900E+01, 0.10166100E+02, -.30144600E+01, 0.75378100E+01, 0.11628900E+01, 0.15181100E+00, 0.52098400E+01, 0.13219900E+01, -.14211300E+00, 0.26581100E+01, 0.11904500E+01, -.13268200E+01, 0.13444300E+00, 0.12247000E+01, 0.66897200E+01, -.47019800E+00, 0.30857200E+00, 0.62872100E+00, -.36340500E+02, -.15781600E+01, -.55621300E+01, 0.23290000E+00, 0.38971500E+01, 0.17575600E+00, -.63750900E+00, 0.29653900E+01, -.25023400E+01, -.24812200E+01, -.21375900E+01, -.88586800E+00, -.33175900E+01, 0.13647300E+02, 0.14350600E+01, -.23674700E+01, -.54835800E+01, -.46285900E+00, 0.24791000E+01, 0.25919800E+01, -.87375400E+00, -.10182300E+01, 0.44853700E+01, 0.96815100E+00, 0.15616600E+01, -.27010900E+00, 0.86633200E+01, -.20319800E+01, 0.12439500E+01, -.36745400E+01, -.20489100E+01, 0.10936000E+00, -.28357600E+01, -.10015900E+00, 0.27136700E+00, 0.75119800E+00, -.57260700E+01, 0.94645000E+00, 0.18386600E+01, -.47036600E+00, 0.74673500E+00, 0.74901400E-01, 0.11555200E+00, 0.27701600E+00, -.60009300E+00, -.45185500E+00, 0.27566200E+00, 0.29983900E+00, 0.56013100E+00, -.97522900E+00, 0.27981500E+01, 0.46439100E+00, -.48042400E+01, 0.17460700E+01, -.13219700E+01, 0.22774900E+01, 0.60832000E+00, 0.13210900E+01, -.94100800E+00, 0.15055900E+01, 0.39144900E+00, 0.39431600E+00, 0.26866300E+00, -.11509100E+00, 0.38043500E+01, -.60726800E+00, 0.81485900E+00, -.19407100E+01, 0.44723500E+00, -.67627600E+00, -.50998900E+00, -.18435300E+00, 0.40151700E+00, -.48848400E+00, -.22662300E+01, 0.95667900E+00, 0.13919700E+01, 0.75600400E+01, -.48246200E+00, 0.73553400E+00, -.34553300E+00, -.67173100E+00, 0.22284700E+01, 0.35051300E+00, 0.29409700E+00, 0.81208100E-01, 0.10233000E-01, 0.21267400E+00, -.73325900E+00, 0.83395400E+00, 0.28450400E+01, -.40077400E+00, -.12345800E+00, -.42840000E+00, -.65115600E+00, 0.47479400E+00, 0.16068500E+00, -.18449900E+00, -.55961700E-01, 0.86139100E+00, -.90193900E+00, 0.11184200E+01, -.19932000E+00, 0.48051300E+00, -.25664000E+00, 0.10364500E+01, -.46358500E+00, 0.65386300E+00, -.18602500E+01, -.82844000E+00, -.68176200E-01, -.24897300E+00, 0.18054600E+00, 0.17376100E+01, 0.29536600E+00, -.17114900E+00, -.64101300E+00, 0.23012300E+01, -.15787600E+01, 0.47034700E+00, -.10046100E+01, -.17298400E+01, 0.12851000E+00, -.11536400E+01, 0.16068900E+00, -.32675900E+01, -.23716100E+01, -.82707400E+00, -.49746700E+00, 0.10708900E+01, 0.17111500E+01, -.64116900E-01, -.10690000E+01, 0.79996800E+00, -.33053800E+00, 0.95280500E+00, -.10438600E+01, 0.27538500E+00, 0.18686500E+00, -.78146300E+00, 0.14979400E+01, 0.53617100E+00, -.14736400E+01, -.93038400E+00, -.27502500E+03, 0.13845000E+03, 0.13591400E+03, 0.57607400E+01, 0.48457200E+02, 0.82792100E+02, -.32321000E+02, -.65276300E+01, 0.72451800E+02, -.11627600E+02, 0.27903900E+02, -.20303900E+02, -.63412500E+01, -.19193300E+02, 0.85516600E+00, -.67039100E+02, 0.44104800E+01, 0.62887100E+01, -.48556000E+02, 0.78524100E+01, -.57731100E+01, 0.49143500E+02, 0.37405500E+01, -.85873400E+01, 0.64063900E+01, -.23148400E+01, 0.26835500E+02, 0.68130000E+01, -.86183700E+01, -.86738100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.45805600E+01, 0.35087900E+01, 0.20373200E+01, 0.72124800E+01, -.23046100E+01, -.31269300E+02, 0.10600000E+02, -.14248100E+01, -.15472200E+01, 0.20525900E+01, -.35073900E+01, -.44516200E+01, 0.11690000E+01, -.24243000E+00, 0.10198300E+01, 0.29514100E+01, 0.73061400E+00, 0.23539100E+00, -.12460400E+01, 0.41923700E+00, -.89788300E-01, 0.40857000E+00, 0.24331000E+00, 0.34683100E+01, -.82289700E+00, 0.21241700E+01, 0.26893100E-01, -.14996300E+01, 0.26660200E+00, -.14546200E+01, 0.79714600E+00, -.18140400E+01, -.62496300E+00, 0.68409800E+00, 0.18840500E+01, -.97229800E-01, -.32828300E+00, -.85746800E+00, 0.28208900E+01, 0.16477400E+01, 0.98729200E+01, -.19977900E-01, -.13121500E+01, -.45871700E+00, 0.46275800E+00, 0.90640100E+00, 0.14990600E+00, -.83998300E+00, -.12940800E+01, 0.99280200E-01, -.52695600E+00, 0.17752500E+00, -.10614600E+01, -.84985100E+00, 0.14513700E+01, -.73076800E+00, -.64951800E+00, -.49609800E+00, 0.63212900E-01, -.33457800E+01, -.16422400E+00, -.15986700E+01, -.50900500E+00, 0.31188600E-01, -.42058800E+00, 0.45385500E+00, 0.12357100E+00, -.10654300E+01, 0.16678000E+00, 0.15165900E+00, 0.59009800E+00, -.48160900E+00, 0.12274000E+00, 0.12272800E+01, -.30600900E+00, -.20366300E+00, -.59380200E+00, 0.81896100E+00, 0.58406500E+00, -.73471100E+01, 0.32219000E+01, -.17537600E+01, 0.74355200E+00, 0.90326500E+00, 0.60876400E+00, -.15940900E+01, 0.14893500E+01, -.11198500E+01, -.25673800E-01, -.21932700E+00, -.54302500E+00, 0.53619800E-01, -.93264800E+00, -.33314100E+01, 0.44851900E+00, -.44775100E+00, -.37868200E-01, 0.24841400E+00, -.43146900E+00, -.44851600E+00, 0.30585100E+00, -.17305000E+01, 0.10134800E-01, -.14928600E+01, -.21131000E+01, 0.13788300E+01, 0.74531900E+00, 0.56934600E+00, 0.59090000E+00, -.24748600E+00, -.15168100E+00, 0.10249300E+00, 0.39303000E+00, -.75290000E+00, 0.86530900E-02, 0.13143000E+01, -.12455800E+01, -.17195500E+01, 0.22890800E-01, 0.46646700E+00, -.12190700E+01, -.18510500E+00, -.10244700E+01, -.15129100E+00, 0.28786200E-01, 0.19945300E+00, -.21764100E+00, 0.44531300E+00, -.35483900E+00, 0.18443500E+00, -.36113500E+00, 0.88910300E+00, -.32869000E+00, -.74492800E-01, -.56137900E-01, 0.93550500E+00, -.34221300E+00, 0.58415900E+00, 0.46576800E-01, -.30921600E+00, -.11128900E+01, -.14679700E+00, 0.22235200E+00, -.78441300E+00, -.47072100E+00, -.26179100E+00, 0.45052900E-01, 0.23407800E+00, 0.48958200E+00, -.34524300E+00, 0.66783300E+00, 0.66896500E-01, 0.26432300E+01, 0.76402600E+00, 0.41005600E+00, 0.35038100E+00, -.66168400E+00, -.11123100E+00, -.11422200E-01, 0.59428800E-01, -.19587400E+00, -.11343000E+00, -.13829600E+01, 0.45995400E+00, -.41502000E+00, -.36855000E+00, 0.31788900E+00, -.11995100E-01, 0.34777200E-01, -.72297900E+00, -.54840500E+00, -.29731800E+00, 0.23160000E+01, -.68867700E+00, -.15342400E+02, -.56143400E+02, 0.45534400E+01, -.93354500E+01, 0.80764400E+02, -.40618000E+02, 0.89787600E+01, -.24665500E+02, 0.48039200E+01, 0.72781600E+01, 0.11119100E+02, 0.71008600E+01, -.49498100E+02, -.10803400E+01, 0.24131400E+01, -.33104600E+02, -.82785200E+01, -.74865800E+01, 0.33948500E+02, -.26366600E+01, -.22656800E+01, -.16777300E+01, 0.45567600E+01, -.25508300E+02, 0.11948000E+01, 0.23383900E+01, 0.85848300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.73029300E+01, -.25634500E+01, 0.55946800E+01, 0.67491800E+01, -.41596800E+01, -.28107800E+02, -.10901000E+02, -.91706400E+01, -.17405400E+01, -.65834400E+00, 0.49468000E+01, -.12190200E+01, 0.20388900E+01, 0.58839200E+00, -.80658900E+00, 0.36789700E+01, 0.68720400E+00, -.61731300E-01, 0.23694100E+01, -.23714900E-01, -.29373600E+00, -.92189300E+00, -.95054500E-01, 0.22916300E+01, -.96097500E+00, 0.12862300E-01, 0.10378400E+01, -.38373700E+01, 0.43105200E+00, -.46457300E+01, -.36040000E+00, 0.20913800E+01, 0.14750700E+01, -.43087300E+00, 0.12247700E+01, -.99251800E+00, -.57329300E+00, -.84178100E+00, -.22738600E+00, 0.95336300E+00, 0.44288800E+01, 0.26975800E+00, -.11455100E+01, -.22682900E+01, -.64942200E+00, 0.10761900E+01, 0.12255600E+01, -.65392100E+00, -.41182800E-01, 0.20468300E+01, 0.22409200E+01, 0.13489400E+01, -.34289100E+00, 0.30899700E+01, -.66953100E-02, 0.48155700E+00, -.12452900E+01, -.19663500E+00, -.16285500E+00, 0.25964200E+00, -.15648200E+00, 0.24676300E+00, 0.29455700E+00, -.18930500E+01, 0.34051700E+00, 0.73796600E+00, -.40516900E+00, 0.14981900E+00, 0.62478900E+00, -.96667400E-01, 0.94822100E+00, -.31676900E+00, 0.33769700E+00, -.55614200E+00, 0.17346200E+00, -.20354200E+00, 0.17253700E+00, 0.20147500E+00, 0.55165400E+00, -.35048600E+01, 0.91190400E+00, 0.62132400E+00, 0.56637900E+00, -.42306100E+00, 0.41340000E-01, -.51372800E+00, 0.68404500E+00, 0.21314900E-02, -.27339900E+00, 0.17228100E+00, -.74609400E-02, 0.90328300E+00, 0.16674000E+00, -.57543500E+00, -.37984900E+00, 0.12312600E+01, -.11148000E+01, 0.19696200E+00, 0.31573600E+00, 0.97679300E-01, 0.14636800E+00, 0.66779000E+00, -.41885100E+00, -.13884800E+01, 0.49688400E+00, -.37080900E-01, -.14113100E+00, -.24921700E+00, 0.24177600E+00, -.28148600E+01, 0.54945000E+00, 0.18982900E+00, 0.11056500E+01, -.18965100E+00, 0.36898200E+00, -.11323900E+01, 0.18542200E+01, 0.21664000E+01, -.17276200E+00, -.10739500E+01, -.38440300E+00, 0.60119400E+00, -.93150200E-01, -.22364800E+00, 0.10840900E+00, -.69619700E+00, 0.12055600E+00, 0.34232600E+00, 0.12759500E-01, -.33435800E+00, -.24891900E+00, -.22002800E+00, -.31365000E+00, -.32594600E-01, 0.72229000E-01, -.19281100E+00, -.32512500E+00, 0.16516500E+00, -.19900600E+00, -.42788800E-01, -.39121000E-01, 0.28418100E+00, -.31060300E+00, -.49949700E+00, 0.71330200E+00, -.61068700E+00, 0.24153600E+00, 0.12456100E+00, 0.56237200E-01, -.37760000E+00, 0.93989700E-01, -.14143700E+00, 0.96628200E+00, 0.48695000E-01, -.93587700E-01, -.13779300E+00, 0.96665300E-03, 0.16278000E+00, -.10592900E+00, -.12466300E+00, 0.32957100E-01, 0.35304300E+00, 0.13851700E+00, 0.23067300E-01, 0.16042400E+00, 0.74362400E-01, 0.95394400E-02, 0.74142900E-01, -.51096500E-01, 0.25414700E+00, 0.18468900E-01, -.78928600E-02, -.25041200E+00, 0.36352700E+01, -.12988600E+01, -.28775300E+01, -.40172300E+01, 0.24965200E+00, -.36173600E+01, -.75284200E+00, -.19990500E+01, 0.10235800E+01, -.30850100E+01, -.24335600E+01, -.26580500E+01, -.21726200E+00, -.15554800E+02, 0.19351800E+01, 0.72787600E+01, -.56034600E+01, 0.20201200E+01, -.14538600E+00, 0.57014000E+01, 0.22653100E+01, -.77042600E+01, 0.20753700E+01, -.17252900E+01, 0.12224700E+01, 0.73991800E+01, -.14817900E+01, 0.26756400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.65351000E+01, 0.18640700E+01, -.40201600E+01, -.57530400E+01, 0.34770700E+01, 0.21329400E+02, 0.85040100E+01, 0.11657000E+02, 0.11790100E+01, 0.29012100E-01, 0.32561100E+01, 0.87316100E+00, -.24531900E+01, -.83596200E+00, -.28499400E+00, -.18415900E+01, -.72126400E+00, -.20638000E+00, 0.11234300E+00, 0.12230100E+00, 0.10489000E+01, -.13151400E+01, -.60187200E+00, 0.10480700E+01, -.13123000E+01, 0.84063400E+00, -.61566100E-01, 0.18301700E+02, 0.89049400E+00, -.84593500E+00, -.89567300E-01, -.35009300E+00, 0.12360200E+01, 0.51364500E+00, -.35029300E+00, 0.13671400E+01, 0.99365600E+00, -.42088000E+00, 0.20204700E+01, 0.15815600E+01, 0.11143800E+02, -.10102800E+00, 0.42696100E+01, 0.18508900E+01, -.16995900E+01, 0.39149900E-01, -.17711300E+01, 0.17087100E+00, -.77649100E-01, -.25354200E+01, -.65005500E+00, -.18660800E+01, -.25065600E+00, -.22152500E+01, 0.43248700E+01, -.14449800E+01, 0.19708700E+01, 0.13006900E+01, -.21920500E+00, 0.48283500E+00, -.14640800E+00, 0.12867000E+01, -.92435900E-01, -.18154100E+01, -.30204800E+00, -.15067500E+01, -.38532400E-01, -.36394100E+00, 0.22649900E+00, -.57730200E+00, 0.35365700E+00, 0.53477200E-01, 0.52305600E+00, -.21329000E+01, -.66870600E-01, -.49685000E+00, 0.68765500E+00, -.43536900E-01, -.69010800E+00, 0.17008100E+01, -.56358800E+00, -.88383400E+00, -.14265200E+01, 0.80427900E+00, -.60287400E+00, 0.67913900E+00, -.19089100E+00, -.19172000E+00, -.33185800E-01, 0.14112300E+00, 0.18718700E+00, -.19794800E+00, 0.45170400E+00, 0.62359600E-01, 0.30849000E+00, -.65140000E+00, 0.62265900E+00, -.37897800E+00, -.35679200E+00, -.77134200E+00, 0.22889900E-01, 0.12995700E+01, -.33795500E+00, -.23009600E+01, 0.25497300E+01, 0.60547800E-01, -.25543500E+00, -.27030400E+00, 0.10485300E+01, 0.43507500E+00, 0.14913400E+00, 0.29127400E+00, 0.37424900E+00, -.17763900E+00, 0.35369400E-01, -.18979200E-01, 0.10372200E+00, 0.16915200E+01, -.29340200E+00, -.16872000E+00, -.42902000E+00, -.53541600E+00, 0.34823900E+00, 0.25061300E-01, -.10089200E+00, 0.47689000E+00, -.36057900E+00, -.15744000E+00, 0.30219700E+00, -.24873100E+00, 0.11933800E+00, 0.10466700E+01, 0.74654400E+00, -.79770100E-01, 0.34230200E-01, 0.55017600E-02, -.47904900E+00, 0.49018100E+00, 0.25687000E-01, -.91846900E-01, -.78796100E+00, -.57498300E-01, 0.43850600E+00, 0.14424100E+00, -.38068800E+00, 0.11745700E+00, -.17293500E+00, -.24472000E-01, -.81878100E-01, -.85887800E+00, 0.15414600E+00, -.30659500E+00, 0.30021900E+01, 0.37850400E+00, -.23114200E+00, 0.34300600E-02, -.71045600E+00, -.30047600E+00, -.26992700E+00, -.76492100E-01, 0.13667700E-01, -.10010800E+00, 0.47623200E+00, -.19928200E+00, 0.42427700E+00, 0.19261400E+00, -.32935000E+00, 0.21805400E+00, 0.21981900E+00, 0.25231400E+00, -.22181600E+00, 0.80779000E-01, -.27594900E+00, -.13944800E+00, 0.10398600E+02, 0.60410600E+01, -.85672800E+01, -.72286800E+01, 0.10248800E+02, -.22617200E-01, 0.30249900E+01, 0.92646900E+01, -.94017800E+00, 0.28321500E+01, 0.31933900E+01, 0.23377400E+01, -.18023600E+02, -.12091700E+01, -.69816000E+01, -.18362800E+02, -.28107300E+01, 0.44468200E+00, 0.18658700E+02, -.16024000E+01, 0.72988200E+01, -.31382100E+01, 0.21491400E+01, 0.86212600E+01, -.75835000E+01, 0.30867000E+01, -.75930300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.23692600E+02, 0.13833900E+02, -.12022400E+02, -.27696900E+02, 0.88779800E+01, 0.14417000E+03, -.56475600E+01, 0.20395900E+02, 0.76252000E+01, -.42594700E+01, -.23753900E+02, 0.10661400E+02, -.98266800E+01, -.21163700E+01, -.18203400E+01, -.10331500E+02, -.21881800E+01, 0.25426700E+01, 0.15031200E+01, -.49164700E+01, 0.16147100E+01, -.24856400E+01, -.18326100E+01, -.14931900E+02, 0.37318100E+01, -.70036100E+01, -.16613200E+01, 0.37023600E+02, 0.41986100E+00, 0.43824200E+01, -.18767400E+01, -.17195600E+01, -.18101200E+01, -.81428200E+00, -.48725500E+01, 0.20256300E+00, 0.20324800E+01, 0.35656600E+01, -.21673300E+01, 0.13666600E+01, -.25809900E+02, -.79631100E+00, 0.53228700E+01, 0.32070300E+01, -.60034200E+00, -.43653800E+01, -.19097100E+01, 0.31035900E+01, 0.70604400E+01, -.27237000E+01, 0.23566900E+01, 0.42405200E-02, 0.27610200E+01, -.44096400E+01, -.82950900E+01, 0.75177400E+00, 0.12256500E+01, 0.23865700E+01, -.14235500E+01, 0.13925000E+01, 0.62197200E+00, 0.95833300E+00, -.51964700E-01, -.12490700E+01, -.43102800E+00, -.96494400E+00, 0.13991100E+00, -.25169600E+01, -.13602200E+01, 0.10706600E+01, 0.12756800E+00, 0.69078700E+00, -.11397600E+01, -.28294200E+00, 0.13089000E+00, 0.92858600E+00, -.19457300E+00, 0.19608300E+01, -.24067200E+00, 0.20282300E+02, -.44401200E+01, 0.25864000E+01, -.15062600E+01, -.22120700E+01, -.11574500E+01, 0.28048700E+01, -.49101000E+00, 0.17327300E+01, -.11262200E+01, -.16901000E+00, 0.16569100E+01, 0.11261700E+02, 0.17146300E+01, -.27628500E-01, -.17550800E+01, 0.30677100E+01, -.22315600E+01, 0.15117300E+01, 0.16651500E+01, 0.10256300E+01, -.14608700E+00, 0.20075100E+01, -.63882000E+00, 0.35645900E+01, -.59138100E+01, -.20407300E+01, -.14305200E+01, 0.57784600E-01, -.23033400E+01, -.15148200E+02, -.17066500E+00, -.10091900E+01, 0.85111800E+00, 0.57074100E+00, -.49529700E+00, -.25803600E+01, 0.23101700E+01, -.34059100E+01, 0.14064800E+00, -.16338000E+01, 0.64285500E+01, 0.24055400E+01, 0.46874300E-02, -.35739700E+00, 0.11133500E+01, -.43456200E+01, 0.24179300E+01, -.24214900E+01, -.65011900E+00, -.13431800E+01, 0.20828600E-01, -.14428100E+01, -.73379300E+00, 0.14932600E+01, -.97776800E+00, 0.50009600E+00, 0.67092500E+00, -.29521700E+00, -.20111400E+00, 0.17135300E+00, 0.10347000E+01, -.32034300E-01, -.12921700E+00, 0.17348900E+01, -.56419800E+00, -.38094400E+00, -.20764500E+00, -.10325300E+01, -.15538900E+01, 0.31120200E+00, -.88273800E+00, 0.20586500E+00, -.54314700E+01, -.16301100E+01, -.93739800E+00, -.44248200E+00, 0.33896800E+00, -.19737100E+01, -.34292900E+00, -.28567800E+00, -.67695700E-01, 0.55210400E+00, 0.27909300E+01, -.35412700E-01, 0.10415200E+01, 0.11721700E-01, -.74158200E+00, -.40791100E+00, -.23644000E+00, 0.36596800E+01, 0.15126700E+00, 0.71320600E+00, -.27836900E+01, 0.37423400E-01, 0.72092600E+00, -.16586900E+03, 0.31316800E+02, 0.18472600E+02, 0.40866900E+03, -.15317200E+03, 0.63412800E+02, -.10410900E+03, 0.63223600E+02, 0.41317300E+02, 0.73010300E+02, 0.40409800E+02, -.61454800E+02, -.14192800E+02, -.45711700E+01, -.63522500E+02, -.49606500E+02, -.33027900E+02, 0.64602300E+02, -.20062700E+02, 0.11188000E+02, -.20191800E+02, 0.23006300E+02, -.10576000E+03, -.11832400E+02, 0.18421100E+02, 0.92027400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14634500E+02, 0.51362600E+01, -.96108500E+01, -.11707000E+02, 0.73071300E+01, 0.56091900E+02, 0.21905300E+02, 0.22514500E+02, 0.33932900E+01, 0.12972800E+01, -.15029300E+02, -.78951500E-01, -.46738500E+01, -.10259700E+01, 0.12026200E+01, -.57812900E+01, -.12454000E+01, 0.55218900E+00, -.45079700E+01, 0.37304500E+00, 0.83654900E+00, 0.12037800E+01, -.66133000E-01, -.55626100E+01, 0.25471800E+01, -.24954300E+00, -.22117400E+01, 0.15494000E+02, -.51006300E+00, 0.11729000E+02, 0.71160200E+00, -.54675800E+01, -.30883300E+01, 0.12052100E+01, -.22014200E+01, 0.19872200E+01, 0.14578700E+01, 0.24664800E+01, 0.94309900E+00, 0.22994400E+00, -.53923800E+01, -.87148600E+00, 0.23464000E+01, 0.51668300E+01, 0.12483700E+01, -.20401300E+01, -.28687400E+01, 0.14488800E+01, -.25493300E+00, -.42225400E+01, -.46292500E+01, -.27876500E+01, 0.37282400E+00, -.40984400E+01, 0.10446800E+01, -.84932300E+00, 0.22524700E+01, 0.20530100E+00, 0.30346400E+00, -.10113600E+01, 0.18090100E+01, -.31554700E+00, -.26533200E+00, 0.13489500E+01, -.42559400E+00, -.13546500E+01, 0.51367800E+00, -.12113800E+00, -.15057000E+01, 0.36983000E+00, -.19386400E+01, 0.54118200E+00, -.46354600E+00, 0.15608500E+00, -.58819200E+00, 0.35825000E+00, -.36573200E+00, 0.44050400E+00, -.12459000E+01, 0.12767200E+02, -.23641600E+01, -.22355200E+01, -.15894000E+01, 0.14253600E+01, -.85537500E-01, 0.14920100E+01, -.91485800E+00, 0.77071200E-02, 0.65169800E+00, -.52182300E+00, 0.40010400E+00, 0.22920300E+01, -.17008100E+00, -.36037500E+00, -.29986200E-01, -.19463000E+01, 0.12600600E+01, 0.11564600E+00, -.17936800E+00, -.61836800E+00, -.18565600E+00, -.10307700E+01, -.19485800E+00, 0.16693800E+01, -.18382800E+01, 0.35043900E+00, 0.11803100E+00, 0.52810200E+00, -.26879800E+00, 0.65698300E+00, -.42904800E+00, -.24457600E+00, -.53179100E+00, -.14791400E+00, -.33995300E+00, 0.12983800E+01, -.21583100E+01, -.12560800E+01, 0.60815700E-01, 0.76653500E+00, 0.42787100E-01, -.81458600E+00, -.17773200E+00, 0.25257000E+00, -.15030800E+00, 0.74941700E+00, -.82298000E-01, -.79302900E+00, -.95390700E-01, -.16135700E+00, 0.29115100E+00, 0.43828700E+00, 0.66750000E+00, -.36025400E-01, -.16815700E+00, 0.37415700E+00, -.14490400E+00, 0.26784600E+00, 0.22372700E+00, 0.20933900E+00, -.37369600E+00, -.30513700E+00, 0.61495900E+00, 0.45976900E+00, -.13963100E+01, 0.70449900E+00, -.33194000E+00, -.44973700E+00, -.63189100E+00, 0.65615100E+00, -.28982300E+00, 0.74734900E-01, -.75142300E+00, -.25214100E+00, 0.50459300E-01, 0.53614200E-01, -.11845700E+00, -.72574800E+00, 0.96241800E-01, 0.21220500E-02, -.14096800E+00, -.55404300E+00, -.27039900E+00, 0.29004900E+00, 0.19492300E-01, -.21270300E+00, -.12170800E+00, -.16907200E+00, 0.58246600E-01, -.48059400E+00, 0.46007300E-02, 0.90195300E-02, 0.83667800E+00, 0.43746400E+00, 0.12844100E+01, -.17778400E+00, 0.24535800E+02, 0.18933100E+02, 0.34751500E+02, -.22298600E+01, 0.69987600E+01, -.18398100E+02, 0.15495700E+02, 0.44159500E+01, 0.80761200E+01, 0.12945000E+01, 0.62222600E+02, -.36479800E+01, -.53855200E+01, 0.37502400E+02, -.48320700E+01, -.27879700E+01, -.38391900E+02, -.40396500E+01, 0.71719900E+01, -.21939400E+01, 0.20018500E+01, -.17722300E+02, -.59147300E+01, 0.14661600E+00, 0.29589200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.42470200E+01, 0.13124100E+00, 0.26698200E+01, 0.59000700E+01, -.29465800E+01, -.34751200E+02, -.18797100E+02, -.36831100E+01, -.21151000E+01, 0.55075500E+00, -.27036900E+01, -.29510200E+01, 0.12497900E+01, 0.26968400E+00, 0.10190300E+00, 0.78165300E+00, 0.64256800E+00, 0.13333100E+01, 0.25068200E+00, 0.10074300E+01, 0.14516800E+00, 0.43969200E+00, 0.36826400E+00, 0.63230300E+01, -.12549100E+01, 0.22757900E+01, 0.35646400E+00, -.16837600E+02, 0.46540000E+00, 0.34073800E+01, 0.11607200E+01, -.20204300E+01, -.11307300E+01, 0.33610800E+00, 0.10185100E+01, -.15318500E+01, -.11901600E+01, 0.14644900E+00, -.17900500E+01, -.39711200E+01, -.17527700E-01, 0.53122100E+00, -.11768400E+00, -.93075700E+00, -.23239100E+00, 0.72140600E+00, 0.46074800E+00, 0.50450600E-02, -.15938000E+01, 0.72824100E+00, -.78428200E+00, -.38314300E+00, -.21799800E-01, 0.89775400E+00, -.32083200E+00, 0.41484500E+00, -.85367200E-01, -.15368200E+01, 0.10058300E+01, 0.12419100E+01, -.93520300E+00, 0.52873200E+00, -.35393800E+00, 0.13571200E+01, -.17470900E+00, -.68231600E+00, 0.31597500E+00, -.12040600E+01, 0.50907700E-01, -.13947100E+00, -.42138300E+00, -.61726100E-02, -.27896800E-01, 0.28472100E+00, 0.62380300E+00, -.20359400E-01, -.21309400E-01, 0.61545800E+00, -.23758800E+00, -.53290300E+01, 0.93321500E+00, -.21613000E+00, 0.51212100E+00, 0.35968400E+00, -.26734300E+00, -.21851700E+00, 0.29572600E-01, 0.64890600E+00, -.27364300E+00, -.20341900E+00, 0.53766900E+00, 0.19071700E+01, 0.35243300E+00, 0.18369800E+01, -.60158900E+00, -.34711900E+00, -.58152900E+00, -.68713100E-02, 0.75971800E-01, 0.60021400E-01, 0.94786100E-01, -.12222600E+01, -.62584100E+00, 0.63057600E-02, -.13551900E+01, 0.67615800E+00, 0.16826400E+00, 0.45644400E+00, 0.31128000E+00, -.16990400E+00, 0.77601100E+00, 0.99548500E-01, 0.98304900E+00, -.59741900E+00, 0.30492100E+00, 0.54417100E+00, -.57745100E+00, 0.20977900E+01, -.25948500E+00, -.11787700E+01, -.18009700E+01, 0.52840900E+00, -.69429300E-01, -.76090000E-01, 0.19513700E+00, -.26879200E+00, -.12520500E+00, 0.44575100E+00, -.61436900E+00, -.39972300E+00, -.33083300E+00, 0.16465300E-01, -.74446000E+00, -.37354600E+00, -.18074900E+00, 0.12080700E+01, -.56679100E+00, 0.60580000E+00, 0.14283200E-01, -.12496600E+00, -.88114900E+00, 0.11353500E+00, 0.13257800E-01, -.84734400E+00, -.29795300E+00, -.33737000E+00, 0.74837000E-01, 0.38327600E-01, 0.44018500E-01, -.37469600E+00, 0.45735800E-01, -.46526900E+00, 0.21457200E+01, -.82784400E+00, -.26854600E+00, 0.15349800E+00, 0.40971700E-02, 0.36938000E+00, -.27537500E+00, -.70511400E+00, -.10829800E+00, 0.49440900E-01, -.92128200E-01, -.39640800E+00, 0.43128300E+00, 0.34623300E+00, -.21061400E+00, 0.31944900E+00, -.81157000E-01, 0.53450700E-01, -.73617900E+00, 0.17798500E+00, -.61388500E-01, 0.70757000E-01, -.33582700E+00, 0.17019200E+00, 0.47179600E+00, 0.13972600E+02, -.68868300E+01, 0.32881700E+01, -.89189300E+01, -.15041200E+00, -.94868500E+01, -.54188300E+01, -.73499400E+01, -.62130800E+01, -.10648400E+02, 0.32359300E+01, -.12978400E+01, -.37306700E+02, 0.66377000E+01, 0.81178900E+01, 0.37736200E+02, 0.30079000E+01, -.41109800E+00, 0.37449500E+01, -.25029000E+01, -.10040800E+01, -.69094700E+00, -.44004100E+01, 0.22033000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11684400E+02, 0.10075700E+02, 0.56431900E+01, 0.13321300E+02, -.38220200E+01, -.74704400E+02, -.39715600E+01, -.79049200E+01, -.42812800E+01, 0.23023800E+01, 0.41240700E+01, -.57677800E+01, 0.46903200E+01, 0.73237700E+00, 0.18171100E+01, 0.43517200E+01, 0.99665800E+00, -.12325500E+01, 0.20900200E+00, -.11720300E+01, -.48182900E+00, -.13250900E+01, 0.99450500E+00, 0.77754500E+01, -.15833900E+01, 0.32368900E+01, 0.97301900E+00, -.14108300E+02, 0.55181500E+00, -.40967400E+01, -.27671700E+00, -.62126100E-01, -.19113200E+00, 0.50039900E+00, 0.12725300E+01, -.13953800E+01, -.70863100E+00, -.95685900E+00, -.19510800E+01, -.14082500E+01, -.52536800E+01, -.81546100E-01, -.11983000E+01, -.41491600E+01, -.11132900E+00, 0.17349100E+01, 0.12613400E+01, -.11481900E+01, -.11594900E+01, 0.12256200E+01, 0.26922400E+01, 0.13807500E+01, -.18819600E+01, 0.16096700E+01, 0.83039100E+01, -.36407000E+00, -.21111400E+01, 0.13020400E+01, -.50704800E+00, -.27999000E+01, -.12858500E+01, -.15522900E+01, 0.50064900E+00, 0.94490400E+00, 0.22574200E+00, 0.22842200E+01, -.73657300E+00, -.24388900E+01, 0.41861100E+00, 0.68938800E+00, 0.85398300E+00, 0.36796500E+00, 0.97456000E+00, 0.62793800E-02, 0.64222400E-01, -.97742600E+00, 0.80724900E+00, -.14505900E+01, 0.41116900E+00, -.83886600E+01, 0.20830400E+01, -.18682200E+01, 0.22109500E+00, 0.86828000E+00, -.22314000E+00, -.12526100E+01, 0.72878600E+00, -.12838500E+01, -.10330000E+00, -.99479900E-01, -.10785100E+01, -.53095700E+01, -.85316000E+00, -.57390400E+01, 0.18128600E+01, -.96013700E+00, 0.20014000E+01, -.21670500E+00, -.72063400E+00, -.10560900E+01, 0.17280300E+00, -.87863300E+00, 0.24403000E+00, -.17283700E+01, 0.12471700E+01, 0.79457800E+00, 0.49395200E+00, 0.22126700E+00, 0.12333300E+01, 0.53188700E+00, -.56934500E+00, 0.78692400E+00, 0.40527200E+00, -.50596700E+00, -.14280400E+00, 0.13656300E+01, -.17179300E+01, -.62082100E+00, 0.16953500E+00, 0.82967000E+00, -.28778300E+01, -.10239300E+01, 0.51089700E-01, 0.20219400E+00, -.52992400E+00, 0.19686900E+01, -.11999200E+01, 0.78424200E+00, 0.26327500E+00, 0.56296600E+00, -.20902200E+00, 0.61231600E+00, 0.46828100E+00, -.58340800E+00, 0.64305100E-01, 0.70778300E+00, -.37965200E+01, 0.11904800E+01, -.96649700E+00, 0.14941000E+00, 0.69509000E-01, 0.40057900E+00, -.51890100E-02, 0.44425600E+00, -.34292200E+00, -.69267400E+00, 0.52910900E+00, -.12449300E+00, -.16474500E+01, -.91450200E+00, -.17319700E+00, 0.59918600E+00, 0.31226800E+01, -.14029400E+00, 0.38952300E+00, 0.53730900E+00, -.94645400E+00, 0.10925100E+01, 0.16001100E+00, -.23689000E+00, 0.13446500E+00, -.10844300E+01, -.20621200E+01, -.28474000E+00, -.58568300E+00, -.16058200E+00, 0.82329600E+00, -.32196700E+00, -.49408000E+00, 0.12048300E+01, 0.22271900E-01, 0.21801900E+00, -.11298400E+01, -.13384700E+00, -.12901800E+01, 0.28503500E+00, -.16115000E+00, 0.14811700E+01, 0.98077000E+02, 0.42511300E+01, 0.27063700E+02, -.40102000E+01, 0.63795000E+01, 0.17097700E+02, 0.11311700E+02, 0.12707100E+02, 0.93964300E+01, -.16646900E+02, -.22354200E+02, 0.43767900E+02, -.18688900E+02, -.13905100E+02, -.43654200E+02, -.18183300E+02, 0.24243400E+02, -.18921400E+02, 0.18308300E+02, -.38499600E+01, -.23647400E+02, 0.99033700E+01, -.17888200E+02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.41847100E+01, -.30526600E+01, -.20008400E+01, -.64211900E+01, 0.22013100E+01, 0.25817300E+02, -.36805800E+01, 0.17613200E+01, 0.13228300E+01, -.15506300E+01, 0.46442200E+01, 0.41191700E+01, -.10561300E+01, 0.15663700E+00, -.71116200E+00, -.23525600E+01, -.74173100E+00, -.68848400E+00, 0.11092600E+01, -.14079300E+00, -.20906000E-01, -.45533200E+00, -.69607800E-01, 0.75909000E-01, -.10441400E+01, -.43836900E+00, 0.32944800E+00, 0.27325000E+01, -.74324500E+00, 0.15424100E+01, -.33667400E+00, -.79509300E+00, -.66292500E+00, -.70421900E+00, -.14510400E+01, -.14548800E+01, 0.53596200E+00, 0.17778400E+01, -.23233900E+01, -.60720300E+01, -.30547800E+01, 0.91663300E+00, -.49698300E+00, 0.11248200E+01, 0.13258500E+01, -.96940200E+00, 0.12024300E+00, 0.18019500E+01, 0.10844000E+01, 0.14022000E+00, 0.55765700E+00, -.52947900E+00, 0.12892400E+01, 0.44088100E+01, -.22221800E+01, 0.14407700E+01, 0.75325600E+00, -.17003500E+01, 0.11815400E+01, 0.35491400E+01, 0.42732900E+00, 0.13345500E+01, 0.45817900E-01, 0.33216000E+01, 0.36764000E+00, -.23744800E+01, 0.10874900E+00, 0.42168800E+01, 0.74606300E+00, -.11741400E+01, 0.26886600E+00, -.81047800E+00, 0.66516700E+00, 0.10053500E-01, -.10723600E+00, -.13298500E+00, 0.25721200E+00, -.14534900E+01, 0.12032100E+00, -.90202100E+00, 0.35767400E+00, 0.10736600E+01, 0.14084300E+01, -.14241100E+01, 0.43053600E+00, -.15395600E-01, -.42271100E+00, 0.26432900E+00, 0.30787500E+00, 0.10222500E+01, -.65960400E-01, -.14495500E+01, -.47312400E-02, 0.37544500E+01, 0.83298800E+00, 0.54803500E+00, -.32211000E+00, -.53359800E+00, 0.15776800E+00, 0.77756300E+00, 0.14557800E+00, 0.17356700E+01, 0.12527800E+01, -.16863300E-01, 0.31016800E+00, -.11654400E+01, -.42864300E+00, -.15000600E+00, 0.22866100E+00, 0.10972700E+01, 0.35749500E+00, 0.25960400E+00, 0.57552000E-01, 0.90137000E+00, -.94257700E-01, -.10464600E+01, 0.97965400E+00, 0.90709000E+00, 0.11451700E+00, -.68028800E+00, 0.17882100E+01, 0.35953400E+00, 0.16710600E+00, -.65516600E-01, 0.19675700E+00, -.58774200E+00, -.22282300E+00, 0.50424300E+00, 0.82990800E+00, 0.60535700E-01, -.24522800E+00, 0.80463900E-01, -.13248300E+00, 0.58842300E+00, 0.79783900E-01, -.26814600E-01, 0.68309800E+00, -.35917100E+00, 0.99543300E-01, 0.25985900E+00, -.31145700E+00, 0.71200700E-02, -.21414600E-01, 0.28267000E+00, 0.30554600E+00, -.13971400E+00, 0.80245500E-01, 0.51510500E-01, 0.33647600E+00, 0.13385200E+00, 0.15593900E-01, 0.12324600E+00, 0.87755100E+00, 0.18561700E+00, 0.21847900E+00, -.44520600E-03, 0.73782000E-01, 0.21571400E+00, 0.13402400E+00, 0.50130600E-01, 0.76193200E-02, -.21622300E+00, -.34238800E+00, 0.33940900E-01, -.31463300E+00, -.25599000E+00, 0.33186600E+00, -.36966200E+00, -.67176900E-01, 0.30467100E+00, 0.13991500E+00, -.12318000E+00, -.12782600E+00, -.57188000E-01, -.43909900E+00, 0.25095900E-01, -.98657100E-01, -.18288400E+00, 0.12247200E+00, 0.14548600E+02, -.36222700E+01, 0.36170300E+00, -.44913600E+01, -.26771500E+01, -.32684100E+01, -.16796000E+01, -.14498300E+02, 0.23683600E+01, 0.17396400E+01, -.18526100E+02, 0.31714500E+01, 0.18883400E+01, 0.18748400E+02, 0.21094500E+01, -.20511300E+01, 0.28366600E+01, -.17222700E+01, -.56984200E-02, 0.17807100E+01, -.20630500E+01, 0.10258400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.21166300E+02, -.11804100E+02, 0.11104000E+02, 0.25686000E+02, -.10786300E+02, -.99206600E+02, -.15306500E+02, -.28946200E+02, -.53713600E+01, 0.25477300E+01, 0.71979800E+01, -.88690500E+01, 0.73533900E+01, 0.36076400E+01, -.27643700E+01, 0.90401600E+01, 0.23529900E+01, 0.21204300E+01, 0.69623800E+00, 0.31697200E+01, -.45393600E+00, 0.23728300E+01, 0.96660300E+00, 0.91747000E+01, 0.19280100E+00, 0.20571500E+01, 0.15488100E+01, -.65768100E+02, 0.78830100E+00, -.77109500E+01, 0.15965600E+01, 0.62388300E+01, 0.34711600E+01, 0.12071400E+01, 0.13164100E+01, 0.23122100E+01, -.14371300E+01, -.78684300E+01, 0.12022000E+01, 0.48315700E+01, 0.14107100E+02, -.12599000E+01, -.35074700E-01, -.14590100E+01, -.17132200E+01, 0.53534300E+01, -.56393700E+00, -.53452200E+01, -.96723200E+01, 0.11957700E+01, -.65697300E+01, -.26790400E+00, -.43590800E+01, -.11842100E+01, 0.14722000E+02, -.26211400E+01, -.13337200E+01, 0.35716100E+00, -.25107600E-01, -.80784000E+01, 0.15313300E+01, -.17925900E+01, 0.74525600E+00, -.96051800E+01, 0.85064300E+00, 0.55111400E+01, -.16050400E+01, -.93262400E+00, 0.11469500E+01, -.10674800E+01, -.12691100E+01, -.68448600E+00, -.28156200E-01, 0.11897600E+01, 0.78174900E+00, -.48058300E+00, 0.19450100E+00, -.42575400E+01, -.11221300E+00, -.14148100E+02, 0.36992300E+00, 0.58534600E+00, 0.20585600E+01, 0.47736600E+00, 0.60094800E+00, -.10242200E+01, -.41085100E+00, -.70368600E+00, 0.34421800E+00, 0.22297800E+00, 0.39505300E+00, -.26454600E+01, 0.39664000E+00, -.50104300E+00, -.53628400E+00, -.12507200E+01, 0.24588500E+00, 0.68738800E+00, -.62221700E+00, -.11872700E+01, -.50102400E+00, -.59729800E+00, -.59035900E+00, -.36909400E+01, 0.52372800E+01, 0.78532100E+00, 0.62418600E+00, -.40099800E+00, 0.75074600E-01, -.29997700E+01, 0.62164600E+00, -.60029800E+00, 0.37153800E+00, -.81963100E-01, 0.86730400E+00, -.17800800E+01, 0.29170300E+01, 0.64589500E+01, -.54799700E+00, -.30375400E+00, -.18754200E+01, -.14849300E+01, 0.90962000E+00, 0.79224600E-02, -.46444800E+00, 0.22942700E+01, -.16983100E+01, -.97420000E+00, -.53946300E+00, -.18404400E+01, 0.89954600E+00, -.43179200E+00, 0.62882200E+00, -.80866200E+00, -.33344000E+00, 0.13185200E+00, 0.14134200E+01, -.19699000E+00, 0.13758000E+00, 0.21937100E+00, -.62398800E+00, -.15164800E+00, 0.29533000E+00, 0.15852300E+01, 0.17495300E+00, 0.11755800E+01, -.32426600E-01, 0.10261900E+01, 0.33961400E+00, 0.32724400E+00, 0.10818700E+00, 0.43025300E-01, 0.11323900E+00, 0.84768100E+00, -.18302400E+00, -.31961200E+00, 0.13234100E+00, -.34540900E-01, -.18836700E+00, -.84497000E-01, -.40876900E+00, 0.14767100E+01, 0.44451400E+00, 0.53650900E+00, 0.74668000E+00, 0.63110200E+00, 0.72336000E-01, -.33726300E+00, -.58477500E+00, -.19572600E+00, 0.37514600E-01, -.11162900E+01, 0.11484900E+01, 0.27868300E+00, 0.10481100E+01, -.41327500E+00, 0.10026100E+01, 0.72473100E+00, -.62335400E+00, 0.50138500E+00, 0.28306300E+02, 0.45127700E+01, 0.90612100E+01, 0.85926500E+01, 0.26033800E+00, 0.32195200E+02, -.18810400E+02, -.76674700E+01, 0.18587700E+02, 0.22025400E+02, -.13986600E+02, -.33705400E+02, -.22147800E+02, -.74199100E+01, -.17043900E+02, -.93840600E+01, 0.83976100E+01, 0.58099700E+01, 0.18098400E+02, 0.32450800E+01, -.32751700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.39086900E+01, 0.18609200E+01, 0.21906900E+01, 0.68502200E+01, -.29500900E+01, -.26403400E+02, -.11066200E+02, -.39650000E+01, -.15873800E+01, 0.46990500E+00, 0.28064600E+00, -.21005800E+01, 0.12298900E+01, 0.69852000E+00, -.67406900E+00, 0.18488100E+01, 0.40959400E+00, 0.80498500E+00, -.24856100E+00, 0.60641300E+00, -.55424500E+00, 0.13540800E+01, 0.36525600E+00, 0.16401900E+01, 0.91735400E+00, 0.67510900E+00, 0.10694500E+00, -.10032700E+02, 0.86581000E+00, -.26438500E+00, 0.72890000E+00, -.69023600E+00, -.13254600E+01, -.49654300E-01, 0.51044800E+00, -.26272800E+01, -.90148800E+00, 0.26195900E+00, -.14216200E+01, -.15764900E+01, 0.38914000E+00, 0.17100400E+00, -.24403600E+00, -.18701400E+01, -.36978100E+00, 0.10771700E+01, 0.42059300E+00, -.43235700E+00, -.38430500E+00, 0.83902200E+00, 0.12443600E+01, 0.42828200E+00, -.47876600E+00, 0.32544600E+01, 0.24419600E+01, 0.26887200E+00, -.10622900E+01, -.40054600E+00, 0.28241500E+00, 0.22635100E+00, -.66195900E+00, -.78004000E-01, 0.32106100E-01, 0.18314200E+01, -.96144900E-01, 0.50394200E-01, -.13591400E+00, 0.12573200E+01, 0.33494600E+00, -.24952900E+00, 0.36158200E+00, -.80638400E-01, 0.50629600E+00, -.73439000E+00, -.46784400E+00, -.33941000E+00, -.27628900E-01, -.87523100E-01, 0.64140700E-01, -.44634100E+01, 0.16578400E+01, 0.47830200E+00, 0.13209300E+00, -.42964300E+00, -.31959500E+00, -.48646500E+00, 0.58664200E+00, -.69226800E+00, 0.41962000E+00, 0.56629500E+00, 0.23447200E-01, -.19342400E+01, -.46510000E-01, 0.82902800E+00, 0.29797500E+00, 0.14371200E+00, -.17541600E+00, 0.43282600E+00, -.16650300E+00, -.98590400E-01, -.15001100E+00, 0.51797400E+00, 0.61409900E+00, -.27629100E+00, -.14452900E+01, 0.47720000E+00, 0.41314700E-01, 0.16895200E+00, 0.13052900E+00, -.43889200E+00, 0.29526200E+00, -.21038100E+00, 0.28709400E+00, 0.15465900E+00, -.77777200E-01, -.18211500E+00, -.17774800E+00, 0.21769700E+00, 0.88692800E-01, -.49842100E+00, 0.39185500E+00, -.10527400E+00, 0.10333300E+00, 0.34964700E-01, -.53319300E-01, -.40438600E+00, -.28975900E+00, -.20297300E-02, 0.48005100E+00, -.11079200E+00, 0.91599300E-01, 0.81815700E-02, 0.27354200E+00, 0.18057300E+00, -.16335300E+00, -.13023000E+00, 0.23072200E+00, -.13190100E+00, 0.73317000E-01, 0.18897200E+00, 0.14896700E+00, -.61820600E-01, 0.14132400E+00, 0.75021600E+00, 0.44422500E+00, 0.10432100E+00, -.83693000E-01, -.29264100E+00, -.41203000E+00, 0.33117700E+00, -.14991000E+00, -.21323800E+00, -.10660500E+01, -.42940700E+00, -.27203600E+00, -.18519700E+00, -.57284600E-01, 0.12493100E+00, 0.34622100E-01, -.21524900E+00, 0.18015000E+00, -.75848900E-01, 0.60109200E+00, -.24469100E+00, 0.25876700E+00, 0.37984200E-01, -.17655200E+00, -.67902800E-01, 0.85421000E-01, 0.51795000E+00, -.11201300E+00, 0.38507700E-01, -.50012300E+00, -.44101300E-01, -.24726900E+00, 0.15174800E+00, 0.54039100E-01, -.27889600E+00, -.15609200E+00, 0.28339800E+00, -.94412900E-02, 0.11259300E+02, -.53061700E+01, 0.11529600E+00, -.34051100E+01, 0.17048200E+00, -.27078800E+02, -.31237400E+00, -.15757900E+01, -.16144700E+02, 0.29911300E+00, 0.49963100E+00, 0.16528000E+02, -.45759700E+00, 0.99597400E+00, -.81157400E+00, 0.14384500E+01, 0.11356400E+02, -.18374200E+01, 0.75309800E+00, -.88506100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.15140600E+02, 0.78071600E+01, -.96569900E+01, -.15656500E+02, 0.73173200E+01, 0.73153700E+02, 0.23129400E+02, 0.15830000E+02, 0.42747900E+01, -.68374000E+00, -.35275700E+01, 0.50463500E+01, -.59285100E+01, -.87769600E+00, 0.34038800E+00, -.43818900E+01, -.13817400E+01, 0.20247200E+00, -.21345000E+01, -.85697000E+00, 0.79886200E+00, 0.57808200E+00, -.13621500E+01, -.58487300E+01, 0.10143600E+01, -.41865200E+00, -.21771700E+01, 0.28607000E+02, 0.94378000E+00, 0.20118100E+01, 0.10848900E+00, -.17219500E+01, 0.27619400E+00, 0.17988700E+00, 0.13687900E+01, 0.19616100E+01, -.20396200E-01, 0.24144800E+00, 0.47758500E+01, 0.80477700E+01, 0.14413000E+02, -.27262000E+00, 0.14996500E+01, 0.26474800E+01, -.36619800E+00, -.94748800E+00, -.94965800E+00, 0.12178000E+01, 0.39515800E+01, -.23978300E+01, 0.24933300E+01, 0.49844100E+00, 0.21432600E+01, -.55805500E+01, -.96148200E+01, -.40362300E+00, 0.11858400E+01, 0.11225200E+01, -.15731400E+01, -.35508400E-01, 0.12796100E+00, 0.22560500E+00, -.19790300E+00, -.69104000E+01, -.75224200E+00, 0.10301200E-01, 0.75840700E+00, -.43325800E+01, -.24167400E+01, -.55429300E+00, 0.38307300E+00, -.10581000E+01, -.98365000E+00, 0.14881400E+01, 0.39555600E+00, 0.30625600E+00, 0.22437800E+00, 0.25521700E+01, -.37227800E+00, 0.79031200E+01, -.49015700E+00, -.31497000E+00, -.23043000E+01, 0.83462300E+00, -.91110100E+00, 0.36423000E+00, 0.70942200E+00, -.12045400E+01, -.75088800E+00, -.61841300E+00, 0.17516700E+00, 0.78141100E+01, 0.13094700E+00, -.19488300E+01, -.22326400E+01, 0.53921300E+00, -.12819200E+01, 0.16210900E+01, 0.90760500E-01, -.88854100E+00, 0.47950100E+00, -.24095700E+01, -.22395000E+01, -.20880000E+01, -.49647700E+00, 0.70252700E+00, 0.32933600E+00, 0.46550800E+00, 0.79103800E+00, -.12018000E+00, -.74951700E+00, -.10640200E+00, -.38052100E+00, -.10121800E+01, 0.60309300E+00, 0.22708900E+01, 0.38163200E+00, 0.64284900E+01, -.85335500E-01, -.10816600E+01, -.26619300E+01, 0.10555700E+01, -.62301500E+00, -.24935600E+00, 0.13920100E+00, -.21073000E+00, 0.12657100E+01, -.21056200E+00, -.12788000E+01, -.14661600E+01, -.18042800E+00, 0.55442600E-01, -.71526800E-01, -.68909200E+00, -.14609000E+00, -.64263200E+00, -.21694000E+01, 0.32708100E+00, -.31403300E+00, 0.34612900E+00, -.39427700E+00, 0.13445600E+00, -.28044300E+00, 0.40358200E+00, -.51415600E+00, 0.41208900E+00, 0.11349700E+00, 0.77782700E-01, -.14807500E+00, -.53907200E+00, -.69090800E+00, 0.63302000E+00, -.12818400E+01, 0.21461700E-01, 0.51301300E+00, -.77995500E-01, 0.75245400E+00, -.11934200E+01, 0.37237900E+00, 0.64217600E+00, -.46065700E+00, -.13246200E+00, -.71037200E-01, 0.21848700E+00, -.53638900E-01, 0.59025300E-01, -.23368500E+00, 0.28454200E+00, -.10671000E+00, -.11384200E+01, 0.36450500E+00, 0.12305400E+00, 0.54197100E+00, -.53813200E-01, 0.12252700E+01, -.29717900E+00, 0.29099200E+00, 0.21551400E+01, 0.59809100E+00, -.72914200E+00, 0.31925900E+00, -.14535900E+01, 0.13911300E+02, -.46070600E+01, 0.43521100E+01, -.13233900E+01, 0.10998100E+02, 0.59138600E+01, 0.30621500E+02, 0.45766500E+02, 0.21989000E+01, -.46592300E+00, -.46703800E+02, 0.72012500E+01, -.26050700E+02, 0.70938600E+01, -.79015600E+01, 0.17302600E+01, 0.28831700E+02, 0.35086100E+00, -.37109900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.11778200E+02, -.68947500E+01, 0.99768800E+01, 0.18355800E+02, -.69661200E+01, -.72351700E+02, 0.30445600E+01, 0.37681700E+00, -.40317800E+01, 0.20477100E+01, -.59657500E+00, -.15293100E+02, 0.28886100E+01, 0.21410800E+01, -.16169600E+01, 0.11459400E+02, 0.15252100E+01, 0.10586100E+00, 0.21695800E+00, 0.36781100E+01, -.20234700E+00, -.94129200E+00, 0.49021500E+00, 0.17519300E+01, 0.15416600E+00, 0.20483400E+01, 0.30703600E+00, 0.27917100E+02, 0.11641000E+01, 0.88906000E+01, 0.96241800E+00, -.64442300E+01, 0.31486300E+00, 0.16888200E+01, 0.38027400E+01, 0.19717300E+00, 0.64679600E+00, 0.25571000E+01, 0.24217600E+01, 0.52233900E+01, 0.13393200E+02, -.73979600E+00, -.21757700E+01, -.12698500E+00, 0.48229700E+00, 0.36962800E-01, -.55299600E+00, -.17493700E+01, -.38569100E+01, 0.12345200E+01, -.83491300E+00, -.78522800E-01, -.74489900E+00, -.10980000E+01, 0.11829600E+01, -.18318500E+00, 0.76118200E+00, -.51943400E+00, 0.54779900E+00, 0.71284400E+00, 0.17977200E+01, -.35243000E+00, -.29068500E-01, -.43425700E+01, -.13619000E+01, -.16677900E+01, 0.45993400E+00, 0.50611100E+01, -.92879600E-01, -.14979500E+01, -.14964500E+01, -.13464300E+01, 0.14551700E+01, -.73525600E+00, -.27501300E+00, 0.41862700E+00, -.52943200E+00, -.80724900E+00, 0.77690200E+00, -.22819300E+01, 0.12670500E+01, -.18361200E+01, -.88178800E+00, 0.11464400E+01, 0.20093800E+01, -.63520900E+00, 0.28369300E+00, -.32899900E+00, 0.12866400E+01, 0.78253800E+00, -.10586400E+01, -.77085300E+01, -.16162100E+01, -.11683800E+01, 0.19930800E+01, -.49328500E+00, 0.23146500E+00, 0.12113100E+01, -.67634100E+00, -.45704300E+00, 0.90729900E+00, -.92414800E+00, 0.77515500E+00, -.22813600E+01, -.77354300E+00, 0.17520700E+01, 0.53756200E+00, 0.75236200E+00, 0.22014100E+01, 0.48087600E+01, -.14151000E+01, 0.79367800E+00, 0.94044300E+00, -.17190200E+01, -.31253900E+00, 0.34412400E+01, -.31961700E+01, -.11260800E+01, 0.56387700E+00, 0.11522400E+01, -.39632000E+01, -.59779100E+00, 0.87471100E+00, 0.34666200E+00, -.89093700E+00, 0.13674900E+01, -.52139400E+00, 0.15874700E+01, 0.35358600E+00, 0.15448500E+01, 0.22318900E+00, 0.66592500E+00, 0.58838800E+00, -.72431000E+00, 0.68239200E+00, -.40240500E+00, 0.92791200E-01, 0.40681300E+00, 0.33240600E+00, -.55060500E+00, 0.48661800E+00, -.29633000E+00, 0.10359000E+01, -.24837000E+01, -.39084100E+00, -.46522500E+00, -.24251400E+00, -.93699900E+00, -.61793800E+00, -.50414800E+00, -.24385600E+00, 0.30322800E-01, 0.16432800E+01, -.11187400E+01, 0.28748700E+00, 0.12142100E+00, 0.24738800E+00, -.22082000E-01, 0.13142800E+00, 0.55227200E-02, 0.97472600E-01, -.16566000E+01, -.15173200E+01, -.45049600E+00, -.47644600E-01, -.25036100E+00, -.25292500E+00, 0.72217900E+00, 0.48036900E+00, -.19711200E+01, -.10648500E+01, 0.55878300E+00, 0.79353900E+00, 0.30764400E+00, -.21125200E+01, 0.19774600E+00, -.93939600E+00, -.91297900E+00, -.43186900E-01, -.29584900E+00, -.33230700E+00, -.45306100E+00, -.30447100E-02, 0.10663500E+02, 0.58252000E+01, -.78969500E+01, 0.65096400E+02, -.13421700E+02, -.60810600E+02, -.70663100E+01, -.55779300E+01, 0.11190300E+02, 0.79840200E+01, -.13837300E+02, 0.61949800E+02, -.14618600E+02, 0.12009500E+02, -.23400200E+00, -.60183100E+02, 0.90341200E+01, -.79938400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.89738600E+00, 0.32955600E+00, 0.48724400E+00, 0.19958800E+01, -.59295300E+00, -.10226900E+02, 0.40357200E+01, 0.12028400E+01, -.52564800E+00, 0.91573100E+00, -.18335200E+01, -.16238200E+01, 0.26864300E+00, -.53897500E+00, 0.47999000E+00, 0.87122900E+00, 0.25581400E+00, 0.56425000E+00, -.37870000E+00, 0.54469100E+00, 0.99824600E-01, 0.29401600E+00, -.64943600E-01, 0.20993500E+01, -.49775200E+00, 0.85999400E+00, -.13908500E+00, -.83088800E+01, -.48300000E-01, 0.10297500E+01, 0.37242400E+00, -.14422800E+01, -.68360400E+00, 0.40918700E+00, 0.76525400E+00, 0.62596400E+00, -.29229300E+00, -.47475200E+00, 0.82495400E+00, 0.13033100E+00, 0.61386300E-02, -.48810400E-01, 0.98611000E+00, 0.71472000E+00, -.19912000E+00, -.23697200E+00, -.27693600E+00, -.67773100E-01, -.33197200E+00, -.68199400E+00, -.13424700E+01, 0.56794800E-01, -.15447800E+00, -.45771400E+00, -.95310200E+00, -.17636900E+00, -.40573000E-02, -.15333700E+00, -.58418500E-01, -.12610700E+01, -.51945800E+00, 0.75256300E-01, 0.17088700E+00, -.19099100E+01, 0.36709700E+00, -.16024800E+00, -.60324700E-01, -.97601300E+00, 0.43215500E+00, 0.20773200E-01, 0.15298900E+01, 0.62523000E-01, -.32778900E-01, -.57432400E+00, 0.29803800E+00, -.21873200E-01, 0.80780400E-01, -.27591000E+00, 0.42482400E+00, -.20406300E+01, -.19320100E+00, 0.48953300E-01, -.75341100E-01, -.13867200E-01, -.16482800E-01, -.22202400E+00, 0.50210200E+00, -.18871300E+00, 0.41139900E-02, -.27582300E-01, -.21102300E+00, -.16441400E+01, -.75820600E-01, 0.22709100E+00, -.44121200E-01, -.34171400E+00, 0.51682700E+00, -.16925600E+00, -.25494400E+00, -.19186700E+00, -.15689800E+00, -.16008100E+00, 0.12837900E+00, 0.36218900E-01, 0.14154300E+01, 0.92482100E-01, 0.13864700E+00, -.93963100E-01, 0.19834300E-01, 0.23636900E+01, 0.12580000E-01, -.49890000E-01, -.48241600E+00, 0.16552400E+00, 0.10269700E-01, 0.18656600E+00, -.28483100E+00, 0.36427500E+00, 0.16510500E-01, 0.45240600E+00, -.17454600E+00, -.48376300E+00, 0.10886100E+00, 0.13104400E+00, -.13957300E+00, 0.77753400E+00, -.40168100E+00, -.68462800E-01, -.67799200E-01, 0.69796800E-01, 0.13358600E+00, -.20517900E+00, 0.18408600E+00, -.16951600E+00, 0.53844600E-01, -.14794700E+00, 0.32154800E+00, -.26574500E+00, 0.18628800E-01, 0.25420000E-01, -.46218400E-01, 0.91931600E-02, 0.37561500E-01, 0.40035800E+00, -.75314700E-02, 0.12379300E+00, 0.20044100E-01, 0.15457900E+00, 0.16491500E+00, -.12128400E+00, -.31377200E-01, -.30561100E-01, 0.59881000E+00, 0.13173900E+00, -.49860500E-03, 0.13458300E-01, 0.11710000E-01, 0.22070800E+00, -.36735000E-01, -.21900300E-01, 0.99622800E-02, -.15437600E+00, -.23331700E-02, -.70668000E-01, -.22492600E-01, 0.51486200E-01, 0.92332200E-01, -.15401200E+00, -.62370700E-01, 0.18205200E+00, -.30818100E+00, -.96872400E-01, 0.11046400E+00, 0.17130700E-01, -.16972100E-01, 0.12460000E-01, 0.12705600E+00, 0.88732300E-01, 0.10723700E+00, -.25281200E+00, -.22282500E-01, -.50535800E-01, -.74074200E-01, -.79201400E-02, 0.92926600E+00, 0.24751100E+01, -.16513700E+02, 0.21591100E+01, 0.84601800E+00, -.22019600E+02, 0.62591400E-01, -.23390000E+01, 0.22180500E+02, 0.16340700E+01, -.97591300E+00, 0.23564100E+01, -.12774500E+01, -.21861700E+00, 0.70815500E+00, 0.17207200E+00, 0.11962300E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.10443000E+02, -.87358000E+01, -.52335400E+01, -.12398300E+02, 0.48460100E+01, 0.51877600E+02, 0.13536800E+02, 0.12459800E+02, 0.30906900E+01, -.14225500E+01, 0.17354900E+01, 0.48512800E+01, -.35776600E+01, -.16006500E+01, 0.68220700E+00, -.38944400E+01, -.10853400E+01, -.10829400E+01, -.11994300E+01, 0.20371400E+01, 0.11805900E-01, 0.13193200E+01, -.73780700E+00, -.45282800E+01, -.30041300E+00, -.64605100E+00, -.96272800E+00, 0.23008100E+02, 0.33390100E+00, 0.41968200E+01, 0.42828500E+00, -.23316800E+01, -.11162700E+01, -.73713400E+00, 0.73819000E-01, -.12018700E+01, 0.32038500E+00, 0.36062500E+01, 0.56296400E+00, -.71082100E+00, 0.72785600E+01, 0.92659600E+00, -.10490100E+01, 0.20587900E+01, 0.99995400E+00, -.23348400E+01, 0.10916200E+01, 0.20078800E+01, 0.22710300E+01, -.45753400E+00, 0.18924900E+01, -.17226300E+00, 0.20547500E+01, 0.13695600E+01, -.81226800E+01, 0.15629600E+01, 0.15887800E+01, -.17561500E+01, 0.73176400E+00, 0.46816200E+01, -.14382700E+01, 0.17323500E+01, -.53352700E+00, 0.34659400E+01, -.33979500E+00, -.27059500E+01, 0.79660600E+00, 0.21469700E+01, 0.45562900E-02, -.24597400E+00, -.25001800E+00, -.31361000E+00, 0.51533800E-01, -.19162200E+00, -.41203200E+00, 0.19643200E+00, -.21991100E+00, 0.22447600E+01, 0.62296500E-01, 0.53748900E+01, 0.16614600E+00, -.47318700E+00, 0.31769300E-02, -.10445100E+00, 0.65537400E-01, 0.68506300E+00, 0.26038000E+00, 0.33342200E+00, 0.20746300E+00, 0.36436300E+00, 0.93543900E-01, 0.21934000E+01, 0.47513300E-01, 0.54551000E+01, -.64875500E+00, 0.12407700E+00, -.68256300E+00, -.65037600E+00, 0.26695500E+00, 0.88300100E+00, 0.71100000E-01, 0.90059300E+00, 0.63539600E+00, 0.16100000E+01, -.22519300E+01, -.50633900E+00, -.19476200E+00, 0.57280200E-01, -.17484100E+00, 0.54245400E+00, 0.51904200E+00, 0.24127200E+00, 0.27345300E+00, 0.45195600E+00, -.26399900E+00, -.84797300E+00, 0.35990100E+00, 0.19771800E+01, 0.28592300E+00, -.12088900E+01, 0.13904100E+01, 0.14935000E+01, -.10434200E+01, -.28228600E+00, 0.36823800E+00, -.22131100E+01, 0.11881300E+01, 0.88838900E+00, 0.89641700E+00, -.27431500E+00, -.60412900E+00, 0.78332700E+00, -.10584700E+01, 0.11027100E+01, -.46287300E-01, -.49923000E+00, -.10273000E+01, 0.43158500E+00, -.42524500E+00, 0.64095400E-01, -.24795300E+00, 0.21391000E+00, -.13716600E+00, -.26448100E+00, -.40696100E+00, -.10446400E+00, 0.52489100E-01, 0.15197700E+00, 0.36922100E-01, -.56106000E+00, -.10211300E+00, -.26912000E+00, 0.94497600E+00, -.25405900E+00, -.18017500E+00, 0.95618700E-01, 0.16513200E+00, -.26319600E-01, -.20651300E+00, -.27742600E+00, -.12438900E+00, 0.27081100E+00, -.28791700E+00, 0.92487300E-01, 0.21731600E+00, 0.15912200E+00, -.21905100E+00, 0.34534500E+00, 0.24170900E-01, -.12075100E+01, -.26191300E+00, 0.28808900E+00, 0.55249000E+00, 0.21414800E+00, 0.92667800E+00, -.85673100E-01, 0.23032500E+00, 0.10646700E+01, -.14852200E+00, -.56057600E+00, 0.33361900E+00, -.60247600E+00, 0.14141100E+00, 0.28135300E+00, 0.47072800E+01, -.18793500E+02, 0.10113000E+03, -.10487700E+02, 0.60298500E+00, 0.14537300E+03, -.17856800E+00, 0.14594900E+02, -.14676700E+03, -.81493700E+01, -.68027000E+00, -.10344700E+02, 0.58072900E+01, 0.22370500E+01, 0.16361600E+01, 0.16808700E+01, -.73087800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.14081300E+02, 0.19850800E+01, -.11076300E+02, -.18371000E+02, 0.97174700E+01, 0.73222900E+02, 0.84442000E+00, 0.73672800E+01, 0.43187700E+01, -.15223400E+01, 0.44093900E+01, 0.13956200E+02, -.44738700E+01, -.20580500E+01, 0.20347800E+01, -.11141700E+02, -.17249000E+01, -.13279600E+01, 0.69252600E+00, -.25902700E+01, 0.22762000E+00, -.80801500E+00, -.23117200E+00, -.21710800E+01, -.16714800E+01, -.12281300E+01, 0.84299400E-01, 0.52800400E+01, -.18968800E+00, -.77382600E+01, -.95050900E+00, 0.46222300E+01, 0.11888300E+01, -.85414400E+00, -.39870400E+01, 0.24674100E+01, 0.12073500E+01, -.14492500E+01, -.23819900E+01, -.37105200E+01, -.26787300E+02, -.21211300E+00, 0.58794300E+01, -.35420900E-01, -.17187600E+01, 0.73014000E+00, -.75512300E+00, 0.33747500E+00, 0.37372700E+01, -.27519800E+01, 0.24774500E+01, 0.54450600E+00, -.40926400E+00, -.43062000E+00, 0.64733500E+01, -.12132600E+01, 0.63729700E+00, 0.34493500E+01, -.13705400E+01, 0.92018300E-01, -.11020000E+01, 0.10885500E+01, 0.44463300E+00, 0.76602200E+00, 0.15585300E+01, 0.16376400E+01, -.11607800E+01, -.30328400E+01, 0.73585300E+00, 0.57007500E+00, 0.12496800E+01, 0.15853300E+01, -.14995300E+00, -.28998500E+01, -.47903100E+00, -.14561300E+01, 0.23491100E+01, 0.74945700E+00, -.24048700E+01, 0.80630800E+01, -.24073500E+01, -.55641900E+00, -.44018800E+01, -.16498700E+01, -.24060400E+01, 0.88377800E+00, 0.27311500E+00, -.39297600E+01, 0.54062100E+00, 0.40360800E+00, -.21629600E+00, -.10356900E+02, 0.60952600E+00, -.12582000E+02, 0.31758700E+01, -.14218700E+01, 0.46305300E+01, -.13357200E+01, -.14332900E+01, -.21258400E+01, -.66515000E+00, 0.23898600E+01, 0.63268600E+00, 0.14590000E+01, -.34290900E+01, 0.17913300E+01, 0.11757500E+00, 0.21810600E+00, -.42579800E+00, 0.48025300E+01, -.21287700E+01, -.71806300E+00, -.41842400E+01, 0.92565100E+00, -.61228700E+00, 0.20835700E+01, -.30883400E+01, -.87046600E+01, 0.65723500E-01, 0.48359200E+01, 0.26224500E+01, -.38171300E+01, -.29357900E+00, 0.63941400E+00, -.56353800E+00, 0.30633900E+01, -.44588800E+00, -.30260500E+01, 0.24371100E+01, 0.31874300E+00, 0.15309500E+01, 0.86688700E+00, 0.25513100E+01, 0.68191000E+00, -.10622400E+01, 0.63881500E-01, -.20452300E+01, 0.65471200E+00, -.79190200E-01, -.88225900E+00, 0.20061100E+01, -.49604400E+00, -.45368700E+00, 0.28473800E+01, 0.11419500E+01, 0.29777700E+00, 0.56756100E-01, 0.13407900E+00, 0.38129700E+00, 0.19704100E+00, 0.17245100E+00, 0.89026300E+00, -.33943100E+01, 0.25474000E+01, 0.36857000E+00, 0.21973800E+00, -.14824100E+01, -.10131300E+01, 0.41966100E+00, 0.10873000E+01, 0.11987300E-01, 0.96880600E-01, 0.11776900E+01, 0.62431000E+00, -.99075400E+00, -.33756200E+00, 0.18400000E+00, -.91250500E-01, 0.27838300E+00, -.17243800E+00, 0.23045600E+01, -.21830100E+00, -.44826900E+00, -.25024100E+00, -.15764600E+01, -.29653200E+00, -.91308100E+00, -.53310300E+00, 0.39977400E-01, -.21069300E+00, 0.53380300E+00, -.10620700E+01, 0.37005700E+00, 0.10049000E+00, 0.39094900E+01, 0.60993600E+00, -.71852700E+02, -.18948000E+01, -.16608900E+01, 0.66781300E+01, -.84507200E+00, 0.15031600E+02, -.59454400E+01, -.77988400E+00, 0.21579900E+01, -.87200100E+01, 0.30398500E+01, -.11560500E+01, -.44443900E+01, 0.38323400E+01, -.54470300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.48167400E+01, -.16661200E+01, 0.24559600E+01, 0.40669100E+01, -.18484000E+01, -.16666200E+02, -.50001200E+00, -.51448800E+01, -.91432400E+00, 0.45048700E+00, 0.42332500E+00, -.16616400E+01, 0.16934700E+01, 0.47154400E+00, 0.15278500E+00, 0.17414100E+01, 0.50596000E+00, 0.25412100E+00, -.58210400E+00, 0.12832200E+00, -.55053500E+00, 0.10820500E+01, 0.34937700E+00, 0.18661400E+01, 0.37508400E-01, 0.74600800E+00, -.38524600E+00, -.17790900E+02, -.81904400E-01, 0.88801600E+00, 0.28667200E+00, 0.58363700E-01, -.39127400E+00, -.57407800E-01, 0.87207100E+00, -.37595700E+00, -.68862700E+00, -.13659000E+00, -.58656200E-01, -.36580800E+00, -.19178900E+01, -.10011500E+00, -.77181000E+00, 0.47035700E+00, 0.69245700E+00, 0.46808400E+00, 0.15494200E+00, -.40825500E+00, -.11630000E+01, 0.34789900E+00, -.10592900E+01, 0.23647200E+00, -.45864900E+00, 0.83113200E+00, -.17043900E+00, 0.25520600E+00, -.29706400E+00, -.86580300E+00, 0.33348200E+00, -.85903700E+00, 0.25719900E+00, -.18832300E+00, 0.11960000E+00, -.11573800E+01, 0.42978400E+00, 0.10566800E+01, -.25944200E+00, -.10516100E+00, 0.12108200E+00, 0.84943000E-01, -.61530200E-02, -.18609600E+00, -.39528800E+00, 0.90076600E+00, 0.27786100E+00, -.46345700E-02, -.11751900E+00, 0.44037300E+00, -.75139600E-02, -.20173300E+01, 0.11173000E+00, -.42500400E+00, 0.88725200E+00, 0.47736900E+00, 0.23848600E+00, -.11755700E+00, -.19821800E+00, -.19393900E+00, -.83233900E-01, -.42180800E+00, 0.37603700E-02, 0.51036100E+00, 0.46010800E-01, 0.18444500E+00, -.71443100E+00, -.17445700E+00, -.28150200E-01, -.11016900E+00, -.97280900E-01, -.26284900E-01, -.58613100E-01, -.97662200E+00, -.25051200E+00, -.22852900E+00, 0.17956400E+01, 0.17621500E+00, 0.33331200E+00, -.12581100E+00, -.18926200E+00, -.23600800E+00, 0.26639100E+00, -.64670500E-01, 0.19557500E+00, -.14280400E+00, 0.95567100E-01, -.25222400E+00, 0.32962300E+00, 0.37183200E+00, -.12156700E+00, -.18198100E+00, -.43847600E+00, -.20682400E+00, 0.13396500E+00, 0.23814600E-01, 0.67936800E-01, 0.16784100E+00, 0.34450300E-01, -.27418700E+00, -.19090800E+00, 0.42221700E-01, -.65722700E-01, -.27286700E+00, -.59011300E-01, -.95447100E-01, 0.23571300E-02, 0.99018400E-01, 0.10872900E+00, -.17019400E+00, -.12432900E-01, -.12377700E+00, 0.49200300E-01, 0.81449600E-01, -.16278000E+00, 0.64941100E-01, 0.29123400E+00, -.12690800E+00, 0.11744200E+00, 0.26110600E+00, 0.19424500E+00, -.17158000E+00, -.48270800E-01, -.51633200E-01, 0.27262400E+00, -.35005800E-01, -.80383600E-01, -.41387800E-01, 0.17093000E+00, 0.10045800E+00, -.79611000E-01, -.53290700E-01, 0.22909300E-01, 0.93577200E-01, 0.24588300E+00, -.10908100E+00, 0.90605400E-01, 0.11002000E+00, -.22863600E-01, 0.61725800E-01, 0.42835500E-02, -.10194300E+00, -.75315100E-01, 0.58134100E-01, 0.11348100E-01, 0.21949200E-01, 0.16550700E-02, -.17003500E-01, 0.79923100E-02, -.72946400E-01, 0.25140900E-01, -.16340100E-01, 0.24215700E-01, 0.50637700E-01, -.70995600E-01, 0.17468600E+00, -.27510700E+00, -.60114100E-01, 0.95368100E-01, 0.34792200E+01, 0.11560100E+02, -.18482600E+01, 0.38486100E+00, -.23680000E+01, 0.15770100E+01, 0.34857700E+01, -.11729800E+02, 0.48696600E+01, -.35473200E+01, 0.12554000E+00, 0.11744100E+02, -.83311200E+00, 0.55922600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.66917000E+01, -.34294500E+01, 0.37084900E+01, 0.65704200E+01, -.27831800E+01, -.31760200E+02, -.50322000E+00, -.67825400E+01, -.17424500E+01, 0.80105200E+00, 0.30819100E+01, -.17463000E+01, 0.27820600E+01, 0.38796400E+00, -.92253900E-01, 0.20093400E+01, 0.55565200E+00, 0.10290200E+00, 0.83372300E+00, 0.76350700E+00, -.48875000E+00, 0.28655600E+00, 0.52169000E+00, 0.30397900E+01, -.19248400E+00, 0.33128300E+00, 0.60566600E+00, -.17905600E+02, -.68890200E+00, -.13077800E+01, 0.23369400E+00, 0.15227800E+01, 0.12556000E+00, -.11735200E+00, 0.92659300E+00, -.48110900E+00, -.94544500E+00, -.10487600E+01, -.71383900E+00, -.15583500E+01, 0.26441200E+01, 0.46621400E+00, -.11995000E+01, -.13642300E+01, -.23028200E-01, 0.86636400E+00, 0.97708000E+00, -.38981000E+00, -.10576000E+01, 0.15030300E+01, -.75291500E+00, 0.55099500E+00, -.14448900E+00, 0.30829400E+01, -.69427800E+00, 0.50919200E+00, -.10914200E+01, -.10592000E+01, 0.22041800E+00, -.19523200E+01, -.16486900E+00, 0.88432900E-01, 0.36488900E+00, -.28563000E+01, 0.43865900E+00, 0.11408400E+01, -.35412100E+00, -.44656100E-01, 0.15428800E+00, -.25587300E-01, 0.99300000E-01, -.73367500E-01, -.16015400E+00, 0.66168600E-01, 0.36415800E-01, 0.13591500E+00, -.22210800E+00, -.29131300E+00, 0.29538100E-01, 0.14391100E+01, -.34483800E+00, -.88214600E+00, 0.59981100E+00, 0.48188900E+00, 0.20361200E+00, 0.14378100E-01, 0.11565000E+00, 0.30951400E+00, 0.18358100E+00, 0.37621900E-01, -.79659700E-01, 0.28179300E+00, -.17514000E+00, 0.13971600E+01, -.65256600E+00, -.47702400E+00, 0.65283100E-02, 0.91390400E-01, -.18090500E+00, -.72647500E-01, -.94642700E-02, -.78841400E+00, -.21969600E+00, 0.15071100E+00, 0.91982000E+00, 0.39980000E+00, 0.26192200E+00, 0.16506200E+00, 0.45052700E-01, 0.96415500E+00, 0.21039200E+00, -.11820000E+00, 0.15948600E+00, -.40720800E+00, 0.13525800E+00, 0.30773400E+00, -.36805300E+00, 0.13003100E+01, -.48097200E-01, -.25856500E+00, -.10693000E+01, -.34396400E+00, 0.42260200E+00, 0.94989000E-01, -.85550600E-01, 0.16471600E+00, 0.15228000E+00, -.42303400E+00, -.38119100E-01, 0.47004700E-01, 0.59128400E-01, -.71814600E+00, 0.21961600E+00, -.15528900E+00, 0.28389100E-01, -.52257900E+00, -.13198000E+00, -.31241200E+00, -.92084800E-01, -.17284300E+00, 0.80495700E+00, 0.63262700E-01, -.80704800E-01, 0.13239200E+00, 0.56509400E+00, -.23572600E+00, 0.28250400E-03, 0.68585300E-01, 0.32617500E+00, -.27198300E+00, -.84414300E-01, -.22962200E+00, 0.43136700E+00, -.23242700E+00, -.18063600E+00, -.10399700E-01, 0.21581600E+00, 0.17918900E+00, -.15684500E+00, -.20491800E+00, 0.47462600E-01, -.75760800E-01, 0.22836800E+00, -.24559800E+00, 0.10232500E+00, 0.10493900E+00, -.16085700E+00, 0.32875000E+00, 0.13728200E+00, -.55253000E+00, -.29992000E+00, 0.21624800E+00, 0.18890600E+00, 0.50101400E-01, -.13505600E+00, 0.39739500E-02, -.10357900E+00, -.44636300E-01, 0.96323300E-01, -.91024000E-01, 0.76923600E-01, -.16002500E+00, -.25469600E-01, 0.77647300E-01, 0.14094900E+01, 0.35132700E+00, 0.66370600E-01, 0.71030000E+00, -.11973600E+02, -.25849300E+02, 0.61182900E+00, 0.24585100E+01, 0.26254500E+02, -.23154900E+00, 0.12111700E+02, -.72322000E-01, 0.10432300E+00, -.64476700E+00, -.12022800E+02, -.42692100E+00, 0.79542700E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.44874700E+01, -.39817200E+01, -.26479000E+01, -.81331100E+01, 0.33470900E+01, 0.28692600E+02, -.12232600E+02, 0.13702500E+00, 0.15764800E+01, -.18427100E+01, -.16417600E+01, 0.57220600E+01, -.18063100E+01, 0.65459400E-01, -.25759300E+00, -.37397900E+01, -.83713900E+00, -.87938100E+00, 0.16917800E+01, -.52900700E+00, 0.46542300E+00, -.13501700E+01, -.61698000E+00, -.37419600E+01, 0.11492300E+01, -.23735200E+01, 0.14370700E+00, 0.71640900E+01, -.10164400E+01, -.93507700E+00, -.92804100E+00, 0.54348200E+00, 0.13614300E+01, -.44015600E+00, -.11353700E+01, 0.56134700E-01, 0.12083000E+01, 0.10261000E+00, -.50509500E+00, 0.43089000E+00, 0.14916700E+02, 0.53011300E+00, -.63038100E-01, -.35427400E+00, -.15808000E+01, 0.44938100E+00, 0.80669500E+00, -.10778900E+01, -.17771700E+01, 0.39193500E+00, -.96586600E+00, -.17951800E+00, -.78378500E-01, 0.75324600E+01, 0.52685900E+00, 0.27993400E+00, -.40578400E+00, -.88833600E+00, 0.37284100E+00, 0.40895300E+01, 0.10315500E+01, 0.15373000E+01, 0.17671800E+00, 0.29984300E+01, 0.26963800E-01, -.12065900E+01, -.18118600E+00, 0.49682300E+01, 0.69057600E+00, -.13816800E+01, 0.13824100E+00, 0.47127900E+00, 0.11622600E+01, -.14657000E+01, -.10107700E+01, -.37848600E+00, 0.46623300E+00, -.38318200E+00, -.43374800E+00, -.42041900E+01, 0.11210000E+01, 0.27563600E+01, -.15829600E+01, -.35343800E+00, -.62272200E+00, -.75066100E-01, 0.40894700E+00, -.19599100E+01, 0.16204800E+01, 0.10097000E+01, -.12438100E+00, -.17351200E+01, 0.29551400E-01, -.53806300E+01, 0.10322500E+01, 0.18157400E+00, 0.21452600E+00, 0.27524200E-01, -.48896200E+00, -.84183400E+00, -.35675600E+00, 0.48945300E+00, 0.65514800E+00, -.16181300E+01, 0.66355400E+01, -.15380200E+00, 0.59179100E-01, -.90982800E+00, 0.45400900E+00, 0.33813100E+01, -.23735200E+00, 0.43242500E+00, -.76514800E+00, 0.46179700E+00, 0.30007800E+00, -.25811000E+00, 0.11804300E+01, 0.28750400E+01, -.35252700E+00, 0.57615400E+00, -.20680500E+00, -.31643300E+00, 0.20337900E+00, -.58940000E-02, -.39477800E+00, 0.56883100E+00, -.92169800E-01, -.31168300E+00, 0.54437300E+00, -.10899700E+01, 0.63734400E+00, 0.24753600E+00, 0.90880300E+00, -.24504500E+00, 0.24028600E+00, -.36332300E+00, -.11892900E+01, 0.71255800E+00, -.73213500E-01, -.49883500E+00, 0.61101600E+00, 0.72267200E-01, 0.24336600E+00, -.13443200E+01, -.19571700E-01, -.29536400E+00, -.35936700E-01, -.39607500E+00, -.84090100E+00, -.69930500E+00, 0.22041200E+00, -.15415400E+00, 0.25267400E+01, 0.64424100E+00, -.24812700E+00, -.47344100E-01, -.33594100E-01, -.69698500E-01, -.35458800E+00, 0.12674500E+00, -.72754600E-01, -.20167900E-01, 0.12139300E+00, -.14223300E+00, -.95986400E-01, -.25637500E-01, -.10879900E+00, 0.21041300E+00, 0.15746300E+00, 0.36385100E-01, 0.42339700E-01, -.15015100E-01, -.12369900E+00, -.11181600E+00, -.62684900E+00, -.24985300E-01, -.16829900E+00, -.41322900E-01, 0.92288800E-01, -.27797400E+00, 0.46432000E-01, -.24193200E+00, 0.10390200E+00, 0.17994300E+00, 0.69294400E+00, 0.14401600E+00, 0.46028400E+00, 0.41919900E+00, -.46902900E+00, -.41791100E+02, -.13617900E+00, -.18855100E+01, 0.42124800E+02, -.84813200E+00, -.49715900E+00, 0.13793100E+01, 0.97592100E+00, -.53091700E+00, 0.61375800E+00, -.14123000E+00, 0.10890400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.36556000E+01, 0.15894800E+01, -.23107200E+01, -.28074200E+01, 0.17312300E+01, 0.10657600E+02, 0.29513600E+01, 0.44917800E+01, 0.64168100E+00, 0.51369600E-01, 0.19535300E+00, 0.18190100E+01, -.13062500E+01, -.46926500E+00, 0.87187800E-01, -.17382800E+01, -.44043500E+00, -.16246300E+00, 0.25545600E+00, -.13334200E+00, 0.29583800E+00, -.62006600E+00, -.17633000E+00, -.89630400E+00, 0.65663000E-01, -.27097300E+00, 0.34008600E+00, 0.10099600E+02, 0.14691800E-01, -.94509700E+00, -.79802300E-01, -.33786200E+00, 0.34334800E+00, 0.11956500E+00, -.15484700E+00, 0.33886200E+00, 0.50911500E+00, -.13187400E+00, 0.32475500E+00, -.83410700E-01, 0.20564100E+01, 0.14096300E+00, 0.51392000E+00, -.30922100E+00, -.51588700E+00, -.12252800E+00, -.63126500E-01, 0.27665800E+00, 0.80923500E+00, -.37874400E+00, 0.45087300E+00, -.24188200E+00, 0.13719600E+00, -.16745400E+00, 0.19800600E+00, -.26379000E+00, 0.94970400E-01, 0.28870600E+00, -.10449400E+00, 0.26154900E+00, -.17431700E+00, -.91424700E-01, -.22663400E+00, 0.17227400E+01, -.23889300E+00, -.92507900E+00, 0.23139700E+00, 0.21741300E+00, 0.11156800E+00, -.12848000E+00, 0.34158200E+00, 0.28521700E-01, 0.30790500E+00, -.32552200E+00, -.28712500E+00, -.75212300E-01, -.69739600E-02, -.13272900E+00, 0.79060500E-01, -.76583900E+00, 0.63640500E+00, 0.28521600E+00, -.42358200E+00, -.17749100E+00, -.64447100E-01, -.30737600E+00, 0.38790300E+00, -.78447500E-01, -.13218200E-01, 0.31575100E+00, -.16556200E+00, 0.40816600E-01, -.19539300E+00, -.97012300E+00, 0.46022900E+00, 0.16019300E+00, 0.69355200E-01, -.80939900E-01, 0.44385500E-01, 0.74254600E-02, 0.47125800E-01, 0.32914100E+00, 0.13817300E+00, 0.78067200E-01, -.14236800E+01, -.78379100E-01, -.10739900E+00, 0.18601400E+00, 0.14115600E+00, 0.73678900E-01, -.16264300E+00, 0.69356300E-01, -.12141900E+00, 0.65536100E-01, -.71107000E-01, 0.18734900E+00, -.11590500E+00, -.43175400E+00, 0.61916200E-01, 0.26127300E+00, 0.31082100E+00, 0.13008300E+00, -.31934000E+00, -.46284300E-01, -.30479500E-01, -.11321400E+00, -.41902800E-01, 0.29411200E+00, -.40792300E-02, -.10388600E+00, 0.11934100E-01, 0.28001100E+00, 0.34990700E-01, 0.10526500E-01, 0.59284800E-01, -.33732900E-01, -.64588500E-01, 0.15738800E+00, 0.23859200E-01, 0.65932400E-01, -.19351600E+00, -.49830200E-01, 0.11420000E+00, -.21304500E+00, -.15339200E+00, 0.33799800E-01, -.30151500E-01, -.97686600E-01, -.77277900E-01, 0.73765600E-01, 0.11074100E+00, 0.58083700E-01, 0.79493000E-01, 0.11471100E+00, 0.10286800E+00, 0.33848300E-01, -.80880200E-01, -.75303900E-02, 0.49248900E-01, 0.27698900E-01, -.21528300E-01, -.32024600E-01, -.28169300E+00, 0.11691500E+00, -.12129000E+00, -.11770900E+00, 0.25815400E-01, 0.71483000E-02, 0.32911000E-01, -.17360600E+00, 0.39853400E-02, -.67538500E-01, 0.16799400E+00, -.31302800E-01, -.24546200E-01, -.22932600E-01, -.22556400E-01, -.12828700E-01, -.41599400E-01, 0.45085800E-01, -.24653400E-01, -.88800900E-02, 0.57157100E-01, -.10843800E+00, -.13958100E+00, -.22074900E-01, -.61230400E-01, -.60679700E+00, -.11636300E+00, 0.94581000E-02, 0.38986200E+00, 0.13819100E+00, 0.26868300E-01, 0.13953800E+00, 0.72816700E-01, -.53657400E-01, -.13869900E+00, -.47530800E-01, 0.10132800E-01, -.25621900E+00, 0.81270400E-02, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.28246100E+02, -.39974200E+01, 0.17312500E+02, 0.31241000E+02, -.16365100E+02, -.14623600E+03, -.18748400E+01, -.27686700E+02, -.83743100E+01, 0.31727300E+01, 0.60328600E+01, -.13439300E+02, 0.11738700E+02, 0.21054600E+01, -.56421100E-01, 0.13056700E+02, 0.28709600E+01, 0.85394000E+00, -.25071100E+01, 0.34685100E+01, -.32515800E+01, 0.61657600E+01, 0.23557200E+01, 0.14028400E+02, -.12066400E+01, 0.50203500E+01, 0.22901200E+00, -.76968700E+02, -.31258100E+01, -.15458100E+00, 0.19029100E+01, 0.23498100E+01, -.26017200E+01, -.76406900E+00, 0.48166300E+01, -.57265500E+01, -.50732600E+01, -.17409300E+01, -.24354700E+01, -.11438300E+02, 0.99283000E+01, 0.25743000E+01, -.87333000E+01, -.56219300E+01, 0.36885200E+01, 0.16640700E+01, 0.39140300E+01, 0.19045200E+01, -.14789500E+01, 0.65947600E+01, -.29549900E+00, 0.36786800E+00, 0.11626700E+01, 0.60902500E+01, -.10302900E+02, 0.32852100E+01, -.39035000E+01, -.73031900E+01, 0.27646800E+01, -.34298800E+01, -.28272600E+01, -.30172200E+01, -.24491900E+00, 0.81476800E+01, 0.31424100E+00, 0.22555500E+00, 0.13952300E+01, 0.23548400E+01, 0.16196800E+01, -.92347700E+00, -.22761700E+00, -.18820500E+01, -.20842100E+01, 0.92860100E+01, 0.41724400E-01, 0.10828200E+01, -.29503600E+01, -.61930300E+00, 0.96340900E+00, -.20943200E+02, 0.59044000E+01, 0.14844900E+01, 0.98183800E+01, -.11357800E+01, 0.10760200E+01, -.33369000E+01, 0.39842800E+00, 0.28786000E+01, -.18847400E+01, -.41765700E+00, 0.10760100E+01, 0.12521200E+02, -.86103900E+00, 0.79356400E+01, -.44312900E+01, 0.17645500E+01, -.54965000E+01, 0.31555000E+01, 0.10880600E+01, 0.24581100E+01, 0.47962500E+00, -.74065800E+01, -.25588500E+00, 0.21440000E+01, 0.33815100E+01, -.87751400E+00, 0.12691000E+01, -.29225100E+00, -.17393400E+01, -.14661000E+01, 0.16374600E+01, 0.71735300E-01, 0.19319100E+01, -.11143700E+01, 0.56323400E+00, -.12998800E+00, 0.10909300E+01, 0.31110000E+01, -.28090800E-01, -.30476900E+01, -.28582400E+01, 0.32250300E+01, -.50800800E+00, -.82729100E+00, 0.64248900E+00, -.28578500E+01, 0.15364300E+01, 0.10079900E+01, -.25405200E+01, 0.59496700E+00, -.15908500E+01, -.27827600E+01, -.43891900E+01, -.14799700E+00, -.57301000E-01, 0.91501100E+00, 0.35944600E+00, -.86079300E+00, -.56475000E+00, -.15054100E+01, 0.21216300E+01, 0.38534200E+00, -.14826100E+01, -.35257700E+01, 0.34282000E+00, -.71657700E+00, 0.36782700E+00, 0.96863100E+00, 0.22067900E+01, -.20882900E+00, 0.87524400E+00, 0.71194700E-01, 0.81638200E+00, 0.79989500E+00, 0.34009800E+00, -.50605500E-02, 0.17418100E+01, 0.27542700E+00, -.87126000E-01, 0.79135000E+00, -.62157900E+00, 0.29021200E+00, -.20510900E+01, -.21518400E+00, -.82444500E+00, -.21164500E+00, 0.13945600E+01, -.76972400E+00, -.98778600E+00, -.10457800E+01, 0.46181900E+00, -.35565300E+00, 0.91675600E+00, 0.78471200E+00, -.43636000E+01, -.33812900E+00, -.10170300E+01, -.22303100E+01, 0.75189100E+00, -.35585200E+00, -.19654800E+00, 0.59172600E-02, -.76167600E+00, -.21915600E+00, 0.32205500E+01, 0.35282400E+00, -.17342400E+01, 0.96458700E+00, 0.73436100E+00, 0.15981900E+01, 0.47073800E+00, 0.40135500E+02, 0.12478300E+01, 0.34686900E+01, 0.46290100E+01, -.14409000E+02, -.28962100E+01, -.18943900E+01, -.65164000E+01, 0.88850000E+01, 0.59912900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.65136400E+01, -.77958600E+00, 0.35360500E+01, 0.66824200E+01, -.25479700E+01, -.34159100E+02, -.47792200E+01, -.53782600E+01, -.19505000E+01, 0.63733600E+00, 0.74305300E+01, -.17576000E+01, 0.22501500E+01, 0.68278800E+00, -.22511200E+00, 0.17577700E+01, 0.52704400E+00, 0.22467700E+00, 0.10215800E+01, 0.51248900E+00, -.31928500E+00, -.25331300E-01, 0.58409500E+00, 0.22290300E+01, -.72002900E+00, 0.70252900E+00, 0.10111100E+01, -.32746400E+01, 0.82760000E+00, -.21003700E+01, 0.41490100E+00, 0.19440700E+01, 0.52666000E+00, -.12869900E-01, 0.89714300E+00, -.44713500E+00, -.93846300E+00, -.11722300E+01, -.54195800E+00, 0.93002900E+00, 0.79624200E+00, 0.23790200E+00, -.72179800E+00, -.17786200E+01, -.21144300E+00, 0.79120400E+00, 0.74202200E+00, -.33019700E+00, 0.45202800E-01, 0.11676900E+01, 0.12555200E+01, 0.92789100E+00, -.35468200E+00, 0.24324400E+00, 0.98389000E+00, -.19811700E-02, -.62209400E+00, 0.51683300E+00, -.27649300E+00, -.11850100E+01, -.90722900E+00, 0.11356300E+00, 0.77184900E-01, -.22584600E+01, 0.39091700E+00, 0.14739500E+01, -.31304400E+00, -.28159900E+01, -.45243700E+00, 0.89254100E+00, -.45673400E-01, 0.41287700E+00, -.21993000E+00, -.40037700E+00, 0.50006500E+00, 0.95047800E-01, 0.11128100E+00, 0.16095000E+01, 0.51613200E-01, 0.79482200E+00, 0.29491800E+00, -.15581100E+01, -.17827300E+00, 0.46400800E+00, -.40020400E-01, 0.14243800E+00, 0.17549800E+01, 0.50592500E+00, -.56238600E-01, 0.85324800E+00, 0.13497700E+00, 0.41425700E+01, 0.36439300E-02, 0.18214600E+01, -.16834300E+01, 0.59177400E-01, -.76566300E+00, 0.26295600E+00, -.10767000E+00, -.57903300E+00, -.98790500E-01, -.68504100E+00, -.34242600E+00, -.95847300E+00, 0.28306800E+01, 0.34951300E+00, 0.33216800E-01, -.33164100E-01, 0.65118900E+00, -.47085000E+00, -.26957400E+00, 0.54161500E+00, 0.79986200E+00, -.58633100E+00, 0.46197600E+00, 0.10007200E+01, -.51712400E+00, 0.19363300E+01, -.46845400E+00, 0.12288500E+00, -.66172200E+00, -.89109100E+00, -.67887700E+00, -.27928500E-02, 0.20792300E+00, 0.43315100E+00, -.11752000E-01, 0.15267100E+00, -.74959000E+00, 0.22394500E+00, 0.20032100E-02, 0.21613000E+00, 0.25291500E-01, -.10164100E+01, 0.41413700E+00, 0.39175000E+00, 0.20734100E+00, 0.25226500E+00, 0.91206600E-01, 0.91777200E-02, -.14835400E+01, 0.95341900E-01, 0.94274700E-01, -.40596200E+00, 0.14476300E+00, 0.73455500E-01, 0.18616100E+00, 0.36389600E+00, -.38500800E-01, -.56531600E+00, 0.30885900E+00, -.35684300E+00, 0.32001600E+01, -.70911500E-01, -.21315700E+00, 0.12159700E+00, 0.54164600E-01, 0.72313200E+00, -.38153000E+00, -.43300800E+00, -.64683100E-01, 0.14007900E+00, 0.91553400E-02, -.79415600E+00, 0.33007000E+00, 0.20764000E+00, -.24550600E+00, 0.39613800E+00, 0.27588800E-01, -.34875100E+00, -.99326200E+00, 0.12256600E-02, -.86750000E-02, -.39687400E-02, -.14158800E-01, 0.29455200E-04, -.70189800E-02, -.79214400E-02, 0.16961900E-02, 0.58078800E-03, -.38529300E-02, 0.55301100E-02, 0.36871900E-02, 0.10555700E-02, -.67754200E-01, -.12983200E-01, 0.40976700E-02, 0.12153500E-01, -.48975400E-02, -.37335200E-03, 0.50581700E-01, -.39033300E-03, 0.47328000E+00, -.77306200E-03, -.21069100E-01, 0.92366000E-02, -.20092300E-02, -.62460900E-03, 0.51638500E-03, -.22498800E-01, -.15573000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.42571900E+01, -.39649400E+01, -.36047900E+01, -.52620500E+01, 0.39921300E+01, 0.20383000E+02, -.69764500E-01, 0.21025200E+01, 0.12974600E+01, -.39358300E+00, 0.57811100E+01, 0.39286000E+01, -.14935700E+01, 0.39226100E+00, 0.57059300E+00, -.28821800E+01, -.66205600E+00, -.57034400E+00, -.65477100E+00, 0.29134600E+00, 0.18435800E+00, 0.28745300E+00, -.27129900E+00, 0.16600300E+00, -.12055300E+01, 0.57773300E+00, -.10486200E+00, 0.54342000E+01, 0.36112100E+00, 0.10510100E+00, -.28686800E+00, 0.86008700E+00, 0.10064000E+01, -.49779100E-01, -.69275700E+00, 0.97457300E+00, 0.77274600E+00, -.54246600E+00, -.25407800E+00, 0.72426100E+00, -.46463000E+01, -.21053600E+00, -.44816300E+00, 0.19036800E+01, -.21481500E+00, 0.20035100E+00, -.33016500E-01, 0.51251200E-04, 0.30881900E+00, -.96028900E+00, -.96239900E+00, -.45465400E+00, -.64544100E+00, 0.59730000E+00, 0.11643100E+01, -.12550500E-01, 0.71672200E+00, -.13430600E+00, 0.32795700E+00, 0.14224800E+01, -.85281900E-01, 0.47092400E+00, -.13843500E+00, 0.16884100E+01, 0.54260000E+00, -.46248900E+00, -.72624100E-01, 0.69054500E+00, 0.23791800E+00, -.95509600E-01, -.40304400E-01, 0.12454400E+00, -.14545400E+00, -.11989600E+01, -.57603100E+00, -.37350100E+00, 0.14403400E+00, 0.18216000E+00, -.14110900E+00, 0.24392200E+01, -.28378000E+00, 0.24307800E-01, 0.12046800E+00, -.21141400E+00, -.23080600E+00, 0.31689100E+00, 0.26302600E-01, -.80929100E-01, -.45384300E-01, 0.80571700E-01, 0.34358400E+00, -.12444900E+01, 0.23198000E+00, -.17954900E+01, -.59098400E+00, 0.54519100E+00, 0.36892000E+00, -.22643700E+00, 0.19883000E+00, -.23403300E+00, 0.40898600E-01, 0.77094500E+00, -.82192800E+00, -.30117200E+00, -.37396800E+01, 0.56381300E+00, -.94161100E-01, 0.14949200E-01, -.15680700E+00, -.11940100E+01, 0.21901000E+00, -.58609900E+00, -.57388400E-01, 0.31431600E+00, -.43142100E+00, -.29002600E+00, -.19556100E+00, -.13809600E+01, -.10664400E+00, 0.58528000E+00, 0.65980800E+00, -.26078500E+00, 0.40131300E+00, 0.97472400E-01, -.33686000E-01, -.30425500E-01, -.19345900E+00, 0.12740100E+00, 0.15932900E+00, -.26237500E+00, -.41665900E-01, 0.35014500E+00, -.21455900E-01, 0.77272600E-01, 0.87203100E-01, -.10828500E+00, 0.40432100E+00, -.36241000E-01, 0.19328300E+00, 0.41945300E+00, -.66925600E+00, -.26039600E-01, -.32280300E-01, 0.11459300E+00, 0.36728200E+00, -.20221600E+00, 0.19406400E+00, 0.14973000E+00, -.22302500E+00, 0.11010500E+00, -.15806100E+00, 0.76406400E-01, -.68099000E+00, -.21488600E+00, -.94593700E-01, -.22314800E-02, -.67735900E-02, 0.14718600E+00, -.21539900E-01, -.29274900E+00, 0.30639600E-01, 0.30707100E+00, 0.33288500E+00, 0.79651600E-01, 0.22165700E+00, 0.78817300E-01, -.19978700E+00, 0.26661800E+00, 0.11268400E+00, -.47953200E+00, 0.51622800E-01, 0.39863000E-01, 0.10398600E+00, -.40050000E-02, 0.24089400E+00, -.10032500E+00, 0.11972600E-01, -.21158200E-01, -.12416800E+00, 0.88022100E-01, 0.58336300E-01, -.20155600E-01, 0.60084700E-01, -.32237900E-01, -.12983200E+00, -.48538300E-02, 0.51119700E-01, 0.13058300E+00, 0.56069700E-01, -.16983300E+00, -.14091100E+00, -.14956800E-01, 0.80871700E-01, 0.11197300E+01, -.11621700E-01, -.74223400E+00, -.93372700E+00, -.89041900E-01, 0.11778100E+00, 0.11837200E+00, 0.27934100E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.24857200E+02, -.72387300E+01, 0.13731600E+02, 0.23846900E+02, -.10682400E+02, -.12237700E+03, -.34343700E+02, -.28308900E+02, -.71211800E+01, 0.16119000E+01, 0.11798000E+02, -.57097700E+01, 0.97272000E+01, 0.20405500E+01, -.13245600E+01, 0.57302900E+01, 0.19222000E+01, 0.10047400E+00, 0.53894300E+01, 0.45477400E+00, -.86493400E+00, -.16393800E+01, 0.19628900E+01, 0.16968200E+02, -.39122400E+01, 0.28298200E+01, 0.32226000E+01, -.73722400E+02, -.67679600E+00, -.83300800E+01, 0.57238800E+00, 0.21664800E+01, 0.15369900E+01, 0.68426300E-01, -.13109200E+01, -.23569500E+01, 0.35333800E+00, -.24954200E+01, -.10416300E+02, -.18581100E+02, -.27853900E+02, 0.10902000E+01, 0.16309900E+01, -.62352200E+01, -.12254200E+01, 0.36903200E+01, 0.20802500E+01, -.22669100E+01, -.74986900E+01, 0.40096700E+01, -.34730300E+01, -.16217000E+00, -.37009600E+01, 0.11169100E+02, 0.15652600E+02, 0.53214100E+00, -.30159200E+01, -.22628100E+01, 0.21961500E+01, -.15887000E+01, 0.29556000E+01, -.15745100E+01, 0.74795900E+00, 0.87311800E+01, 0.24200700E+01, 0.21385600E+01, -.13797600E+01, 0.51655000E+01, 0.41321900E+01, -.64367700E+00, -.22226200E+01, 0.30130200E+00, 0.56172500E+00, 0.22134000E+01, -.92485100E+00, -.11219200E+01, 0.77708700E+00, -.19984800E+01, -.32996500E+01, -.92453200E+01, 0.10722700E+01, 0.69928800E-01, 0.23436600E+01, -.10567800E+01, 0.16121600E+01, -.95232200E+00, -.30823500E+01, -.91336400E+00, 0.94567900E+00, -.90925200E-02, 0.29454200E+00, -.12071400E+02, 0.19479800E+00, -.30639300E+01, 0.33884800E+01, -.64288100E+00, 0.18673200E+01, 0.47013300E+00, -.82219700E+00, 0.17869000E+00, -.73238200E+00, 0.17741200E+01, 0.35243300E+01, 0.23134500E+01, -.37891500E+01, 0.97861500E+00, 0.46939900E+00, 0.99918500E-01, -.16149800E+01, -.14083900E+01, 0.46633400E+00, -.88895000E+00, -.72567600E+00, 0.11511300E+01, -.88961300E+00, -.24882900E+01, -.38244000E+00, -.57308600E+01, -.17087700E+00, 0.10328600E+01, 0.49965100E+01, -.93473300E+00, -.71813500E+00, -.47818400E-01, 0.29404300E+00, -.14240700E+01, -.32250900E+00, -.49853600E+00, 0.25278400E+00, -.73298700E+00, 0.40162700E+00, -.10493000E+01, -.30039700E+00, 0.64178000E+00, -.93912700E-01, 0.49912500E+00, 0.25590600E+01, -.66754800E+00, 0.43907400E+00, -.43052900E+00, 0.11870100E+01, -.88958100E-01, 0.43967700E+00, -.82058400E+00, 0.14137100E+01, -.14043000E+01, -.68933700E-02, -.18254200E+00, -.83405800E-01, 0.63552000E+00, -.23269900E+00, -.91267200E+00, -.42413200E+01, -.20018800E+01, -.93363200E+00, 0.98614100E-01, -.80976400E+00, 0.54122100E+00, -.46935300E+00, -.12984300E+01, -.41715200E+00, 0.14068300E+01, -.47915600E-01, 0.50732900E+00, 0.54668600E+00, 0.32309800E+00, -.79761000E-01, 0.16870000E+00, -.15987700E+00, -.54157200E+00, 0.41485300E+00, -.12998200E+00, 0.73418600E+00, 0.31893800E+00, 0.20025000E+01, -.41109400E+00, 0.61600900E+00, 0.26137700E+01, 0.10239000E+01, -.11312800E+01, 0.99495000E-01, -.17109100E+01, 0.13503100E+01, 0.13624100E+00, -.32685000E+01, -.77840400E+00, -.12684000E+00, 0.26150900E+00, -.14323000E+00, -.13999800E+00, -.16426900E+01, -.82385700E-02, -.19697500E-01, -.97177600E-01, -.80912200E+01, 0.12693400E+00, 0.35403000E-01, 0.42354900E+00, 0.33327600E+01, -.40488100E-01, -.80195400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.49873000E+01, 0.23494900E+01, -.27574200E+01, -.48973900E+01, 0.25737400E+01, 0.24393500E+02, 0.87274700E+01, 0.56810500E+01, 0.13719100E+01, -.44659500E+00, 0.21569100E+01, 0.17264200E+01, -.15975700E+01, -.73418100E-01, -.11099100E+00, -.14868600E+01, -.54843800E+00, -.27414100E+00, 0.18004400E+00, -.18684400E+00, 0.38466400E+00, -.51849800E+00, -.40097500E+00, -.11553700E+01, -.11436000E+00, -.16167800E+00, 0.15100100E+00, 0.98163900E+01, 0.38656700E+00, -.28815500E+00, -.15768100E+00, 0.20005100E+00, 0.61327100E+00, -.27459400E-01, -.31902300E+00, 0.42719600E+00, 0.50891000E+00, 0.14585700E-01, 0.51276900E+00, 0.65076200E+00, 0.33057700E+01, 0.10058400E+00, 0.59819100E+00, 0.77424400E+00, -.40171900E+00, -.30856700E+00, -.17283700E+00, 0.40949200E+00, 0.70268400E+00, -.83172200E+00, 0.37052800E+00, -.41398600E+00, 0.98573400E-01, -.30549400E+00, 0.79408700E+00, -.31600600E+00, 0.77332100E+00, 0.41981100E+00, -.41765400E-01, 0.81362500E+00, -.11328900E+01, 0.67391700E+00, -.10597500E+00, 0.14190400E+01, -.17685000E-01, -.51011200E+00, 0.84525600E-02, -.28286700E+00, -.13353500E+00, 0.16914100E+00, 0.24188400E+00, 0.44409600E+00, -.92246500E-01, -.48671100E+00, -.18068200E+00, -.12691800E+00, 0.31146600E+00, -.61913300E+00, -.18554300E+00, 0.68291300E+00, -.30730000E+00, 0.55087600E+00, -.38221100E-01, -.45806600E+00, -.50162600E+00, 0.31968500E+00, -.51649900E+00, -.84433900E-01, -.79240400E-01, -.73842400E-01, 0.20915200E-01, -.75028800E+00, 0.83663900E-01, -.71776200E+00, 0.65275400E+00, -.14840900E-01, 0.32629200E+00, -.15355200E+00, -.59091600E-02, 0.92665100E-01, 0.50452500E-02, 0.42045000E+00, 0.36166200E+00, 0.14014200E+00, 0.17211800E+00, -.42225800E+00, -.12025700E+00, -.11400900E+00, -.67954800E-01, -.83935900E-01, -.28618000E+00, 0.11810700E+00, -.33148400E+00, 0.27316400E+00, -.18079700E+00, -.16875100E+00, 0.25547400E-01, -.14955600E+01, 0.26047500E-01, 0.59302000E+00, 0.10814000E+01, -.72531800E-01, -.26362500E+00, -.39476400E-01, 0.88469700E-01, -.30334300E-01, -.55287500E-01, 0.99162900E-02, 0.15342100E-01, 0.16927500E-01, 0.20701400E-01, 0.27128700E+00, 0.68932200E-01, -.24029300E-01, 0.52713700E-01, 0.12046900E+00, -.11977000E+00, 0.96574400E-01, -.87408300E-02, 0.30581500E-01, -.17002200E+00, 0.34232200E-02, 0.63214900E-02, -.45523800E-01, 0.25723700E-01, 0.60000900E-03, -.42258000E-03, -.33213300E-01, -.10634900E+00, -.36869800E-02, 0.18586200E-02, -.79548000E-03, 0.76780500E-02, -.53010900E-03, -.63602200E-02, 0.62800100E-02, -.60135100E-01, 0.29441400E-01, -.19453500E-02, -.36472700E-01, 0.13760200E-01, 0.52857900E-01, 0.46852400E-01, -.20957500E-01, 0.53984000E-02, 0.81320600E-02, -.29879300E-02, 0.46589900E-02, 0.38328400E-02, 0.62439300E-01, 0.79929500E-01, 0.17952600E-01, -.10023400E+00, -.18295400E-01, -.67155300E-01, 0.69589700E-02, -.33835700E-01, -.75606400E-02, 0.70230500E-02, 0.48745300E-01, -.11780700E-01, -.54694500E-02, 0.88564500E-02, -.11339700E-01, -.27573200E-01, -.13228000E-01, -.10194200E-01, 0.11234600E+00, 0.11283500E+00, -.15699800E+00, -.57190800E+00, 0.45443400E-02, 0.86674400E-01, -.11685400E+00, -.36024100E-02, -.10290900E+01, 0.43182200E-01, -.56588900E-02, 0.72946700E-01, -.61977600E-01, 0.20920600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.46504200E+01, 0.32287800E+01, 0.36418400E+01, 0.55941900E+01, -.34802700E+01, -.23611200E+02, -.44406100E+01, -.21821400E+01, -.14775600E+01, 0.47365400E+00, -.60721800E+01, -.40506800E+01, 0.14260700E+01, -.72544500E-01, -.42497500E+00, 0.28627500E+01, 0.60700300E+00, 0.51590900E+00, 0.48920500E+00, -.28380400E+00, -.17878400E+00, -.44137400E+00, 0.29075800E+00, 0.16001500E+00, 0.90500100E+00, -.39339900E+00, -.26066200E-01, -.30641900E+01, -.22458000E+00, 0.15467900E+00, 0.16935400E+00, -.12009800E+01, -.13261900E+01, 0.89242100E-01, 0.50134700E+00, -.12994600E+01, -.69112200E+00, 0.71005300E+00, -.46824800E+00, -.85546700E+00, -.56318500E+00, 0.73058600E-01, 0.32176000E+00, -.22108700E+01, 0.17501700E+00, -.26806700E+00, 0.11167400E+00, -.42314200E-01, 0.31810500E+00, 0.11559900E+01, 0.14457500E+01, 0.63318700E+00, 0.48677400E+00, -.40285300E+00, -.91997900E+00, 0.20860700E+00, -.11276200E+01, 0.49381900E+00, -.51181400E+00, -.13678800E+01, 0.33797000E+00, -.79995100E+00, 0.19746500E+00, -.16799200E+01, -.49169700E+00, 0.45963000E+00, 0.13285800E+00, -.66518000E+00, -.24826100E+00, 0.43907400E-01, -.21271100E-01, -.33873700E+00, 0.26179800E+00, 0.82201800E+00, 0.34698600E+00, 0.32544100E+00, -.24803500E+00, 0.24750800E+00, 0.16057100E+00, -.79690900E+00, 0.43051200E+00, -.42019300E+00, -.63269800E-01, 0.33432300E+00, 0.25546800E+00, -.38525000E+00, 0.37607200E+00, 0.21316100E+00, -.26191900E-01, -.32097900E-01, -.10780900E+00, 0.21760300E+01, -.20781200E+00, 0.58714800E+00, 0.44038700E-01, -.10692700E+00, -.58625600E+00, 0.23633600E+00, 0.38621600E-01, 0.17354400E+00, 0.91588600E-01, -.75965500E+00, 0.92121300E-01, 0.14113700E+00, 0.23154900E+01, -.27689800E+00, 0.36057400E-01, 0.40464400E-01, 0.14085200E+00, -.27436400E+00, -.20803000E-01, 0.29320900E+00, 0.26175500E+00, -.37674200E+00, 0.24840600E+00, 0.48043400E+00, -.20424600E+00, 0.11316900E+01, 0.96019900E-01, -.54779900E+00, -.94776600E+00, 0.22544700E+00, 0.14568600E+00, 0.39843100E-01, 0.98053800E-02, 0.10071500E+00, 0.12874800E+00, -.11682100E+00, -.19257800E+00, 0.12657800E+00, 0.17315100E-01, -.67686300E+00, -.22337700E-01, -.69858700E-01, -.37963300E-01, 0.28863800E-01, -.61016200E+00, 0.38224300E-01, -.19834600E+00, 0.53000100E-01, 0.73429000E+00, 0.49671100E-01, -.24242500E-02, -.50156000E-01, -.28274100E+00, 0.12279400E+00, -.14920600E+00, -.14779300E+00, 0.15926800E+00, -.10956500E+00, 0.14779500E+00, -.90895100E-01, 0.72982500E+00, 0.21349000E+00, 0.65500300E-01, 0.15509500E-01, -.16333500E-01, -.15117900E+00, 0.26131800E-02, 0.28880000E+00, -.33170900E-01, -.27783900E+00, -.33341500E+00, -.72710800E-01, -.20242200E+00, -.75910900E-01, 0.19276900E+00, -.26466600E+00, -.12069300E+00, 0.50239600E+00, -.74830700E-01, -.43311700E-01, -.96895200E-01, 0.52405800E-02, -.18992900E+00, 0.99363700E-01, 0.93070700E-02, 0.59512300E-01, 0.13562300E+00, -.11267900E+00, -.48550200E-01, 0.13820200E-01, -.56988300E-01, 0.37107800E-01, 0.18759800E+00, 0.17488700E-01, -.42907000E-01, -.11360100E+00, -.77539900E-01, 0.21823700E+00, 0.16766000E+00, 0.14578200E-01, -.94888400E-01, -.84261700E+00, 0.45891200E-03, -.16154600E+00, 0.34210600E+00, 0.30216700E-01, -.35894100E-01, -.61023400E-01, 0.26769600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.38052800E+01, 0.42155000E+01, 0.15541600E+01, 0.62807900E+01, -.23520400E+01, -.24804500E+02, -.11644400E+02, -.43062500E+01, -.15309300E+01, 0.56876500E+00, 0.46653200E-01, -.17545200E+01, 0.12157000E+01, 0.71161600E+00, -.57500500E+00, 0.11712500E+01, 0.31183100E+00, 0.10607200E+01, -.60257800E+00, -.23261100E+00, -.33757400E+00, 0.11672700E+01, 0.39678400E+00, 0.19518000E+01, 0.73512800E+00, 0.58062500E+00, 0.20537000E+00, -.90740600E+01, 0.58023100E+00, -.56600300E+00, 0.43399000E+00, -.84114700E+00, -.13807500E+01, -.12593900E-02, 0.24525600E+00, -.23214900E+01, -.74280800E+00, 0.30066600E+00, -.14867100E+01, -.21992400E+01, -.21675800E+01, 0.13874500E+00, 0.24854900E+00, -.17781000E+01, -.27772300E+00, 0.94046100E+00, 0.17763800E+00, -.31659400E+00, -.16211000E+00, 0.69000700E+00, 0.10742300E+01, 0.39727200E+00, -.44002900E+00, 0.27020600E+01, 0.24629600E+01, 0.14041300E+00, -.11160800E+01, -.14782600E+00, 0.16260100E+00, -.44742100E+00, -.34664900E+00, -.26444600E+00, 0.70651600E-01, 0.11590200E+01, -.12485900E+00, 0.20522600E-01, -.16735700E+00, 0.10886200E+01, 0.27415900E+00, -.20923400E+00, 0.52878800E+00, -.30604700E-01, 0.45903300E+00, -.76489500E+00, -.41847500E+00, -.31281900E+00, -.30897400E-01, -.19397700E+00, 0.54534400E-01, -.48411100E+01, 0.15657300E+01, 0.53844000E+00, 0.19546400E-01, -.42471400E+00, -.35545100E+00, -.47347800E+00, 0.38917400E+00, -.76751000E+00, 0.36563500E+00, 0.35660300E+00, 0.22249300E-02, -.24183900E+01, -.48982800E-01, 0.15129200E+00, 0.45859000E+00, 0.10465800E+00, 0.78996000E-01, 0.49054800E+00, -.19617600E+00, -.12739900E+00, -.17621600E+00, 0.30081600E+00, 0.64104300E+00, -.12585800E+00, -.64438300E+00, 0.36591800E+00, 0.55986400E-01, 0.13931400E+00, 0.11512100E+00, -.20948300E+00, 0.16225600E+00, -.16826400E+00, 0.15349100E+00, 0.13936500E+00, -.11498600E+00, -.26648700E-02, -.34689300E+00, 0.55910800E-01, 0.81840500E-01, -.36336400E+00, 0.31603400E+00, -.17812300E+00, 0.26985700E+00, 0.77813500E-01, -.10626100E+00, -.28562800E+00, -.25189400E+00, -.85619100E-01, 0.47566700E+00, -.48395400E-03, 0.16058200E+00, -.26667800E-01, 0.44680600E+00, 0.17591500E+00, -.11788600E+00, -.24364200E+00, 0.19584000E+00, -.17080100E+00, 0.86837500E-01, 0.12260600E-01, 0.40200200E+00, -.92976200E-01, 0.14520600E+00, 0.64605900E+00, 0.41244100E+00, 0.57263100E-01, -.75498500E-01, -.32455300E+00, -.45263900E+00, 0.29601700E+00, -.15451400E+00, -.20209300E+00, -.10452700E+01, -.35522800E+00, -.29167000E+00, -.15404700E+00, -.23660800E-02, 0.51912500E-01, -.15366100E-01, -.16420800E+00, 0.13732000E+00, -.11584300E+00, 0.61666400E+00, -.26731900E+00, 0.22700300E+00, 0.60137700E-01, -.20281600E+00, -.19151200E-01, 0.82875200E-01, 0.45063800E+00, -.10663800E+00, 0.83547300E-01, -.39864000E+00, -.66765800E-01, -.24603300E+00, 0.12898400E+00, 0.44253800E-01, -.26814500E+00, -.13106200E+00, 0.19737800E+00, 0.99865900E-02, 0.87697800E+00, 0.50909200E-01, 0.54312600E-01, 0.72105700E-01, 0.65222700E-02, 0.30531700E-02, 0.63696600E-01, 0.28323800E-01, 0.31995000E-01, 0.55811800E-01, 0.13575800E-01, -.21161700E-01, 0.75507400E-01, 0.22812100E-01, -.69185600E-01, -.86464800E-01, -.62773700E+00, 0.72740000E-02, -.70030800E-01, 0.63600500E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.53461100E+00, 0.27106200E+01, 0.66358600E-01, 0.18059000E+01, -.31448600E+00, 0.54971300E+01, 0.12128900E+02, -.58608800E+00, 0.49976700E+00, 0.74039900E+00, -.39437900E+01, -.13904100E+01, -.32343400E+00, 0.96469500E-01, 0.92779300E-01, 0.11144500E+01, 0.26185900E+00, 0.17611300E+00, -.20153600E+00, -.46500300E+00, 0.90066000E-01, -.14105200E+00, -.13989800E+00, 0.40817700E+00, -.31095100E+00, 0.43529900E+00, -.38287800E+00, -.37443300E+01, 0.13083100E+00, 0.44399500E+00, 0.60119300E-01, -.31807000E+00, -.36538700E+00, 0.11014500E+00, -.92130000E-01, 0.10289300E+00, -.14639700E-01, -.30880200E+00, 0.61461900E+00, 0.90681200E+00, -.15927100E+01, -.30941300E+00, 0.51827300E+00, 0.64357500E+00, 0.44579900E+00, 0.14586900E+00, -.70632000E+00, 0.53889900E-01, 0.54461800E+00, -.35523100E+00, -.15364300E-01, 0.66349500E-03, -.65624600E-01, -.79093200E+00, 0.12790900E+00, -.14649200E+00, -.21013600E+00, 0.18634100E+00, -.17871600E+00, -.96872600E+00, 0.68913500E-01, -.47743100E+00, -.98011200E-01, 0.49064600E+00, -.35857000E-01, 0.40278300E+00, 0.10491600E-01, -.14717800E+01, -.16699200E+00, 0.53157400E+00, 0.13680800E+00, 0.27419100E+00, -.22116500E+00, 0.24284600E+00, -.49571300E-01, 0.39494000E-01, -.13930700E+00, 0.21344800E+00, 0.41285800E-01, 0.40445200E+00, 0.22030400E+00, -.22596000E+00, -.44879800E-01, 0.15086000E+00, -.79292500E-01, -.12374000E+00, 0.23513600E+00, 0.66911500E-01, -.23905000E+00, -.45020200E-01, 0.86241100E-01, 0.17762300E+01, 0.19917700E-02, -.54591300E+00, -.48000900E+00, 0.89230500E-01, -.41279800E-01, 0.36143400E-01, 0.84593700E-01, -.62096300E-01, 0.66935400E-01, -.53449300E+00, -.41054400E+00, -.69623500E-01, 0.52402300E+00, -.14800600E+00, 0.33835200E-01, 0.46916000E-01, 0.42363700E-02, -.99933800E+00, -.90425100E-01, 0.55954000E-01, 0.13607300E+00, -.10504000E+00, 0.24000400E-01, 0.22511500E-01, 0.22456400E+00, 0.97868000E+00, -.10860000E+00, -.65642300E-01, -.32643100E+00, -.76087800E-01, -.15828500E+00, -.28056100E-01, 0.48817200E-01, 0.14557400E+00, 0.48489800E-01, -.13586100E+00, -.34215900E+00, -.27225600E+00, -.65435100E-01, -.29926800E+00, 0.11023000E+00, -.23379200E+00, -.66361200E-01, 0.32916600E+00, -.25809700E+00, 0.13679700E+00, -.37131300E-01, 0.90134300E-01, -.14295600E+00, 0.10075700E+00, -.99006400E-01, 0.35363000E-03, -.77556500E-01, 0.66276200E-01, 0.91904300E-01, 0.15682700E+00, 0.18788000E+00, -.22738000E+00, 0.11318300E+00, 0.65117800E-01, 0.64772000E+00, 0.27276600E+00, 0.11516800E+00, 0.27457000E-01, 0.12724300E-01, -.44458200E-02, -.38951600E-01, 0.51813400E-01, -.55170200E-01, -.99379100E-01, -.29629400E-01, -.32579100E-01, -.77913400E-01, -.10149700E-01, 0.71014500E-01, -.72758800E-01, -.36223500E-01, 0.63022800E-01, 0.70843400E-01, -.26293600E-01, -.75560400E-01, -.41815600E-01, -.21123100E+00, 0.10572800E-01, -.81686400E-01, -.12388100E+00, -.94460100E-02, 0.72987300E-01, 0.11131100E-01, 0.44815900E-01, -.53447700E-01, -.20403300E-01, 0.13315300E+00, 0.28348400E-01, 0.76745800E-02, 0.23177500E-01, 0.20822000E-01, 0.30072700E-01, 0.23201400E+00, 0.12560200E-01, -.18003400E-01, 0.59944600E-01, -.63949000E-01, -.72722000E-02, -.10374400E+00, -.17754400E-02, 0.33854000E+00, 0.91414300E-01, 0.10993000E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.55660200E+01, -.34718500E+01, 0.31369200E+01, 0.43948900E+01, -.20858700E+01, -.20372800E+02, -.31946300E+01, -.69688700E+01, -.11570100E+01, -.98919100E-01, 0.48802300E+01, -.10396200E+01, 0.22993900E+01, 0.10325800E+01, -.58503200E+00, 0.19759800E+01, 0.33795600E+00, -.71996200E+00, 0.45341500E+00, 0.49897600E-01, -.42694700E+00, 0.19284000E+00, 0.29177000E+00, 0.12602500E+01, -.99509000E-01, 0.79612000E-01, 0.27910500E+00, -.75283200E+01, -.43551700E+00, -.22033900E+01, -.23415400E+00, 0.30065500E+01, 0.74791300E+00, -.44961600E+00, -.25608300E+00, -.99235000E+00, -.51590600E+00, -.68678500E+00, -.42977600E+00, -.95044300E+00, 0.60241400E+01, 0.36907900E+00, -.17622800E+01, -.48931200E+00, 0.45227700E+00, 0.10703300E+01, 0.49378000E+00, -.32784200E+00, -.11398900E+01, 0.12094000E+01, -.16441700E+00, -.14514300E+00, -.41245900E+00, 0.16921000E+01, 0.27666200E+01, 0.10395400E+00, -.10770100E+00, -.39953500E+00, 0.30037300E+00, 0.24382400E+00, 0.50591500E+00, 0.96585600E-01, 0.22736700E+00, 0.11805600E+01, 0.33628200E-01, 0.84028900E+00, -.45858900E+00, 0.18083100E+01, 0.24125600E+00, -.20267100E+00, -.76237800E+00, 0.17408000E+00, -.17573000E-01, 0.70526100E+00, -.20133600E+00, -.20661900E+00, 0.23095100E+00, -.54539900E-01, -.48240200E+00, -.89814500E+00, 0.60107400E-01, 0.78306100E+00, -.85909100E-01, 0.60993000E-01, -.88714500E-01, 0.20751300E+00, -.95191000E+00, -.52485400E+00, 0.26117700E+00, 0.36399900E-01, -.44576600E-01, -.13302500E+01, -.79170200E-02, 0.73005100E+00, 0.76246900E-01, -.33236100E+00, 0.16429200E+00, -.21496700E-01, -.12207500E+00, -.46594400E-01, -.15622900E+00, 0.13975200E+00, 0.27399300E+00, 0.10607400E-01, 0.24806600E+00, 0.15828900E-01, 0.97955000E-01, -.13292700E+00, -.88258200E-02, 0.15750600E+01, -.38867700E-01, 0.75002600E-01, -.35902600E+00, 0.25684900E+00, 0.17447700E-01, -.46307500E-02, 0.17287900E+00, 0.50586100E-01, -.38477800E-04, 0.40455500E+00, 0.38121300E+00, -.26635500E+00, -.18986600E+00, -.61714100E-02, -.20323600E-01, 0.43912200E+00, -.32640800E+00, 0.13869800E+00, 0.27922800E+00, 0.12824900E+00, 0.91600100E-01, 0.45969900E+00, -.92671300E-01, 0.71377300E-02, 0.47558600E-01, 0.36100100E+00, 0.17024100E+00, 0.15625500E+00, 0.38219100E-01, 0.24737200E+00, -.27980400E+00, -.28880700E-01, 0.20943600E-01, 0.29320000E-02, 0.71455700E-01, 0.24139900E+00, 0.93531500E-01, 0.28167100E+00, 0.10810700E+00, -.72979000E-01, 0.14724800E+00, 0.10681600E+00, 0.43334000E-01, 0.54054300E+00, 0.14575300E+00, -.29228400E-01, -.43169200E-02, 0.21299500E+00, 0.67009100E-01, 0.17020500E+00, -.22405900E-01, -.68364600E-01, -.96795000E-01, 0.69983400E-02, -.12965900E+00, -.10445400E+00, 0.24603800E+00, -.33895100E+00, -.59304200E-01, 0.49618500E-01, 0.34745300E+00, -.51457700E-01, -.16662300E+00, -.14284700E-01, -.27984000E+00, -.64977300E-01, -.17885300E+00, -.29883200E+00, -.14287000E-01, 0.24128400E+00, 0.44711600E-01, 0.24780300E+00, -.19745600E-01, 0.91324600E-01, -.28832600E+00, 0.12357300E-01, -.25873600E-01, 0.34281900E+00, -.25960400E+00, 0.25118900E+00, -.50820400E+00, 0.71415100E-01, -.81480800E-01, 0.21302000E+00, -.28083800E-02, -.42012900E+00, -.19981700E+00, 0.13401600E+00, 0.27002500E+00, 0.15043100E+01, -.25029600E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { -.28720000E+01, -.33171600E+01, -.10117700E+01, -.48179200E+01, 0.15205400E+01, 0.17630000E+02, 0.59237200E+01, 0.17093100E+01, 0.10578700E+01, -.77671300E+00, 0.12585600E+01, 0.17285500E+01, -.66851300E+00, -.54379000E+00, 0.42802300E+00, -.42074800E+00, -.20461900E+00, -.10387500E+01, 0.76001700E+00, 0.10245400E-01, 0.11077300E+00, -.98578600E+00, -.41965600E+00, -.14921400E+01, -.49293200E+00, -.49576400E+00, -.32879000E+00, 0.75696800E+01, -.34526900E+00, -.73843600E+00, -.52810300E+00, 0.93672900E+00, 0.13051400E+01, -.13001700E+00, 0.11726800E-01, 0.14779400E+01, 0.71217400E+00, -.22669800E+00, 0.11659500E+01, 0.16718000E+01, 0.96437100E+00, -.65799000E-01, -.43934400E+00, 0.12810600E+01, 0.26380900E+00, -.84046200E+00, 0.43749000E-01, 0.23851000E+00, 0.24272200E+00, -.35192300E+00, -.59153000E+00, -.19103400E+00, 0.46431100E+00, -.26513800E+01, -.26179600E+01, -.75334400E-01, 0.89337800E+00, 0.19129300E+00, -.18737900E+00, 0.34625600E+00, 0.11635300E+00, 0.13552400E+00, -.10202900E+00, -.99583000E+00, 0.52726000E-01, -.38146200E-01, 0.21214000E+00, -.10405600E+01, -.18649100E+00, 0.15904200E+00, -.39569800E+00, -.26012100E-02, -.39328700E+00, 0.63782200E+00, 0.36700800E+00, 0.25465200E+00, -.21906200E-01, 0.19695100E+00, 0.36619300E-01, 0.31294500E+01, -.11275300E+01, -.33375600E+00, 0.94768600E-01, 0.32338400E+00, 0.24970700E+00, 0.32464200E+00, -.24993900E+00, 0.67207100E+00, -.38233300E+00, -.27425500E+00, -.28204500E-02, 0.22159000E+01, 0.39273300E-01, 0.42652000E+00, -.56393100E+00, -.11510800E+00, -.78948100E-01, -.63341500E+00, 0.21963600E+00, 0.22742400E+00, 0.15123400E+00, -.34513800E+00, -.67383800E+00, 0.19178500E+00, 0.59458600E+00, -.37788500E+00, -.44846300E-01, -.11214600E+00, -.18318000E+00, 0.83424600E-01, -.51890200E-01, 0.11070800E+00, -.97149500E-01, -.12098300E+00, 0.93651800E-01, -.13792000E+00, 0.38211800E+00, -.39937900E+00, -.65094300E-01, 0.28070100E+00, -.18283700E+00, 0.19559400E+00, -.28702300E+00, -.71669300E-01, 0.13695800E+00, 0.18689400E+00, 0.26381700E+00, -.49704900E-02, -.52780900E+00, 0.64335700E-02, -.21126700E+00, -.26066700E+00, -.49739700E+00, -.13252200E+00, 0.30032500E-01, 0.24216900E+00, -.53470200E-01, -.65540400E-01, -.75758900E-01, -.15393100E+00, -.20153100E+00, 0.96612700E-01, -.24034800E+00, -.45816400E+00, -.25158300E+00, -.13565300E+00, 0.10172500E+00, 0.38659000E+00, 0.50675800E+00, -.34095200E+00, 0.15254400E+00, 0.20794100E+00, 0.86043200E+00, 0.28808400E+00, 0.22441200E+00, 0.13600500E+00, 0.30583200E-01, 0.39941900E-01, -.10226500E-01, 0.13181200E+00, -.94497200E-01, 0.15418600E+00, -.43284900E+00, 0.14581800E+00, -.16692500E+00, -.16620500E-02, 0.20116600E+00, 0.27560700E-01, -.83731900E-01, -.23398700E+00, 0.56822700E-01, -.53810600E-01, 0.21410800E+00, 0.27330500E-01, 0.11366600E-02, -.54076800E-01, -.13924800E+00, 0.82922900E-01, 0.12279100E+00, -.18423500E+00, -.54485200E-01, -.65665300E+00, -.80716400E-01, -.12139800E-01, -.31380200E+00, -.93655700E-01, -.54195600E-01, 0.28472300E-01, -.19184800E-01, -.88769000E-01, -.15905500E+00, 0.59740000E-02, -.23601600E-01, -.69807800E-01, -.12422500E-01, 0.23770400E+00, 0.14673100E+00, -.68851600E+00, 0.32471800E-01, -.16638600E+00, 0.87213200E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
            { 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 }
        }
    };





void MainWindow::on_predictButton_clicked()
{

    QString update_message("Predicting...");
    ui->message_label->setText(update_message);
    // copy the contents of the cells of both tables to appropriately-named variables
    yield = ui->mechpropTable->item(0,0)->text().toDouble(&read_ok);
    toughness = ui->mechpropTable->item(1,0)->text().toDouble(&read_ok);
    elongation = ui->mechpropTable->item(2,0)->text().toDouble(&read_ok);
    reduction = ui->mechpropTable->item(3,0)->text().toDouble(&read_ok);
    uts = ui->mechpropTable->item(4,0)->text().toDouble(&read_ok);
    temperature = ui->experimentTable->item(0,0)->text().toDouble(&read_ok);
    frequency = ui->experimentTable->item(1,0)->text().toDouble(&read_ok);
    stressconc = ui->experimentTable->item(2,0)->text().toDouble(&read_ok);
    stress = ui->experimentTable->item(3,0)->text().toDouble(&read_ok);
    r_eff = ui->experimentTable->item(4,0)->text().toDouble(&read_ok);

    update_message.sprintf("Reading in user-specified parameters...");
    ui->message_label->setText(update_message);

    // Check what temperature unit is used and convert to Celsius if necessary
    if (ui->kelvinButton->isChecked()==true)
    {
        temperature = temperature - 2.7315E+02;
    };
    if (ui->farenheitButton->isChecked()==true)
    {
        temperature = (temperature - 3.2E+01) * (5.0/9.0);
    };

    // Check what value was given for the stress variable and convert to a stress range, as given in the source data
    // If stress amplitude is given:
    if (ui->amplitudeButton->isChecked()==true) // is stress amplitude (max - mean) is given, double it to give a range (max-min)
    {
        stress = 2.0 * stress;
    };
    // If mean stress is given:
    if (ui->meanButton->isChecked()==true)
    {
        if (stress == 0.0) // If mean stress is zero, i.e. R=-1, then there are an infinite number of conditions, so give an error message.
        {
            ui->message_label->setText(zeromean);
        };
        stress = (2.0*stress) * (1-r_eff) / (1+r_eff);
    };
    // If maximum stress is given:
    if(ui->maximumButton->isChecked()==true)
    {
        stress = stress * (1-r_eff);
    };
    // If minimium stress is given:
    if(ui->minimumButton->isChecked()==true)
    {
        stress = stress * ( (1/r_eff) - 1 );
    };

    // Check if fracture toughness is given and, if so, convert to Charpy toughness using the Rolfe-Novak-Barson correlation:
    if(ui->fracturetoughnessButton->isChecked()==true)
    {
        toughness = ( 0.2 * (toughness / yield ) * (toughness / yield) + 0.05 ) * yield;
    };

    update_message.sprintf("Reading in data from networks.");
    ui->message_label->setText(update_message);

    // Make the predictions:

    // Declare and initialise all the variables:
    double bendingUncertainty = 2.34E+25;
    double uniaxialUncertainty = 5.67E+28;
    double torsionalUncertainty = 6.54E+24;
    int i,j,k;
    QString predictBending;
    QString predictUniaxial;
    QString predictTorsional;
    QString uncertaintyBending;
    QString uncertaintyUniaxial;
    QString uncertaintyTorsional;
    double uniaxial_normal_input[11]; // 1=temperature, 2=frequency, 3=stress concentration factor, 4=stress amplitude, 5=UTS, 6=elongation, 7=RoA, 8=Charpy, 9=yield stress, 10=effective R ratio
    double bending_normal_input[9]; // 1=frequency, 2=stress conc factor, 3=stress amplitude, 4=UTS, 5=elongation, 6=RoA, 7=Charpy, 8=Yield stress
    double torsion_normal_input[8]; // 1=frequency, 2=stress amplitude, 3=UTS, 4=elongation, 5=RoA, 6=Charpy, 7=yield stress

    // Perform the calculations necessary to make predictions:
    // Begin with the uniaxial network.  This network consists of nine models and ten inputs.  The numbers of hidden units in each model are: 22, 20, 24, 25, 25, 25, 24, 25 and 23.
    int uniaxial_no_in_cttee = 9;
    int uniaxial_no_inputs = 10;
    int uniaxial_hidden_units[9] = {22, 20, 24, 25, 25, 25, 24, 25, 23};
    double uniaxial_weights_hu [9][25][10] = {
        {{ 0.70919900E-01, -.47772500E+00, -.20762800E-01, -.54065300E+00, 0.42414700E+01, 0.76049600E+00, 0.12758500E+00, 0.11823700E+00, 0.40318500E+01, -.75150900E-01}, { 0.16236400E+00, -.20374900E+00, -.62360700E-02, 0.15480000E+01, -.32025900E+01, 0.13510200E+01, -.26364900E+00, -.11006600E+01, 0.10355800E+02, 0.49009900E-01}, { 0.33018000E+00, -.59235000E-01, -.56026500E-01, -.18095900E+01, 0.38555300E+00, 0.57637000E+00, 0.85215800E-02, -.40147900E+00, 0.78098500E+00, 0.37582900E+00}, { -.70772100E-01, -.83315400E-01, -.85938900E-01, -.63354700E+01, 0.29997900E+01, 0.61614600E+00, -.34965700E+00, 0.83789800E+00, -.31001300E+00, 0.26110200E+00}, { 0.29024300E+00, 0.25526600E+00, 0.50769700E-02, -.60595600E+01, 0.25138900E+01, 0.98991400E+00, -.23824000E+00, -.53964800E+00, -.13345000E+01, 0.18326800E-01}, { -.16427300E+00, -.46419300E+00, -.59027200E-01, -.84943600E+00, -.98962500E-01, -.69070600E+00, 0.52110200E+00, -.55871700E-01, 0.81838900E+00, -.41148300E+00}, { -.98889300E-01, -.27518900E-01, -.77884000E-01, -.14435000E+01, 0.11165900E+01, -.14911000E+01, 0.25012500E+00, 0.18414600E+01, -.68872100E+01, -.51404200E-02}, { -.33289500E-01, -.62198800E-01, -.60394800E-01, -.90678500E+00, -.23145400E+01, -.66910100E+00, -.35636200E+00, 0.24868800E+01, 0.79916700E+00, 0.28169500E+00}, { -.72562500E-02, 0.12913800E+00, -.12889200E+00, -.11834100E+01, -.23450100E+01, 0.18370300E+01, 0.39851200E+00, -.14644400E+00, 0.17962500E+01, 0.37034900E-02}, { -.21408000E+00, -.23925100E+00, -.35071100E-01, -.10829300E+01, -.88032000E+00, 0.54138600E+00, -.38773200E+00, 0.91042300E+00, -.66250300E+00, 0.26264500E+00}, { 0.47998700E+00, 0.62582700E-01, 0.14791600E+00, 0.12234500E+01, 0.43078400E+01, 0.14590100E+01, -.48646700E+00, 0.17760800E+01, 0.22543700E+01, -.15651800E-01}, { 0.63478500E+00, 0.14183700E+01, -.19625800E-01, -.27955400E+01, -.25522900E+01, 0.64817700E+00, 0.11282500E+01, -.14278200E+01, 0.24380200E+01, -.37006000E-01}, { 0.42753100E+00, -.11073500E+00, 0.93144800E-01, -.83629900E+01, 0.43047400E+01, 0.82345500E+00, -.16233800E+00, 0.59317000E+00, -.12528900E+01, -.22027300E+00}, { -.55121100E+00, -.11728900E+00, 0.77610700E-01, 0.80309300E+01, -.37886700E+01, -.12359500E+01, 0.18865900E+00, -.30338900E-01, 0.15313700E+01, 0.38766800E+00}, { 0.11395400E+00, -.10861200E+00, -.46934400E-01, -.19365100E+01, -.23114700E+01, -.11529300E+01, 0.99526000E+00, 0.93147500E+00, 0.16596800E+01, 0.13074400E+00}, { 0.25697700E-01, 0.53906200E+00, 0.84041700E-01, -.64103300E+00, -.94599800E+01, 0.21693700E+01, 0.81483700E+00, -.62688500E+00, 0.56388900E+01, 0.30189200E+00}, { 0.87032300E-01, -.11168900E+01, -.88583500E-01, 0.17354200E+01, 0.22706800E+01, 0.36753600E+00, -.49572300E+00, 0.10435300E+01, -.92272600E+00, -.44319700E-01}, { -.47377000E-01, -.80120400E-02, 0.10851700E+00, 0.15731100E+00, -.20651600E+01, -.16882700E+01, 0.77975400E+00, -.19278000E+01, -.30817300E-01, -.18828500E-01}, { 0.26082700E+00, -.70027700E-02, 0.12378000E+00, 0.25758600E+01, -.81357200E+00, -.64736200E+00, 0.37023300E+00, -.82055800E+00, -.12498000E+01, -.12759400E+00}, { -.43434700E+00, 0.91709700E+00, -.14645200E+00, -.15147200E+01, -.43449300E+01, 0.79033000E+00, 0.38952500E+00, -.13539100E+01, 0.21297600E+01, -.16849900E-01}, { -.12407000E+00, 0.45425300E+00, 0.28734000E-02, 0.66912500E+00, 0.44632200E+00, -.78716000E+00, -.18385800E+00, 0.59237100E+00, 0.31724100E+01, 0.10076300E+00}, { 0.16941200E+00, 0.77440700E-01, -.48930000E-01, 0.61851500E-01, -.26471600E+01, -.13039000E+00, -.29786400E+00, -.70297000E+00, -.49277100E+01, 0.62080400E-01}, { 0.13588759-152, 0.13035429E-75, 0.22133864E-51, 0.60135957-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.48922360E-61, 0.72556075E-42, 0.38630182E-85, 0.60442034-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.89777217E-66, 0.29070227E-32, 0.12839988-152, 0.25188188E-51, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ -.55968900E-01, -.14258900E+01, 0.18881000E-01, -.40309400E+00, 0.52581700E+01, 0.10900200E+01, 0.49653500E+00, 0.11829900E+01, -.63823900E+00, 0.60844500E-01}, { -.25515200E+00, 0.13628600E+00, -.34862400E-01, 0.83713000E+01, -.17336500E+01, 0.31530600E+00, 0.21403300E+00, 0.31683100E+00, -.86341100E+00, -.42386100E-01}, { -.81151500E-02, -.81369300E-01, -.92799900E-02, 0.28693700E+00, -.16385200E+00, 0.44623900E-01, 0.62400900E-01, -.19121800E-01, -.12867800E+00, -.11379800E+00}, { 0.15427700E+00, 0.20242200E-01, -.86121200E-01, 0.50392700E+01, -.70724000E+00, 0.71976900E+00, 0.12818700E+01, 0.37189600E+00, -.12147800E+01, 0.21867500E+00}, { 0.23833000E+00, 0.10104700E+00, 0.72445300E-02, 0.65992700E+00, 0.10962700E+00, -.21991500E-01, -.19898000E-01, -.20134800E+01, -.29442500E+01, -.40939900E+00}, { 0.71075800E-01, 0.10806400E+00, -.84293200E-01, 0.53463900E+00, -.15003400E+01, 0.34098300E+00, -.48360000E+00, 0.11612200E+01, 0.50737400E+01, -.47173500E-01}, { 0.23983100E+00, -.64506100E-01, 0.12910200E+00, -.54626900E+01, 0.15451300E+01, -.11119400E+00, -.99776300E+00, -.85936700E+00, 0.32692900E+00, -.13197500E+00}, { 0.23680300E+00, -.77993900E-01, -.47134000E-04, -.28464300E+01, -.24468000E+00, 0.15254100E+01, 0.88507600E+00, -.15325700E+01, -.15378200E+01, -.59412900E+00}, { -.14614000E+00, 0.11065500E+00, 0.14802800E-01, -.21083300E+01, 0.11800700E+01, -.11094100E+01, -.18759700E+01, -.46685000E+00, -.24884200E+01, 0.41455300E+00}, { -.98205300E-01, 0.27973200E-01, -.14587500E+00, 0.21092100E+00, -.28923500E+01, -.32375800E+00, -.64487700E+00, -.99294300E-01, -.64457700E+00, -.65225400E+00}, { 0.10622000E+00, -.95095200E+00, -.36462700E-01, -.22825100E+00, -.20206300E+01, -.47139100E+00, -.14968700E+00, -.17739800E+00, 0.83089400E+00, -.88749600E+00}, { -.12382500E+00, 0.93485000E+00, -.12634500E+00, 0.34802300E+00, -.38449300E+00, -.61658700E+00, 0.82178800E+00, 0.14642800E+01, -.23065300E+00, 0.32281400E+00}, { -.10034600E+00, 0.14934500E-01, 0.12083300E+00, -.37954400E+01, 0.13848800E+01, -.12575300E+01, -.11325100E+01, 0.24882900E-02, -.90384300E+00, 0.31534800E+00}, { 0.88899200E-01, 0.79875300E-01, -.62586700E-01, 0.95571100E+01, -.62477300E+00, -.11376800E+00, 0.60284300E+00, 0.16905000E+00, -.24493400E+01, 0.15451000E+00}, { 0.28801200E+00, -.33496800E+00, 0.75480000E-01, -.29639500E+00, -.76672400E+00, -.71640500E+00, 0.17725400E+01, 0.80114700E+00, 0.10660900E+01, 0.68123500E-01}, { -.30320500E+00, 0.35371100E+00, 0.52239300E-01, 0.83142800E+00, -.51815600E+01, -.62785600E+00, -.45598700E+00, -.55041700E+00, 0.18277100E+01, -.20903500E+00}, { 0.88339200E-01, 0.56016900E-01, 0.83191800E-01, -.11486600E+00, 0.77693400E+00, 0.59372200E+00, 0.22965600E+00, 0.65267500E+00, 0.43137900E+01, 0.15806600E+00}, { 0.52117000E-01, -.50291600E-01, 0.51833900E-01, -.17176800E+01, -.11490700E+01, -.24020700E+00, 0.70695900E+00, -.12526800E+01, -.13549700E+01, -.57679000E+00}, { 0.49111300E-01, -.35598700E+00, -.15945700E-01, -.35018600E+00, 0.19658900E+01, 0.37860500E+00, 0.36100200E+00, -.11109700E+00, -.42653100E+01, 0.16680200E+00}, { -.18034800E+00, 0.27537400E+00, -.11932800E-01, -.48444300E+00, 0.29466400E+01, -.13103900E+00, -.56064000E+00, 0.12045700E+01, -.21920600E+01, 0.94618700E-01}, { 0.14316633-152, 0.40664543E-85, 0.60369144-153, 0.29906386E-66, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60134700-153, 0.32424566E-85, 0.15192477E-46, 0.12819663-152, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.36155183E-42, 0.14790113E-75, 0.12837029-152, 0.60383540-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.21756146E-75, 0.12825376-152, 0.61210515E-61, 0.29906952E-66, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.18792105-152, 0.10864439E-70, 0.60134704-153, 0.33117911E-32, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ 0.17572300E+00, 0.74204900E-01, -.25675400E-01, -.11948000E+01, 0.22162000E+01, -.54843800E+00, -.26134500E-01, 0.97102500E+00, 0.10739500E-01, -.20373800E+00}, { -.82499700E-01, 0.60344600E+00, 0.88927100E-01, -.23863700E+01, -.28378500E+01, 0.11354700E+01, 0.37240400E+00, -.12789200E+00, -.19593200E+01, 0.55455700E+00}, { 0.10078200E+00, -.59117700E+00, 0.49859700E+00, 0.14050600E+01, 0.89152100E+00, -.27344700E+00, 0.69261300E+00, 0.89269400E-01, 0.18979100E+01, 0.81698800E+00}, { 0.91452200E-01, -.23416400E+00, 0.16633300E+00, 0.57378500E+01, -.10723100E+01, 0.72654600E+00, 0.19328500E+01, -.24746400E+00, 0.35088500E+00, 0.33625700E+00}, { -.40372100E-01, -.82154700E+00, -.30217800E-01, 0.18469000E+00, 0.34078000E+01, 0.10696600E+01, -.16383300E+01, -.28054600E+00, -.71567000E+00, 0.40744600E-01}, { -.28348400E-01, -.16768200E+00, -.25058100E+00, 0.46432300E+00, -.40652800E+01, 0.66488400E+00, 0.14218100E+01, -.17123500E+00, 0.99525700E+00, 0.14706600E+00}, { -.29071600E+00, -.18549500E+00, -.28067200E-01, 0.53704700E+01, -.68773600E+00, 0.58124600E+00, 0.13749800E+01, 0.85316300E+00, 0.35192100E+00, 0.13142500E+00}, { -.12196000E+00, -.20892200E+00, 0.45076600E+00, -.65595900E+01, 0.17059300E+01, -.26583200E+00, 0.32915600E+00, -.11947200E-01, -.10282200E+01, -.27914500E+00}, { 0.13199800E-01, -.12272100E+01, 0.92511500E-01, -.74196800E+00, -.16164900E+01, 0.96847300E+00, -.90707700E+00, -.79857200E+00, -.13486500E+01, -.63662100E-02}, { -.96953500E-01, -.18231600E+00, -.33462100E+00, 0.29587900E+00, -.57249000E+00, -.11268000E+01, -.17537600E+01, -.13323500E+01, -.39869700E+00, -.14611000E+00}, { -.24128400E+00, 0.81714600E+00, -.28492800E+00, -.31723000E+00, 0.14744200E+01, -.56961600E+00, -.22702500E-01, 0.66609200E+00, -.15430700E+01, 0.46695500E+00}, { 0.13593100E+00, -.10902500E+00, 0.28902700E+00, -.31634600E+00, 0.16056200E+01, -.76029400E+00, 0.20640900E+01, -.18913900E+01, -.14371000E+01, 0.16771600E+00}, { -.30598200E+00, -.85817400E-01, 0.25301100E+00, -.73910000E+01, 0.18670600E+01, 0.67917800E+00, 0.10939000E+00, -.16684600E+00, -.10189400E+01, -.44196300E+00}, { 0.13626100E-01, 0.49770000E+00, 0.10280900E+00, 0.13459500E+01, 0.16395200E+01, -.11739300E+00, -.14193400E+01, -.28071300E+00, -.15136900E+01, -.14956500E+00}, { 0.23665900E+00, 0.74097400E-01, 0.45411100E+00, 0.14172700E+01, 0.17416700E+01, -.46825900E+00, 0.72910400E-02, -.38686400E+00, 0.54387600E-01, 0.84195000E-01}, { -.15742500E+00, -.22813900E+01, 0.12567500E+00, 0.98615700E+00, 0.39553000E+01, 0.17375500E+00, -.57473300E+00, 0.10434100E+01, 0.15027800E+01, -.20378400E+00}, { -.81410900E-01, -.24311600E+00, -.42679200E+00, -.90685400E+00, 0.95340400E+00, 0.11385100E+01, -.20239400E+01, -.10769300E+01, -.86513000E+00, 0.49408000E+00}, { -.33006100E-01, -.34699200E-01, 0.57731800E+00, 0.54482100E-01, -.92333800E+00, -.24062700E+00, 0.61924100E+00, -.18733200E+00, -.12580000E+01, -.57965700E+00}, { 0.84409500E-01, 0.15840200E+01, 0.31993600E+00, 0.24230700E-01, 0.42134400E+01, 0.16118900E-01, -.13189400E+01, -.22778500E+01, -.96997200E+00, -.26053900E+00}, { -.17957900E+00, 0.10119700E+00, -.29135900E+00, 0.90626100E-01, -.62241400E+00, -.14034000E+00, 0.14320200E+01, 0.17000200E+01, -.46848000E+00, 0.25738100E+00}, { 0.12406000E+00, -.22965300E+00, 0.28840800E+00, 0.10370400E+01, -.22218000E+01, -.60986300E+00, 0.19415300E+01, -.16045800E+01, 0.17195000E+01, 0.32197300E-01}, { -.58696600E+00, 0.24086800E+00, -.39272500E+00, 0.33865900E+01, 0.29925500E+00, 0.13480300E+01, 0.28971400E+00, 0.10968700E+01, 0.16548000E+00, -.25244400E+00}, { -.63953900E-01, -.47066200E+00, -.26116300E+00, 0.13249100E+01, -.67716400E-01, -.68589300E-01, -.22816400E+00, -.19111700E+01, 0.16057500E+00, -.17312800E+00}, { 0.54281300E-01, 0.12720600E+01, 0.15724100E+00, -.31615500E-01, 0.27121300E+01, -.58054100E+00, 0.51029200E+00, -.52706900E+00, 0.95311300E+00, 0.53061100E-02}, { 0.55994580E-66, 0.67231180E-66, 0.42717970E-32, 0.50671237E-85, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ 0.13123200E+00, 0.14591300E+01, -.13078700E+00, -.38202600E+00, -.52960900E+00, -.70312900E+00, 0.55745900E+00, -.64402700E+00, -.47913300E+01, 0.70114800E+00}, { 0.18605200E-02, 0.21219500E+00, 0.16472600E+00, -.31321700E+01, -.48015500E+00, 0.18047700E+00, 0.27684700E+00, -.19432200E+01, 0.18742500E+00, 0.29220900E+00}, { 0.21148200E+00, 0.18087800E+01, -.12803400E+00, 0.11692000E+01, -.14795700E+01, -.99126900E-02, 0.99562700E+00, -.34534100E+00, 0.98940200E+00, 0.19487900E+01}, { 0.11792800E+00, 0.55131300E+00, 0.52794400E+00, -.40165500E+01, -.11239100E+01, -.23154000E+00, -.21015000E+00, 0.10487700E-01, 0.93650600E+00, -.87159900E+00}, { -.26529800E+00, -.45964800E-01, -.35021700E+00, 0.21546100E+00, 0.27470700E+01, 0.19195100E+00, 0.61020100E+00, 0.71830700E+00, 0.71329100E+00, -.10410400E+00}, { 0.29164000E+00, 0.53406900E+00, -.27468000E+00, 0.38198800E+01, -.20399300E+01, 0.18856400E+00, 0.15737200E+01, -.15320400E+01, -.24633600E+00, 0.34964600E+00}, { -.20409400E+00, 0.10105100E+01, -.10240400E+00, -.60306500E+00, -.17388600E+01, -.95937500E+00, 0.67941400E+00, 0.80577200E+00, -.27188800E+01, 0.49734300E+00}, { 0.86634800E-01, -.29867600E+00, 0.30445900E-02, -.51091500E-01, 0.24043500E-02, 0.36625900E-01, -.25093500E+00, 0.41307400E+00, 0.21502600E+00, -.33231000E-01}, { 0.27762000E+00, 0.92131900E-01, 0.19435500E+00, -.17563600E+01, 0.35849200E+01, 0.47271700E+00, -.59040000E+00, 0.10557200E+01, -.19090300E+01, -.42802800E+00}, { 0.25480100E+00, 0.87436300E+00, -.42366200E+00, -.52046900E+00, 0.35167100E+01, -.28488600E+00, -.24501200E+00, 0.35499900E+00, -.85676900E+00, -.11925200E+00}, { -.28018800E+00, 0.25868100E+00, -.21585200E+00, 0.33713100E+00, -.18446400E+01, -.65103700E+00, -.14261300E+01, 0.28563200E-01, -.18199100E+01, -.60039100E+00}, { 0.15329100E+00, 0.20978800E+00, 0.81158000E-01, 0.39675200E+00, 0.39512400E+01, -.91455800E+00, -.19561300E+01, 0.23303300E+00, -.43409600E+01, -.23725300E+00}, { -.66290900E-01, -.14641800E+01, -.63557100E-01, 0.18843400E+01, 0.10680200E+01, -.73611900E+00, 0.12525000E+00, 0.30140900E+00, -.13263900E+01, 0.81975400E+00}, { -.60953500E+00, -.16083400E+00, -.64676900E+00, 0.67539900E+01, -.69822400E+00, -.34251400E+00, -.34002900E+00, 0.48305300E+00, -.15373900E+00, 0.84050700E+00}, { 0.48563600E-01, -.17025900E+00, -.41571500E+00, 0.38768700E-01, 0.17363600E+01, -.41292900E+00, -.14257100E+01, 0.61561400E+00, -.23369300E+01, -.62129100E+00}, { 0.93274200E-01, 0.29344400E+00, 0.16489700E+00, 0.37531100E+01, -.51125100E+00, -.61802500E+00, 0.27490900E-01, 0.76807300E+00, -.24575400E+00, 0.70014500E+00}, { 0.14978800E-01, 0.29679100E+00, 0.16188700E-01, -.52495300E+00, -.49301100E+00, -.27830500E+00, -.40333100E+00, 0.75308000E+00, -.73433400E+00, 0.40215000E+00}, { -.33472700E-01, 0.32132400E+00, -.22268100E+00, 0.15187800E+00, 0.16252300E+01, -.31291100E+00, 0.72592800E+00, 0.32591700E+01, -.24843400E+01, 0.55322800E+00}, { 0.31076200E+00, 0.80833100E-01, -.16034500E-01, -.18508600E+01, -.10177000E-01, 0.14419400E+00, -.18282200E+01, 0.15751300E+01, 0.15321100E+01, -.51861600E+00}, { 0.23394900E+00, -.16493600E+01, 0.39429200E+00, -.27017900E+00, -.10183400E+01, 0.52539000E+00, -.42235600E+00, -.30687900E+01, 0.21350300E+01, -.52053800E+00}, { -.28106300E+00, -.10565500E+01, -.40559700E+00, 0.23495200E+01, -.10496400E+00, -.31731500E+00, 0.80469300E+00, -.76270800E+00, -.73109000E+00, 0.23850100E+00}, { 0.44652300E-01, -.27584500E+00, -.56721500E-01, -.73923800E-01, 0.55778700E-01, -.16192200E-01, -.24830100E+00, 0.27396000E+00, 0.27098600E+00, -.80315400E-02}, { 0.52526100E+00, 0.15597200E+00, 0.21178800E+00, -.52307200E+01, 0.95836600E-01, -.26053700E-01, 0.78525800E+00, -.28728000E+01, -.77785400E-01, -.23768300E+00}, { 0.17181700E+00, 0.58520900E+00, 0.18604800E+00, 0.18531900E+00, 0.44558300E+01, -.63020900E+00, -.12807600E+01, -.18685600E+01, -.45338900E+01, -.35170400E+00}, { 0.24843900E+00, 0.46055800E+00, 0.14318300E+00, 0.27219300E+00, 0.30765000E+01, -.71290900E-01, -.44487200E+00, -.22244300E+01, -.16171400E+01, -.47382200E+00}},
        {{ -.36285500E-01, -.21969000E-01, -.69957900E-01, 0.12739600E+01, -.10095400E+01, -.19673500E+01, -.10802500E+01, -.25852000E+00, 0.10590900E+01, 0.37461700E-01}, { 0.19869600E+00, -.69502100E-01, 0.24734400E-01, -.68070100E+01, 0.39742700E+01, -.12551600E+00, -.84450200E+00, 0.92981900E+00, -.20651000E+00, -.10610800E+00}, { -.13776400E+00, -.71561100E-01, 0.19890600E+00, -.88889100E+01, 0.57873600E+01, 0.48353700E+00, -.15406000E+00, -.19162100E+00, -.16324300E+01, -.58200100E-01}, { -.84399000E-01, 0.20702300E+00, -.98909900E-01, -.29350900E+01, 0.15063400E+01, 0.12390300E+01, 0.68658800E+00, 0.79778100E+00, 0.90109800E+00, -.27610500E+00}, { -.22969300E-01, 0.33291500E+00, -.90190200E-02, 0.31738100E+01, -.23914100E+01, -.39601000E+00, -.20935100E+00, -.42842800E+00, -.14481600E+01, 0.42251800E+00}, { -.43920300E-01, -.44738400E+00, -.93531000E-01, 0.23962200E+00, -.40362100E+01, -.11960100E+01, 0.78559700E+00, -.16491700E+01, -.10166000E+01, -.21749300E+00}, { -.10691800E-01, 0.28302000E+00, 0.16860900E-03, 0.55490200E-01, -.77119400E+01, -.11318700E+01, -.39066700E-02, 0.98073800E+00, -.15589700E+01, 0.11546300E+00}, { 0.18607600E-01, -.20364400E+00, 0.82205700E-02, -.99936100E+00, 0.15321700E+01, 0.12273700E+01, -.80901000E-01, -.32800200E+00, -.21953700E+01, 0.23618000E+00}, { -.33901400E-01, 0.27777900E+00, 0.65965200E-02, 0.66370100E+00, -.20674700E+00, -.51500200E+00, -.12724000E+00, -.16298500E+01, 0.65954600E+00, 0.34096000E+00}, { -.87418000E-02, -.78608000E-01, -.62247400E-01, 0.15911300E+01, 0.38931200E+01, -.48295300E+00, -.50755800E-01, -.28425000E+01, -.29719000E+01, 0.34531200E-01}, { -.20158800E-01, -.13631700E+00, -.97257900E-01, -.11522400E+01, 0.41465100E+01, 0.24086800E+01, 0.72148200E+00, -.14907300E+01, -.20108700E+01, 0.11202600E+00}, { 0.76761500E-02, -.17265500E+00, 0.21605600E+00, 0.37117600E+00, -.16168400E+01, -.51251100E+00, 0.55035900E+00, -.17616000E+01, -.10088600E+01, -.44781500E+00}, { -.87123100E-01, 0.12796200E+00, 0.13502600E+00, 0.39818300E+01, -.24087200E+01, -.27012200E+01, -.94105100E+00, -.65218100E+00, -.12652200E+01, 0.15386000E+00}, { 0.82228800E-02, 0.25297500E+00, -.53741600E-01, -.30704900E+00, -.36084800E+01, 0.45693500E+00, -.12981900E+00, 0.10945000E+01, -.16375900E+01, 0.21019000E-01}, { -.38635100E-01, -.21917900E-01, 0.14702900E-01, -.27530000E+01, -.49346900E+01, -.27021100E+00, -.16417900E+00, 0.33863500E+01, 0.29891200E+00, 0.91583100E-01}, { 0.16516900E+00, -.46160900E-02, -.90709100E-01, 0.76140700E+01, -.38953800E+01, -.52377600E+00, 0.57400300E+00, -.31603200E+00, 0.40864200E+00, 0.35020600E+00}, { 0.11029400E-01, 0.70243400E+00, -.31572000E-01, 0.10931300E+01, -.40664200E+01, -.13114000E+01, -.65425900E+00, -.13849900E+01, -.41142500E+00, -.37122900E+00}, { 0.84672100E-01, -.12873100E+00, 0.11115200E+00, -.80005400E+01, 0.56408600E+01, 0.68320400E-01, -.13938000E+00, 0.18945000E+00, -.13514900E+01, 0.39793000E+00}, { -.84642400E-03, 0.41609400E+00, 0.83360000E-01, 0.29800600E+01, -.20162100E+01, -.93036900E+00, -.62221900E+00, 0.21066800E+00, -.10980200E+01, -.26239500E+00}, { 0.69194300E-01, -.15005800E+00, 0.22329600E+00, 0.42699800E+00, -.51327000E+01, -.19645000E+01, 0.22081600E+00, -.10016200E+01, -.14897100E-03, 0.15576300E+00}, { -.81657100E-01, 0.13081600E+00, -.34461900E-01, 0.31503900E+01, 0.21380500E+01, -.45217400E-01, -.41610800E-01, -.29081400E+01, 0.16094500E+01, 0.37135700E-01}, { -.93307700E-02, 0.76282000E-01, -.11547100E+00, 0.82261100E+00, 0.10118500E+02, -.20261700E+01, 0.18785600E+00, -.28747600E+01, 0.17357800E+01, -.33132400E+00}, { 0.34308600E-01, 0.26075000E+00, 0.57060800E-01, -.11230400E+01, -.39770100E+01, 0.22598100E+00, 0.49729800E+00, 0.11762800E+01, 0.17291500E+01, 0.12174000E+00}, { -.11513700E-01, 0.31294000E+00, 0.33041100E-01, 0.10900800E+01, -.23261700E+01, 0.38631300E+00, -.77630000E+00, -.10046700E+01, -.71657900E+00, -.90630800E-01}, { 0.19295500E-01, -.14905900E+00, -.28496000E-01, -.11062900E+01, 0.26664900E+01, 0.16238200E+01, -.30922300E+00, 0.35264500E+00, -.83881100E+00, -.88479500E-01}},
        {{ -.13725100E-01, 0.18929100E+00, -.45698300E+00, -.98829000E-01, -.18939200E+01, 0.26639800E-01, -.14734000E+01, -.36266600E+00, -.82393900E+00, -.10896800E+00}, { 0.63311300E-01, 0.21699500E+00, 0.14236500E+00, 0.12636800E+01, 0.95125200E+00, -.28612500E+00, -.13039700E+01, 0.53812400E+00, 0.47517400E+00, -.10435600E+00}, { 0.51764400E-01, 0.37457500E+00, -.86449100E-01, 0.41668500E+00, -.24819100E+00, -.77998300E+00, -.72809700E-01, -.12305900E+00, -.65383800E-01, -.12288900E+00}, { 0.12172700E+00, -.25871000E-01, -.28262100E-01, -.18782400E+01, -.10527600E+01, 0.28794000E+00, 0.43261200E+00, -.14937900E+01, -.12497100E+01, 0.32745600E+00}, { 0.31719000E-02, 0.36856200E+00, -.95345700E-01, 0.67287600E+00, 0.97574500E-02, -.10546400E+01, 0.32795100E+00, 0.13598300E+01, 0.35504700E+01, 0.82968100E-02}, { 0.13603100E+00, 0.11242500E+00, 0.50433300E+00, -.88680100E+00, -.24776900E+01, -.55039900E+00, 0.27961900E+00, 0.12373200E+01, -.20594500E+01, 0.18900900E+00}, { -.37700800E-02, 0.69143600E-02, -.28724400E-01, 0.73553500E+00, 0.59322100E-01, 0.93827500E-01, 0.10222700E+00, 0.15798700E+00, -.15438100E-01, -.17363400E-01}, { 0.10241200E-01, 0.11146400E+00, -.41722600E+00, -.20668500E+01, -.25047300E+00, 0.19168800E+01, 0.86339200E+00, 0.20688400E+00, -.11164400E+01, -.82237300E-01}, { 0.10731200E+00, 0.21225700E-02, 0.39320900E+00, -.73499600E+01, 0.17984900E+01, -.17701300E+00, -.55903000E-01, -.32910900E+00, 0.70386300E+00, -.61787600E-01}, { 0.11177500E+00, -.36458100E-01, -.44256600E+00, 0.10266700E+02, -.16662000E+01, -.96413300E+00, 0.59490000E+00, 0.13892700E-01, -.21520600E+01, 0.32622900E+00}, { -.32913500E+00, -.20271100E+00, 0.45821100E+00, -.45193100E+01, -.99392900E+00, 0.13424100E+01, 0.17051900E+01, 0.15847900E+01, -.15490100E+01, -.16290800E+00}, { 0.29556900E-01, -.91009700E-01, 0.19300600E+00, -.31979800E+00, 0.24899400E+01, -.40789000E+00, 0.23199700E+00, 0.13435500E+01, 0.28798900E+01, -.19739800E-01}, { -.94573400E-01, 0.43215700E+00, -.27165800E+00, -.38098200E+00, 0.28281200E+01, 0.52302100E+00, 0.30569600E+00, 0.22511500E+01, 0.52179400E+01, -.15507200E+00}, { -.50867000E-01, -.92546500E-01, -.46433700E+00, 0.10546900E+00, 0.69826200E+01, 0.21592300E+00, -.27996900E+01, -.76281500E+00, -.31133700E+01, -.17811700E+00}, { -.24379300E-02, -.94825500E-01, -.40267400E-02, -.99649500E+01, 0.15068800E+01, -.12211100E+00, -.75796700E-05, -.43210500E+00, 0.21838200E+01, -.39588200E+00}, { 0.60662600E-01, 0.44529400E-01, -.23120000E+00, -.20065700E+00, 0.19052600E+01, 0.13764200E+01, -.23027200E+01, 0.20374300E+01, 0.33850500E-01, -.11137600E+00}, { 0.55206300E-01, -.33295800E+00, -.17481400E+00, -.10280300E+01, 0.23888200E+01, 0.43702700E+00, 0.11479400E+01, 0.37647700E+00, 0.56290400E+00, -.50093100E-01}, { -.15097600E-01, 0.27184700E-01, -.10062900E-01, 0.17688000E+01, 0.51060800E+01, 0.13403500E+01, -.17172700E+00, -.22503700E+00, -.15658300E+01, 0.14690700E+00}, { 0.11522600E+00, 0.88535800E-01, -.72407200E-01, -.56302200E+01, 0.23145600E+01, -.10931900E+01, -.42976200E+00, -.41708700E+00, -.39206900E+00, 0.65610600E-01}, { -.82391800E-01, -.83993300E-01, -.13420000E+00, -.13189800E+01, -.30707000E+01, 0.76900100E+00, -.63376700E+00, -.34940600E+00, 0.40738200E+00, -.36037600E+00}, { 0.72800200E-01, -.13450700E-01, 0.43394500E-01, 0.98330300E+00, 0.38756700E+01, -.24607600E+00, -.46162700E-01, -.21381800E+01, -.17002200E+01, -.10258400E+00}, { -.57994600E-01, -.20188400E-01, 0.37331000E+00, -.12370600E+01, -.23270800E+01, -.64616600E-01, 0.21209700E+01, 0.32140100E+00, -.33137600E+01, 0.24002200E+00}, { -.33314900E-01, 0.16335300E+00, -.44591700E-01, -.81586800E+01, 0.25612400E+01, 0.18048800E+01, -.45419100E+00, -.26530500E+00, -.22892000E+00, 0.20734800E+00}, { 0.17771200E-01, 0.18596800E+00, 0.58278900E+00, 0.17327300E+01, -.47208800E+01, -.88856100E+00, 0.46572500E+00, -.17236700E+01, -.13514100E+01, 0.15737900E+00}, { -.21095000E-01, 0.15157000E+00, 0.21668000E+00, -.66960400E+01, 0.16519500E+01, 0.39345300E+00, -.94946800E+00, 0.63208900E+00, 0.11483900E+01, -.65377500E-02}},
        {{ -.12744200E+00, -.11466700E+01, 0.41491000E-01, -.51095200E+00, 0.18058700E+01, -.15643000E+00, -.12276800E+01, 0.14615100E+01, -.21447400E+01, -.39048700E-01}, { 0.48863200E-01, 0.66020200E+00, -.28068400E+00, -.47789700E+01, 0.90972100E+00, 0.15746800E+00, -.17119700E+01, -.43886000E+00, -.23479300E+01, -.40192000E+00}, { 0.30336100E+00, -.33489700E+00, 0.27641600E+00, -.55574500E+01, 0.11190300E+01, -.69912900E+00, -.36999800E+00, -.56778200E+00, 0.45469500E+00, 0.23683600E+00}, { -.23207800E+00, 0.23580500E+01, -.44722600E+00, -.40295000E+00, -.18050500E+01, 0.86797400E+00, 0.27702400E+01, 0.11832000E+01, 0.14779200E+01, -.92951000E-01}, { 0.16771300E+00, -.13903800E+01, 0.98328800E-01, -.50713800E+00, -.54465300E+01, 0.93991600E+00, -.10873000E+01, 0.20939600E+01, 0.62076500E+00, 0.23443300E-01}, { -.29922300E+00, -.77841800E+00, 0.85814100E-01, 0.34438200E-01, -.42372100E+01, 0.18598900E+01, -.52299600E+00, 0.12097800E+01, -.13199600E+00, 0.22326600E+00}, { 0.96983600E+00, 0.25369100E-01, -.14716600E+00, -.92361500E+01, 0.72769400E+00, -.13009300E+00, -.10950800E+01, 0.19249800E+00, 0.26246700E+01, -.18076000E+00}, { 0.14187800E+00, -.46587000E+00, 0.34554000E+00, 0.49834100E+01, -.46776800E+00, -.25161700E+00, 0.12400800E+01, 0.39765300E+00, 0.10015600E+01, 0.12864500E+00}, { -.51431800E+00, 0.10422100E+00, 0.72268800E-01, 0.11788400E+01, -.36259700E+01, -.69593700E+00, 0.40130200E+00, -.44513800E+00, 0.22664800E+01, 0.13196800E+00}, { 0.21365300E+00, 0.13330800E+01, 0.12448600E+00, -.85591700E+00, -.33862600E+01, -.16218600E+01, 0.20115200E+01, -.46659100E-01, -.90425700E+00, -.12142800E+00}, { 0.19635400E+00, 0.63622000E+00, -.20253700E+00, 0.52736200E+01, -.27887400E+00, -.69524100E+00, -.10151900E+01, 0.37358700E+00, -.78753600E+00, -.20719500E-01}, { -.53437500E-01, -.20333200E+01, -.15712600E-01, -.11711600E+01, 0.23210900E+01, -.20416200E+01, 0.16453800E+01, -.13000300E+00, 0.10594300E+01, -.71793100E-03}, { -.35638400E+00, 0.46809000E+00, 0.47996200E-02, 0.43184400E+01, -.83184000E+00, -.93029000E-01, -.47366500E+00, 0.22688100E+00, -.13229800E-01, -.15599500E+00}, { 0.16095800E+00, -.27691700E+00, 0.11503300E+00, -.37191500E+00, 0.27360600E+01, -.29922400E+00, 0.44906600E+01, 0.10403800E+01, -.59870600E+00, 0.22918600E+00}, { 0.88808400E+00, -.17214700E+00, 0.78205100E-01, -.82636400E+01, 0.10035000E+01, -.57310700E+00, -.69940000E+00, -.30428700E+00, 0.18844300E+01, 0.10037900E-01}, { 0.14334000E+00, 0.22945000E+01, 0.15607300E+00, -.64844800E+00, -.34108900E+01, -.13289100E+01, 0.20800500E+01, -.43578200E+00, -.15937900E+01, -.13060700E-01}, { 0.22278700E+00, 0.11520500E+01, 0.14366100E+00, 0.11044800E+00, 0.33730000E+01, -.14551300E+00, -.39438000E+00, 0.18358000E+00, -.51193800E+00, 0.19999700E+00}, { 0.42187600E-01, -.34604800E+00, 0.16698800E+00, -.14893300E+00, 0.17138400E+01, 0.53549100E+00, 0.49562700E+01, 0.83860500E+00, 0.47261600E+00, 0.32619000E-01}, { -.22000300E+00, -.72454100E+00, -.45412200E+00, -.10850300E+01, 0.31833700E+01, -.13826400E+01, 0.11847200E+01, 0.55514400E+00, 0.55266700E+00, 0.23003400E+00}, { -.13368400E+00, 0.16026300E+01, -.26724000E+00, -.59328700E+00, -.48193100E+01, 0.22575900E+00, 0.18176900E+01, 0.49462300E+00, -.56354400E+00, -.61368600E-02}, { -.43480800E+00, -.46024400E+00, -.15746100E+00, -.10620600E+01, -.86081100E+00, 0.11619400E+00, 0.15524900E+01, -.66489300E-01, -.30025000E+00, -.24887700E+00}, { 0.28383800E+00, -.13499000E+01, 0.28133800E+00, 0.36688700E+00, -.11719500E+01, 0.80135700E+00, -.24795900E+01, -.17979200E+01, 0.77895700E+00, -.25816300E+00}, { -.63291100E-01, -.74239700E-01, -.29347600E+00, 0.25971600E+00, -.13100400E+01, 0.65331000E+00, -.14352700E+01, 0.19878200E+01, 0.14708900E+01, 0.11494400E+00}, { 0.30217400E+00, -.43841300E+00, 0.19706400E+00, 0.13993500E+01, -.36229000E+01, 0.57011000E+00, -.12620800E+01, 0.59229800E-01, 0.29610800E+01, 0.23661200E-01}, { 0.45634386E-71, 0.86039033E-66, 0.17320865-152, 0.56411394E-37, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ -.13228300E+00, 0.28089800E+00, 0.36555400E-01, -.36524000E+01, 0.16049600E+01, -.10235700E+01, -.93491100E+00, -.14346200E+00, -.10190400E+01, -.57871300E+00}, { 0.23534000E-01, -.16815800E+00, 0.23153300E-01, -.34207200E+01, -.11760700E+01, 0.34741900E+00, 0.15631400E+01, -.16935600E+00, 0.17250300E+01, 0.16236700E+00}, { 0.43261200E+00, -.25664900E+00, 0.39735400E+00, 0.11132500E+01, 0.45216400E+01, 0.83500100E+00, -.89681900E+00, -.74856000E+00, -.20528900E+01, -.32288000E+00}, { -.22022600E+00, 0.54510800E+00, -.31046200E-01, 0.12490700E+01, 0.69593500E+00, 0.19900200E+00, 0.28333000E+01, 0.41295000E+00, 0.31156400E+01, 0.37245200E-01}, { 0.38984600E+00, -.37493700E+00, 0.16614700E+00, -.35080900E+00, 0.87382800E+00, -.13604900E+00, -.59519600E+00, -.14587800E+01, -.64224400E+01, 0.22582100E+00}, { -.50070400E-01, 0.44736900E-01, -.11653600E+00, 0.13035000E+01, -.89532500E+00, -.70729600E+00, 0.18301300E+01, 0.22987800E+00, -.26500600E+01, -.77591100E-01}, { -.28667600E+00, 0.48199100E+00, -.14418200E+00, 0.35352500E+00, 0.37731200E+00, 0.21667200E+00, -.14042100E+01, -.94921900E-01, -.16410700E+01, -.34341200E+00}, { 0.10424900E+00, -.25097400E+00, 0.32474400E-01, -.13800800E+01, 0.41420000E+01, 0.44573900E+00, 0.13379000E+00, 0.21305500E+00, -.19521100E+01, 0.10229800E+00}, { 0.59648400E-01, -.91571500E-02, -.27671300E+00, 0.97119900E-01, 0.35860700E+00, -.24292400E+00, -.23036300E+00, 0.18673300E+01, 0.35924300E+01, -.14915800E+00}, { 0.57997400E+00, 0.17912800E+00, 0.28765900E+00, -.14509200E+01, -.47282800E+01, -.59991300E+00, 0.14019100E+01, -.44480000E+00, 0.25094300E+01, -.30908500E-01}, { 0.10285800E+01, -.32994500E-01, -.75417900E-02, -.97138500E+01, -.45676400E+00, 0.81112500E+00, -.79058900E+00, 0.28762400E+00, 0.44757900E+01, -.40481000E+00}, { 0.73163200E-01, 0.40082000E+00, 0.38513700E-02, 0.52307800E+00, 0.10814800E+01, 0.36260900E-01, 0.17838100E+01, -.83107500E+00, -.89333600E+00, -.17665600E+00}, { -.34547900E-01, -.14317200E+00, -.12752900E-01, 0.79478700E+00, 0.56313600E+00, -.10040200E+00, 0.45349900E+00, 0.12125100E+00, 0.12360600E+00, -.50283300E-01}, { 0.40434500E+00, -.35898700E+00, 0.19685800E+00, -.57589300E+01, 0.88097200E+00, 0.33433000E+00, -.42360400E+00, -.28350000E+00, 0.78446900E+00, -.18216200E-01}, { -.15911100E+00, -.16113200E+01, 0.47616500E-01, -.21304300E+01, -.26858900E+01, -.42628300E+00, 0.24792400E+00, 0.52412800E+00, 0.47507800E+01, -.16129900E+00}, { 0.50456900E+00, 0.70437000E+00, 0.66559700E-01, 0.35521300E+01, 0.18457600E+01, -.16692000E+00, -.51051700E+00, 0.28580600E+00, -.31341700E+01, 0.37830900E+00}, { 0.57824500E+00, -.64871400E-01, 0.23644400E+00, 0.54295700E+00, 0.36476300E+01, -.33257000E+00, 0.37682500E+00, 0.10267200E+01, 0.86485900E+00, -.39010200E+00}, { 0.10492200E+00, -.98076900E+00, 0.13585100E+00, -.46644600E+01, 0.16121400E+01, 0.10637000E+01, -.32740300E+00, 0.13717900E+00, -.37458100E+00, 0.31524400E+00}, { -.41461800E+00, -.47629200E+00, 0.16327800E+00, 0.12490500E+01, 0.17594000E+01, 0.41286300E+00, 0.72805200E+00, -.22161400E+00, -.45626300E+01, -.15826800E+00}, { -.78861100E-01, 0.34306100E+00, 0.96167800E-02, -.15882400E+01, 0.43853800E+00, -.22760300E+00, -.18886400E+01, -.11173600E+01, -.63025300E+00, -.14135400E+00}, { -.51463600E-01, -.99001200E+00, -.58136600E-01, -.14453400E+00, 0.94410600E+01, -.55897300E+00, -.34602900E+00, 0.10707400E+01, -.31938500E+01, -.50437900E+00}, { -.89408100E+00, 0.17551800E+00, 0.56974100E-01, 0.83067700E+01, 0.18789400E+00, -.22122900E+00, 0.34693200E+00, 0.17016600E+00, -.34320900E+01, 0.31843900E+00}, { 0.30791500E-01, 0.44326800E+00, 0.80095600E-01, -.54766500E+00, -.59582600E+01, 0.41644100E+00, 0.21289500E+00, -.10488700E+01, 0.16449200E+01, 0.17552200E+00}, { 0.27693100E-01, 0.34145200E+00, 0.31835200E+00, 0.15120200E+01, -.34859800E+01, 0.51842700E-01, 0.77509500E+00, -.52909200E+00, 0.11305800E+01, 0.50215900E+00}, { 0.20555700E+00, -.67216200E+00, 0.21270900E+00, -.13791400E+01, -.15279300E+01, -.51313200E+00, -.34956800E+01, -.31509100E+00, -.16669300E+01, 0.42822200E-01}},
        {{ 0.16163200E+00, 0.16369700E-01, -.72840800E-01, 0.31648000E+01, -.50214500E+00, -.16514600E+00, 0.11710300E+01, -.61454600E+00, -.18642500E+00, 0.52568400E-01}, { 0.11619100E+00, -.47637900E+00, 0.78328500E-01, -.10875400E+01, 0.19801400E+01, 0.75222200E+00, 0.42056500E+00, -.34747500E+00, 0.18054100E+00, 0.42966600E+00}, { -.48103900E+00, -.39104700E+00, -.31765900E+00, 0.47163600E+01, -.34665300E+00, 0.71324200E+00, 0.51288500E+00, 0.15834600E+01, 0.13529800E+01, 0.82074100E+00}, { -.86816300E-03, 0.11329400E+01, 0.98622300E-02, -.81462800E+00, 0.19409700E+01, -.41318700E+00, 0.95027100E+00, 0.30051300E-01, -.23051700E+01, -.53699200E+00}, { 0.28360500E+00, -.99205800E+00, 0.60146600E-01, 0.48154200E+01, -.10641100E+01, -.52862300E+00, 0.12788300E+01, -.13997300E+01, 0.12593400E+01, 0.30408300E+00}, { 0.25127500E+00, -.47761100E+00, 0.28187500E+00, -.43365200E+01, -.56672500E+00, -.91260500E+00, -.97551100E+00, -.76650500E+00, -.32257800E-01, -.41948600E+00}, { -.27999900E-01, -.21638000E+00, 0.78793000E-01, -.14160900E+01, 0.11240200E+01, 0.79555800E-01, 0.13165400E+01, -.54297000E+00, -.94517500E+00, -.17449200E+00}, { 0.81068100E-01, -.27628400E+00, -.18437900E-01, -.23124000E+01, -.16684000E+01, 0.99624800E+00, 0.13143900E+01, -.12894400E+01, 0.61525500E+00, 0.24646600E+00}, { 0.64097200E-01, -.35897900E+00, 0.15854900E+00, -.40540300E+00, 0.12353100E+01, -.88097600E+00, 0.15756700E+00, 0.12994500E+01, -.29764700E+01, -.27772800E+00}, { 0.26102100E+00, 0.44932900E-02, 0.33384900E+00, -.78879200E+01, 0.27236500E+01, 0.76275300E+00, -.96984200E+00, 0.12636600E+01, -.30678800E+01, -.68841500E+00}, { 0.21304000E+00, 0.60398900E+00, 0.20213500E+00, 0.90937800E+00, -.24979100E+01, -.88907700E-01, -.14126400E+01, -.77043900E+00, 0.25227500E+00, 0.47188800E+00}, { 0.16287300E+00, -.25035500E+00, 0.54666000E-01, 0.14221600E+01, 0.11942700E+01, -.44011100E+00, 0.13867500E+00, -.18904300E+01, 0.45286200E+01, -.12321700E-01}, { -.12410500E+00, 0.14487000E+00, -.18927800E+00, -.19603700E+01, -.42951900E+01, -.39136200E+00, 0.11281800E+01, 0.34219300E+01, 0.29331300E+01, -.24553100E+00}, { -.13731300E+00, 0.80681600E-01, -.10583400E+00, -.11360800E-02, -.18314100E+01, -.11420400E+01, -.28255700E+00, -.11820900E+01, -.10374000E+01, -.12582300E+01}, { 0.83222500E-01, 0.32840900E+00, 0.32791300E+00, 0.91174900E+00, -.18137600E+01, -.59822500E+00, 0.28483300E+00, -.52062600E+00, 0.57429400E+00, 0.73966600E+00}, { -.36235600E-01, 0.24096300E-01, -.21384900E-01, -.32801300E+00, 0.15072300E+00, -.10988300E-01, 0.95962300E+00, -.55715100E+00, 0.63272700E+01, -.10822600E+00}, { -.18315300E+00, 0.11092500E+01, -.12035400E+00, 0.47217000E+00, 0.77574400E-01, 0.27312600E+00, -.50689100E+00, 0.45681500E+00, -.95612200E-01, 0.15621100E+01}, { 0.48847200E-01, -.79829700E-01, 0.13512700E+00, 0.20887400E+01, 0.24744100E+01, -.46849000E+00, -.71022500E+00, -.28776300E+01, 0.13330300E+01, 0.11706000E+00}, { -.12472800E+00, 0.12284500E+00, -.25405900E+00, -.56169100E+00, -.15097000E+01, -.59891300E+00, -.92197300E+00, 0.42046100E+00, -.21277900E+01, -.31723800E-01}, { -.11757900E+00, 0.77967700E+00, -.26090900E+00, -.10001600E+01, 0.17438500E+01, -.37207900E+00, 0.38843300E+00, 0.12935000E+00, 0.40982300E+01, -.22795900E+00}, { 0.80459000E-01, 0.69729600E+00, -.17704100E-01, 0.49965600E+00, 0.24706900E+01, 0.11335800E+01, -.86652900E-01, -.29656900E+01, -.42769400E+00, 0.12167100E+00}, { -.16742100E+00, -.30781500E+00, -.82649800E-01, -.15632500E+01, -.27741300E+01, -.51293400E-01, -.22585500E+00, -.10566400E+01, -.11467200E+01, 0.23858900E+00}, { 0.11288000E+00, 0.39589800E+00, 0.12450900E+00, -.40000600E+00, -.10139200E+01, 0.62602500E-01, -.26624900E+01, 0.94934600E+00, -.18392300E+01, 0.76436000E+00}, { 0.39369815E-61, 0.60135668-153, 0.15777371E-51, 0.36155457E-42, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.69632547E-76, 0.60470544-153, 0.17309246-152, 0.59350130E-37, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
    };
    double uniaxial_theta_hu [9][25] = {
        { -.73142000E-01, 0.26917900E-01, -.15452800E+00, 0.59812400E-01, 0.70726300E-01, 0.86121500E-01, 0.21651300E+00, 0.12469600E+00, 0.23115600E+00, 0.16339700E+00, -.38269500E+00, -.82869800E-01, -.17223800E-01, 0.21138300E-01, 0.80121500E-01, -.20787800E+00, -.76384500E-01, -.97527100E-01, -.53783100E-01, 0.38338800E+00, -.48567500E-01, -.16183400E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.14627500E+00, 0.58585800E+00, 0.55669200E-01, 0.85293100E+00, -.12460400E+00, 0.74058700E+00, -.84547400E+00, -.31342400E+00, 0.15589300E+00, 0.13700200E+01, -.32604400E+00, 0.49941000E+00, -.41925700E-01, 0.56316600E+00, -.34739800E+00, -.16777800E+00, -.84301000E+00, -.61127500E+00, 0.35631500E-02, 0.34289900E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.20861200E-01, -.13808200E+00, -.84712400E+00, -.28662700E-01, 0.28215300E-01, 0.38817700E+00, 0.18751400E-01, -.58220200E+00, -.28536000E+00, 0.61655100E+00, 0.38205900E+00, -.55839400E+00, -.60558200E+00, -.16475800E+00, -.92199600E+00, -.14816800E+00, 0.79784700E+00, -.82953900E+00, -.59991000E+00, 0.58629800E+00, -.98479800E+00, 0.22474200E+00, 0.64505400E+00, -.23520200E+00, 0.00000000E+00 },
        { 0.23321900E+00, -.10231600E+00, 0.22442500E+00, -.78147400E+00, 0.61208000E+00, 0.70944800E+00, 0.17085500E+00, 0.10954200E-01, -.33284000E+00, 0.59838000E+00, 0.38394800E+00, -.14294800E+00, 0.10347400E+00, 0.10291400E+01, 0.60209700E+00, -.24887500E+00, -.55294900E-03, 0.38228200E+00, -.55223100E-01, -.83497000E+00, 0.55854800E+00, 0.12315900E+00, -.51544200E+00, -.30821800E+00, -.27376600E+00 },
        { 0.30505800E+00, -.18192300E+00, -.64013100E+00, 0.19535800E+00, -.39459700E-01, 0.36918700E+00, 0.33080500E-01, 0.98172200E-01, 0.48448200E-01, 0.22588700E+00, 0.25561900E+00, -.32479700E+00, -.54729500E+00, 0.23376300E+00, -.26039300E-01, 0.40410600E+00, -.30267400E-01, -.40512700E+00, -.55029100E-01, -.98447900E+00, 0.22369800E+00, 0.41552500E+00, -.17978400E+00, 0.28719500E-01, -.44445200E+00 },
        { 0.74511400E+00, -.29742900E+00, 0.15018000E+00, -.21915300E+00, -.43834200E-01, -.51070300E+00, 0.11619100E+00, 0.11280900E+01, -.84751600E+00, 0.40871300E+00, -.12568600E+01, -.85954300E+00, 0.70029100E+00, 0.94836700E+00, -.11725600E+01, 0.49274300E+00, 0.42079300E+00, -.90265600E-01, 0.14034500E+00, 0.22478500E+00, 0.17951900E+00, -.15360500E+01, -.22473900E+00, -.15087800E+01, -.37602200E+00 },
        { 0.60235700E-01, 0.63369300E+00, -.24407400E+00, 0.81775800E+00, -.18057500E+00, -.14058300E-01, 0.18646300E+00, -.40488000E+00, 0.42822900E+00, -.21159600E+00, 0.37090000E+00, 0.83553900E-01, 0.24819100E+00, -.19720600E+00, -.49836400E-01, -.38297000E+00, -.16205100E+00, -.27406700E+00, 0.72229900E+00, 0.45306300E+00, 0.25284100E+00, -.47283000E+00, 0.27065200E+00, -.42559400E+00, 0.00000000E+00 },
        { 0.51073800E-02, 0.13149700E-01, -.68758200E+00, 0.11545100E+00, -.40364500E+00, 0.31400900E+00, 0.30760400E+00, -.59678400E-01, 0.15819400E+00, -.23964700E+00, 0.12099600E+00, -.10593100E-03, -.32207900E-02, -.39924500E+00, -.70837300E-01, -.51508000E-01, -.82838000E+00, -.31278100E+00, -.52424600E-01, -.85392700E-02, 0.12648500E+00, 0.31338100E+00, -.25550500E+00, -.32115400E+00, -.22521500E+00 },
        { 0.20015900E+00, -.19549800E+00, 0.65460700E+00, -.88220300E-01, -.76126800E-01, -.74334300E+00, -.14384400E+00, 0.35524200E-03, -.10547200E+00, -.67249100E+00, -.46734600E+00, -.13499500E+00, 0.41240600E+00, 0.20053900E+00, -.46202000E+00, 0.10965800E+00, 0.38000800E+00, -.30635000E+00, 0.71743700E+00, 0.39153900E+00, 0.62665100E-01, 0.17754900E+00, -.27585300E+00, 0.00000000E+00, 0.00000000E+00 },
    };
    double uniaxial_weights_models [9][25] = {
        { 0.49673800E+01, 0.56493400E+01, 0.65437600E+01, 0.56938800E+01, -.42310300E+01, 0.83489000E+01, 0.87105800E+01, 0.38859500E+01, 0.11610700E+02, -.74743700E+01, -.39989500E+01, -.48734500E+01, -.54977000E+01, -.52086700E+01, -.60676900E+01, -.21106400E+01, -.11730100E+02, -.42620200E+01, 0.71265600E+01, -.73997600E+01, 0.65173000E+01, 0.74748900E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36467400E+01, 0.29992400E+01, 0.39030200E+00, 0.40231200E+01, -.31755600E+01, -.61499900E+01, 0.37615700E+01, 0.30497400E+01, -.36779200E+01, -.78098300E+01, 0.70324200E+01, 0.47138000E+01, 0.46454800E+01, -.18772000E+01, -.44878400E+01, -.67641300E+01, -.67954100E+01, -.66990700E+01, -.65883300E+01, -.39379200E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.73114100E+01, -.23362400E+01, -.49972200E+01, -.47558100E+01, 0.12272100E+02, 0.67145200E+01, 0.62588300E+01, -.48415400E+01, -.59649300E+01, -.54408000E+01, 0.63924400E+01, -.66022900E+01, 0.35107300E+01, -.63380700E+01, 0.95944000E+01, -.46881700E+01, 0.54890100E+01, 0.81837400E+01, 0.72187000E+01, 0.41117400E+01, 0.10427500E+02, -.56201800E+01, 0.61787900E+01, -.99872000E+01, 0.00000000E+00 },
        { 0.32899200E+01, 0.70002100E+01, -.62793000E+01, 0.49712400E+01, -.24040500E+01, 0.38070600E+01, -.53458600E+01, -.10930200E+01, 0.68801100E+01, 0.52900200E+01, 0.22162300E+01, -.58603400E+01, 0.41232600E+01, 0.27803800E+01, -.93242400E+01, 0.43521200E+01, -.19115300E+01, -.56918000E+01, 0.59479000E+01, -.67240200E+01, 0.82782600E+01, -.12504900E+01, -.30780200E+01, 0.68269700E+01, -.79667300E+01 },
        { -.54979800E+01, -.46695800E+01, -.62447100E+01, -.57817900E+01, -.51011000E+01, 0.68706800E+01, -.44774200E+01, -.71638200E+01, 0.57079200E+01, -.45732600E+01, 0.53443100E+01, -.69449300E+01, -.43035700E+01, 0.91993600E+01, 0.64713600E+01, -.59132200E+01, 0.50827400E+01, 0.59283400E+01, 0.84447900E+01, 0.74266400E+01, 0.48912000E+01, 0.17253100E+01, -.86113900E+01, -.70859500E+01, 0.10268100E+02 },
        { -.64919200E+01, -.64401700E+01, 0.70910900E+01, 0.34089000E+01, 0.81280600E+01, -.86523200E+01, -.61851200E+00, -.47702300E+01, 0.65092700E+01, -.52655600E+01, -.22626500E+01, -.79503300E+01, -.31647100E+01, 0.49486100E+01, -.53398300E+01, 0.55833800E+01, 0.63767300E+01, 0.55029200E+01, 0.88659400E+00, 0.62949800E+01, -.95448100E+01, 0.60927200E+01, -.29802100E+01, 0.54186500E+01, -.34142800E+01 },
        { -.74192200E+01, 0.40620100E+01, 0.65127500E+01, -.53578800E+01, 0.55824900E+01, -.74462400E+01, 0.40989600E+01, 0.54501600E+01, -.61890500E+01, -.80945300E+01, -.28418500E+01, 0.75195400E+01, 0.52372400E+01, -.63998600E+01, -.68959800E+01, 0.45749600E+01, -.74161800E+01, 0.48637300E+01, -.80408300E+01, 0.59106600E+01, -.55990800E+01, -.62798300E+01, 0.45097100E+01, -.60292000E+01, 0.00000000E+00 },
        { 0.35895400E+01, 0.33560600E+01, 0.72494300E+01, 0.54585200E+01, 0.53521700E+01, 0.49302800E+01, 0.52248900E+01, 0.46880300E+01, 0.84344900E+01, -.68089600E+01, 0.42664700E+01, 0.61584000E+01, -.83760800E+00, 0.68674200E+01, 0.62202200E+01, 0.46762800E+01, -.10018800E+02, -.48858400E+01, -.71493400E+01, -.43829400E+01, 0.39914400E+01, 0.76942300E+01, 0.10950100E+02, 0.52393400E+01, 0.46357100E+01 },
        { 0.60209600E+01, 0.54464000E+01, 0.41336900E+01, 0.70988300E+01, -.43340700E+01, 0.59984100E+01, -.69623800E+01, 0.49980600E+01, -.10030600E+02, -.17862700E+01, -.90207700E+01, 0.78755300E+01, -.57316200E+01, -.52961000E+01, 0.95072600E+01, -.74507200E+01, -.88453200E+01, -.79657800E+01, 0.10863800E+02, 0.44711900E+01, -.47968300E+01, -.62947700E+01, 0.62112700E+01, 0.00000000E+00, 0.00000000E+00 },
    };
    double uniaxial_theta_models[9] = {-.14970700E+01, 0.17437700E+01, 0.20156000E+01, -.14431700E+01, 0.28827400E+01, 0.66022500E+00, 0.25984500E+01, -.17350000E+01, 0.21146100E+01 };
    double uniaxial_minimum_inputs[10] = { 0.20000000E+02, 0.10000000E+01, 0.10000000E+01, 0.90000000E+02, 0.45700000E+03, 0.50000000E+00, 0.00000000E+00, 0.46200000E+01, 0.32000000E+03, -.10000000E+01 };
    double uniaxial_maximum_inputs[10] = { 0.18000000E+03, 0.20000000E+05, 0.30000000E+01, 0.12600000E+04, 0.21280000E+04, 0.41000000E+02, 0.74000000E+02, 0.30500000E+03, 0.19680000E+04, 0.73000000E+03 };
    double uniaxial_minimum_output = 0.37657000E+01 ;
    double uniaxial_maximum_output = 0.99489000E+01 ;

    update_message.sprintf("Finished reading in 'Uniaxial'.");
    ui->message_label->setText(update_message);

    // Now do the bending model.  This consists of five models and eight inputs.  The inputs from the uniaxial model that are not used are FIRST and SECOND.  The number of hidden units in are 5,22, 25, 23 and 21.
    int bending_no_in_cttee = 5;
    int bending_no_inputs = 8;
    int bending_hidden_units[5] = {22, 25, 23, 21, 20};
    double bending_weights_hu [5][25][8] = {
        {{ -.24451500E-01, 0.10073200E+00, -.13419300E+01, -.62045200E+01, -.29940200E+00, 0.24570500E+00, 0.35672900E+00, 0.11306900E+01}, { 0.13949100E+00, -.44774400E+00, -.23373700E+01, -.34575400E+01, 0.11826100E+01, 0.19432900E+00, -.15655000E+01, -.22643200E+01}, { -.13874300E-01, 0.29287200E+00, 0.33808600E+01, -.55203700E+01, 0.87496500E+00, -.46716600E+00, -.15072900E+01, -.50215500E+00}, { 0.51415800E-01, -.18554100E+00, 0.24928000E+01, 0.14638800E+01, 0.14682600E+01, 0.70616900E-01, 0.48244700E+00, -.36427600E+00}, { -.10220100E-01, 0.68708400E-01, 0.86160900E+00, 0.61168100E+01, -.22991400E+01, -.15552100E+00, 0.52469900E+00, -.20989500E+01}, { 0.87918100E-01, -.13397500E+00, 0.51749400E+00, -.26035800E+01, 0.90073400E+00, -.94882800E+00, -.23601000E+01, 0.30319400E+00}, { -.15153400E+00, -.22865100E+00, -.39951500E+01, -.34784100E+00, 0.26969200E+00, -.69844800E+00, -.16935100E+01, -.96198700E+00}, { -.51285200E-01, 0.38042500E+00, 0.77954100E+01, -.13556100E+01, 0.22074000E+01, -.14385900E+00, 0.65495100E+00, -.30580100E+01}, { -.55650300E-02, 0.17753500E+01, 0.90738000E+01, -.12914500E+01, 0.16107600E+01, -.50635400E-01, 0.52946400E-01, -.31755300E+01}, { 0.78519100E-01, -.68511900E+00, 0.27431100E+01, -.48966200E+00, 0.70806400E-01, 0.76194100E+00, 0.15357300E+01, 0.65953200E+00}, { 0.85683500E-01, 0.12225100E+01, 0.27686500E+01, -.56405000E+01, -.31540700E+00, -.70137000E+00, -.65036700E+00, 0.21179900E+00}, { 0.26731300E-01, 0.18743000E-01, 0.50053600E+00, 0.10808700E+01, -.50271900E+00, -.96458900E-01, 0.18272200E+01, 0.53781400E-01}, { 0.12769900E-01, -.56289800E+00, 0.21235400E+01, 0.26289300E+01, -.21542500E+01, -.18677700E+01, 0.10801000E+01, 0.29079600E+01}, { 0.44568400E-01, -.24454400E-01, 0.14642200E-01, 0.48586900E+00, 0.32062900E+00, -.32772900E+00, -.54363000E+00, 0.85917400E+00}, { -.20305300E+00, -.11119500E+01, -.19109700E+01, 0.27723700E+01, -.16279700E+00, 0.20245700E+01, 0.17029600E+01, -.84077400E+00}, { 0.99842700E-01, -.61941300E+00, 0.16835600E+00, -.24803500E+01, -.24839000E+00, -.93740300E+00, -.90132200E+00, 0.50544300E+01}, { -.62229100E-02, 0.57738600E+00, 0.60213600E-01, -.20153400E+01, 0.70785400E+00, 0.23699600E+00, 0.25691100E+00, 0.25860400E+00}, { -.34712200E-01, -.93452500E-01, 0.14415500E+01, 0.15337400E+01, -.10612700E+01, -.20074300E+01, -.12134100E-01, 0.48740900E+01}, { -.37572300E-01, 0.45717800E+00, 0.84044800E+00, -.43347100E+01, -.43871300E+00, -.52113500E+00, -.38358800E+00, 0.14063000E+01}, { 0.15532000E+00, 0.27047500E+00, 0.13737300E+01, 0.33108400E+01, 0.20319100E+01, -.33037700E+00, 0.37949000E+00, 0.64558400E+00}, { 0.12305900E-01, 0.10397100E+00, 0.94446300E+00, -.38181500E+00, 0.61391100E+00, -.20007700E+01, -.45308100E+00, 0.32489700E+01}, { -.21064200E-01, 0.75243200E-01, -.25748800E+01, -.17705200E+00, 0.30079000E+00, -.74929200E+00, 0.66362700E+00, 0.63825200E-01}, { 0.48644211E-85, 0.65182494E-37, 0.60412845-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.18315397E-75, 0.44392198E-37, 0.60136126-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.15797081-152, 0.23694795E-37, 0.10862436E-70, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ 0.48911100E+00, -.14125800E+00, 0.20235300E+00, -.51152600E+01, -.67291700E+00, 0.57006600E+00, -.17486500E-01, -.78071500E+00}, { -.26475100E-01, 0.26307500E+00, 0.15522900E+01, 0.23928000E+01, 0.22073500E+01, -.14320300E+01, -.14440200E+00, -.85723200E+00}, { -.15122100E-01, -.62258900E-01, -.15564300E+00, -.24863100E-01, -.52816100E-01, 0.11864000E+00, 0.10851200E+00, 0.16912800E-01}, { 0.11354800E+01, -.82252500E+00, -.31441500E+01, -.46426100E+01, -.96829700E+00, -.87185300E+00, -.36227900E+00, 0.15235500E+01}, { -.86022500E-01, -.23875100E-02, 0.65665000E-01, 0.69950700E+00, 0.33657600E-01, 0.12913300E+00, -.10435800E+00, 0.82167200E-02}, { -.30878600E+00, 0.40112800E+00, 0.37490200E+01, 0.24048500E+01, -.10887100E+01, -.63531000E+00, -.10300100E+01, -.27752500E+00}, { 0.11338100E+00, 0.34008000E-01, -.27805800E+00, -.33881700E+01, 0.14392900E+01, 0.32151800E+00, -.14597300E+01, -.17359700E+01}, { 0.20243600E+00, 0.80211500E+00, -.74164700E-01, -.15346900E+01, 0.67623100E+00, -.18798700E-01, -.21519400E+01, -.11066200E+01}, { -.95321600E-01, -.26326200E+00, -.19268400E+01, 0.35421600E+01, 0.11790000E+00, 0.13428100E+01, -.87989800E+00, 0.44448100E+00}, { -.16361900E+00, -.15436900E+00, -.14802500E+00, -.20768100E+00, -.45712900E+00, -.30645300E+00, 0.23786400E+00, 0.14429600E+00}, { -.40925100E-03, -.24561600E-01, -.72720200E-01, 0.53524800E-01, -.72905000E-02, 0.67923700E-01, 0.60112300E-01, 0.10435900E-01}, { -.13491900E+00, -.11132300E+00, -.13105000E+00, -.45195100E+00, -.39950700E+00, -.21824100E+00, 0.29293300E+00, 0.21402300E+00}, { -.19954200E+00, -.60227600E+00, 0.83705000E+00, 0.20869600E+01, -.21675800E+00, 0.11937500E+01, 0.25248800E+01, 0.46452600E+00}, { 0.21597700E+00, 0.59833900E+00, -.24914200E+01, -.18182600E+01, -.69002100E-01, -.12983100E+01, -.25604300E+01, -.87442500E+00}, { -.43439900E+00, 0.15337800E+00, 0.40585700E+01, 0.11600100E+01, 0.76108000E-01, 0.55460400E+00, 0.19674900E+01, 0.26096800E+01}, { 0.25981000E+00, 0.15413900E+01, 0.81750800E+01, -.53541700E+00, 0.22949000E+01, -.18475700E+01, 0.23950100E+00, -.27156300E+01}, { -.62928200E+00, 0.65287800E-01, -.46125700E+01, 0.10444100E+01, -.59786100E+00, -.52066300E+00, -.19542900E+01, -.18486400E+01}, { 0.25748200E-01, 0.35452000E+00, -.30393200E+01, 0.19421500E+01, -.18232600E+01, 0.13140800E+01, -.96074200E+00, 0.13489100E+01}, { -.44892900E+00, -.33330600E+00, 0.10577100E+00, -.22914400E+01, -.10675700E+01, -.52287300E+00, 0.11981400E+01, 0.14356500E+01}, { 0.16452500E+00, 0.29556100E+00, 0.15333600E+01, 0.14903700E+01, 0.13440900E+01, 0.12215000E+01, -.47967700E-01, 0.13080700E+01}, { 0.98336800E-01, -.86640500E-01, 0.24940100E+00, -.86710900E+00, 0.36651200E-01, -.16531900E+01, -.67196400E+00, 0.24022000E+01}, { -.50768500E+00, 0.75857900E+00, -.91115900E+00, -.10970000E+01, -.14009400E+01, 0.96458200E+00, 0.99110400E+00, 0.24068100E+01}, { 0.21897800E+00, -.74646100E+00, -.72540800E+00, -.63235600E+00, -.49038500E+00, -.24156300E+01, -.17928500E+01, -.58861900E+00}, { -.76411100E-01, -.21171000E+00, -.16986000E+01, -.16201800E+01, 0.61561500E-01, 0.12546000E+01, 0.14952800E+01, -.23917000E+01}, { 0.39155100E-01, -.35501700E+00, -.18964100E+01, -.53903700E+01, 0.45940800E+00, -.28648200E+00, 0.22552100E+00, 0.26407900E+01}},
        {{ 0.15072600E+00, -.27335100E+00, 0.23687600E+01, -.44556900E+01, 0.19332000E+01, 0.46731600E+01, 0.96220600E-01, 0.14044900E+01}, { 0.14509800E+00, -.20839800E+00, -.11877700E+01, 0.91005800E+00, -.19905200E+01, 0.15277500E+01, -.19483000E+00, 0.19034700E+01}, { 0.12716000E+00, -.36287600E+00, -.13974200E+01, -.13684000E+01, 0.87356500E+00, -.60761100E+00, 0.90587500E+00, -.76659700E+00}, { -.97324900E-01, 0.15876700E+01, 0.10294200E+02, 0.16721600E+00, 0.29706400E+01, -.11676300E+01, -.16210400E+00, -.56635200E+01}, { 0.98045700E-01, 0.22065600E+00, -.36602100E+01, 0.88988900E+00, -.29635000E+01, -.19096000E+01, 0.23886100E-01, -.59967300E+00}, { -.14517300E+00, 0.16295200E+00, -.12846700E+01, -.17231800E+00, 0.32183700E+01, 0.27723600E+00, -.54335000E+00, -.55669700E+00}, { -.18231000E+00, -.23379700E+00, 0.24155700E+01, 0.18256500E+01, 0.20017200E+00, 0.10079700E+01, 0.10394500E+00, -.60655400E+00}, { -.89610600E-01, -.22855500E+00, -.47101700E+01, -.33495800E+01, -.76260200E+00, -.71316000E+00, -.10566100E+01, -.21257800E+01}, { 0.19310900E+00, 0.48995100E+00, 0.40470300E+00, 0.87908800E+00, 0.27358700E+01, 0.20361600E+01, -.81822700E-01, -.42400200E+01}, { 0.16140600E-01, 0.58279700E+00, -.20772200E+01, 0.37474500E+00, 0.24064100E+01, -.65537300E+01, 0.64080400E+00, 0.38969200E+00}, { 0.21978500E-01, 0.41716300E+00, -.98221100E+00, -.10822500E+01, 0.20999200E+01, -.10732500E+01, -.17156800E+00, -.20974000E+01}, { 0.25548600E+00, 0.27666000E+00, -.20997900E+01, -.73589700E+00, -.22018400E+01, -.94727900E+00, -.75088700E+00, -.15501000E+01}, { 0.16051100E+00, 0.27940200E+00, -.15120500E+01, 0.22440500E+01, 0.23639600E+01, -.29052500E+01, 0.24269400E+00, -.13036900E+01}, { 0.28483800E-01, -.37497900E-01, 0.34123000E+01, -.23557300E+01, 0.96646400E+00, -.24666600E+01, 0.49411100E-01, -.19568900E+01}, { 0.21306400E-01, 0.16801000E+00, -.91498500E+00, 0.74993800E+00, 0.14537100E+01, -.75746800E+00, 0.10492500E+01, -.25627600E+01}, { -.91561300E-01, -.38297500E+00, -.42570500E+01, 0.24667400E+00, 0.21451500E+01, -.40064700E+00, -.49696700E+00, 0.10672500E+01}, { 0.26454100E+00, 0.12048900E+00, 0.30727000E+01, 0.33803700E+01, 0.12323200E+01, 0.47114100E+00, 0.49544200E-01, 0.60166900E+00}, { -.11297500E+00, -.24982400E-02, -.24377900E+01, -.57262000E+00, 0.21491600E+01, -.42071500E+01, -.51394200E+00, -.19874200E+01}, { 0.33523000E+00, 0.68837100E+00, -.44762500E+01, 0.43523600E+00, -.13611000E+01, -.54417300E+01, 0.39592900E+00, -.16140100E+00}, { 0.62496200E-01, -.84391900E+00, -.79955600E+01, -.76358000E-01, -.29434800E+01, 0.10397800E+01, 0.26398600E+00, 0.47399500E+01}, { 0.58232600E-01, -.10032000E+00, 0.28753300E+01, -.18965800E+01, 0.13281700E+01, -.22953000E+01, 0.33838200E-01, -.30486400E+01}, { 0.57260600E-01, 0.21441200E+00, -.14878400E+01, -.96655200E+00, 0.52848100E+00, -.33362500E+01, -.71286800E+00, -.26558800E+01}, { -.28142800E+00, 0.50799500E+00, -.15092300E+01, 0.18800500E+01, -.22946900E+01, -.37547900E+01, 0.71130200E-01, 0.31152400E+00}, { 0.14850875E-75, 0.36295313E-42, 0.12578054E-70, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.90579727E-42, 0.11303560E-41, 0.10408365E-41, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ -.11212800E+01, -.47373000E+00, 0.12350300E+01, 0.31123100E+01, 0.21261900E+01, 0.48132100E+00, -.43899900E+00, -.27152800E+00}, { -.78338400E-01, -.10181000E+01, -.21574800E+01, 0.49658000E+01, -.44967500E+00, 0.13052800E+01, -.56087500E+00, -.11022500E+01}, { 0.80084200E-01, -.50648000E-01, 0.17148000E+01, 0.30096800E+00, 0.17744700E+00, -.31442000E+00, 0.98693900E+00, -.53646700E+00}, { -.15774200E+00, -.69864500E+00, -.20405000E+01, 0.17267400E+01, 0.17266400E+01, -.14609100E+01, -.95969700E+00, -.14139200E+01}, { 0.18200900E+00, -.10784500E+00, 0.48052500E+00, 0.73137200E+00, 0.86281800E+00, 0.34449700E+00, -.63901900E+00, 0.16329400E+01}, { 0.31260000E+00, 0.18404900E+00, -.15207500E+00, -.32819500E+00, 0.11204300E+00, -.44594900E+00, 0.14393700E-01, 0.15321100E+00}, { -.32357600E+00, -.92827200E+00, -.11682300E+01, -.17685000E+01, 0.75708500E+00, -.64418700E+00, 0.52071800E-01, -.18218000E+01}, { -.69862700E+00, 0.31482300E-01, 0.29934200E+01, -.14966800E+01, 0.15171800E+01, -.94562200E-01, -.49719600E+00, -.11783100E-01}, { 0.36913600E+00, 0.26177400E+00, -.16534600E+01, 0.45477600E+01, 0.76773400E+00, -.40895700E+01, -.26887800E+00, -.14157500E+01}, { 0.44455000E-01, -.94116200E-01, -.33685300E+01, 0.84423400E+00, 0.66429200E+00, -.22379300E+01, -.72768400E+00, -.14369800E+01}, { 0.11928400E+01, 0.47194300E+00, -.12826500E+01, 0.19303700E+01, -.60331300E+00, -.29837600E+01, -.41577700E+00, -.41114300E+00}, { -.32097000E+01, 0.10726400E+01, 0.56956500E+01, -.75422000E+00, 0.13669000E+01, -.62555000E+00, -.50717800E-01, -.14034000E+01}, { 0.35688900E+00, 0.24212400E+00, 0.22110800E+01, -.35172400E+01, 0.39301600E+00, 0.20793200E+01, 0.21343500E+00, 0.25706900E+00}, { -.84473100E+00, -.38720000E+00, -.12953800E+01, 0.53753600E+01, 0.21471400E+00, -.20637000E+00, 0.62098200E+00, -.13969500E+01}, { 0.51330700E+00, 0.96768200E-01, -.12992500E+01, -.27529800E+01, -.84608200E-01, -.75097500E+00, -.76867500E+00, -.28521300E+00}, { -.90106100E+00, -.36235800E+00, -.33856300E+01, -.67890700E+00, -.64715500E+00, 0.93964500E+00, -.40605400E+00, 0.20582500E+01}, { 0.15837800E+01, -.28152700E+00, 0.58415000E+01, -.34524900E+01, 0.92520400E+00, 0.30146700E+01, -.24694500E+00, 0.62905700E+00}, { 0.22308000E+00, -.22815900E+00, -.14080800E+01, 0.16653500E+01, -.22338000E+01, 0.13316000E+01, -.64359100E+00, 0.20357400E+00}, { 0.19092200E+00, -.28455200E+00, 0.76353600E+00, 0.50470600E+00, -.34532100E-02, 0.16440100E+00, 0.17090300E-03, -.80988100E+00}, { -.13348100E+01, 0.64788300E+00, -.26321900E+01, 0.27356600E+01, -.12512900E+01, -.20922600E+01, -.44577400E+00, 0.16997600E+01}, { -.15983400E+01, -.41540600E-02, 0.58582700E+01, -.40194500E+01, 0.16282300E+00, 0.43689300E+01, -.64024600E+00, 0.16943700E+00}, { 0.15697334E-75, 0.46665418E-85, 0.60383142-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.82068010E-66, 0.14850875E-75, 0.63522883E-66, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.18780451-152, 0.36154599E-42, 0.30624798E-56, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.24049501E-56, 0.16542915-152, 0.15579262E-75, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ -.17737000E-01, 0.48877000E+00, -.38461100E+01, -.21926000E+01, 0.12338600E+00, 0.42913800E+01, 0.60068600E+00, 0.56009100E+00}, { -.83186300E-01, -.95162800E+00, -.68754600E+00, 0.29005000E+01, 0.14372400E+00, -.17219300E+01, -.16208700E+01, 0.10246800E+00}, { 0.20968500E+00, 0.49454300E+00, 0.83726700E+00, -.29347900E+01, -.24432900E+01, 0.32517100E+00, -.19359600E+01, 0.90050400E+00}, { -.14994500E+01, -.35498000E+00, 0.13751200E+01, 0.27500200E+01, 0.30881700E+01, -.16658500E+01, -.65434200E+00, -.88864300E+00}, { -.89362800E-01, -.43147900E+00, -.28109300E+01, 0.17223300E+01, -.22260000E+01, -.21711000E+00, -.43178200E+00, -.10173500E-01}, { 0.21262400E+01, -.37287800E+00, 0.12818400E+02, -.65720200E+01, 0.51442800E+00, 0.31577400E+00, -.74249500E+00, -.12430600E+01}, { -.55320700E+00, -.19400400E+00, -.17726400E+01, 0.14517400E+01, 0.16074600E+01, -.27067900E+01, 0.11947900E+01, 0.90624000E+00}, { 0.74207100E+00, 0.18456800E+00, -.23109600E+01, -.94683600E-01, 0.30926100E+00, -.30898400E+01, 0.21133100E+00, -.16151100E+01}, { -.10440500E+01, -.21385700E+00, -.77403400E+01, 0.90117800E-01, -.15660900E+01, 0.32661100E+01, 0.21957100E+00, 0.71042400E+00}, { 0.23046500E-01, 0.77779300E-01, -.17536900E+01, 0.23629800E+01, 0.18625000E+01, -.16516200E+00, 0.99202400E+00, -.16525900E+01}, { -.11259600E+00, -.10762900E+00, 0.22555900E+01, -.21072500E+01, 0.19097900E+01, -.52960800E+00, 0.64926600E+00, 0.12546600E+01}, { 0.87102800E+00, 0.46793900E+00, 0.84400700E+01, -.25090300E-02, -.14479600E+01, -.31535000E+01, 0.83380700E+00, -.39977900E+00}, { 0.64458000E+00, -.56960200E-01, -.73693800E+01, 0.42704600E+01, -.15772800E+01, -.83469600E+00, 0.12773500E+01, 0.10699000E+01}, { 0.91099500E+00, 0.61374500E+00, -.17831200E+01, 0.32532400E+01, 0.14158700E+01, 0.24185200E+01, -.78816100E+00, -.68261400E-01}, { -.50297000E+00, -.42677800E-01, -.10588000E+01, 0.21492800E+01, 0.37805900E+00, -.12642300E+01, 0.98713500E+00, -.13127600E+01}, { -.70363600E+00, -.52042800E+00, 0.45293600E+01, -.25222000E+01, 0.70048400E+00, 0.14491900E+01, -.10726700E+01, -.90859500E+00}, { 0.90141900E+00, -.63419800E+00, -.26182100E+01, -.93308300E+00, 0.11169300E+01, 0.42597900E+01, 0.13526700E+01, -.10606600E+01}, { 0.42052400E+00, -.12705300E+00, -.71790000E+00, -.17019800E+01, -.14609700E+01, -.24657100E+01, 0.26284800E+00, -.12939800E+01}, { -.16131000E+01, -.19543000E+00, 0.55542600E+00, 0.23010700E+01, 0.31160100E+00, -.27082300E+01, -.74739300E+00, 0.16063400E+01}, { -.16570600E+00, 0.32105100E-01, 0.26965400E+01, 0.23935800E+01, 0.30418000E+00, -.24478000E+01, 0.68794700E+00, -.83641200E+00}, { 0.60427353-153, 0.21698797E-75, 0.15860762E-46, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60382340-153, 0.60134704-153, 0.60367773-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.59305291E-37, 0.14334615-152, 0.23694280E-37, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.13559636-152, 0.36155286E-42, 0.16601736E-75, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.69902286E-76, 0.13037116E-75, 0.60383539-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
    };
    double bending_theta_hu [5][25] = {
        { 0.10205500E-01, 0.61493900E+00, -.77703600E+00, -.42335100E+00, -.60829500E+00, -.27429400E+00, 0.52811000E+00, 0.15580500E+01, 0.17836500E+01, 0.10106300E+01, -.34744900E+00, 0.54170100E+00, 0.29239100E-01, -.18140700E+00, -.73101900E+00, -.43431100E+00, -.21937000E+00, 0.48117600E+00, -.84813700E-01, 0.58153200E+00, -.44696200E+00, -.48028100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36675600E+00, 0.16712700E+00, 0.31813900E-01, -.83658000E+00, 0.55860800E-01, -.26316100E+00, -.11429400E+00, -.40158400E+00, 0.50584100E+00, 0.13290200E+00, -.42480900E-02, 0.16510000E+00, 0.16922300E+00, 0.11989100E+00, -.17885600E+00, 0.20750500E+01, -.17855800E+00, 0.18596900E+00, 0.11803900E+00, 0.22078500E+00, 0.24345900E+00, 0.16085300E+00, -.59339000E+00, -.32397200E+00, -.28129200E+00 },
        { 0.47044800E+00, -.16650800E+00, 0.95840200E+00, 0.20963600E+01, -.41476600E+00, 0.45048800E+00, 0.96001500E+00, 0.53925500E+00, -.10433600E+01, -.17521800E+00, -.10116600E+01, -.86846500E+00, -.39862200E+00, -.63053300E+00, -.39342800E+00, 0.29289000E+00, -.42957500E+00, 0.35194500E+00, -.10853400E+01, -.16823200E+01, -.27904800E+00, -.17919400E+00, -.36698600E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.18447900E+00, -.35718900E-01, -.62053300E-01, -.78216500E-01, 0.92896400E-01, -.77272600E-01, -.80312200E-01, 0.23565400E+00, -.62531800E+00, -.17515200E-01, -.77162900E-01, -.23975700E+00, -.23023100E+00, 0.96019500E-01, -.50765800E-01, 0.16232100E+00, 0.30261200E+00, -.61454200E-01, -.43912700E-01, 0.34699000E+00, 0.24317800E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.66867800E-01, 0.18856900E+00, 0.25008600E+00, 0.75642500E+00, -.48237600E+00, 0.12209500E+01, -.21455800E+00, 0.60292700E+00, 0.81270900E+00, -.93733600E-01, 0.41342200E+00, -.17171100E+01, -.38110500E+00, 0.76590800E+00, -.29918500E+00, -.56401000E-01, 0.32147100E+00, -.26890500E+00, 0.15893700E+01, 0.31659000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
    };
    double bending_weights_models [5][25] = {
        { -.38235200E+01, -.25845700E+01, -.29729700E+01, 0.54654200E+01, -.41571500E+01, 0.46555600E+01, 0.31378500E+01, 0.21013400E+01, -.17927200E+01, -.34630400E+01, 0.50522000E+01, 0.51829400E+01, 0.35017400E+01, 0.16479300E+01, 0.23456800E+01, 0.29356900E+01, 0.20535000E+01, -.32570700E+01, -.54001900E+01, -.59286300E+01, -.30810700E+01, -.28921100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.18898700E+01, -.26768900E+01, -.15031800E+00, -.16703600E+01, -.31615600E-01, 0.16452600E+01, 0.17205000E+01, -.22913600E+01, -.20357600E+01, -.46760000E+00, -.11174300E+00, -.31190300E+00, -.21927600E+01, -.15549200E+01, 0.18534100E+01, -.85416900E+00, 0.13832700E+01, 0.13192200E+01, -.21696800E+01, -.23231100E+01, 0.22663200E+01, -.24262800E+01, -.18835400E+01, 0.18069800E+01, 0.17548400E+01 },
        { -.28824200E+01, -.53891200E+01, -.44035800E+01, -.28978400E+01, 0.35166200E+01, -.42175000E+01, -.38525100E+01, -.27605900E+01, 0.38145500E+01, -.54783200E+01, -.54890500E+01, -.46809100E+01, 0.36330000E+01, 0.36351600E+01, -.27187200E+01, 0.35580200E+01, -.55663600E+01, -.34209500E+01, 0.33961400E+01, -.45110200E+01, -.38039800E+01, 0.43032800E+01, -.58449300E+01, 0.00000000E+00, 0.00000000E+00 },
        { 0.33049800E+01, -.47431600E+01, 0.41232500E+01, 0.44848400E+01, -.32160000E+01, -.70633800E+00, -.25934200E+01, 0.28053800E+01, -.36548500E+01, -.38309500E+01, 0.38680900E+01, -.22997800E+01, 0.68117900E+01, 0.35578300E+01, 0.43702000E+01, 0.22714500E+01, -.20489200E+01, 0.49872200E+01, 0.32673700E+01, 0.29644300E+01, -.11824500E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.36167900E+01, -.18610000E+01, -.24141100E+01, 0.39596000E+01, 0.47424200E+01, -.79939400E+00, -.36719700E+01, -.24162600E+01, -.33192400E+01, -.52113100E+01, 0.41532500E+01, -.27857300E+01, -.29060100E+01, 0.22678500E+01, 0.31937600E+01, -.49398300E+01, 0.26058000E+01, 0.39298900E+01, -.22125300E+01, -.31400700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
    };
    double bending_theta_models[5] = {0.12392600E+01, -.81282700E+00, 0.77305100E+00, -.20775800E+01, -.77649000E+00 };
    double bending_minimum_inputs[8] = { 0.30000000E+02, 0.10000000E+01, 0.40000000E+02, 0.45500000E+03, 0.20000000E+00, 0.00000000E+00, 0.34000000E+01, 0.24200000E+03 };
    double bending_maximum_inputs[8] = { 0.20000000E+05, 0.30000000E+01, 0.14100000E+04, 0.21680000E+04, 0.68000000E+02, 0.93000000E+02, 0.31100000E+03, 0.24666667E+04 };
    double bending_minimum_output = 0.35132000E+01 ;
    double bending_maximum_output = 0.99624000E+01 ;

    update_message.sprintf("Finished reading in 'Bending'.");
    ui->message_label->setText(update_message);

    //Now do the torsion inputs.  This consists of 6 models with seven inputs and a maximum number of hidden units of 25.  The number of hidden units in each model are {19, 25, 20, 16, 19 and 10}.
    int torsion_no_in_cttee = 6;
    int torsion_no_inputs = 7;
    int torsion_hidden_units[6] = {19, 25, 20, 16, 19, 10};
    double torsion_weights_hu [6][25][7] = {
        {{ 0.11729100E+00, 0.99386600E+00, -.21436600E+01, -.14040900E+01, 0.18876900E+00, -.20949700E+01, -.11300800E+01}, { -.76063300E-01, 0.49731900E+00, -.36248100E+00, 0.87356900E+00, 0.21622200E+00, -.63790700E+00, -.40213800E+00}, { 0.12415600E+00, -.29510100E+00, 0.55832200E+00, -.51483600E+00, -.18823400E+00, 0.63200500E+00, 0.56990300E+00}, { -.51026500E+00, -.51524200E+00, -.13714400E+01, -.19541300E+01, -.80712800E-01, 0.51548000E+01, -.17392200E+01}, { 0.56756500E+00, -.99698300E+00, 0.15607700E+01, -.22218500E+01, 0.64088700E+00, 0.12294400E+00, -.27066400E+00}, { -.69032900E+00, -.57393700E+00, 0.16251900E+01, -.34001700E+00, -.10832600E+01, 0.29947000E+01, 0.12286400E+00}, { -.72954100E+00, 0.11417300E+01, 0.16091800E+01, -.37489900E+01, 0.18494900E+00, 0.38768700E+01, -.21104300E+01}, { -.12203200E+00, 0.31433900E+00, -.55772900E+00, 0.57291800E+00, 0.20086300E+00, -.64760600E+00, -.58350300E+00}, { -.23488200E+00, -.33805600E+01, 0.89500600E+00, -.28612300E+00, -.18638700E+00, -.98014500E+00, -.28462100E+00}, { -.17807800E+00, -.11934300E+00, -.14367400E+01, 0.23887400E+00, 0.15208800E+01, 0.45325400E+01, -.43383600E+00}, { -.42187400E+00, 0.11316000E+01, -.14246100E+01, -.28043000E+01, 0.49820800E+00, 0.30764700E+01, 0.14923100E+01}, { -.53991200E+00, 0.71245100E+00, 0.16991000E+01, 0.72938600E+00, -.10989500E+01, 0.41924700E+01, 0.76684200E+00}, { -.94307100E+00, -.13003900E+01, 0.51682800E+00, -.37064000E+01, -.53473300E+00, 0.41626200E+01, -.43044200E+01}, { 0.52292900E+00, 0.12066500E+01, 0.11506600E+00, 0.95040800E+00, -.14425100E+01, 0.35878900E+00, 0.20521400E+01}, { 0.51542200E+00, -.31381600E+00, -.15459400E+01, -.21468400E+01, -.57255900E+00, -.85156500E+00, -.66044800E-01}, { -.11622800E+00, 0.37536600E+00, -.50845000E+00, 0.59473400E+00, 0.22724400E+00, -.61384800E+00, -.53210300E+00}, { -.19905300E+00, 0.30943700E+00, 0.29032100E+00, -.28353700E+01, -.91104700E+00, -.46607900E+00, -.25110900E+01}, { 0.35801600E+00, -.65217100E+00, -.22180600E+00, 0.18065700E+01, 0.69802400E+00, -.92574500E+00, -.88633400E+00}, { -.12045700E+00, -.11677400E+00, -.83596900E+00, 0.48890500E+00, -.17308900E-01, -.15011400E+00, -.12175600E+01}, { 0.60383766-153, 0.60455978-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60134704-153, 0.42628180E-85, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.44357265E-37, 0.14715645E-75, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.23157522E-51, 0.34435331E-85, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.24061922E-56, 0.77232224E-42, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.17315061-152, 0.60426843-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ 0.12772500E+00, 0.49134800E-01, -.40309300E-01, 0.53836500E-01, -.34310000E-01, 0.15121200E+00, -.31122100E+00}, { 0.72938100E+00, -.94083500E+00, -.85807800E+00, 0.18810000E+01, -.28501600E+00, -.37168100E+01, 0.50452100E+00}, { -.36404700E+00, -.30792400E+00, -.39650800E+00, 0.13409400E+01, 0.33303900E+00, 0.86841400E+00, -.30836400E+01}, { 0.89492000E-01, 0.69175800E-01, -.29958000E-01, 0.48808500E-01, -.58245000E-01, 0.18672100E+00, -.38086200E+00}, { 0.33160100E+00, 0.30402200E+01, -.63919200E+00, 0.11037000E+01, 0.24145800E+00, 0.61648800E+00, -.27158900E+00}, { -.54870500E+00, 0.12689700E+01, 0.43467800E+00, 0.14443400E+01, 0.57428700E-01, 0.57786600E+00, -.11745100E+01}, { -.64398400E-01, -.92249800E-01, 0.16431600E-01, -.41123000E-01, 0.78726800E-01, -.22215700E+00, 0.44254300E+00}, { 0.24453300E+00, -.10176400E+01, -.46874600E+00, -.10204100E+01, 0.90602200E-01, -.41408100E+00, 0.10626300E+01}, { 0.80248400E-01, 0.57196300E-01, -.32190300E-01, 0.46053700E-01, -.47953500E-01, 0.16019100E+00, -.32772800E+00}, { -.80701900E+00, -.10695700E+00, 0.19644700E+00, -.27711800E+01, -.92754000E+00, -.29212900E+01, -.27972800E+01}, { -.45380300E-01, 0.61510800E+00, 0.64007700E+00, -.33578800E+00, -.35415800E+00, 0.60839900E+00, 0.26554800E+01}, { 0.80553200E+00, -.11147000E+01, 0.67527500E+00, -.29497000E+01, -.83037900E+00, 0.25062500E+01, -.44644200E+00}, { 0.25772500E+00, -.13985900E+01, 0.50804400E+00, 0.17376900E+01, -.70860500E+00, 0.13927800E+01, 0.13302900E+00}, { -.69167900E+00, 0.88123700E+00, -.30410800E+01, -.26753400E+01, 0.72875600E+00, 0.27737100E+01, 0.29679500E+01}, { 0.74546700E+00, -.87688700E+00, 0.13618200E+01, -.25155200E+01, -.16155500E+01, 0.19631700E+01, -.49025200E+01}, { -.30970300E-01, 0.19536700E+01, -.21933200E+01, 0.20430600E+01, 0.15870000E+00, -.23859100E+00, -.21020000E+00}, { -.68494600E+00, 0.23429900E+00, -.24768800E+00, 0.25261900E+00, -.96313600E+00, -.28988500E+01, -.30120600E+01}, { 0.43123200E-01, 0.40361200E-01, -.16495600E-01, 0.23220400E-01, -.22217300E-01, 0.99679600E-01, -.20350000E+00}, { 0.77624700E-01, 0.32739700E-01, -.27202900E-01, 0.35271000E-01, -.17084000E-01, 0.94587200E-01, -.18971200E+00}, { 0.47583500E+00, 0.11487000E+01, 0.14721600E+01, 0.17934000E+01, 0.11887400E+01, 0.17805000E+01, -.32610900E+00}, { 0.50074200E+00, 0.61731500E+00, 0.39381400E+00, -.15994700E+01, 0.49416000E+00, -.21189400E+01, 0.24883100E+01}, { 0.61488800E-01, 0.17491000E+00, 0.66258300E-01, 0.38479800E-01, -.15624400E+00, 0.27152700E+00, -.57567000E+00}, { 0.14705700E+00, 0.28720600E-01, 0.66374800E+00, 0.24692000E-01, -.72839600E+00, -.28969600E+00, -.40041400E+01}, { -.10913600E+00, -.57729800E-01, 0.35038500E-01, -.47919900E-01, 0.45632100E-01, -.16731000E+00, 0.34840700E+00}, { 0.58052900E-01, 0.14507900E+00, 0.29629900E-01, 0.33551600E-01, -.12947900E+00, 0.27185300E+00, -.54638600E+00}},
        {{ 0.93345300E+00, -.10735800E+01, -.70749100E+00, 0.51020000E+00, 0.89601500E+00, -.18062100E+01, -.13647600E+01}, { 0.23939400E-01, 0.98518800E-02, -.12426500E+00, -.91144700E-01, -.60546900E-01, -.93322200E-01, 0.34357600E-01}, { 0.44143300E+00, -.24925100E+01, 0.18757600E+01, -.26484000E+01, -.48568100E-01, 0.25591600E+01, -.20955400E+01}, { 0.12963000E+01, -.14431000E+01, 0.20776300E+01, 0.32970400E+01, -.48840900E+00, -.38945800E+01, -.23841500E+01}, { -.36865700E+00, 0.34887900E+01, -.13776500E+01, -.75125300E+00, -.15149500E+01, 0.17055200E+01, 0.13670900E+01}, { 0.60071100E+00, -.20121900E+01, -.72015100E+00, -.87799800E+00, 0.53027300E+00, 0.17639400E+01, 0.11596700E+01}, { 0.11484100E+01, -.12806100E+01, -.14947800E+01, 0.33339900E+01, 0.33152000E-02, -.49788300E+01, 0.83140100E+00}, { 0.71861800E-01, 0.30388300E-01, -.31008700E+00, -.91525400E-01, -.12576100E+00, -.18756700E+00, 0.79881600E-01}, { -.58135500E+00, -.22616000E+01, -.10754900E+00, -.28095300E+00, -.30561000E+00, 0.98035600E+00, -.11680400E+01}, { -.14720800E+00, -.10963100E+00, 0.37909700E+00, 0.13968000E+00, 0.20747200E+00, 0.13681000E+00, -.13744300E+00}, { -.14644900E-01, 0.86026900E-02, -.40800700E-01, 0.49142000E-01, -.16677000E-01, -.11575800E+00, 0.21141200E-01}, { 0.31479100E-01, 0.25115500E-01, -.96466500E-01, -.13139200E+00, -.53338400E-01, -.23436900E-01, 0.27451300E-01}, { 0.30356200E+00, -.38689500E+01, 0.15034100E+00, 0.20102600E+00, 0.18733500E+00, -.90060600E+00, 0.72456000E+00}, { 0.39023800E+00, 0.38935200E-01, -.48391000E+01, -.19955700E+00, -.59426100E-02, -.20022900E+01, 0.14681500E+01}, { 0.21765500E+00, -.15037000E+00, 0.12875100E+01, -.74039000E+00, 0.35638900E+00, -.13106400E+01, -.16197200E+01}, { 0.54908500E+00, -.97663200E+00, -.14965500E+01, -.26344100E+01, -.60346000E+00, 0.16269900E-02, -.52266800E+00}, { -.16003800E+00, 0.18643100E+01, -.11690400E+01, 0.31841600E+01, -.13376300E-01, -.30006700E-01, -.31440700E+00}, { 0.21595400E+00, 0.21140700E+00, -.30028600E+00, -.19371800E+00, -.30926100E+00, -.12262700E+00, 0.20642200E+00}, { 0.44419300E+00, 0.22167300E+00, 0.25883400E+01, -.12834100E+01, -.84653300E-01, -.21619000E+00, 0.29602000E+00}, { 0.23331200E+00, 0.28890700E+00, 0.51545100E+00, 0.32562000E+01, 0.69200300E+00, -.12583000E-01, 0.16273200E+01}, { 0.18052075-152, 0.32558648E-85, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.69631226E-76, 0.17312102-152, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60427126-153, 0.60134705-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.15823279-152, 0.61077539E-61, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.15826238-152, 0.23694280E-37, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ -.28192800E+00, 0.20478000E+01, -.78613900E+00, 0.51692700E+00, 0.18526600E+01, 0.41766900E+00, 0.17871500E+00}, { 0.43886600E+00, -.16103000E+01, 0.41195500E+01, 0.29601200E+01, -.98392000E+00, -.23159900E+01, -.38126200E+01}, { -.19433000E+00, 0.19931800E+01, 0.37933300E+01, -.57610700E+00, -.14281000E-01, 0.25535500E+01, -.25628400E+01}, { 0.48035300E-01, 0.21111500E+01, -.97991400E+00, -.98047000E+00, 0.13150800E+01, -.80022400E+00, -.73701700E+00}, { -.16081400E+00, -.68914700E+00, -.32378200E+00, -.50852600E+00, -.27265600E+00, -.26687600E+00, -.11493700E+00}, { -.40259300E+00, 0.10076300E+01, 0.11481400E+00, 0.23117700E+01, 0.13577100E+00, -.10741700E+01, -.52836200E+00}, { 0.77319600E-01, -.29886200E+01, 0.30853100E+01, -.23368400E+01, 0.31962600E-01, 0.26769200E+00, -.11564800E+00}, { -.43991400E+00, 0.22609400E+01, 0.79050100E+00, 0.44975300E-01, 0.48617800E+00, -.10313800E+01, -.10757500E+01}, { 0.56569900E+00, -.22004400E+01, -.10884100E+00, -.14589100E+01, -.10748800E+01, 0.13378300E+01, -.24139200E+01}, { -.37307200E+00, -.35892200E+01, 0.11250100E+01, -.69586400E+00, -.18282800E+00, -.64766300E+00, 0.12749900E-01}, { 0.35287100E+00, -.21178100E+01, 0.49467600E+00, 0.16905500E+01, 0.12315000E+01, 0.58496600E+00, 0.16283200E+01}, { -.68895800E-01, 0.17509800E+00, 0.92420900E+00, 0.51553700E+00, 0.73211900E+00, 0.11785800E+01, 0.29873000E+00}, { -.68207800E-01, 0.73346000E-01, 0.70072800E-01, 0.40195600E+00, 0.12669600E+00, 0.28270900E-01, 0.64909800E-01}, { 0.53436000E+00, -.21952000E+01, -.11589100E+01, 0.25703600E+01, -.12852700E+00, -.38103800E+01, 0.12111400E+01}, { -.45558200E+00, 0.26010900E+01, -.11516400E+01, -.48963800E-01, -.39454800E+00, 0.13575100E+01, 0.35626700E+01}, { -.46858600E+00, -.13480200E+01, 0.42853200E+00, -.13974400E+01, 0.87059100E+00, -.26010200E+00, 0.14861200E+01}, { 0.90245825E-42, 0.17879846E-51, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.10300670E-70, 0.67719703E-42, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.17303385-152, 0.45634472E-71, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.11755343E-46, 0.41629761E-61, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.17303373-152, 0.42612441E-85, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60136070-153, 0.18043301-152, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.45634559E-71, 0.60470716-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.13582863-152, 0.48699193E-85, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.15615079E-32, 0.13654544E-70, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ -.84022600E-01, -.25628700E+00, -.63070300E+00, 0.88416900E+00, 0.58114500E+00, 0.62162800E+00, -.14771500E+01}, { 0.15379400E+00, 0.24428900E+01, 0.13259500E-01, -.95923900E+00, 0.23995100E+01, -.17017600E+01, -.55338700E-01}, { -.82704500E-01, -.27305500E+00, 0.18194100E+01, -.35072800E+00, -.12341300E+01, 0.94656700E+00, 0.34405200E+01}, { 0.18647600E+00, -.87117100E+00, 0.88466300E+00, -.21582600E-01, 0.49147300E+00, 0.99209800E-01, 0.10098100E+01}, { -.63314000E+00, 0.13374900E+01, 0.10022800E+01, -.14185400E+01, -.39641500E+00, 0.46115600E+01, 0.39525100E+00}, { 0.15332400E+00, 0.63975000E+00, 0.16809100E+01, 0.15760800E+00, -.15601300E+00, 0.24171200E+01, 0.71998500E+00}, { -.10886800E+00, 0.52232900E+00, 0.17862100E+01, 0.21962400E+01, 0.40595700E+00, 0.27787700E+00, 0.44612100E+01}, { 0.63615300E-01, -.54626800E-01, -.21335400E+01, 0.22237000E+01, -.87598000E+00, -.10553700E+01, -.65706500E+00}, { 0.53322800E+00, -.14958100E+01, -.53011900E-01, 0.25348300E+01, 0.13210600E+00, 0.91043700E+00, 0.17008200E+01}, { -.75454200E+00, 0.14204600E+01, -.21448700E+01, -.18193200E+01, 0.72319100E+00, 0.36179700E+01, 0.29617500E+01}, { 0.19839500E+00, 0.16866100E+00, -.40483400E+00, -.30239900E+00, -.62385600E+00, 0.16650800E+00, 0.16416500E+00}, { -.83745500E-02, -.34596100E+00, -.44857200E+00, -.19188800E+00, -.96518300E-01, -.28783600E+00, 0.13872100E+00}, { 0.75707800E-01, 0.11787700E+01, -.88911100E+00, 0.24914100E+01, 0.16264700E+01, 0.12303300E+01, 0.28479700E+01}, { 0.12026400E-01, 0.12547300E+01, 0.50244600E+00, 0.26229800E+01, 0.21591500E+01, 0.78184900E+00, -.13212200E+00}, { 0.35585400E+00, -.14353900E+01, -.73671200E+00, -.76904700E-01, 0.21593600E-01, -.10511200E+01, -.70683600E-01}, { 0.60120500E+00, -.78720200E+00, 0.97717400E+00, -.25012300E+01, -.29111400E+00, 0.16536100E+01, -.12602800E+01}, { 0.63660800E+00, -.13860800E+01, 0.16697300E+01, -.74260300E-01, 0.59427300E+00, 0.75947100E+00, 0.25170500E+00}, { -.84526400E-01, 0.14706500E+01, 0.23972200E+01, -.13635400E+00, 0.14375200E+01, 0.11352900E+01, 0.27048700E+01}, { 0.74324800E+00, 0.11509200E+01, -.13149000E+01, -.90385300E+00, 0.15675300E+01, -.17340700E+01, 0.18760500E+01}, { 0.32425059E-85, 0.45633524E-71, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.31184872E-32, 0.16901274E-51, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60136071-153, 0.13808015E-46, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.41629764E-61, 0.60135842-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.17312034-152, 0.10335869E-46, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60136014-153, 0.48691338E-85, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
        {{ 0.12315300E+01, -.15097100E+00, 0.74782800E+00, -.20171400E+01, -.73551100E+00, 0.24611900E+01, -.22580900E+01}, { -.17548900E+00, -.31179900E+01, 0.73258500E+00, 0.28373500E+00, -.33920500E+00, -.12295700E+01, 0.52792300E-01}, { 0.92973300E+00, -.53770600E+00, 0.20161000E+01, -.17478900E+01, -.65351600E+00, 0.17059500E+01, -.48991200E+01}, { 0.14090100E+00, -.13065900E+01, 0.36302600E+01, -.18445600E+01, 0.52950300E+00, 0.83413600E+00, -.47626900E+00}, { 0.37300900E+00, -.15599500E+00, 0.21194700E+00, 0.50465700E+00, -.73212200E+00, -.27274700E+00, -.44153500E+01}, { 0.10812400E-01, 0.44016000E+00, -.14636700E+01, 0.19925600E+01, 0.10472100E+00, -.28043900E+00, 0.24939500E+01}, { 0.15059500E+01, 0.14261500E+01, 0.11853300E+01, -.13086300E+01, -.14117700E-01, 0.29939900E+01, -.14698700E+01}, { 0.64837200E+00, 0.30242200E+00, 0.70352600E+00, 0.48006500E+00, 0.53880000E+00, 0.16005400E+01, 0.20495300E+01}, { 0.50323500E+00, -.20325000E+01, 0.36046800E+01, 0.12746400E+01, -.13515400E+01, -.12213000E+01, -.30112900E+01}, { 0.53154600E+00, 0.94525000E+00, 0.99349800E+00, 0.44611100E+00, -.11043500E+01, 0.96980300E+00, 0.14924100E+01}, { 0.60135957-153, 0.15528548E-32, 0.14319957-152, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.11717737E-46, 0.15765128E-51, 0.15823103E-46, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.33132960E-32, 0.60485566-153, 0.36155321E-42, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.29069977E-32, 0.96926847E-71, 0.60135955-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60135784-153, 0.36446096E-85, 0.44386391E-37, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.24201586E-51, 0.13703304E-70, 0.13961250-307, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.24068133E-56, 0.60397935-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.53945512E-61, 0.15071618-152, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60442034-153, 0.60136071-153, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.45633524E-71, 0.11717736E-46, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.18291782E-75, 0.38539917E-56, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.36853839-318}, { 0.11717737E-46, 0.44357265E-37, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.38888178E-32, 0.42733016E-32, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.12026940-152, 0.61210441E-61, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}, { 0.60383142-153, 0.15711000E-75, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00}},
    };
    double torsion_theta_hu [6][25] = {
        { -.65420400E+00, -.21624700E+00, 0.13931600E+00, -.39450600E+00, 0.48205700E+00, 0.10108900E+00, -.29262200E+00, -.14787500E+00, -.21153900E+00, -.29931700E+00, -.24993900E+00, -.21072500E-01, -.79807800E+00, 0.87526300E+00, 0.15242100E-01, -.16879400E+00, -.38937400E+00, -.76993900E+00, 0.46233300E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.36158600E-01, 0.43362700E-01, -.72324100E+00, 0.38161600E-01, 0.52916400E+00, 0.14948800E+00, -.37224200E-01, -.89502000E-01, 0.32891200E-01, 0.50138200E+00, -.79111500E+00, -.94271300E+00, -.51748700E+00, -.50499100E+00, -.68510200E+00, -.85002700E+00, 0.61360700E+00, 0.33632300E-01, 0.27619000E-01, 0.60751400E+00, 0.46259000E+00, 0.29106400E-01, -.64053100E+00, -.36021800E-01, 0.28347800E-01 },
        { -.38936700E+00, 0.66859200E-01, -.89195700E+00, 0.55304300E+00, 0.26999400E+00, -.82209700E+00, 0.11212500E+00, 0.70805500E-01, -.48147500E+00, -.42633600E-01, -.14858300E-01, 0.70019500E-01, 0.16674700E+00, -.62798500E+00, 0.12872000E+00, 0.46829000E+00, 0.48696700E+00, -.27522800E-01, 0.55513200E+00, 0.54173100E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.50905000E+00, 0.46508200E+00, 0.76914900E+00, 0.60423100E-01, 0.37942100E-01, -.13004300E+00, 0.52801500E+00, 0.12495400E+00, -.67968300E+00, -.40846100E+00, 0.39420800E-01, 0.20610000E+00, 0.75590400E-01, -.14357900E+00, 0.11321900E+01, -.12692000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.49086400E+00, 0.17328200E+00, -.12934100E+00, -.71139300E-01, 0.41396600E+00, 0.75716400E+00, 0.34768600E+00, -.61473100E+00, -.31490400E+00, -.27444500E+00, -.15558400E+00, -.69909600E-01, 0.26934200E+00, -.11374900E-01, 0.12710800E+00, 0.15702400E+00, 0.68755300E+00, 0.11463400E+01, -.44906600E-01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.43553100E+00, -.32427300E-01, 0.48666100E+00, 0.11062800E+01, -.11471800E+01, -.52095400E+00, 0.29226400E+00, 0.13444300E+00, 0.58359400E+00, 0.65613000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
    };
    double torsion_weights_models [6][25] = {
        { -.32209200E+01, 0.18408200E+01, -.14865600E+01, -.38862500E+01, 0.34977900E+01, -.43896900E+01, -.37610600E+01, 0.15896100E+01, 0.33588900E+01, 0.21680800E+01, 0.61332400E+01, 0.18415300E+01, 0.32654200E+01, 0.49403900E+01, -.40076200E+01, 0.15977200E+01, 0.50192000E+01, 0.23320600E+01, 0.17937100E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { 0.54524900E+00, 0.49416900E+01, -.40242800E+01, 0.68060700E+00, -.39408300E+01, 0.22216200E+01, -.82237400E+00, -.19451700E+01, 0.57077200E+00, -.53612600E+01, 0.39197500E+01, 0.61131300E+01, -.46156200E+01, 0.49246600E+01, -.44934700E+01, -.60838700E+01, 0.60681800E+01, 0.31988500E+00, 0.31928600E+00, 0.46414800E+01, -.21564500E+01, 0.14124800E+01, 0.78704300E+01, -.60526200E+00, 0.12247200E+01 },
        { 0.56137000E+01, 0.30158100E+00, -.31113200E+01, -.50113700E+01, 0.42839100E+01, 0.38566600E+01, 0.41335200E+01, 0.67237900E+00, 0.28429500E+01, -.91509500E+00, 0.72302000E-01, 0.26717400E+00, 0.42257300E+01, -.49934300E+01, 0.28339900E+01, -.37825300E+01, 0.32567000E+01, 0.94409700E+00, 0.27653200E+01, -.39760700E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.34527100E+01, -.57374100E+01, 0.53028500E+01, 0.27404600E+01, -.14528500E+01, 0.47895900E+01, 0.37838300E+01, -.52632200E+01, -.36860000E+01, 0.29175700E+01, -.26330200E+01, 0.16764700E+01, 0.81198700E+00, 0.47509200E+01, -.34872500E+01, -.45837600E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.78231200E+01, 0.45155300E+01, 0.33761400E+01, -.24951700E+01, -.57608800E+01, 0.59195900E+01, -.41700500E+01, -.64223500E+01, 0.48839900E+01, 0.58822300E+01, 0.23212500E+01, 0.18902500E+01, -.50674200E+01, 0.60355300E+01, 0.29382500E+01, -.52923800E+01, 0.39147700E+01, -.55405200E+01, -.44053800E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
        { -.57698000E+01, 0.44567200E+01, 0.44264200E+01, 0.48494700E+01, 0.25316500E+01, 0.44950000E+01, 0.35631100E+01, -.26348400E+01, -.36299200E+01, 0.35544400E+01, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00, 0.00000000E+00 },
    };
    double torsion_theta_models[6] = {-.58118500E+00, 0.52476400E+00, 0.72279500E+00, 0.10985200E+01, -.21660100E+01, 0.24840600E+00 };
    double torsion_minimum_inputs[7] = { 0.33000000E+02, 0.14000000E+03, 0.47300000E+03, 0.10000000E+02, 0.50000000E+01, 0.15000000E+02, 0.32000000E+03 };
    double torsion_maximum_inputs[7] = { 0.50000000E+02, 0.70000000E+03, 0.17560000E+04, 0.40000000E+02, 0.74000000E+02, 0.31100000E+03, 0.16360000E+04 };
    double torsion_minimum_output = 0.40170000E+01 ;
    double torsion_maximum_output = 0.79713000E+01 ;

    update_message.sprintf("Normalising inputs...");
    ui->message_label->setText(update_message);

    // normalise the custom data
    uniaxial_normal_input[0] = (temperature - uniaxial_minimum_inputs[0])/(uniaxial_maximum_inputs[0]-uniaxial_minimum_inputs[0]) - 0.5;
    uniaxial_normal_input[1] = (frequency - uniaxial_minimum_inputs[1])/(uniaxial_maximum_inputs[1]-uniaxial_minimum_inputs[1]) - 0.5;
    uniaxial_normal_input[2] = (stressconc - uniaxial_minimum_inputs[2])/(uniaxial_maximum_inputs[2]-uniaxial_minimum_inputs[2]) - 0.5;
    uniaxial_normal_input[3] = (stress - uniaxial_minimum_inputs[3])/(uniaxial_maximum_inputs[3]-uniaxial_minimum_inputs[3]) - 0.5;
    uniaxial_normal_input[4] = (uts - uniaxial_minimum_inputs[4])/(uniaxial_maximum_inputs[4]-uniaxial_minimum_inputs[4]) - 0.5;
    uniaxial_normal_input[5] = (elongation - uniaxial_minimum_inputs[5])/(uniaxial_maximum_inputs[5]-uniaxial_minimum_inputs[5]) - 0.5;
    uniaxial_normal_input[6] = (reduction - uniaxial_minimum_inputs[6])/(uniaxial_maximum_inputs[6]-uniaxial_minimum_inputs[6]) - 0.5;
    uniaxial_normal_input[7] = (toughness - uniaxial_minimum_inputs[7])/(uniaxial_maximum_inputs[7]-uniaxial_minimum_inputs[7]) - 0.5;
    uniaxial_normal_input[8] = (yield - uniaxial_minimum_inputs[8])/(uniaxial_maximum_inputs[8]-uniaxial_minimum_inputs[8]) - 0.5;
    uniaxial_normal_input[9] = (r_eff - uniaxial_minimum_inputs[9])/(uniaxial_maximum_inputs[9]-uniaxial_minimum_inputs[9]) - 0.5;
    update_message.sprintf("Finished normalising 'Uniaxial'.");
    ui->message_label->setText(update_message);

    bending_normal_input[0] = (frequency - bending_minimum_inputs[0])/(bending_maximum_inputs[0]-bending_minimum_inputs[0]) - 0.5;
    bending_normal_input[1] = (stressconc - bending_minimum_inputs[1])/(bending_maximum_inputs[1]-bending_minimum_inputs[1]) - 0.5;
    bending_normal_input[2] = (stress - bending_minimum_inputs[2])/(bending_maximum_inputs[2]-bending_minimum_inputs[2]) - 0.5;
    bending_normal_input[3] = (uts - bending_minimum_inputs[3])/(bending_maximum_inputs[3]-bending_minimum_inputs[3]) - 0.5;
    bending_normal_input[4] = (elongation - bending_minimum_inputs[4])/(bending_maximum_inputs[4]-bending_minimum_inputs[4]) - 0.5;
    bending_normal_input[5] = (reduction - bending_minimum_inputs[5])/(bending_maximum_inputs[5]-bending_minimum_inputs[5]) - 0.5;
    bending_normal_input[6] = (toughness - bending_minimum_inputs[6])/(bending_maximum_inputs[6]-bending_minimum_inputs[6]) - 0.5;
    bending_normal_input[7] = (yield - bending_minimum_inputs[7])/(bending_maximum_inputs[7]-bending_minimum_inputs[7]) - 0.5;
    update_message.sprintf("Finished normalising 'Bending'.");
    ui->message_label->setText(update_message);

    torsion_normal_input[0] = (frequency - torsion_minimum_inputs[0])/(torsion_maximum_inputs[0]-torsion_minimum_inputs[0]) - 0.5;
    torsion_normal_input[1] = (stress - torsion_minimum_inputs[1])/(torsion_maximum_inputs[1]-torsion_minimum_inputs[1]) - 0.5;
    torsion_normal_input[2] = (uts - torsion_minimum_inputs[2])/(torsion_maximum_inputs[2]-torsion_minimum_inputs[2]) - 0.5;
    torsion_normal_input[3] = (elongation - torsion_minimum_inputs[3])/(torsion_maximum_inputs[3]-torsion_minimum_inputs[3]) - 0.5;
    torsion_normal_input[4] = (reduction - torsion_minimum_inputs[4])/(torsion_maximum_inputs[4]-torsion_minimum_inputs[4]) - 0.5;
    torsion_normal_input[5] = (toughness - torsion_minimum_inputs[5])/(torsion_maximum_inputs[5]-torsion_minimum_inputs[5]) - 0.5;
    torsion_normal_input[6] = (yield - torsion_minimum_inputs[6])/(torsion_maximum_inputs[6]-bending_minimum_inputs[6]) - 0.5;
    update_message.sprintf("Finished normalising 'Torsion'.");
    ui->message_label->setText(update_message);

    // find the value of each hidden unit
    double uniaxial_hu[9][25];
    double bending_hu[5][25];
    double torsion_hu[6][25];
    double this_positive_exponential;
    double this_negative_exponential;
    double this_cosh;
    double this_sinh;
    double this_tanh;
    double uniaxial_normalised_predictions[9];
    double bending_normalised_predictions[9];
    double torsion_normalised_predictions[9];
    double uniaxial_overall_prediction = 0.0;
    double bending_overall_prediction = 0.0;
    double torsion_overall_prediction = 0.0;
    double uniaxial_unnorm_prediction;
    double bending_unnorm_prediction;
    double torsion_unnorm_prediction;
    double uniaxial_predicted_life;
    double bending_predicted_life;
    double torsion_predicted_life;
    int max_hu = 25;

    update_message.sprintf("Starting HUs");
    ui->message_label->setText(update_message);

    // do uniaxial models first - go through each model in the committee:
    for(i=0;i<uniaxial_no_in_cttee;i++)
    {
        uniaxial_normalised_predictions[i] = 0.0;
        update_message.sprintf("Starting model %d",i+1);
        ui->message_label->setText(update_message);
        // go through each hidden unit in the model:
        for(j=0;j<max_hu;j++)
        {
            // set the value of the hidden unit to zero:
            uniaxial_hu[i][j] = 0.0;
            // for each input, multiply thr normalised input for the uniaxail network by the weight for the ith model, jth hidden unit and kth input and add to the previous value for the hidden unit:
            for(k=0;k<uniaxial_no_inputs;k++)
            {
                uniaxial_hu[i][j] = uniaxial_hu[i][j] + uniaxial_weights_hu[i][j][k] * uniaxial_normal_input[k];
                update_message.sprintf("Finished uniaxial model %d, HU %d, input %d",i+1,j+1,k+1);
                ui->message_label->setText(update_message);
            }
            // after considering all inputs, add the offset for the ith model and jth hidden unit to get the final value.
            uniaxial_hu[i][j] = uniaxial_hu[i][j] + uniaxial_theta_hu[i][j];
            // find e^ +/- the hidden unit for prediction purposes:
            this_positive_exponential = exp(uniaxial_hu[i][j]);
            this_negative_exponential = exp(-uniaxial_hu[i][j]);
            // calculate sinh, cosh and tanh for those exponentials
            this_cosh = 0.5*(this_positive_exponential+this_negative_exponential);
            this_sinh = 0.5*(this_positive_exponential-this_negative_exponential);
            this_tanh = this_sinh / this_cosh;
            // calculate the normalised prediction for the ith model, accounting for each hidden unit in turn.
            uniaxial_normalised_predictions[i] = uniaxial_normalised_predictions[i] + this_tanh * uniaxial_weights_models[i][j];
        }
    // add the contribution from each hidden unit to the model and then add the theta offset.
        uniaxial_normalised_predictions[i] = uniaxial_normalised_predictions[i] + uniaxial_theta_models[i];
    // add the ith prediction to the overall prediction (average of all i models of the committee).
        uniaxial_overall_prediction = uniaxial_overall_prediction + uniaxial_normalised_predictions[i];
    }
    // divide the variable uniaxial_overall_prediction by the number of models in the committee to convert its current value (i.e. the sum of all i predictions from the committee) to a mean prediction.
    uniaxial_overall_prediction = uniaxial_overall_prediction / uniaxial_no_in_cttee;
    // unnormalise the overall prediction
    uniaxial_unnorm_prediction = ( (0.5 + uniaxial_overall_prediction) ) * (uniaxial_maximum_output - uniaxial_minimum_output) + uniaxial_minimum_output;
    // convert the prediction (decadic logarithm of number of cycles) to the expected fatigue life.
    uniaxial_predicted_life = pow(10.0,uniaxial_unnorm_prediction);
    // tell the user the network prediction has been made.
    update_message.sprintf("Finished uniaxial model %d, HU %d",i,j);
    ui->message_label->setText(update_message);

    // do bending models next - go through each model in the committee:
    for(i=0;i<bending_no_in_cttee;i++)
    {
        bending_normalised_predictions[i] = 0.0;
        update_message.sprintf("Starting model %d",i+1);
        ui->message_label->setText(update_message);
        // go through each hidden unit in the model:
        for(j=0;j<max_hu;j++)
        {
            // set the value of the hidden unit to zero:
            bending_hu[i][j] = 0.0;
            // for each input, multiply thr normalised input for the uniaxail network by the weight for the ith model, jth hidden unit and kth input and add to the previous value for the hidden unit:
            for(k=0;k<bending_no_inputs;k++)
            {
                bending_hu[i][j] = bending_hu[i][j] + bending_weights_hu[i][j][k] * bending_normal_input[k];
                update_message.sprintf("Finished bending model %d, HU %d, input %d",i+1,j+1,k+1);
                ui->message_label->setText(update_message);
            }
            // after considering all inputs, add the offset for the ith model and jth hidden unit to get the final value.
            bending_hu[i][j] = bending_hu[i][j] + bending_theta_hu[i][j];
            // find e^ +/- the hidden unit for prediction purposes:
            this_positive_exponential = exp(bending_hu[i][j]);
            this_negative_exponential = exp(-bending_hu[i][j]);
            // calculate sinh, cosh and tanh for those exponentials
            this_cosh = 0.5*(this_positive_exponential+this_negative_exponential);
            this_sinh = 0.5*(this_positive_exponential-this_negative_exponential);
            this_tanh = this_sinh / this_cosh;
            // calculate the normalised prediction for the ith model, accounting for each hidden unit in turn.
            bending_normalised_predictions[i] = bending_normalised_predictions[i] + this_tanh * bending_weights_models[i][j];
        }
        // add the contribution from each hidden unit to the model and then add the theta offset.
        bending_normalised_predictions[i] = bending_normalised_predictions[i] + bending_theta_models[i];
        // add the ith prediction to the overall prediction (average of all i models of the committee).
        bending_overall_prediction = bending_overall_prediction + bending_normalised_predictions[i];
    }
    // divide the variable bending_overall_prediction by the number of models in the committee to convert its current value (i.e. the sum of all i predictions from the committee) to a mean prediction.
    bending_overall_prediction = bending_overall_prediction / bending_no_in_cttee;
    // unnormalise the overall prediction
    bending_unnorm_prediction = ( (0.5 + bending_overall_prediction) ) * (bending_maximum_output - bending_minimum_output) + bending_minimum_output;
    // convert the prediction (decadic logarithm of number of cycles) to the expected fatigue life.     bending_predicted_life = pow(10.0,bending_unnorm_prediction);
    bending_predicted_life = pow(10.0,bending_unnorm_prediction);
    // tell the user the network prediction has been made.
    update_message.sprintf("Finished bending model %d, HU %d",i,j);
    ui->message_label->setText(update_message);

    // finally do torsion models - go through each model in the committee:
    for(i=0;i<torsion_no_in_cttee;i++)
    {
        torsion_normalised_predictions[i] = 0.0;
        update_message.sprintf("Starting model %d",i+1);
        ui->message_label->setText(update_message);
        // go through each hidden unit in the model:
        for(j=0;j<max_hu;j++)
        {
            // set the value of the hidden unit to zero:
            torsion_hu[i][j] = 0.0;
            // for each input, multiply thr normalised input for the uniaxail network by the weight for the ith model, jth hidden unit and kth input and add to the previous value for the hidden unit:
            for(k=0;k<torsion_no_inputs;k++)
            {
                torsion_hu[i][j] = torsion_hu[i][j] + torsion_weights_hu[i][j][k] * torsion_normal_input[k];
                update_message.sprintf("Finished torsion model %d, HU %d, input %d",i+1,j+1,k+1);
                ui->message_label->setText(update_message);
            }
            // after considering all inputs, add the offset for the ith model and jth hidden unit to get the final value.
            torsion_hu[i][j] = torsion_hu[i][j] + torsion_theta_hu[i][j];
            // find e^ +/- the hidden unit for prediction purposes:
            this_positive_exponential = exp(torsion_hu[i][j]);
            this_negative_exponential = exp(-torsion_hu[i][j]);
            // calculate sinh, cosh and tanh for those exponentials
            this_cosh = 0.5*(this_positive_exponential+this_negative_exponential);
            this_sinh = 0.5*(this_positive_exponential-this_negative_exponential);
            this_tanh = this_sinh / this_cosh;
            // calcualte the normalised prediction for the ith model, accounting for each hidden unit in turn.
            torsion_normalised_predictions[i] = torsion_normalised_predictions[i] + this_tanh * torsion_weights_models[i][j];
        }
        // add the contribution from each hidden unit to the model and then add the theta offset.
        torsion_normalised_predictions[i] = torsion_normalised_predictions[i] + torsion_theta_models[i];
        // add the ith prediction to the overall prediction (average of all i models of the committee).
        torsion_overall_prediction = torsion_overall_prediction + torsion_normalised_predictions[i];
    }
    // divide the variable torsion_overall_prediction by the number of models in the committee to convert its current value (i.e. the sum of all i predictions from the committee) to a mean prediction.
    torsion_overall_prediction = torsion_overall_prediction / torsion_no_in_cttee;
    // unnormalise the overall prediction
    torsion_unnorm_prediction = ( (0.5 + torsion_overall_prediction) ) * (torsion_maximum_output - torsion_minimum_output) + torsion_minimum_output;
    // convert the prediction (decadic logarithm of number of cycles) to the expected fatigue life.     torsion_predicted_life = pow(10.0,torsion_unnorm_prediction);
    torsion_predicted_life = pow(10.0,torsion_unnorm_prediction);
    // tell the user the network prediction has been made.
    update_message.sprintf("Finished torsion model %d, HU %d",i,j);
    ui->message_label->setText(update_message);


    // Write the answers to the QString variables for display:
    predictBending.sprintf("%8.2E",bending_predicted_life);
    predictUniaxial.sprintf("%8.2E",uniaxial_predicted_life);
    predictTorsional.sprintf("%8.2E",torsion_predicted_life);
    uncertaintyBending.sprintf("%8.2E",bendingUncertainty);
    uncertaintyUniaxial.sprintf("%8.2E",uniaxialUncertainty);
    uncertaintyTorsional.sprintf("%8.2E",torsionalUncertainty);

    // Display the predictions and uncertainties:
    ui->predictBending->setText(predictBending);
    ui->predictUniaxial->setText(predictUniaxial);
    ui->predictTorsional->setText(predictTorsional);
    /*ui->uncertaintyBending->setText(uncertaintyBending);
    ui->uncertaintyUniaxial->setText(uncertaintyUniaxial);
    ui->uncertaintyTorsional->setText(uncertaintyTorsional);*/
    ui->uncertaintyBending->setText("X.XXE+XX");
    ui->uncertaintyUniaxial->setText("Y.YYE+YY");
    ui->uncertaintyTorsional->setText("Z.ZZE+ZZ");

    update_message.sprintf("Predictions complete.");
    ui->message_label->setText(update_message);

    QCheckBox uncertainties_checkbox;
    if(ui->uncertainties_checkbox->isChecked()==true)
    {
        /*
           Now calculate the uncertainties in each prediction.
           Whereas the predictions written in the main loop, the uncertainties are too complex for this to be practicable and rely on many
           source data.  Thus, functions are used instead.

           Begin with the uniaxial model:
        */


        /*
           each sensitivity depends on all inputs: one offset for the whole model, one offset for each hidden unit, one weight for each
           hidden unit and one for each input for each hidden unit.  The total number of dependencies is therefore
           1 + no_hu + no_hu + no_input*no_hu = 1+(no_input+2)*no_hu
           there is one sensitivity for each dependence for each model:
        */

        // Make an array containing the sensitivities of the uniaxial predictions to the inputs.
        double uniaxial_sensitivity[9][301];// 1+max_hu*(uniaxial_no_inputs+2) = 301
        // Initialise the uniaxial_sensitivity array so that all elements are zero.
        for(i=0;i<uniaxial_no_in_cttee;i++)
        {
            for(j=0;j<(1+max_hu*(uniaxial_no_inputs+2));j++)
            {
                uniaxial_sensitivity[i][j] = 0.0;
            };
        };
    //----------------------------------------------------------------------------------------------------------------------------------//
    // i, j, k are dummy variables, 'no_required' is the number of calcualtions required to fully define the sensitivity,
    // 'this_factor' is avariable used when determining what element to write to.
        int no_required,this_factor;
    // 'this_sum' is the summed sensitivity that is being calculated; 'upper exponential' and 'lower exponential' are e raised to + and
    // - he total sensitivities, respecitvely; 'this_cosh' and 'this_sinh' are the hyperbolic cosine and hyperbolic sine, dependent on
    // the 'upper_exponential' and lower_exponential' variables.
        double this_sum,upper_exponential,lower_exponential;//,this_cosh,this_sinh;
    //----------------------------------------------------------------------------------------------------------------------------------//
        for(i=0;i<uniaxial_no_in_cttee;i++)
        {
    // calculate the number of calculations required to fully describe the sensitivity of the model's output to the input.
    // 25 is the maximum number of hidden units in each model and so gives the maximum number of calculations required.
    // When the number of hidden units is less than 25, the excess weights are 0, so result in a contribution of 0.
                no_required = 1 + uniaxial_hidden_units[i] * (uniaxial_no_inputs + 1 );
    // go through each hidden unit in turn:
                for(j=0;j<uniaxial_hidden_units[i];j++)
                {
    // calculate 'this_factor' to determine the element of the array 'sensitivity' to use in calculations
                    this_factor = j * (uniaxial_no_inputs+1);
    // reset the variable 'this_sum' to start each sensitivity measure again.
                    this_sum = 0.0;
    // go through each input varaible:
                    for(k=0;k<uniaxial_no_inputs;k++)
                    {
    // add the contribution of each combination of hidden unit and input to the sensitivity.
                        this_sum = this_sum + uniaxial_weights_hu[i][j][k] * uniaxial_normal_input[k];
                    };
    // add the contribution from the shift for the current hidden unit.
                    this_sum = this_sum + uniaxial_theta_hu[i][j];
    // calculate the hyperbolic sine and cosine functions to use when determining the sensitivity:
                    upper_exponential = exp(this_sum);
                    lower_exponential = exp(-this_sum);
                    this_cosh = 0.5 * (upper_exponential + lower_exponential);
                    this_sinh = 0.5 * (upper_exponential - lower_exponential);
    // calcualte an intermediate answer on the way to arriving at the sensitivity.
                    uniaxial_sensitivity[i][this_factor] = (uniaxial_weights_models[i][j] / (this_cosh*this_cosh));
    // go through each input and copy the values of the sensitivity equal to the differentail of the output.  Since the output is a tanh
    // function (default in bigback, which powers Model Manager), the differential is a cosh^2 function.
                    for(k=0;k<uniaxial_no_inputs;k++)
                    {
                        uniaxial_sensitivity[i][k+1+this_factor] = uniaxial_sensitivity[i][this_factor] * uniaxial_normal_input[k];
                    }
    // Not sure about this as it seems to be calculating the output (tanh(sum of weights*inputs+theta)) and storing it in the final
    // no_hidden_units elements).
                    uniaxial_sensitivity[i][no_required+j] = this_sinh / this_cosh;
                };
                uniaxial_sensitivity[i][no_required-1] = 1.0;
        };
    // 'no_in_cttee'is the number of models in the committee; 'no_inputs' is the number of input variables; 'max_hidden_units' is the
    // maximum number of hidden units in any one model of the committee (the maximum value of any element inthe array 'no_hidden_units');
    // max_lu_parameters if the largest possible number of parameters in the .lu file of any model in the committee.
    //    int uniaxial_max_lu = 1 + max_hu * ( 2 + uniaxial_no_inputs );
    // 'no_hidden_units' is the number of hidden units in each model in the committee.
        int uniaxial_no_lu[9];
        for(i=0;i<uniaxial_no_in_cttee;i++)
        {
            uniaxial_no_lu[i] = 1 + (2+uniaxial_no_inputs) * uniaxial_hidden_units[i];
        };
    // 'indices' is the array containing integers related to the 'lu_parameters', read in the subroutine 'read_lu'.
        int uniaxial_indices[9][301] = {
            {  7, 262, 255, 219,  71, 226,  74, 259, 115,  76,  11, 174, 112, 255, 256,  71, 118, 226, 152, 153, 215, 121, 120, 214, 113, 219, 164, 191,  62, 153, 226, 217, 121, 140, 126, 135, 256,  39,  82, 139,  84, 198, 149, 196, 143, 134, 176,  48, 128, 198, 170,  60, 251,  72, 259,  71, 193, 255, 130,  76, 173, 256, 236,  88, 152, 150, 172, 167, 220,  70, 236, 198, 118, 225, 170, 115, 256,  85, 112, 209,  81, 137, 164, 173, 194, 168, 174, 116, 228, 146, 260, 130, 126, 151, 129, 217, 162, 118, 160, 117, 142, 218, 103, 104, 239, 131, 220, 116, 209, 256, 160, 153, 160, 114, 167, 175, 208, 132, 201, 201, 220, 153, 192, 259, 125, 216, 152, 235, 168, 240, 216, 239, 215, 215, 173, 136, 159, 251, 173, 140, 141, 149, 164, 207, 215, 167, 147, 204, 173, 198, 194, 194, 251, 176, 225, 156, 262, 158, 198, 231, 172, 209, 237, 176, 165, 182, 182, 204, 169, 192, 204, 217, 215, 194, 242, 234, 262, 214, 255, 180, 217, 225, 197, 234, 194, 239, 207, 191, 189, 190, 196, 217, 235, 230, 195, 236, 230, 227, 221, 235, 231, 202, 256, 234, 205, 225, 230, 225, 220, 219, 211, 215, 213, 251, 236, 240, 219, 236, 225, 230, 231, 222, 223, 224, 240, 237, 256, 228, 230, 235, 237, 237, 233, 260, 236, 236, 262, 238, 259, 240, 241, 262, 259, 265, 245, 259, 256, 248, 249, 250, 262, 260, 253, 254, 262, 256, 257, 258, 260, 262, 261, 262, 263, 264, 265,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
            { 58, 223, 181, 236, 227, 184, 234,  48, 241, 233, 110, 102, 149, 109,  73, 237,  82, 234, 151, 152, 176, 178, 104, 149, 146,  26,  79, 182, 150, 241,  62,  85, 115,  76, 107, 179,  37, 179,  75,  95, 176, 227, 178,  77,  83, 203, 149, 236, 186,  75, 176, 131,  95,  95,  95,  73, 234, 176,  66, 187, 131,  86, 230,  64,  84, 236, 118, 150,  69,  70,  91, 138, 177, 144, 108, 186, 179,  87, 123,  80,  81, 154,  88,  84, 116, 106, 144, 236, 159, 154, 148,  92,  93,  95, 150, 205, 151, 206, 184, 227, 101, 151, 103, 223, 150, 203, 143, 214, 172, 214, 115, 126, 146, 114, 181, 139, 117, 182, 132, 204, 178, 230, 154, 164, 125, 192, 241, 128, 203, 139, 241, 149, 164, 134, 135, 136, 138, 227, 161, 162, 141, 185, 179, 145, 179, 172, 147, 162, 152, 216, 189, 162, 153, 189, 225, 156, 187, 158, 161, 216, 173, 205, 163, 187, 184, 194, 167, 189, 169, 170, 175, 184, 223, 174, 178, 214, 196, 205, 179, 180, 227, 185, 208, 208, 230, 192, 233, 204, 234, 190, 191, 195, 193, 214, 198, 214, 230, 220, 234, 200, 201, 202, 209, 230, 209, 236, 207, 227, 241, 230, 211, 216, 213, 227, 223, 216, 217, 219, 220, 230, 224, 241, 234, 224, 237, 230, 227, 228, 229, 233, 237, 234, 234, 236, 235, 236, 241, 238, 239, 240, 241,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
            {276, 157,  27, 287, 249, 251, 208, 156, 206, 204, 203, 273,  28, 159,  71, 281,  60, 277,  19, 162, 142, 176, 201, 142, 165, 181, 277, 281,  29, 238, 253, 153, 215,  40, 169,  65,  71,  74,  84, 153, 281,  84, 106, 244, 162, 135, 205, 238, 172,  65, 108, 263, 194,  61, 214, 258, 209, 174, 181, 138, 183,  95,  77,  77, 170,  82,  86, 137,  82, 181, 218, 172, 148, 253, 247, 160,  88, 185, 281, 174, 218, 253, 160, 261, 140, 218, 160, 165, 215, 151, 138,  92, 115, 247, 159, 209, 259, 173, 225, 261, 128, 212, 103, 174, 134, 184, 172, 259, 109, 269, 183, 151, 227, 114, 128, 238, 208, 176, 148, 208, 154, 127, 151, 273, 125, 126, 241, 253, 223, 130, 159, 182, 204, 248, 181, 136, 141, 142, 139, 245, 239, 179, 143, 217, 281, 171, 147, 151, 150, 175, 208, 231, 244, 182, 260, 281, 181, 158, 239, 172, 253, 264, 192, 175, 207, 249, 167, 287, 184, 209, 181, 197, 273, 192, 212, 212, 206, 178, 230, 180, 216, 273, 253, 245, 220, 259, 204, 225, 189, 247, 191, 251, 259, 207, 263, 219, 197, 269, 287, 200, 216, 202, 218, 267, 219, 261, 287, 258, 258, 269, 211, 214, 213, 216, 267, 251, 234, 258, 256, 239, 251, 245, 277, 231, 249, 244, 277, 263, 273, 244, 263, 287, 261, 246, 235, 240, 269, 263, 246, 246, 269, 242, 248, 245, 261, 263, 258, 259, 273, 250, 259, 252, 267, 263, 255, 264, 257, 281, 260, 263, 281, 273, 273, 281, 267, 266, 282, 268, 276, 270, 271, 272, 273, 274, 287, 277, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
            {267, 171, 170, 228, 227, 167,  51, 296,  74, 263,  66, 286, 168,  32, 247,  71, 263, 224,  51, 193, 248, 116, 223, 127, 251, 225, 173, 121,  30, 229, 271, 145, 229, 216, 176, 146, 225,  61, 154, 113, 249, 150, 175,  94, 139, 271, 118,  48, 250, 277, 126, 113, 152, 120, 148,  62,  72, 151, 147,  60,  74, 129, 245, 245, 212, 151, 244, 138, 215,  70, 227, 167,  77, 132, 161, 245, 147, 296,  79, 229,  81, 255, 259, 231, 124, 171, 252, 149, 172, 198, 147, 228, 230, 115, 263, 194, 112, 109, 121, 271, 117, 204, 225, 258, 195, 152, 251, 263, 250, 152, 174, 290, 170, 114, 152, 214, 121, 231, 250, 264, 159, 142, 167, 197, 125, 205, 250, 128, 159, 151, 272, 192, 247, 147, 253, 136, 272, 215, 263, 230, 167, 153, 209, 170, 192, 146, 267, 258, 154, 194, 196, 190, 226, 264, 224, 194, 260, 228, 201, 290, 258, 197, 163, 194, 256, 269, 267, 190, 169, 196, 230, 203, 176, 212, 260, 274, 269, 178, 183, 180, 196, 274, 272, 198, 249, 251, 251, 212, 189, 275, 191, 258, 215, 194, 245, 229, 264, 206, 231, 200, 267, 202, 255, 284, 264, 251, 218, 208, 231, 229, 211, 299, 213, 252, 219, 296, 217, 218, 263, 284, 274, 222, 259, 228, 230, 230, 264, 231, 267, 250, 267, 232, 233, 234, 235, 236, 237, 238, 239, 284, 241, 242, 260, 275, 290, 246, 255, 264, 286, 258, 260, 264, 264, 284, 256, 258, 257, 259, 270, 274, 261, 273, 299, 284, 286, 266, 274, 268, 272, 277, 275, 284, 290, 290, 284, 289, 286, 299, 279, 296, 286, 284, 283, 284, 285, 286, 287, 301, 290, 296, 291, 292, 293, 296, 295, 296, 297, 298, 299, 301, 301 },
            { 74, 279, 285, 234, 300,  61, 106,  60,  57, 299,  66,  31, 175,  58, 192, 238, 236, 277,  73, 228, 297,  77, 190,  63, 135, 180,  29, 292,  71, 191, 216, 137, 181,  76,  63, 168, 192, 139, 101, 228, 227, 140, 275, 231, 271,  69, 190,  48, 296, 198, 277, 159, 185,  72, 195,  65, 101, 207,  59, 170, 134, 108, 269, 157, 157, 292, 277, 285,  75,  70, 175, 239, 183, 240, 117, 142, 143,  95, 196, 113, 234, 117, 183, 285,  85, 129,  87, 121, 182, 196, 115,  92, 300, 279, 148, 109, 191, 205, 292, 107, 196, 146, 103, 208, 110, 241, 163, 151, 190, 205, 223, 112, 241, 114, 119, 151, 250, 130, 194, 242, 150, 234, 156, 146, 192, 296, 127, 161, 196, 130, 131, 187, 228, 297, 241, 136, 300, 159, 220, 249, 162, 181, 236, 214, 145, 208, 147, 242, 156, 161, 237, 184, 157, 157, 267, 197, 194, 158, 159, 190, 194, 207, 221, 218, 237, 207, 167, 226, 169, 285, 187, 269, 180, 241, 269, 176, 227, 178, 179, 192, 220, 296, 275, 241, 253, 186, 194, 250, 189, 192, 299, 231, 208, 236, 225, 225, 300, 226, 253, 200, 201, 202, 238, 208, 226, 206, 212, 273, 256, 250, 211, 249, 213, 218, 239, 277, 260, 263, 292, 260, 235, 222, 277, 224, 252, 262, 274, 274, 229, 230, 237, 241, 233, 265, 241, 238, 249, 256, 284, 279, 249, 299, 292, 244, 296, 246, 296, 249, 300, 263, 267, 262, 296, 284, 255, 279, 257, 273, 273, 274, 262, 262, 270, 264, 265, 266, 292, 268, 296, 271, 277, 285, 285, 296, 296, 284, 297, 285, 285, 280, 281, 299, 292, 297, 290, 296, 287, 296, 289, 292, 297, 292, 296, 294, 295, 299, 297, 298, 300, 300, 301 },
            { 82, 123, 124, 126, 127,  10,  85, 260, 207, 138, 132, 197, 112, 256, 291,  96, 127, 129,  19, 106, 127,  88, 283, 118, 135, 234, 136, 290, 238, 192, 227, 299,  99, 141, 204,  80,  37,  87, 143, 195,  95, 119, 273, 252, 131, 108, 245, 291,  49,  92, 139, 205, 240,  54, 150, 172, 101, 200, 164, 291, 237, 130,  85, 190, 298, 121, 193,  68, 249,  70, 124, 107, 198, 168, 287, 140,  77, 203, 137, 113,  81,  96, 127, 201, 183, 198, 137, 110, 216, 297, 249, 126, 115, 189, 146, 258, 105, 189, 209, 184, 297, 198, 230, 146, 176, 119, 230, 117, 267, 117, 286, 204, 196, 114, 129, 138, 231, 140, 225, 120, 196, 196, 123, 163, 125, 137, 132, 250, 205, 206, 208, 259, 260, 134, 287, 195, 245, 183, 259, 274, 171, 250, 150, 238, 145, 198, 147, 250, 204, 271, 203, 153, 215, 154, 264, 156, 157, 234, 206, 215, 161, 239, 234, 215, 165, 239, 260, 170, 169, 256, 207, 183, 176, 273, 175, 176, 223, 297, 273, 201, 250, 230, 190, 203, 185, 214, 252, 218, 260, 200, 191, 201, 248, 194, 253, 273, 256, 198, 259, 297, 251, 202, 253, 214, 273, 231, 274, 250, 273, 256, 211, 212, 213, 225, 252, 217, 245, 240, 220, 250, 252, 222, 250, 224, 259, 236, 248, 228, 286, 287, 261, 286, 233, 241, 235, 291, 271, 239, 268, 275, 268, 242, 261, 244, 262, 246, 258, 258, 260, 258, 251, 267, 299, 256, 255, 275, 257, 274, 272, 287, 273, 290, 263, 275, 268, 266, 287, 298, 269, 273, 286, 286, 299, 299, 299, 295, 277, 287, 279, 298, 281, 291, 293, 298, 287, 301, 298, 300, 289, 301, 299, 292, 295, 294, 295, 296, 299, 299, 301, 300, 301 },
            {289, 182, 128, 268, 266, 222, 228, 225, 215, 174, 187,  21,  16, 270, 280, 214, 281, 192,  51, 186, 281, 132, 186,  83,  69, 169, 115, 132, 161, 279,  75, 150,  38, 205,  52, 181, 280, 226,  98,  43, 192, 115, 258, 220,  53, 218, 130,  48,  49,  72, 184, 219, 165,  65, 231, 206, 217, 120,  59, 184, 242, 270, 123, 216, 194, 231, 253,  98, 170, 280, 172, 172, 204,  74, 163,  76, 158, 197,  98, 190,  81, 236, 139, 204, 249, 126, 198, 121, 176, 238, 263,  92, 109, 113,  95, 161, 260, 118,  99, 258, 214, 223, 103, 287, 132, 158, 130, 172, 109, 207, 236, 152, 162, 114, 170, 218, 218, 241, 218, 249, 192, 198, 230, 218, 125, 287, 151, 211, 142, 230, 193, 280, 261, 184, 228, 136, 204, 212, 179, 207, 162, 192, 219, 220, 190, 260, 147, 190, 229, 216, 241, 192, 192, 219, 247, 253, 164, 169, 163, 216, 281, 222, 185, 279, 193, 201, 270, 183, 268, 264, 222, 190, 203, 192, 279, 190, 236, 178, 252, 180, 212, 203, 287, 252, 253, 204, 242, 268, 189, 251, 191, 268, 239, 218, 214, 242, 241, 242, 266, 214, 214, 202, 219, 264, 229, 279, 266, 249, 209, 228, 270, 227, 213, 222, 252, 217, 230, 228, 222, 231, 260, 222, 242, 224, 238, 226, 249, 256, 261, 256, 266, 280, 281, 234, 235, 241, 252, 279, 240, 261, 241, 249, 256, 244, 260, 246, 261, 259, 264, 252, 262, 268, 279, 261, 281, 280, 257, 259, 259, 281, 268, 288, 288, 288, 289, 268, 280, 273, 281, 288, 271, 279, 280, 274, 287, 278, 277, 278, 280, 280, 287, 282, 283, 284, 285, 288, 287, 288, 289,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
            { 30, 294, 168, 298, 281, 181, 296,  27, 216, 284, 154, 166,  60, 170, 175,  16, 225, 227, 117,  65, 186,  33, 178, 179, 280, 175, 104,  63, 117, 271, 196, 297, 269, 184, 196, 240, 180, 229, 225, 289,  44,  42, 159,  49,  51, 112,  58,  48, 180, 187, 186, 183, 118, 116, 173, 162, 128, 267,  59, 118, 284, 296, 296, 203, 204,  66, 197,  97, 173,  70, 204, 163, 172, 167, 225, 150, 121, 228, 231, 164,  81, 165, 296, 298, 260, 130, 286, 161, 171, 115, 284, 175, 183,  94, 194, 289, 223, 216, 286, 220, 128, 269, 104, 185, 108, 203, 262, 203, 214, 269, 119, 266, 113, 114, 187, 281, 287, 192, 209, 241, 176, 215, 145, 192, 125, 280, 286, 280, 274, 130, 172, 230, 270, 134, 196, 136, 297, 170, 212, 212, 214, 227, 143, 161, 266, 149, 147, 240, 256, 195, 151, 154, 196, 179, 284, 266, 174, 158, 272, 258, 185, 183, 298, 230, 205, 223, 262, 241, 169, 178, 234, 181, 231, 266, 258, 214, 233, 225, 289, 204, 290, 194, 287, 262, 218, 269, 280, 238, 223, 241, 191, 260, 201, 206, 206, 270, 229, 214, 214, 200, 240, 202, 266, 233, 206, 227, 219, 208, 267, 249, 219, 231, 213, 287, 275, 281, 230, 262, 294, 269, 231, 222, 231, 224, 280, 294, 284, 238, 258, 294, 273, 240, 290, 289, 235, 262, 298, 298, 239, 256, 242, 270, 271, 244, 250, 246, 247, 250, 266, 251, 271, 289, 253, 264, 255, 280, 257, 287, 273, 273, 266, 297, 263, 298, 289, 267, 298, 268, 272, 284, 294, 298, 289, 286, 287, 289, 277, 287, 290, 296, 298, 286, 295, 290, 298, 298, 287, 288, 291, 297, 291, 292, 295, 297, 298, 298, 297, 298, 299, 300, 301 },
            {270, 204, 258, 263, 249, 259, 145, 257, 118, 154, 148, 203, 106, 260,  27, 190,  62,  83, 206, 272, 241, 153, 236, 105, 201, 214, 181,  83, 183,  87, 147,  33, 137,  83,  46, 216, 181,  54, 152, 253, 139, 183, 104, 245,  85, 149, 151, 103, 146,  51, 108, 230, 198, 173, 110, 140, 242, 107, 214, 239,  65, 102, 105, 198,  82,  76, 251, 138, 152,  70, 173, 110, 259, 174, 117, 214, 257,  87, 126, 234,  81, 146, 247, 237, 214, 238, 110, 135, 233, 211, 252, 263, 101, 150, 142, 227, 253, 274, 239, 240, 128, 189, 103, 143, 173, 161, 127, 115, 225, 230, 137, 242, 132, 114, 147, 145, 184, 173, 230, 241, 170, 250, 197, 225, 125, 182, 223, 264, 151, 200, 274, 234, 220, 134, 237, 136, 147, 151, 151, 239, 234, 165, 223, 198, 205, 205, 181, 172, 189, 162, 242, 225, 190, 170, 196, 189, 275, 158, 208, 231, 201, 227, 192, 185, 194, 189, 201, 168, 169, 272, 173, 186, 223, 197, 194, 250, 212, 178, 179, 180, 240, 259, 264, 198, 208, 208, 209, 204, 201, 225, 191, 249, 230, 274, 195, 215, 197, 204, 250, 234, 264, 202, 205, 275, 207, 228, 230, 258, 275, 242, 211, 263, 213, 217, 241, 218, 252, 246, 219, 272, 272, 222, 223, 224, 258, 238, 275, 274, 229, 260, 258, 250, 259, 236, 235, 238, 272, 250, 263, 249, 253, 272, 249, 244, 274, 272, 252, 257, 249, 258, 257, 257, 257, 259, 257, 274, 270, 272, 270, 263, 261, 262, 274, 274, 265, 270, 267, 268, 272, 272, 271, 272, 273, 274, 275, 276, 277,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 }
        };

    // the array 'uncertainties' will contain the sassessed uncertainties in the predictions, dependent on the 'sensitivity' array,
    // which is inturn dependent on the user-specified inputs and the lower/upper decomposition of the Hessian matrix for each model.
        double uniaxial_uncertainties[9];
    // 'these_bending_sensitivities' is a copy of the row of the array 'sensitivity' that is associated with the model that is being considered
    // used to both ensure 'sensitivity' is not altered by this subroutine and to simplify the passing of values to the subroutine
    // 'backsub'.
        double these_sensitivities[301];

// lu_parameters, determined in the subroutine are declared outside the loop for memory allocation reasons.

// 'these_indices' contains the 'indices' for the model currently being operated on.
     int these_indices[301];
 // copy the lu_parameters for each model in turn to a two-dimension array - this simplifies the use of the 'backsub' subroutine.
     double these_lu_parameters[301][301];
     for(j=0;j<301;j++)
     {
         these_indices[j] = -164;
         for(k=0;k<301;k++)
         {
             these_lu_parameters[j][k] = -4536334.2432432;
         };
     };
     for(i=0;i<uniaxial_no_in_cttee;i++)
     {
     // determine the number of calculations required to calculate the uncertainty in the prediction of each model.  Equal to the number
     // of weights (no. inputs * no. hidden units + no. hidden units) + the number of offsets (no_hidden_units + 1).  This is equal to
     // each dimension of the array containing the 'lu_parameters' (i.e, equal to 'no_lu_paramters' in the 'read_lu' subroutine).
     // copy the 'lu_parameters' for the current (i7th) model to a two-dimension array 'these_lu_parameters'.  This simplifies the use of
     // the 'backsub' subroutine.  Similarly, reduce the dimensionality of 'indices' from two to one.  Finally, make a copy of the
     // 'g-vector' ('sensitivity') so that the original is preserved while the calculations are ongoing.

         for(j=0;j<uniaxial_no_lu[i];j++)
         {
             for(k=0;k<uniaxial_no_lu[i];k++)
             {
                 these_lu_parameters[j][k] = uniaxial_lu_parameters[i][j][k];
             };
             these_indices[j] = uniaxial_indices[i][j];
             these_sensitivities[j] = uniaxial_sensitivity[i][j];
         };
     // perform a backsubstitution algorithm to determine the uncertainties.
     //    call backsub(these_lu_parameters,no_lu_parameters(i7),these_indices,these_sensitivities,max_lu_parameters)
     int l, m;
     // 'the_sum' is a variable that is used to perform sumations for each iteration of the backsubstitution.
     double the_sum;
     // specify a "tolerance" such that if the value of "the_sum" exceeds it, "the_sum" is taken to be nonzero.  It is not safe to use
     // "if(the_sum == 0)", since any small perturbation in very small decimanl places would cause the logical test to return FALSE.
     double tolerance = 1.0E-12;
     //----------------------------------------------------------------------------------------------------------------------------------//
     // the following are the equivalent variables between this subroutine and the Numerical Recipes original:
     // uniaxial_no_lu[i[ == np; integer variable
     // max_lu_parameters == n; integer variable
     // these_indices[max_lu_parameters] == indx[n]; 'permutation vector'
     // these_lu_parameters[no_of_calculations][no_of_calculations] == a[np][np]; L/U decomposition of the matrix for which .  The
     //            decomposition is performed via another Numerical Recipes subroutine LUDCMP, and is done as part of the bigback program.
     // these_sensitivities[max_lu_parameters] == b[n]; Is originally the right-hand side vector in A.x=B, but is replaced by the values
     //                                                      of x, which is the solution to the problem (in this case, the sensitivities).
     //----------------------------------------------------------------------------------------------------------------------------------//
     // reset the varaible i (the coordinate of the first nonvanishing elment of the 'out_sense' or 'sensitivity' matrix).
         m=0;
         // do the following over all the necessary elements of the matrix - the matrix wil not be defined (or be 0) beyond this value for the
         // first dimension m.

         for(j=0;j<uniaxial_no_lu[i];j++)
         {
         // take an integer from the indices array
             k = these_indices[j]; // these_indices[j] agrees with these_inidces(j8) of the FORTRAN variant.
         // set the summation to be the 'sensitivity' of the output to the jth parameter.
             the_sum = these_sensitivities[k-1];// these_sensitivities[k-1] initially agrees with the FORTRAN variant, but diverges, e.g. after 13 loops in the first model...
         // swap the value of out_sense of the jth parameter to that of the kth parameter.

             these_sensitivities[k-1] = these_sensitivities[j];
         // if a nonzero sum has happened previously for the ith model:
             if(m != 0)
             {
                 for(l=m-1;l<j;l++)
                 {
         // perform a stepwise summation of the nonzero elements:
                     the_sum = the_sum - ( these_lu_parameters[j][l] * these_sensitivities[l] );
                 };
             }
             // if all elements have been zero so far, check to see if the current one is nonzero.
             else if(fabs(the_sum) >= fabs(tolerance))
             {
                 m = j+1;
             };
             these_sensitivities[j] = the_sum;
         };
         // now do the backsubstitution over all the element in the matrix for the ith model model:
         for(j=uniaxial_no_lu[i]-1;j>=0;j--)
         {
             the_sum = these_sensitivities[j];
             if(j < uniaxial_no_lu[i]-1)
             {
                 for(k=(j+1);k<uniaxial_no_lu[i];k++)
                 {
                     the_sum = the_sum - these_lu_parameters[j][k] * these_sensitivities[k];
                 };
             };
             these_sensitivities[j] = the_sum / these_lu_parameters[j][j];
         };

     // first ensure the total uncertainties for each model are set to zero and then use the new sensitivity-derived information to
     // calculate the actual uncertainties:
         uniaxial_uncertainties[i] = 0.0;
         for(j=0;j<uniaxial_no_lu[i];j++)
         {
             uniaxial_uncertainties[i] = uniaxial_uncertainties[i] + these_sensitivities[j] * uniaxial_sensitivity[i][j];
         };
     };
     double uniaxial_noise[9] = { 0.962230E-01, 0.983110E-01, 0.959220E-01, 0.953850E-01, 0.955360E-01, 0.953270E-01, 0.956790E-01, 0.941530E-01, 0.980330E-01 };
     double uniaxial_errors[9] = { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
     double uniaxial_overall_error = 0.0;
     double uniaxial_overall_uncertainty = 0.0;
     for(i=0;i<uniaxial_no_in_cttee;i++)
     {
         uniaxial_errors[i] = uniaxial_uncertainties[i] + uniaxial_noise[i]*uniaxial_noise[i];
         uniaxial_errors[i] = pow(uniaxial_errors[i],0.5) * ( uniaxial_maximum_output - uniaxial_minimum_output );
         uniaxial_overall_error = uniaxial_overall_error + uniaxial_errors[i]*uniaxial_errors[i];
     };
     uniaxial_overall_error = uniaxial_overall_error / uniaxial_no_in_cttee;
     uniaxial_overall_error = pow(uniaxial_overall_error,0.5);
     uniaxial_overall_uncertainty = pow(10.0,uniaxial_overall_error);




     //       Now do the bending model:

         // Make an array containing the sensitivities of the bending predictions to the inputs.
         double bending_sensitivity[5][251];//1+max_hu*(bending_no_inputs+2)=251
         // Initialise the bending_sensitivity array so that all elements are zero.
         for(i=0;i<bending_no_in_cttee;i++)
         {
             for(j=0;j<(1+max_hu*(bending_no_inputs+2));j++)
             {
                 bending_sensitivity[i][j] = 0.0;
             };
         };
     //----------------------------------------------------------------------------------------------------------------------------------//
     // i, j, k are dummy variables, 'no_required' is the number of calcualtions required to fully define the sensitivity,
     // 'this_factor' is avariable used when determining what element to write to.
         int bending_no_required=0;//,this_factor;
     // 'this_sum' is the summed sensitivity that is being calculated; 'upper exponential' and 'lower exponential' are e raised to + and
     // - he total sensitivities, respecitvely; 'this_cosh' and 'this_sinh' are the hyperbolic cosine and hyperbolic sine, dependent on
     // the 'upper_exponential' and lower_exponential' variables.
     //    double this_sum,upper_exponential,lower_exponential;//,this_cosh,this_sinh;
     //----------------------------------------------------------------------------------------------------------------------------------//
         this_factor=0;
         this_sum=0.0;
         upper_exponential=0.0;
         lower_exponential=0.0;
         this_cosh=0.0;
         this_sinh=0.0;
         for(i=0;i<bending_no_in_cttee;i++)
         {
     // calculate the number of calculations required to fully describe the sensitivity of the model's output to the input.
     // 25 is the maximum number of hidden units in each model and so gives the maximum number of calculations required.
     // When the number of hidden units is less than 25, the excess weights are 0, so result in a contribution of 0.
                 bending_no_required = 1 + bending_hidden_units[i] * (bending_no_inputs + 1);
     // go through each hidden unit in turn:
                 for(j=0;j<bending_hidden_units[i];j++)
                 {
     // calculate 'this_factor' to determine the element of the array 'sensitivity' to use in calculations
                     this_factor = j * (bending_no_inputs+1);
     // reset the variable 'this_sum' to start each sensitivity measure again.
                     this_sum = 0.0;
     // go through each input varaible:
                     for(k=0;k<bending_no_inputs;k++)
                     {
     // add the contribution of each combination of hidden unit and input to the sensitivity.
                         this_sum = this_sum + bending_weights_hu[i][j][k] * bending_normal_input[k];
                     };
     // add the contribution from the shift for the current hidden unit.
                     this_sum = this_sum + bending_theta_hu[i][j];
     // calculate the hyperbolic sine and cosine functions to use when determining the sensitivity:
                     upper_exponential = exp(this_sum);
                     lower_exponential = exp(-this_sum);
                     this_cosh = 0.5 * (upper_exponential + lower_exponential);
                     this_sinh = 0.5 * (upper_exponential - lower_exponential);
     // calcualte an intermediate answer on the way to arriving at the sensitivity.
                     bending_sensitivity[i][this_factor] = (bending_weights_models[i][j] / (this_cosh*this_cosh));
     // go through each input and copy the values of the sensitivity equal to the differentail of the output.  Since the output is a tanh
     // function (default in bigback, which powers Model Manager), the differential is a cosh^2 function.
                     for(k=0;k<bending_no_inputs;k++)
                     {
                         bending_sensitivity[i][k+1+this_factor] = bending_sensitivity[i][this_factor] * bending_normal_input[k];
                     }
     // Not sure about this as it seems to be calculating the output (tanh(sum of weights*inputs+theta)) and storing it in the final
     // no_hidden_units elements).
                     bending_sensitivity[i][bending_no_required+j] = this_sinh / this_cosh;
                 };
                 bending_sensitivity[i][bending_no_required-1] = 1.0;
         };

     // 'no_in_cttee'is the number of models in the committee; 'no_inputs' is the number of input variables; 'max_hidden_units' is the
     // maximum number of hidden units in any one model of the committee (the maximum value of any element inthe array 'no_hidden_units');
     // max_lu_parameters if the largest possible number of parameters in the .lu file of any model in the committee.
     //    int bending_max_lu = 1 + max_hu * ( 2 + bending_no_inputs );
     // 'no_hidden_units' is the number of hidden units in each model in the committee.
         int bending_no_lu[5];
         for(i=0;i<bending_no_in_cttee;i++)
         {
             bending_no_lu[i] = 1 + (2+bending_no_inputs) * bending_hidden_units[i];
         };
    // 'indices' is the array containing integers related to the 'lu_parameters', read in the subroutine 'read_lu'.
         int bending_indices[5][251] = {
             { 152, 185,   4, 210,  14,   7,  13, 134,  18, 214, 184, 205, 175,  58,  34,  58,  58,  89, 116, 160,  80,  98,  68,  89,  88,  49, 142, 182, 157,  59, 208,  70,  34,  78,  62, 189,  42, 184, 197, 143,  43, 185, 143,  53,  71,  53,  56,  85, 161,  61, 184, 184, 202, 161,  60, 187,  66,  75, 181,  98, 178,  62,  63, 139,  76, 132, 130,  76, 130, 130, 143, 106, 140,  74, 176, 143, 210, 158,  99, 176, 170, 159, 160, 176, 193, 208,  87,  99, 115, 112, 107, 179, 176, 121,  99,  97, 205, 112, 139, 106, 210, 162, 103, 170, 160, 121, 187, 196, 157, 110, 129, 124, 130, 134, 133, 188, 129, 166, 119, 179, 196, 214, 205, 141, 181, 134, 135, 128, 216, 132, 208, 195, 184, 180, 158, 152, 137, 138, 174, 189, 161, 181, 186, 148, 184, 146, 176, 177, 171, 208, 192, 155, 189, 171, 171, 156, 185, 195, 180, 177, 197, 216, 174, 164, 208, 192, 197, 205, 172, 179, 181, 178, 173, 178, 186, 193, 185, 214, 185, 186, 189, 210, 183, 205, 185, 189, 195, 211, 197, 193, 191, 210, 197, 194, 214, 197, 211, 198, 212, 204, 210, 214, 214, 204, 208, 210, 210, 210, 211, 216, 211, 212, 216, 214, 215, 216, 217, 218, 219, 220, 221,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
             { 224, 131, 239,   4, 130, 230, 242,  16, 135, 248, 152, 143, 161, 130, 242, 128, 166,  53, 214, 206, 161, 125, 133, 211, 193, 166, 178, 204, 210,  67,  50,  71, 128,  50,  60, 231,  37,  38,  39,  40,  41,  42,  43,  44,  45, 130, 249,  49,  58,  60,  52, 215, 213, 169, 197,  62, 148,  67, 213, 176,  61, 135, 244, 112, 206, 188, 139, 134, 116, 193,  80, 215, 168, 131, 161, 157, 147, 160, 142, 176, 141, 214, 179,  84, 179, 116, 211, 175, 166, 135,  91,  92,  93,  94,  95,  96,  97,  98,  99, 100, 101, 102, 151, 133, 105, 106, 107, 108, 166, 196, 170, 125, 220, 178, 175, 249, 151, 132, 202, 138, 128, 223, 137, 128, 128, 193, 216, 143, 149, 235, 188, 225, 205, 184, 213, 176, 151, 149, 159, 140, 221, 202, 206, 144, 152, 188, 178, 179, 235, 212, 152, 188, 153, 157, 239, 159, 221, 239, 167, 180, 202, 167, 222, 182, 179, 214, 188, 211, 203, 242, 213, 205, 210, 174, 210, 212, 223, 223, 196, 216, 192, 182, 223, 205, 224, 230, 194, 230, 247, 215, 230, 235, 203, 197, 224, 224, 239, 224, 244, 248, 201, 248, 213, 230, 242, 220, 214, 219, 209, 239, 242, 225, 239, 216, 219, 220, 220, 218, 235, 223, 225, 230, 239, 239, 231, 244, 244, 244, 229, 249, 237, 237, 233, 237, 249, 236, 239, 238, 239, 240, 241, 249, 243, 249, 245, 246, 247, 248, 249, 250, 251 },
             {   8, 220,  23, 166,  22, 149, 210, 165,  72, 116,  44, 170,  98,  35,  70, 112, 115, 134,  86,  67, 188,  65, 214, 152, 149,  85, 210,  65, 167,  64, 149, 117,  87, 178,  80, 143, 166,  68, 197, 153, 149,  62, 125, 213,  72, 124, 212, 206,  53, 161, 111, 229, 230, 214,  88,  89,  64, 113, 148, 171, 176,  87,  75, 142, 164,  66, 107, 210, 107, 169, 160, 224, 151, 179, 220, 180, 115,  85,  79,  90, 148, 180, 179,  84, 167, 205, 157, 107, 106, 179,  99, 200, 200, 202, 167, 114, 205, 121, 138, 203, 146, 160, 168, 121, 180, 177, 171, 159, 113, 110, 229, 168, 207, 194, 185, 205, 142, 130, 119, 175, 186, 122, 125, 133, 168, 180, 202, 128, 207, 201, 185, 174, 176, 163, 220, 149, 177, 230, 174, 140, 168, 157, 188, 187, 175, 212, 147, 186, 186, 152, 192, 175, 174, 165, 161, 207, 177, 178, 210, 194, 200, 175, 180, 200, 175, 185, 193, 192, 204, 210, 194, 192, 177, 187, 224, 177, 193, 200, 220, 226, 206, 182, 183, 187, 187, 197, 213, 188, 193, 207, 191, 193, 213, 200, 195, 200, 201, 198, 212, 230, 204, 226, 210, 226, 226, 230, 212, 220, 223, 227, 229, 213, 231, 220, 220, 229, 229, 229, 226, 224, 221, 230, 226, 224, 225, 227, 229, 228, 230, 231, 231,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
             {   8,  77, 209, 184,  76, 191, 194, 179,  81, 202, 152, 210,  58, 107,  79, 188, 143,  97,  74, 134,  73, 183, 189, 143,  61, 125, 185, 207, 187, 142, 161, 200, 192,  94,  35, 204,  59,  79,  62,  58, 181,  96, 103,  80, 139,  80,  53, 116,  60,  89,  85, 182, 125,  71, 144,  63,  95, 140, 177, 140, 105,  98,  99,  92, 121,  78, 137, 188, 170,  75,  87, 150,  99, 144, 194, 138,  95, 130,  85, 191, 172, 175, 149, 105,  93, 182, 162, 114, 181, 141, 106, 106, 210,  97, 191, 186, 114,  98, 198, 151, 117, 116, 161, 114, 114, 116, 172, 184, 137, 124, 136, 132, 204, 182, 148, 184, 161, 183, 177, 126, 192, 203, 178, 132, 162, 184, 135, 159, 151, 209, 131, 157, 150, 150, 178, 143, 176, 179, 139, 183, 145, 162, 202, 186, 170, 175, 147, 194, 170, 200, 183, 189, 153, 182, 182, 186, 184, 159, 194, 160, 170, 178, 209, 209, 198, 203, 181, 168, 200, 183, 172, 200, 174, 210, 191, 207, 210, 189, 202, 188, 186, 191, 188, 202, 209, 207, 187, 198, 191, 210, 203, 194, 193, 203, 195, 200, 197, 209, 203, 203, 204, 209, 207, 204, 205, 206, 210, 208, 210, 210, 211,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
             {  17, 108, 179,   4, 116,  77,  81,  53,  61, 189, 103, 125,  62, 186,  35, 192, 187, 152, 101, 149, 147, 153, 139, 106,  26, 106, 134, 104,  44, 148, 146,  71,  89, 165, 153,  81, 183, 150, 143, 102,  76, 141,  80,  52,  98,  58, 195,  48, 161, 185, 170, 185, 113,  75, 113, 146, 192,  67,  97, 170, 116, 179, 146, 151, 115, 153,  89, 175,  69,  97, 166, 175, 146, 168, 146, 110, 149, 168, 123, 107, 146, 169, 179, 180, 170, 126, 171, 178, 102, 145, 147, 123, 135, 168, 176, 177, 108, 106, 111, 192, 138, 192, 114, 195, 105, 142, 126, 170, 177, 161, 168, 140, 175, 120, 144, 170, 139, 149, 120, 152, 196, 196, 186, 177, 137, 130, 160, 132, 171, 177, 142, 192, 139, 166, 144, 196, 157, 168, 186, 140, 186, 150, 189, 166, 165, 152, 196, 171, 150, 187, 168, 192, 170, 159, 155, 156, 176, 176, 175, 176, 166, 162, 178, 164, 170, 187, 171, 178, 196, 173, 193, 176, 173, 174, 186, 196, 196, 196, 179, 192, 195, 198, 196, 192, 193, 193, 189, 192, 195, 195, 191, 196, 195, 194, 195, 196, 197, 198, 199, 200, 201,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
         };

    // the array 'uncertainties' will contain the sassessed uncertainties in the predictions, dependent on the 'sensitivity' array,
    // which is inturn dependent on the user-specified inputs and the lower/upper decomposition of the Hessian matrix for each model.
         double bending_uncertainties[5];
    // 'these_bending_sensitivities' is a copy of the row of the array 'sensitivity' that is associated with the model that is being considered
    // used to both ensure 'sensitivity' is not altered by this subroutine and to simplify the passing of values to the subroutine
    // 'backsub'.
         double these_bending_sensitivities[251];

    // bending_lu_parameters is defined outside the loop for memory allocation reasons.



    // 'these_indices' contains the 'indices' for the model currently being operated on.
        int these_bending_indices[251];
    // copy the lu_parameters for each model in turn to a two-dimension array - this simplifies the use of the 'backsub' subroutine.
        double these_bending_lu_parameters[251][251];
        for(j=0;j<251;j++)
        {
            these_bending_indices[j] = -164;
            for(k=0;k<251;k++)
            {
                these_bending_lu_parameters[j][k] = -4536334.2432432;
            };
        };
        for(i=0;i<bending_no_in_cttee;i++)
        {
        // determine the number of calculations required to calculate the uncertainty in the prediction of each model.  Equal to the number
        // of weights (no. inputs * no. hidden units + no. hidden units) + the number of offsets (no_hidden_units + 1).  This is equal to
        // each dimension of the array containing the 'lu_parameters' (i.e, equal to 'no_lu_paramters' in the 'read_lu' subroutine).
        // copy the 'lu_parameters' for the current (i7th) model to a two-dimension array 'these_lu_parameters'.  This simplifies the use of
        // the 'backsub' subroutine.  Similarly, reduce the dimensionality of 'indices' from two to one.  Finally, make a copy of the
        // 'g-vector' ('sensitivity') so that the original is preserved while the calculations are ongoing.

            for(j=0;j<bending_no_lu[i];j++)
            {
                for(k=0;k<bending_no_lu[i];k++)
                {
                    these_bending_lu_parameters[j][k] = bending_lu_parameters[i][j][k];
                };
                these_bending_indices[j] = bending_indices[i][j];
                these_bending_sensitivities[j] = bending_sensitivity[i][j];
            };
        // perform a backsubstitution algorithm to determine the uncertainties.
        //    call backsub(these_lu_parameters,no_lu_parameters(i7),these_indices,these_bending_sensitivities,max_lu_parameters)
        int l, m;
        // 'the_sum' is a variable that is used to perform sumations for each iteration of the backsubstitution.
        double the_sum;
        // specify a "tolerance" such that if the value of "the_sum" exceeds it, "the_sum" is taken to be nonzero.  It is not safe to use 
        // "if(the_sum == 0)", since any small perturbation in very small decimanl places would cause the logical test to return FALSE.
        double tolerance = 1.0E-12;
        //----------------------------------------------------------------------------------------------------------------------------------//
        // the following are the equivalent variables between this subroutine and the Numerical Recipes original:
        // bending_no_lu[i[ == np; integer variable
        // max_lu_parameters == n; integer variable
        // these_indices[max_lu_parameters] == indx[n]; 'permutation vector'
        // these_lu_parameters[no_of_calculations][no_of_calculations] == a[np][np]; L/U decomposition of the matrix for which .  The
        //            decomposition is performed via another Numerical Recipes subroutine LUDCMP, and is done as part of the bigback program.
        // these_bending_sensitivities[max_lu_parameters] == b[n]; Is originally the right-hand side vector in A.x=B, but is replaced by the values
        //                                                      of x, which is the solution to the problem (in this case, the sensitivities).
        //----------------------------------------------------------------------------------------------------------------------------------//
        // reset the varaible i (the coordinate of the first nonvanishing elment of the 'out_sense' or 'sensitivity' matrix).
            m=0;
            // do the following over all the necessary elements of the matrix - the matrix wil not be defined (or be 0) beyond this value for the
            // first dimension m.

            for(j=0;j<bending_no_lu[i];j++)
            {
            // take an integer from the indices array
                k = these_bending_indices[j]; // these_indices[j] agrees with these_inidces(j8) of the FORTRAN variant.
            // set the summation to be the 'sensitivity' of the output to the jth parameter.
                the_sum = these_bending_sensitivities[k-1];// these_bending_sensitivities[k-1] initially agrees with the FORTRAN variant, but diverges, e.g. after 13 loops in the first model...
           // swap the value of out_sense of the jth parameter to that of the kth parameter.

                these_bending_sensitivities[k-1] = these_bending_sensitivities[j];
            // if a nonzero sum has happened previously for the ith model:
                if(m != 0)
                {
                    for(l=m-1;l<j;l++)
                    {
            // perform a stepwise summation of the nonzero elements:
                        the_sum = the_sum - ( these_bending_lu_parameters[j][l] * these_bending_sensitivities[l] );
                    };
                }
                // if all elements have been zero so far, check to see if the current one is nonzero.
                else if(fabs(the_sum) >= fabs(tolerance))
                {
                    m = j+1;
                };
                these_bending_sensitivities[j] = the_sum;
            };
            // now do the backsubstitution over all the element in the matrix for the ith model model:
            for(j=bending_no_lu[i]-1;j>=0;j--)
            {
                the_sum = these_bending_sensitivities[j];
                if(j < bending_no_lu[i]-1)
                {
                    for(k=(j+1);k<bending_no_lu[i];k++)
                    {
                        the_sum = the_sum - these_bending_lu_parameters[j][k] * these_bending_sensitivities[k];
                    };
                };
                these_bending_sensitivities[j] = the_sum / these_bending_lu_parameters[j][j];
            };

        // first ensure the total uncertainties for each model are set to zero and then use the new sensitivity-derived information to
        // calculate the actual uncertainties:
            bending_uncertainties[i] = 0.0;
            for(j=0;j<bending_no_lu[i];j++)
            {
                bending_uncertainties[i] = bending_uncertainties[i] + these_bending_sensitivities[j] * bending_sensitivity[i][j];
            };
        };
        double bending_noise[5] = { 0.645260E-01, 0.659350E-01, 0.641650E-01, 0.654640E-01, 0.647950E-01 };
        double bending_errors[5] = { 0.0, 0.0, 0.0, 0.0, 0.0 };
        double bending_overall_error = 0.0;
        double bending_overall_uncertainty = 0.0;

        for(i=0;i<bending_no_in_cttee;i++)
        {
            bending_errors[i] = bending_uncertainties[i] + bending_noise[i]*bending_noise[i];
            bending_errors[i] = pow(bending_errors[i],0.5) * ( bending_maximum_output - bending_minimum_output );
            bending_overall_error = bending_overall_error + bending_errors[i]*bending_errors[i];
        };

        bending_overall_error = bending_overall_error / bending_no_in_cttee;
        bending_overall_error = pow(bending_overall_error,0.5);
        bending_overall_uncertainty = pow(10.0,bending_overall_error);










    //       Now do the torsion model:

        // Make an array containing the sensitivities of the torsion predictions to the inputs.
        double torsion_sensitivity[6][226];//1+max_hu*(torsion_no_inputs+2)=226
        // Initialise the torsion_sensitivity array so that all elements are zero.
        for(i=0;i<torsion_no_in_cttee;i++)
        {
            for(j=0;j<(1+max_hu*(torsion_no_inputs+2));j++)
            {
                torsion_sensitivity[i][j] = 0.0;
            };
        };
    //----------------------------------------------------------------------------------------------------------------------------------//
    // i, j, k are dummy variables, 'no_required' is the number of calcualtions required to fully define the sensitivity, 
    // 'this_factor' is avariable used when determining what element to write to.
        int torsion_no_required=0;//,this_factor;
    // 'this_sum' is the summed sensitivity that is being calculated; 'upper exponential' and 'lower exponential' are e raised to + and
    // - he total sensitivities, respecitvely; 'this_cosh' and 'this_sinh' are the hyperbolic cosine and hyperbolic sine, dependent on
    // the 'upper_exponential' and lower_exponential' variables.
    //    double this_sum,upper_exponential,lower_exponential;//,this_cosh,this_sinh;
    //----------------------------------------------------------------------------------------------------------------------------------//
        this_factor=0;
        this_sum=0.0;
        upper_exponential=0.0;
        lower_exponential=0.0;
        this_cosh=0.0;
        this_sinh=0.0;
        for(i=0;i<torsion_no_in_cttee;i++)
        {
    // calculate the number of calculations required to fully describe the sensitivity of the model's output to the input.
    // 25 is the maximum number of hidden units in each model and so gives the maximum number of calculations required.
    // When the number of hidden units is less than 25, the excess weights are 0, so result in a contribution of 0.
                torsion_no_required = 1 + torsion_hidden_units[i] * (torsion_no_inputs + 1);
    // go through each hidden unit in turn:
                for(j=0;j<torsion_hidden_units[i];j++)
                {
    // calculate 'this_factor' to determine the element of the array 'sensitivity' to use in calculations
                    this_factor = j * (torsion_no_inputs+1);
    // reset the variable 'this_sum' to start each sensitivity measure again.
                    this_sum = 0.0;
    // go through each input varaible:
                    for(k=0;k<torsion_no_inputs;k++)
                    {
    // add the contribution of each combination of hidden unit and input to the sensitivity.
                        this_sum = this_sum + torsion_weights_hu[i][j][k] * torsion_normal_input[k];
                    };
    // add the contribution from the shift for the current hidden unit.
                    this_sum = this_sum + torsion_theta_hu[i][j];
    // calculate the hyperbolic sine and cosine functions to use when determining the sensitivity:
                    upper_exponential = exp(this_sum);
                    lower_exponential = exp(-this_sum);
                    this_cosh = 0.5 * (upper_exponential + lower_exponential);
                    this_sinh = 0.5 * (upper_exponential - lower_exponential);
    // calcualte an intermediate answer on the way to arriving at the sensitivity.
                    torsion_sensitivity[i][this_factor] = (torsion_weights_models[i][j] / (this_cosh*this_cosh));
    // go through each input and copy the values of the sensitivity equal to the differentail of the output.  Since the output is a tanh
    // function (default in bigback, which powers Model Manager), the differential is a cosh^2 function.
                    for(k=0;k<torsion_no_inputs;k++)
                    {
                        torsion_sensitivity[i][k+1+this_factor] = torsion_sensitivity[i][this_factor] * torsion_normal_input[k];
                    }
    // Not sure about this as it seems to be calculating the output (tanh(sum of weights*inputs+theta)) and storing it in the final
    // no_hidden_units elements).
                    torsion_sensitivity[i][torsion_no_required+j] = this_sinh / this_cosh;
                };
                torsion_sensitivity[i][torsion_no_required-1] = 1.0;
        };

    // 'no_in_cttee'is the number of models in the committee; 'no_inputs' is the number of input variables; 'max_hidden_units' is the
    // maximum number of hidden units in any one model of the committee (the maximum value of any element inthe array 'no_hidden_units');
    // max_lu_parameters if the largest possible number of parameters in the .lu file of any model in the committee.
    //    int torsion_max_lu = 1 + max_hu * ( 2 + torsion_no_inputs );
    // 'no_hidden_units' is the number of hidden units in each model in the committee.
        int torsion_no_lu[6];
        for(i=0;i<torsion_no_in_cttee;i++)
        {
            torsion_no_lu[i] = 1 + (2+torsion_no_inputs) * torsion_hidden_units[i];
        };
    // 'indices' is the array containing integers related to the 'lu_parameters', read in the subroutine 'read_lu'.
        int torsion_indices[6][226] = {
            {  99,  26, 169,  47, 170, 162, 154,  39, 103, 143,  87, 135, 146,  71,  93,  95,  50,  36, 159,  79, 147, 111,  80,  56,  29,  77, 152, 154, 101,  32, 119,  76,  37,  80, 138,  55,  92, 166, 144, 100,  91,  53,  74, 130,  90,  72,  82, 119,  88, 151, 136, 136,  80,  78,  75, 134, 151,  75, 159,  79,  61, 111,  63, 134, 104,  66, 106, 159, 115, 139,  87, 138, 141, 159,  79,  98, 115, 102, 144, 144, 112, 115, 134, 134, 102, 149, 111,  93, 134, 169, 143, 135, 166, 163, 130,  96, 148, 152, 159, 144, 160, 154, 119, 141, 149, 117, 107, 163, 141, 110, 134, 130, 148, 151, 139, 147, 146, 144, 169, 120, 121, 122, 123, 124, 125, 126, 127, 128, 162, 170, 131, 151, 139, 134, 169, 136, 147, 160, 142, 141, 147, 162, 154, 147, 147, 166, 154, 163, 154, 150, 151, 163, 162, 169, 159, 156, 169, 158, 160, 170, 161, 166, 163, 164, 165, 169, 167, 168, 170, 170, 171, 172,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
            { 133,  82, 204, 206, 101, 167, 223,  88, 183,  95,  74, 111, 135, 209,  39,  83,  87,  23, 159, 163, 165, 108,  77, 119,  90,  82, 204, 135, 101, 167, 223, 206,  79,  91, 223, 115,  77,  86, 127,  95,  74, 117,  47,  93, 131, 127, 223,  84,  90,  82, 204, 135, 101, 167,  55, 206, 122,  85, 164, 103, 125, 154, 133, 135, 159,  66,  67,  68,  69,  70,  71,  88,  75, 159,  77,  94, 167,  95, 215, 204,  88, 114, 114, 130, 204, 109,  88,  99,  95, 101, 168, 106, 209,  94, 133, 164, 131, 168, 162, 206, 181, 209, 168, 126, 129, 106, 156, 111, 125, 168, 157, 112, 166, 216, 204, 116, 181, 156, 127, 168, 154, 132, 134, 134, 223, 209, 127, 167, 222, 209, 165, 178, 175, 203, 206, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 154, 175, 155, 209, 223, 158, 203, 216, 216, 168, 167, 204, 181, 204, 223, 223, 169, 170, 171, 172, 173, 174, 216, 206, 178, 184, 204, 204, 209, 203, 206, 204, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 206, 202, 204, 206, 205, 215, 209, 208, 209, 210, 211, 216, 215, 214, 222, 222, 217, 218, 219, 220, 221, 223, 223, 224, 225, 226 }, 
            { 179, 180, 162,  71, 181, 178,  55, 170, 127,  55,  51,  23,  39,  26, 135, 175,  36, 159, 125, 135, 111, 103, 151,  32, 125,  30,  53, 128, 123,  56,  45, 175, 119, 150,  98,  99,  72,  72,  47,  40,  45,  42, 181, 181, 133, 159,  56,  69, 131,  69,  51, 143, 111, 170,  56, 143, 127, 143, 130, 151,  72, 165,  69, 157, 123,  66, 157, 135, 152, 160, 165, 157, 127, 143, 130, 151, 157, 111, 152,  80,  81,  82,  83,  84,  85,  86,  87,  88,  89,  90,  91,  92,  93,  94,  95,  96, 103, 150, 150, 104, 106, 159, 126, 104, 122, 151, 152, 111, 130, 170, 130, 149, 128, 152, 115, 149, 125, 147, 157, 152, 150, 134, 151, 146, 147, 159, 152, 146, 143, 175, 157, 162, 170, 160, 181, 136, 137, 138, 139, 140, 141, 142, 152, 144, 149, 147, 162, 159, 151, 157, 151, 170, 178, 154, 181, 181, 157, 180, 162, 181, 180, 165, 163, 164, 181, 166, 167, 168, 169, 179, 171, 172, 173, 174, 175, 176, 177, 181, 181, 181, 181,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 }, 
            {  95, 139, 140, 139,  69,   8, 119,  31,  55, 112, 106, 137,  15, 127,  87, 119,  50,  47,  23,  69, 116,  71, 131, 114,  82, 117, 112,  31,  88,  79,  88,  63, 125, 117,  39, 144, 116, 107,  85, 111,  54,  56, 137,  80,  53, 127, 115, 114, 109, 122,  53,  53, 124,  77, 140,  80, 103,  80,  63,  83,  66, 117, 106, 115, 112,  87,  68, 131, 111,  71,  87, 138, 131,  74,  75, 144, 116, 124, 107, 131, 131,  95, 105, 125, 118, 107, 125, 119,  89,  90,  91,  92,  93,  94, 118,  96,  97,  98,  99, 100, 101, 102, 139, 104, 127, 131, 127, 144, 119, 110, 124, 118, 138, 115, 132, 131, 118, 144, 124, 120, 144, 132, 124, 124, 137, 144, 137, 128, 144, 144, 140, 132, 144, 140, 135, 136, 144, 139, 140, 144, 141, 142, 143, 144, 145,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
            { 171,  66, 154, 165, 166, 157,   7, 143,  47,  18,  71, 135,  13, 103,  67,  19,  24,  55,  87,  23, 119,  67,  79, 141, 135, 127, 111,  66, 109, 172, 151,  51, 163,  67, 119, 119,  63,  67,  58, 139,  79, 119,  77,  99, 151,  69,  95,  98,  50,  80,  58, 167, 144,  71,  80, 144, 133, 167,  80, 107, 128,  63, 147, 115,  72, 138,  71, 144, 149,  75, 128, 122, 101,  74, 144, 125, 154, 142, 108, 136, 131,  82, 139, 106, 141, 123, 128, 154, 159,  90,  91, 106, 167, 159,  98, 106, 151, 109, 167, 106, 136, 127, 138, 106, 166, 141, 158, 142, 154, 138, 144, 112, 158, 114, 139, 116, 123, 159, 152, 128, 127, 128, 158, 172, 146, 149, 165, 172, 139, 130, 165, 144, 135, 158, 167, 144, 165, 146, 158, 158, 151, 147, 165, 158, 166, 172, 154, 149, 159, 150, 166, 165, 159, 163, 155, 172, 160, 165, 159, 172, 167, 162, 165, 164, 165, 166, 171, 168, 169, 170, 171, 172,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 },
            {  91,  79,  82,  90,  37,  63,  31,  83,  23,  31,  44,  47,  34,  29,  53,  29,  71,  39,  35,  26,  55,  24,  37,  35,  45,  32,  53,  61,  55,  56,  47,  43,  38,  76,  83,  43,  67,  74,  69,  75,  46,  77,  66,  54,  82,  53,  63,  66,  70,  69,  53,  56,  53,  64,  61,  66,  82,  58,  59,  70,  77,  62,  79,  72,  80,  75,  78,  75,  76,  72,  79,  75,  83,  75,  82,  91,  82,  79,  90,  82,  87,  91,  90,  84,  86,  90,  87,  88,  90,  91,  91,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0 }
        };

    // the array 'uncertainties' will contain the sassessed uncertainties in the predictions, dependent on the 'sensitivity' array,
    // which is inturn dependent on the user-specified inputs and the lower/upper decomposition of the Hessian matrix for each model.
        double torsion_uncertainties[6];
    // 'these_torsion_sensitivities' is a copy of the row of the array 'sensitivity' that is associated with the model that is being considered
    // used to both ensure 'sensitivity' is not altered by this subroutine and to simplify the passing of values to the subroutine
    // 'backsub'.
        double these_torsion_sensitivities[226];


    // torsion_lu_parameters are defined outside this loop for memory allocation reasons.




    // 'these_indices' contains the 'indices' for the model currently being operated on.
        int these_torsion_indices[226];
    // copy the lu_parameters for each model in turn to a two-dimension array - this simplifies the use of the 'backsub' subroutine.
        double these_torsion_lu_parameters[226][226];
        for(j=0;j<226;j++)
        {
            these_torsion_indices[j] = -164;
            for(k=0;k<226;k++)
            {
                these_torsion_lu_parameters[j][k] = -4536334.2432432;
            };
        };
        for(i=0;i<torsion_no_in_cttee;i++)
        {
        // determine the number of calculations required to calculate the uncertainty in the prediction of each model.  Equal to the number
        // of weights (no. inputs * no. hidden units + no. hidden units) + the number of offsets (no_hidden_units + 1).  This is equal to
        // each dimension of the array containing the 'lu_parameters' (i.e, equal to 'no_lu_paramters' in the 'read_lu' subroutine).
        // copy the 'lu_parameters' for the current (i7th) model to a two-dimension array 'these_lu_parameters'.  This simplifies the use of
        // the 'backsub' subroutine.  Similarly, reduce the dimensionality of 'indices' from two to one.  Finally, make a copy of the
        // 'g-vector' ('sensitivity') so that the original is preserved while the calculations are ongoing.

            for(j=0;j<torsion_no_lu[i];j++)
            {
                for(k=0;k<torsion_no_lu[i];k++)
                {
                    these_torsion_lu_parameters[j][k] = torsion_lu_parameters[i][j][k];
                };
                these_torsion_indices[j] = torsion_indices[i][j];
                these_torsion_sensitivities[j] = torsion_sensitivity[i][j];
            };
        // perform a backsubstitution algorithm to determine the uncertainties.
        //    call backsub(these_lu_parameters,no_lu_parameters(i7),these_indices,these_torsion_sensitivities,max_lu_parameters)
        int l, m;
        // 'the_sum' is a variable that is used to perform sumations for each iteration of the backsubstitution.
        double the_sum;
        // specify a "tolerance" such that if the value of "the_sum" exceeds it, "the_sum" is taken to be nonzero.  It is not safe to use 
        // "if(the_sum == 0)", since any small perturbation in very small decimanl places would cause the logical test to return FALSE.
        double tolerance = 1.0E-12;
        //----------------------------------------------------------------------------------------------------------------------------------//
        // the following are the equivalent variables between this subroutine and the Numerical Recipes original:
        // torsion_no_lu[i[ == np; integer variable
        // max_lu_parameters == n; integer variable
        // these_indices[max_lu_parameters] == indx[n]; 'permutation vector'
        // these_lu_parameters[no_of_calculations][no_of_calculations] == a[np][np]; L/U decomposition of the matrix for which .  The
        //            decomposition is performed via another Numerical Recipes subroutine LUDCMP, and is done as part of the bigback program.
        // these_torsion_sensitivities[max_lu_parameters] == b[n]; Is originally the right-hand side vector in A.x=B, but is replaced by the values
        //                                                      of x, which is the solution to the problem (in this case, the sensitivities).
        //----------------------------------------------------------------------------------------------------------------------------------//
        // reset the varaible i (the coordinate of the first nonvanishing elment of the 'out_sense' or 'sensitivity' matrix).
            m=0;
            // do the following over all the necessary elements of the matrix - the matrix wil not be defined (or be 0) beyond this value for the
            // first dimension m.

            for(j=0;j<torsion_no_lu[i];j++)
            {
            // take an integer from the indices array
                k = these_torsion_indices[j]; // these_indices[j] agrees with these_inidces(j8) of the FORTRAN variant.
            // set the summation to be the 'sensitivity' of the output to the jth parameter.
                the_sum = these_torsion_sensitivities[k-1];// these_torsion_sensitivities[k-1] initially agrees with the FORTRAN variant, but diverges, e.g. after 13 loops in the first model...
            // swap the value of out_sense of the jth parameter to that of the kth parameter.

                these_torsion_sensitivities[k-1] = these_torsion_sensitivities[j];
            // if a nonzero sum has happened previously for the ith model:
                if(m != 0)
                {
                    for(l=m-1;l<j;l++)
                    {
            // perform a stepwise summation of the nonzero elements:
                        the_sum = the_sum - ( these_torsion_lu_parameters[j][l] * these_torsion_sensitivities[l] );

                    };
               }
                // if all elements have been zero so far, check to see if the current one is nonzero.
                else if(fabs(the_sum) >= fabs(tolerance))
                {
                    m = j+1;
                };
                these_torsion_sensitivities[j] = the_sum;
           };
            // now do the backsubstitution over all the element in the matrix for the ith model model:
            for(j=torsion_no_lu[i]-1;j>=0;j--)
            {
                the_sum = these_torsion_sensitivities[j];
                if(j < torsion_no_lu[i]-1)
                {
                    for(k=(j+1);k<torsion_no_lu[i];k++)
                    {
                        the_sum = the_sum - these_torsion_lu_parameters[j][k] * these_torsion_sensitivities[k];
                    };
                };
                these_torsion_sensitivities[j] = the_sum / these_torsion_lu_parameters[j][j];
            };

        // first ensure the total uncertainties for each model are set to zero and then use the new sensitivity-derived information to
        // calculate the actual uncertainties:
            torsion_uncertainties[i] = 0.0;
            for(j=0;j<torsion_no_lu[i];j++)
            {
                torsion_uncertainties[i] = torsion_uncertainties[i] + these_torsion_sensitivities[j] * torsion_sensitivity[i][j];
            };
        };
        double torsion_noise[6] = { 0.104800E+00, 0.104570E+00, 0.104760E+00, 0.105640E+00, 0.104330E+00, 0.106960E+00 };
        double torsion_errors[6] = { 0.0, 0.0, 0.0, 0.0, 0.0 };
        double torsion_overall_error = 0.0;
        double torsion_overall_uncertainty = 0.0;

        for(i=0;i<torsion_no_in_cttee;i++)
        {
            torsion_errors[i] = torsion_uncertainties[i] + torsion_noise[i]*torsion_noise[i];
            torsion_errors[i] = pow(torsion_errors[i],0.5) * ( torsion_maximum_output - torsion_minimum_output );
            torsion_overall_error = torsion_overall_error + torsion_errors[i]*torsion_errors[i];
        };

        torsion_overall_error = torsion_overall_error / torsion_no_in_cttee;
        torsion_overall_error = pow(torsion_overall_error,0.5);
        torsion_overall_uncertainty = pow(10.0,torsion_overall_error);




       uncertaintyBending.sprintf("%8.2E",bending_overall_uncertainty);
       uncertaintyUniaxial.sprintf("%8.2E",uniaxial_overall_uncertainty);
       uncertaintyTorsional.sprintf("%8.2E",torsion_overall_uncertainty);
       ui->uncertaintyBending->setText(uncertaintyBending);
       ui->uncertaintyUniaxial->setText(uncertaintyUniaxial);
       ui->uncertaintyTorsional->setText(uncertaintyTorsional);
    };
    
};

void MainWindow::on_helpButton_clicked()
{
    QString the_manual = QCoreApplication::applicationDirPath();
    the_manual.append("/FLiPS_user_manual.pdf");
    QDesktopServices::openUrl(QUrl::fromLocalFile(the_manual));
};

void MainWindow::on_OnlineDataButton_clicked()
{
    QString the_data_url = QString("http://smds.nims.go.jp/openTest/en/content/fatiguelist.html");
    QDesktopServices::openUrl(the_data_url);
};


void MainWindow::on_datafileButton_clicked()
{
    QString the_data_file = QCoreApplication::applicationDirPath();
    the_data_file.append("/FLiPS_source_data.txt");
    QDesktopServices::openUrl(QUrl::fromLocalFile(the_data_file));
};
